/*
Package main is a generated package which contains definitions
of structs which represent a YANG schema. The generated schema can be
compressed by a series of transformations (compression was false
in this case).

This package was generated by /Users/mk/go/pkg/mod/github.com/openconfig/ygot@v0.10.13/genutil/names.go
using the following YANG input files:
	- models/openconfig/public/release/models/interfaces/openconfig-interfaces.yang
	- models/openconfig/public/release/models/openflow/openconfig-openflow.yang
	- models/openconfig/public/release/models/platform/openconfig-platform.yang
	- models/openconfig/public/release/models/system/openconfig-system.yang
	- models/openconfig/public/release/models/acl/openconfig-acl.yang
	- models/openconfig/public/release/models/network-instance/openconfig-network-instance.yang
Imported modules were sourced from:
	- models/...
*/
package main

import (
	"encoding/json"
	"fmt"
	"reflect"

	gpb "github.com/openconfig/gnmi/proto/gnmi"
	"github.com/openconfig/goyang/pkg/yang"
	"github.com/openconfig/ygot/ygot"
	"github.com/openconfig/ygot/ytypes"

	spb "code.fbi.h-da.de/danet/gosdn/api/go/gosdn/southbound"
	"github.com/google/uuid"
	"github.com/openconfig/ygot/util"
	log "github.com/sirupsen/logrus"
)

var PluginSymbol Csbi

// Binary is a type that is used for fields that have a YANG type of
// binary. It is used such that binary fields can be distinguished from
// leaf-lists of uint8s (which are mapped to []uint8, equivalent to
// []byte in reflection).
type Binary []byte

// YANGEmpty is a type that is used for fields that have a YANG type of
// empty. It is used such that empty fields can be distinguished from boolean fields
// in the generated code.
type YANGEmpty bool

var (
	SchemaTree map[string]*yang.Entry
)

func init() {
	var err error
	if SchemaTree, err = UnzipSchema(); err != nil {
		panic("schema error: " + err.Error())
	}
}

// Schema returns the details of the generated schema.
func Schema() (*ytypes.Schema, error) {
	uzp, err := UnzipSchema()
	if err != nil {
		return nil, fmt.Errorf("cannot unzip schema, %v", err)
	}

	return &ytypes.Schema{
		Root:       &Device{},
		SchemaTree: uzp,
		Unmarshal:  Unmarshal,
	}, nil
}

// UnzipSchema unzips the zipped schema and returns a map of yang.Entry nodes,
// keyed by the name of the struct that the yang.Entry describes the schema for.
func UnzipSchema() (map[string]*yang.Entry, error) {
	var schemaTree map[string]*yang.Entry
	var err error
	if schemaTree, err = ygot.GzipToSchema(ySchema); err != nil {
		return nil, fmt.Errorf("could not unzip the schema; %v", err)
	}
	return schemaTree, nil
}

// Unmarshal unmarshals data, which must be RFC7951 JSON format, into
// destStruct, which must be non-nil and the correct GoStruct type. It returns
// an error if the destStruct is not found in the schema or the data cannot be
// unmarshaled. The supplied options (opts) are used to control the behaviour
// of the unmarshal function - for example, determining whether errors are
// thrown for unknown fields in the input JSON.
func Unmarshal(data []byte, destStruct ygot.GoStruct, opts ...ytypes.UnmarshalOpt) error {
	tn := reflect.TypeOf(destStruct).Elem().Name()
	schema, ok := SchemaTree[tn]
	if !ok {
		return fmt.Errorf("could not find schema for type %s", tn)
	}
	var jsonTree interface{}
	if err := json.Unmarshal([]byte(data), &jsonTree); err != nil {
		return err
	}
	return ytypes.Unmarshal(schema, destStruct, jsonTree, opts...)
}

// ΓModelData contains the catalogue information corresponding to the modules for
// which Go code was generated.
var ΓModelData = []*gpb.ModelData{
	{
		Name:         "iana-if-type",
		Organization: "IANA",
	},
	{
		Name:         "ietf-inet-types",
		Organization: "IETF NETMOD (NETCONF Data Modeling Language) Working Group",
	},
	{
		Name:         "ietf-interfaces",
		Organization: "IETF NETMOD (Network Modeling) Working Group",
	},
	{
		Name:         "ietf-yang-types",
		Organization: "IETF NETMOD (NETCONF Data Modeling Language) Working Group",
	},
	{
		Name:         "openconfig-aaa",
		Organization: "OpenConfig working group",
		Version:      "0.5.0",
	},
	{
		Name:         "openconfig-aaa-types",
		Organization: "OpenConfig working group",
		Version:      "0.4.1",
	},
	{
		Name:         "openconfig-acl",
		Organization: "OpenConfig working group",
		Version:      "1.1.1",
	},
	{
		Name:         "openconfig-aft",
		Organization: "OpenConfig working group",
		Version:      "0.6.0",
	},
	{
		Name:         "openconfig-aft-types",
		Organization: "OpenConfig Working Group",
		Version:      "0.3.4",
	},
	{
		Name:         "openconfig-alarm-types",
		Organization: "OpenConfig working group",
		Version:      "0.2.1",
	},
	{
		Name:         "openconfig-alarms",
		Organization: "OpenConfig working group",
		Version:      "0.3.2",
	},
	{
		Name:         "openconfig-bfd",
		Organization: "OpenConfig working group",
		Version:      "0.2.2",
	},
	{
		Name:         "openconfig-bgp",
		Organization: "OpenConfig working group",
		Version:      "0.6.1",
	},
	{
		Name:         "openconfig-bgp-types",
		Organization: "OpenConfig working group",
		Version:      "5.3.0",
	},
	{
		Name:         "openconfig-extensions",
		Organization: "OpenConfig working group",
	},
	{
		Name:         "openconfig-if-aggregate",
		Organization: "OpenConfig working group",
		Version:      "2.4.3",
	},
	{
		Name:         "openconfig-if-ethernet",
		Organization: "OpenConfig working group",
		Version:      "2.10.0",
	},
	{
		Name:         "openconfig-if-types",
		Organization: "OpenConfig working group",
		Version:      "0.2.1",
	},
	{
		Name:         "openconfig-igmp",
		Organization: "OpenConfig working group",
		Version:      "0.2.0",
	},
	{
		Name:         "openconfig-igmp-types",
		Organization: "OpenConfig working group",
		Version:      "0.1.1",
	},
	{
		Name:         "openconfig-inet-types",
		Organization: "OpenConfig working group",
		Version:      "0.4.0",
	},
	{
		Name:         "openconfig-interfaces",
		Organization: "OpenConfig working group",
		Version:      "2.5.0",
	},
	{
		Name:         "openconfig-isis",
		Organization: "OpenConfig working group",
		Version:      "0.6.1",
	},
	{
		Name:         "openconfig-isis-lsdb-types",
		Organization: "OpenConfig working group",
		Version:      "0.4.2",
	},
	{
		Name:         "openconfig-isis-types",
		Organization: "OpenConfig working group",
		Version:      "0.4.3",
	},
	{
		Name:         "openconfig-license",
		Organization: "OpenConfig working group",
		Version:      "0.2.0",
	},
	{
		Name:         "openconfig-local-routing",
		Organization: "OpenConfig working group",
		Version:      "1.2.0",
	},
	{
		Name:         "openconfig-messages",
		Organization: "OpenConfig working group",
		Version:      "0.0.1",
	},
	{
		Name:         "openconfig-mpls",
		Organization: "OpenConfig working group",
		Version:      "3.1.0",
	},
	{
		Name:         "openconfig-mpls-ldp",
		Organization: "OpenConfig working group",
		Version:      "3.1.0",
	},
	{
		Name:         "openconfig-mpls-rsvp",
		Organization: "OpenConfig working group",
		Version:      "3.0.2",
	},
	{
		Name:         "openconfig-mpls-sr",
		Organization: "OpenConfig working group",
		Version:      "3.0.1",
	},
	{
		Name:         "openconfig-mpls-types",
		Organization: "OpenConfig working group",
		Version:      "3.2.0",
	},
	{
		Name:         "openconfig-network-instance",
		Organization: "OpenConfig working group",
		Version:      "0.14.0",
	},
	{
		Name:         "openconfig-network-instance-l3",
		Organization: "OpenConfig working group",
		Version:      "0.11.1",
	},
	{
		Name:         "openconfig-network-instance-types",
		Organization: "OpenConfig working group",
		Version:      "0.9.0",
	},
	{
		Name:         "openconfig-openflow",
		Organization: "OpenConfig working group",
		Version:      "0.1.2",
	},
	{
		Name:         "openconfig-openflow-types",
		Organization: "OpenConfig working group",
		Version:      "0.1.3",
	},
	{
		Name:         "openconfig-ospf-types",
		Organization: "OpenConfig working group",
		Version:      "0.1.3",
	},
	{
		Name:         "openconfig-ospfv2",
		Organization: "OpenConfig working group",
		Version:      "0.2.3",
	},
	{
		Name:         "openconfig-packet-match",
		Organization: "OpenConfig working group",
		Version:      "1.1.1",
	},
	{
		Name:         "openconfig-packet-match-types",
		Organization: "OpenConfig working group",
		Version:      "1.1.0",
	},
	{
		Name:         "openconfig-pim",
		Organization: "OpenConfig working group",
		Version:      "0.4.1",
	},
	{
		Name:         "openconfig-pim-types",
		Organization: "OpenConfig working group",
		Version:      "0.1.1",
	},
	{
		Name:         "openconfig-platform",
		Organization: "OpenConfig working group",
		Version:      "0.13.0",
	},
	{
		Name:         "openconfig-platform-types",
		Organization: "OpenConfig working group",
		Version:      "1.1.0",
	},
	{
		Name:         "openconfig-policy-forwarding",
		Organization: "OpenConfig working group",
		Version:      "0.2.1",
	},
	{
		Name:         "openconfig-policy-types",
		Organization: "OpenConfig working group",
		Version:      "3.1.1",
	},
	{
		Name:         "openconfig-procmon",
		Organization: "OpenConfig working group",
		Version:      "0.4.0",
	},
	{
		Name:         "openconfig-rib-bgp",
		Organization: "OpenConfig working group",
		Version:      "0.7.0",
	},
	{
		Name:         "openconfig-rib-bgp-types",
		Organization: "OpenConfig working group",
		Version:      "0.5.0",
	},
	{
		Name:         "openconfig-routing-policy",
		Organization: "OpenConfig working group",
		Version:      "3.2.2",
	},
	{
		Name:         "openconfig-segment-routing",
		Organization: "OpenConfig working group",
		Version:      "0.3.0",
	},
	{
		Name:         "openconfig-segment-routing-types",
		Organization: "OpenConfig working group",
		Version:      "0.2.0",
	},
	{
		Name:         "openconfig-srte-policy",
		Organization: "OpenConfig working group",
		Version:      "0.2.2",
	},
	{
		Name:         "openconfig-system",
		Organization: "OpenConfig working group",
		Version:      "0.9.1",
	},
	{
		Name:         "openconfig-system-logging",
		Organization: "OpenConfig working group",
		Version:      "0.3.1",
	},
	{
		Name:         "openconfig-system-management",
		Organization: "OpenConfig working group",
		Version:      "0.3.0",
	},
	{
		Name:         "openconfig-system-terminal",
		Organization: "OpenConfig working group",
		Version:      "0.3.1",
	},
	{
		Name:         "openconfig-types",
		Organization: "OpenConfig working group",
		Version:      "0.6.0",
	},
	{
		Name:         "openconfig-vlan",
		Organization: "OpenConfig working group",
		Version:      "3.2.0",
	},
	{
		Name:         "openconfig-vlan-types",
		Organization: "OpenConfig working group",
		Version:      "3.1.1",
	},
	{
		Name:         "openconfig-yang-types",
		Organization: "OpenConfig working group",
		Version:      "0.3.0",
	},
}

// Device represents the /device YANG schema element.
type Device struct {
	Acl              *OpenconfigAcl_Acl                          `path:"acl" module:"openconfig-acl"`
	Bfd              *OpenconfigBfd_Bfd                          `path:"bfd" module:"openconfig-bfd"`
	Bgp              *OpenconfigBgp_Bgp                          `path:"bgp" module:"openconfig-bgp"`
	Components       *OpenconfigPlatform_Components              `path:"components" module:"openconfig-platform"`
	Interfaces       *IETFInterfaces_Interfaces                  `path:"interfaces" module:"ietf-interfaces"`
	InterfacesState  *IETFInterfaces_InterfacesState             `path:"interfaces-state" module:"ietf-interfaces"`
	LocalRoutes      *OpenconfigLocalRouting_LocalRoutes         `path:"local-routes" module:"openconfig-local-routing"`
	Messages         *OpenconfigMessages_Messages                `path:"messages" module:"openconfig-messages"`
	NetworkInstances *OpenconfigNetworkInstance_NetworkInstances `path:"network-instances" module:"openconfig-network-instance"`
	RoutingPolicy    *OpenconfigRoutingPolicy_RoutingPolicy      `path:"routing-policy" module:"openconfig-routing-policy"`
	System           *OpenconfigSystem_System                    `path:"system" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that Device implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*Device) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *Device) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["Device"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *Device) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// IETFInterfaces_Interfaces represents the /ietf-interfaces/interfaces YANG schema element.
type IETFInterfaces_Interfaces struct {
	Interface map[string]*IETFInterfaces_Interfaces_Interface `path:"interface" module:"ietf-interfaces"`
}

// IsYANGGoStruct ensures that IETFInterfaces_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*IETFInterfaces_Interfaces) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// IETFInterfaces_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *IETFInterfaces_Interfaces) NewInterface(Name string) (*IETFInterfaces_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*IETFInterfaces_Interfaces_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &IETFInterfaces_Interfaces_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *IETFInterfaces_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["IETFInterfaces_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *IETFInterfaces_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// IETFInterfaces_InterfacesState represents the /ietf-interfaces/interfaces-state YANG schema element.
type IETFInterfaces_InterfacesState struct {
	Interface map[string]*IETFInterfaces_InterfacesState_Interface `path:"interface" module:"ietf-interfaces"`
}

// IsYANGGoStruct ensures that IETFInterfaces_InterfacesState implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*IETFInterfaces_InterfacesState) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// IETFInterfaces_InterfacesState struct. The keys of the list are populated from the input
// arguments.
func (t *IETFInterfaces_InterfacesState) NewInterface(Name string) (*IETFInterfaces_InterfacesState_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*IETFInterfaces_InterfacesState_Interface)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &IETFInterfaces_InterfacesState_Interface{
		Name: &Name,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *IETFInterfaces_InterfacesState) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["IETFInterfaces_InterfacesState"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *IETFInterfaces_InterfacesState) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// IETFInterfaces_InterfacesState_Interface represents the /ietf-interfaces/interfaces-state/interface YANG schema element.
type IETFInterfaces_InterfacesState_Interface struct {
	AdminStatus   E_IETFInterfaces_InterfacesState_Interface_AdminStatus `path:"admin-status" module:"ietf-interfaces"`
	HigherLayerIf []string                                               `path:"higher-layer-if" module:"ietf-interfaces"`
	IfIndex       *int32                                                 `path:"if-index" module:"ietf-interfaces"`
	LastChange    *string                                                `path:"last-change" module:"ietf-interfaces"`
	LowerLayerIf  []string                                               `path:"lower-layer-if" module:"ietf-interfaces"`
	Name          *string                                                `path:"name" module:"ietf-interfaces"`
	OperStatus    E_IETFInterfaces_InterfacesState_Interface_OperStatus  `path:"oper-status" module:"ietf-interfaces"`
	PhysAddress   *string                                                `path:"phys-address" module:"ietf-interfaces"`
	Speed         *uint64                                                `path:"speed" module:"ietf-interfaces"`
	Statistics    *IETFInterfaces_InterfacesState_Interface_Statistics   `path:"statistics" module:"ietf-interfaces"`
	Type          E_IETFInterfaces_InterfaceType                         `path:"type" module:"ietf-interfaces"`
}

// IsYANGGoStruct ensures that IETFInterfaces_InterfacesState_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*IETFInterfaces_InterfacesState_Interface) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the IETFInterfaces_InterfacesState_Interface struct, which is a YANG list entry.
func (t *IETFInterfaces_InterfacesState_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *IETFInterfaces_InterfacesState_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["IETFInterfaces_InterfacesState_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *IETFInterfaces_InterfacesState_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// IETFInterfaces_InterfacesState_Interface_Statistics represents the /ietf-interfaces/interfaces-state/interface/statistics YANG schema element.
type IETFInterfaces_InterfacesState_Interface_Statistics struct {
	DiscontinuityTime *string `path:"discontinuity-time" module:"ietf-interfaces"`
	InBroadcastPkts   *uint64 `path:"in-broadcast-pkts" module:"ietf-interfaces"`
	InDiscards        *uint32 `path:"in-discards" module:"ietf-interfaces"`
	InErrors          *uint32 `path:"in-errors" module:"ietf-interfaces"`
	InMulticastPkts   *uint64 `path:"in-multicast-pkts" module:"ietf-interfaces"`
	InOctets          *uint64 `path:"in-octets" module:"ietf-interfaces"`
	InUnicastPkts     *uint64 `path:"in-unicast-pkts" module:"ietf-interfaces"`
	InUnknownProtos   *uint32 `path:"in-unknown-protos" module:"ietf-interfaces"`
	OutBroadcastPkts  *uint64 `path:"out-broadcast-pkts" module:"ietf-interfaces"`
	OutDiscards       *uint32 `path:"out-discards" module:"ietf-interfaces"`
	OutErrors         *uint32 `path:"out-errors" module:"ietf-interfaces"`
	OutMulticastPkts  *uint64 `path:"out-multicast-pkts" module:"ietf-interfaces"`
	OutOctets         *uint64 `path:"out-octets" module:"ietf-interfaces"`
	OutUnicastPkts    *uint64 `path:"out-unicast-pkts" module:"ietf-interfaces"`
}

// IsYANGGoStruct ensures that IETFInterfaces_InterfacesState_Interface_Statistics implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*IETFInterfaces_InterfacesState_Interface_Statistics) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *IETFInterfaces_InterfacesState_Interface_Statistics) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["IETFInterfaces_InterfacesState_Interface_Statistics"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *IETFInterfaces_InterfacesState_Interface_Statistics) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// IETFInterfaces_Interfaces_Interface represents the /ietf-interfaces/interfaces/interface YANG schema element.
type IETFInterfaces_Interfaces_Interface struct {
	AdminStatus          E_IETFInterfaces_Interfaces_Interface_AdminStatus          `path:"admin-status" module:"ietf-interfaces"`
	Description          *string                                                    `path:"description" module:"ietf-interfaces"`
	Enabled              *bool                                                      `path:"enabled" module:"ietf-interfaces"`
	HigherLayerIf        []string                                                   `path:"higher-layer-if" module:"ietf-interfaces"`
	IfIndex              *int32                                                     `path:"if-index" module:"ietf-interfaces"`
	LastChange           *string                                                    `path:"last-change" module:"ietf-interfaces"`
	LinkUpDownTrapEnable E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable `path:"link-up-down-trap-enable" module:"ietf-interfaces"`
	LowerLayerIf         []string                                                   `path:"lower-layer-if" module:"ietf-interfaces"`
	Name                 *string                                                    `path:"name" module:"ietf-interfaces"`
	OperStatus           E_IETFInterfaces_Interfaces_Interface_OperStatus           `path:"oper-status" module:"ietf-interfaces"`
	PhysAddress          *string                                                    `path:"phys-address" module:"ietf-interfaces"`
	Speed                *uint64                                                    `path:"speed" module:"ietf-interfaces"`
	Statistics           *IETFInterfaces_Interfaces_Interface_Statistics            `path:"statistics" module:"ietf-interfaces"`
	Type                 E_IETFInterfaces_InterfaceType                             `path:"type" module:"ietf-interfaces"`
}

// IsYANGGoStruct ensures that IETFInterfaces_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*IETFInterfaces_Interfaces_Interface) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the IETFInterfaces_Interfaces_Interface struct, which is a YANG list entry.
func (t *IETFInterfaces_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *IETFInterfaces_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["IETFInterfaces_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *IETFInterfaces_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// IETFInterfaces_Interfaces_Interface_Statistics represents the /ietf-interfaces/interfaces/interface/statistics YANG schema element.
type IETFInterfaces_Interfaces_Interface_Statistics struct {
	DiscontinuityTime *string `path:"discontinuity-time" module:"ietf-interfaces"`
	InBroadcastPkts   *uint64 `path:"in-broadcast-pkts" module:"ietf-interfaces"`
	InDiscards        *uint32 `path:"in-discards" module:"ietf-interfaces"`
	InErrors          *uint32 `path:"in-errors" module:"ietf-interfaces"`
	InMulticastPkts   *uint64 `path:"in-multicast-pkts" module:"ietf-interfaces"`
	InOctets          *uint64 `path:"in-octets" module:"ietf-interfaces"`
	InUnicastPkts     *uint64 `path:"in-unicast-pkts" module:"ietf-interfaces"`
	InUnknownProtos   *uint32 `path:"in-unknown-protos" module:"ietf-interfaces"`
	OutBroadcastPkts  *uint64 `path:"out-broadcast-pkts" module:"ietf-interfaces"`
	OutDiscards       *uint32 `path:"out-discards" module:"ietf-interfaces"`
	OutErrors         *uint32 `path:"out-errors" module:"ietf-interfaces"`
	OutMulticastPkts  *uint64 `path:"out-multicast-pkts" module:"ietf-interfaces"`
	OutOctets         *uint64 `path:"out-octets" module:"ietf-interfaces"`
	OutUnicastPkts    *uint64 `path:"out-unicast-pkts" module:"ietf-interfaces"`
}

// IsYANGGoStruct ensures that IETFInterfaces_Interfaces_Interface_Statistics implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*IETFInterfaces_Interfaces_Interface_Statistics) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *IETFInterfaces_Interfaces_Interface_Statistics) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["IETFInterfaces_Interfaces_Interface_Statistics"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *IETFInterfaces_Interfaces_Interface_Statistics) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl represents the /openconfig-acl/acl YANG schema element.
type OpenconfigAcl_Acl struct {
	AclSets    *OpenconfigAcl_Acl_AclSets    `path:"acl-sets" module:"openconfig-acl"`
	Config     *OpenconfigAcl_Acl_Config     `path:"config" module:"openconfig-acl"`
	Interfaces *OpenconfigAcl_Acl_Interfaces `path:"interfaces" module:"openconfig-acl"`
	State      *OpenconfigAcl_Acl_State      `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigAcl_Acl_AclSets represents the /openconfig-acl/acl/acl-sets YANG schema element.
type OpenconfigAcl_Acl_AclSets struct {
	AclSet map[OpenconfigAcl_Acl_AclSets_AclSet_Key]*OpenconfigAcl_Acl_AclSets_AclSet `path:"acl-set" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets) IsYANGGoStruct() {}

// OpenconfigAcl_Acl_AclSets_AclSet_Key represents the key for list AclSet of element /openconfig-acl/acl/acl-sets.
type OpenconfigAcl_Acl_AclSets_AclSet_Key struct {
	Name string                   `path:"name"`
	Type E_OpenconfigAcl_ACL_TYPE `path:"type"`
}

// NewAclSet creates a new entry in the AclSet list of the
// OpenconfigAcl_Acl_AclSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_AclSets) NewAclSet(Name string, Type E_OpenconfigAcl_ACL_TYPE) (*OpenconfigAcl_Acl_AclSets_AclSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclSet == nil {
		t.AclSet = make(map[OpenconfigAcl_Acl_AclSets_AclSet_Key]*OpenconfigAcl_Acl_AclSets_AclSet)
	}

	key := OpenconfigAcl_Acl_AclSets_AclSet_Key{
		Name: Name,
		Type: Type,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclSet", key)
	}

	t.AclSet[key] = &OpenconfigAcl_Acl_AclSets_AclSet{
		Name: &Name,
		Type: Type,
	}

	return t.AclSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigAcl_Acl_AclSets_AclSet represents the /openconfig-acl/acl/acl-sets/acl-set YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet struct {
	AclEntries *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries `path:"acl-entries" module:"openconfig-acl"`
	Config     *OpenconfigAcl_Acl_AclSets_AclSet_Config     `path:"config" module:"openconfig-acl"`
	Name       *string                                      `path:"name" module:"openconfig-acl"`
	State      *OpenconfigAcl_Acl_AclSets_AclSet_State      `path:"state" module:"openconfig-acl"`
	Type       E_OpenconfigAcl_ACL_TYPE                     `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_AclSets_AclSet struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_AclSets_AclSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries struct {
	AclEntry map[uint32]*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry `path:"acl-entry" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries) IsYANGGoStruct() {}

// NewAclEntry creates a new entry in the AclEntry list of the
// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries) NewAclEntry(SequenceId uint32) (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclEntry", key)
	}

	t.AclEntry[key] = &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry{
		SequenceId: &SequenceId,
	}

	return t.AclEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry struct {
	Actions        *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions        `path:"actions" module:"openconfig-acl"`
	Config         *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config         `path:"config" module:"openconfig-acl"`
	InputInterface *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface `path:"input-interface" module:"openconfig-acl"`
	Ipv4           *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4           `path:"ipv4" module:"openconfig-acl"`
	Ipv6           *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6           `path:"ipv6" module:"openconfig-acl"`
	L2             *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2             `path:"l2" module:"openconfig-acl"`
	SequenceId     *uint32                                                              `path:"sequence-id" module:"openconfig-acl"`
	State          *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State          `path:"state" module:"openconfig-acl"`
	Transport      *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport      `path:"transport" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/actions YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions struct {
	Config *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config struct {
	ForwardingAction E_OpenconfigAcl_FORWARDING_ACTION `path:"forwarding-action" module:"openconfig-acl"`
	LogAction        E_OpenconfigAcl_LOG_ACTION        `path:"log-action" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State struct {
	ForwardingAction E_OpenconfigAcl_FORWARDING_ACTION `path:"forwarding-action" module:"openconfig-acl"`
	LogAction        E_OpenconfigAcl_LOG_ACTION        `path:"log-action" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Actions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config struct {
	Description *string `path:"description" module:"openconfig-acl"`
	SequenceId  *uint32 `path:"sequence-id" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface struct {
	Config       *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config       `path:"config" module:"openconfig-acl"`
	InterfaceRef *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef `path:"interface-ref" module:"openconfig-acl"`
	State        *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State        `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface/interface-ref YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef struct {
	Config *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface/interface-ref/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-acl"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface/interface-ref/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-acl"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/input-interface/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State struct {
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_InputInterface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4 represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4 YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4 struct {
	Config *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config struct {
	DestinationAddress *string                                                                         `path:"destination-address" module:"openconfig-acl"`
	Dscp               *uint8                                                                          `path:"dscp" module:"openconfig-acl"`
	HopLimit           *uint8                                                                          `path:"hop-limit" module:"openconfig-acl"`
	Protocol           OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union `path:"protocol" module:"openconfig-acl"`
	SourceAddress      *string                                                                         `path:"source-address" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/config/protocol within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/config/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_Uint8 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/config/protocol
// is to be set to a uint8 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_Uint8
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_Uint8) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_Config_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State struct {
	DestinationAddress *string                                                                        `path:"destination-address" module:"openconfig-acl"`
	Dscp               *uint8                                                                         `path:"dscp" module:"openconfig-acl"`
	HopLimit           *uint8                                                                         `path:"hop-limit" module:"openconfig-acl"`
	Protocol           OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union `path:"protocol" module:"openconfig-acl"`
	SourceAddress      *string                                                                        `path:"source-address" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state/protocol within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_Uint8 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state/protocol
// is to be set to a uint8 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_Uint8
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_Uint8) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv4_State_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6 represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6 YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6 struct {
	Config *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config struct {
	DestinationAddress   *string                                                                         `path:"destination-address" module:"openconfig-acl"`
	DestinationFlowLabel *uint32                                                                         `path:"destination-flow-label" module:"openconfig-acl"`
	Dscp                 *uint8                                                                          `path:"dscp" module:"openconfig-acl"`
	HopLimit             *uint8                                                                          `path:"hop-limit" module:"openconfig-acl"`
	Protocol             OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union `path:"protocol" module:"openconfig-acl"`
	SourceAddress        *string                                                                         `path:"source-address" module:"openconfig-acl"`
	SourceFlowLabel      *uint32                                                                         `path:"source-flow-label" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/config/protocol within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/config/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_Uint8 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/config/protocol
// is to be set to a uint8 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_Uint8
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_Uint8) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_Config_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State struct {
	DestinationAddress   *string                                                                        `path:"destination-address" module:"openconfig-acl"`
	DestinationFlowLabel *uint32                                                                        `path:"destination-flow-label" module:"openconfig-acl"`
	Dscp                 *uint8                                                                         `path:"dscp" module:"openconfig-acl"`
	HopLimit             *uint8                                                                         `path:"hop-limit" module:"openconfig-acl"`
	Protocol             OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union `path:"protocol" module:"openconfig-acl"`
	SourceAddress        *string                                                                        `path:"source-address" module:"openconfig-acl"`
	SourceFlowLabel      *uint32                                                                        `path:"source-flow-label" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state/protocol within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_Uint8 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state/protocol
// is to be set to a uint8 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_Uint8
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_Uint8) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Ipv6_State_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2 represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2 YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2 struct {
	Config *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config struct {
	DestinationMac     *string                                                                        `path:"destination-mac" module:"openconfig-acl"`
	DestinationMacMask *string                                                                        `path:"destination-mac-mask" module:"openconfig-acl"`
	Ethertype          OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union `path:"ethertype" module:"openconfig-acl"`
	SourceMac          *string                                                                        `path:"source-mac" module:"openconfig-acl"`
	SourceMacMask      *string                                                                        `path:"source-mac-mask" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/config/ethertype within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/config/ethertype
// is to be set to a E_OpenconfigPacketMatchTypes_ETHERTYPE value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE struct {
	E_OpenconfigPacketMatchTypes_ETHERTYPE E_OpenconfigPacketMatchTypes_ETHERTYPE
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_Uint16 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/config/ethertype
// is to be set to a uint16 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_Uint16
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_Uint16) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_ETHERTYPE:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE{v}, nil
	case uint16:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_Config_Ethertype_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_ETHERTYPE, uint16]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State struct {
	DestinationMac     *string                                                                       `path:"destination-mac" module:"openconfig-acl"`
	DestinationMacMask *string                                                                       `path:"destination-mac-mask" module:"openconfig-acl"`
	Ethertype          OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union `path:"ethertype" module:"openconfig-acl"`
	SourceMac          *string                                                                       `path:"source-mac" module:"openconfig-acl"`
	SourceMacMask      *string                                                                       `path:"source-mac-mask" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state/ethertype within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state/ethertype
// is to be set to a E_OpenconfigPacketMatchTypes_ETHERTYPE value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE struct {
	E_OpenconfigPacketMatchTypes_ETHERTYPE E_OpenconfigPacketMatchTypes_ETHERTYPE
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_Uint16 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state/ethertype
// is to be set to a uint16 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_Uint16
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_Uint16) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_ETHERTYPE:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE{v}, nil
	case uint16:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_L2_State_Ethertype_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_ETHERTYPE, uint16]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State struct {
	Description    *string `path:"description" module:"openconfig-acl"`
	MatchedOctets  *uint64 `path:"matched-octets" module:"openconfig-acl"`
	MatchedPackets *uint64 `path:"matched-packets" module:"openconfig-acl"`
	SequenceId     *uint32 `path:"sequence-id" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport struct {
	Config *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config struct {
	DestinationPort OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union `path:"destination-port" module:"openconfig-acl"`
	SourcePort      OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union      `path:"source-port" module:"openconfig-acl"`
	TcpFlags        []E_OpenconfigPacketMatchTypes_TCP_FLAGS                                                    `path:"tcp-flags" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/destination-port within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/destination-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_String is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/destination-port
// is to be set to a string value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_String struct {
	String string
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_String
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_String) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_Uint16 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/destination-port
// is to be set to a uint16 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_Uint16
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_Uint16) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort{v}, nil
	case string:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_String{v}, nil
	case uint16:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort, string, uint16]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/source-port within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/source-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_String is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/source-port
// is to be set to a string value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_String struct {
	String string
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_String
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_String) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_Uint16 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/source-port
// is to be set to a uint16 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_Uint16
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_Uint16) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort{v}, nil
	case string:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_String{v}, nil
	case uint16:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort, string, uint16]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State represents the /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State struct {
	DestinationPort OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union `path:"destination-port" module:"openconfig-acl"`
	SourcePort      OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union      `path:"source-port" module:"openconfig-acl"`
	TcpFlags        []E_OpenconfigPacketMatchTypes_TCP_FLAGS                                                   `path:"tcp-flags" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_String is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port
// is to be set to a string value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_String struct {
	String string
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_String
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_String) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_Uint16 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port
// is to be set to a uint16 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_Uint16
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_Uint16) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort{v}, nil
	case string:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_String{v}, nil
	case uint16:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_DestinationPort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort, string, uint16]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port within the YANG schema.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union interface {
	Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union()
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_String is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port
// is to be set to a string value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_String struct {
	String string
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_String
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_String) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union() {
}

// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_Uint16 is used when /openconfig-acl/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port
// is to be set to a uint16 value.
type OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_Uint16
// implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union interface.
func (*OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_Uint16) Is_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union() {
}

// To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State) To_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union(i interface{}) (OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort{v}, nil
	case string:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_String{v}, nil
	case uint16:
		return &OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_State_SourcePort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort, string, uint16]", i, i)
	}
}

// OpenconfigAcl_Acl_AclSets_AclSet_Config represents the /openconfig-acl/acl/acl-sets/acl-set/config YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_Config struct {
	Description *string                  `path:"description" module:"openconfig-acl"`
	Name        *string                  `path:"name" module:"openconfig-acl"`
	Type        E_OpenconfigAcl_ACL_TYPE `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_AclSets_AclSet_State represents the /openconfig-acl/acl/acl-sets/acl-set/state YANG schema element.
type OpenconfigAcl_Acl_AclSets_AclSet_State struct {
	Description *string                  `path:"description" module:"openconfig-acl"`
	Name        *string                  `path:"name" module:"openconfig-acl"`
	Type        E_OpenconfigAcl_ACL_TYPE `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_AclSets_AclSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_AclSets_AclSet_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_AclSets_AclSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_AclSets_AclSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Config represents the /openconfig-acl/acl/config YANG schema element.
type OpenconfigAcl_Acl_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Config) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigAcl_Acl_Interfaces represents the /openconfig-acl/acl/interfaces YANG schema element.
type OpenconfigAcl_Acl_Interfaces struct {
	Interface map[string]*OpenconfigAcl_Acl_Interfaces_Interface `path:"interface" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigAcl_Acl_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_Interfaces) NewInterface(Id string) (*OpenconfigAcl_Acl_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigAcl_Acl_Interfaces_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigAcl_Acl_Interfaces_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigAcl_Acl_Interfaces_Interface represents the /openconfig-acl/acl/interfaces/interface YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface struct {
	Config         *OpenconfigAcl_Acl_Interfaces_Interface_Config         `path:"config" module:"openconfig-acl"`
	EgressAclSets  *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets  `path:"egress-acl-sets" module:"openconfig-acl"`
	Id             *string                                                `path:"id" module:"openconfig-acl"`
	IngressAclSets *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets `path:"ingress-acl-sets" module:"openconfig-acl"`
	InterfaceRef   *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef   `path:"interface-ref" module:"openconfig-acl"`
	State          *OpenconfigAcl_Acl_Interfaces_Interface_State          `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_Config represents the /openconfig-acl/acl/interfaces/interface/config YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_Config struct {
	Id *string `path:"id" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets struct {
	EgressAclSet map[OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Key]*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet `path:"egress-acl-set" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets) IsYANGGoStruct() {}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Key represents the key for list EgressAclSet of element /openconfig-acl/acl/interfaces/interface/egress-acl-sets.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Key struct {
	SetName string                   `path:"set-name"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type"`
}

// NewEgressAclSet creates a new entry in the EgressAclSet list of the
// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets) NewEgressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.EgressAclSet == nil {
		t.EgressAclSet = make(map[OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Key]*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet)
	}

	key := OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.EgressAclSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list EgressAclSet", key)
	}

	t.EgressAclSet[key] = &OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet{
		SetName: &SetName,
		Type:    Type,
	}

	return t.EgressAclSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet struct {
	AclEntries *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries `path:"acl-entries" module:"openconfig-acl"`
	Config     *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config     `path:"config" module:"openconfig-acl"`
	SetName    *string                                                                       `path:"set-name" module:"openconfig-acl"`
	State      *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State      `path:"state" module:"openconfig-acl"`
	Type       E_OpenconfigAcl_ACL_TYPE                                                      `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SetName == nil {
		return nil, fmt.Errorf("nil value for key SetName")
	}

	return map[string]interface{}{
		"set-name": *t.SetName,
		"type":     t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set/acl-entries YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries struct {
	AclEntry map[uint32]*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry `path:"acl-entry" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries) IsYANGGoStruct() {
}

// NewAclEntry creates a new entry in the AclEntry list of the
// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries) NewAclEntry(SequenceId uint32) (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclEntry", key)
	}

	t.AclEntry[key] = &OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry{
		SequenceId: &SequenceId,
	}

	return t.AclEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set/acl-entries/acl-entry YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry struct {
	SequenceId *uint32                                                                                      `path:"sequence-id" module:"openconfig-acl"`
	State      *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set/acl-entries/acl-entry/state YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State struct {
	MatchedOctets  *uint64 `path:"matched-octets" module:"openconfig-acl"`
	MatchedPackets *uint64 `path:"matched-packets" module:"openconfig-acl"`
	SequenceId     *uint32 `path:"sequence-id" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_AclEntries_AclEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set/config YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config struct {
	SetName *string                  `path:"set-name" module:"openconfig-acl"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State represents the /openconfig-acl/acl/interfaces/interface/egress-acl-sets/egress-acl-set/state YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State struct {
	SetName *string                  `path:"set-name" module:"openconfig-acl"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_EgressAclSets_EgressAclSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets struct {
	IngressAclSet map[OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Key]*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet `path:"ingress-acl-set" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets) IsYANGGoStruct() {}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Key represents the key for list IngressAclSet of element /openconfig-acl/acl/interfaces/interface/ingress-acl-sets.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Key struct {
	SetName string                   `path:"set-name"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type"`
}

// NewIngressAclSet creates a new entry in the IngressAclSet list of the
// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets) NewIngressAclSet(SetName string, Type E_OpenconfigAcl_ACL_TYPE) (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.IngressAclSet == nil {
		t.IngressAclSet = make(map[OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Key]*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet)
	}

	key := OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Key{
		SetName: SetName,
		Type:    Type,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.IngressAclSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list IngressAclSet", key)
	}

	t.IngressAclSet[key] = &OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet{
		SetName: &SetName,
		Type:    Type,
	}

	return t.IngressAclSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet struct {
	AclEntries *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries `path:"acl-entries" module:"openconfig-acl"`
	Config     *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config     `path:"config" module:"openconfig-acl"`
	SetName    *string                                                                         `path:"set-name" module:"openconfig-acl"`
	State      *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State      `path:"state" module:"openconfig-acl"`
	Type       E_OpenconfigAcl_ACL_TYPE                                                        `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SetName == nil {
		return nil, fmt.Errorf("nil value for key SetName")
	}

	return map[string]interface{}{
		"set-name": *t.SetName,
		"type":     t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/acl-entries YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries struct {
	AclEntry map[uint32]*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry `path:"acl-entry" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries) IsYANGGoStruct() {
}

// NewAclEntry creates a new entry in the AclEntry list of the
// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries) NewAclEntry(SequenceId uint32) (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AclEntry == nil {
		t.AclEntry = make(map[uint32]*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AclEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AclEntry", key)
	}

	t.AclEntry[key] = &OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry{
		SequenceId: &SequenceId,
	}

	return t.AclEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/acl-entries/acl-entry YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry struct {
	SequenceId *uint32                                                                                        `path:"sequence-id" module:"openconfig-acl"`
	State      *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry struct, which is a YANG list entry.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/acl-entries/acl-entry/state YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State struct {
	MatchedOctets  *uint64 `path:"matched-octets" module:"openconfig-acl"`
	MatchedPackets *uint64 `path:"matched-packets" module:"openconfig-acl"`
	SequenceId     *uint32 `path:"sequence-id" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_AclEntries_AclEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/config YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config struct {
	SetName *string                  `path:"set-name" module:"openconfig-acl"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State represents the /openconfig-acl/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/state YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State struct {
	SetName *string                  `path:"set-name" module:"openconfig-acl"`
	Type    E_OpenconfigAcl_ACL_TYPE `path:"type" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_IngressAclSets_IngressAclSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef represents the /openconfig-acl/acl/interfaces/interface/interface-ref YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-acl"`
	State  *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-acl/acl/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-acl"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State represents the /openconfig-acl/acl/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-acl"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_Interfaces_Interface_State represents the /openconfig-acl/acl/interfaces/interface/state YANG schema element.
type OpenconfigAcl_Acl_Interfaces_Interface_State struct {
	Id *string `path:"id" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_Interfaces_Interface_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigAcl_Acl_State represents the /openconfig-acl/acl/state YANG schema element.
type OpenconfigAcl_Acl_State struct {
	CounterCapability E_OpenconfigAcl_ACL_COUNTER_CAPABILITY `path:"counter-capability" module:"openconfig-acl"`
}

// IsYANGGoStruct ensures that OpenconfigAcl_Acl_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigAcl_Acl_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigAcl_Acl_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigAcl_Acl_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigAcl_Acl_State) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBfd_Bfd represents the /openconfig-bfd/bfd YANG schema element.
type OpenconfigBfd_Bfd struct {
	Interfaces *OpenconfigBfd_Bfd_Interfaces `path:"interfaces" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBfd_Bfd_Interfaces represents the /openconfig-bfd/bfd/interfaces YANG schema element.
type OpenconfigBfd_Bfd_Interfaces struct {
	Interface map[string]*OpenconfigBfd_Bfd_Interfaces_Interface `path:"interface" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigBfd_Bfd_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBfd_Bfd_Interfaces) NewInterface(Id string) (*OpenconfigBfd_Bfd_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigBfd_Bfd_Interfaces_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigBfd_Bfd_Interfaces_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBfd_Bfd_Interfaces_Interface represents the /openconfig-bfd/bfd/interfaces/interface YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface struct {
	Config           *OpenconfigBfd_Bfd_Interfaces_Interface_Config           `path:"config" module:"openconfig-bfd"`
	Id               *string                                                  `path:"id" module:"openconfig-bfd"`
	InterfaceRef     *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef     `path:"interface-ref" module:"openconfig-bfd"`
	MicroBfdSessions *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions `path:"micro-bfd-sessions" module:"openconfig-bfd"`
	Peers            *OpenconfigBfd_Bfd_Interfaces_Interface_Peers            `path:"peers" module:"openconfig-bfd"`
	State            *OpenconfigBfd_Bfd_Interfaces_Interface_State            `path:"state" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBfd_Bfd_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_Config represents the /openconfig-bfd/bfd/interfaces/interface/config YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_Config struct {
	DesiredMinimumTxInterval *uint32 `path:"desired-minimum-tx-interval" module:"openconfig-bfd"`
	DetectionMultiplier      *uint8  `path:"detection-multiplier" module:"openconfig-bfd"`
	EnablePerMemberLink      *bool   `path:"enable-per-member-link" module:"openconfig-bfd"`
	Enabled                  *bool   `path:"enabled" module:"openconfig-bfd"`
	Id                       *string `path:"id" module:"openconfig-bfd"`
	LocalAddress             *string `path:"local-address" module:"openconfig-bfd"`
	RequiredMinimumReceive   *uint32 `path:"required-minimum-receive" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef represents the /openconfig-bfd/bfd/interfaces/interface/interface-ref YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-bfd"`
	State  *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-bfd/bfd/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-bfd"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State represents the /openconfig-bfd/bfd/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-bfd"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions represents the /openconfig-bfd/bfd/interfaces/interface/micro-bfd-sessions YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions struct {
	MicroBfdSession map[string]*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession `path:"micro-bfd-session" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions) IsYANGGoStruct() {}

// NewMicroBfdSession creates a new entry in the MicroBfdSession list of the
// OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions) NewMicroBfdSession(MemberInterface string) (*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MicroBfdSession == nil {
		t.MicroBfdSession = make(map[string]*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession)
	}

	key := MemberInterface

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.MicroBfdSession[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list MicroBfdSession", key)
	}

	t.MicroBfdSession[key] = &OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession{
		MemberInterface: &MemberInterface,
	}

	return t.MicroBfdSession[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession represents the /openconfig-bfd/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession struct {
	Config          *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config `path:"config" module:"openconfig-bfd"`
	MemberInterface *string                                                                         `path:"member-interface" module:"openconfig-bfd"`
	State           *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State  `path:"state" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession struct, which is a YANG list entry.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MemberInterface == nil {
		return nil, fmt.Errorf("nil value for key MemberInterface")
	}

	return map[string]interface{}{
		"member-interface": *t.MemberInterface,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config represents the /openconfig-bfd/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/config YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config struct {
	LocalAddress    *string `path:"local-address" module:"openconfig-bfd"`
	MemberInterface *string `path:"member-interface" module:"openconfig-bfd"`
	RemoteAddress   *string `path:"remote-address" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State represents the /openconfig-bfd/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/state YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State struct {
	Async                         *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async `path:"async" module:"openconfig-bfd"`
	DemandModeRequested           *bool                                                                                `path:"demand-mode-requested" module:"openconfig-bfd"`
	FailureTransitions            *uint64                                                                              `path:"failure-transitions" module:"openconfig-bfd"`
	LastFailureTime               *uint64                                                                              `path:"last-failure-time" module:"openconfig-bfd"`
	LocalAddress                  *string                                                                              `path:"local-address" module:"openconfig-bfd"`
	LocalDiagnosticCode           E_OpenconfigBfd_BfdDiagnosticCode                                                    `path:"local-diagnostic-code" module:"openconfig-bfd"`
	LocalDiscriminator            *string                                                                              `path:"local-discriminator" module:"openconfig-bfd"`
	MemberInterface               *string                                                                              `path:"member-interface" module:"openconfig-bfd"`
	RemoteAddress                 *string                                                                              `path:"remote-address" module:"openconfig-bfd"`
	RemoteAuthenticationEnabled   *bool                                                                                `path:"remote-authentication-enabled" module:"openconfig-bfd"`
	RemoteControlPlaneIndependent *bool                                                                                `path:"remote-control-plane-independent" module:"openconfig-bfd"`
	RemoteDiagnosticCode          E_OpenconfigBfd_BfdDiagnosticCode                                                    `path:"remote-diagnostic-code" module:"openconfig-bfd"`
	RemoteDiscriminator           *string                                                                              `path:"remote-discriminator" module:"openconfig-bfd"`
	RemoteMinimumReceiveInterval  *uint32                                                                              `path:"remote-minimum-receive-interval" module:"openconfig-bfd"`
	RemoteSessionState            E_OpenconfigBfd_BfdSessionState                                                      `path:"remote-session-state" module:"openconfig-bfd"`
	SessionState                  E_OpenconfigBfd_BfdSessionState                                                      `path:"session-state" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async represents the /openconfig-bfd/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/state/async YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async struct {
	LastPacketReceived    *uint64 `path:"last-packet-received" module:"openconfig-bfd"`
	LastPacketTransmitted *uint64 `path:"last-packet-transmitted" module:"openconfig-bfd"`
	ReceivedPackets       *uint64 `path:"received-packets" module:"openconfig-bfd"`
	TransmittedPackets    *uint64 `path:"transmitted-packets" module:"openconfig-bfd"`
	UpTransitions         *uint64 `path:"up-transitions" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_MicroBfdSessions_MicroBfdSession_State_Async) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_Peers represents the /openconfig-bfd/bfd/interfaces/interface/peers YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_Peers struct {
	Peer map[string]*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer `path:"peer" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_Peers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_Peers) IsYANGGoStruct() {}

// NewPeer creates a new entry in the Peer list of the
// OpenconfigBfd_Bfd_Interfaces_Interface_Peers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers) NewPeer(LocalDiscriminator string) (*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Peer == nil {
		t.Peer = make(map[string]*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer)
	}

	key := LocalDiscriminator

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Peer[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Peer", key)
	}

	t.Peer[key] = &OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer{
		LocalDiscriminator: &LocalDiscriminator,
	}

	return t.Peer[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_Peers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer represents the /openconfig-bfd/bfd/interfaces/interface/peers/peer YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer struct {
	LocalDiscriminator *string                                                  `path:"local-discriminator" module:"openconfig-bfd"`
	State              *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State `path:"state" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer struct, which is a YANG list entry.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalDiscriminator == nil {
		return nil, fmt.Errorf("nil value for key LocalDiscriminator")
	}

	return map[string]interface{}{
		"local-discriminator": *t.LocalDiscriminator,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State represents the /openconfig-bfd/bfd/interfaces/interface/peers/peer/state YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State struct {
	Async                         *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async `path:"async" module:"openconfig-bfd"`
	DemandModeRequested           *bool                                                          `path:"demand-mode-requested" module:"openconfig-bfd"`
	Echo                          *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo  `path:"echo" module:"openconfig-bfd"`
	FailureTransitions            *uint64                                                        `path:"failure-transitions" module:"openconfig-bfd"`
	LastFailureTime               *uint64                                                        `path:"last-failure-time" module:"openconfig-bfd"`
	LocalAddress                  *string                                                        `path:"local-address" module:"openconfig-bfd"`
	LocalDiagnosticCode           E_OpenconfigBfd_BfdDiagnosticCode                              `path:"local-diagnostic-code" module:"openconfig-bfd"`
	LocalDiscriminator            *string                                                        `path:"local-discriminator" module:"openconfig-bfd"`
	RemoteAddress                 *string                                                        `path:"remote-address" module:"openconfig-bfd"`
	RemoteAuthenticationEnabled   *bool                                                          `path:"remote-authentication-enabled" module:"openconfig-bfd"`
	RemoteControlPlaneIndependent *bool                                                          `path:"remote-control-plane-independent" module:"openconfig-bfd"`
	RemoteDiagnosticCode          E_OpenconfigBfd_BfdDiagnosticCode                              `path:"remote-diagnostic-code" module:"openconfig-bfd"`
	RemoteDiscriminator           *string                                                        `path:"remote-discriminator" module:"openconfig-bfd"`
	RemoteMinimumReceiveInterval  *uint32                                                        `path:"remote-minimum-receive-interval" module:"openconfig-bfd"`
	RemoteSessionState            E_OpenconfigBfd_BfdSessionState                                `path:"remote-session-state" module:"openconfig-bfd"`
	SessionState                  E_OpenconfigBfd_BfdSessionState                                `path:"session-state" module:"openconfig-bfd"`
	SubscribedProtocols           []E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                `path:"subscribed-protocols" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async represents the /openconfig-bfd/bfd/interfaces/interface/peers/peer/state/async YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async struct {
	LastPacketReceived    *uint64 `path:"last-packet-received" module:"openconfig-bfd"`
	LastPacketTransmitted *uint64 `path:"last-packet-transmitted" module:"openconfig-bfd"`
	ReceivedPackets       *uint64 `path:"received-packets" module:"openconfig-bfd"`
	TransmittedPackets    *uint64 `path:"transmitted-packets" module:"openconfig-bfd"`
	UpTransitions         *uint64 `path:"up-transitions" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Async) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo represents the /openconfig-bfd/bfd/interfaces/interface/peers/peer/state/echo YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo struct {
	Active                *bool   `path:"active" module:"openconfig-bfd"`
	LastPacketReceived    *uint64 `path:"last-packet-received" module:"openconfig-bfd"`
	LastPacketTransmitted *uint64 `path:"last-packet-transmitted" module:"openconfig-bfd"`
	ReceivedPackets       *uint64 `path:"received-packets" module:"openconfig-bfd"`
	TransmittedPackets    *uint64 `path:"transmitted-packets" module:"openconfig-bfd"`
	UpTransitions         *uint64 `path:"up-transitions" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_Peers_Peer_State_Echo) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBfd_Bfd_Interfaces_Interface_State represents the /openconfig-bfd/bfd/interfaces/interface/state YANG schema element.
type OpenconfigBfd_Bfd_Interfaces_Interface_State struct {
	DesiredMinimumTxInterval *uint32 `path:"desired-minimum-tx-interval" module:"openconfig-bfd"`
	DetectionMultiplier      *uint8  `path:"detection-multiplier" module:"openconfig-bfd"`
	EnablePerMemberLink      *bool   `path:"enable-per-member-link" module:"openconfig-bfd"`
	Enabled                  *bool   `path:"enabled" module:"openconfig-bfd"`
	Id                       *string `path:"id" module:"openconfig-bfd"`
	LocalAddress             *string `path:"local-address" module:"openconfig-bfd"`
	RequiredMinimumReceive   *uint32 `path:"required-minimum-receive" module:"openconfig-bfd"`
}

// IsYANGGoStruct ensures that OpenconfigBfd_Bfd_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBfd_Bfd_Interfaces_Interface_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBfd_Bfd_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBfd_Bfd_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp represents the /openconfig-bgp/bgp YANG schema element.
type OpenconfigBgp_Bgp struct {
	Global     *OpenconfigBgp_Bgp_Global     `path:"global" module:"openconfig-bgp"`
	Neighbors  *OpenconfigBgp_Bgp_Neighbors  `path:"neighbors" module:"openconfig-bgp"`
	PeerGroups *OpenconfigBgp_Bgp_PeerGroups `path:"peer-groups" module:"openconfig-bgp"`
	Rib        *OpenconfigBgp_Bgp_Rib        `path:"rib" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBgp_Bgp_Global represents the /openconfig-bgp/bgp/global YANG schema element.
type OpenconfigBgp_Bgp_Global struct {
	AfiSafis                *OpenconfigBgp_Bgp_Global_AfiSafis                `path:"afi-safis" module:"openconfig-bgp"`
	Confederation           *OpenconfigBgp_Bgp_Global_Confederation           `path:"confederation" module:"openconfig-bgp"`
	Config                  *OpenconfigBgp_Bgp_Global_Config                  `path:"config" module:"openconfig-bgp"`
	DefaultRouteDistance    *OpenconfigBgp_Bgp_Global_DefaultRouteDistance    `path:"default-route-distance" module:"openconfig-bgp"`
	DynamicNeighborPrefixes *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes `path:"dynamic-neighbor-prefixes" module:"openconfig-bgp"`
	GracefulRestart         *OpenconfigBgp_Bgp_Global_GracefulRestart         `path:"graceful-restart" module:"openconfig-bgp"`
	RouteSelectionOptions   *OpenconfigBgp_Bgp_Global_RouteSelectionOptions   `path:"route-selection-options" module:"openconfig-bgp"`
	State                   *OpenconfigBgp_Bgp_Global_State                   `path:"state" module:"openconfig-bgp"`
	UseMultiplePaths        *OpenconfigBgp_Bgp_Global_UseMultiplePaths        `path:"use-multiple-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBgp_Bgp_Global_AfiSafis represents the /openconfig-bgp/bgp/global/afi-safis YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigBgp_Bgp_Global_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi struct {
	AddPaths              *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths              `path:"add-paths" module:"openconfig-bgp"`
	AfiSafiName           E_OpenconfigBgpTypes_AFI_SAFI_TYPE                               `path:"afi-safi-name" module:"openconfig-bgp"`
	Config                *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config                `path:"config" module:"openconfig-bgp"`
	GracefulRestart       *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart       `path:"graceful-restart" module:"openconfig-bgp"`
	Ipv4LabeledUnicast    *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast    `path:"ipv4-labeled-unicast" module:"openconfig-bgp"`
	Ipv4Unicast           *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast           `path:"ipv4-unicast" module:"openconfig-bgp"`
	Ipv6LabeledUnicast    *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast    `path:"ipv6-labeled-unicast" module:"openconfig-bgp"`
	Ipv6Unicast           *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast           `path:"ipv6-unicast" module:"openconfig-bgp"`
	L2VpnEvpn             *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn             `path:"l2vpn-evpn" module:"openconfig-bgp"`
	L2VpnVpls             *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls             `path:"l2vpn-vpls" module:"openconfig-bgp"`
	L3VpnIpv4Multicast    *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast    `path:"l3vpn-ipv4-multicast" module:"openconfig-bgp"`
	L3VpnIpv4Unicast      *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast      `path:"l3vpn-ipv4-unicast" module:"openconfig-bgp"`
	L3VpnIpv6Multicast    *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast    `path:"l3vpn-ipv6-multicast" module:"openconfig-bgp"`
	L3VpnIpv6Unicast      *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast      `path:"l3vpn-ipv6-unicast" module:"openconfig-bgp"`
	RouteSelectionOptions *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions `path:"route-selection-options" module:"openconfig-bgp"`
	SrtePolicyIpv4        *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4        `path:"srte-policy-ipv4" module:"openconfig-bgp"`
	SrtePolicyIpv6        *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6        `path:"srte-policy-ipv6" module:"openconfig-bgp"`
	State                 *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State                 `path:"state" module:"openconfig-bgp"`
	UseMultiplePaths      *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths      `path:"use-multiple-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/add-paths YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/add-paths/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-bgp"`
	Receive              *bool   `path:"receive" module:"openconfig-bgp"`
	Send                 *bool   `path:"send" module:"openconfig-bgp"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/add-paths/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-bgp"`
	Receive              *bool   `path:"receive" module:"openconfig-bgp"`
	Send                 *bool   `path:"send" module:"openconfig-bgp"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-bgp"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/graceful-restart YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/graceful-restart/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/graceful-restart/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast struct {
	Config      *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config      `path:"config" module:"openconfig-bgp"`
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	State       *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State       `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv4-unicast/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast struct {
	Config      *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config      `path:"config" module:"openconfig-bgp"`
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	State       *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State       `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/ipv6-unicast/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/route-selection-options YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/route-selection-options/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-bgp"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-bgp"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-bgp"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-bgp"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-bgp"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/route-selection-options/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-bgp"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-bgp"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-bgp"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-bgp"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-bgp"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4 represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4 struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6 represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6 struct {
	PrefixLimit *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State struct {
	AfiSafiName   E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-bgp"`
	Enabled       *bool                              `path:"enabled" module:"openconfig-bgp"`
	TotalPaths    *uint32                            `path:"total-paths" module:"openconfig-bgp"`
	TotalPrefixes *uint32                            `path:"total-prefixes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config `path:"config" module:"openconfig-bgp"`
	Ebgp   *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-bgp"`
	Ibgp   *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State represents the /openconfig-bgp/bgp/global/afi-safis/afi-safi/use-multiple-paths/state YANG schema element.
type OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_Confederation represents the /openconfig-bgp/bgp/global/confederation YANG schema element.
type OpenconfigBgp_Bgp_Global_Confederation struct {
	Config *OpenconfigBgp_Bgp_Global_Confederation_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_Confederation_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_Confederation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_Confederation) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_Confederation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_Confederation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_Confederation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_Confederation_Config represents the /openconfig-bgp/bgp/global/confederation/config YANG schema element.
type OpenconfigBgp_Bgp_Global_Confederation_Config struct {
	Identifier *uint32  `path:"identifier" module:"openconfig-bgp"`
	MemberAs   []uint32 `path:"member-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_Confederation_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_Confederation_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_Confederation_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_Confederation_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_Confederation_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_Confederation_State represents the /openconfig-bgp/bgp/global/confederation/state YANG schema element.
type OpenconfigBgp_Bgp_Global_Confederation_State struct {
	Identifier *uint32  `path:"identifier" module:"openconfig-bgp"`
	MemberAs   []uint32 `path:"member-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_Confederation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_Confederation_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_Confederation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_Confederation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_Confederation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_Config represents the /openconfig-bgp/bgp/global/config YANG schema element.
type OpenconfigBgp_Bgp_Global_Config struct {
	As       *uint32 `path:"as" module:"openconfig-bgp"`
	RouterId *string `path:"router-id" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DefaultRouteDistance represents the /openconfig-bgp/bgp/global/default-route-distance YANG schema element.
type OpenconfigBgp_Bgp_Global_DefaultRouteDistance struct {
	Config *OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DefaultRouteDistance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DefaultRouteDistance) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DefaultRouteDistance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DefaultRouteDistance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DefaultRouteDistance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config represents the /openconfig-bgp/bgp/global/default-route-distance/config YANG schema element.
type OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config struct {
	ExternalRouteDistance *uint8 `path:"external-route-distance" module:"openconfig-bgp"`
	InternalRouteDistance *uint8 `path:"internal-route-distance" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DefaultRouteDistance_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State represents the /openconfig-bgp/bgp/global/default-route-distance/state YANG schema element.
type OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State struct {
	ExternalRouteDistance *uint8 `path:"external-route-distance" module:"openconfig-bgp"`
	InternalRouteDistance *uint8 `path:"internal-route-distance" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DefaultRouteDistance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes represents the /openconfig-bgp/bgp/global/dynamic-neighbor-prefixes YANG schema element.
type OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes struct {
	DynamicNeighborPrefix map[string]*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix `path:"dynamic-neighbor-prefix" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes) IsYANGGoStruct() {}

// NewDynamicNeighborPrefix creates a new entry in the DynamicNeighborPrefix list of the
// OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes) NewDynamicNeighborPrefix(Prefix string) (*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DynamicNeighborPrefix == nil {
		t.DynamicNeighborPrefix = make(map[string]*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DynamicNeighborPrefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DynamicNeighborPrefix", key)
	}

	t.DynamicNeighborPrefix[key] = &OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix{
		Prefix: &Prefix,
	}

	return t.DynamicNeighborPrefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix represents the /openconfig-bgp/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix YANG schema element.
type OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix struct {
	Config *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config `path:"config" module:"openconfig-bgp"`
	Prefix *string                                                                        `path:"prefix" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config represents the /openconfig-bgp/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix/config YANG schema element.
type OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config struct {
	PeerGroup *string `path:"peer-group" module:"openconfig-bgp"`
	Prefix    *string `path:"prefix" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State represents the /openconfig-bgp/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix/state YANG schema element.
type OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State struct {
	PeerGroup *string `path:"peer-group" module:"openconfig-bgp"`
	Prefix    *string `path:"prefix" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_GracefulRestart represents the /openconfig-bgp/bgp/global/graceful-restart YANG schema element.
type OpenconfigBgp_Bgp_Global_GracefulRestart struct {
	Config *OpenconfigBgp_Bgp_Global_GracefulRestart_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_GracefulRestart_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_GracefulRestart) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_GracefulRestart_Config represents the /openconfig-bgp/bgp/global/graceful-restart/config YANG schema element.
type OpenconfigBgp_Bgp_Global_GracefulRestart_Config struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-bgp"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-bgp"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-bgp"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_GracefulRestart_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_GracefulRestart_State represents the /openconfig-bgp/bgp/global/graceful-restart/state YANG schema element.
type OpenconfigBgp_Bgp_Global_GracefulRestart_State struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-bgp"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-bgp"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-bgp"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_GracefulRestart_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_RouteSelectionOptions represents the /openconfig-bgp/bgp/global/route-selection-options YANG schema element.
type OpenconfigBgp_Bgp_Global_RouteSelectionOptions struct {
	Config *OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_RouteSelectionOptions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config represents the /openconfig-bgp/bgp/global/route-selection-options/config YANG schema element.
type OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-bgp"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-bgp"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-bgp"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-bgp"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-bgp"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_RouteSelectionOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State represents the /openconfig-bgp/bgp/global/route-selection-options/state YANG schema element.
type OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-bgp"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-bgp"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-bgp"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-bgp"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-bgp"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_RouteSelectionOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_State represents the /openconfig-bgp/bgp/global/state YANG schema element.
type OpenconfigBgp_Bgp_Global_State struct {
	As            *uint32 `path:"as" module:"openconfig-bgp"`
	RouterId      *string `path:"router-id" module:"openconfig-bgp"`
	TotalPaths    *uint32 `path:"total-paths" module:"openconfig-bgp"`
	TotalPrefixes *uint32 `path:"total-prefixes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths represents the /openconfig-bgp/bgp/global/use-multiple-paths YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths struct {
	Config *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config `path:"config" module:"openconfig-bgp"`
	Ebgp   *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-bgp"`
	Ibgp   *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_UseMultiplePaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config represents the /openconfig-bgp/bgp/global/use-multiple-paths/config YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/global/use-multiple-paths/ebgp YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config represents the /openconfig-bgp/bgp/global/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State represents the /openconfig-bgp/bgp/global/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/global/use-multiple-paths/ibgp YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config represents the /openconfig-bgp/bgp/global/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State represents the /openconfig-bgp/bgp/global/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Global_UseMultiplePaths_State represents the /openconfig-bgp/bgp/global/use-multiple-paths/state YANG schema element.
type OpenconfigBgp_Bgp_Global_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Global_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Global_UseMultiplePaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Global_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Global_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors represents the /openconfig-bgp/bgp/neighbors YANG schema element.
type OpenconfigBgp_Bgp_Neighbors struct {
	Neighbor map[string]*OpenconfigBgp_Bgp_Neighbors_Neighbor `path:"neighbor" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigBgp_Bgp_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigBgp_Bgp_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigBgp_Bgp_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigBgp_Bgp_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBgp_Bgp_Neighbors_Neighbor represents the /openconfig-bgp/bgp/neighbors/neighbor YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor struct {
	AfiSafis         *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis         `path:"afi-safis" module:"openconfig-bgp"`
	ApplyPolicy      *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy      `path:"apply-policy" module:"openconfig-bgp"`
	AsPathOptions    *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions    `path:"as-path-options" module:"openconfig-bgp"`
	Config           *OpenconfigBgp_Bgp_Neighbors_Neighbor_Config           `path:"config" module:"openconfig-bgp"`
	EbgpMultihop     *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop     `path:"ebgp-multihop" module:"openconfig-bgp"`
	EnableBfd        *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd        `path:"enable-bfd" module:"openconfig-bgp"`
	ErrorHandling    *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling    `path:"error-handling" module:"openconfig-bgp"`
	GracefulRestart  *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart  `path:"graceful-restart" module:"openconfig-bgp"`
	LoggingOptions   *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions   `path:"logging-options" module:"openconfig-bgp"`
	NeighborAddress  *string                                                `path:"neighbor-address" module:"openconfig-bgp"`
	RouteReflector   *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector   `path:"route-reflector" module:"openconfig-bgp"`
	State            *OpenconfigBgp_Bgp_Neighbors_Neighbor_State            `path:"state" module:"openconfig-bgp"`
	Timers           *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers           `path:"timers" module:"openconfig-bgp"`
	Transport        *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport        `path:"transport" module:"openconfig-bgp"`
	UseMultiplePaths *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths `path:"use-multiple-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi struct {
	AddPaths           *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-bgp"`
	AfiSafiName        E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                        `path:"afi-safi-name" module:"openconfig-bgp"`
	ApplyPolicy        *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-bgp"`
	Config             *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config             `path:"config" module:"openconfig-bgp"`
	GracefulRestart    *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-bgp"`
	Ipv4LabeledUnicast *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-bgp"`
	Ipv4Unicast        *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-bgp"`
	Ipv6LabeledUnicast *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-bgp"`
	Ipv6Unicast        *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-bgp"`
	L2VpnEvpn          *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-bgp"`
	L2VpnVpls          *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-bgp"`
	L3VpnIpv4Multicast *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-bgp"`
	L3VpnIpv4Unicast   *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-bgp"`
	L3VpnIpv6Multicast *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-bgp"`
	L3VpnIpv6Unicast   *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-bgp"`
	SrtePolicyIpv4     *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-bgp"`
	SrtePolicyIpv6     *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-bgp"`
	State              *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State              `path:"state" module:"openconfig-bgp"`
	UseMultiplePaths   *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-bgp"`
	Receive              *bool   `path:"receive" module:"openconfig-bgp"`
	Send                 *bool   `path:"send" module:"openconfig-bgp"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-bgp"`
	Receive              *bool   `path:"receive" module:"openconfig-bgp"`
	Send                 *bool   `path:"send" module:"openconfig-bgp"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-bgp"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State struct {
	Advertised *bool `path:"advertised" module:"openconfig-bgp"`
	Enabled    *bool `path:"enabled" module:"openconfig-bgp"`
	Received   *bool `path:"received" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast struct {
	Config      *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config      `path:"config" module:"openconfig-bgp"`
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	State       *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State       `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast struct {
	Config      *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config      `path:"config" module:"openconfig-bgp"`
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	State       *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State       `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4 represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4 struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6 represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6 struct {
	PrefixLimit *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State struct {
	Active      *bool                                                                 `path:"active" module:"openconfig-bgp"`
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                    `path:"afi-safi-name" module:"openconfig-bgp"`
	Enabled     *bool                                                                 `path:"enabled" module:"openconfig-bgp"`
	Prefixes    *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes `path:"prefixes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/state/prefixes YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes struct {
	Installed         *uint32 `path:"installed" module:"openconfig-bgp"`
	Received          *uint32 `path:"received" module:"openconfig-bgp"`
	ReceivedPrePolicy *uint32 `path:"received-pre-policy" module:"openconfig-bgp"`
	Sent              *uint32 `path:"sent" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config `path:"config" module:"openconfig-bgp"`
	Ebgp   *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State represents the /openconfig-bgp/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy represents the /openconfig-bgp/bgp/neighbors/neighbor/apply-policy YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/apply-policy/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State represents the /openconfig-bgp/bgp/neighbors/neighbor/apply-policy/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions represents the /openconfig-bgp/bgp/neighbors/neighbor/as-path-options YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/as-path-options/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-bgp"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-bgp"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State represents the /openconfig-bgp/bgp/neighbors/neighbor/as-path-options/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-bgp"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-bgp"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_AsPathOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Config struct {
	AuthPassword     *string                               `path:"auth-password" module:"openconfig-bgp"`
	Description      *string                               `path:"description" module:"openconfig-bgp"`
	Enabled          *bool                                 `path:"enabled" module:"openconfig-bgp"`
	LocalAs          *uint32                               `path:"local-as" module:"openconfig-bgp"`
	NeighborAddress  *string                               `path:"neighbor-address" module:"openconfig-bgp"`
	PeerAs           *uint32                               `path:"peer-as" module:"openconfig-bgp"`
	PeerGroup        *string                               `path:"peer-group" module:"openconfig-bgp"`
	PeerType         E_OpenconfigBgp_PeerType              `path:"peer-type" module:"openconfig-bgp"`
	RemovePrivateAs  E_OpenconfigBgp_RemovePrivateAsOption `path:"remove-private-as" module:"openconfig-bgp"`
	RouteFlapDamping *bool                                 `path:"route-flap-damping" module:"openconfig-bgp"`
	SendCommunity    E_OpenconfigBgp_CommunityType         `path:"send-community" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop represents the /openconfig-bgp/bgp/neighbors/neighbor/ebgp-multihop YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/ebgp-multihop/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-bgp"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State represents the /openconfig-bgp/bgp/neighbors/neighbor/ebgp-multihop/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-bgp"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EbgpMultihop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd represents the /openconfig-bgp/bgp/neighbors/neighbor/enable-bfd YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/enable-bfd/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State represents the /openconfig-bgp/bgp/neighbors/neighbor/enable-bfd/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling represents the /openconfig-bgp/bgp/neighbors/neighbor/error-handling YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/error-handling/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config struct {
	TreatAsWithdraw *bool `path:"treat-as-withdraw" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State represents the /openconfig-bgp/bgp/neighbors/neighbor/error-handling/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State struct {
	ErroneousUpdateMessages *uint32 `path:"erroneous-update-messages" module:"openconfig-bgp"`
	TreatAsWithdraw         *bool   `path:"treat-as-withdraw" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_ErrorHandling_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart represents the /openconfig-bgp/bgp/neighbors/neighbor/graceful-restart YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/graceful-restart/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-bgp"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-bgp"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-bgp"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State represents the /openconfig-bgp/bgp/neighbors/neighbor/graceful-restart/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State struct {
	Enabled         *bool                                                             `path:"enabled" module:"openconfig-bgp"`
	HelperOnly      *bool                                                             `path:"helper-only" module:"openconfig-bgp"`
	LocalRestarting *bool                                                             `path:"local-restarting" module:"openconfig-bgp"`
	Mode            E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode `path:"mode" module:"openconfig-bgp"`
	PeerRestartTime *uint16                                                           `path:"peer-restart-time" module:"openconfig-bgp"`
	PeerRestarting  *bool                                                             `path:"peer-restarting" module:"openconfig-bgp"`
	RestartTime     *uint16                                                           `path:"restart-time" module:"openconfig-bgp"`
	StaleRoutesTime *float64                                                          `path:"stale-routes-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions represents the /openconfig-bgp/bgp/neighbors/neighbor/logging-options YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/logging-options/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State represents the /openconfig-bgp/bgp/neighbors/neighbor/logging-options/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_LoggingOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector represents the /openconfig-bgp/bgp/neighbors/neighbor/route-reflector YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config struct {
	RouteReflectorClient    *bool                                                                                    `path:"route-reflector-client" module:"openconfig-bgp"`
	RouteReflectorClusterId OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/config/route-reflector-cluster-id within the YANG schema.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union interface {
	Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union()
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String is used when /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/config/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String
// implements the OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String) Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/config/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// To_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config) To_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union(i interface{}) (OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State represents the /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State struct {
	RouteReflectorClient    *bool                                                                                   `path:"route-reflector-client" module:"openconfig-bgp"`
	RouteReflectorClusterId OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id within the YANG schema.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union interface {
	Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union()
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String is used when /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String
// implements the OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String) Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-bgp/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// To_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State) To_OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union(i interface{}) (OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_State represents the /openconfig-bgp/bgp/neighbors/neighbor/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_State struct {
	AuthPassword           *string                                                   `path:"auth-password" module:"openconfig-bgp"`
	Description            *string                                                   `path:"description" module:"openconfig-bgp"`
	DynamicallyConfigured  *bool                                                     `path:"dynamically-configured" module:"openconfig-bgp"`
	Enabled                *bool                                                     `path:"enabled" module:"openconfig-bgp"`
	EstablishedTransitions *uint64                                                   `path:"established-transitions" module:"openconfig-bgp"`
	LastEstablished        *uint64                                                   `path:"last-established" module:"openconfig-bgp"`
	LocalAs                *uint32                                                   `path:"local-as" module:"openconfig-bgp"`
	Messages               *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages      `path:"messages" module:"openconfig-bgp"`
	NeighborAddress        *string                                                   `path:"neighbor-address" module:"openconfig-bgp"`
	PeerAs                 *uint32                                                   `path:"peer-as" module:"openconfig-bgp"`
	PeerGroup              *string                                                   `path:"peer-group" module:"openconfig-bgp"`
	PeerType               E_OpenconfigBgp_PeerType                                  `path:"peer-type" module:"openconfig-bgp"`
	Queues                 *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues        `path:"queues" module:"openconfig-bgp"`
	RemovePrivateAs        E_OpenconfigBgp_RemovePrivateAsOption                     `path:"remove-private-as" module:"openconfig-bgp"`
	RouteFlapDamping       *bool                                                     `path:"route-flap-damping" module:"openconfig-bgp"`
	SendCommunity          E_OpenconfigBgp_CommunityType                             `path:"send-community" module:"openconfig-bgp"`
	SessionState           E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState `path:"session-state" module:"openconfig-bgp"`
	SupportedCapabilities  []E_OpenconfigBgpTypes_BGP_CAPABILITY                     `path:"supported-capabilities" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages represents the /openconfig-bgp/bgp/neighbors/neighbor/state/messages YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages struct {
	Received *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received `path:"received" module:"openconfig-bgp"`
	Sent     *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent     `path:"sent" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received represents the /openconfig-bgp/bgp/neighbors/neighbor/state/messages/received YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received struct {
	NOTIFICATION                 *uint64                                `path:"NOTIFICATION" module:"openconfig-bgp"`
	UPDATE                       *uint64                                `path:"UPDATE" module:"openconfig-bgp"`
	LastNotificationErrorCode    E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-bgp"`
	LastNotificationErrorSubcode E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-bgp"`
	LastNotificationTime         *uint64                                `path:"last-notification-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Received) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent represents the /openconfig-bgp/bgp/neighbors/neighbor/state/messages/sent YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent struct {
	NOTIFICATION                 *uint64                                `path:"NOTIFICATION" module:"openconfig-bgp"`
	UPDATE                       *uint64                                `path:"UPDATE" module:"openconfig-bgp"`
	LastNotificationErrorCode    E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-bgp"`
	LastNotificationErrorSubcode E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-bgp"`
	LastNotificationTime         *uint64                                `path:"last-notification-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Messages_Sent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues represents the /openconfig-bgp/bgp/neighbors/neighbor/state/queues YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues struct {
	Input  *uint32 `path:"input" module:"openconfig-bgp"`
	Output *uint32 `path:"output" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_State_Queues) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers represents the /openconfig-bgp/bgp/neighbors/neighbor/timers YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/timers/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-bgp"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-bgp"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-bgp"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State represents the /openconfig-bgp/bgp/neighbors/neighbor/timers/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-bgp"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-bgp"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-bgp"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-bgp"`
	NegotiatedHoldTime           *float64 `path:"negotiated-hold-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport represents the /openconfig-bgp/bgp/neighbors/neighbor/transport YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/transport/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config struct {
	LocalAddress *string `path:"local-address" module:"openconfig-bgp"`
	MtuDiscovery *bool   `path:"mtu-discovery" module:"openconfig-bgp"`
	PassiveMode  *bool   `path:"passive-mode" module:"openconfig-bgp"`
	TcpMss       *uint16 `path:"tcp-mss" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State represents the /openconfig-bgp/bgp/neighbors/neighbor/transport/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State struct {
	LocalAddress  *string `path:"local-address" module:"openconfig-bgp"`
	LocalPort     *uint16 `path:"local-port" module:"openconfig-bgp"`
	MtuDiscovery  *bool   `path:"mtu-discovery" module:"openconfig-bgp"`
	PassiveMode   *bool   `path:"passive-mode" module:"openconfig-bgp"`
	RemoteAddress *string `path:"remote-address" module:"openconfig-bgp"`
	RemotePort    *uint16 `path:"remote-port" module:"openconfig-bgp"`
	TcpMss        *uint16 `path:"tcp-mss" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config `path:"config" module:"openconfig-bgp"`
	Ebgp   *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths/ebgp YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State represents the /openconfig-bgp/bgp/neighbors/neighbor/use-multiple-paths/state YANG schema element.
type OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Neighbors_Neighbor_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups represents the /openconfig-bgp/bgp/peer-groups YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups struct {
	PeerGroup map[string]*OpenconfigBgp_Bgp_PeerGroups_PeerGroup `path:"peer-group" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups) IsYANGGoStruct() {}

// NewPeerGroup creates a new entry in the PeerGroup list of the
// OpenconfigBgp_Bgp_PeerGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_PeerGroups) NewPeerGroup(PeerGroupName string) (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PeerGroup == nil {
		t.PeerGroup = make(map[string]*OpenconfigBgp_Bgp_PeerGroups_PeerGroup)
	}

	key := PeerGroupName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PeerGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PeerGroup", key)
	}

	t.PeerGroup[key] = &OpenconfigBgp_Bgp_PeerGroups_PeerGroup{
		PeerGroupName: &PeerGroupName,
	}

	return t.PeerGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup represents the /openconfig-bgp/bgp/peer-groups/peer-group YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup struct {
	AfiSafis         *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis         `path:"afi-safis" module:"openconfig-bgp"`
	ApplyPolicy      *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy      `path:"apply-policy" module:"openconfig-bgp"`
	AsPathOptions    *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions    `path:"as-path-options" module:"openconfig-bgp"`
	Config           *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config           `path:"config" module:"openconfig-bgp"`
	EbgpMultihop     *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop     `path:"ebgp-multihop" module:"openconfig-bgp"`
	EnableBfd        *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd        `path:"enable-bfd" module:"openconfig-bgp"`
	ErrorHandling    *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling    `path:"error-handling" module:"openconfig-bgp"`
	GracefulRestart  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart  `path:"graceful-restart" module:"openconfig-bgp"`
	LoggingOptions   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions   `path:"logging-options" module:"openconfig-bgp"`
	PeerGroupName    *string                                                  `path:"peer-group-name" module:"openconfig-bgp"`
	RouteReflector   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector   `path:"route-reflector" module:"openconfig-bgp"`
	State            *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State            `path:"state" module:"openconfig-bgp"`
	Timers           *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers           `path:"timers" module:"openconfig-bgp"`
	Transport        *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport        `path:"transport" module:"openconfig-bgp"`
	UseMultiplePaths *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths `path:"use-multiple-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_PeerGroups_PeerGroup struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PeerGroupName == nil {
		return nil, fmt.Errorf("nil value for key PeerGroupName")
	}

	return map[string]interface{}{
		"peer-group-name": *t.PeerGroupName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi struct {
	AddPaths           *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-bgp"`
	AfiSafiName        E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                          `path:"afi-safi-name" module:"openconfig-bgp"`
	ApplyPolicy        *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-bgp"`
	Config             *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config             `path:"config" module:"openconfig-bgp"`
	GracefulRestart    *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-bgp"`
	Ipv4LabeledUnicast *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-bgp"`
	Ipv4Unicast        *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-bgp"`
	Ipv6LabeledUnicast *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-bgp"`
	Ipv6Unicast        *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-bgp"`
	L2VpnEvpn          *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-bgp"`
	L2VpnVpls          *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-bgp"`
	L3VpnIpv4Multicast *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-bgp"`
	L3VpnIpv4Unicast   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-bgp"`
	L3VpnIpv6Multicast *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-bgp"`
	L3VpnIpv6Unicast   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-bgp"`
	SrtePolicyIpv4     *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-bgp"`
	SrtePolicyIpv6     *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-bgp"`
	State              *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State              `path:"state" module:"openconfig-bgp"`
	UseMultiplePaths   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-bgp"`
	Receive              *bool   `path:"receive" module:"openconfig-bgp"`
	Send                 *bool   `path:"send" module:"openconfig-bgp"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-bgp"`
	Receive              *bool   `path:"receive" module:"openconfig-bgp"`
	Send                 *bool   `path:"send" module:"openconfig-bgp"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-bgp"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast struct {
	Config      *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config      `path:"config" module:"openconfig-bgp"`
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	State       *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State       `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast struct {
	Config      *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config      `path:"config" module:"openconfig-bgp"`
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
	State       *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State       `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4 represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4 struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6 represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6 struct {
	PrefixLimit *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-bgp"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-bgp"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-bgp"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-bgp"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config `path:"config" module:"openconfig-bgp"`
	Ebgp   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-bgp"`
	Ibgp   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy represents the /openconfig-bgp/bgp/peer-groups/peer-group/apply-policy YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/apply-policy/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/apply-policy/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-bgp"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-bgp"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-bgp"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions represents the /openconfig-bgp/bgp/peer-groups/peer-group/as-path-options YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/as-path-options/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-bgp"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-bgp"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/as-path-options/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-bgp"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-bgp"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_AsPathOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config struct {
	AuthPassword     *string                               `path:"auth-password" module:"openconfig-bgp"`
	Description      *string                               `path:"description" module:"openconfig-bgp"`
	LocalAs          *uint32                               `path:"local-as" module:"openconfig-bgp"`
	PeerAs           *uint32                               `path:"peer-as" module:"openconfig-bgp"`
	PeerGroupName    *string                               `path:"peer-group-name" module:"openconfig-bgp"`
	PeerType         E_OpenconfigBgp_PeerType              `path:"peer-type" module:"openconfig-bgp"`
	RemovePrivateAs  E_OpenconfigBgp_RemovePrivateAsOption `path:"remove-private-as" module:"openconfig-bgp"`
	RouteFlapDamping *bool                                 `path:"route-flap-damping" module:"openconfig-bgp"`
	SendCommunity    E_OpenconfigBgp_CommunityType         `path:"send-community" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop represents the /openconfig-bgp/bgp/peer-groups/peer-group/ebgp-multihop YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/ebgp-multihop/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-bgp"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/ebgp-multihop/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-bgp"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd represents the /openconfig-bgp/bgp/peer-groups/peer-group/enable-bfd YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/enable-bfd/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/enable-bfd/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling represents the /openconfig-bgp/bgp/peer-groups/peer-group/error-handling YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/error-handling/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config struct {
	TreatAsWithdraw *bool `path:"treat-as-withdraw" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/error-handling/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State struct {
	TreatAsWithdraw *bool `path:"treat-as-withdraw" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_ErrorHandling_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart represents the /openconfig-bgp/bgp/peer-groups/peer-group/graceful-restart YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/graceful-restart/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-bgp"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-bgp"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-bgp"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/graceful-restart/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-bgp"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-bgp"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-bgp"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions represents the /openconfig-bgp/bgp/peer-groups/peer-group/logging-options YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/logging-options/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/logging-options/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_LoggingOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector represents the /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config struct {
	RouteReflectorClient    *bool                                                                                      `path:"route-reflector-client" module:"openconfig-bgp"`
	RouteReflectorClusterId OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/config/route-reflector-cluster-id within the YANG schema.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union interface {
	Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union()
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String is used when /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/config/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String
// implements the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String) Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/config/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// To_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) To_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union(i interface{}) (OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State struct {
	RouteReflectorClient    *bool                                                                                     `path:"route-reflector-client" module:"openconfig-bgp"`
	RouteReflectorClusterId OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id within the YANG schema.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union interface {
	Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union()
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String is used when /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String
// implements the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String) Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-bgp/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// To_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State) To_OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union(i interface{}) (OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State struct {
	AuthPassword     *string                               `path:"auth-password" module:"openconfig-bgp"`
	Description      *string                               `path:"description" module:"openconfig-bgp"`
	LocalAs          *uint32                               `path:"local-as" module:"openconfig-bgp"`
	PeerAs           *uint32                               `path:"peer-as" module:"openconfig-bgp"`
	PeerGroupName    *string                               `path:"peer-group-name" module:"openconfig-bgp"`
	PeerType         E_OpenconfigBgp_PeerType              `path:"peer-type" module:"openconfig-bgp"`
	RemovePrivateAs  E_OpenconfigBgp_RemovePrivateAsOption `path:"remove-private-as" module:"openconfig-bgp"`
	RouteFlapDamping *bool                                 `path:"route-flap-damping" module:"openconfig-bgp"`
	SendCommunity    E_OpenconfigBgp_CommunityType         `path:"send-community" module:"openconfig-bgp"`
	TotalPaths       *uint32                               `path:"total-paths" module:"openconfig-bgp"`
	TotalPrefixes    *uint32                               `path:"total-prefixes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers represents the /openconfig-bgp/bgp/peer-groups/peer-group/timers YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/timers/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-bgp"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-bgp"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-bgp"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/timers/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-bgp"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-bgp"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-bgp"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport represents the /openconfig-bgp/bgp/peer-groups/peer-group/transport YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/transport/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config struct {
	LocalAddress *string `path:"local-address" module:"openconfig-bgp"`
	MtuDiscovery *bool   `path:"mtu-discovery" module:"openconfig-bgp"`
	PassiveMode  *bool   `path:"passive-mode" module:"openconfig-bgp"`
	TcpMss       *uint16 `path:"tcp-mss" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/transport/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State struct {
	LocalAddress *string `path:"local-address" module:"openconfig-bgp"`
	MtuDiscovery *bool   `path:"mtu-discovery" module:"openconfig-bgp"`
	PassiveMode  *bool   `path:"passive-mode" module:"openconfig-bgp"`
	TcpMss       *uint16 `path:"tcp-mss" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config `path:"config" module:"openconfig-bgp"`
	Ebgp   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-bgp"`
	Ibgp   *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ebgp YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-bgp"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ibgp YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State represents the /openconfig-bgp/bgp/peer-groups/peer-group/use-multiple-paths/state YANG schema element.
type OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib represents the /openconfig-bgp/bgp/rib YANG schema element.
type OpenconfigBgp_Bgp_Rib struct {
	AfiSafis       *OpenconfigBgp_Bgp_Rib_AfiSafis       `path:"afi-safis" module:"openconfig-bgp"`
	AttrSets       *OpenconfigBgp_Bgp_Rib_AttrSets       `path:"attr-sets" module:"openconfig-bgp"`
	Communities    *OpenconfigBgp_Bgp_Rib_Communities    `path:"communities" module:"openconfig-bgp"`
	ExtCommunities *OpenconfigBgp_Bgp_Rib_ExtCommunities `path:"ext-communities" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigBgp_Bgp_Rib_AfiSafis represents the /openconfig-bgp/bgp/rib/afi-safis YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis) IsYANGGoStruct() {}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi struct {
	AfiSafiName    E_OpenconfigBgpTypes_AFI_SAFI_TYPE                     `path:"afi-safi-name" module:"openconfig-bgp"`
	Ipv4SrtePolicy *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy `path:"ipv4-srte-policy" module:"openconfig-bgp"`
	Ipv4Unicast    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast    `path:"ipv4-unicast" module:"openconfig-bgp"`
	Ipv6SrtePolicy *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy `path:"ipv6-srte-policy" module:"openconfig-bgp"`
	Ipv6Unicast    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast    `path:"ipv6-unicast" module:"openconfig-bgp"`
	State          *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State          `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy struct {
	LocRib    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib    `path:"loc-rib" module:"openconfig-bgp"`
	Neighbors *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors `path:"neighbors" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) IsYANGGoStruct() {}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route struct {
	Color             *uint32                                                                                      `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                      `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                      `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                              `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors struct {
	Neighbor map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor `path:"neighbor" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	AdjRibInPre     *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	AdjRibOutPost   *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	AdjRibOutPre    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	NeighborAddress *string                                                                                 `path:"neighbor-address" module:"openconfig-bgp"`
	State           *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State         `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	Color             *uint32                                                                                                               `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                               `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                               `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                       `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	Color             *uint32                                                                                                              `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                              `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                              `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                      `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	Color             *uint32                                                                                                                `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                                `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                                `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                        `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	Color             *uint32                                                                                                               `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                               `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                               `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                       `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast struct {
	LocRib    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib    `path:"loc-rib" module:"openconfig-bgp"`
	Neighbors *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors `path:"neighbors" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes `path:"routes" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) IsYANGGoStruct() {}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key struct {
	Prefix string                                                                                    `path:"prefix"`
	Origin OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin"`
	PathId uint32                                                                                    `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) NewRoute(Prefix string, Origin OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route struct {
	Origin            OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-bgp"`
	PathId            *uint32                                                                                   `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                   `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin within the YANG schema.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union interface {
	Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union()
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE is used when /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin
// is to be set to a E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE value.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE struct {
	E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
}

// Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String is used when /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin
// is to be set to a string value.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String
// implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String) Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                                                                   `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                                                                   `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                                                                   `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                              `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                                                                   `path:"last-modified" module:"openconfig-bgp"`
	Origin            OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-bgp"`
	PathId            *uint32                                                                                   `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                   `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                                                                     `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                           `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State struct {
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors struct {
	Neighbor map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor `path:"neighbor" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	AdjRibInPre     *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	AdjRibOutPost   *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	AdjRibOutPre    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	NeighborAddress *string                                                                              `path:"neighbor-address" module:"openconfig-bgp"`
	State           *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State         `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	PathId            *uint32                                                                                                            `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                            `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                    `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State struct {
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	PathId            *uint32                                                                                                           `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                           `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                   `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State struct {
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	PathId            *uint32                                                                                                             `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                             `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                     `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State struct {
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	PathId            *uint32                                                                                                            `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                            `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                    `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State struct {
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy struct {
	LocRib    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib    `path:"loc-rib" module:"openconfig-bgp"`
	Neighbors *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors `path:"neighbors" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) IsYANGGoStruct() {}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route struct {
	Color             *uint32                                                                                      `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                      `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                      `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                              `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors struct {
	Neighbor map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor `path:"neighbor" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	AdjRibInPre     *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	AdjRibOutPost   *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	AdjRibOutPre    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	NeighborAddress *string                                                                                 `path:"neighbor-address" module:"openconfig-bgp"`
	State           *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State         `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	Color             *uint32                                                                                                               `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                               `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                               `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                       `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	Color             *uint32                                                                                                              `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                              `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                              `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                      `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	Color             *uint32                                                                                                                `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                                `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                                `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                        `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	Color             *uint32                                                                                                               `path:"color" module:"openconfig-bgp"`
	Endpoint          *string                                                                                                               `path:"endpoint" module:"openconfig-bgp"`
	PathId            *uint32                                                                                                               `path:"path-id" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	Color             *uint32                                      `path:"color" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                       `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast struct {
	LocRib    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib    `path:"loc-rib" module:"openconfig-bgp"`
	Neighbors *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors `path:"neighbors" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes `path:"routes" module:"openconfig-bgp"`
	State  *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State  `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) IsYANGGoStruct() {}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key struct {
	Prefix string                                                                                    `path:"prefix"`
	Origin OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin"`
	PathId uint32                                                                                    `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) NewRoute(Prefix string, Origin OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route struct {
	Origin            OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-bgp"`
	PathId            *uint32                                                                                   `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                   `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin within the YANG schema.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union interface {
	Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union()
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE is used when /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin
// is to be set to a E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE value.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE struct {
	E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
}

// Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String is used when /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin
// is to be set to a string value.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String
// implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String) Is_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                                                                   `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                                                                   `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                                                                   `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                              `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                                                                   `path:"last-modified" module:"openconfig-bgp"`
	Origin            OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-bgp"`
	PathId            *uint32                                                                                   `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                   `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                                                                     `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) To_OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                           `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State struct {
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors struct {
	Neighbor map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor `path:"neighbor" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) IsYANGGoStruct() {}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-bgp"`
	AdjRibInPre     *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-bgp"`
	AdjRibOutPost   *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-bgp"`
	AdjRibOutPre    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-bgp"`
	NeighborAddress *string                                                                              `path:"neighbor-address" module:"openconfig-bgp"`
	State           *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State         `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	PathId            *uint32                                                                                                            `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                            `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                    `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	PathId            *uint32                                                                                                           `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                           `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                   `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	PathId            *uint32                                                                                                             `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                             `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                     `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	PathId            *uint32                                                                                                            `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                                                                                            `path:"prefix" module:"openconfig-bgp"`
	State             *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-bgp"`
	UnknownAttributes *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-bgp"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-bgp"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-bgp"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-bgp"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-bgp"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-bgp"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-bgp"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                    `path:"attr-type" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-bgp"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-bgp"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-bgp"`
	Extended   *bool   `path:"extended" module:"openconfig-bgp"`
	Optional   *bool   `path:"optional" module:"openconfig-bgp"`
	Partial    *bool   `path:"partial" module:"openconfig-bgp"`
	Transitive *bool   `path:"transitive" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State represents the /openconfig-bgp/bgp/rib/afi-safis/afi-safi/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets represents the /openconfig-bgp/bgp/rib/attr-sets YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets struct {
	AttrSet map[uint64]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet `path:"attr-set" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets) IsYANGGoStruct() {}

// NewAttrSet creates a new entry in the AttrSet list of the
// OpenconfigBgp_Bgp_Rib_AttrSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets) NewAttrSet(Index uint64) (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AttrSet == nil {
		t.AttrSet = make(map[uint64]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AttrSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AttrSet", key)
	}

	t.AttrSet[key] = &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet{
		Index: &Index,
	}

	return t.AttrSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet struct {
	Aggregator          *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator          `path:"aggregator" module:"openconfig-bgp"`
	AsPath              *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath              `path:"as-path" module:"openconfig-bgp"`
	As4Path             *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path             `path:"as4-path" module:"openconfig-bgp"`
	Index               *uint64                                                     `path:"index" module:"openconfig-bgp"`
	State               *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State               `path:"state" module:"openconfig-bgp"`
	TunnelEncapsulation *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation `path:"tunnel-encapsulation" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/aggregator YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator struct {
	State *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/aggregator/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State struct {
	Address *string `path:"address" module:"openconfig-bgp"`
	As      *uint32 `path:"as" module:"openconfig-bgp"`
	As4     *uint32 `path:"as4" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_Aggregator_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as4-path YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path struct {
	As4Segment []*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment `path:"as4-segment" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as4-path/as4-segment YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment struct {
	State *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as4-path/as4-segment/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State struct {
	Member []uint32                             `path:"member" module:"openconfig-bgp"`
	Type   E_OpenconfigRibBgp_AsPathSegmentType `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as-path YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath struct {
	AsSegment []*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment `path:"as-segment" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as-path/as-segment YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment struct {
	State *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/as-path/as-segment/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State struct {
	Member []uint32                             `path:"member" module:"openconfig-bgp"`
	Type   E_OpenconfigRibBgp_AsPathSegmentType `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State struct {
	Aigp            *uint64                              `path:"aigp" module:"openconfig-bgp"`
	AtomicAggregate *bool                                `path:"atomic-aggregate" module:"openconfig-bgp"`
	ClusterList     []string                             `path:"cluster-list" module:"openconfig-bgp"`
	Index           *uint64                              `path:"index" module:"openconfig-bgp"`
	LocalPref       *uint32                              `path:"local-pref" module:"openconfig-bgp"`
	Med             *uint32                              `path:"med" module:"openconfig-bgp"`
	NextHop         *string                              `path:"next-hop" module:"openconfig-bgp"`
	Origin          E_OpenconfigRibBgp_BgpOriginAttrType `path:"origin" module:"openconfig-bgp"`
	OriginatorId    *string                              `path:"originator-id" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation struct {
	Tunnels *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels `path:"tunnels" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels struct {
	Tunnel map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel `path:"tunnel" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) IsYANGGoStruct() {}

// NewTunnel creates a new entry in the Tunnel list of the
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) NewTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tunnel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tunnel", key)
	}

	t.Tunnel[key] = &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel{
		Type: Type,
	}

	return t.Tunnel[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel struct {
	State   *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State   `path:"state" module:"openconfig-bgp"`
	Subtlvs *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs `path:"subtlvs" module:"openconfig-bgp"`
	Type    E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE                                  `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State struct {
	Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs struct {
	Subtlv map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) NewSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv struct {
	RemoteEndpoints *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints `path:"remote-endpoints" module:"openconfig-bgp"`
	SegmentLists    *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists    `path:"segment-lists" module:"openconfig-bgp"`
	State           *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State           `path:"state" module:"openconfig-bgp"`
	Type            E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE                                                  `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints struct {
	RemoteEndpoint map[string]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint `path:"remote-endpoint" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) IsYANGGoStruct() {
}

// NewRemoteEndpoint creates a new entry in the RemoteEndpoint list of the
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) NewRemoteEndpoint(Endpoint string) (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteEndpoint == nil {
		t.RemoteEndpoint = make(map[string]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint)
	}

	key := Endpoint

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RemoteEndpoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RemoteEndpoint", key)
	}

	t.RemoteEndpoint[key] = &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint{
		Endpoint: &Endpoint,
	}

	return t.RemoteEndpoint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints/remote-endpoint YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint struct {
	Endpoint *string                                                                                                                        `path:"endpoint" module:"openconfig-bgp"`
	State    *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	return map[string]interface{}{
		"endpoint": *t.Endpoint,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints/remote-endpoint/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State struct {
	As       *uint32 `path:"as" module:"openconfig-bgp"`
	Endpoint *string `path:"endpoint" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists struct {
	SegmentList map[uint64]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList `path:"segment-list" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) IsYANGGoStruct() {
}

// NewSegmentList creates a new entry in the SegmentList list of the
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) NewSegmentList(InstanceId uint64) (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint64]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList)
	}

	key := InstanceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SegmentList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SegmentList", key)
	}

	t.SegmentList[key] = &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList{
		InstanceId: &InstanceId,
	}

	return t.SegmentList[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList struct {
	InstanceId *uint64                                                                                                                     `path:"instance-id" module:"openconfig-bgp"`
	Segments   *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments `path:"segments" module:"openconfig-bgp"`
	State      *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State    `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceId == nil {
		return nil, fmt.Errorf("nil value for key InstanceId")
	}

	return map[string]interface{}{
		"instance-id": *t.InstanceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments struct {
	Segment map[uint64]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment `path:"segment" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) IsYANGGoStruct() {
}

// NewSegment creates a new entry in the Segment list of the
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) NewSegment(Index uint64) (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Segment == nil {
		t.Segment = make(map[uint64]*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Segment[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Segment", key)
	}

	t.Segment[key] = &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment{
		Index: &Index,
	}

	return t.Segment[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment struct {
	Index *uint64                                                                                                                                   `path:"index" module:"openconfig-bgp"`
	State *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State struct {
	Index             *uint64                                                                                                                                            `path:"index" module:"openconfig-bgp"`
	LocalInterfaceId  *uint32                                                                                                                                            `path:"local-interface-id" module:"openconfig-bgp"`
	LocalIpv4Address  *string                                                                                                                                            `path:"local-ipv4-address" module:"openconfig-bgp"`
	LocalIpv6Address  *string                                                                                                                                            `path:"local-ipv6-address" module:"openconfig-bgp"`
	MplsBos           *bool                                                                                                                                              `path:"mpls-bos" module:"openconfig-bgp"`
	MplsTc            *uint8                                                                                                                                             `path:"mpls-tc" module:"openconfig-bgp"`
	MplsTtl           *uint8                                                                                                                                             `path:"mpls-ttl" module:"openconfig-bgp"`
	RemoteIpv4Address *string                                                                                                                                            `path:"remote-ipv4-address" module:"openconfig-bgp"`
	RemoteIpv6Address *string                                                                                                                                            `path:"remote-ipv6-address" module:"openconfig-bgp"`
	Sid               OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union `path:"sid" module:"openconfig-bgp"`
	Type              E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type    `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid within the YANG schema.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface {
	Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union()
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid is used when /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid
// is to be set to a E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid value.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid struct {
	E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
}

// Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
// implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid) Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union() {
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String is used when /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid
// is to be set to a string value.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String
// implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String) Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union() {
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32 is used when /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32
// implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32) Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union() {
}

// To_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) To_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid:
		return &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union, unknown union type, got: %T, want any of [E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid, string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State struct {
	InstanceId *uint64 `path:"instance-id" module:"openconfig-bgp"`
	Weight     *uint32 `path:"weight" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State represents the /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State struct {
	BindingSid OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union `path:"binding-sid" module:"openconfig-bgp"`
	Colors     []uint32                                                                                                        `path:"colors" module:"openconfig-bgp"`
	Preference *uint32                                                                                                         `path:"preference" module:"openconfig-bgp"`
	Type       E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE                                                        `path:"type" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid within the YANG schema.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface {
	Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union()
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid is used when /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid
// is to be set to a E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid value.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid struct {
	E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
}

// Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
// implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid) Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union() {
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String is used when /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid
// is to be set to a string value.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String
// implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String) Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union() {
}

// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32 is used when /openconfig-bgp/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32
// implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface.
func (*OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32) Is_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union() {
}

// To_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) To_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid:
		return &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union, unknown union type, got: %T, want any of [E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid, string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_Communities represents the /openconfig-bgp/bgp/rib/communities YANG schema element.
type OpenconfigBgp_Bgp_Rib_Communities struct {
	Community map[uint64]*OpenconfigBgp_Bgp_Rib_Communities_Community `path:"community" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_Communities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_Communities) IsYANGGoStruct() {}

// NewCommunity creates a new entry in the Community list of the
// OpenconfigBgp_Bgp_Rib_Communities struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_Communities) NewCommunity(Index uint64) (*OpenconfigBgp_Bgp_Rib_Communities_Community, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Community == nil {
		t.Community = make(map[uint64]*OpenconfigBgp_Bgp_Rib_Communities_Community)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Community[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Community", key)
	}

	t.Community[key] = &OpenconfigBgp_Bgp_Rib_Communities_Community{
		Index: &Index,
	}

	return t.Community[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_Communities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_Communities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_Communities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_Communities_Community represents the /openconfig-bgp/bgp/rib/communities/community YANG schema element.
type OpenconfigBgp_Bgp_Rib_Communities_Community struct {
	Index *uint64                                            `path:"index" module:"openconfig-bgp"`
	State *OpenconfigBgp_Bgp_Rib_Communities_Community_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_Communities_Community implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_Communities_Community) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_Communities_Community struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_Communities_Community) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_Communities_Community) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_Communities_Community"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_Communities_Community) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_Communities_Community_State represents the /openconfig-bgp/bgp/rib/communities/community/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_Communities_Community_State struct {
	Community []OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union `path:"community" module:"openconfig-bgp"`
	Index     *uint64                                                             `path:"index" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_Communities_Community_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_Communities_Community_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_Communities_Community_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_Communities_Community_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_Communities_Community_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/communities/community/state/community within the YANG schema.
type OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union interface {
	Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union()
}

// OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY is used when /openconfig-bgp/bgp/rib/communities/community/state/community
// is to be set to a E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY value.
type OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY struct {
	E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
}

// Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union ensures that OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
// implements the OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union interface.
func (*OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union() {
}

// OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_String is used when /openconfig-bgp/bgp/rib/communities/community/state/community
// is to be set to a string value.
type OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union ensures that OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_String
// implements the OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union interface.
func (*OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_String) Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union() {
}

// OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_Uint32 is used when /openconfig-bgp/bgp/rib/communities/community/state/community
// is to be set to a uint32 value.
type OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union ensures that OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_Uint32
// implements the OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union interface.
func (*OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_Uint32) Is_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union() {
}

// To_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_Communities_Community_State) To_OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY:
		return &OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_String{v}, nil
	case uint32:
		return &OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_Communities_Community_State_Community_Union, unknown union type, got: %T, want any of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, string, uint32]", i, i)
	}
}

// OpenconfigBgp_Bgp_Rib_ExtCommunities represents the /openconfig-bgp/bgp/rib/ext-communities YANG schema element.
type OpenconfigBgp_Bgp_Rib_ExtCommunities struct {
	ExtCommunity map[uint64]*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity `path:"ext-community" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_ExtCommunities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_ExtCommunities) IsYANGGoStruct() {}

// NewExtCommunity creates a new entry in the ExtCommunity list of the
// OpenconfigBgp_Bgp_Rib_ExtCommunities struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities) NewExtCommunity(Index uint64) (*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExtCommunity == nil {
		t.ExtCommunity = make(map[uint64]*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExtCommunity[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExtCommunity", key)
	}

	t.ExtCommunity[key] = &OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity{
		Index: &Index,
	}

	return t.ExtCommunity[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_ExtCommunities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity represents the /openconfig-bgp/bgp/rib/ext-communities/ext-community YANG schema element.
type OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity struct {
	Index *uint64                                                  `path:"index" module:"openconfig-bgp"`
	State *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State `path:"state" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity struct, which is a YANG list entry.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State represents the /openconfig-bgp/bgp/rib/ext-communities/ext-community/state YANG schema element.
type OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State struct {
	ExtCommunity []OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union `path:"ext-community" module:"openconfig-bgp"`
	Index        *uint64                                                                      `path:"index" module:"openconfig-bgp"`
}

// IsYANGGoStruct ensures that OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-bgp/bgp/rib/ext-communities/ext-community/state/ext-community within the YANG schema.
type OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union interface {
	Is_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union()
}

// OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary is used when /openconfig-bgp/bgp/rib/ext-communities/ext-community/state/ext-community
// is to be set to a Binary value.
type OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary struct {
	Binary Binary
}

// Is_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union ensures that OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary
// implements the OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union interface.
func (*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary) Is_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union() {
}

// OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String is used when /openconfig-bgp/bgp/rib/ext-communities/ext-community/state/ext-community
// is to be set to a string value.
type OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String struct {
	String string
}

// Is_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union ensures that OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String
// implements the OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union interface.
func (*OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String) Is_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union() {
}

// To_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State) To_OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union(i interface{}) (OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union, error) {
	switch v := i.(type) {
	case Binary:
		return &OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary{v}, nil
	case string:
		return &OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigBgp_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
	}
}

// OpenconfigLocalRouting_LocalRoutes represents the /openconfig-local-routing/local-routes YANG schema element.
type OpenconfigLocalRouting_LocalRoutes struct {
	Config          *OpenconfigLocalRouting_LocalRoutes_Config          `path:"config" module:"openconfig-local-routing"`
	LocalAggregates *OpenconfigLocalRouting_LocalRoutes_LocalAggregates `path:"local-aggregates" module:"openconfig-local-routing"`
	State           *OpenconfigLocalRouting_LocalRoutes_State           `path:"state" module:"openconfig-local-routing"`
	StaticRoutes    *OpenconfigLocalRouting_LocalRoutes_StaticRoutes    `path:"static-routes" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_Config represents the /openconfig-local-routing/local-routes/config YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates represents the /openconfig-local-routing/local-routes/local-aggregates YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates struct {
	Aggregate map[string]*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate `path:"aggregate" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates) IsYANGGoStruct() {}

// NewAggregate creates a new entry in the Aggregate list of the
// OpenconfigLocalRouting_LocalRoutes_LocalAggregates struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates) NewAggregate(Prefix string) (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Aggregate == nil {
		t.Aggregate = make(map[string]*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Aggregate[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Aggregate", key)
	}

	t.Aggregate[key] = &OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate{
		Prefix: &Prefix,
	}

	return t.Aggregate[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_LocalAggregates"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate represents the /openconfig-local-routing/local-routes/local-aggregates/aggregate YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate struct {
	Config *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config `path:"config" module:"openconfig-local-routing"`
	Prefix *string                                                              `path:"prefix" module:"openconfig-local-routing"`
	State  *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State  `path:"state" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate struct, which is a YANG list entry.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config represents the /openconfig-local-routing/local-routes/local-aggregates/aggregate/config YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config struct {
	Description *string                                                                          `path:"description" module:"openconfig-local-routing"`
	Discard     *bool                                                                            `path:"discard" module:"openconfig-local-routing"`
	Prefix      *string                                                                          `path:"prefix" module:"openconfig-local-routing"`
	SetTag      OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union `path:"set-tag" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/local-aggregates/aggregate/config/set-tag within the YANG schema.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union interface {
	Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union()
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_String is used when /openconfig-local-routing/local-routes/local-aggregates/aggregate/config/set-tag
// is to be set to a string value.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_String
// implements the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_String) Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union() {
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32 is used when /openconfig-local-routing/local-routes/local-aggregates/aggregate/config/set-tag
// is to be set to a uint32 value.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32
// implements the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32) Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union() {
}

// To_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config) To_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union(i interface{}) (OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_Config_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State represents the /openconfig-local-routing/local-routes/local-aggregates/aggregate/state YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State struct {
	Description *string                                                                         `path:"description" module:"openconfig-local-routing"`
	Discard     *bool                                                                           `path:"discard" module:"openconfig-local-routing"`
	Prefix      *string                                                                         `path:"prefix" module:"openconfig-local-routing"`
	SetTag      OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union `path:"set-tag" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/local-aggregates/aggregate/state/set-tag within the YANG schema.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union interface {
	Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union()
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_String is used when /openconfig-local-routing/local-routes/local-aggregates/aggregate/state/set-tag
// is to be set to a string value.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_String
// implements the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_String) Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union() {
}

// OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_Uint32 is used when /openconfig-local-routing/local-routes/local-aggregates/aggregate/state/set-tag
// is to be set to a uint32 value.
type OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_Uint32
// implements the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_Uint32) Is_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union() {
}

// To_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State) To_OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union(i interface{}) (OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigLocalRouting_LocalRoutes_LocalAggregates_Aggregate_State_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigLocalRouting_LocalRoutes_State represents the /openconfig-local-routing/local-routes/state YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_State struct {
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes represents the /openconfig-local-routing/local-routes/static-routes YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes struct {
	Static map[string]*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static `path:"static" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes) IsYANGGoStruct() {}

// NewStatic creates a new entry in the Static list of the
// OpenconfigLocalRouting_LocalRoutes_StaticRoutes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes) NewStatic(Prefix string) (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Static == nil {
		t.Static = make(map[string]*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Static[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Static", key)
	}

	t.Static[key] = &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static{
		Prefix: &Prefix,
	}

	return t.Static[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static represents the /openconfig-local-routing/local-routes/static-routes/static YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static struct {
	Config   *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config   `path:"config" module:"openconfig-local-routing"`
	NextHops *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops `path:"next-hops" module:"openconfig-local-routing"`
	Prefix   *string                                                          `path:"prefix" module:"openconfig-local-routing"`
	State    *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State    `path:"state" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static struct, which is a YANG list entry.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config represents the /openconfig-local-routing/local-routes/static-routes/static/config YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config struct {
	Description *string                                                                    `path:"description" module:"openconfig-local-routing"`
	Prefix      *string                                                                    `path:"prefix" module:"openconfig-local-routing"`
	SetTag      OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union `path:"set-tag" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/static-routes/static/config/set-tag within the YANG schema.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union interface {
	Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union()
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_String is used when /openconfig-local-routing/local-routes/static-routes/static/config/set-tag
// is to be set to a string value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_String
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_String) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union() {
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_Uint32 is used when /openconfig-local-routing/local-routes/static-routes/static/config/set-tag
// is to be set to a uint32 value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_Uint32
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_Uint32) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union() {
}

// To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config) To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union(i interface{}) (OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_Config_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops struct {
	NextHop map[string]*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop `path:"next-hop" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops) NewNextHop(Index string) (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[string]*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop struct {
	Config       *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config       `path:"config" module:"openconfig-local-routing"`
	EnableBfd    *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd    `path:"enable-bfd" module:"openconfig-local-routing"`
	Index        *string                                                                               `path:"index" module:"openconfig-local-routing"`
	InterfaceRef *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef `path:"interface-ref" module:"openconfig-local-routing"`
	State        *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State        `path:"state" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop struct, which is a YANG list entry.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/config YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config struct {
	Index   *string                                                                                      `path:"index" module:"openconfig-local-routing"`
	Metric  *uint32                                                                                      `path:"metric" module:"openconfig-local-routing"`
	NextHop OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union `path:"next-hop" module:"openconfig-local-routing"`
	Recurse *bool                                                                                        `path:"recurse" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/config/next-hop within the YANG schema.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union interface {
	Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union()
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP is used when /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/config/next-hop
// is to be set to a E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP struct {
	E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union() {
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String is used when /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/config/next-hop
// is to be set to a string value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String struct {
	String string
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union() {
}

// To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config) To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union(i interface{}) (OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP{v}, nil
	case string:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union, unknown union type, got: %T, want any of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, string]", i, i)
	}
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/enable-bfd YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd struct {
	Config *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config `path:"config" module:"openconfig-local-routing"`
	State  *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State  `path:"state" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/enable-bfd/config YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/enable-bfd/state YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/interface-ref YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef struct {
	Config *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config `path:"config" module:"openconfig-local-routing"`
	State  *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State  `path:"state" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/interface-ref/config YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-local-routing"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/interface-ref/state YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-local-routing"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State represents the /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/state YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State struct {
	Index   *string                                                                                     `path:"index" module:"openconfig-local-routing"`
	Metric  *uint32                                                                                     `path:"metric" module:"openconfig-local-routing"`
	NextHop OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union `path:"next-hop" module:"openconfig-local-routing"`
	Recurse *bool                                                                                       `path:"recurse" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/state/next-hop within the YANG schema.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union interface {
	Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union()
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP is used when /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/state/next-hop
// is to be set to a E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP struct {
	E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union() {
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String is used when /openconfig-local-routing/local-routes/static-routes/static/next-hops/next-hop/state/next-hop
// is to be set to a string value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String struct {
	String string
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union() {
}

// To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State) To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union(i interface{}) (OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP{v}, nil
	case string:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union, unknown union type, got: %T, want any of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, string]", i, i)
	}
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State represents the /openconfig-local-routing/local-routes/static-routes/static/state YANG schema element.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State struct {
	Description *string                                                                   `path:"description" module:"openconfig-local-routing"`
	Prefix      *string                                                                   `path:"prefix" module:"openconfig-local-routing"`
	SetTag      OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union `path:"set-tag" module:"openconfig-local-routing"`
}

// IsYANGGoStruct ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-local-routing/local-routes/static-routes/static/state/set-tag within the YANG schema.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union interface {
	Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union()
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_String is used when /openconfig-local-routing/local-routes/static-routes/static/state/set-tag
// is to be set to a string value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_String
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_String) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union() {
}

// OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_Uint32 is used when /openconfig-local-routing/local-routes/static-routes/static/state/set-tag
// is to be set to a uint32 value.
type OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union ensures that OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_Uint32
// implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union interface.
func (*OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_Uint32) Is_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union() {
}

// To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State) To_OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union(i interface{}) (OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigLocalRouting_LocalRoutes_StaticRoutes_Static_State_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigMessages_Messages represents the /openconfig-messages/messages YANG schema element.
type OpenconfigMessages_Messages struct {
	Config       *OpenconfigMessages_Messages_Config       `path:"config" module:"openconfig-messages"`
	DebugEntries *OpenconfigMessages_Messages_DebugEntries `path:"debug-entries" module:"openconfig-messages"`
	State        *OpenconfigMessages_Messages_State        `path:"state" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigMessages_Messages_Config represents the /openconfig-messages/messages/config YANG schema element.
type OpenconfigMessages_Messages_Config struct {
	Severity E_OpenconfigMessages_SyslogSeverity `path:"severity" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigMessages_Messages_DebugEntries represents the /openconfig-messages/messages/debug-entries YANG schema element.
type OpenconfigMessages_Messages_DebugEntries struct {
	DebugService map[E_OpenconfigMessages_DEBUG_SERVICE]*OpenconfigMessages_Messages_DebugEntries_DebugService `path:"debug-service" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_DebugEntries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_DebugEntries) IsYANGGoStruct() {}

// NewDebugService creates a new entry in the DebugService list of the
// OpenconfigMessages_Messages_DebugEntries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigMessages_Messages_DebugEntries) NewDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) (*OpenconfigMessages_Messages_DebugEntries_DebugService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DebugService == nil {
		t.DebugService = make(map[E_OpenconfigMessages_DEBUG_SERVICE]*OpenconfigMessages_Messages_DebugEntries_DebugService)
	}

	key := Service

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DebugService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DebugService", key)
	}

	t.DebugService[key] = &OpenconfigMessages_Messages_DebugEntries_DebugService{
		Service: Service,
	}

	return t.DebugService[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_DebugEntries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_DebugEntries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_DebugEntries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigMessages_Messages_DebugEntries_DebugService represents the /openconfig-messages/messages/debug-entries/debug-service YANG schema element.
type OpenconfigMessages_Messages_DebugEntries_DebugService struct {
	Config  *OpenconfigMessages_Messages_DebugEntries_DebugService_Config `path:"config" module:"openconfig-messages"`
	Service E_OpenconfigMessages_DEBUG_SERVICE                            `path:"service" module:"openconfig-messages"`
	State   *OpenconfigMessages_Messages_DebugEntries_DebugService_State  `path:"state" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_DebugEntries_DebugService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_DebugEntries_DebugService) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigMessages_Messages_DebugEntries_DebugService struct, which is a YANG list entry.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"service": t.Service,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_DebugEntries_DebugService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigMessages_Messages_DebugEntries_DebugService_Config represents the /openconfig-messages/messages/debug-entries/debug-service/config YANG schema element.
type OpenconfigMessages_Messages_DebugEntries_DebugService_Config struct {
	Enabled *bool                              `path:"enabled" module:"openconfig-messages"`
	Service E_OpenconfigMessages_DEBUG_SERVICE `path:"service" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_DebugEntries_DebugService_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_DebugEntries_DebugService_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_DebugEntries_DebugService_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigMessages_Messages_DebugEntries_DebugService_State represents the /openconfig-messages/messages/debug-entries/debug-service/state YANG schema element.
type OpenconfigMessages_Messages_DebugEntries_DebugService_State struct {
	Enabled *bool                              `path:"enabled" module:"openconfig-messages"`
	Service E_OpenconfigMessages_DEBUG_SERVICE `path:"service" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_DebugEntries_DebugService_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_DebugEntries_DebugService_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_DebugEntries_DebugService_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_DebugEntries_DebugService_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigMessages_Messages_State represents the /openconfig-messages/messages/state YANG schema element.
type OpenconfigMessages_Messages_State struct {
	Message  *OpenconfigMessages_Messages_State_Message `path:"message" module:"openconfig-messages"`
	Severity E_OpenconfigMessages_SyslogSeverity        `path:"severity" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigMessages_Messages_State_Message represents the /openconfig-messages/messages/state/message YANG schema element.
type OpenconfigMessages_Messages_State_Message struct {
	AppName  *string `path:"app-name" module:"openconfig-messages"`
	Msg      *string `path:"msg" module:"openconfig-messages"`
	Msgid    *string `path:"msgid" module:"openconfig-messages"`
	Priority *uint8  `path:"priority" module:"openconfig-messages"`
	Procid   *string `path:"procid" module:"openconfig-messages"`
}

// IsYANGGoStruct ensures that OpenconfigMessages_Messages_State_Message implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigMessages_Messages_State_Message) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigMessages_Messages_State_Message) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigMessages_Messages_State_Message"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigMessages_Messages_State_Message) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances represents the /openconfig-network-instance/network-instances YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances struct {
	NetworkInstance map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance `path:"network-instance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances) IsYANGGoStruct() {}

// NewNetworkInstance creates a new entry in the NetworkInstance list of the
// OpenconfigNetworkInstance_NetworkInstances struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances) NewNetworkInstance(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NetworkInstance == nil {
		t.NetworkInstance = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NetworkInstance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NetworkInstance", key)
	}

	t.NetworkInstance[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance{
		Name: &Name,
	}

	return t.NetworkInstance[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance represents the /openconfig-network-instance/network-instances/network-instance YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance struct {
	Afts                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts                  `path:"afts" module:"openconfig-network-instance"`
	Config                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config                `path:"config" module:"openconfig-network-instance"`
	ConnectionPoints      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints      `path:"connection-points" module:"openconfig-network-instance"`
	Encapsulation         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation         `path:"encapsulation" module:"openconfig-network-instance"`
	Fdb                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb                   `path:"fdb" module:"openconfig-network-instance"`
	InterInstancePolicies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies `path:"inter-instance-policies" module:"openconfig-network-instance"`
	Interfaces            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces            `path:"interfaces" module:"openconfig-network-instance"`
	Mpls                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls                  `path:"mpls" module:"openconfig-network-instance"`
	Name                  *string                                                                           `path:"name" module:"openconfig-network-instance"`
	PolicyForwarding      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding      `path:"policy-forwarding" module:"openconfig-network-instance"`
	Protocols             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols             `path:"protocols" module:"openconfig-network-instance"`
	RouteLimits           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits           `path:"route-limits" module:"openconfig-network-instance"`
	SegmentRouting        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting        `path:"segment-routing" module:"openconfig-network-instance"`
	State                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State                 `path:"state" module:"openconfig-network-instance"`
	TableConnections      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections      `path:"table-connections" module:"openconfig-network-instance"`
	Tables                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables                `path:"tables" module:"openconfig-network-instance"`
	Vlans                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans                 `path:"vlans" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts represents the /openconfig-network-instance/network-instances/network-instance/afts YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts struct {
	Ethernet         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet         `path:"ethernet" module:"openconfig-network-instance"`
	Ipv4Unicast      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast      `path:"ipv4-unicast" module:"openconfig-network-instance"`
	Ipv6Unicast      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast      `path:"ipv6-unicast" module:"openconfig-network-instance"`
	Mpls             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls             `path:"mpls" module:"openconfig-network-instance"`
	NextHopGroups    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups    `path:"next-hop-groups" module:"openconfig-network-instance"`
	NextHops         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops         `path:"next-hops" module:"openconfig-network-instance"`
	PolicyForwarding *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding `path:"policy-forwarding" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet represents the /openconfig-network-instance/network-instances/network-instance/afts/ethernet YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet struct {
	MacEntry map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry `path:"mac-entry" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet) IsYANGGoStruct() {}

// NewMacEntry creates a new entry in the MacEntry list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet) NewMacEntry(MacAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MacEntry == nil {
		t.MacEntry = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry)
	}

	key := MacAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.MacEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list MacEntry", key)
	}

	t.MacEntry[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry{
		MacAddress: &MacAddress,
	}

	return t.MacEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry represents the /openconfig-network-instance/network-instances/network-instance/afts/ethernet/mac-entry YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry struct {
	MacAddress *string                                                                                  `path:"mac-address" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MacAddress == nil {
		return nil, fmt.Errorf("nil value for key MacAddress")
	}

	return map[string]interface{}{
		"mac-address": *t.MacAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State represents the /openconfig-network-instance/network-instances/network-instance/afts/ethernet/mac-entry/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State struct {
	MacAddress       *string `path:"mac-address" module:"openconfig-network-instance"`
	NextHopGroup     *uint64 `path:"next-hop-group" module:"openconfig-network-instance"`
	OctetsForwarded  *uint64 `path:"octets-forwarded" module:"openconfig-network-instance"`
	PacketsForwarded *uint64 `path:"packets-forwarded" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ethernet_MacEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast struct {
	Ipv4Entry map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry `path:"ipv4-entry" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast) IsYANGGoStruct() {
}

// NewIpv4Entry creates a new entry in the Ipv4Entry list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast) NewIpv4Entry(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4Entry == nil {
		t.Ipv4Entry = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4Entry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4Entry", key)
	}

	t.Ipv4Entry[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry{
		Prefix: &Prefix,
	}

	return t.Ipv4Entry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry struct {
	Prefix *string                                                                                      `path:"prefix" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State struct {
	DecapsulateHeader E_OpenconfigAft_EncapsulationHeaderType       `path:"decapsulate-header" module:"openconfig-network-instance"`
	NextHopGroup      *uint64                                       `path:"next-hop-group" module:"openconfig-network-instance"`
	OctetsForwarded   *uint64                                       `path:"octets-forwarded" module:"openconfig-network-instance"`
	OriginProtocol    E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"origin-protocol" module:"openconfig-network-instance"`
	PacketsForwarded  *uint64                                       `path:"packets-forwarded" module:"openconfig-network-instance"`
	Prefix            *string                                       `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv4Unicast_Ipv4Entry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast struct {
	Ipv6Entry map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry `path:"ipv6-entry" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast) IsYANGGoStruct() {
}

// NewIpv6Entry creates a new entry in the Ipv6Entry list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast) NewIpv6Entry(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6Entry == nil {
		t.Ipv6Entry = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6Entry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6Entry", key)
	}

	t.Ipv6Entry[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry{
		Prefix: &Prefix,
	}

	return t.Ipv6Entry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry struct {
	Prefix *string                                                                                      `path:"prefix" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State represents the /openconfig-network-instance/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State struct {
	DecapsulateHeader E_OpenconfigAft_EncapsulationHeaderType       `path:"decapsulate-header" module:"openconfig-network-instance"`
	NextHopGroup      *uint64                                       `path:"next-hop-group" module:"openconfig-network-instance"`
	OctetsForwarded   *uint64                                       `path:"octets-forwarded" module:"openconfig-network-instance"`
	OriginProtocol    E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"origin-protocol" module:"openconfig-network-instance"`
	PacketsForwarded  *uint64                                       `path:"packets-forwarded" module:"openconfig-network-instance"`
	Prefix            *string                                       `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Ipv6Unicast_Ipv6Entry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls represents the /openconfig-network-instance/network-instances/network-instance/afts/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls struct {
	LabelEntry map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry `path:"label-entry" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls) IsYANGGoStruct() {}

// NewLabelEntry creates a new entry in the LabelEntry list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls) NewLabelEntry(Label OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LabelEntry == nil {
		t.LabelEntry = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry)
	}

	key := Label

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LabelEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LabelEntry", key)
	}

	t.LabelEntry[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry{
		Label: Label,
	}

	return t.LabelEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry represents the /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry struct {
	Label OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union `path:"label" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State            `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"label": t.Label,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label is used when /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State represents the /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State struct {
	Label                OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union                  `path:"label" module:"openconfig-network-instance"`
	NextHopGroup         *uint64                                                                                                            `path:"next-hop-group" module:"openconfig-network-instance"`
	OctetsForwarded      *uint64                                                                                                            `path:"octets-forwarded" module:"openconfig-network-instance"`
	PacketsForwarded     *uint64                                                                                                            `path:"packets-forwarded" module:"openconfig-network-instance"`
	PoppedMplsLabelStack []OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union `path:"popped-mpls-label-stack" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/state/popped-mpls-label-stack within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack is used when /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/state/popped-mpls-label-stack
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/afts/mpls/label-entry/state/popped-mpls-label-stack
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups struct {
	NextHopGroup map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup `path:"next-hop-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups) IsYANGGoStruct() {
}

// NewNextHopGroup creates a new entry in the NextHopGroup list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups) NewNextHopGroup(Id uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHopGroup == nil {
		t.NextHopGroup = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHopGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHopGroup", key)
	}

	t.NextHopGroup[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup{
		Id: &Id,
	}

	return t.NextHopGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup struct {
	Conditional *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional `path:"conditional" module:"openconfig-network-instance"`
	Id          *uint64                                                                                                 `path:"id" module:"openconfig-network-instance"`
	NextHops    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops    `path:"next-hops" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional struct {
	Condition map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition `path:"condition" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional) IsYANGGoStruct() {
}

// NewCondition creates a new entry in the Condition list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional) NewCondition(Id uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Condition == nil {
		t.Condition = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Condition[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Condition", key)
	}

	t.Condition[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition{
		Id: &Id,
	}

	return t.Condition[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition struct {
	Id              *uint64                                                                                                                           `path:"id" module:"openconfig-network-instance"`
	InputInterfaces *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces `path:"input-interfaces" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition/input-interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces struct {
	InputInterface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface `path:"input-interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces) IsYANGGoStruct() {
}

// NewInputInterface creates a new entry in the InputInterface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces) NewInputInterface(Id string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InputInterface == nil {
		t.InputInterface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.InputInterface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list InputInterface", key)
	}

	t.InputInterface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface{
		Id: &Id,
	}

	return t.InputInterface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition/input-interfaces/input-interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface struct {
	Id    *string                                                                                                                                                `path:"id" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition/input-interfaces/input-interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State struct {
	Id           *string `path:"id" module:"openconfig-network-instance"`
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_InputInterfaces_InputInterface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/conditional/condition/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State struct {
	Dscp         []uint8 `path:"dscp" module:"openconfig-network-instance"`
	Id           *uint64 `path:"id" module:"openconfig-network-instance"`
	NextHopGroup *uint64 `path:"next-hop-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_Conditional_Condition_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/next-hops YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops struct {
	NextHop map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop `path:"next-hop" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops) IsYANGGoStruct() {
}

// NewNextHop creates a new entry in the NextHop list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops) NewNextHop(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/next-hops/next-hop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop struct {
	Index *uint64                                                                                                            `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/next-hops/next-hop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State struct {
	Index  *uint64 `path:"index" module:"openconfig-network-instance"`
	Weight *uint64 `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_NextHops_NextHop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hop-groups/next-hop-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State struct {
	BackupNextHopGroup *uint64 `path:"backup-next-hop-group" module:"openconfig-network-instance"`
	Color              *uint64 `path:"color" module:"openconfig-network-instance"`
	Id                 *uint64 `path:"id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHopGroups_NextHopGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops struct {
	NextHop map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop `path:"next-hop" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops) IsYANGGoStruct() {}

// NewNextHop creates a new entry in the NextHop list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops) NewNextHop(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop struct {
	Index        *uint64                                                                                        `path:"index" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State represents the /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State struct {
	EncapsulateHeader    E_OpenconfigAft_EncapsulationHeaderType                                                                             `path:"encapsulate-header" module:"openconfig-network-instance"`
	Index                *uint64                                                                                                             `path:"index" module:"openconfig-network-instance"`
	IpAddress            *string                                                                                                             `path:"ip-address" module:"openconfig-network-instance"`
	LspName              *string                                                                                                             `path:"lsp-name" module:"openconfig-network-instance"`
	MacAddress           *string                                                                                                             `path:"mac-address" module:"openconfig-network-instance"`
	OriginProtocol       E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                                                       `path:"origin-protocol" module:"openconfig-network-instance"`
	PushedMplsLabelStack []OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union `path:"pushed-mpls-label-stack" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/state/pushed-mpls-label-stack within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack is used when /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/state/pushed-mpls-label-stack
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/afts/next-hops/next-hop/state/pushed-mpls-label-stack
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding represents the /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding struct {
	PolicyForwardingEntry map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry `path:"policy-forwarding-entry" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding) IsYANGGoStruct() {
}

// NewPolicyForwardingEntry creates a new entry in the PolicyForwardingEntry list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding) NewPolicyForwardingEntry(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PolicyForwardingEntry == nil {
		t.PolicyForwardingEntry = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PolicyForwardingEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PolicyForwardingEntry", key)
	}

	t.PolicyForwardingEntry[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry{
		Index: &Index,
	}

	return t.PolicyForwardingEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry represents the /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry struct {
	Index *uint64                                                                                                       `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State represents the /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State struct {
	Index            *uint64                                                                                                                       `path:"index" module:"openconfig-network-instance"`
	IpDscp           *uint8                                                                                                                        `path:"ip-dscp" module:"openconfig-network-instance"`
	IpPrefix         *string                                                                                                                       `path:"ip-prefix" module:"openconfig-network-instance"`
	IpProtocol       OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union `path:"ip-protocol" module:"openconfig-network-instance"`
	L4DstPort        *uint16                                                                                                                       `path:"l4-dst-port" module:"openconfig-network-instance"`
	L4SrcPort        *uint16                                                                                                                       `path:"l4-src-port" module:"openconfig-network-instance"`
	MacAddress       *string                                                                                                                       `path:"mac-address" module:"openconfig-network-instance"`
	MplsLabel        OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union  `path:"mpls-label" module:"openconfig-network-instance"`
	MplsTc           *uint8                                                                                                                        `path:"mpls-tc" module:"openconfig-network-instance"`
	NextHopGroup     *uint64                                                                                                                       `path:"next-hop-group" module:"openconfig-network-instance"`
	OctetsForwarded  *uint64                                                                                                                       `path:"octets-forwarded" module:"openconfig-network-instance"`
	PacketsForwarded *uint64                                                                                                                       `path:"packets-forwarded" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/ip-protocol within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/ip-protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_Uint8 is used when /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/ip-protocol
// is to be set to a uint8 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_Uint8
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_Uint8) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_IpProtocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/mpls-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel is used when /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/mpls-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/mpls-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config represents the /openconfig-network-instance/network-instances/network-instance/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config struct {
	Description            *string                                                `path:"description" module:"openconfig-network-instance"`
	Enabled                *bool                                                  `path:"enabled" module:"openconfig-network-instance"`
	EnabledAddressFamilies []E_OpenconfigTypes_ADDRESS_FAMILY                     `path:"enabled-address-families" module:"openconfig-network-instance"`
	Mtu                    *uint16                                                `path:"mtu" module:"openconfig-network-instance"`
	Name                   *string                                                `path:"name" module:"openconfig-network-instance"`
	RouteDistinguisher     *string                                                `path:"route-distinguisher" module:"openconfig-network-instance"`
	RouterId               *string                                                `path:"router-id" module:"openconfig-network-instance"`
	Type                   E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints represents the /openconfig-network-instance/network-instances/network-instance/connection-points YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints struct {
	ConnectionPoint map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint `path:"connection-point" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints) IsYANGGoStruct() {
}

// NewConnectionPoint creates a new entry in the ConnectionPoint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints) NewConnectionPoint(ConnectionPointId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ConnectionPoint == nil {
		t.ConnectionPoint = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint)
	}

	key := ConnectionPointId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ConnectionPoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ConnectionPoint", key)
	}

	t.ConnectionPoint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint{
		ConnectionPointId: &ConnectionPointId,
	}

	return t.ConnectionPoint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint struct {
	Config            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config    `path:"config" module:"openconfig-network-instance"`
	ConnectionPointId *string                                                                                                `path:"connection-point-id" module:"openconfig-network-instance"`
	Endpoints         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints `path:"endpoints" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State     `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConnectionPointId == nil {
		return nil, fmt.Errorf("nil value for key ConnectionPointId")
	}

	return map[string]interface{}{
		"connection-point-id": *t.ConnectionPointId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config struct {
	ConnectionPointId *string `path:"connection-point-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints struct {
	Endpoint map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint `path:"endpoint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints) IsYANGGoStruct() {
}

// NewEndpoint creates a new entry in the Endpoint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints) NewEndpoint(EndpointId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Endpoint == nil {
		t.Endpoint = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint)
	}

	key := EndpointId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Endpoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Endpoint", key)
	}

	t.Endpoint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint{
		EndpointId: &EndpointId,
	}

	return t.Endpoint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint struct {
	Config     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config `path:"config" module:"openconfig-network-instance"`
	EndpointId *string                                                                                                                `path:"endpoint-id" module:"openconfig-network-instance"`
	Local      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local  `path:"local" module:"openconfig-network-instance"`
	Remote     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote `path:"remote" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.EndpointId == nil {
		return nil, fmt.Errorf("nil value for key EndpointId")
	}

	return map[string]interface{}{
		"endpoint-id": *t.EndpointId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config struct {
	EndpointId *string                                        `path:"endpoint-id" module:"openconfig-network-instance"`
	Precedence *uint16                                        `path:"precedence" module:"openconfig-network-instance"`
	Type       E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/local YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/local/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config struct {
	Interface            *string `path:"interface" module:"openconfig-network-instance"`
	SiteId               *uint16 `path:"site-id" module:"openconfig-network-instance"`
	SiteLabelBlockOffset *uint16 `path:"site-label-block-offset" module:"openconfig-network-instance"`
	SiteLabelBlockSize   *uint16 `path:"site-label-block-size" module:"openconfig-network-instance"`
	Subinterface         *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/local/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State struct {
	Interface            *string `path:"interface" module:"openconfig-network-instance"`
	SiteId               *uint16 `path:"site-id" module:"openconfig-network-instance"`
	SiteLabelBlockOffset *uint16 `path:"site-label-block-offset" module:"openconfig-network-instance"`
	SiteLabelBlockSize   *uint16 `path:"site-label-block-size" module:"openconfig-network-instance"`
	Subinterface         *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Local_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/remote YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/remote/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config struct {
	RemoteSystem             *string `path:"remote-system" module:"openconfig-network-instance"`
	SiteId                   *uint16 `path:"site-id" module:"openconfig-network-instance"`
	VirtualCircuitIdentifier *uint32 `path:"virtual-circuit-identifier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/remote/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State struct {
	RemoteSystem             *string `path:"remote-system" module:"openconfig-network-instance"`
	SiteId                   *uint16 `path:"site-id" module:"openconfig-network-instance"`
	VirtualCircuitIdentifier *uint32 `path:"virtual-circuit-identifier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_Remote_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State struct {
	Active     *bool                                          `path:"active" module:"openconfig-network-instance"`
	EndpointId *string                                        `path:"endpoint-id" module:"openconfig-network-instance"`
	Precedence *uint16                                        `path:"precedence" module:"openconfig-network-instance"`
	Type       E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_Endpoints_Endpoint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State represents the /openconfig-network-instance/network-instances/network-instance/connection-points/connection-point/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State struct {
	ConnectionPointId *string `path:"connection-point-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_ConnectionPoints_ConnectionPoint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation represents the /openconfig-network-instance/network-instances/network-instance/encapsulation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config represents the /openconfig-network-instance/network-instances/network-instance/encapsulation/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config struct {
	ControlWord         *bool                                                  `path:"control-word" module:"openconfig-network-instance"`
	EncapsulationType   E_OpenconfigNetworkInstanceTypes_ENCAPSULATION         `path:"encapsulation-type" module:"openconfig-network-instance"`
	LabelAllocationMode E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE `path:"label-allocation-mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State represents the /openconfig-network-instance/network-instances/network-instance/encapsulation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State struct {
	ControlWord         *bool                                                  `path:"control-word" module:"openconfig-network-instance"`
	EncapsulationType   E_OpenconfigNetworkInstanceTypes_ENCAPSULATION         `path:"encapsulation-type" module:"openconfig-network-instance"`
	LabelAllocationMode E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE `path:"label-allocation-mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Encapsulation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb represents the /openconfig-network-instance/network-instances/network-instance/fdb YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config   `path:"config" module:"openconfig-network-instance"`
	MacTable *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable `path:"mac-table" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config represents the /openconfig-network-instance/network-instances/network-instance/fdb/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config struct {
	MacAgingTime   *uint16 `path:"mac-aging-time" module:"openconfig-network-instance"`
	MacLearning    *bool   `path:"mac-learning" module:"openconfig-network-instance"`
	MaximumEntries *uint16 `path:"maximum-entries" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable struct {
	Entries *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries `path:"entries" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries struct {
	Entry map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry `path:"entry" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Key represents the key for list Entry of element /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Key struct {
	MacAddress string `path:"mac-address"`
	Vlan       uint16 `path:"vlan"`
}

// NewEntry creates a new entry in the Entry list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries) NewEntry(MacAddress string, Vlan uint16) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Entry == nil {
		t.Entry = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Key{
		MacAddress: MacAddress,
		Vlan:       Vlan,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Entry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Entry", key)
	}

	t.Entry[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry{
		MacAddress: &MacAddress,
		Vlan:       &Vlan,
	}

	return t.Entry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry struct {
	Config     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config    `path:"config" module:"openconfig-network-instance"`
	Interface  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface `path:"interface" module:"openconfig-network-instance"`
	MacAddress *string                                                                                          `path:"mac-address" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State     `path:"state" module:"openconfig-network-instance"`
	Vlan       *uint16                                                                                          `path:"vlan" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MacAddress == nil {
		return nil, fmt.Errorf("nil value for key MacAddress")
	}

	if t.Vlan == nil {
		return nil, fmt.Errorf("nil value for key Vlan")
	}

	return map[string]interface{}{
		"mac-address": *t.MacAddress,
		"vlan":        *t.Vlan,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config struct {
	MacAddress *string `path:"mac-address" module:"openconfig-network-instance"`
	Vlan       *uint16 `path:"vlan" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface struct {
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State represents the /openconfig-network-instance/network-instances/network-instance/fdb/mac-table/entries/entry/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State struct {
	Age        *uint64                                                                                                 `path:"age" module:"openconfig-network-instance"`
	EntryType  E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType `path:"entry-type" module:"openconfig-network-instance"`
	MacAddress *string                                                                                                 `path:"mac-address" module:"openconfig-network-instance"`
	Vlan       *uint16                                                                                                 `path:"vlan" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State represents the /openconfig-network-instance/network-instances/network-instance/fdb/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State struct {
	MacAgingTime   *uint16 `path:"mac-aging-time" module:"openconfig-network-instance"`
	MacLearning    *bool   `path:"mac-learning" module:"openconfig-network-instance"`
	MaximumEntries *uint16 `path:"maximum-entries" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies represents the /openconfig-network-instance/network-instances/network-instance/inter-instance-policies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies struct {
	ApplyPolicy *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy `path:"apply-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/inter-instance-policies/apply-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config represents the /openconfig-network-instance/network-instances/network-instance/inter-instance-policies/apply-policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State represents the /openconfig-network-instance/network-instances/network-instance/inter-instance-policies/apply-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_InterInstancePolicies_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces) IsYANGGoStruct() {}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces) NewInterface(Id string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config `path:"config" module:"openconfig-network-instance"`
	Id     *string                                                                                 `path:"id" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config struct {
	AssociatedAddressFamilies []E_OpenconfigTypes_ADDRESS_FAMILY `path:"associated-address-families" module:"openconfig-network-instance"`
	Id                        *string                            `path:"id" module:"openconfig-network-instance"`
	Interface                 *string                            `path:"interface" module:"openconfig-network-instance"`
	Subinterface              *uint32                            `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State struct {
	AssociatedAddressFamilies []E_OpenconfigTypes_ADDRESS_FAMILY `path:"associated-address-families" module:"openconfig-network-instance"`
	Id                        *string                            `path:"id" module:"openconfig-network-instance"`
	Interface                 *string                            `path:"interface" module:"openconfig-network-instance"`
	Subinterface              *uint32                            `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls represents the /openconfig-network-instance/network-instances/network-instance/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls struct {
	Global                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global                `path:"global" module:"openconfig-network-instance"`
	Lsps                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps                  `path:"lsps" module:"openconfig-network-instance"`
	SignalingProtocols    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols    `path:"signaling-protocols" module:"openconfig-network-instance"`
	TeGlobalAttributes    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes    `path:"te-global-attributes" module:"openconfig-network-instance"`
	TeInterfaceAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes `path:"te-interface-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global represents the /openconfig-network-instance/network-instances/network-instance/mpls/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global struct {
	Config              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config              `path:"config" module:"openconfig-network-instance"`
	InterfaceAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes `path:"interface-attributes" module:"openconfig-network-instance"`
	ReservedLabelBlocks *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks `path:"reserved-label-blocks" module:"openconfig-network-instance"`
	State               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State               `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config struct {
	NullLabel       E_OpenconfigMplsTypes_NULL_LABEL_TYPE          `path:"null-label" module:"openconfig-network-instance"`
	PwEncapsulation E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION `path:"pw-encapsulation" module:"openconfig-network-instance"`
	TtlPropagation  *bool                                          `path:"ttl-propagation" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config       `path:"config" module:"openconfig-network-instance"`
	InterfaceId  *string                                                                                                            `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config struct {
	InterfaceId *string `path:"interface-id" module:"openconfig-network-instance"`
	MplsEnabled *bool   `path:"mpls-enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/interface-attributes/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State struct {
	InterfaceId *string `path:"interface-id" module:"openconfig-network-instance"`
	MplsEnabled *bool   `path:"mpls-enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_InterfaceAttributes_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks struct {
	ReservedLabelBlock map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock `path:"reserved-label-block" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks) IsYANGGoStruct() {
}

// NewReservedLabelBlock creates a new entry in the ReservedLabelBlock list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks) NewReservedLabelBlock(LocalId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ReservedLabelBlock == nil {
		t.ReservedLabelBlock = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock)
	}

	key := LocalId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ReservedLabelBlock[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ReservedLabelBlock", key)
	}

	t.ReservedLabelBlock[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock{
		LocalId: &LocalId,
	}

	return t.ReservedLabelBlock[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config `path:"config" module:"openconfig-network-instance"`
	LocalId *string                                                                                                               `path:"local-id" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalId == nil {
		return nil, fmt.Errorf("nil value for key LocalId")
	}

	return map[string]interface{}{
		"local-id": *t.LocalId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config struct {
	LocalId    *string                                                                                                                               `path:"local-id" module:"openconfig-network-instance"`
	LowerBound OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union `path:"lower-bound" module:"openconfig-network-instance"`
	UpperBound OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union `path:"upper-bound" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/lower-bound within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/lower-bound
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/lower-bound
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/upper-bound within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/upper-bound
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/upper-bound
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State struct {
	LocalId    *string                                                                                                                              `path:"local-id" module:"openconfig-network-instance"`
	LowerBound OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union `path:"lower-bound" module:"openconfig-network-instance"`
	UpperBound OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union `path:"upper-bound" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/lower-bound within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/lower-bound
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/lower-bound
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_LowerBound_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/upper-bound within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/upper-bound
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/upper-bound
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_State_UpperBound_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State struct {
	NullLabel       E_OpenconfigMplsTypes_NULL_LABEL_TYPE          `path:"null-label" module:"openconfig-network-instance"`
	PwEncapsulation E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION `path:"pw-encapsulation" module:"openconfig-network-instance"`
	TtlPropagation  *bool                                          `path:"ttl-propagation" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps struct {
	ConstrainedPath   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath   `path:"constrained-path" module:"openconfig-network-instance"`
	StaticLsps        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps        `path:"static-lsps" module:"openconfig-network-instance"`
	UnconstrainedPath *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath `path:"unconstrained-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath struct {
	NamedExplicitPaths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths `path:"named-explicit-paths" module:"openconfig-network-instance"`
	Tunnels            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels            `path:"tunnels" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths struct {
	NamedExplicitPath map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath `path:"named-explicit-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths) IsYANGGoStruct() {
}

// NewNamedExplicitPath creates a new entry in the NamedExplicitPath list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths) NewNamedExplicitPath(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NamedExplicitPath == nil {
		t.NamedExplicitPath = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NamedExplicitPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NamedExplicitPath", key)
	}

	t.NamedExplicitPath[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath{
		Name: &Name,
	}

	return t.NamedExplicitPath[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath struct {
	Config               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config               `path:"config" module:"openconfig-network-instance"`
	ExplicitRouteObjects *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects `path:"explicit-route-objects" module:"openconfig-network-instance"`
	Name                 *string                                                                                                                                         `path:"name" module:"openconfig-network-instance"`
	State                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State                `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config struct {
	Name                  *string                                                                                                                                             `path:"name" module:"openconfig-network-instance"`
	SidProtectionRequired *bool                                                                                                                                               `path:"sid-protection-required" module:"openconfig-network-instance"`
	SidSelectionMode      E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode `path:"sid-selection-mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects struct {
	ExplicitRouteObject map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject `path:"explicit-route-object" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects) IsYANGGoStruct() {
}

// NewExplicitRouteObject creates a new entry in the ExplicitRouteObject list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects) NewExplicitRouteObject(Index uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExplicitRouteObject == nil {
		t.ExplicitRouteObject = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExplicitRouteObject[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExplicitRouteObject", key)
	}

	t.ExplicitRouteObject[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject{
		Index: &Index,
	}

	return t.ExplicitRouteObject[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config `path:"config" module:"openconfig-network-instance"`
	Index  *uint8                                                                                                                                                                     `path:"index" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config struct {
	Address *string                      `path:"address" module:"openconfig-network-instance"`
	HopType E_OpenconfigMpls_MplsHopType `path:"hop-type" module:"openconfig-network-instance"`
	Index   *uint8                       `path:"index" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State struct {
	Address *string                      `path:"address" module:"openconfig-network-instance"`
	HopType E_OpenconfigMpls_MplsHopType `path:"hop-type" module:"openconfig-network-instance"`
	Index   *uint8                       `path:"index" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_ExplicitRouteObjects_ExplicitRouteObject_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State struct {
	Name                  *string                                                                                                                                             `path:"name" module:"openconfig-network-instance"`
	SidProtectionRequired *bool                                                                                                                                               `path:"sid-protection-required" module:"openconfig-network-instance"`
	SidSelectionMode      E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode `path:"sid-selection-mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels struct {
	Tunnel map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel `path:"tunnel" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels) IsYANGGoStruct() {
}

// NewTunnel creates a new entry in the Tunnel list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels) NewTunnel(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tunnel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tunnel", key)
	}

	t.Tunnel[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel{
		Name: &Name,
	}

	return t.Tunnel[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel struct {
	Bandwidth           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth           `path:"bandwidth" module:"openconfig-network-instance"`
	Config              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config              `path:"config" module:"openconfig-network-instance"`
	Name                *string                                                                                                                  `path:"name" module:"openconfig-network-instance"`
	P2PTunnelAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes `path:"p2p-tunnel-attributes" module:"openconfig-network-instance"`
	State               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State               `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth struct {
	AutoBandwidth *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth `path:"auto-bandwidth" module:"openconfig-network-instance"`
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config        `path:"config" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth struct {
	Config    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config    `path:"config" module:"openconfig-network-instance"`
	Overflow  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow  `path:"overflow" module:"openconfig-network-instance"`
	State     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State     `path:"state" module:"openconfig-network-instance"`
	Underflow *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow `path:"underflow" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config struct {
	AdjustInterval  *uint32 `path:"adjust-interval" module:"openconfig-network-instance"`
	AdjustThreshold *uint8  `path:"adjust-threshold" module:"openconfig-network-instance"`
	Enabled         *bool   `path:"enabled" module:"openconfig-network-instance"`
	MaxBw           *uint64 `path:"max-bw" module:"openconfig-network-instance"`
	MinBw           *uint64 `path:"min-bw" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/overflow YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/overflow/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config struct {
	Enabled           *bool   `path:"enabled" module:"openconfig-network-instance"`
	OverflowThreshold *uint8  `path:"overflow-threshold" module:"openconfig-network-instance"`
	TriggerEventCount *uint16 `path:"trigger-event-count" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/overflow/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State struct {
	Enabled           *bool   `path:"enabled" module:"openconfig-network-instance"`
	OverflowThreshold *uint8  `path:"overflow-threshold" module:"openconfig-network-instance"`
	TriggerEventCount *uint16 `path:"trigger-event-count" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Overflow_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State struct {
	AdjustInterval  *uint32 `path:"adjust-interval" module:"openconfig-network-instance"`
	AdjustThreshold *uint8  `path:"adjust-threshold" module:"openconfig-network-instance"`
	Enabled         *bool   `path:"enabled" module:"openconfig-network-instance"`
	IntervalHighBw  *uint64 `path:"interval-high-bw" module:"openconfig-network-instance"`
	MaxBw           *uint64 `path:"max-bw" module:"openconfig-network-instance"`
	MinBw           *uint64 `path:"min-bw" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/underflow YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/underflow/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	TriggerEventCount  *uint16 `path:"trigger-event-count" module:"openconfig-network-instance"`
	UnderflowThreshold *uint8  `path:"underflow-threshold" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/auto-bandwidth/underflow/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	TriggerEventCount  *uint16 `path:"trigger-event-count" module:"openconfig-network-instance"`
	UnderflowThreshold *uint8  `path:"underflow-threshold" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_AutoBandwidth_Underflow_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config struct {
	SetBandwidth      *uint64                          `path:"set-bandwidth" module:"openconfig-network-instance"`
	SpecificationType E_OpenconfigMpls_TeBandwidthType `path:"specification-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State struct {
	SetBandwidth      *uint64                          `path:"set-bandwidth" module:"openconfig-network-instance"`
	SignaledBandwidth *uint64                          `path:"signaled-bandwidth" module:"openconfig-network-instance"`
	SpecificationType E_OpenconfigMpls_TeBandwidthType `path:"specification-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Bandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config struct {
	AdminStatus              E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS `path:"admin-status" module:"openconfig-network-instance"`
	Description              *string                                   `path:"description" module:"openconfig-network-instance"`
	HoldPriority             *uint8                                    `path:"hold-priority" module:"openconfig-network-instance"`
	Metric                   *int32                                    `path:"metric" module:"openconfig-network-instance"`
	MetricType               E_OpenconfigMplsTypes_LSP_METRIC_TYPE     `path:"metric-type" module:"openconfig-network-instance"`
	Name                     *string                                   `path:"name" module:"openconfig-network-instance"`
	Preference               *uint8                                    `path:"preference" module:"openconfig-network-instance"`
	ProtectionStyleRequested E_OpenconfigMplsTypes_PROTECTION_TYPE     `path:"protection-style-requested" module:"openconfig-network-instance"`
	ReoptimizeTimer          *uint16                                   `path:"reoptimize-timer" module:"openconfig-network-instance"`
	SetupPriority            *uint8                                    `path:"setup-priority" module:"openconfig-network-instance"`
	ShortcutEligible         *bool                                     `path:"shortcut-eligible" module:"openconfig-network-instance"`
	SignalingProtocol        E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL `path:"signaling-protocol" module:"openconfig-network-instance"`
	SoftPreemption           *bool                                     `path:"soft-preemption" module:"openconfig-network-instance"`
	Source                   *string                                   `path:"source" module:"openconfig-network-instance"`
	Type                     E_OpenconfigMplsTypes_TUNNEL_TYPE         `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes struct {
	Config            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config            `path:"config" module:"openconfig-network-instance"`
	P2PPrimaryPath    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath    `path:"p2p-primary-path" module:"openconfig-network-instance"`
	P2PSecondaryPaths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths `path:"p2p-secondary-paths" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State             `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config struct {
	Destination *string `path:"destination" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct {
	P2PPrimaryPath map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath `path:"p2p-primary-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) IsYANGGoStruct() {
}

// NewP2PPrimaryPath creates a new entry in the P2PPrimaryPath list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) NewP2PPrimaryPath(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.P2PPrimaryPath == nil {
		t.P2PPrimaryPath = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.P2PPrimaryPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list P2PPrimaryPath", key)
	}

	t.P2PPrimaryPath[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath{
		Name: &Name,
	}

	return t.P2PPrimaryPath[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath struct {
	AdminGroups             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups             `path:"admin-groups" module:"openconfig-network-instance"`
	CandidateSecondaryPaths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths `path:"candidate-secondary-paths" module:"openconfig-network-instance"`
	Config                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config                  `path:"config" module:"openconfig-network-instance"`
	Name                    *string                                                                                                                                                                        `path:"name" module:"openconfig-network-instance"`
	State                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State                   `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/admin-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/admin-groups/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config struct {
	ExcludeGroup    []string `path:"exclude-group" module:"openconfig-network-instance"`
	IncludeAllGroup []string `path:"include-all-group" module:"openconfig-network-instance"`
	IncludeAnyGroup []string `path:"include-any-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/admin-groups/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State struct {
	ExcludeGroup    []string `path:"exclude-group" module:"openconfig-network-instance"`
	IncludeAllGroup []string `path:"include-all-group" module:"openconfig-network-instance"`
	IncludeAnyGroup []string `path:"include-any-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_AdminGroups_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/candidate-secondary-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths struct {
	CandidateSecondaryPath map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath `path:"candidate-secondary-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths) IsYANGGoStruct() {
}

// NewCandidateSecondaryPath creates a new entry in the CandidateSecondaryPath list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths) NewCandidateSecondaryPath(SecondaryPath string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.CandidateSecondaryPath == nil {
		t.CandidateSecondaryPath = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath)
	}

	key := SecondaryPath

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.CandidateSecondaryPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list CandidateSecondaryPath", key)
	}

	t.CandidateSecondaryPath[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath{
		SecondaryPath: &SecondaryPath,
	}

	return t.CandidateSecondaryPath[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/candidate-secondary-paths/candidate-secondary-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath struct {
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config `path:"config" module:"openconfig-network-instance"`
	SecondaryPath *string                                                                                                                                                                                                      `path:"secondary-path" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SecondaryPath == nil {
		return nil, fmt.Errorf("nil value for key SecondaryPath")
	}

	return map[string]interface{}{
		"secondary-path": *t.SecondaryPath,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/candidate-secondary-paths/candidate-secondary-path/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config struct {
	Priority      *uint16 `path:"priority" module:"openconfig-network-instance"`
	SecondaryPath *string `path:"secondary-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/candidate-secondary-paths/candidate-secondary-path/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State struct {
	Active        *bool   `path:"active" module:"openconfig-network-instance"`
	Priority      *uint16 `path:"priority" module:"openconfig-network-instance"`
	SecondaryPath *string `path:"secondary-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_CandidateSecondaryPaths_CandidateSecondaryPath_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config struct {
	CspfTiebreaker        E_OpenconfigMpls_CspfTieBreaking              `path:"cspf-tiebreaker" module:"openconfig-network-instance"`
	ExplicitPathName      *string                                       `path:"explicit-path-name" module:"openconfig-network-instance"`
	HoldPriority          *uint8                                        `path:"hold-priority" module:"openconfig-network-instance"`
	Name                  *string                                       `path:"name" module:"openconfig-network-instance"`
	PathComputationMethod E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD `path:"path-computation-method" module:"openconfig-network-instance"`
	PathComputationServer *string                                       `path:"path-computation-server" module:"openconfig-network-instance"`
	Preference            *uint8                                        `path:"preference" module:"openconfig-network-instance"`
	RetryTimer            *uint16                                       `path:"retry-timer" module:"openconfig-network-instance"`
	SetupPriority         *uint8                                        `path:"setup-priority" module:"openconfig-network-instance"`
	UseCspf               *bool                                         `path:"use-cspf" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State struct {
	AssociatedRsvpSessions []uint64                                      `path:"associated-rsvp-sessions" module:"openconfig-network-instance"`
	CspfMetric             *uint64                                       `path:"cspf-metric" module:"openconfig-network-instance"`
	CspfTiebreaker         E_OpenconfigMpls_CspfTieBreaking              `path:"cspf-tiebreaker" module:"openconfig-network-instance"`
	ExplicitPathName       *string                                       `path:"explicit-path-name" module:"openconfig-network-instance"`
	HoldPriority           *uint8                                        `path:"hold-priority" module:"openconfig-network-instance"`
	Name                   *string                                       `path:"name" module:"openconfig-network-instance"`
	PathComputationMethod  E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD `path:"path-computation-method" module:"openconfig-network-instance"`
	PathComputationServer  *string                                       `path:"path-computation-server" module:"openconfig-network-instance"`
	Preference             *uint8                                        `path:"preference" module:"openconfig-network-instance"`
	RetryTimer             *uint16                                       `path:"retry-timer" module:"openconfig-network-instance"`
	SetupPriority          *uint8                                        `path:"setup-priority" module:"openconfig-network-instance"`
	SpfMetric              *uint64                                       `path:"spf-metric" module:"openconfig-network-instance"`
	UseCspf                *bool                                         `path:"use-cspf" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PPrimaryPath_P2PPrimaryPath_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths struct {
	P2PSecondaryPath map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath `path:"p2p-secondary-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths) IsYANGGoStruct() {
}

// NewP2PSecondaryPath creates a new entry in the P2PSecondaryPath list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths) NewP2PSecondaryPath(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.P2PSecondaryPath == nil {
		t.P2PSecondaryPath = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.P2PSecondaryPath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list P2PSecondaryPath", key)
	}

	t.P2PSecondaryPath[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath{
		Name: &Name,
	}

	return t.P2PSecondaryPath[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath struct {
	AdminGroups *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups `path:"admin-groups" module:"openconfig-network-instance"`
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config      `path:"config" module:"openconfig-network-instance"`
	Name        *string                                                                                                                                                                 `path:"name" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/admin-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/admin-groups/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config struct {
	ExcludeGroup    []string `path:"exclude-group" module:"openconfig-network-instance"`
	IncludeAllGroup []string `path:"include-all-group" module:"openconfig-network-instance"`
	IncludeAnyGroup []string `path:"include-any-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/admin-groups/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State struct {
	ExcludeGroup    []string `path:"exclude-group" module:"openconfig-network-instance"`
	IncludeAllGroup []string `path:"include-all-group" module:"openconfig-network-instance"`
	IncludeAnyGroup []string `path:"include-any-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_AdminGroups_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config struct {
	CspfTiebreaker        E_OpenconfigMpls_CspfTieBreaking              `path:"cspf-tiebreaker" module:"openconfig-network-instance"`
	ExplicitPathName      *string                                       `path:"explicit-path-name" module:"openconfig-network-instance"`
	HoldPriority          *uint8                                        `path:"hold-priority" module:"openconfig-network-instance"`
	Name                  *string                                       `path:"name" module:"openconfig-network-instance"`
	PathComputationMethod E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD `path:"path-computation-method" module:"openconfig-network-instance"`
	PathComputationServer *string                                       `path:"path-computation-server" module:"openconfig-network-instance"`
	Preference            *uint8                                        `path:"preference" module:"openconfig-network-instance"`
	RetryTimer            *uint16                                       `path:"retry-timer" module:"openconfig-network-instance"`
	SetupPriority         *uint8                                        `path:"setup-priority" module:"openconfig-network-instance"`
	UseCspf               *bool                                         `path:"use-cspf" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State struct {
	AssociatedRsvpSessions []uint64                                      `path:"associated-rsvp-sessions" module:"openconfig-network-instance"`
	CspfMetric             *uint64                                       `path:"cspf-metric" module:"openconfig-network-instance"`
	CspfTiebreaker         E_OpenconfigMpls_CspfTieBreaking              `path:"cspf-tiebreaker" module:"openconfig-network-instance"`
	ExplicitPathName       *string                                       `path:"explicit-path-name" module:"openconfig-network-instance"`
	HoldPriority           *uint8                                        `path:"hold-priority" module:"openconfig-network-instance"`
	Name                   *string                                       `path:"name" module:"openconfig-network-instance"`
	PathComputationMethod  E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD `path:"path-computation-method" module:"openconfig-network-instance"`
	PathComputationServer  *string                                       `path:"path-computation-server" module:"openconfig-network-instance"`
	Preference             *uint8                                        `path:"preference" module:"openconfig-network-instance"`
	RetryTimer             *uint16                                       `path:"retry-timer" module:"openconfig-network-instance"`
	SetupPriority          *uint8                                        `path:"setup-priority" module:"openconfig-network-instance"`
	SpfMetric              *uint64                                       `path:"spf-metric" module:"openconfig-network-instance"`
	UseCspf                *bool                                         `path:"use-cspf" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_P2PSecondaryPaths_P2PSecondaryPath_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State struct {
	Destination *string `path:"destination" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_P2PTunnelAttributes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State struct {
	AdminStatus              E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS                                                                           `path:"admin-status" module:"openconfig-network-instance"`
	AutoGenerated            *bool                                                                                                               `path:"auto-generated" module:"openconfig-network-instance"`
	Counters                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters `path:"counters" module:"openconfig-network-instance"`
	Description              *string                                                                                                             `path:"description" module:"openconfig-network-instance"`
	HoldPriority             *uint8                                                                                                              `path:"hold-priority" module:"openconfig-network-instance"`
	Metric                   *int32                                                                                                              `path:"metric" module:"openconfig-network-instance"`
	MetricType               E_OpenconfigMplsTypes_LSP_METRIC_TYPE                                                                               `path:"metric-type" module:"openconfig-network-instance"`
	Name                     *string                                                                                                             `path:"name" module:"openconfig-network-instance"`
	OperStatus               E_OpenconfigMplsTypes_LSP_OPER_STATUS                                                                               `path:"oper-status" module:"openconfig-network-instance"`
	Preference               *uint8                                                                                                              `path:"preference" module:"openconfig-network-instance"`
	ProtectionStyleRequested E_OpenconfigMplsTypes_PROTECTION_TYPE                                                                               `path:"protection-style-requested" module:"openconfig-network-instance"`
	ReoptimizeTimer          *uint16                                                                                                             `path:"reoptimize-timer" module:"openconfig-network-instance"`
	Role                     E_OpenconfigMplsTypes_LSP_ROLE                                                                                      `path:"role" module:"openconfig-network-instance"`
	SetupPriority            *uint8                                                                                                              `path:"setup-priority" module:"openconfig-network-instance"`
	ShortcutEligible         *bool                                                                                                               `path:"shortcut-eligible" module:"openconfig-network-instance"`
	SignalingProtocol        E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL                                                                           `path:"signaling-protocol" module:"openconfig-network-instance"`
	SoftPreemption           *bool                                                                                                               `path:"soft-preemption" module:"openconfig-network-instance"`
	Source                   *string                                                                                                             `path:"source" module:"openconfig-network-instance"`
	Type                     E_OpenconfigMplsTypes_TUNNEL_TYPE                                                                                   `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters struct {
	Bytes                  *uint64 `path:"bytes" module:"openconfig-network-instance"`
	CurrentPathTime        *uint64 `path:"current-path-time" module:"openconfig-network-instance"`
	NextReoptimizationTime *uint64 `path:"next-reoptimization-time" module:"openconfig-network-instance"`
	OnlineTime             *uint64 `path:"online-time" module:"openconfig-network-instance"`
	Packets                *uint64 `path:"packets" module:"openconfig-network-instance"`
	PathChanges            *uint64 `path:"path-changes" module:"openconfig-network-instance"`
	StateChanges           *uint64 `path:"state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_Tunnels_Tunnel_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps struct {
	StaticLsp map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp `path:"static-lsp" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps) IsYANGGoStruct() {
}

// NewStaticLsp creates a new entry in the StaticLsp list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps) NewStaticLsp(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.StaticLsp == nil {
		t.StaticLsp = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.StaticLsp[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list StaticLsp", key)
	}

	t.StaticLsp[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp{
		Name: &Name,
	}

	return t.StaticLsp[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config  `path:"config" module:"openconfig-network-instance"`
	Egress  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress  `path:"egress" module:"openconfig-network-instance"`
	Ingress *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress `path:"ingress" module:"openconfig-network-instance"`
	Name    *string                                                                                            `path:"name" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State   `path:"state" module:"openconfig-network-instance"`
	Transit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit `path:"transit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config struct {
	Name *string `path:"name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config struct {
	IncomingLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union `path:"incoming-label" module:"openconfig-network-instance"`
	NextHop       *string                                                                                                                     `path:"next-hop" module:"openconfig-network-instance"`
	PushLabel     OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union     `path:"push-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/incoming-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/incoming-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/incoming-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/push-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/push-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/push-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State struct {
	IncomingLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union `path:"incoming-label" module:"openconfig-network-instance"`
	NextHop       *string                                                                                                                    `path:"next-hop" module:"openconfig-network-instance"`
	PushLabel     OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union     `path:"push-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/incoming-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/incoming-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/incoming-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/push-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/push-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/push-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_State_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config struct {
	IncomingLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union `path:"incoming-label" module:"openconfig-network-instance"`
	NextHop       *string                                                                                                                      `path:"next-hop" module:"openconfig-network-instance"`
	PushLabel     OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union     `path:"push-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/incoming-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/incoming-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/incoming-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/push-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/push-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/push-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_Config_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State struct {
	IncomingLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union `path:"incoming-label" module:"openconfig-network-instance"`
	NextHop       *string                                                                                                                     `path:"next-hop" module:"openconfig-network-instance"`
	PushLabel     OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union     `path:"push-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/incoming-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/incoming-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/incoming-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/push-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/push-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/push-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Ingress_State_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State struct {
	Name *string `path:"name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config struct {
	IncomingLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union `path:"incoming-label" module:"openconfig-network-instance"`
	NextHop       *string                                                                                                                      `path:"next-hop" module:"openconfig-network-instance"`
	PushLabel     OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union     `path:"push-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/incoming-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/incoming-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/incoming-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/push-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/push-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/push-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_Config_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State struct {
	IncomingLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union `path:"incoming-label" module:"openconfig-network-instance"`
	NextHop       *string                                                                                                                     `path:"next-hop" module:"openconfig-network-instance"`
	PushLabel     OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union     `path:"push-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/incoming-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/incoming-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/incoming-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_IncomingLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/push-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/push-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/push-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Transit_State_PushLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/unconstrained-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath struct {
	PathSetupProtocol *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol `path:"path-setup-protocol" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/unconstrained-path/path-setup-protocol YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol struct {
	Ldp *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp `path:"ldp" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp represents the /openconfig-network-instance/network-instances/network-instance/mpls/lsps/unconstrained-path/path-setup-protocol/ldp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_UnconstrainedPath_PathSetupProtocol_Ldp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols struct {
	Ldp            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp            `path:"ldp" module:"openconfig-network-instance"`
	RsvpTe         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe         `path:"rsvp-te" module:"openconfig-network-instance"`
	SegmentRouting *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting `path:"segment-routing" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp struct {
	Global              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global              `path:"global" module:"openconfig-network-instance"`
	InterfaceAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes `path:"interface-attributes" module:"openconfig-network-instance"`
	Neighbors           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors           `path:"neighbors" module:"openconfig-network-instance"`
	Targeted            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted            `path:"targeted" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global struct {
	Authentication  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication  `path:"authentication" module:"openconfig-network-instance"`
	Config          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config          `path:"config" module:"openconfig-network-instance"`
	GracefulRestart *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart `path:"graceful-restart" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/authentication/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config struct {
	AuthenticationKey *string `path:"authentication-key" module:"openconfig-network-instance"`
	Enable            *bool   `path:"enable" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State struct {
	AuthenticationKey *string `path:"authentication-key" module:"openconfig-network-instance"`
	Enable            *bool   `path:"enable" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config struct {
	LsrId *string `path:"lsr-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	ForwardingHoldtime *uint16 `path:"forwarding-holdtime" module:"openconfig-network-instance"`
	HelperEnable       *bool   `path:"helper-enable" module:"openconfig-network-instance"`
	ReconnectTime      *uint16 `path:"reconnect-time" module:"openconfig-network-instance"`
	RecoveryTime       *uint16 `path:"recovery-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	ForwardingHoldtime *uint16 `path:"forwarding-holdtime" module:"openconfig-network-instance"`
	HelperEnable       *bool   `path:"helper-enable" module:"openconfig-network-instance"`
	ReconnectTime      *uint16 `path:"reconnect-time" module:"openconfig-network-instance"`
	RecoveryTime       *uint16 `path:"recovery-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State struct {
	LsrId *string `path:"lsr-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes struct {
	Config     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config     `path:"config" module:"openconfig-network-instance"`
	Interfaces *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces `path:"interfaces" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State      `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config struct {
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface struct {
	AddressFamilies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies `path:"address-families" module:"openconfig-network-instance"`
	Config          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config          `path:"config" module:"openconfig-network-instance"`
	InterfaceId     *string                                                                                                                                          `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef    `path:"interface-ref" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies struct {
	AddressFamily map[E_OpenconfigMplsLdp_MplsLdpAfi]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily `path:"address-family" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies) IsYANGGoStruct() {
}

// NewAddressFamily creates a new entry in the AddressFamily list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies) NewAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AddressFamily == nil {
		t.AddressFamily = make(map[E_OpenconfigMplsLdp_MplsLdpAfi]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily)
	}

	key := AfiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AddressFamily[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AddressFamily", key)
	}

	t.AddressFamily[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily{
		AfiName: AfiName,
	}

	return t.AddressFamily[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily struct {
	AfiName E_OpenconfigMplsLdp_MplsLdpAfi                                                                                                                                        `path:"afi-name" module:"openconfig-network-instance"`
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config `path:"config" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name": t.AfiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config struct {
	AfiName E_OpenconfigMplsLdp_MplsLdpAfi `path:"afi-name" module:"openconfig-network-instance"`
	Enabled *bool                          `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State struct {
	AfiName E_OpenconfigMplsLdp_MplsLdpAfi `path:"afi-name" module:"openconfig-network-instance"`
	Enabled *bool                          `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_AddressFamilies_AddressFamily_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config struct {
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	InterfaceId   *string `path:"interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State struct {
	Counters      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters `path:"counters" module:"openconfig-network-instance"`
	HelloHoldtime *uint16                                                                                                                                         `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16                                                                                                                                         `path:"hello-interval" module:"openconfig-network-instance"`
	InterfaceId   *string                                                                                                                                         `path:"interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_Interfaces_Interface_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State struct {
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_InterfaceAttributes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors struct {
	Neighbor map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Key represents the key for list Neighbor of element /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Key struct {
	LsrId        string `path:"lsr-id"`
	LabelSpaceId uint16 `path:"label-space-id"`
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors) NewNeighbor(LsrId string, LabelSpaceId uint16) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Key{
		LsrId:        LsrId,
		LabelSpaceId: LabelSpaceId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor{
		LsrId:        &LsrId,
		LabelSpaceId: &LabelSpaceId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor struct {
	Authentication   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication   `path:"authentication" module:"openconfig-network-instance"`
	Config           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config           `path:"config" module:"openconfig-network-instance"`
	HelloAdjacencies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies `path:"hello-adjacencies" module:"openconfig-network-instance"`
	LabelSpaceId     *uint16                                                                                                                     `path:"label-space-id" module:"openconfig-network-instance"`
	LsrId            *string                                                                                                                     `path:"lsr-id" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State            `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LabelSpaceId == nil {
		return nil, fmt.Errorf("nil value for key LabelSpaceId")
	}

	if t.LsrId == nil {
		return nil, fmt.Errorf("nil value for key LsrId")
	}

	return map[string]interface{}{
		"label-space-id": *t.LabelSpaceId,
		"lsr-id":         *t.LsrId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/authentication/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config struct {
	AuthenticationKey *string `path:"authentication-key" module:"openconfig-network-instance"`
	Enable            *bool   `path:"enable" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State struct {
	AuthenticationKey *string `path:"authentication-key" module:"openconfig-network-instance"`
	Enable            *bool   `path:"enable" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config struct {
	LabelSpaceId *uint16 `path:"label-space-id" module:"openconfig-network-instance"`
	LsrId        *string `path:"lsr-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies struct {
	HelloAdjacency map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency `path:"hello-adjacency" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_Key represents the key for list HelloAdjacency of element /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_Key struct {
	RemoteAddress string `path:"remote-address"`
	LocalAddress  string `path:"local-address"`
}

// NewHelloAdjacency creates a new entry in the HelloAdjacency list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies) NewHelloAdjacency(RemoteAddress string, LocalAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.HelloAdjacency == nil {
		t.HelloAdjacency = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_Key{
		RemoteAddress: RemoteAddress,
		LocalAddress:  LocalAddress,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.HelloAdjacency[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list HelloAdjacency", key)
	}

	t.HelloAdjacency[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency{
		RemoteAddress: &RemoteAddress,
		LocalAddress:  &LocalAddress,
	}

	return t.HelloAdjacency[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency struct {
	HelloHoldtime *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime `path:"hello-holdtime" module:"openconfig-network-instance"`
	InterfaceRef  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef  `path:"interface-ref" module:"openconfig-network-instance"`
	LocalAddress  *string                                                                                                                                                  `path:"local-address" module:"openconfig-network-instance"`
	RemoteAddress *string                                                                                                                                                  `path:"remote-address" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalAddress == nil {
		return nil, fmt.Errorf("nil value for key LocalAddress")
	}

	if t.RemoteAddress == nil {
		return nil, fmt.Errorf("nil value for key RemoteAddress")
	}

	return map[string]interface{}{
		"local-address":  *t.LocalAddress,
		"remote-address": *t.RemoteAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/hello-holdtime YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/hello-holdtime/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State struct {
	Adjacent        *uint16 `path:"adjacent" module:"openconfig-network-instance"`
	HelloExpiration *uint64 `path:"hello-expiration" module:"openconfig-network-instance"`
	Negotiated      *uint16 `path:"negotiated" module:"openconfig-network-instance"`
	NextHello       *uint64 `path:"next-hello" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_HelloHoldtime_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State struct {
	AdjacencyType E_OpenconfigMplsLdp_MplsLdpAdjacencyType `path:"adjacency-type" module:"openconfig-network-instance"`
	HelloDropped  *uint64                                  `path:"hello-dropped" module:"openconfig-network-instance"`
	HelloReceived *uint64                                  `path:"hello-received" module:"openconfig-network-instance"`
	LastClear     *uint64                                  `path:"last-clear" module:"openconfig-network-instance"`
	LocalAddress  *string                                  `path:"local-address" module:"openconfig-network-instance"`
	RemoteAddress *string                                  `path:"remote-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_HelloAdjacencies_HelloAdjacency_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State struct {
	LabelSpaceId *uint16                                                                                                                        `path:"label-space-id" module:"openconfig-network-instance"`
	LsrId        *string                                                                                                                        `path:"lsr-id" module:"openconfig-network-instance"`
	SessionState E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState `path:"session-state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted struct {
	AddressFamilies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies `path:"address-families" module:"openconfig-network-instance"`
	Config          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config          `path:"config" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies struct {
	AddressFamily map[E_OpenconfigMplsLdp_MplsLdpAfi]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily `path:"address-family" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies) IsYANGGoStruct() {
}

// NewAddressFamily creates a new entry in the AddressFamily list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies) NewAddressFamily(AfiName E_OpenconfigMplsLdp_MplsLdpAfi) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AddressFamily == nil {
		t.AddressFamily = make(map[E_OpenconfigMplsLdp_MplsLdpAfi]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily)
	}

	key := AfiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AddressFamily[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AddressFamily", key)
	}

	t.AddressFamily[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily{
		AfiName: AfiName,
	}

	return t.AddressFamily[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily struct {
	AfiName E_OpenconfigMplsLdp_MplsLdpAfi                                                                                                         `path:"afi-name" module:"openconfig-network-instance"`
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config  `path:"config" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State   `path:"state" module:"openconfig-network-instance"`
	Targets *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets `path:"targets" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name": t.AfiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config struct {
	AfiName E_OpenconfigMplsLdp_MplsLdpAfi `path:"afi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State struct {
	AfiName E_OpenconfigMplsLdp_MplsLdpAfi `path:"afi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/targets YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets struct {
	Target map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target `path:"target" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets) IsYANGGoStruct() {
}

// NewTarget creates a new entry in the Target list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets) NewTarget(RemoteAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Target == nil {
		t.Target = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target)
	}

	key := RemoteAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Target[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Target", key)
	}

	t.Target[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target{
		RemoteAddress: &RemoteAddress,
	}

	return t.Target[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/targets/target YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target struct {
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config `path:"config" module:"openconfig-network-instance"`
	RemoteAddress *string                                                                                                                                              `path:"remote-address" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RemoteAddress == nil {
		return nil, fmt.Errorf("nil value for key RemoteAddress")
	}

	return map[string]interface{}{
		"remote-address": *t.RemoteAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/targets/target/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config struct {
	Enabled       *bool   `path:"enabled" module:"openconfig-network-instance"`
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	LocalAddress  *string `path:"local-address" module:"openconfig-network-instance"`
	RemoteAddress *string `path:"remote-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/targets/target/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State struct {
	Enabled       *bool   `path:"enabled" module:"openconfig-network-instance"`
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	LocalAddress  *string `path:"local-address" module:"openconfig-network-instance"`
	RemoteAddress *string `path:"remote-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_AddressFamilies_AddressFamily_Targets_Target_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config struct {
	HelloAccept   *bool   `path:"hello-accept" module:"openconfig-network-instance"`
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State struct {
	HelloAccept   *bool   `path:"hello-accept" module:"openconfig-network-instance"`
	HelloHoldtime *uint16 `path:"hello-holdtime" module:"openconfig-network-instance"`
	HelloInterval *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Targeted_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe struct {
	Global              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global              `path:"global" module:"openconfig-network-instance"`
	InterfaceAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes `path:"interface-attributes" module:"openconfig-network-instance"`
	Neighbors           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors           `path:"neighbors" module:"openconfig-network-instance"`
	Sessions            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions            `path:"sessions" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global struct {
	GracefulRestart *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart `path:"graceful-restart" module:"openconfig-network-instance"`
	Hellos          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos          `path:"hellos" module:"openconfig-network-instance"`
	SoftPreemption  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption  `path:"soft-preemption" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config struct {
	Enable       *bool   `path:"enable" module:"openconfig-network-instance"`
	RecoveryTime *uint32 `path:"recovery-time" module:"openconfig-network-instance"`
	RestartTime  *uint32 `path:"restart-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State struct {
	Enable       *bool   `path:"enable" module:"openconfig-network-instance"`
	RecoveryTime *uint32 `path:"recovery-time" module:"openconfig-network-instance"`
	RestartTime  *uint32 `path:"restart-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/hellos YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/hellos/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config struct {
	HelloInterval    *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	RefreshReduction *bool   `path:"refresh-reduction" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/hellos/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State struct {
	HelloInterval    *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	RefreshReduction *bool   `path:"refresh-reduction" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_Hellos_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/soft-preemption YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/soft-preemption/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config struct {
	Enable                *bool   `path:"enable" module:"openconfig-network-instance"`
	SoftPreemptionTimeout *uint16 `path:"soft-preemption-timeout" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/soft-preemption/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State struct {
	Enable                *bool   `path:"enable" module:"openconfig-network-instance"`
	SoftPreemptionTimeout *uint16 `path:"soft-preemption-timeout" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_SoftPreemption_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State struct {
	Counters *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters `path:"counters" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters struct {
	Errors                      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors `path:"errors" module:"openconfig-network-instance"`
	InAckMessages               *uint64                                                                                                                 `path:"in-ack-messages" module:"openconfig-network-instance"`
	InHelloMessages             *uint64                                                                                                                 `path:"in-hello-messages" module:"openconfig-network-instance"`
	InPathErrorMessages         *uint64                                                                                                                 `path:"in-path-error-messages" module:"openconfig-network-instance"`
	InPathMessages              *uint64                                                                                                                 `path:"in-path-messages" module:"openconfig-network-instance"`
	InPathTearMessages          *uint64                                                                                                                 `path:"in-path-tear-messages" module:"openconfig-network-instance"`
	InReservationErrorMessages  *uint64                                                                                                                 `path:"in-reservation-error-messages" module:"openconfig-network-instance"`
	InReservationMessages       *uint64                                                                                                                 `path:"in-reservation-messages" module:"openconfig-network-instance"`
	InReservationTearMessages   *uint64                                                                                                                 `path:"in-reservation-tear-messages" module:"openconfig-network-instance"`
	InSrefreshMessages          *uint64                                                                                                                 `path:"in-srefresh-messages" module:"openconfig-network-instance"`
	OutAckMessages              *uint64                                                                                                                 `path:"out-ack-messages" module:"openconfig-network-instance"`
	OutHelloMessages            *uint64                                                                                                                 `path:"out-hello-messages" module:"openconfig-network-instance"`
	OutPathErrorMessages        *uint64                                                                                                                 `path:"out-path-error-messages" module:"openconfig-network-instance"`
	OutPathMessages             *uint64                                                                                                                 `path:"out-path-messages" module:"openconfig-network-instance"`
	OutPathTearMessages         *uint64                                                                                                                 `path:"out-path-tear-messages" module:"openconfig-network-instance"`
	OutReservationErrorMessages *uint64                                                                                                                 `path:"out-reservation-error-messages" module:"openconfig-network-instance"`
	OutReservationMessages      *uint64                                                                                                                 `path:"out-reservation-messages" module:"openconfig-network-instance"`
	OutReservationTearMessages  *uint64                                                                                                                 `path:"out-reservation-tear-messages" module:"openconfig-network-instance"`
	OutSrefreshMessages         *uint64                                                                                                                 `path:"out-srefresh-messages" module:"openconfig-network-instance"`
	PathTimeouts                *uint64                                                                                                                 `path:"path-timeouts" module:"openconfig-network-instance"`
	RateLimitedMessages         *uint64                                                                                                                 `path:"rate-limited-messages" module:"openconfig-network-instance"`
	ReservationTimeouts         *uint64                                                                                                                 `path:"reservation-timeouts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/global/state/counters/errors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors struct {
	AuthenticationFail *uint64 `path:"authentication-fail" module:"openconfig-network-instance"`
	BadChecksum        *uint64 `path:"bad-checksum" module:"openconfig-network-instance"`
	BadPacketFormat    *uint64 `path:"bad-packet-format" module:"openconfig-network-instance"`
	BadPacketLength    *uint64 `path:"bad-packet-length" module:"openconfig-network-instance"`
	OutOfOrder         *uint64 `path:"out-of-order" module:"openconfig-network-instance"`
	ReceivedNack       *uint64 `path:"received-nack" module:"openconfig-network-instance"`
	TransmitFailure    *uint64 `path:"transmit-failure" module:"openconfig-network-instance"`
	TransmitQueueFull  *uint64 `path:"transmit-queue-full" module:"openconfig-network-instance"`
	UnknownAck         *uint64 `path:"unknown-ack" module:"openconfig-network-instance"`
	UnknownNack        *uint64 `path:"unknown-nack" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Global_State_Counters_Errors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface struct {
	Authentication        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication        `path:"authentication" module:"openconfig-network-instance"`
	BandwidthReservations *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations `path:"bandwidth-reservations" module:"openconfig-network-instance"`
	Config                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config                `path:"config" module:"openconfig-network-instance"`
	Hellos                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos                `path:"hellos" module:"openconfig-network-instance"`
	InterfaceId           *string                                                                                                                                        `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef          `path:"interface-ref" module:"openconfig-network-instance"`
	Protection            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection            `path:"protection" module:"openconfig-network-instance"`
	State                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State                 `path:"state" module:"openconfig-network-instance"`
	Subscription          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription          `path:"subscription" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/authentication/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config struct {
	AuthenticationKey *string `path:"authentication-key" module:"openconfig-network-instance"`
	Enable            *bool   `path:"enable" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State struct {
	AuthenticationKey *string `path:"authentication-key" module:"openconfig-network-instance"`
	Enable            *bool   `path:"enable" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations struct {
	BandwidthReservation map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation `path:"bandwidth-reservation" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations) IsYANGGoStruct() {
}

// NewBandwidthReservation creates a new entry in the BandwidthReservation list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations) NewBandwidthReservation(Priority OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthReservation == nil {
		t.BandwidthReservation = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthReservation[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthReservation", key)
	}

	t.BandwidthReservation[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation{
		Priority: Priority,
	}

	return t.BandwidthReservation[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation struct {
	Priority OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union `path:"priority" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State               `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"priority": t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/priority within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/priority
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_Uint8 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/priority
// is to be set to a uint8 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_Uint8
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_Uint8) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State struct {
	ActiveReservationsCount *uint64                                                                                                                                                                                 `path:"active-reservations-count" module:"openconfig-network-instance"`
	AvailableBandwidth      *uint64                                                                                                                                                                                 `path:"available-bandwidth" module:"openconfig-network-instance"`
	HighwaterMark           *uint64                                                                                                                                                                                 `path:"highwater-mark" module:"openconfig-network-instance"`
	Priority                OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union `path:"priority" module:"openconfig-network-instance"`
	ReservedBandwidth       *uint64                                                                                                                                                                                 `path:"reserved-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config struct {
	InterfaceId *string `path:"interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/hellos YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/hellos/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config struct {
	HelloInterval    *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	RefreshReduction *bool   `path:"refresh-reduction" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/hellos/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State struct {
	HelloInterval    *uint16 `path:"hello-interval" module:"openconfig-network-instance"`
	RefreshReduction *bool   `path:"refresh-reduction" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Hellos_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config struct {
	BypassOptimizeInterval       *uint16                               `path:"bypass-optimize-interval" module:"openconfig-network-instance"`
	LinkProtectionStyleRequested E_OpenconfigMplsTypes_PROTECTION_TYPE `path:"link-protection-style-requested" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State struct {
	BypassOptimizeInterval       *uint16                               `path:"bypass-optimize-interval" module:"openconfig-network-instance"`
	LinkProtectionStyleRequested E_OpenconfigMplsTypes_PROTECTION_TYPE `path:"link-protection-style-requested" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Protection_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State struct {
	Counters         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters `path:"counters" module:"openconfig-network-instance"`
	InterfaceId      *string                                                                                                                                 `path:"interface-id" module:"openconfig-network-instance"`
	MaxLinkBandwidth *uint64                                                                                                                                 `path:"max-link-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters struct {
	Errors                      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors `path:"errors" module:"openconfig-network-instance"`
	InAckMessages               *uint64                                                                                                                                        `path:"in-ack-messages" module:"openconfig-network-instance"`
	InHelloMessages             *uint64                                                                                                                                        `path:"in-hello-messages" module:"openconfig-network-instance"`
	InPathErrorMessages         *uint64                                                                                                                                        `path:"in-path-error-messages" module:"openconfig-network-instance"`
	InPathMessages              *uint64                                                                                                                                        `path:"in-path-messages" module:"openconfig-network-instance"`
	InPathTearMessages          *uint64                                                                                                                                        `path:"in-path-tear-messages" module:"openconfig-network-instance"`
	InReservationErrorMessages  *uint64                                                                                                                                        `path:"in-reservation-error-messages" module:"openconfig-network-instance"`
	InReservationMessages       *uint64                                                                                                                                        `path:"in-reservation-messages" module:"openconfig-network-instance"`
	InReservationTearMessages   *uint64                                                                                                                                        `path:"in-reservation-tear-messages" module:"openconfig-network-instance"`
	InSrefreshMessages          *uint64                                                                                                                                        `path:"in-srefresh-messages" module:"openconfig-network-instance"`
	OutAckMessages              *uint64                                                                                                                                        `path:"out-ack-messages" module:"openconfig-network-instance"`
	OutHelloMessages            *uint64                                                                                                                                        `path:"out-hello-messages" module:"openconfig-network-instance"`
	OutPathErrorMessages        *uint64                                                                                                                                        `path:"out-path-error-messages" module:"openconfig-network-instance"`
	OutPathMessages             *uint64                                                                                                                                        `path:"out-path-messages" module:"openconfig-network-instance"`
	OutPathTearMessages         *uint64                                                                                                                                        `path:"out-path-tear-messages" module:"openconfig-network-instance"`
	OutReservationErrorMessages *uint64                                                                                                                                        `path:"out-reservation-error-messages" module:"openconfig-network-instance"`
	OutReservationMessages      *uint64                                                                                                                                        `path:"out-reservation-messages" module:"openconfig-network-instance"`
	OutReservationTearMessages  *uint64                                                                                                                                        `path:"out-reservation-tear-messages" module:"openconfig-network-instance"`
	OutSrefreshMessages         *uint64                                                                                                                                        `path:"out-srefresh-messages" module:"openconfig-network-instance"`
	RateLimitedMessages         *uint64                                                                                                                                        `path:"rate-limited-messages" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/state/counters/errors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors struct {
	AuthenticationFail *uint64 `path:"authentication-fail" module:"openconfig-network-instance"`
	BadChecksum        *uint64 `path:"bad-checksum" module:"openconfig-network-instance"`
	BadPacketFormat    *uint64 `path:"bad-packet-format" module:"openconfig-network-instance"`
	BadPacketLength    *uint64 `path:"bad-packet-length" module:"openconfig-network-instance"`
	OutOfOrder         *uint64 `path:"out-of-order" module:"openconfig-network-instance"`
	ReceivedNack       *uint64 `path:"received-nack" module:"openconfig-network-instance"`
	TransmitFailure    *uint64 `path:"transmit-failure" module:"openconfig-network-instance"`
	TransmitQueueFull  *uint64 `path:"transmit-queue-full" module:"openconfig-network-instance"`
	UnknownAck         *uint64 `path:"unknown-ack" module:"openconfig-network-instance"`
	UnknownNack        *uint64 `path:"unknown-nack" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_State_Counters_Errors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/subscription YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/subscription/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config struct {
	Subscription *uint8 `path:"subscription" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/subscription/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State struct {
	CalculatedAbsoluteSubscriptionBw *uint64 `path:"calculated-absolute-subscription-bw" module:"openconfig-network-instance"`
	Subscription                     *uint8  `path:"subscription" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_Subscription_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors) NewNeighbor(Address string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor{
		Address: &Address,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor struct {
	Address *string                                                                                                             `path:"address" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State struct {
	Address           *string                                                                                                                             `path:"address" module:"openconfig-network-instance"`
	DetectedInterface *string                                                                                                                             `path:"detected-interface" module:"openconfig-network-instance"`
	NeighborStatus    E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus `path:"neighbor-status" module:"openconfig-network-instance"`
	RefreshReduction  *bool                                                                                                                               `path:"refresh-reduction" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions struct {
	Session map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session `path:"session" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions) IsYANGGoStruct() {
}

// NewSession creates a new entry in the Session list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions) NewSession(LocalIndex uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Session == nil {
		t.Session = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session)
	}

	key := LocalIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Session[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Session", key)
	}

	t.Session[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session{
		LocalIndex: &LocalIndex,
	}

	return t.Session[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session struct {
	ExplicitRouteObjects *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects `path:"explicit-route-objects" module:"openconfig-network-instance"`
	LocalIndex           *uint64                                                                                                                          `path:"local-index" module:"openconfig-network-instance"`
	RecordRouteObjects   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects   `path:"record-route-objects" module:"openconfig-network-instance"`
	State                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State                `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalIndex == nil {
		return nil, fmt.Errorf("nil value for key LocalIndex")
	}

	return map[string]interface{}{
		"local-index": *t.LocalIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects struct {
	ExplicitRouteObject map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject `path:"explicit-route-object" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects) IsYANGGoStruct() {
}

// NewExplicitRouteObject creates a new entry in the ExplicitRouteObject list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects) NewExplicitRouteObject(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExplicitRouteObject == nil {
		t.ExplicitRouteObject = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExplicitRouteObject[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExplicitRouteObject", key)
	}

	t.ExplicitRouteObject[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject{
		Index: &Index,
	}

	return t.ExplicitRouteObject[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject struct {
	Index *uint64                                                                                                                                                    `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State struct {
	Asn         *uint32                                                                                                                                                               `path:"asn" module:"openconfig-network-instance"`
	Index       *uint64                                                                                                                                                               `path:"index" module:"openconfig-network-instance"`
	InterfaceId *uint32                                                                                                                                                               `path:"interface-id" module:"openconfig-network-instance"`
	IpPrefix    *string                                                                                                                                                               `path:"ip-prefix" module:"openconfig-network-instance"`
	Label       OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union `path:"label" module:"openconfig-network-instance"`
	Loose       *bool                                                                                                                                                                 `path:"loose" module:"openconfig-network-instance"`
	Type        E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type      `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects struct {
	RecordRouteObject map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject `path:"record-route-object" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects) IsYANGGoStruct() {
}

// NewRecordRouteObject creates a new entry in the RecordRouteObject list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects) NewRecordRouteObject(Index uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RecordRouteObject == nil {
		t.RecordRouteObject = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RecordRouteObject[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RecordRouteObject", key)
	}

	t.RecordRouteObject[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject{
		Index: &Index,
	}

	return t.RecordRouteObject[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject struct {
	Index *uint8                                                                                                                                                 `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State struct {
	Address       *string                                                                                                                                                                   `path:"address" module:"openconfig-network-instance"`
	Index         *uint8                                                                                                                                                                    `path:"index" module:"openconfig-network-instance"`
	ReportedFlags *uint8                                                                                                                                                                    `path:"reported-flags" module:"openconfig-network-instance"`
	ReportedLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union `path:"reported-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state/reported-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state/reported-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state/reported-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State struct {
	DestinationAddress  *string                                                                                                                         `path:"destination-address" module:"openconfig-network-instance"`
	LabelIn             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union  `path:"label-in" module:"openconfig-network-instance"`
	LabelOut            OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union `path:"label-out" module:"openconfig-network-instance"`
	LocalIndex          *uint64                                                                                                                         `path:"local-index" module:"openconfig-network-instance"`
	LspId               *uint16                                                                                                                         `path:"lsp-id" module:"openconfig-network-instance"`
	ProtectionRequested E_OpenconfigMplsTypes_PROTECTION_TYPE                                                                                           `path:"protection-requested" module:"openconfig-network-instance"`
	SenderTspec         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec   `path:"sender-tspec" module:"openconfig-network-instance"`
	SessionName         *string                                                                                                                         `path:"session-name" module:"openconfig-network-instance"`
	SourceAddress       *string                                                                                                                         `path:"source-address" module:"openconfig-network-instance"`
	Status              E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status       `path:"status" module:"openconfig-network-instance"`
	TunnelId            *uint16                                                                                                                         `path:"tunnel-id" module:"openconfig-network-instance"`
	Type                E_OpenconfigMplsTypes_LSP_ROLE                                                                                                  `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-in within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-in
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-in
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-out within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-out
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-out
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/sender-tspec YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec struct {
	PeakDataRate Binary `path:"peak-data-rate" module:"openconfig-network-instance"`
	Rate         Binary `path:"rate" module:"openconfig-network-instance"`
	Size         Binary `path:"size" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_SenderTspec) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting struct {
	AggregateSidCounters *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters `path:"aggregate-sid-counters" module:"openconfig-network-instance"`
	Interfaces           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces           `path:"interfaces" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters struct {
	AggregateSidCounter map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter `path:"aggregate-sid-counter" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters) IsYANGGoStruct() {
}

// NewAggregateSidCounter creates a new entry in the AggregateSidCounter list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters) NewAggregateSidCounter(MplsLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AggregateSidCounter == nil {
		t.AggregateSidCounter = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter)
	}

	key := MplsLabel

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AggregateSidCounter[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AggregateSidCounter", key)
	}

	t.AggregateSidCounter[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter{
		MplsLabel: MplsLabel,
	}

	return t.AggregateSidCounter[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter struct {
	MplsLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union `path:"mpls-label" module:"openconfig-network-instance"`
	State     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State                `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"mpls-label": t.MplsLabel,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/mpls-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/mpls-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/mpls-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State struct {
	InOctets  *uint64                                                                                                                                                          `path:"in-octets" module:"openconfig-network-instance"`
	InPkts    *uint64                                                                                                                                                          `path:"in-pkts" module:"openconfig-network-instance"`
	MplsLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union `path:"mpls-label" module:"openconfig-network-instance"`
	OutOctets *uint64                                                                                                                                                          `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts   *uint64                                                                                                                                                          `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config       `path:"config" module:"openconfig-network-instance"`
	InterfaceId  *string                                                                                                                              `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	SidCounters  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters  `path:"sid-counters" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config struct {
	InterfaceId *string `path:"interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters struct {
	SidCounter map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter `path:"sid-counter" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters) IsYANGGoStruct() {
}

// NewSidCounter creates a new entry in the SidCounter list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters) NewSidCounter(MplsLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SidCounter == nil {
		t.SidCounter = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter)
	}

	key := MplsLabel

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SidCounter[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SidCounter", key)
	}

	t.SidCounter[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter{
		MplsLabel: MplsLabel,
	}

	return t.SidCounter[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter struct {
	ForwardingClasses *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses    `path:"forwarding-classes" module:"openconfig-network-instance"`
	MplsLabel         OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union `path:"mpls-label" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State                `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"mpls-label": t.MplsLabel,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/mpls-label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/mpls-label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/mpls-label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/forwarding-classes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses struct {
	ForwardingClass map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass `path:"forwarding-class" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses) IsYANGGoStruct() {
}

// NewForwardingClass creates a new entry in the ForwardingClass list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses) NewForwardingClass(Exp uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ForwardingClass == nil {
		t.ForwardingClass = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass)
	}

	key := Exp

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ForwardingClass[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ForwardingClass", key)
	}

	t.ForwardingClass[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass{
		Exp: &Exp,
	}

	return t.ForwardingClass[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/forwarding-classes/forwarding-class YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass struct {
	Exp   *uint8                                                                                                                                                                                 `path:"exp" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Exp == nil {
		return nil, fmt.Errorf("nil value for key Exp")
	}

	return map[string]interface{}{
		"exp": *t.Exp,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/forwarding-classes/forwarding-class/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State struct {
	Exp       *uint8  `path:"exp" module:"openconfig-network-instance"`
	InOctets  *uint64 `path:"in-octets" module:"openconfig-network-instance"`
	InPkts    *uint64 `path:"in-pkts" module:"openconfig-network-instance"`
	OutOctets *uint64 `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts   *uint64 `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_ForwardingClasses_ForwardingClass_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State struct {
	InOctets  *uint64                                                                                                                                                             `path:"in-octets" module:"openconfig-network-instance"`
	InPkts    *uint64                                                                                                                                                             `path:"in-pkts" module:"openconfig-network-instance"`
	MplsLabel OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union `path:"mpls-label" module:"openconfig-network-instance"`
	OutOctets *uint64                                                                                                                                                             `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts   *uint64                                                                                                                                                             `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_SidCounters_SidCounter_State_MplsLabel_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State struct {
	InOctets    *uint64 `path:"in-octets" module:"openconfig-network-instance"`
	InPkts      *uint64 `path:"in-pkts" module:"openconfig-network-instance"`
	InterfaceId *string `path:"interface-id" module:"openconfig-network-instance"`
	OutOctets   *uint64 `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts     *uint64 `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes struct {
	MplsAdminGroups *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups `path:"mpls-admin-groups" module:"openconfig-network-instance"`
	Srlgs           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs           `path:"srlgs" module:"openconfig-network-instance"`
	TeLspTimers     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers     `path:"te-lsp-timers" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/mpls-admin-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups struct {
	AdminGroup map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup `path:"admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups) IsYANGGoStruct() {
}

// NewAdminGroup creates a new entry in the AdminGroup list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups) NewAdminGroup(AdminGroupName string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdminGroup == nil {
		t.AdminGroup = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup)
	}

	key := AdminGroupName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdminGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdminGroup", key)
	}

	t.AdminGroup[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup{
		AdminGroupName: &AdminGroupName,
	}

	return t.AdminGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/mpls-admin-groups/admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup struct {
	AdminGroupName *string                                                                                                               `path:"admin-group-name" module:"openconfig-network-instance"`
	Config         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config `path:"config" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AdminGroupName == nil {
		return nil, fmt.Errorf("nil value for key AdminGroupName")
	}

	return map[string]interface{}{
		"admin-group-name": *t.AdminGroupName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/mpls-admin-groups/admin-group/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config struct {
	AdminGroupName *string `path:"admin-group-name" module:"openconfig-network-instance"`
	BitPosition    *uint32 `path:"bit-position" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/mpls-admin-groups/admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State struct {
	AdminGroupName *string `path:"admin-group-name" module:"openconfig-network-instance"`
	BitPosition    *uint32 `path:"bit-position" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_MplsAdminGroups_AdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs struct {
	Srlg map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg `path:"srlg" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs) IsYANGGoStruct() {
}

// NewSrlg creates a new entry in the Srlg list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs) NewSrlg(Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srlg == nil {
		t.Srlg = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Srlg[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Srlg", key)
	}

	t.Srlg[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg{
		Name: &Name,
	}

	return t.Srlg[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg struct {
	Config            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config            `path:"config" module:"openconfig-network-instance"`
	Name              *string                                                                                                          `path:"name" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State             `path:"state" module:"openconfig-network-instance"`
	StaticSrlgMembers *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers `path:"static-srlg-members" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config struct {
	Cost         *uint32                               `path:"cost" module:"openconfig-network-instance"`
	FloodingType E_OpenconfigMpls_MplsSrlgFloodingType `path:"flooding-type" module:"openconfig-network-instance"`
	Name         *string                               `path:"name" module:"openconfig-network-instance"`
	Value        *uint32                               `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State struct {
	Cost         *uint32                               `path:"cost" module:"openconfig-network-instance"`
	FloodingType E_OpenconfigMpls_MplsSrlgFloodingType `path:"flooding-type" module:"openconfig-network-instance"`
	Name         *string                               `path:"name" module:"openconfig-network-instance"`
	Value        *uint32                               `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/static-srlg-members YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers struct {
	MembersList map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList `path:"members-list" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers) IsYANGGoStruct() {
}

// NewMembersList creates a new entry in the MembersList list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers) NewMembersList(FromAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.MembersList == nil {
		t.MembersList = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList)
	}

	key := FromAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.MembersList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list MembersList", key)
	}

	t.MembersList[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList{
		FromAddress: &FromAddress,
	}

	return t.MembersList[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/static-srlg-members/members-list YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config `path:"config" module:"openconfig-network-instance"`
	FromAddress *string                                                                                                                             `path:"from-address" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.FromAddress == nil {
		return nil, fmt.Errorf("nil value for key FromAddress")
	}

	return map[string]interface{}{
		"from-address": *t.FromAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/static-srlg-members/members-list/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config struct {
	FromAddress *string `path:"from-address" module:"openconfig-network-instance"`
	ToAddress   *string `path:"to-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/static-srlg-members/members-list/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State struct {
	FromAddress *string `path:"from-address" module:"openconfig-network-instance"`
	ToAddress   *string `path:"to-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_Srlgs_Srlg_StaticSrlgMembers_MembersList_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/te-lsp-timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/te-lsp-timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config struct {
	CleanupDelay    *uint16 `path:"cleanup-delay" module:"openconfig-network-instance"`
	InstallDelay    *uint16 `path:"install-delay" module:"openconfig-network-instance"`
	ReoptimizeTimer *uint16 `path:"reoptimize-timer" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-global-attributes/te-lsp-timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State struct {
	CleanupDelay    *uint16 `path:"cleanup-delay" module:"openconfig-network-instance"`
	InstallDelay    *uint16 `path:"install-delay" module:"openconfig-network-instance"`
	ReoptimizeTimer *uint16 `path:"reoptimize-timer" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeGlobalAttributes_TeLspTimers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface struct {
	Config               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config               `path:"config" module:"openconfig-network-instance"`
	IgpFloodingBandwidth *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth `path:"igp-flooding-bandwidth" module:"openconfig-network-instance"`
	InterfaceId          *string                                                                                                               `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef         `path:"interface-ref" module:"openconfig-network-instance"`
	State                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State                `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config struct {
	AdminGroup     []string `path:"admin-group" module:"openconfig-network-instance"`
	InterfaceId    *string  `path:"interface-id" module:"openconfig-network-instance"`
	SrlgMembership []string `path:"srlg-membership" module:"openconfig-network-instance"`
	TeMetric       *uint32  `path:"te-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config struct {
	DeltaPercentage        *uint8                                                                                                                                               `path:"delta-percentage" module:"openconfig-network-instance"`
	DownThresholds         []uint8                                                                                                                                              `path:"down-thresholds" module:"openconfig-network-instance"`
	ThresholdSpecification E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification `path:"threshold-specification" module:"openconfig-network-instance"`
	ThresholdType          E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType          `path:"threshold-type" module:"openconfig-network-instance"`
	UpDownThresholds       []uint8                                                                                                                                              `path:"up-down-thresholds" module:"openconfig-network-instance"`
	UpThresholds           []uint8                                                                                                                                              `path:"up-thresholds" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State struct {
	DeltaPercentage        *uint8                                                                                                                                               `path:"delta-percentage" module:"openconfig-network-instance"`
	DownThresholds         []uint8                                                                                                                                              `path:"down-thresholds" module:"openconfig-network-instance"`
	ThresholdSpecification E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification `path:"threshold-specification" module:"openconfig-network-instance"`
	ThresholdType          E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType          `path:"threshold-type" module:"openconfig-network-instance"`
	UpDownThresholds       []uint8                                                                                                                                              `path:"up-down-thresholds" module:"openconfig-network-instance"`
	UpThresholds           []uint8                                                                                                                                              `path:"up-thresholds" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/mpls/te-interface-attributes/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State struct {
	AdminGroup     []string `path:"admin-group" module:"openconfig-network-instance"`
	InterfaceId    *string  `path:"interface-id" module:"openconfig-network-instance"`
	SrlgMembership []string `path:"srlg-membership" module:"openconfig-network-instance"`
	TeMetric       *uint32  `path:"te-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding struct {
	Interfaces          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces          `path:"interfaces" module:"openconfig-network-instance"`
	PathSelectionGroups *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups `path:"path-selection-groups" module:"openconfig-network-instance"`
	Policies            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies            `path:"policies" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config       `path:"config" module:"openconfig-network-instance"`
	InterfaceId  *string                                                                                                        `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config struct {
	ApplyForwardingPolicy *string `path:"apply-forwarding-policy" module:"openconfig-network-instance"`
	InterfaceId           *string `path:"interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State struct {
	ApplyForwardingPolicy *string `path:"apply-forwarding-policy" module:"openconfig-network-instance"`
	InterfaceId           *string `path:"interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/path-selection-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups struct {
	PathSelectionGroup map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup `path:"path-selection-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups) IsYANGGoStruct() {
}

// NewPathSelectionGroup creates a new entry in the PathSelectionGroup list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups) NewPathSelectionGroup(GroupId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PathSelectionGroup == nil {
		t.PathSelectionGroup = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup)
	}

	key := GroupId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PathSelectionGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PathSelectionGroup", key)
	}

	t.PathSelectionGroup[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup{
		GroupId: &GroupId,
	}

	return t.PathSelectionGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/path-selection-groups/path-selection-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config `path:"config" module:"openconfig-network-instance"`
	GroupId *string                                                                                                                    `path:"group-id" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.GroupId == nil {
		return nil, fmt.Errorf("nil value for key GroupId")
	}

	return map[string]interface{}{
		"group-id": *t.GroupId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/path-selection-groups/path-selection-group/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config struct {
	GroupId *string  `path:"group-id" module:"openconfig-network-instance"`
	MplsLsp []string `path:"mpls-lsp" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/path-selection-groups/path-selection-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State struct {
	GroupId *string  `path:"group-id" module:"openconfig-network-instance"`
	MplsLsp []string `path:"mpls-lsp" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_PathSelectionGroups_PathSelectionGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies struct {
	Policy map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy `path:"policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies) IsYANGGoStruct() {
}

// NewPolicy creates a new entry in the Policy list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies) NewPolicy(PolicyId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Policy == nil {
		t.Policy = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy)
	}

	key := PolicyId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Policy[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Policy", key)
	}

	t.Policy[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy{
		PolicyId: &PolicyId,
	}

	return t.Policy[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config `path:"config" module:"openconfig-network-instance"`
	PolicyId *string                                                                                             `path:"policy-id" module:"openconfig-network-instance"`
	Rules    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules  `path:"rules" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PolicyId == nil {
		return nil, fmt.Errorf("nil value for key PolicyId")
	}

	return map[string]interface{}{
		"policy-id": *t.PolicyId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config struct {
	PolicyId *string `path:"policy-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules struct {
	Rule map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule `path:"rule" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules) IsYANGGoStruct() {
}

// NewRule creates a new entry in the Rule list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules) NewRule(SequenceId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Rule == nil {
		t.Rule = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule)
	}

	key := SequenceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Rule[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Rule", key)
	}

	t.Rule[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule{
		SequenceId: &SequenceId,
	}

	return t.Rule[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule struct {
	Action     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action    `path:"action" module:"openconfig-network-instance"`
	Config     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config    `path:"config" module:"openconfig-network-instance"`
	Ipv4       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4      `path:"ipv4" module:"openconfig-network-instance"`
	Ipv6       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6      `path:"ipv6" module:"openconfig-network-instance"`
	L2         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2        `path:"l2" module:"openconfig-network-instance"`
	SequenceId *uint32                                                                                                           `path:"sequence-id" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State     `path:"state" module:"openconfig-network-instance"`
	Transport  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport `path:"transport" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SequenceId == nil {
		return nil, fmt.Errorf("nil value for key SequenceId")
	}

	return map[string]interface{}{
		"sequence-id": *t.SequenceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action struct {
	Config         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config         `path:"config" module:"openconfig-network-instance"`
	EncapsulateGre *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre `path:"encapsulate-gre" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State          `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config struct {
	DecapsulateGre     *bool   `path:"decapsulate-gre" module:"openconfig-network-instance"`
	Discard            *bool   `path:"discard" module:"openconfig-network-instance"`
	NetworkInstance    *string `path:"network-instance" module:"openconfig-network-instance"`
	NextHop            *string `path:"next-hop" module:"openconfig-network-instance"`
	PathSelectionGroup *string `path:"path-selection-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config  `path:"config" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State   `path:"state" module:"openconfig-network-instance"`
	Targets *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets `path:"targets" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config struct {
	IdentifyingPrefix *string `path:"identifying-prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State struct {
	IdentifyingPrefix *string `path:"identifying-prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/targets YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets struct {
	Target map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target `path:"target" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets) IsYANGGoStruct() {
}

// NewTarget creates a new entry in the Target list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets) NewTarget(Id string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Target == nil {
		t.Target = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Target[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Target", key)
	}

	t.Target[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target{
		Id: &Id,
	}

	return t.Target[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/targets/target YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config `path:"config" module:"openconfig-network-instance"`
	Id     *string                                                                                                                                             `path:"id" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/targets/target/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config struct {
	Destination *string `path:"destination" module:"openconfig-network-instance"`
	Id          *string `path:"id" module:"openconfig-network-instance"`
	IpTtl       *uint8  `path:"ip-ttl" module:"openconfig-network-instance"`
	Source      *string `path:"source" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/encapsulate-gre/targets/target/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State struct {
	Destination *string `path:"destination" module:"openconfig-network-instance"`
	Id          *string `path:"id" module:"openconfig-network-instance"`
	IpTtl       *uint8  `path:"ip-ttl" module:"openconfig-network-instance"`
	Source      *string `path:"source" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_EncapsulateGre_Targets_Target_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/action/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State struct {
	DecapsulateGre     *bool   `path:"decapsulate-gre" module:"openconfig-network-instance"`
	Discard            *bool   `path:"discard" module:"openconfig-network-instance"`
	NetworkInstance    *string `path:"network-instance" module:"openconfig-network-instance"`
	NextHop            *string `path:"next-hop" module:"openconfig-network-instance"`
	PathSelectionGroup *string `path:"path-selection-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Action_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config struct {
	SequenceId *uint32 `path:"sequence-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4 represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4 struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config struct {
	DestinationAddress *string                                                                                                                           `path:"destination-address" module:"openconfig-network-instance"`
	Dscp               *uint8                                                                                                                            `path:"dscp" module:"openconfig-network-instance"`
	HopLimit           *uint8                                                                                                                            `path:"hop-limit" module:"openconfig-network-instance"`
	Protocol           OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union `path:"protocol" module:"openconfig-network-instance"`
	SourceAddress      *string                                                                                                                           `path:"source-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/config/protocol within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/config/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_Uint8 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/config/protocol
// is to be set to a uint8 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_Uint8
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_Uint8) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_Config_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State struct {
	DestinationAddress *string                                                                                                                          `path:"destination-address" module:"openconfig-network-instance"`
	Dscp               *uint8                                                                                                                           `path:"dscp" module:"openconfig-network-instance"`
	HopLimit           *uint8                                                                                                                           `path:"hop-limit" module:"openconfig-network-instance"`
	Protocol           OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union `path:"protocol" module:"openconfig-network-instance"`
	SourceAddress      *string                                                                                                                          `path:"source-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state/protocol within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_Uint8 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state/protocol
// is to be set to a uint8 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_Uint8
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_Uint8) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv4_State_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6 represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6 struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config struct {
	DestinationAddress   *string                                                                                                                           `path:"destination-address" module:"openconfig-network-instance"`
	DestinationFlowLabel *uint32                                                                                                                           `path:"destination-flow-label" module:"openconfig-network-instance"`
	Dscp                 *uint8                                                                                                                            `path:"dscp" module:"openconfig-network-instance"`
	HopLimit             *uint8                                                                                                                            `path:"hop-limit" module:"openconfig-network-instance"`
	Protocol             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union `path:"protocol" module:"openconfig-network-instance"`
	SourceAddress        *string                                                                                                                           `path:"source-address" module:"openconfig-network-instance"`
	SourceFlowLabel      *uint32                                                                                                                           `path:"source-flow-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/config/protocol within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/config/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_Uint8 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/config/protocol
// is to be set to a uint8 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_Uint8
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_Uint8) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_Config_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State struct {
	DestinationAddress   *string                                                                                                                          `path:"destination-address" module:"openconfig-network-instance"`
	DestinationFlowLabel *uint32                                                                                                                          `path:"destination-flow-label" module:"openconfig-network-instance"`
	Dscp                 *uint8                                                                                                                           `path:"dscp" module:"openconfig-network-instance"`
	HopLimit             *uint8                                                                                                                           `path:"hop-limit" module:"openconfig-network-instance"`
	Protocol             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union `path:"protocol" module:"openconfig-network-instance"`
	SourceAddress        *string                                                                                                                          `path:"source-address" module:"openconfig-network-instance"`
	SourceFlowLabel      *uint32                                                                                                                          `path:"source-flow-label" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state/protocol within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state/protocol
// is to be set to a E_OpenconfigPacketMatchTypes_IP_PROTOCOL value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL struct {
	E_OpenconfigPacketMatchTypes_IP_PROTOCOL E_OpenconfigPacketMatchTypes_IP_PROTOCOL
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_Uint8 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state/protocol
// is to be set to a uint8 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_Uint8 struct {
	Uint8 uint8
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_Uint8
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_Uint8) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_IP_PROTOCOL:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_E_OpenconfigPacketMatchTypes_IP_PROTOCOL{v}, nil
	case uint8:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union_Uint8{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Ipv6_State_Protocol_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_IP_PROTOCOL, uint8]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2 represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2 struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config struct {
	DestinationMac     *string                                                                                                                          `path:"destination-mac" module:"openconfig-network-instance"`
	DestinationMacMask *string                                                                                                                          `path:"destination-mac-mask" module:"openconfig-network-instance"`
	Ethertype          OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union `path:"ethertype" module:"openconfig-network-instance"`
	SourceMac          *string                                                                                                                          `path:"source-mac" module:"openconfig-network-instance"`
	SourceMacMask      *string                                                                                                                          `path:"source-mac-mask" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/config/ethertype within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/config/ethertype
// is to be set to a E_OpenconfigPacketMatchTypes_ETHERTYPE value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE struct {
	E_OpenconfigPacketMatchTypes_ETHERTYPE E_OpenconfigPacketMatchTypes_ETHERTYPE
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_Uint16 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/config/ethertype
// is to be set to a uint16 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_Uint16
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_Uint16) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_ETHERTYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE{v}, nil
	case uint16:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_Config_Ethertype_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_ETHERTYPE, uint16]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State struct {
	DestinationMac     *string                                                                                                                         `path:"destination-mac" module:"openconfig-network-instance"`
	DestinationMacMask *string                                                                                                                         `path:"destination-mac-mask" module:"openconfig-network-instance"`
	Ethertype          OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union `path:"ethertype" module:"openconfig-network-instance"`
	SourceMac          *string                                                                                                                         `path:"source-mac" module:"openconfig-network-instance"`
	SourceMacMask      *string                                                                                                                         `path:"source-mac-mask" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state/ethertype within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state/ethertype
// is to be set to a E_OpenconfigPacketMatchTypes_ETHERTYPE value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE struct {
	E_OpenconfigPacketMatchTypes_ETHERTYPE E_OpenconfigPacketMatchTypes_ETHERTYPE
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_Uint16 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state/ethertype
// is to be set to a uint16 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_Uint16
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_Uint16) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPacketMatchTypes_ETHERTYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_E_OpenconfigPacketMatchTypes_ETHERTYPE{v}, nil
	case uint16:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_L2_State_Ethertype_Union, unknown union type, got: %T, want any of [E_OpenconfigPacketMatchTypes_ETHERTYPE, uint16]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State struct {
	MatchedOctets *uint64 `path:"matched-octets" module:"openconfig-network-instance"`
	MatchedPkts   *uint64 `path:"matched-pkts" module:"openconfig-network-instance"`
	SequenceId    *uint32 `path:"sequence-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config struct {
	DestinationPort OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union `path:"destination-port" module:"openconfig-network-instance"`
	SourcePort      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union      `path:"source-port" module:"openconfig-network-instance"`
	TcpFlags        []E_OpenconfigPacketMatchTypes_TCP_FLAGS                                                                                                      `path:"tcp-flags" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/destination-port within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/destination-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_String is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/destination-port
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_Uint16 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/destination-port
// is to be set to a uint16 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_Uint16
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_Uint16) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_String{v}, nil
	case uint16:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_DestinationPort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort, string, uint16]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/source-port within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/source-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_String is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/source-port
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_Uint16 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/source-port
// is to be set to a uint16 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_Uint16
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_Uint16) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_String{v}, nil
	case uint16:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_Config_SourcePort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort, string, uint16]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State struct {
	DestinationPort OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union `path:"destination-port" module:"openconfig-network-instance"`
	SourcePort      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union      `path:"source-port" module:"openconfig-network-instance"`
	TcpFlags        []E_OpenconfigPacketMatchTypes_TCP_FLAGS                                                                                                     `path:"tcp-flags" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_String is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_Uint16 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port
// is to be set to a uint16 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_Uint16
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_Uint16) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_String{v}, nil
	case uint16:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_DestinationPort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort, string, uint16]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port
// is to be set to a E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort struct {
	E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_String is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_Uint16 is used when /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port
// is to be set to a uint16 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_Uint16 struct {
	Uint16 uint16
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_Uint16
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_Uint16) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_String{v}, nil
	case uint16:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union_Uint16{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_Rules_Rule_Transport_State_SourcePort_Union, unknown union type, got: %T, want any of [E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort, string, uint16]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State represents the /openconfig-network-instance/network-instances/network-instance/policy-forwarding/policies/policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State struct {
	PolicyId *string `path:"policy-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_PolicyForwarding_Policies_Policy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols represents the /openconfig-network-instance/network-instances/network-instance/protocols YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols struct {
	Protocol map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol `path:"protocol" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols) IsYANGGoStruct() {}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Key represents the key for list Protocol of element /openconfig-network-instance/network-instances/network-instance/protocols.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Key struct {
	Identifier E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"identifier"`
	Name       string                                        `path:"name"`
}

// NewProtocol creates a new entry in the Protocol list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols) NewProtocol(Identifier E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, Name string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Protocol == nil {
		t.Protocol = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Key{
		Identifier: Identifier,
		Name:       Name,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Protocol[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Protocol", key)
	}

	t.Protocol[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol{
		Identifier: Identifier,
		Name:       &Name,
	}

	return t.Protocol[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol struct {
	Bgp             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp             `path:"bgp" module:"openconfig-network-instance"`
	Config          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config          `path:"config" module:"openconfig-network-instance"`
	Identifier      E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                                  `path:"identifier" module:"openconfig-network-instance"`
	Igmp            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp            `path:"igmp" module:"openconfig-network-instance"`
	Isis            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis            `path:"isis" module:"openconfig-network-instance"`
	LocalAggregates *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates `path:"local-aggregates" module:"openconfig-network-instance"`
	Name            *string                                                                                        `path:"name" module:"openconfig-network-instance"`
	Ospfv2          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2          `path:"ospfv2" module:"openconfig-network-instance"`
	Pim             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim             `path:"pim" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State           `path:"state" module:"openconfig-network-instance"`
	StaticRoutes    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes    `path:"static-routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol) ΛListKeyMap() (map[string]interface{}, error) {

	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"identifier": t.Identifier,
		"name":       *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp struct {
	Global     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global     `path:"global" module:"openconfig-network-instance"`
	Neighbors  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors  `path:"neighbors" module:"openconfig-network-instance"`
	PeerGroups *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups `path:"peer-groups" module:"openconfig-network-instance"`
	Rib        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib        `path:"rib" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global struct {
	AfiSafis                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis                `path:"afi-safis" module:"openconfig-network-instance"`
	Confederation           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation           `path:"confederation" module:"openconfig-network-instance"`
	Config                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config                  `path:"config" module:"openconfig-network-instance"`
	DefaultRouteDistance    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance    `path:"default-route-distance" module:"openconfig-network-instance"`
	DynamicNeighborPrefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes `path:"dynamic-neighbor-prefixes" module:"openconfig-network-instance"`
	GracefulRestart         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart         `path:"graceful-restart" module:"openconfig-network-instance"`
	RouteSelectionOptions   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions   `path:"route-selection-options" module:"openconfig-network-instance"`
	State                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State                   `path:"state" module:"openconfig-network-instance"`
	UseMultiplePaths        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths        `path:"use-multiple-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis) IsYANGGoStruct() {
}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi struct {
	AddPaths              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths              `path:"add-paths" module:"openconfig-network-instance"`
	AfiSafiName           E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                                                                               `path:"afi-safi-name" module:"openconfig-network-instance"`
	Config                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config                `path:"config" module:"openconfig-network-instance"`
	GracefulRestart       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart       `path:"graceful-restart" module:"openconfig-network-instance"`
	Ipv4LabeledUnicast    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast    `path:"ipv4-labeled-unicast" module:"openconfig-network-instance"`
	Ipv4Unicast           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast           `path:"ipv4-unicast" module:"openconfig-network-instance"`
	Ipv6LabeledUnicast    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast    `path:"ipv6-labeled-unicast" module:"openconfig-network-instance"`
	Ipv6Unicast           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast           `path:"ipv6-unicast" module:"openconfig-network-instance"`
	L2VpnEvpn             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn             `path:"l2vpn-evpn" module:"openconfig-network-instance"`
	L2VpnVpls             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls             `path:"l2vpn-vpls" module:"openconfig-network-instance"`
	L3VpnIpv4Multicast    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast    `path:"l3vpn-ipv4-multicast" module:"openconfig-network-instance"`
	L3VpnIpv4Unicast      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast      `path:"l3vpn-ipv4-unicast" module:"openconfig-network-instance"`
	L3VpnIpv6Multicast    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast    `path:"l3vpn-ipv6-multicast" module:"openconfig-network-instance"`
	L3VpnIpv6Unicast      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast      `path:"l3vpn-ipv6-unicast" module:"openconfig-network-instance"`
	RouteSelectionOptions *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions `path:"route-selection-options" module:"openconfig-network-instance"`
	SrtePolicyIpv4        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4        `path:"srte-policy-ipv4" module:"openconfig-network-instance"`
	SrtePolicyIpv6        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6        `path:"srte-policy-ipv6" module:"openconfig-network-instance"`
	State                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State                 `path:"state" module:"openconfig-network-instance"`
	UseMultiplePaths      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths      `path:"use-multiple-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/add-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/add-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-network-instance"`
	Receive              *bool   `path:"receive" module:"openconfig-network-instance"`
	Send                 *bool   `path:"send" module:"openconfig-network-instance"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/add-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-network-instance"`
	Receive              *bool   `path:"receive" module:"openconfig-network-instance"`
	Send                 *bool   `path:"send" module:"openconfig-network-instance"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_AddPaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-network-instance"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config      `path:"config" module:"openconfig-network-instance"`
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv4-unicast/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv4Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config      `path:"config" module:"openconfig-network-instance"`
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/ipv6-unicast/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_Ipv6Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/route-selection-options YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/route-selection-options/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-network-instance"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-network-instance"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-network-instance"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-network-instance"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-network-instance"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/route-selection-options/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-network-instance"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-network-instance"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-network-instance"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-network-instance"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-network-instance"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_RouteSelectionOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4 struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6 struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State struct {
	AfiSafiName   E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-network-instance"`
	Enabled       *bool                              `path:"enabled" module:"openconfig-network-instance"`
	TotalPaths    *uint32                            `path:"total-paths" module:"openconfig-network-instance"`
	TotalPrefixes *uint32                            `path:"total-prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config `path:"config" module:"openconfig-network-instance"`
	Ebgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-network-instance"`
	Ibgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/use-multiple-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_AfiSafis_AfiSafi_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/confederation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/confederation/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config struct {
	Identifier *uint32  `path:"identifier" module:"openconfig-network-instance"`
	MemberAs   []uint32 `path:"member-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/confederation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State struct {
	Identifier *uint32  `path:"identifier" module:"openconfig-network-instance"`
	MemberAs   []uint32 `path:"member-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Confederation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config struct {
	As       *uint32 `path:"as" module:"openconfig-network-instance"`
	RouterId *string `path:"router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/default-route-distance YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/default-route-distance/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config struct {
	ExternalRouteDistance *uint8 `path:"external-route-distance" module:"openconfig-network-instance"`
	InternalRouteDistance *uint8 `path:"internal-route-distance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/default-route-distance/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State struct {
	ExternalRouteDistance *uint8 `path:"external-route-distance" module:"openconfig-network-instance"`
	InternalRouteDistance *uint8 `path:"internal-route-distance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DefaultRouteDistance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/dynamic-neighbor-prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes struct {
	DynamicNeighborPrefix map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix `path:"dynamic-neighbor-prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes) IsYANGGoStruct() {
}

// NewDynamicNeighborPrefix creates a new entry in the DynamicNeighborPrefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes) NewDynamicNeighborPrefix(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DynamicNeighborPrefix == nil {
		t.DynamicNeighborPrefix = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DynamicNeighborPrefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DynamicNeighborPrefix", key)
	}

	t.DynamicNeighborPrefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix{
		Prefix: &Prefix,
	}

	return t.DynamicNeighborPrefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config `path:"config" module:"openconfig-network-instance"`
	Prefix *string                                                                                                                                        `path:"prefix" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config struct {
	PeerGroup *string `path:"peer-group" module:"openconfig-network-instance"`
	Prefix    *string `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/dynamic-neighbor-prefixes/dynamic-neighbor-prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State struct {
	PeerGroup *string `path:"peer-group" module:"openconfig-network-instance"`
	Prefix    *string `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_DynamicNeighborPrefixes_DynamicNeighborPrefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-network-instance"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-network-instance"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-network-instance"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-network-instance"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/route-selection-options YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/route-selection-options/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-network-instance"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-network-instance"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-network-instance"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-network-instance"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-network-instance"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/route-selection-options/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State struct {
	AdvertiseInactiveRoutes *bool `path:"advertise-inactive-routes" module:"openconfig-network-instance"`
	AlwaysCompareMed        *bool `path:"always-compare-med" module:"openconfig-network-instance"`
	EnableAigp              *bool `path:"enable-aigp" module:"openconfig-network-instance"`
	ExternalCompareRouterId *bool `path:"external-compare-router-id" module:"openconfig-network-instance"`
	IgnoreAsPathLength      *bool `path:"ignore-as-path-length" module:"openconfig-network-instance"`
	IgnoreNextHopIgpMetric  *bool `path:"ignore-next-hop-igp-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_RouteSelectionOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State struct {
	As            *uint32 `path:"as" module:"openconfig-network-instance"`
	RouterId      *string `path:"router-id" module:"openconfig-network-instance"`
	TotalPaths    *uint32 `path:"total-paths" module:"openconfig-network-instance"`
	TotalPrefixes *uint32 `path:"total-prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config `path:"config" module:"openconfig-network-instance"`
	Ebgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-network-instance"`
	Ibgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ebgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ibgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/global/use-multiple-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Global_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor struct {
	AfiSafis         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis         `path:"afi-safis" module:"openconfig-network-instance"`
	ApplyPolicy      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy      `path:"apply-policy" module:"openconfig-network-instance"`
	AsPathOptions    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions    `path:"as-path-options" module:"openconfig-network-instance"`
	Config           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config           `path:"config" module:"openconfig-network-instance"`
	EbgpMultihop     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop     `path:"ebgp-multihop" module:"openconfig-network-instance"`
	EnableBfd        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd        `path:"enable-bfd" module:"openconfig-network-instance"`
	ErrorHandling    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling    `path:"error-handling" module:"openconfig-network-instance"`
	GracefulRestart  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart  `path:"graceful-restart" module:"openconfig-network-instance"`
	LoggingOptions   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions   `path:"logging-options" module:"openconfig-network-instance"`
	NeighborAddress  *string                                                                                                                `path:"neighbor-address" module:"openconfig-network-instance"`
	RouteReflector   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector   `path:"route-reflector" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State            `path:"state" module:"openconfig-network-instance"`
	Timers           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers           `path:"timers" module:"openconfig-network-instance"`
	Transport        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport        `path:"transport" module:"openconfig-network-instance"`
	UseMultiplePaths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths `path:"use-multiple-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis) IsYANGGoStruct() {
}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi struct {
	AddPaths           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-network-instance"`
	AfiSafiName        E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                                                                                        `path:"afi-safi-name" module:"openconfig-network-instance"`
	ApplyPolicy        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-network-instance"`
	Config             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config             `path:"config" module:"openconfig-network-instance"`
	GracefulRestart    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-network-instance"`
	Ipv4LabeledUnicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-network-instance"`
	Ipv4Unicast        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-network-instance"`
	Ipv6LabeledUnicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-network-instance"`
	Ipv6Unicast        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-network-instance"`
	L2VpnEvpn          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-network-instance"`
	L2VpnVpls          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-network-instance"`
	L3VpnIpv4Multicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-network-instance"`
	L3VpnIpv4Unicast   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-network-instance"`
	L3VpnIpv6Multicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-network-instance"`
	L3VpnIpv6Unicast   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-network-instance"`
	SrtePolicyIpv4     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-network-instance"`
	SrtePolicyIpv6     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State              `path:"state" module:"openconfig-network-instance"`
	UseMultiplePaths   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-network-instance"`
	Receive              *bool   `path:"receive" module:"openconfig-network-instance"`
	Send                 *bool   `path:"send" module:"openconfig-network-instance"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/add-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-network-instance"`
	Receive              *bool   `path:"receive" module:"openconfig-network-instance"`
	Send                 *bool   `path:"send" module:"openconfig-network-instance"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_AddPaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-network-instance"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State struct {
	Advertised *bool `path:"advertised" module:"openconfig-network-instance"`
	Enabled    *bool `path:"enabled" module:"openconfig-network-instance"`
	Received   *bool `path:"received" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config      `path:"config" module:"openconfig-network-instance"`
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv4-unicast/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv4Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config      `path:"config" module:"openconfig-network-instance"`
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/ipv6-unicast/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_Ipv6Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4 struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6 struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State struct {
	Active      *bool                                                                                                                                 `path:"active" module:"openconfig-network-instance"`
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                                                                                    `path:"afi-safi-name" module:"openconfig-network-instance"`
	Enabled     *bool                                                                                                                                 `path:"enabled" module:"openconfig-network-instance"`
	Prefixes    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/state/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes struct {
	Installed         *uint32 `path:"installed" module:"openconfig-network-instance"`
	Received          *uint32 `path:"received" module:"openconfig-network-instance"`
	ReceivedPrePolicy *uint32 `path:"received-pre-policy" module:"openconfig-network-instance"`
	Sent              *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_State_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config `path:"config" module:"openconfig-network-instance"`
	Ebgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/use-multiple-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AfiSafis_AfiSafi_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/as-path-options YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/as-path-options/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-network-instance"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-network-instance"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/as-path-options/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-network-instance"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-network-instance"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_AsPathOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config struct {
	AuthPassword     *string                               `path:"auth-password" module:"openconfig-network-instance"`
	Description      *string                               `path:"description" module:"openconfig-network-instance"`
	Enabled          *bool                                 `path:"enabled" module:"openconfig-network-instance"`
	LocalAs          *uint32                               `path:"local-as" module:"openconfig-network-instance"`
	NeighborAddress  *string                               `path:"neighbor-address" module:"openconfig-network-instance"`
	PeerAs           *uint32                               `path:"peer-as" module:"openconfig-network-instance"`
	PeerGroup        *string                               `path:"peer-group" module:"openconfig-network-instance"`
	PeerType         E_OpenconfigBgp_PeerType              `path:"peer-type" module:"openconfig-network-instance"`
	RemovePrivateAs  E_OpenconfigBgp_RemovePrivateAsOption `path:"remove-private-as" module:"openconfig-network-instance"`
	RouteFlapDamping *bool                                 `path:"route-flap-damping" module:"openconfig-network-instance"`
	SendCommunity    E_OpenconfigBgp_CommunityType         `path:"send-community" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/ebgp-multihop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/ebgp-multihop/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-network-instance"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/ebgp-multihop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-network-instance"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EbgpMultihop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/enable-bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/enable-bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/enable-bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/error-handling YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/error-handling/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config struct {
	TreatAsWithdraw *bool `path:"treat-as-withdraw" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/error-handling/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State struct {
	ErroneousUpdateMessages *uint32 `path:"erroneous-update-messages" module:"openconfig-network-instance"`
	TreatAsWithdraw         *bool   `path:"treat-as-withdraw" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_ErrorHandling_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-network-instance"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-network-instance"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State struct {
	Enabled         *bool                                                             `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly      *bool                                                             `path:"helper-only" module:"openconfig-network-instance"`
	LocalRestarting *bool                                                             `path:"local-restarting" module:"openconfig-network-instance"`
	Mode            E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode `path:"mode" module:"openconfig-network-instance"`
	PeerRestartTime *uint16                                                           `path:"peer-restart-time" module:"openconfig-network-instance"`
	PeerRestarting  *bool                                                             `path:"peer-restarting" module:"openconfig-network-instance"`
	RestartTime     *uint16                                                           `path:"restart-time" module:"openconfig-network-instance"`
	StaleRoutesTime *float64                                                          `path:"stale-routes-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/logging-options YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/logging-options/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/logging-options/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_LoggingOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config struct {
	RouteReflectorClient    *bool                                                                                                                                                    `path:"route-reflector-client" module:"openconfig-network-instance"`
	RouteReflectorClusterId OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/config/route-reflector-cluster-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/config/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/config/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_Config_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State struct {
	RouteReflectorClient    *bool                                                                                                                                                   `path:"route-reflector-client" module:"openconfig-network-instance"`
	RouteReflectorClusterId OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/route-reflector/state/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_RouteReflector_State_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State struct {
	AuthPassword           *string                                                                                                              `path:"auth-password" module:"openconfig-network-instance"`
	Description            *string                                                                                                              `path:"description" module:"openconfig-network-instance"`
	DynamicallyConfigured  *bool                                                                                                                `path:"dynamically-configured" module:"openconfig-network-instance"`
	Enabled                *bool                                                                                                                `path:"enabled" module:"openconfig-network-instance"`
	EstablishedTransitions *uint64                                                                                                              `path:"established-transitions" module:"openconfig-network-instance"`
	LastEstablished        *uint64                                                                                                              `path:"last-established" module:"openconfig-network-instance"`
	LocalAs                *uint32                                                                                                              `path:"local-as" module:"openconfig-network-instance"`
	Messages               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages `path:"messages" module:"openconfig-network-instance"`
	NeighborAddress        *string                                                                                                              `path:"neighbor-address" module:"openconfig-network-instance"`
	PeerAs                 *uint32                                                                                                              `path:"peer-as" module:"openconfig-network-instance"`
	PeerGroup              *string                                                                                                              `path:"peer-group" module:"openconfig-network-instance"`
	PeerType               E_OpenconfigBgp_PeerType                                                                                             `path:"peer-type" module:"openconfig-network-instance"`
	Queues                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues   `path:"queues" module:"openconfig-network-instance"`
	RemovePrivateAs        E_OpenconfigBgp_RemovePrivateAsOption                                                                                `path:"remove-private-as" module:"openconfig-network-instance"`
	RouteFlapDamping       *bool                                                                                                                `path:"route-flap-damping" module:"openconfig-network-instance"`
	SendCommunity          E_OpenconfigBgp_CommunityType                                                                                        `path:"send-community" module:"openconfig-network-instance"`
	SessionState           E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState                                                            `path:"session-state" module:"openconfig-network-instance"`
	SupportedCapabilities  []E_OpenconfigBgpTypes_BGP_CAPABILITY                                                                                `path:"supported-capabilities" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages struct {
	Received *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received `path:"received" module:"openconfig-network-instance"`
	Sent     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent     `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/received YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received struct {
	NOTIFICATION                 *uint64                                `path:"NOTIFICATION" module:"openconfig-network-instance"`
	UPDATE                       *uint64                                `path:"UPDATE" module:"openconfig-network-instance"`
	LastNotificationErrorCode    E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-network-instance"`
	LastNotificationErrorSubcode E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-network-instance"`
	LastNotificationTime         *uint64                                `path:"last-notification-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Received) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/sent YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent struct {
	NOTIFICATION                 *uint64                                `path:"NOTIFICATION" module:"openconfig-network-instance"`
	UPDATE                       *uint64                                `path:"UPDATE" module:"openconfig-network-instance"`
	LastNotificationErrorCode    E_OpenconfigBgpTypes_BGP_ERROR_CODE    `path:"last-notification-error-code" module:"openconfig-network-instance"`
	LastNotificationErrorSubcode E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE `path:"last-notification-error-subcode" module:"openconfig-network-instance"`
	LastNotificationTime         *uint64                                `path:"last-notification-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Messages_Sent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/queues YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues struct {
	Input  *uint32 `path:"input" module:"openconfig-network-instance"`
	Output *uint32 `path:"output" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_State_Queues) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-network-instance"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-network-instance"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-network-instance"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-network-instance"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-network-instance"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-network-instance"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-network-instance"`
	NegotiatedHoldTime           *float64 `path:"negotiated-hold-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/transport YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/transport/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config struct {
	LocalAddress *string `path:"local-address" module:"openconfig-network-instance"`
	MtuDiscovery *bool   `path:"mtu-discovery" module:"openconfig-network-instance"`
	PassiveMode  *bool   `path:"passive-mode" module:"openconfig-network-instance"`
	TcpMss       *uint16 `path:"tcp-mss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/transport/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State struct {
	LocalAddress  *string `path:"local-address" module:"openconfig-network-instance"`
	LocalPort     *uint16 `path:"local-port" module:"openconfig-network-instance"`
	MtuDiscovery  *bool   `path:"mtu-discovery" module:"openconfig-network-instance"`
	PassiveMode   *bool   `path:"passive-mode" module:"openconfig-network-instance"`
	RemoteAddress *string `path:"remote-address" module:"openconfig-network-instance"`
	RemotePort    *uint16 `path:"remote-port" module:"openconfig-network-instance"`
	TcpMss        *uint16 `path:"tcp-mss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config `path:"config" module:"openconfig-network-instance"`
	Ebgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths/ebgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool `path:"allow-multiple-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/use-multiple-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Neighbors_Neighbor_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups struct {
	PeerGroup map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup `path:"peer-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups) IsYANGGoStruct() {
}

// NewPeerGroup creates a new entry in the PeerGroup list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups) NewPeerGroup(PeerGroupName string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PeerGroup == nil {
		t.PeerGroup = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup)
	}

	key := PeerGroupName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PeerGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PeerGroup", key)
	}

	t.PeerGroup[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup{
		PeerGroupName: &PeerGroupName,
	}

	return t.PeerGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup struct {
	AfiSafis         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis         `path:"afi-safis" module:"openconfig-network-instance"`
	ApplyPolicy      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy      `path:"apply-policy" module:"openconfig-network-instance"`
	AsPathOptions    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions    `path:"as-path-options" module:"openconfig-network-instance"`
	Config           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config           `path:"config" module:"openconfig-network-instance"`
	EbgpMultihop     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop     `path:"ebgp-multihop" module:"openconfig-network-instance"`
	EnableBfd        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd        `path:"enable-bfd" module:"openconfig-network-instance"`
	ErrorHandling    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling    `path:"error-handling" module:"openconfig-network-instance"`
	GracefulRestart  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart  `path:"graceful-restart" module:"openconfig-network-instance"`
	LoggingOptions   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions   `path:"logging-options" module:"openconfig-network-instance"`
	PeerGroupName    *string                                                                                                                  `path:"peer-group-name" module:"openconfig-network-instance"`
	RouteReflector   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector   `path:"route-reflector" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State            `path:"state" module:"openconfig-network-instance"`
	Timers           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers           `path:"timers" module:"openconfig-network-instance"`
	Transport        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport        `path:"transport" module:"openconfig-network-instance"`
	UseMultiplePaths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths `path:"use-multiple-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PeerGroupName == nil {
		return nil, fmt.Errorf("nil value for key PeerGroupName")
	}

	return map[string]interface{}{
		"peer-group-name": *t.PeerGroupName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis) IsYANGGoStruct() {
}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi struct {
	AddPaths           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths           `path:"add-paths" module:"openconfig-network-instance"`
	AfiSafiName        E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                                                                                          `path:"afi-safi-name" module:"openconfig-network-instance"`
	ApplyPolicy        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy        `path:"apply-policy" module:"openconfig-network-instance"`
	Config             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config             `path:"config" module:"openconfig-network-instance"`
	GracefulRestart    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart    `path:"graceful-restart" module:"openconfig-network-instance"`
	Ipv4LabeledUnicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast `path:"ipv4-labeled-unicast" module:"openconfig-network-instance"`
	Ipv4Unicast        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast        `path:"ipv4-unicast" module:"openconfig-network-instance"`
	Ipv6LabeledUnicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast `path:"ipv6-labeled-unicast" module:"openconfig-network-instance"`
	Ipv6Unicast        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast        `path:"ipv6-unicast" module:"openconfig-network-instance"`
	L2VpnEvpn          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn          `path:"l2vpn-evpn" module:"openconfig-network-instance"`
	L2VpnVpls          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls          `path:"l2vpn-vpls" module:"openconfig-network-instance"`
	L3VpnIpv4Multicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast `path:"l3vpn-ipv4-multicast" module:"openconfig-network-instance"`
	L3VpnIpv4Unicast   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast   `path:"l3vpn-ipv4-unicast" module:"openconfig-network-instance"`
	L3VpnIpv6Multicast *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast `path:"l3vpn-ipv6-multicast" module:"openconfig-network-instance"`
	L3VpnIpv6Unicast   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast   `path:"l3vpn-ipv6-unicast" module:"openconfig-network-instance"`
	SrtePolicyIpv4     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4     `path:"srte-policy-ipv4" module:"openconfig-network-instance"`
	SrtePolicyIpv6     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6     `path:"srte-policy-ipv6" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State              `path:"state" module:"openconfig-network-instance"`
	UseMultiplePaths   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths   `path:"use-multiple-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-network-instance"`
	Receive              *bool   `path:"receive" module:"openconfig-network-instance"`
	Send                 *bool   `path:"send" module:"openconfig-network-instance"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/add-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State struct {
	EligiblePrefixPolicy *string `path:"eligible-prefix-policy" module:"openconfig-network-instance"`
	Receive              *bool   `path:"receive" module:"openconfig-network-instance"`
	Send                 *bool   `path:"send" module:"openconfig-network-instance"`
	SendMax              *uint8  `path:"send-max" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_AddPaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-network-instance"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config      `path:"config" module:"openconfig-network-instance"`
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv4-unicast/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv4Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-labeled-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6LabeledUnicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast struct {
	Config      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config      `path:"config" module:"openconfig-network-instance"`
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/ipv6-unicast/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State struct {
	SendDefaultRoute *bool `path:"send-default-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_Ipv6Unicast_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-evpn/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnEvpn_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l2vpn-vpls/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L2VpnVpls_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-multicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv4-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv4Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-multicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Multicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/l3vpn-ipv6-unicast/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_L3VpnIpv6Unicast_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4 struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv4/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv4_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6 struct {
	PrefixLimit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit `path:"prefix-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/srte-policy-ipv6/prefix-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State struct {
	MaxPrefixes         *uint32  `path:"max-prefixes" module:"openconfig-network-instance"`
	PreventTeardown     *bool    `path:"prevent-teardown" module:"openconfig-network-instance"`
	RestartTimer        *float64 `path:"restart-timer" module:"openconfig-network-instance"`
	WarningThresholdPct *uint8   `path:"warning-threshold-pct" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_SrtePolicyIpv6_PrefixLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-network-instance"`
	Enabled     *bool                              `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config `path:"config" module:"openconfig-network-instance"`
	Ebgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-network-instance"`
	Ibgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/use-multiple-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AfiSafis_AfiSafi_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State struct {
	DefaultExportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-export-policy" module:"openconfig-network-instance"`
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ExportPolicy        []string                                    `path:"export-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ApplyPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/as-path-options YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/as-path-options/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-network-instance"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-network-instance"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/as-path-options/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State struct {
	AllowOwnAs          *uint8 `path:"allow-own-as" module:"openconfig-network-instance"`
	DisablePeerAsFilter *bool  `path:"disable-peer-as-filter" module:"openconfig-network-instance"`
	ReplacePeerAs       *bool  `path:"replace-peer-as" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_AsPathOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config struct {
	AuthPassword     *string                               `path:"auth-password" module:"openconfig-network-instance"`
	Description      *string                               `path:"description" module:"openconfig-network-instance"`
	LocalAs          *uint32                               `path:"local-as" module:"openconfig-network-instance"`
	PeerAs           *uint32                               `path:"peer-as" module:"openconfig-network-instance"`
	PeerGroupName    *string                               `path:"peer-group-name" module:"openconfig-network-instance"`
	PeerType         E_OpenconfigBgp_PeerType              `path:"peer-type" module:"openconfig-network-instance"`
	RemovePrivateAs  E_OpenconfigBgp_RemovePrivateAsOption `path:"remove-private-as" module:"openconfig-network-instance"`
	RouteFlapDamping *bool                                 `path:"route-flap-damping" module:"openconfig-network-instance"`
	SendCommunity    E_OpenconfigBgp_CommunityType         `path:"send-community" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/ebgp-multihop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/ebgp-multihop/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-network-instance"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/ebgp-multihop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-network-instance"`
	MultihopTtl *uint8 `path:"multihop-ttl" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EbgpMultihop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/enable-bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/enable-bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/enable-bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/error-handling YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/error-handling/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config struct {
	TreatAsWithdraw *bool `path:"treat-as-withdraw" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/error-handling/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State struct {
	TreatAsWithdraw *bool `path:"treat-as-withdraw" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_ErrorHandling_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-network-instance"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-network-instance"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State struct {
	Enabled         *bool    `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly      *bool    `path:"helper-only" module:"openconfig-network-instance"`
	RestartTime     *uint16  `path:"restart-time" module:"openconfig-network-instance"`
	StaleRoutesTime *float64 `path:"stale-routes-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/logging-options YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/logging-options/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/logging-options/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State struct {
	LogNeighborStateChanges *bool `path:"log-neighbor-state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_LoggingOptions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config struct {
	RouteReflectorClient    *bool                                                                                                                                                      `path:"route-reflector-client" module:"openconfig-network-instance"`
	RouteReflectorClusterId OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/config/route-reflector-cluster-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/config/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/config/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_Config_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State struct {
	RouteReflectorClient    *bool                                                                                                                                                     `path:"route-reflector-client" module:"openconfig-network-instance"`
	RouteReflectorClusterId OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union `path:"route-reflector-cluster-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/route-reflector/state/route-reflector-cluster-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_RouteReflector_State_RouteReflectorClusterId_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State struct {
	AuthPassword     *string                               `path:"auth-password" module:"openconfig-network-instance"`
	Description      *string                               `path:"description" module:"openconfig-network-instance"`
	LocalAs          *uint32                               `path:"local-as" module:"openconfig-network-instance"`
	PeerAs           *uint32                               `path:"peer-as" module:"openconfig-network-instance"`
	PeerGroupName    *string                               `path:"peer-group-name" module:"openconfig-network-instance"`
	PeerType         E_OpenconfigBgp_PeerType              `path:"peer-type" module:"openconfig-network-instance"`
	RemovePrivateAs  E_OpenconfigBgp_RemovePrivateAsOption `path:"remove-private-as" module:"openconfig-network-instance"`
	RouteFlapDamping *bool                                 `path:"route-flap-damping" module:"openconfig-network-instance"`
	SendCommunity    E_OpenconfigBgp_CommunityType         `path:"send-community" module:"openconfig-network-instance"`
	TotalPaths       *uint32                               `path:"total-paths" module:"openconfig-network-instance"`
	TotalPrefixes    *uint32                               `path:"total-prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-network-instance"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-network-instance"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-network-instance"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State struct {
	ConnectRetry                 *float64 `path:"connect-retry" module:"openconfig-network-instance"`
	HoldTime                     *float64 `path:"hold-time" module:"openconfig-network-instance"`
	KeepaliveInterval            *float64 `path:"keepalive-interval" module:"openconfig-network-instance"`
	MinimumAdvertisementInterval *float64 `path:"minimum-advertisement-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/transport YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/transport/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config struct {
	LocalAddress *string `path:"local-address" module:"openconfig-network-instance"`
	MtuDiscovery *bool   `path:"mtu-discovery" module:"openconfig-network-instance"`
	PassiveMode  *bool   `path:"passive-mode" module:"openconfig-network-instance"`
	TcpMss       *uint16 `path:"tcp-mss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/transport/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State struct {
	LocalAddress *string `path:"local-address" module:"openconfig-network-instance"`
	MtuDiscovery *bool   `path:"mtu-discovery" module:"openconfig-network-instance"`
	PassiveMode  *bool   `path:"passive-mode" module:"openconfig-network-instance"`
	TcpMss       *uint16 `path:"tcp-mss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config `path:"config" module:"openconfig-network-instance"`
	Ebgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp   `path:"ebgp" module:"openconfig-network-instance"`
	Ibgp   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp   `path:"ibgp" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ebgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ebgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ebgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State struct {
	AllowMultipleAs *bool   `path:"allow-multiple-as" module:"openconfig-network-instance"`
	MaximumPaths    *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ebgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ibgp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ibgp/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/ibgp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State struct {
	MaximumPaths *uint32 `path:"maximum-paths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_Ibgp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/use-multiple-paths/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_PeerGroups_PeerGroup_UseMultiplePaths_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib struct {
	AfiSafis       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis       `path:"afi-safis" module:"openconfig-network-instance"`
	AttrSets       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets       `path:"attr-sets" module:"openconfig-network-instance"`
	Communities    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities    `path:"communities" module:"openconfig-network-instance"`
	ExtCommunities *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities `path:"ext-communities" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis struct {
	AfiSafi map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi `path:"afi-safi" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis) IsYANGGoStruct() {
}

// NewAfiSafi creates a new entry in the AfiSafi list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis) NewAfiSafi(AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AfiSafi == nil {
		t.AfiSafi = make(map[E_OpenconfigBgpTypes_AFI_SAFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi)
	}

	key := AfiSafiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AfiSafi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AfiSafi", key)
	}

	t.AfiSafi[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi{
		AfiSafiName: AfiSafiName,
	}

	return t.AfiSafi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi struct {
	AfiSafiName    E_OpenconfigBgpTypes_AFI_SAFI_TYPE                                                                                     `path:"afi-safi-name" module:"openconfig-network-instance"`
	Ipv4SrtePolicy *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy `path:"ipv4-srte-policy" module:"openconfig-network-instance"`
	Ipv4Unicast    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast    `path:"ipv4-unicast" module:"openconfig-network-instance"`
	Ipv6SrtePolicy *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy `path:"ipv6-srte-policy" module:"openconfig-network-instance"`
	Ipv6Unicast    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast    `path:"ipv6-unicast" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State          `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-safi-name": t.AfiSafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy struct {
	LocRib    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib    `path:"loc-rib" module:"openconfig-network-instance"`
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route struct {
	Color             *uint32                                                                                                                                                      `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                      `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                      `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                              `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	AdjRibInPre     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	AdjRibOutPost   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	AdjRibOutPre    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	NeighborAddress *string                                                                                                                                                 `path:"neighbor-address" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	Color             *uint32                                                                                                                                                                               `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                               `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                               `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                       `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	Color             *uint32                                                                                                                                                                              `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                              `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                              `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                      `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	Color             *uint32                                                                                                                                                                                `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                                `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                                `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                        `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	Color             *uint32                                                                                                                                                                               `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                               `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                               `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                       `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4SrtePolicy_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast struct {
	LocRib    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib    `path:"loc-rib" module:"openconfig-network-instance"`
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes `path:"routes" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key struct {
	Prefix string                                                                                                                                                    `path:"prefix"`
	Origin OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin"`
	PathId uint32                                                                                                                                                    `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) NewRoute(Prefix string, Origin OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route struct {
	Origin            OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                   `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin
// is to be set to a E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE struct {
	E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                                                                                                                                   `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                                                                                                                                   `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                                                                                                                                   `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                                                              `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                                                                                                                                   `path:"last-modified" module:"openconfig-network-instance"`
	Origin            OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                   `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                                                                                                                                     `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                           `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_LocRib_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	AdjRibInPre     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	AdjRibOutPost   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	AdjRibOutPre    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	NeighborAddress *string                                                                                                                                              `path:"neighbor-address" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                            `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                            `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                    `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPost_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                           `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                           `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                   `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibInPre_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                             `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                             `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                     `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPost_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                            `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                            `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                    `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_AdjRibOutPre_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv4Unicast_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy struct {
	LocRib    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib    `path:"loc-rib" module:"openconfig-network-instance"`
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route struct {
	Color             *uint32                                                                                                                                                      `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                      `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                      `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                              `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	AdjRibInPre     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	AdjRibOutPost   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	AdjRibOutPre    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	NeighborAddress *string                                                                                                                                                 `path:"neighbor-address" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	Color             *uint32                                                                                                                                                                               `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                               `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                               `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                       `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	Color             *uint32                                                                                                                                                                              `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                              `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                              `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                      `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	Color             *uint32                                                                                                                                                                                `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                                `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                                `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                        `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	PathId   uint32 `path:"path-id"`
	Endpoint string `path:"endpoint"`
	Color    uint32 `path:"color"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(PathId uint32, Endpoint string, Color uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		PathId:   PathId,
		Endpoint: Endpoint,
		Color:    Color,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		PathId:   &PathId,
		Endpoint: &Endpoint,
		Color:    &Color,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	Color             *uint32                                                                                                                                                                               `path:"color" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                                                                                               `path:"endpoint" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                                               `path:"path-id" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
		"path-id":  *t.PathId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	Color             *uint32                                      `path:"color" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	Endpoint          *string                                      `path:"endpoint" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                       `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6SrtePolicy_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast struct {
	LocRib    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib    `path:"loc-rib" module:"openconfig-network-instance"`
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes `path:"routes" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key struct {
	Prefix string                                                                                                                                                    `path:"prefix"`
	Origin OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin"`
	PathId uint32                                                                                                                                                    `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) NewRoute(Prefix string, Origin OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_Key{
		Prefix: Prefix,
		Origin: Origin,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route{
		Prefix: &Prefix,
		Origin: Origin,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route struct {
	Origin            OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                   `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {

	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"origin":  t.Origin,
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin
// is to be set to a E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE struct {
	E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State struct {
	AttrIndex         *uint64                                                                                                                                                   `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                                                                                                                                   `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                                                                                                                                   `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON                                                                                                              `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                                                                                                                                   `path:"last-modified" module:"openconfig-network-instance"`
	Origin            OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union `path:"origin" module:"openconfig-network-instance"`
	PathId            *uint32                                                                                                                                                   `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                                                                                                                                     `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_State_Origin_Union, unknown union type, got: %T, want any of [E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                           `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_LocRib_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor struct {
	AdjRibInPost    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost  `path:"adj-rib-in-post" module:"openconfig-network-instance"`
	AdjRibInPre     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre   `path:"adj-rib-in-pre" module:"openconfig-network-instance"`
	AdjRibOutPost   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost `path:"adj-rib-out-post" module:"openconfig-network-instance"`
	AdjRibOutPre    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre  `path:"adj-rib-out-pre" module:"openconfig-network-instance"`
	NeighborAddress *string                                                                                                                                              `path:"neighbor-address" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                            `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                            `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	BestPath          *bool                                        `path:"best-path" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                    `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                           `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                           `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                   `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibInPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                             `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                             `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                     `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPost_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre struct {
	Routes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes `path:"routes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct {
	Route map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route `path:"route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key represents the key for list Route of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key struct {
	Prefix string `path:"prefix"`
	PathId uint32 `path:"path-id"`
}

// NewRoute creates a new entry in the Route list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) NewRoute(Prefix string, PathId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Route == nil {
		t.Route = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_Key{
		Prefix: Prefix,
		PathId: PathId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Route[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Route", key)
	}

	t.Route[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route{
		Prefix: &Prefix,
		PathId: &PathId,
	}

	return t.Route[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct {
	PathId            *uint32                                                                                                                                                                            `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                                                                                                                                                            `path:"prefix" module:"openconfig-network-instance"`
	State             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State             `path:"state" module:"openconfig-network-instance"`
	UnknownAttributes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes `path:"unknown-attributes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛListKeyMap() (map[string]interface{}, error) {
	if t.PathId == nil {
		return nil, fmt.Errorf("nil value for key PathId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"path-id": *t.PathId,
		"prefix":  *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State struct {
	AttrIndex         *uint64                                      `path:"attr-index" module:"openconfig-network-instance"`
	CommunityIndex    *uint64                                      `path:"community-index" module:"openconfig-network-instance"`
	ExtCommunityIndex *uint64                                      `path:"ext-community-index" module:"openconfig-network-instance"`
	InvalidReason     E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON `path:"invalid-reason" module:"openconfig-network-instance"`
	LastModified      *uint64                                      `path:"last-modified" module:"openconfig-network-instance"`
	PathId            *uint32                                      `path:"path-id" module:"openconfig-network-instance"`
	Prefix            *string                                      `path:"prefix" module:"openconfig-network-instance"`
	ValidRoute        *bool                                        `path:"valid-route" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct {
	UnknownAttribute map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute `path:"unknown-attribute" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) IsYANGGoStruct() {
}

// NewUnknownAttribute creates a new entry in the UnknownAttribute list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) NewUnknownAttribute(AttrType uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnknownAttribute == nil {
		t.UnknownAttribute = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute)
	}

	key := AttrType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnknownAttribute[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnknownAttribute", key)
	}

	t.UnknownAttribute[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute{
		AttrType: &AttrType,
	}

	return t.UnknownAttribute[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct {
	AttrType *uint8                                                                                                                                                                                                    `path:"attr-type" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AttrType == nil {
		return nil, fmt.Errorf("nil value for key AttrType")
	}

	return map[string]interface{}{
		"attr-type": *t.AttrType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/unknown-attributes/unknown-attribute/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State struct {
	AttrLen    *uint16 `path:"attr-len" module:"openconfig-network-instance"`
	AttrType   *uint8  `path:"attr-type" module:"openconfig-network-instance"`
	AttrValue  Binary  `path:"attr-value" module:"openconfig-network-instance"`
	Extended   *bool   `path:"extended" module:"openconfig-network-instance"`
	Optional   *bool   `path:"optional" module:"openconfig-network-instance"`
	Partial    *bool   `path:"partial" module:"openconfig-network-instance"`
	Transitive *bool   `path:"transitive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_AdjRibOutPre_Routes_Route_UnknownAttributes_UnknownAttribute_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State struct {
	NeighborAddress *string `path:"neighbor-address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_Ipv6Unicast_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State struct {
	AfiSafiName E_OpenconfigBgpTypes_AFI_SAFI_TYPE `path:"afi-safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AfiSafis_AfiSafi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets struct {
	AttrSet map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet `path:"attr-set" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets) IsYANGGoStruct() {
}

// NewAttrSet creates a new entry in the AttrSet list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets) NewAttrSet(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AttrSet == nil {
		t.AttrSet = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AttrSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AttrSet", key)
	}

	t.AttrSet[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet{
		Index: &Index,
	}

	return t.AttrSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet struct {
	Aggregator          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator          `path:"aggregator" module:"openconfig-network-instance"`
	AsPath              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath              `path:"as-path" module:"openconfig-network-instance"`
	As4Path             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path             `path:"as4-path" module:"openconfig-network-instance"`
	Index               *uint64                                                                                                                     `path:"index" module:"openconfig-network-instance"`
	State               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State               `path:"state" module:"openconfig-network-instance"`
	TunnelEncapsulation *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation `path:"tunnel-encapsulation" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/aggregator YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/aggregator/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State struct {
	Address *string `path:"address" module:"openconfig-network-instance"`
	As      *uint32 `path:"as" module:"openconfig-network-instance"`
	As4     *uint32 `path:"as4" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_Aggregator_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as4-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path struct {
	As4Segment []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment `path:"as4-segment" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as4-path/as4-segment YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as4-path/as4-segment/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State struct {
	Member []uint32                             `path:"member" module:"openconfig-network-instance"`
	Type   E_OpenconfigRibBgp_AsPathSegmentType `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_As4Path_As4Segment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath struct {
	AsSegment []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment `path:"as-segment" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as-path/as-segment YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as-path/as-segment/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State struct {
	Member []uint32                             `path:"member" module:"openconfig-network-instance"`
	Type   E_OpenconfigRibBgp_AsPathSegmentType `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_AsPath_AsSegment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State struct {
	Aigp            *uint64                              `path:"aigp" module:"openconfig-network-instance"`
	AtomicAggregate *bool                                `path:"atomic-aggregate" module:"openconfig-network-instance"`
	ClusterList     []string                             `path:"cluster-list" module:"openconfig-network-instance"`
	Index           *uint64                              `path:"index" module:"openconfig-network-instance"`
	LocalPref       *uint32                              `path:"local-pref" module:"openconfig-network-instance"`
	Med             *uint32                              `path:"med" module:"openconfig-network-instance"`
	NextHop         *string                              `path:"next-hop" module:"openconfig-network-instance"`
	Origin          E_OpenconfigRibBgp_BgpOriginAttrType `path:"origin" module:"openconfig-network-instance"`
	OriginatorId    *string                              `path:"originator-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation struct {
	Tunnels *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels `path:"tunnels" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels struct {
	Tunnel map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel `path:"tunnel" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) IsYANGGoStruct() {
}

// NewTunnel creates a new entry in the Tunnel list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) NewTunnel(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tunnel == nil {
		t.Tunnel = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tunnel[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tunnel", key)
	}

	t.Tunnel[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel{
		Type: Type,
	}

	return t.Tunnel[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel struct {
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State   `path:"state" module:"openconfig-network-instance"`
	Subtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs `path:"subtlvs" module:"openconfig-network-instance"`
	Type    E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE                                                                                                  `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State struct {
	Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs struct {
	Subtlv map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) NewSubtlv(Type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv struct {
	RemoteEndpoints *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints `path:"remote-endpoints" module:"openconfig-network-instance"`
	SegmentLists    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists    `path:"segment-lists" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State           `path:"state" module:"openconfig-network-instance"`
	Type            E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE                                                                                                                  `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints struct {
	RemoteEndpoint map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint `path:"remote-endpoint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) IsYANGGoStruct() {
}

// NewRemoteEndpoint creates a new entry in the RemoteEndpoint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) NewRemoteEndpoint(Endpoint string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteEndpoint == nil {
		t.RemoteEndpoint = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint)
	}

	key := Endpoint

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RemoteEndpoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RemoteEndpoint", key)
	}

	t.RemoteEndpoint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint{
		Endpoint: &Endpoint,
	}

	return t.RemoteEndpoint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints/remote-endpoint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint struct {
	Endpoint *string                                                                                                                                                                                        `path:"endpoint" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	return map[string]interface{}{
		"endpoint": *t.Endpoint,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/remote-endpoints/remote-endpoint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State struct {
	As       *uint32 `path:"as" module:"openconfig-network-instance"`
	Endpoint *string `path:"endpoint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_RemoteEndpoints_RemoteEndpoint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists struct {
	SegmentList map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList `path:"segment-list" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) IsYANGGoStruct() {
}

// NewSegmentList creates a new entry in the SegmentList list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) NewSegmentList(InstanceId uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList)
	}

	key := InstanceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SegmentList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SegmentList", key)
	}

	t.SegmentList[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList{
		InstanceId: &InstanceId,
	}

	return t.SegmentList[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList struct {
	InstanceId *uint64                                                                                                                                                                                     `path:"instance-id" module:"openconfig-network-instance"`
	Segments   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments `path:"segments" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceId == nil {
		return nil, fmt.Errorf("nil value for key InstanceId")
	}

	return map[string]interface{}{
		"instance-id": *t.InstanceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments struct {
	Segment map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment `path:"segment" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) IsYANGGoStruct() {
}

// NewSegment creates a new entry in the Segment list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) NewSegment(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Segment == nil {
		t.Segment = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Segment[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Segment", key)
	}

	t.Segment[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment{
		Index: &Index,
	}

	return t.Segment[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment struct {
	Index *uint64                                                                                                                                                                                                   `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State struct {
	Index             *uint64                                                                                                                                                                                                            `path:"index" module:"openconfig-network-instance"`
	LocalInterfaceId  *uint32                                                                                                                                                                                                            `path:"local-interface-id" module:"openconfig-network-instance"`
	LocalIpv4Address  *string                                                                                                                                                                                                            `path:"local-ipv4-address" module:"openconfig-network-instance"`
	LocalIpv6Address  *string                                                                                                                                                                                                            `path:"local-ipv6-address" module:"openconfig-network-instance"`
	MplsBos           *bool                                                                                                                                                                                                              `path:"mpls-bos" module:"openconfig-network-instance"`
	MplsTc            *uint8                                                                                                                                                                                                             `path:"mpls-tc" module:"openconfig-network-instance"`
	MplsTtl           *uint8                                                                                                                                                                                                             `path:"mpls-ttl" module:"openconfig-network-instance"`
	RemoteIpv4Address *string                                                                                                                                                                                                            `path:"remote-ipv4-address" module:"openconfig-network-instance"`
	RemoteIpv6Address *string                                                                                                                                                                                                            `path:"remote-ipv6-address" module:"openconfig-network-instance"`
	Sid               OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union `path:"sid" module:"openconfig-network-instance"`
	Type              E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type                                                                    `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid
// is to be set to a E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid struct {
	E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_Union, unknown union type, got: %T, want any of [E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State struct {
	InstanceId *uint64 `path:"instance-id" module:"openconfig-network-instance"`
	Weight     *uint32 `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State struct {
	BindingSid OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union `path:"binding-sid" module:"openconfig-network-instance"`
	Colors     []uint32                                                                                                                                                                        `path:"colors" module:"openconfig-network-instance"`
	Preference *uint32                                                                                                                                                                         `path:"preference" module:"openconfig-network-instance"`
	Type       E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE                                                                                                                        `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid
// is to be set to a E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid struct {
	E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_Union, unknown union type, got: %T, want any of [E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities struct {
	Community map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community `path:"community" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities) IsYANGGoStruct() {
}

// NewCommunity creates a new entry in the Community list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities) NewCommunity(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Community == nil {
		t.Community = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Community[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Community", key)
	}

	t.Community[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community{
		Index: &Index,
	}

	return t.Community[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community struct {
	Index *uint64                                                                                                            `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State struct {
	Community []OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union `path:"community" module:"openconfig-network-instance"`
	Index     *uint64                                                                                                                             `path:"index" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community
// is to be set to a E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY struct {
	E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_Communities_Community_State_Community_Union, unknown union type, got: %T, want any of [E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities struct {
	ExtCommunity map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity `path:"ext-community" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities) IsYANGGoStruct() {
}

// NewExtCommunity creates a new entry in the ExtCommunity list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities) NewExtCommunity(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ExtCommunity == nil {
		t.ExtCommunity = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ExtCommunity[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ExtCommunity", key)
	}

	t.ExtCommunity[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity{
		Index: &Index,
	}

	return t.ExtCommunity[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity struct {
	Index *uint64                                                                                                                  `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State struct {
	ExtCommunity []OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union `path:"ext-community" module:"openconfig-network-instance"`
	Index        *uint64                                                                                                                                      `path:"index" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community/state/ext-community within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community/state/ext-community
// is to be set to a Binary value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary struct {
	Binary Binary
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/bgp/rib/ext-communities/ext-community/state/ext-community
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union, error) {
	switch v := i.(type) {
	case Binary:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_Binary{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Bgp_Rib_ExtCommunities_ExtCommunity_State_ExtCommunity_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config struct {
	DefaultMetric *uint32                                       `path:"default-metric" module:"openconfig-network-instance"`
	Enabled       *bool                                         `path:"enabled" module:"openconfig-network-instance"`
	Identifier    E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"identifier" module:"openconfig-network-instance"`
	Name          *string                                       `path:"name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp struct {
	Global     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global     `path:"global" module:"openconfig-network-instance"`
	Interfaces *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces `path:"interfaces" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global struct {
	Ssm *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm `path:"ssm" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm struct {
	Mappings *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings `path:"mappings" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm/mappings YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings struct {
	Mapping map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping `path:"mapping" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings) IsYANGGoStruct() {
}

// NewMapping creates a new entry in the Mapping list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings) NewMapping(Source string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Mapping == nil {
		t.Mapping = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping)
	}

	key := Source

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Mapping[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Mapping", key)
	}

	t.Mapping[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping{
		Source: &Source,
	}

	return t.Mapping[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm/mappings/mapping YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config `path:"config" module:"openconfig-network-instance"`
	Source *string                                                                                                                `path:"source" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Source == nil {
		return nil, fmt.Errorf("nil value for key Source")
	}

	return map[string]interface{}{
		"source": *t.Source,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm/mappings/mapping/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config struct {
	Source    *string `path:"source" module:"openconfig-network-instance"`
	SsmRanges *string `path:"ssm-ranges" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/global/ssm/mappings/mapping/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State struct {
	Source    *string `path:"source" module:"openconfig-network-instance"`
	SsmRanges *string `path:"ssm-ranges" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Global_Ssm_Mappings_Mapping_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface struct {
	Config           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config           `path:"config" module:"openconfig-network-instance"`
	Counters         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters         `path:"counters" module:"openconfig-network-instance"`
	InterfaceId      *string                                                                                                                   `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef     `path:"interface-ref" module:"openconfig-network-instance"`
	MembershipGroups *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups `path:"membership-groups" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State            `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config struct {
	Enabled        *bool   `path:"enabled" module:"openconfig-network-instance"`
	FilterPrefixes *string `path:"filter-prefixes" module:"openconfig-network-instance"`
	InterfaceId    *string `path:"interface-id" module:"openconfig-network-instance"`
	QueryInterval  *uint16 `path:"query-interval" module:"openconfig-network-instance"`
	Version        *uint8  `path:"version" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters struct {
	Queries *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries `path:"queries" module:"openconfig-network-instance"`
	Reports *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports `path:"reports" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries struct {
	Received *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received `path:"received" module:"openconfig-network-instance"`
	Sent     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent     `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries/received YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries/received/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State struct {
	V1 *uint32 `path:"v1" module:"openconfig-network-instance"`
	V2 *uint32 `path:"v2" module:"openconfig-network-instance"`
	V3 *uint32 `path:"v3" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Received_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries/sent YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/queries/sent/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State struct {
	V1 *uint32 `path:"v1" module:"openconfig-network-instance"`
	V2 *uint32 `path:"v2" module:"openconfig-network-instance"`
	V3 *uint32 `path:"v3" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Queries_Sent_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/reports YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/counters/reports/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State struct {
	V1 *uint32 `path:"v1" module:"openconfig-network-instance"`
	V2 *uint32 `path:"v2" module:"openconfig-network-instance"`
	V3 *uint32 `path:"v3" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_Counters_Reports_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/membership-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups struct {
	Group map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group `path:"group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups) IsYANGGoStruct() {
}

// NewGroup creates a new entry in the Group list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups) NewGroup(Group string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Group == nil {
		t.Group = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group)
	}

	key := Group

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Group[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Group", key)
	}

	t.Group[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group{
		Group: &Group,
	}

	return t.Group[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/membership-groups/group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group struct {
	Group *string                                                                                                                               `path:"group" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Group == nil {
		return nil, fmt.Errorf("nil value for key Group")
	}

	return map[string]interface{}{
		"group": *t.Group,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/membership-groups/group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State struct {
	Group    *string `path:"group" module:"openconfig-network-instance"`
	Reporter *string `path:"reporter" module:"openconfig-network-instance"`
	Source   *string `path:"source" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_MembershipGroups_Group_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/igmp/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State struct {
	Enabled        *bool   `path:"enabled" module:"openconfig-network-instance"`
	FilterPrefixes *string `path:"filter-prefixes" module:"openconfig-network-instance"`
	InterfaceId    *string `path:"interface-id" module:"openconfig-network-instance"`
	QueryExpires   *uint64 `path:"query-expires" module:"openconfig-network-instance"`
	QueryInterval  *uint16 `path:"query-interval" module:"openconfig-network-instance"`
	Version        *uint8  `path:"version" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Igmp_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis struct {
	Global     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global     `path:"global" module:"openconfig-network-instance"`
	Interfaces *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces `path:"interfaces" module:"openconfig-network-instance"`
	Levels     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels     `path:"levels" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global struct {
	AfiSafi                       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi                       `path:"afi-safi" module:"openconfig-network-instance"`
	Config                        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config                        `path:"config" module:"openconfig-network-instance"`
	GracefulRestart               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart               `path:"graceful-restart" module:"openconfig-network-instance"`
	IgpShortcuts                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts                  `path:"igp-shortcuts" module:"openconfig-network-instance"`
	InterLevelPropagationPolicies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies `path:"inter-level-propagation-policies" module:"openconfig-network-instance"`
	LspBit                        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit                        `path:"lsp-bit" module:"openconfig-network-instance"`
	Mpls                          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls                          `path:"mpls" module:"openconfig-network-instance"`
	Nsr                           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr                           `path:"nsr" module:"openconfig-network-instance"`
	ReferenceBandwidth            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth            `path:"reference-bandwidth" module:"openconfig-network-instance"`
	SegmentRouting                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting                `path:"segment-routing" module:"openconfig-network-instance"`
	State                         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State                         `path:"state" module:"openconfig-network-instance"`
	Timers                        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers                        `path:"timers" module:"openconfig-network-instance"`
	Transport                     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport                     `path:"transport" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi struct {
	Af map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af `path:"af" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Key represents the key for list Af of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Key struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name"`
}

// NewAf creates a new entry in the Af list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi) NewAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Af[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Af", key)
	}

	t.Af[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	return t.Af[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af struct {
	AfiName       E_OpenconfigIsisTypes_AFI_TYPE                                                                                      `path:"afi-name" module:"openconfig-network-instance"`
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config        `path:"config" module:"openconfig-network-instance"`
	MultiTopology *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology `path:"multi-topology" module:"openconfig-network-instance"`
	SafiName      E_OpenconfigIsisTypes_SAFI_TYPE                                                                                     `path:"safi-name" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name":  t.AfiName,
		"safi-name": t.SafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	Metric   *uint32                         `path:"metric" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_MultiTopology_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	Metric   *uint32                         `path:"metric" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_AfiSafi_Af_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config struct {
	AuthenticationCheck  *bool                      `path:"authentication-check" module:"openconfig-network-instance"`
	FastFlooding         *bool                      `path:"fast-flooding" module:"openconfig-network-instance"`
	IidTlv               *bool                      `path:"iid-tlv" module:"openconfig-network-instance"`
	Instance             *string                    `path:"instance" module:"openconfig-network-instance"`
	LevelCapability      E_OpenconfigIsis_LevelType `path:"level-capability" module:"openconfig-network-instance"`
	MaxEcmpPaths         *uint8                     `path:"max-ecmp-paths" module:"openconfig-network-instance"`
	MaximumAreaAddresses *uint8                     `path:"maximum-area-addresses" module:"openconfig-network-instance"`
	Net                  []string                   `path:"net" module:"openconfig-network-instance"`
	PoiTlv               *bool                      `path:"poi-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config struct {
	Enabled    *bool `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly *bool `path:"helper-only" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State struct {
	Enabled    *bool `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly *bool `path:"helper-only" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts struct {
	Afi map[E_OpenconfigIsisTypes_AFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi `path:"afi" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts) IsYANGGoStruct() {
}

// NewAfi creates a new entry in the Afi list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts) NewAfi(AfiName E_OpenconfigIsisTypes_AFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Afi == nil {
		t.Afi = make(map[E_OpenconfigIsisTypes_AFI_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi)
	}

	key := AfiName

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Afi[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Afi", key)
	}

	t.Afi[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi{
		AfiName: AfiName,
	}

	return t.Afi[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi struct {
	AfiName E_OpenconfigIsisTypes_AFI_TYPE                                                                                     `path:"afi-name" module:"openconfig-network-instance"`
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config `path:"config" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name": t.AfiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config struct {
	AfiName E_OpenconfigIsisTypes_AFI_TYPE              `path:"afi-name" module:"openconfig-network-instance"`
	NhType  []E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL `path:"nh-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State struct {
	AfiName E_OpenconfigIsisTypes_AFI_TYPE              `path:"afi-name" module:"openconfig-network-instance"`
	NhType  []E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL `path:"nh-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_IgpShortcuts_Afi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies struct {
	Level1ToLevel2 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 `path:"level1-to-level2" module:"openconfig-network-instance"`
	Level2ToLevel1 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 `path:"level2-to-level1" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config struct {
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State struct {
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level1ToLevel2_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config struct {
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State struct {
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType `path:"default-import-policy" module:"openconfig-network-instance"`
	ImportPolicy        []string                                    `path:"import-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_InterLevelPropagationPolicies_Level2ToLevel1_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit struct {
	AttachedBit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit `path:"attached-bit" module:"openconfig-network-instance"`
	OverloadBit *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit `path:"overload-bit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/attached-bit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/attached-bit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config struct {
	IgnoreBit   *bool `path:"ignore-bit" module:"openconfig-network-instance"`
	SuppressBit *bool `path:"suppress-bit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/attached-bit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State struct {
	IgnoreBit   *bool `path:"ignore-bit" module:"openconfig-network-instance"`
	SuppressBit *bool `path:"suppress-bit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_AttachedBit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit struct {
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config        `path:"config" module:"openconfig-network-instance"`
	ResetTriggers *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers `path:"reset-triggers" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config struct {
	AdvertiseHighMetric *bool `path:"advertise-high-metric" module:"openconfig-network-instance"`
	SetBit              *bool `path:"set-bit" module:"openconfig-network-instance"`
	SetBitOnBoot        *bool `path:"set-bit-on-boot" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers struct {
	ResetTrigger map[E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger `path:"reset-trigger" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers) IsYANGGoStruct() {
}

// NewResetTrigger creates a new entry in the ResetTrigger list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers) NewResetTrigger(ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ResetTrigger == nil {
		t.ResetTrigger = make(map[E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger)
	}

	key := ResetTrigger

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ResetTrigger[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ResetTrigger", key)
	}

	t.ResetTrigger[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger{
		ResetTrigger: ResetTrigger,
	}

	return t.ResetTrigger[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config `path:"config" module:"openconfig-network-instance"`
	ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE                                                                                               `path:"reset-trigger" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"reset-trigger": t.ResetTrigger,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config struct {
	Delay        *uint16                                           `path:"delay" module:"openconfig-network-instance"`
	ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE `path:"reset-trigger" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State struct {
	Delay        *uint16                                           `path:"delay" module:"openconfig-network-instance"`
	ResetTrigger E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE `path:"reset-trigger" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_ResetTriggers_ResetTrigger_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State struct {
	AdvertiseHighMetric *bool `path:"advertise-high-metric" module:"openconfig-network-instance"`
	SetBit              *bool `path:"set-bit" module:"openconfig-network-instance"`
	SetBitOnBoot        *bool `path:"set-bit-on-boot" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_LspBit_OverloadBit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls struct {
	IgpLdpSync *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/mpls/igp-ldp-sync YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/mpls/igp-ldp-sync/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint16 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/mpls/igp-ldp-sync/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint16 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Mpls_IgpLdpSync_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/nsr YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/nsr/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/nsr/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Nsr_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/reference-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/reference-bandwidth/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config struct {
	ReferenceBandwidth *uint32 `path:"reference-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/reference-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State struct {
	ReferenceBandwidth *uint32 `path:"reference-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_ReferenceBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/segment-routing YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/segment-routing/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config struct {
	Enabled *bool   `path:"enabled" module:"openconfig-network-instance"`
	Srgb    *string `path:"srgb" module:"openconfig-network-instance"`
	Srlb    *string `path:"srlb" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/segment-routing/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State struct {
	Enabled *bool   `path:"enabled" module:"openconfig-network-instance"`
	Srgb    *string `path:"srgb" module:"openconfig-network-instance"`
	Srlb    *string `path:"srlb" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_SegmentRouting_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State struct {
	AuthenticationCheck  *bool                      `path:"authentication-check" module:"openconfig-network-instance"`
	FastFlooding         *bool                      `path:"fast-flooding" module:"openconfig-network-instance"`
	IidTlv               *bool                      `path:"iid-tlv" module:"openconfig-network-instance"`
	Instance             *string                    `path:"instance" module:"openconfig-network-instance"`
	LevelCapability      E_OpenconfigIsis_LevelType `path:"level-capability" module:"openconfig-network-instance"`
	MaxEcmpPaths         *uint8                     `path:"max-ecmp-paths" module:"openconfig-network-instance"`
	MaximumAreaAddresses *uint8                     `path:"maximum-area-addresses" module:"openconfig-network-instance"`
	Net                  []string                   `path:"net" module:"openconfig-network-instance"`
	PoiTlv               *bool                      `path:"poi-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers struct {
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config        `path:"config" module:"openconfig-network-instance"`
	LspGeneration *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration `path:"lsp-generation" module:"openconfig-network-instance"`
	Spf           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf           `path:"spf" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config struct {
	LspLifetimeInterval *uint16 `path:"lsp-lifetime-interval" module:"openconfig-network-instance"`
	LspRefreshInterval  *uint16 `path:"lsp-refresh-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/lsp-generation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/lsp-generation/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config struct {
	LspFirstWaitInterval  *uint64 `path:"lsp-first-wait-interval" module:"openconfig-network-instance"`
	LspMaxWaitInterval    *uint64 `path:"lsp-max-wait-interval" module:"openconfig-network-instance"`
	LspSecondWaitInterval *uint64 `path:"lsp-second-wait-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/lsp-generation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State struct {
	AdaptiveTimer         E_OpenconfigIsis_AdaptiveTimerType `path:"adaptive-timer" module:"openconfig-network-instance"`
	LspFirstWaitInterval  *uint64                            `path:"lsp-first-wait-interval" module:"openconfig-network-instance"`
	LspMaxWaitInterval    *uint64                            `path:"lsp-max-wait-interval" module:"openconfig-network-instance"`
	LspSecondWaitInterval *uint64                            `path:"lsp-second-wait-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_LspGeneration_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/spf YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/spf/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config struct {
	SpfFirstInterval  *uint64 `path:"spf-first-interval" module:"openconfig-network-instance"`
	SpfHoldInterval   *uint64 `path:"spf-hold-interval" module:"openconfig-network-instance"`
	SpfSecondInterval *uint64 `path:"spf-second-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/spf/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State struct {
	AdaptiveTimer     E_OpenconfigIsis_AdaptiveTimerType `path:"adaptive-timer" module:"openconfig-network-instance"`
	SpfFirstInterval  *uint64                            `path:"spf-first-interval" module:"openconfig-network-instance"`
	SpfHoldInterval   *uint64                            `path:"spf-hold-interval" module:"openconfig-network-instance"`
	SpfSecondInterval *uint64                            `path:"spf-second-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_Spf_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State struct {
	LspLifetimeInterval *uint16 `path:"lsp-lifetime-interval" module:"openconfig-network-instance"`
	LspRefreshInterval  *uint16 `path:"lsp-refresh-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/transport YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/transport/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config struct {
	LspMtuSize *uint16 `path:"lsp-mtu-size" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/global/transport/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State struct {
	LspMtuSize *uint16 `path:"lsp-mtu-size" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Global_Transport_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface struct {
	AfiSafi         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi         `path:"afi-safi" module:"openconfig-network-instance"`
	Authentication  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication  `path:"authentication" module:"openconfig-network-instance"`
	Bfd             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd             `path:"bfd" module:"openconfig-network-instance"`
	CircuitCounters *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters `path:"circuit-counters" module:"openconfig-network-instance"`
	Config          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config          `path:"config" module:"openconfig-network-instance"`
	EnableBfd       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd       `path:"enable-bfd" module:"openconfig-network-instance"`
	InterfaceId     *string                                                                                                                  `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef    `path:"interface-ref" module:"openconfig-network-instance"`
	Levels          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels          `path:"levels" module:"openconfig-network-instance"`
	Mpls            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls            `path:"mpls" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State           `path:"state" module:"openconfig-network-instance"`
	Timers          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers          `path:"timers" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi struct {
	Af map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af `path:"af" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Key represents the key for list Af of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Key struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name"`
}

// NewAf creates a new entry in the Af list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi) NewAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Af[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Af", key)
	}

	t.Af[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	return t.Af[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE                                                                                             `path:"afi-name" module:"openconfig-network-instance"`
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config `path:"config" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE                                                                                            `path:"safi-name" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name":  t.AfiName,
		"safi-name": t.SafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_AfiSafi_Af_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config   `path:"config" module:"openconfig-network-instance"`
	Key      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key      `path:"key" module:"openconfig-network-instance"`
	Keychain *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain `path:"keychain" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config struct {
	HelloAuthentication *bool `path:"hello-authentication" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/key YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/key/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config struct {
	AuthPassword *string `path:"auth-password" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/key/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State struct {
	AuthPassword *string `path:"auth-password" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Key_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/keychain YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_Keychain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State struct {
	HelloAuthentication *bool `path:"hello-authentication" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config struct {
	BfdTlv *bool `path:"bfd-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State struct {
	BfdTlv *bool `path:"bfd-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Bfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/circuit-counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/circuit-counters/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State struct {
	AdjChanges               *uint32 `path:"adj-changes" module:"openconfig-network-instance"`
	AdjNumber                *uint32 `path:"adj-number" module:"openconfig-network-instance"`
	AuthFails                *uint32 `path:"auth-fails" module:"openconfig-network-instance"`
	AuthTypeFails            *uint32 `path:"auth-type-fails" module:"openconfig-network-instance"`
	IdFieldLenMismatches     *uint32 `path:"id-field-len-mismatches" module:"openconfig-network-instance"`
	InitFails                *uint32 `path:"init-fails" module:"openconfig-network-instance"`
	LanDisChanges            *uint32 `path:"lan-dis-changes" module:"openconfig-network-instance"`
	MaxAreaAddressMismatches *uint32 `path:"max-area-address-mismatches" module:"openconfig-network-instance"`
	RejectedAdj              *uint32 `path:"rejected-adj" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_CircuitCounters_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config struct {
	CircuitType  E_OpenconfigIsis_CircuitType      `path:"circuit-type" module:"openconfig-network-instance"`
	Enabled      *bool                             `path:"enabled" module:"openconfig-network-instance"`
	HelloPadding E_OpenconfigIsis_HelloPaddingType `path:"hello-padding" module:"openconfig-network-instance"`
	InterfaceId  *string                           `path:"interface-id" module:"openconfig-network-instance"`
	Passive      *bool                             `path:"passive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/enable-bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/enable-bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/enable-bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels struct {
	Level map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level `path:"level" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels) IsYANGGoStruct() {
}

// NewLevel creates a new entry in the Level list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels) NewLevel(LevelNumber uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Level == nil {
		t.Level = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level)
	}

	key := LevelNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Level[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Level", key)
	}

	t.Level[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level{
		LevelNumber: &LevelNumber,
	}

	return t.Level[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level struct {
	Adjacencies         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies         `path:"adjacencies" module:"openconfig-network-instance"`
	AfiSafi             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi             `path:"afi-safi" module:"openconfig-network-instance"`
	Config              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config              `path:"config" module:"openconfig-network-instance"`
	HelloAuthentication *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication `path:"hello-authentication" module:"openconfig-network-instance"`
	LevelNumber         *uint8                                                                                                                                    `path:"level-number" module:"openconfig-network-instance"`
	PacketCounters      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters      `path:"packet-counters" module:"openconfig-network-instance"`
	State               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State               `path:"state" module:"openconfig-network-instance"`
	Timers              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers              `path:"timers" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LevelNumber == nil {
		return nil, fmt.Errorf("nil value for key LevelNumber")
	}

	return map[string]interface{}{
		"level-number": *t.LevelNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies struct {
	Adjacency map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency `path:"adjacency" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies) IsYANGGoStruct() {
}

// NewAdjacency creates a new entry in the Adjacency list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies) NewAdjacency(SystemId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Adjacency == nil {
		t.Adjacency = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Adjacency[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Adjacency", key)
	}

	t.Adjacency[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency{
		SystemId: &SystemId,
	}

	return t.Adjacency[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency struct {
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State `path:"state" module:"openconfig-network-instance"`
	SystemId *string                                                                                                                                           `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State struct {
	AdjacencyState            E_OpenconfigIsis_IsisInterfaceAdjState                                                                                                                     `path:"adjacency-state" module:"openconfig-network-instance"`
	AdjacencyType             E_OpenconfigIsis_LevelType                                                                                                                                 `path:"adjacency-type" module:"openconfig-network-instance"`
	AreaAddress               []string                                                                                                                                                   `path:"area-address" module:"openconfig-network-instance"`
	DisSystemId               *string                                                                                                                                                    `path:"dis-system-id" module:"openconfig-network-instance"`
	LocalExtendedCircuitId    *uint32                                                                                                                                                    `path:"local-extended-circuit-id" module:"openconfig-network-instance"`
	MultiTopology             *bool                                                                                                                                                      `path:"multi-topology" module:"openconfig-network-instance"`
	NeighborCircuitType       E_OpenconfigIsis_LevelType                                                                                                                                 `path:"neighbor-circuit-type" module:"openconfig-network-instance"`
	NeighborExtendedCircuitId *uint32                                                                                                                                                    `path:"neighbor-extended-circuit-id" module:"openconfig-network-instance"`
	NeighborIpv4Address       *string                                                                                                                                                    `path:"neighbor-ipv4-address" module:"openconfig-network-instance"`
	NeighborIpv6Address       *string                                                                                                                                                    `path:"neighbor-ipv6-address" module:"openconfig-network-instance"`
	NeighborSnpa              *string                                                                                                                                                    `path:"neighbor-snpa" module:"openconfig-network-instance"`
	Nlpid                     []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid `path:"nlpid" module:"openconfig-network-instance"`
	Priority                  *uint8                                                                                                                                                     `path:"priority" module:"openconfig-network-instance"`
	RemainingHoldTime         *uint16                                                                                                                                                    `path:"remaining-hold-time" module:"openconfig-network-instance"`
	RestartStatus             *bool                                                                                                                                                      `path:"restart-status" module:"openconfig-network-instance"`
	RestartSupport            *bool                                                                                                                                                      `path:"restart-support" module:"openconfig-network-instance"`
	RestartSuppress           *bool                                                                                                                                                      `path:"restart-suppress" module:"openconfig-network-instance"`
	SystemId                  *string                                                                                                                                                    `path:"system-id" module:"openconfig-network-instance"`
	Topology                  []E_OpenconfigIsisTypes_AFI_SAFI_TYPE                                                                                                                      `path:"topology" module:"openconfig-network-instance"`
	UpTime                    *uint32                                                                                                                                                    `path:"up-time" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi struct {
	Af map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af `path:"af" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Key represents the key for list Af of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Key struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name"`
}

// NewAf creates a new entry in the Af list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi) NewAf(AfiName E_OpenconfigIsisTypes_AFI_TYPE, SafiName E_OpenconfigIsisTypes_SAFI_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Af == nil {
		t.Af = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Key{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Af[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Af", key)
	}

	t.Af[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af{
		AfiName:  AfiName,
		SafiName: SafiName,
	}

	return t.Af[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af struct {
	AfiName        E_OpenconfigIsisTypes_AFI_TYPE                                                                                                                  `path:"afi-name" module:"openconfig-network-instance"`
	Config         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config         `path:"config" module:"openconfig-network-instance"`
	SafiName       E_OpenconfigIsisTypes_SAFI_TYPE                                                                                                                 `path:"safi-name" module:"openconfig-network-instance"`
	SegmentRouting *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting `path:"segment-routing" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State          `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi-name":  t.AfiName,
		"safi-name": t.SafiName,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	Metric   *uint32                         `path:"metric" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting struct {
	AdjacencySids *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids `path:"adjacency-sids" module:"openconfig-network-instance"`
	PrefixSids    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids    `path:"prefix-sids" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids struct {
	AdjacencySid map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Key represents the key for list AdjacencySid of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Key struct {
	Neighbor string                                                                                                                                                                                       `path:"neighbor"`
	SidId    OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union `path:"sid-id"`
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids) NewAdjacencySid(Neighbor string, SidId OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Key{
		Neighbor: Neighbor,
		SidId:    SidId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid{
		Neighbor: &Neighbor,
		SidId:    SidId,
	}

	return t.AdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config            `path:"config" module:"openconfig-network-instance"`
	Neighbor *string                                                                                                                                                                                      `path:"neighbor" module:"openconfig-network-instance"`
	SidId    OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union `path:"sid-id" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State             `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Neighbor == nil {
		return nil, fmt.Errorf("nil value for key Neighbor")
	}

	return map[string]interface{}{
		"neighbor": *t.Neighbor,
		"sid-id":   t.SidId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/sid-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/sid-id
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/sid-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/sid-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config struct {
	Group              *bool                                                                                                                                                                                        `path:"group" module:"openconfig-network-instance"`
	Neighbor           *string                                                                                                                                                                                      `path:"neighbor" module:"openconfig-network-instance"`
	ProtectionEligible *bool                                                                                                                                                                                        `path:"protection-eligible" module:"openconfig-network-instance"`
	SidId              OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union `path:"sid-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State struct {
	AllocatedDynamicLocal OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union `path:"allocated-dynamic-local" module:"openconfig-network-instance"`
	Group                 *bool                                                                                                                                                                                                       `path:"group" module:"openconfig-network-instance"`
	Neighbor              *string                                                                                                                                                                                                     `path:"neighbor" module:"openconfig-network-instance"`
	ProtectionEligible    *bool                                                                                                                                                                                                       `path:"protection-eligible" module:"openconfig-network-instance"`
	SidId                 OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union                 `path:"sid-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_SidId_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids struct {
	PrefixSid map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid `path:"prefix-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids) NewPrefixSid(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid{
		Prefix: &Prefix,
	}

	return t.PrefixSid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config `path:"config" module:"openconfig-network-instance"`
	Prefix *string                                                                                                                                                                     `path:"prefix" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config struct {
	LabelOptions E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions `path:"label-options" module:"openconfig-network-instance"`
	Prefix       *string                                                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	SidId        OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union    `path:"sid-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config/sid-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config/sid-id
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config/sid-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config/sid-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State struct {
	LabelOptions E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions `path:"label-options" module:"openconfig-network-instance"`
	Prefix       *string                                                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	SidId        OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union     `path:"sid-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_State_SidId_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State struct {
	AfiName  E_OpenconfigIsisTypes_AFI_TYPE  `path:"afi-name" module:"openconfig-network-instance"`
	Enabled  *bool                           `path:"enabled" module:"openconfig-network-instance"`
	Metric   *uint32                         `path:"metric" module:"openconfig-network-instance"`
	SafiName E_OpenconfigIsisTypes_SAFI_TYPE `path:"safi-name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-network-instance"`
	LevelNumber *uint8 `path:"level-number" module:"openconfig-network-instance"`
	Passive     *bool  `path:"passive" module:"openconfig-network-instance"`
	Priority    *uint8 `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config   `path:"config" module:"openconfig-network-instance"`
	Key      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key      `path:"key" module:"openconfig-network-instance"`
	Keychain *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain `path:"keychain" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config struct {
	HelloAuthentication *bool `path:"hello-authentication" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/key YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/key/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config struct {
	AuthPassword *string `path:"auth-password" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/key/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State struct {
	AuthPassword *string `path:"auth-password" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Key_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/keychain YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_Keychain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/hello-authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State struct {
	HelloAuthentication *bool `path:"hello-authentication" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_HelloAuthentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters struct {
	Csnp    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp    `path:"csnp" module:"openconfig-network-instance"`
	Esh     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh     `path:"esh" module:"openconfig-network-instance"`
	Iih     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih     `path:"iih" module:"openconfig-network-instance"`
	Ish     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish     `path:"ish" module:"openconfig-network-instance"`
	Lsp     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp     `path:"lsp" module:"openconfig-network-instance"`
	Psnp    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp    `path:"psnp" module:"openconfig-network-instance"`
	Unknown *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown `path:"unknown" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/csnp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/csnp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Csnp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/esh YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/esh/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Esh_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/iih YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/iih/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Iih_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/ish YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/ish/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Ish_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Lsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/psnp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/psnp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Psnp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/unknown YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/packet-counters/unknown/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State struct {
	Dropped    *uint32 `path:"dropped" module:"openconfig-network-instance"`
	Processed  *uint32 `path:"processed" module:"openconfig-network-instance"`
	Received   *uint32 `path:"received" module:"openconfig-network-instance"`
	Retransmit *uint32 `path:"retransmit" module:"openconfig-network-instance"`
	Sent       *uint32 `path:"sent" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_PacketCounters_Unknown_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State struct {
	Enabled     *bool  `path:"enabled" module:"openconfig-network-instance"`
	LevelNumber *uint8 `path:"level-number" module:"openconfig-network-instance"`
	Passive     *bool  `path:"passive" module:"openconfig-network-instance"`
	Priority    *uint8 `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config struct {
	HelloInterval   *uint32 `path:"hello-interval" module:"openconfig-network-instance"`
	HelloMultiplier *uint8  `path:"hello-multiplier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State struct {
	HelloInterval   *uint32 `path:"hello-interval" module:"openconfig-network-instance"`
	HelloMultiplier *uint8  `path:"hello-multiplier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls struct {
	IgpLdpSync *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/mpls/igp-ldp-sync YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/mpls/igp-ldp-sync/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint16 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/mpls/igp-ldp-sync/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint16 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Mpls_IgpLdpSync_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State struct {
	CircuitType  E_OpenconfigIsis_CircuitType      `path:"circuit-type" module:"openconfig-network-instance"`
	Enabled      *bool                             `path:"enabled" module:"openconfig-network-instance"`
	HelloPadding E_OpenconfigIsis_HelloPaddingType `path:"hello-padding" module:"openconfig-network-instance"`
	InterfaceId  *string                           `path:"interface-id" module:"openconfig-network-instance"`
	Passive      *bool                             `path:"passive" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config struct {
	CsnpInterval      *uint16 `path:"csnp-interval" module:"openconfig-network-instance"`
	LspPacingInterval *uint64 `path:"lsp-pacing-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State struct {
	CsnpInterval      *uint16 `path:"csnp-interval" module:"openconfig-network-instance"`
	LspPacingInterval *uint64 `path:"lsp-pacing-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels struct {
	Level map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level `path:"level" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels) IsYANGGoStruct() {
}

// NewLevel creates a new entry in the Level list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels) NewLevel(LevelNumber uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Level == nil {
		t.Level = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level)
	}

	key := LevelNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Level[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Level", key)
	}

	t.Level[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level{
		LevelNumber: &LevelNumber,
	}

	return t.Level[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level struct {
	Authentication      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication      `path:"authentication" module:"openconfig-network-instance"`
	Config              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config              `path:"config" module:"openconfig-network-instance"`
	LevelNumber         *uint8                                                                                                               `path:"level-number" module:"openconfig-network-instance"`
	LinkStateDatabase   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase   `path:"link-state-database" module:"openconfig-network-instance"`
	RoutePreference     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference     `path:"route-preference" module:"openconfig-network-instance"`
	State               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State               `path:"state" module:"openconfig-network-instance"`
	SystemLevelCounters *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters `path:"system-level-counters" module:"openconfig-network-instance"`
	TrafficEngineering  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering  `path:"traffic-engineering" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LevelNumber == nil {
		return nil, fmt.Errorf("nil value for key LevelNumber")
	}

	return map[string]interface{}{
		"level-number": *t.LevelNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config   `path:"config" module:"openconfig-network-instance"`
	Key      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key      `path:"key" module:"openconfig-network-instance"`
	Keychain *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain `path:"keychain" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config struct {
	CsnpAuthentication *bool `path:"csnp-authentication" module:"openconfig-network-instance"`
	LspAuthentication  *bool `path:"lsp-authentication" module:"openconfig-network-instance"`
	PsnpAuthentication *bool `path:"psnp-authentication" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/key YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/key/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config struct {
	AuthPassword *string `path:"auth-password" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/key/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State struct {
	AuthPassword *string `path:"auth-password" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Key_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/keychain YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain struct {
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_Keychain) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State struct {
	CsnpAuthentication *bool `path:"csnp-authentication" module:"openconfig-network-instance"`
	LspAuthentication  *bool `path:"lsp-authentication" module:"openconfig-network-instance"`
	PsnpAuthentication *bool `path:"psnp-authentication" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config struct {
	AuthenticationCheck *bool                        `path:"authentication-check" module:"openconfig-network-instance"`
	Enabled             *bool                        `path:"enabled" module:"openconfig-network-instance"`
	LevelNumber         *uint8                       `path:"level-number" module:"openconfig-network-instance"`
	MetricStyle         E_OpenconfigIsis_MetricStyle `path:"metric-style" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase struct {
	Lsp map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp `path:"lsp" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase) IsYANGGoStruct() {
}

// NewLsp creates a new entry in the Lsp list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase) NewLsp(LspId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Lsp == nil {
		t.Lsp = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp)
	}

	key := LspId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Lsp[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Lsp", key)
	}

	t.Lsp[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp{
		LspId: &LspId,
	}

	return t.Lsp[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp struct {
	LspId         *string                                                                                                                              `path:"lsp-id" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State         `path:"state" module:"openconfig-network-instance"`
	Tlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs          `path:"tlvs" module:"openconfig-network-instance"`
	UndefinedTlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs `path:"undefined-tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LspId == nil {
		return nil, fmt.Errorf("nil value for key LspId")
	}

	return map[string]interface{}{
		"lsp-id": *t.LspId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State struct {
	Checksum             *uint16                                                                                                                               `path:"checksum" module:"openconfig-network-instance"`
	Flags                []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags `path:"flags" module:"openconfig-network-instance"`
	IdLength             *uint8                                                                                                                                `path:"id-length" module:"openconfig-network-instance"`
	IsType               *uint8                                                                                                                                `path:"is-type" module:"openconfig-network-instance"`
	LspId                *string                                                                                                                               `path:"lsp-id" module:"openconfig-network-instance"`
	MaximumAreaAddresses *uint8                                                                                                                                `path:"maximum-area-addresses" module:"openconfig-network-instance"`
	PduLength            *uint16                                                                                                                               `path:"pdu-length" module:"openconfig-network-instance"`
	PduType              E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType `path:"pdu-type" module:"openconfig-network-instance"`
	RemainingLifetime    *uint16                                                                                                                               `path:"remaining-lifetime" module:"openconfig-network-instance"`
	SequenceNumber       *uint32                                                                                                                               `path:"sequence-number" module:"openconfig-network-instance"`
	Version              *uint8                                                                                                                                `path:"version" module:"openconfig-network-instance"`
	Version2             *uint8                                                                                                                                `path:"version2" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs struct {
	Tlv map[E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs) IsYANGGoStruct() {
}

// NewTlv creates a new entry in the Tlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs) NewTlv(Type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Tlv == nil {
		t.Tlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Tlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Tlv", key)
	}

	t.Tlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv{
		Type: Type,
	}

	return t.Tlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv struct {
	AreaAddress              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress              `path:"area-address" module:"openconfig-network-instance"`
	Authentication           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication           `path:"authentication" module:"openconfig-network-instance"`
	ExtendedIpv4Reachability *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability `path:"extended-ipv4-reachability" module:"openconfig-network-instance"`
	ExtendedIsReachability   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability   `path:"extended-is-reachability" module:"openconfig-network-instance"`
	Hostname                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname                 `path:"hostname" module:"openconfig-network-instance"`
	InstanceIds              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds              `path:"instance-ids" module:"openconfig-network-instance"`
	Ipv4ExternalReachability *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability `path:"ipv4-external-reachability" module:"openconfig-network-instance"`
	Ipv4InterfaceAddresses   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses   `path:"ipv4-interface-addresses" module:"openconfig-network-instance"`
	Ipv4InternalReachability *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability `path:"ipv4-internal-reachability" module:"openconfig-network-instance"`
	Ipv4Srlgs                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs                `path:"ipv4-srlgs" module:"openconfig-network-instance"`
	Ipv4TeRouterId           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId           `path:"ipv4-te-router-id" module:"openconfig-network-instance"`
	Ipv6InterfaceAddresses   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses   `path:"ipv6-interface-addresses" module:"openconfig-network-instance"`
	Ipv6Reachability         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability         `path:"ipv6-reachability" module:"openconfig-network-instance"`
	Ipv6Srlgs                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs                `path:"ipv6-srlgs" module:"openconfig-network-instance"`
	Ipv6TeRouterId           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId           `path:"ipv6-te-router-id" module:"openconfig-network-instance"`
	IsAliasId                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId                `path:"is-alias-id" module:"openconfig-network-instance"`
	IsReachability           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability           `path:"is-reachability" module:"openconfig-network-instance"`
	IsisNeighborAttribute    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute    `path:"isis-neighbor-attribute" module:"openconfig-network-instance"`
	LspBufferSize            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize            `path:"lsp-buffer-size" module:"openconfig-network-instance"`
	MtIpv4Reachability       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability       `path:"mt-ipv4-reachability" module:"openconfig-network-instance"`
	MtIpv6Reachability       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability       `path:"mt-ipv6-reachability" module:"openconfig-network-instance"`
	MtIsisNeighborAttribute  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute  `path:"mt-isis-neighbor-attribute" module:"openconfig-network-instance"`
	MtIsn                    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn                    `path:"mt-isn" module:"openconfig-network-instance"`
	MultiTopology            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology            `path:"multi-topology" module:"openconfig-network-instance"`
	Nlpid                    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid                    `path:"nlpid" module:"openconfig-network-instance"`
	PurgeOi                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi                  `path:"purge-oi" module:"openconfig-network-instance"`
	RouterCapabilities       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities       `path:"router-capabilities" module:"openconfig-network-instance"`
	State                    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State                    `path:"state" module:"openconfig-network-instance"`
	Type                     E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE                                                                                                                  `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/area-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/area-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_AreaAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/authentication YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/authentication/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State struct {
	AuthenticationKey *string                                                                                                                                                          `path:"authentication-key" module:"openconfig-network-instance"`
	CryptoType        E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType `path:"crypto-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability struct {
	Prefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes struct {
	Prefix map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes) IsYANGGoStruct() {
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes) NewPrefix(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix struct {
	Prefix           *string                                                                                                                                                                                   `path:"prefix" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
	Prefix *string `path:"prefix" module:"openconfig-network-instance"`
	SBit   *bool   `path:"s-bit" module:"openconfig-network-instance"`
	UpDown *bool   `path:"up-down" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct {
	Flags              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags              `path:"flags" module:"openconfig-network-instance"`
	Ipv4SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	Ipv6SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	PrefixSids         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids         `path:"prefix-sids" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State              `path:"state" module:"openconfig-network-instance"`
	Tag                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag                `path:"tag" module:"openconfig-network-instance"`
	Tag64              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64              `path:"tag64" module:"openconfig-network-instance"`
	Type               E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                 `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State struct {
	Flags []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                   `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct {
	PrefixSid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid `path:"prefix-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) NewPrefixSid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                            `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State struct {
	Algorithm *uint8                                                                                                                                                                                                                      `path:"algorithm" module:"openconfig-network-instance"`
	Flags     []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value     *uint32                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag64/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State struct {
	Tag64 []uint64 `path:"tag64" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State struct {
	Tag32 []uint32 `path:"tag32" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                          `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability struct {
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors) NewNeighbor(SystemId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor{
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor struct {
	Instances *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances `path:"instances" module:"openconfig-network-instance"`
	State     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State     `path:"state" module:"openconfig-network-instance"`
	SystemId  *string                                                                                                                                                                             `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances struct {
	Instance map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance `path:"instance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances) IsYANGGoStruct() {
}

// NewInstance creates a new entry in the Instance list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances) NewInstance(Id uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance struct {
	Id               *uint64                                                                                                                                                                                                       `path:"id" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State struct {
	Id     *uint64 `path:"id" module:"openconfig-network-instance"`
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct {
	AdjacencySids              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids              `path:"adjacency-sids" module:"openconfig-network-instance"`
	AdminGroup                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup                 `path:"admin-group" module:"openconfig-network-instance"`
	AvailableBandwidth         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth         `path:"available-bandwidth" module:"openconfig-network-instance"`
	BandwidthConstraints       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints       `path:"bandwidth-constraints" module:"openconfig-network-instance"`
	ExtendedAdminGroup         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup         `path:"extended-admin-group" module:"openconfig-network-instance"`
	Ipv4InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress       `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	Ipv4NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress        `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	Ipv6InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress       `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	Ipv6NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress        `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	LanAdjacencySids           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids           `path:"lan-adjacency-sids" module:"openconfig-network-instance"`
	LinkAttributes             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes             `path:"link-attributes" module:"openconfig-network-instance"`
	LinkDelay                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay                  `path:"link-delay" module:"openconfig-network-instance"`
	LinkDelayVariation         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation         `path:"link-delay-variation" module:"openconfig-network-instance"`
	LinkId                     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId                     `path:"link-id" module:"openconfig-network-instance"`
	LinkLoss                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss                   `path:"link-loss" module:"openconfig-network-instance"`
	LinkProtectionType         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType         `path:"link-protection-type" module:"openconfig-network-instance"`
	MaxLinkBandwidth           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth           `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	MaxReservableLinkBandwidth *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	MinMaxLinkDelay            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay            `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ResidualBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth          `path:"residual-bandwidth" module:"openconfig-network-instance"`
	State                      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State                      `path:"state" module:"openconfig-network-instance"`
	TeDefaultMetric            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric            `path:"te-default-metric" module:"openconfig-network-instance"`
	Type                       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                                             `path:"type" module:"openconfig-network-instance"`
	UnconstrainedLsp           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp           `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	UnreservedBandwidth        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth        `path:"unreserved-bandwidth" module:"openconfig-network-instance"`
	UtilizedBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth          `path:"utilized-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct {
	AdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) NewAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                                      `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State struct {
	Flags  []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value  *uint32                                                                                                                                                                                                                                               `path:"value" module:"openconfig-network-instance"`
	Weight *uint8                                                                                                                                                                                                                                                `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State struct {
	AdminGroup []uint32 `path:"admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct {
	BandwidthConstraint map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint `path:"bandwidth-constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) IsYANGGoStruct() {
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) NewBandwidthConstraint(ModelId uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct {
	Constraints *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints `path:"constraints" module:"openconfig-network-instance"`
	ModelId     *uint8                                                                                                                                                                                                                                                           `path:"model-id" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct {
	Constraint map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint `path:"constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) NewConstraint(ConstraintId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct {
	ConstraintId *uint32                                                                                                                                                                                                                                                                           `path:"constraint-id" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State struct {
	Bandwidth    Binary  `path:"bandwidth" module:"openconfig-network-instance"`
	ConstraintId *uint32 `path:"constraint-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State struct {
	ModelId *uint8 `path:"model-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State struct {
	ExtendedAdminGroup []uint32 `path:"extended-admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct {
	LanAdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid `path:"lan-adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) IsYANGGoStruct() {
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) NewLanAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                                            `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State struct {
	Flags      []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	NeighborId *string                                                                                                                                                                                                                                                     `path:"neighbor-id" module:"openconfig-network-instance"`
	Value      *uint32                                                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
	Weight     *uint8                                                                                                                                                                                                                                                      `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State struct {
	LocalProtection []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection `path:"local-protection" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State struct {
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State struct {
	ABit  *bool   `path:"a-bit" module:"openconfig-network-instance"`
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State struct {
	Local  *uint32 `path:"local" module:"openconfig-network-instance"`
	Remote *uint32 `path:"remote" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	LinkLoss *uint32 `path:"link-loss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State struct {
	Type []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	MaxDelay *uint32 `path:"max-delay" module:"openconfig-network-instance"`
	MinDelay *uint32 `path:"min-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State struct {
	Count *uint16                                    `path:"count" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct {
	SetupPriority map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority `path:"setup-priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) IsYANGGoStruct() {
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) NewSetupPriority(Priority uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct {
	Priority *uint8                                                                                                                                                                                                                                              `path:"priority" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
	Priority  *uint8 `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                                              `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State struct {
	SystemId *string `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/hostname YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/hostname/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State struct {
	Hostname []string `path:"hostname" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Hostname_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/instance-ids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds struct {
	InstanceId map[uint16]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId `path:"instance-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds) IsYANGGoStruct() {
}

// NewInstanceId creates a new entry in the InstanceId list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds) NewInstanceId(InstanceId uint16) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InstanceId == nil {
		t.InstanceId = make(map[uint16]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId)
	}

	key := InstanceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.InstanceId[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list InstanceId", key)
	}

	t.InstanceId[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId{
		InstanceId: &InstanceId,
	}

	return t.InstanceId[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/instance-ids/instance-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId struct {
	InstanceId *uint16                                                                                                                                                      `path:"instance-id" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceId == nil {
		return nil, fmt.Errorf("nil value for key InstanceId")
	}

	return map[string]interface{}{
		"instance-id": *t.InstanceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/instance-ids/instance-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State struct {
	InstanceId *uint16  `path:"instance-id" module:"openconfig-network-instance"`
	TopologyId []uint16 `path:"topology-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_InstanceIds_InstanceId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability struct {
	Prefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes struct {
	Prefix map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes) IsYANGGoStruct() {
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes) NewPrefix(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix struct {
	DefaultMetric *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric `path:"default-metric" module:"openconfig-network-instance"`
	DelayMetric   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric   `path:"delay-metric" module:"openconfig-network-instance"`
	ErrorMetric   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric   `path:"error-metric" module:"openconfig-network-instance"`
	ExpenseMetric *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric `path:"expense-metric" module:"openconfig-network-instance"`
	Prefix        *string                                                                                                                                                                                `path:"prefix" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State struct {
	Flags  E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                                                                                                                                                                                              `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/delay-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/delay-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DelayMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/error-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/error-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ErrorMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/expense-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/expense-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_ExpenseMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State struct {
	Prefix *string `path:"prefix" module:"openconfig-network-instance"`
	UpDown *bool   `path:"up-down" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-interface-addresses YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-interface-addresses/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InterfaceAddresses_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability struct {
	Prefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes struct {
	Prefix map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes) IsYANGGoStruct() {
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes) NewPrefix(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix struct {
	DefaultMetric *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric `path:"default-metric" module:"openconfig-network-instance"`
	DelayMetric   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric   `path:"delay-metric" module:"openconfig-network-instance"`
	ErrorMetric   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric   `path:"error-metric" module:"openconfig-network-instance"`
	ExpenseMetric *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric `path:"expense-metric" module:"openconfig-network-instance"`
	Prefix        *string                                                                                                                                                                                `path:"prefix" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State         `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State struct {
	Flags  E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                                                                                                                                                                                              `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/delay-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/delay-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_DelayMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/error-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/error-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ErrorMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/expense-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/expense-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_ExpenseMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State struct {
	Prefix *string `path:"prefix" module:"openconfig-network-instance"`
	UpDown *bool   `path:"up-down" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4InternalReachability_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-srlgs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs struct {
	Ipv4Srlg map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg `path:"ipv4-srlg" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs) IsYANGGoStruct() {
}

// NewIpv4Srlg creates a new entry in the Ipv4Srlg list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs) NewIpv4Srlg(InstanceNumber uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv4Srlg == nil {
		t.Ipv4Srlg = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg)
	}

	key := InstanceNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv4Srlg[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv4Srlg", key)
	}

	t.Ipv4Srlg[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg{
		InstanceNumber: &InstanceNumber,
	}

	return t.Ipv4Srlg[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-srlgs/ipv4-srlg YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg struct {
	InstanceNumber *uint32                                                                                                                                                  `path:"instance-number" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceNumber == nil {
		return nil, fmt.Errorf("nil value for key InstanceNumber")
	}

	return map[string]interface{}{
		"instance-number": *t.InstanceNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-srlgs/ipv4-srlg/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State struct {
	Flags                []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags `path:"flags" module:"openconfig-network-instance"`
	InstanceNumber       *uint32                                                                                                                                                           `path:"instance-number" module:"openconfig-network-instance"`
	Ipv4InterfaceAddress *string                                                                                                                                                           `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	Ipv4NeighborAddress  *string                                                                                                                                                           `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	PsnNumber            *uint8                                                                                                                                                            `path:"psn-number" module:"openconfig-network-instance"`
	SrlgValue            []uint32                                                                                                                                                          `path:"srlg-value" module:"openconfig-network-instance"`
	SystemId             *string                                                                                                                                                           `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-te-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-te-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State struct {
	RouterId []string `path:"router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4TeRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-interface-addresses YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-interface-addresses/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6InterfaceAddresses_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability struct {
	Prefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes struct {
	Prefix map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes) IsYANGGoStruct() {
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes) NewPrefix(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix{
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix struct {
	Prefix           *string                                                                                                                                                                           `path:"prefix" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
	Prefix *string `path:"prefix" module:"openconfig-network-instance"`
	SBit   *bool   `path:"s-bit" module:"openconfig-network-instance"`
	UpDown *bool   `path:"up-down" module:"openconfig-network-instance"`
	XBit   *bool   `path:"x-bit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct {
	Flags              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags              `path:"flags" module:"openconfig-network-instance"`
	Ipv4SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	Ipv6SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	PrefixSids         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids         `path:"prefix-sids" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State              `path:"state" module:"openconfig-network-instance"`
	Tag                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag                `path:"tag" module:"openconfig-network-instance"`
	Tag64              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64              `path:"tag64" module:"openconfig-network-instance"`
	Type               E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                         `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State struct {
	Flags []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                   `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct {
	PrefixSid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid `path:"prefix-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) NewPrefixSid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                    `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State struct {
	Algorithm *uint8                                                                                                                                                                                                                      `path:"algorithm" module:"openconfig-network-instance"`
	Flags     []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value     *uint32                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag64/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State struct {
	Tag64 []uint64 `path:"tag64" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State struct {
	Tag32 []uint32 `path:"tag32" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                  `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-srlgs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs struct {
	Ipv6Srlg map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg `path:"ipv6-srlg" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs) IsYANGGoStruct() {
}

// NewIpv6Srlg creates a new entry in the Ipv6Srlg list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs) NewIpv6Srlg(InstanceNumber uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Ipv6Srlg == nil {
		t.Ipv6Srlg = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg)
	}

	key := InstanceNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Ipv6Srlg[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Ipv6Srlg", key)
	}

	t.Ipv6Srlg[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg{
		InstanceNumber: &InstanceNumber,
	}

	return t.Ipv6Srlg[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-srlgs/ipv6-srlg YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg struct {
	InstanceNumber *uint32                                                                                                                                                  `path:"instance-number" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceNumber == nil {
		return nil, fmt.Errorf("nil value for key InstanceNumber")
	}

	return map[string]interface{}{
		"instance-number": *t.InstanceNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-srlgs/ipv6-srlg/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State struct {
	Flags                []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags `path:"flags" module:"openconfig-network-instance"`
	InstanceNumber       *uint32                                                                                                                                                           `path:"instance-number" module:"openconfig-network-instance"`
	Ipv6InterfaceAddress *string                                                                                                                                                           `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	Ipv6NeighborAddress  *string                                                                                                                                                           `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	PsnNumber            *uint8                                                                                                                                                            `path:"psn-number" module:"openconfig-network-instance"`
	SrlgValue            []uint32                                                                                                                                                          `path:"srlg-value" module:"openconfig-network-instance"`
	SystemId             *string                                                                                                                                                           `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-te-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-te-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State struct {
	RouterId []string `path:"router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6TeRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-alias-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-alias-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State struct {
	AliasId *string `path:"alias-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsAliasId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability struct {
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors) NewNeighbor(SystemId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor{
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor struct {
	DefaultMetric *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric `path:"default-metric" module:"openconfig-network-instance"`
	DelayMetric   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric   `path:"delay-metric" module:"openconfig-network-instance"`
	ErrorMetric   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric   `path:"error-metric" module:"openconfig-network-instance"`
	ExpenseMetric *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric `path:"expense-metric" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State         `path:"state" module:"openconfig-network-instance"`
	SystemId      *string                                                                                                                                                                         `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State struct {
	Flags  E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                                                                                                                                                                                              `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/delay-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/delay-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_DelayMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/error-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/error-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ErrorMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/expense-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/expense-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State struct {
	Flags  []E_OpenconfigIsis_IsisMetricFlags `path:"flags" module:"openconfig-network-instance"`
	Metric *uint8                             `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_ExpenseMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State struct {
	SystemId *string `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsReachability_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute struct {
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors) NewNeighbor(SystemId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor)
	}

	key := SystemId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor{
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor struct {
	Instances *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances `path:"instances" module:"openconfig-network-instance"`
	State     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State     `path:"state" module:"openconfig-network-instance"`
	SystemId  *string                                                                                                                                                                            `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances struct {
	Instance map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance `path:"instance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances) IsYANGGoStruct() {
}

// NewInstance creates a new entry in the Instance list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances) NewInstance(Id uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance struct {
	Id               *uint64                                                                                                                                                                                                      `path:"id" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State struct {
	Id     *uint64 `path:"id" module:"openconfig-network-instance"`
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct {
	AdjacencySids              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids              `path:"adjacency-sids" module:"openconfig-network-instance"`
	AdminGroup                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup                 `path:"admin-group" module:"openconfig-network-instance"`
	AvailableBandwidth         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth         `path:"available-bandwidth" module:"openconfig-network-instance"`
	BandwidthConstraints       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints       `path:"bandwidth-constraints" module:"openconfig-network-instance"`
	ExtendedAdminGroup         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup         `path:"extended-admin-group" module:"openconfig-network-instance"`
	Ipv4InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress       `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	Ipv4NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress        `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	Ipv6InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress       `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	Ipv6NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress        `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	LanAdjacencySids           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids           `path:"lan-adjacency-sids" module:"openconfig-network-instance"`
	LinkAttributes             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes             `path:"link-attributes" module:"openconfig-network-instance"`
	LinkDelay                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay                  `path:"link-delay" module:"openconfig-network-instance"`
	LinkDelayVariation         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation         `path:"link-delay-variation" module:"openconfig-network-instance"`
	LinkId                     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId                     `path:"link-id" module:"openconfig-network-instance"`
	LinkLoss                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss                   `path:"link-loss" module:"openconfig-network-instance"`
	LinkProtectionType         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType         `path:"link-protection-type" module:"openconfig-network-instance"`
	MaxLinkBandwidth           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth           `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	MaxReservableLinkBandwidth *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	MinMaxLinkDelay            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay            `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ResidualBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth          `path:"residual-bandwidth" module:"openconfig-network-instance"`
	State                      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State                      `path:"state" module:"openconfig-network-instance"`
	TeDefaultMetric            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric            `path:"te-default-metric" module:"openconfig-network-instance"`
	Type                       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                                            `path:"type" module:"openconfig-network-instance"`
	UnconstrainedLsp           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp           `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	UnreservedBandwidth        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth        `path:"unreserved-bandwidth" module:"openconfig-network-instance"`
	UtilizedBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth          `path:"utilized-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct {
	AdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) NewAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State struct {
	Flags  []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value  *uint32                                                                                                                                                                                                                                               `path:"value" module:"openconfig-network-instance"`
	Weight *uint8                                                                                                                                                                                                                                                `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State struct {
	AdminGroup []uint32 `path:"admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct {
	BandwidthConstraint map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint `path:"bandwidth-constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) IsYANGGoStruct() {
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) NewBandwidthConstraint(ModelId uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct {
	Constraints *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints `path:"constraints" module:"openconfig-network-instance"`
	ModelId     *uint8                                                                                                                                                                                                                                                          `path:"model-id" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct {
	Constraint map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint `path:"constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) NewConstraint(ConstraintId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct {
	ConstraintId *uint32                                                                                                                                                                                                                                                                          `path:"constraint-id" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State struct {
	Bandwidth    Binary  `path:"bandwidth" module:"openconfig-network-instance"`
	ConstraintId *uint32 `path:"constraint-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State struct {
	ModelId *uint8 `path:"model-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State struct {
	ExtendedAdminGroup []uint32 `path:"extended-admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct {
	LanAdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid `path:"lan-adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) IsYANGGoStruct() {
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) NewLanAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                                           `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State struct {
	Flags      []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	NeighborId *string                                                                                                                                                                                                                                                     `path:"neighbor-id" module:"openconfig-network-instance"`
	Value      *uint32                                                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
	Weight     *uint8                                                                                                                                                                                                                                                      `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State struct {
	LocalProtection []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection `path:"local-protection" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State struct {
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State struct {
	ABit  *bool   `path:"a-bit" module:"openconfig-network-instance"`
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State struct {
	Local  *uint32 `path:"local" module:"openconfig-network-instance"`
	Remote *uint32 `path:"remote" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	LinkLoss *uint32 `path:"link-loss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State struct {
	Type []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	MaxDelay *uint32 `path:"max-delay" module:"openconfig-network-instance"`
	MinDelay *uint32 `path:"min-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State struct {
	Count *uint16                                    `path:"count" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct {
	SetupPriority map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority `path:"setup-priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) IsYANGGoStruct() {
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) NewSetupPriority(Priority uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct {
	Priority *uint8                                                                                                                                                                                                                                             `path:"priority" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
	Priority  *uint8 `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                                             `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State struct {
	SystemId *string `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_IsisNeighborAttribute_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/lsp-buffer-size YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/lsp-buffer-size/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State struct {
	Size *uint16 `path:"size" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_LspBufferSize_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability struct {
	Prefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes struct {
	Prefix map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Key represents the key for list Prefix of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Key struct {
	MtId   uint16 `path:"mt-id"`
	Prefix string `path:"prefix"`
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes) NewPrefix(MtId uint16, Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Key{
		MtId:   MtId,
		Prefix: Prefix,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix{
		MtId:   &MtId,
		Prefix: &Prefix,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix struct {
	MtId             *uint16                                                                                                                                                                             `path:"mt-id" module:"openconfig-network-instance"`
	Prefix           *string                                                                                                                                                                             `path:"prefix" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"mt-id":  *t.MtId,
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
	MtId   *uint16 `path:"mt-id" module:"openconfig-network-instance"`
	Prefix *string `path:"prefix" module:"openconfig-network-instance"`
	SBit   *bool   `path:"s-bit" module:"openconfig-network-instance"`
	UpDown *bool   `path:"up-down" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct {
	Flags              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags              `path:"flags" module:"openconfig-network-instance"`
	Ipv4SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	Ipv6SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	PrefixSids         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids         `path:"prefix-sids" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State              `path:"state" module:"openconfig-network-instance"`
	Tag                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag                `path:"tag" module:"openconfig-network-instance"`
	Tag64              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64              `path:"tag64" module:"openconfig-network-instance"`
	Type               E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                           `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State struct {
	Flags []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                   `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct {
	PrefixSid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid `path:"prefix-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) NewPrefixSid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                      `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State struct {
	Algorithm *uint8                                                                                                                                                                                                                      `path:"algorithm" module:"openconfig-network-instance"`
	Flags     []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value     *uint32                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag64/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State struct {
	Tag64 []uint64 `path:"tag64" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/tag/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State struct {
	Tag32 []uint32 `path:"tag32" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                    `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv4Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability struct {
	Prefixes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes `path:"prefixes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes struct {
	Prefix map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix `path:"prefix" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Key represents the key for list Prefix of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Key struct {
	Prefix string `path:"prefix"`
	MtId   uint16 `path:"mt-id"`
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes) NewPrefix(Prefix string, MtId uint16) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Key{
		Prefix: Prefix,
		MtId:   MtId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix{
		Prefix: &Prefix,
		MtId:   &MtId,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix struct {
	MtId             *uint16                                                                                                                                                                             `path:"mt-id" module:"openconfig-network-instance"`
	Prefix           *string                                                                                                                                                                             `path:"prefix" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"mt-id":  *t.MtId,
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
	MtId   *uint16 `path:"mt-id" module:"openconfig-network-instance"`
	Prefix *string `path:"prefix" module:"openconfig-network-instance"`
	SBit   *bool   `path:"s-bit" module:"openconfig-network-instance"`
	UpDown *bool   `path:"up-down" module:"openconfig-network-instance"`
	XBit   *bool   `path:"x-bit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct {
	Flags              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags              `path:"flags" module:"openconfig-network-instance"`
	Ipv4SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId `path:"ipv4-source-router-id" module:"openconfig-network-instance"`
	Ipv6SourceRouterId *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId `path:"ipv6-source-router-id" module:"openconfig-network-instance"`
	PrefixSids         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids         `path:"prefix-sids" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State              `path:"state" module:"openconfig-network-instance"`
	Tag                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag                `path:"tag" module:"openconfig-network-instance"`
	Tag64              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64              `path:"tag64" module:"openconfig-network-instance"`
	Type               E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                           `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State struct {
	Flags []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                   `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv4SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State struct {
	RouterId *string                                    `path:"router-id" module:"openconfig-network-instance"`
	Type     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Ipv6SourceRouterId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct {
	PrefixSid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid `path:"prefix-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) IsYANGGoStruct() {
}

// NewPrefixSid creates a new entry in the PrefixSid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) NewPrefixSid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSid == nil {
		t.PrefixSid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSid", key)
	}

	t.PrefixSid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid{
		Value: &Value,
	}

	return t.PrefixSid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                      `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State struct {
	Algorithm *uint8                                                                                                                                                                                                                      `path:"algorithm" module:"openconfig-network-instance"`
	Flags     []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value     *uint32                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag64 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag64/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State struct {
	Tag64 []uint64 `path:"tag64" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag64_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/tag/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State struct {
	Tag32 []uint32 `path:"tag32" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Tag_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                    `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIpv6Reachability_Prefixes_Prefix_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute struct {
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors struct {
	Neighbor map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Key represents the key for list Neighbor of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Key struct {
	MtId     uint16 `path:"mt-id"`
	SystemId string `path:"system-id"`
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors) NewNeighbor(MtId uint16, SystemId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor{
		MtId:     &MtId,
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor struct {
	Instances *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances `path:"instances" module:"openconfig-network-instance"`
	MtId      *uint16                                                                                                                                                                              `path:"mt-id" module:"openconfig-network-instance"`
	State     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State     `path:"state" module:"openconfig-network-instance"`
	SystemId  *string                                                                                                                                                                              `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"mt-id":     *t.MtId,
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances struct {
	Instance map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance `path:"instance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances) IsYANGGoStruct() {
}

// NewInstance creates a new entry in the Instance list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances) NewInstance(Id uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance struct {
	Id               *uint64                                                                                                                                                                                                        `path:"id" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State struct {
	Id     *uint64 `path:"id" module:"openconfig-network-instance"`
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct {
	AdjacencySids              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids              `path:"adjacency-sids" module:"openconfig-network-instance"`
	AdminGroup                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup                 `path:"admin-group" module:"openconfig-network-instance"`
	AvailableBandwidth         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth         `path:"available-bandwidth" module:"openconfig-network-instance"`
	BandwidthConstraints       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints       `path:"bandwidth-constraints" module:"openconfig-network-instance"`
	ExtendedAdminGroup         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup         `path:"extended-admin-group" module:"openconfig-network-instance"`
	Ipv4InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress       `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	Ipv4NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress        `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	Ipv6InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress       `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	Ipv6NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress        `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	LanAdjacencySids           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids           `path:"lan-adjacency-sids" module:"openconfig-network-instance"`
	LinkAttributes             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes             `path:"link-attributes" module:"openconfig-network-instance"`
	LinkDelay                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay                  `path:"link-delay" module:"openconfig-network-instance"`
	LinkDelayVariation         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation         `path:"link-delay-variation" module:"openconfig-network-instance"`
	LinkId                     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId                     `path:"link-id" module:"openconfig-network-instance"`
	LinkLoss                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss                   `path:"link-loss" module:"openconfig-network-instance"`
	LinkProtectionType         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType         `path:"link-protection-type" module:"openconfig-network-instance"`
	MaxLinkBandwidth           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth           `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	MaxReservableLinkBandwidth *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	MinMaxLinkDelay            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay            `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ResidualBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth          `path:"residual-bandwidth" module:"openconfig-network-instance"`
	State                      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State                      `path:"state" module:"openconfig-network-instance"`
	TeDefaultMetric            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric            `path:"te-default-metric" module:"openconfig-network-instance"`
	Type                       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                                              `path:"type" module:"openconfig-network-instance"`
	UnconstrainedLsp           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp           `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	UnreservedBandwidth        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth        `path:"unreserved-bandwidth" module:"openconfig-network-instance"`
	UtilizedBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth          `path:"utilized-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct {
	AdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) NewAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                                       `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State struct {
	Flags  []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value  *uint32                                                                                                                                                                                                                                               `path:"value" module:"openconfig-network-instance"`
	Weight *uint8                                                                                                                                                                                                                                                `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State struct {
	AdminGroup []uint32 `path:"admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct {
	BandwidthConstraint map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint `path:"bandwidth-constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) IsYANGGoStruct() {
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) NewBandwidthConstraint(ModelId uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct {
	Constraints *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints `path:"constraints" module:"openconfig-network-instance"`
	ModelId     *uint8                                                                                                                                                                                                                                                            `path:"model-id" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct {
	Constraint map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint `path:"constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) NewConstraint(ConstraintId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct {
	ConstraintId *uint32                                                                                                                                                                                                                                                                            `path:"constraint-id" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State struct {
	Bandwidth    Binary  `path:"bandwidth" module:"openconfig-network-instance"`
	ConstraintId *uint32 `path:"constraint-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State struct {
	ModelId *uint8 `path:"model-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State struct {
	ExtendedAdminGroup []uint32 `path:"extended-admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct {
	LanAdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid `path:"lan-adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) IsYANGGoStruct() {
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) NewLanAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                                             `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State struct {
	Flags      []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	NeighborId *string                                                                                                                                                                                                                                                     `path:"neighbor-id" module:"openconfig-network-instance"`
	Value      *uint32                                                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
	Weight     *uint8                                                                                                                                                                                                                                                      `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State struct {
	LocalProtection []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection `path:"local-protection" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State struct {
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State struct {
	ABit  *bool   `path:"a-bit" module:"openconfig-network-instance"`
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State struct {
	Local  *uint32 `path:"local" module:"openconfig-network-instance"`
	Remote *uint32 `path:"remote" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	LinkLoss *uint32 `path:"link-loss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State struct {
	Type []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	MaxDelay *uint32 `path:"max-delay" module:"openconfig-network-instance"`
	MinDelay *uint32 `path:"min-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State struct {
	Count *uint16                                    `path:"count" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct {
	SetupPriority map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority `path:"setup-priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) IsYANGGoStruct() {
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) NewSetupPriority(Priority uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct {
	Priority *uint8                                                                                                                                                                                                                                               `path:"priority" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
	Priority  *uint8 `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                                               `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State struct {
	MtId     *uint16 `path:"mt-id" module:"openconfig-network-instance"`
	SystemId *string `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsisNeighborAttribute_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn struct {
	Neighbors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors `path:"neighbors" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors struct {
	Neighbor map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Key represents the key for list Neighbor of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Key struct {
	MtId     uint16 `path:"mt-id"`
	SystemId string `path:"system-id"`
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors) NewNeighbor(MtId uint16, SystemId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Key{
		MtId:     MtId,
		SystemId: SystemId,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor{
		MtId:     &MtId,
		SystemId: &SystemId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor struct {
	Instances *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances `path:"instances" module:"openconfig-network-instance"`
	MtId      *uint16                                                                                                                                                            `path:"mt-id" module:"openconfig-network-instance"`
	State     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State     `path:"state" module:"openconfig-network-instance"`
	SystemId  *string                                                                                                                                                            `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	if t.SystemId == nil {
		return nil, fmt.Errorf("nil value for key SystemId")
	}

	return map[string]interface{}{
		"mt-id":     *t.MtId,
		"system-id": *t.SystemId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances struct {
	Instance map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance `path:"instance" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances) IsYANGGoStruct() {
}

// NewInstance creates a new entry in the Instance list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances) NewInstance(Id uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Instance == nil {
		t.Instance = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Instance[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Instance", key)
	}

	t.Instance[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance{
		Id: &Id,
	}

	return t.Instance[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance struct {
	Id               *uint64                                                                                                                                                                                      `path:"id" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State struct {
	Id     *uint64 `path:"id" module:"openconfig-network-instance"`
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct {
	AdjacencySids              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids              `path:"adjacency-sids" module:"openconfig-network-instance"`
	AdminGroup                 *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup                 `path:"admin-group" module:"openconfig-network-instance"`
	AvailableBandwidth         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth         `path:"available-bandwidth" module:"openconfig-network-instance"`
	BandwidthConstraints       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints       `path:"bandwidth-constraints" module:"openconfig-network-instance"`
	ExtendedAdminGroup         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup         `path:"extended-admin-group" module:"openconfig-network-instance"`
	Ipv4InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress       `path:"ipv4-interface-address" module:"openconfig-network-instance"`
	Ipv4NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress        `path:"ipv4-neighbor-address" module:"openconfig-network-instance"`
	Ipv6InterfaceAddress       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress       `path:"ipv6-interface-address" module:"openconfig-network-instance"`
	Ipv6NeighborAddress        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress        `path:"ipv6-neighbor-address" module:"openconfig-network-instance"`
	LanAdjacencySids           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids           `path:"lan-adjacency-sids" module:"openconfig-network-instance"`
	LinkAttributes             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes             `path:"link-attributes" module:"openconfig-network-instance"`
	LinkDelay                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay                  `path:"link-delay" module:"openconfig-network-instance"`
	LinkDelayVariation         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation         `path:"link-delay-variation" module:"openconfig-network-instance"`
	LinkId                     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId                     `path:"link-id" module:"openconfig-network-instance"`
	LinkLoss                   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss                   `path:"link-loss" module:"openconfig-network-instance"`
	LinkProtectionType         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType         `path:"link-protection-type" module:"openconfig-network-instance"`
	MaxLinkBandwidth           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth           `path:"max-link-bandwidth" module:"openconfig-network-instance"`
	MaxReservableLinkBandwidth *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth `path:"max-reservable-link-bandwidth" module:"openconfig-network-instance"`
	MinMaxLinkDelay            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay            `path:"min-max-link-delay" module:"openconfig-network-instance"`
	ResidualBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth          `path:"residual-bandwidth" module:"openconfig-network-instance"`
	State                      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State                      `path:"state" module:"openconfig-network-instance"`
	TeDefaultMetric            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric            `path:"te-default-metric" module:"openconfig-network-instance"`
	Type                       E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                                            `path:"type" module:"openconfig-network-instance"`
	UnconstrainedLsp           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp           `path:"unconstrained-lsp" module:"openconfig-network-instance"`
	UnreservedBandwidth        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth        `path:"unreserved-bandwidth" module:"openconfig-network-instance"`
	UtilizedBandwidth          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth          `path:"utilized-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct {
	AdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) IsYANGGoStruct() {
}

// NewAdjacencySid creates a new entry in the AdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) NewAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdjacencySid == nil {
		t.AdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdjacencySid", key)
	}

	t.AdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid{
		Value: &Value,
	}

	return t.AdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State struct {
	Flags  []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	Value  *uint32                                                                                                                                                                                                                                               `path:"value" module:"openconfig-network-instance"`
	Weight *uint8                                                                                                                                                                                                                                                `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State struct {
	AdminGroup []uint32 `path:"admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AvailableBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct {
	BandwidthConstraint map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint `path:"bandwidth-constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) IsYANGGoStruct() {
}

// NewBandwidthConstraint creates a new entry in the BandwidthConstraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) NewBandwidthConstraint(ModelId uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.BandwidthConstraint == nil {
		t.BandwidthConstraint = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint)
	}

	key := ModelId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.BandwidthConstraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list BandwidthConstraint", key)
	}

	t.BandwidthConstraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint{
		ModelId: &ModelId,
	}

	return t.BandwidthConstraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct {
	Constraints *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints `path:"constraints" module:"openconfig-network-instance"`
	ModelId     *uint8                                                                                                                                                                                                                                          `path:"model-id" module:"openconfig-network-instance"`
	State       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State       `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ModelId == nil {
		return nil, fmt.Errorf("nil value for key ModelId")
	}

	return map[string]interface{}{
		"model-id": *t.ModelId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct {
	Constraint map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint `path:"constraint" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) IsYANGGoStruct() {
}

// NewConstraint creates a new entry in the Constraint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) NewConstraint(ConstraintId uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Constraint == nil {
		t.Constraint = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint)
	}

	key := ConstraintId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Constraint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Constraint", key)
	}

	t.Constraint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint{
		ConstraintId: &ConstraintId,
	}

	return t.Constraint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct {
	ConstraintId *uint32                                                                                                                                                                                                                                                          `path:"constraint-id" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.ConstraintId == nil {
		return nil, fmt.Errorf("nil value for key ConstraintId")
	}

	return map[string]interface{}{
		"constraint-id": *t.ConstraintId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/constraints/constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State struct {
	Bandwidth    Binary  `path:"bandwidth" module:"openconfig-network-instance"`
	ConstraintId *uint32 `path:"constraint-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_Constraints_Constraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/bandwidth-constraints/bandwidth-constraint/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State struct {
	ModelId *uint8 `path:"model-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_BandwidthConstraints_BandwidthConstraint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/extended-admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State struct {
	ExtendedAdminGroup []uint32 `path:"extended-admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ExtendedAdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv4-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv4NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-interface-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6InterfaceAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/ipv6-neighbor-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State struct {
	Address []string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_Ipv6NeighborAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct {
	LanAdjacencySid map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid `path:"lan-adjacency-sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) IsYANGGoStruct() {
}

// NewLanAdjacencySid creates a new entry in the LanAdjacencySid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) NewLanAdjacencySid(Value uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LanAdjacencySid == nil {
		t.LanAdjacencySid = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid)
	}

	key := Value

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LanAdjacencySid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LanAdjacencySid", key)
	}

	t.LanAdjacencySid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid{
		Value: &Value,
	}

	return t.LanAdjacencySid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State `path:"state" module:"openconfig-network-instance"`
	Value *uint32                                                                                                                                                                                                                           `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Value == nil {
		return nil, fmt.Errorf("nil value for key Value")
	}

	return map[string]interface{}{
		"value": *t.Value,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State struct {
	Flags      []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags `path:"flags" module:"openconfig-network-instance"`
	NeighborId *string                                                                                                                                                                                                                                                     `path:"neighbor-id" module:"openconfig-network-instance"`
	Value      *uint32                                                                                                                                                                                                                                                     `path:"value" module:"openconfig-network-instance"`
	Weight     *uint8                                                                                                                                                                                                                                                      `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State struct {
	LocalProtection []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection `path:"local-protection" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay-variation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State struct {
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelayVariation_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State struct {
	ABit  *bool   `path:"a-bit" module:"openconfig-network-instance"`
	Delay *uint32 `path:"delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-id/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State struct {
	Local  *uint32 `path:"local" module:"openconfig-network-instance"`
	Remote *uint32 `path:"remote" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkId_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-loss/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	LinkLoss *uint32 `path:"link-loss" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkLoss_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State struct {
	Type []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/max-reservable-link-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MaxReservableLinkBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/min-max-link-delay/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State struct {
	ABit     *bool   `path:"a-bit" module:"openconfig-network-instance"`
	MaxDelay *uint32 `path:"max-delay" module:"openconfig-network-instance"`
	MinDelay *uint32 `path:"min-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_MinMaxLinkDelay_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/residual-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_ResidualBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/te-default-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_TeDefaultMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State struct {
	Count *uint16                                    `path:"count" module:"openconfig-network-instance"`
	Type  E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnconstrainedLsp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct {
	SetupPriority map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority `path:"setup-priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) IsYANGGoStruct() {
}

// NewSetupPriority creates a new entry in the SetupPriority list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) NewSetupPriority(Priority uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SetupPriority == nil {
		t.SetupPriority = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SetupPriority[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SetupPriority", key)
	}

	t.SetupPriority[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority{
		Priority: &Priority,
	}

	return t.SetupPriority[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct {
	Priority *uint8                                                                                                                                                                                                                             `path:"priority" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unreserved-bandwidth/setup-priority/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State struct {
	Bandwidth Binary `path:"bandwidth" module:"openconfig-network-instance"`
	Priority  *uint8 `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UnreservedBandwidth_SetupPriority_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State struct {
	Bandwidth Binary                                     `path:"bandwidth" module:"openconfig-network-instance"`
	Type      E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_UtilizedBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                                             `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_Instances_Instance_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State struct {
	MtId     *uint16 `path:"mt-id" module:"openconfig-network-instance"`
	SystemId *string `path:"system-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MtIsn_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology struct {
	Topologies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies `path:"topologies" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology/topologies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies struct {
	Topology map[uint16]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology `path:"topology" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies) IsYANGGoStruct() {
}

// NewTopology creates a new entry in the Topology list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies) NewTopology(MtId uint16) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Topology == nil {
		t.Topology = make(map[uint16]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology)
	}

	key := MtId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Topology[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Topology", key)
	}

	t.Topology[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology{
		MtId: &MtId,
	}

	return t.Topology[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology/topologies/topology YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology struct {
	MtId  *uint16                                                                                                                                                                 `path:"mt-id" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology) ΛListKeyMap() (map[string]interface{}, error) {
	if t.MtId == nil {
		return nil, fmt.Errorf("nil value for key MtId")
	}

	return map[string]interface{}{
		"mt-id": *t.MtId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology/topologies/topology/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State struct {
	Attributes E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes `path:"attributes" module:"openconfig-network-instance"`
	MtId       *uint16                                                                                                                                                                             `path:"mt-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/nlpid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/nlpid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State struct {
	Nlpid []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid `path:"nlpid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/purge-oi YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/purge-oi/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State struct {
	ReceivedSystemId *string `path:"received-system-id" module:"openconfig-network-instance"`
	SourceSystemId   *string `path:"source-system-id" module:"openconfig-network-instance"`
	SystemIdCount    *uint8  `path:"system-id-count" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_PurgeOi_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities struct {
	Capability map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability `path:"capability" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities) IsYANGGoStruct() {
}

// NewCapability creates a new entry in the Capability list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities) NewCapability(InstanceNumber uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Capability == nil {
		t.Capability = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability)
	}

	key := InstanceNumber

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Capability[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Capability", key)
	}

	t.Capability[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability{
		InstanceNumber: &InstanceNumber,
	}

	return t.Capability[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability struct {
	InstanceNumber   *uint32                                                                                                                                                                        `path:"instance-number" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State            `path:"state" module:"openconfig-network-instance"`
	Subtlvs          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs          `path:"subtlvs" module:"openconfig-network-instance"`
	UndefinedSubtlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs `path:"undefined-subtlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InstanceNumber == nil {
		return nil, fmt.Errorf("nil value for key InstanceNumber")
	}

	return map[string]interface{}{
		"instance-number": *t.InstanceNumber,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State struct {
	Flags          []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags `path:"flags" module:"openconfig-network-instance"`
	InstanceNumber *uint32                                                                                                                                                                      `path:"instance-number" module:"openconfig-network-instance"`
	RouterId       *string                                                                                                                                                                      `path:"router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs struct {
	Subtlv map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv `path:"subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs) IsYANGGoStruct() {
}

// NewSubtlv creates a new entry in the Subtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs) NewSubtlv(Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subtlv == nil {
		t.Subtlv = make(map[E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subtlv", key)
	}

	t.Subtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv{
		Type: Type,
	}

	return t.Subtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv struct {
	SegmentRoutingAlgorithms *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms `path:"segment-routing-algorithms" module:"openconfig-network-instance"`
	SegmentRoutingCapability *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability `path:"segment-routing-capability" module:"openconfig-network-instance"`
	State                    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State                    `path:"state" module:"openconfig-network-instance"`
	Type                     E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE                                                                                                                                                            `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-algorithms YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-algorithms/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State struct {
	Algorithm []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm `path:"algorithm" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability struct {
	SrgbDescriptors *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors `path:"srgb-descriptors" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors struct {
	SrgbDescriptor map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor `path:"srgb-descriptor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors) IsYANGGoStruct() {
}

// NewSrgbDescriptor creates a new entry in the SrgbDescriptor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors) NewSrgbDescriptor(Range uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SrgbDescriptor == nil {
		t.SrgbDescriptor = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor)
	}

	key := Range

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SrgbDescriptor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SrgbDescriptor", key)
	}

	t.SrgbDescriptor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor{
		Range: &Range,
	}

	return t.SrgbDescriptor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor struct {
	Range *uint32                                                                                                                                                                                                                                    `path:"range" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Range == nil {
		return nil, fmt.Errorf("nil value for key Range")
	}

	return map[string]interface{}{
		"range": *t.Range,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State struct {
	Label OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union `path:"label" module:"openconfig-network-instance"`
	Range *uint32                                                                                                                                                                                                                                               `path:"range" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state/label within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state/label
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state/label
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State struct {
	Flags []E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags `path:"flags" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/undefined-subtlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs struct {
	UndefinedSubtlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv `path:"undefined-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs) IsYANGGoStruct() {
}

// NewUndefinedSubtlv creates a new entry in the UndefinedSubtlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs) NewUndefinedSubtlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedSubtlv == nil {
		t.UndefinedSubtlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedSubtlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedSubtlv", key)
	}

	t.UndefinedSubtlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv{
		Type: &Type,
	}

	return t.UndefinedSubtlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/undefined-subtlvs/undefined-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                                                               `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/undefined-subtlvs/undefined-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_UndefinedSubtlvs_UndefinedSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State struct {
	Type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/undefined-tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs struct {
	UndefinedTlv map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv `path:"undefined-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs) IsYANGGoStruct() {
}

// NewUndefinedTlv creates a new entry in the UndefinedTlv list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs) NewUndefinedTlv(Type uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UndefinedTlv == nil {
		t.UndefinedTlv = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UndefinedTlv[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UndefinedTlv", key)
	}

	t.UndefinedTlv[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv{
		Type: &Type,
	}

	return t.UndefinedTlv[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/undefined-tlvs/undefined-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State `path:"state" module:"openconfig-network-instance"`
	Type  *uint8                                                                                                                                                  `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Type == nil {
		return nil, fmt.Errorf("nil value for key Type")
	}

	return map[string]interface{}{
		"type": *t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/undefined-tlvs/undefined-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State struct {
	Length *uint8 `path:"length" module:"openconfig-network-instance"`
	Type   *uint8 `path:"type" module:"openconfig-network-instance"`
	Value  Binary `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_UndefinedTlvs_UndefinedTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/route-preference YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/route-preference/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config struct {
	ExternalRoutePreference *uint8 `path:"external-route-preference" module:"openconfig-network-instance"`
	InternalRoutePreference *uint8 `path:"internal-route-preference" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/route-preference/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State struct {
	ExternalRoutePreference *uint8 `path:"external-route-preference" module:"openconfig-network-instance"`
	InternalRoutePreference *uint8 `path:"internal-route-preference" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_RoutePreference_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State struct {
	AuthenticationCheck *bool                        `path:"authentication-check" module:"openconfig-network-instance"`
	Enabled             *bool                        `path:"enabled" module:"openconfig-network-instance"`
	LevelNumber         *uint8                       `path:"level-number" module:"openconfig-network-instance"`
	MetricStyle         E_OpenconfigIsis_MetricStyle `path:"metric-style" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/system-level-counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/system-level-counters/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State struct {
	AuthFails                  *uint32 `path:"auth-fails" module:"openconfig-network-instance"`
	AuthTypeFails              *uint32 `path:"auth-type-fails" module:"openconfig-network-instance"`
	CorruptedLsps              *uint32 `path:"corrupted-lsps" module:"openconfig-network-instance"`
	DatabaseOverloads          *uint32 `path:"database-overloads" module:"openconfig-network-instance"`
	ExceedMaxSeqNums           *uint32 `path:"exceed-max-seq-nums" module:"openconfig-network-instance"`
	IdLenMismatch              *uint32 `path:"id-len-mismatch" module:"openconfig-network-instance"`
	LspErrors                  *uint32 `path:"lsp-errors" module:"openconfig-network-instance"`
	ManualAddressDropFromAreas *uint32 `path:"manual-address-drop-from-areas" module:"openconfig-network-instance"`
	MaxAreaAddressMismatches   *uint32 `path:"max-area-address-mismatches" module:"openconfig-network-instance"`
	OwnLspPurges               *uint32 `path:"own-lsp-purges" module:"openconfig-network-instance"`
	PartChanges                *uint32 `path:"part-changes" module:"openconfig-network-instance"`
	SeqNumSkips                *uint32 `path:"seq-num-skips" module:"openconfig-network-instance"`
	SpfRuns                    *uint32 `path:"spf-runs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_SystemLevelCounters_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/traffic-engineering YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/traffic-engineering/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config struct {
	Enabled      *bool   `path:"enabled" module:"openconfig-network-instance"`
	Ipv4RouterId *string `path:"ipv4-router-id" module:"openconfig-network-instance"`
	Ipv6RouterId *string `path:"ipv6-router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/isis/levels/level/traffic-engineering/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State struct {
	Enabled      *bool   `path:"enabled" module:"openconfig-network-instance"`
	Ipv4RouterId *string `path:"ipv4-router-id" module:"openconfig-network-instance"`
	Ipv6RouterId *string `path:"ipv6-router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_TrafficEngineering_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates struct {
	Aggregate map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate `path:"aggregate" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates) IsYANGGoStruct() {
}

// NewAggregate creates a new entry in the Aggregate list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates) NewAggregate(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Aggregate == nil {
		t.Aggregate = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Aggregate[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Aggregate", key)
	}

	t.Aggregate[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate{
		Prefix: &Prefix,
	}

	return t.Aggregate[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config `path:"config" module:"openconfig-network-instance"`
	Prefix *string                                                                                                         `path:"prefix" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config struct {
	Description *string                                                                                                                     `path:"description" module:"openconfig-network-instance"`
	Discard     *bool                                                                                                                       `path:"discard" module:"openconfig-network-instance"`
	Prefix      *string                                                                                                                     `path:"prefix" module:"openconfig-network-instance"`
	SetTag      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union `path:"set-tag" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/config/set-tag within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/config/set-tag
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/config/set-tag
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_Config_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State struct {
	Description *string                                                                                                                    `path:"description" module:"openconfig-network-instance"`
	Discard     *bool                                                                                                                      `path:"discard" module:"openconfig-network-instance"`
	Prefix      *string                                                                                                                    `path:"prefix" module:"openconfig-network-instance"`
	SetTag      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union `path:"set-tag" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/state/set-tag within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/state/set-tag
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/local-aggregates/aggregate/state/set-tag
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_LocalAggregates_Aggregate_State_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2 represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2 YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2 struct {
	Areas  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas  `path:"areas" module:"openconfig-network-instance"`
	Global *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global `path:"global" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2 implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas struct {
	Area map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area `path:"area" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas) IsYANGGoStruct() {
}

// NewArea creates a new entry in the Area list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas) NewArea(Identifier OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Area == nil {
		t.Area = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area)
	}

	key := Identifier

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Area[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Area", key)
	}

	t.Area[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area{
		Identifier: Identifier,
	}

	return t.Area[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config                 `path:"config" module:"openconfig-network-instance"`
	Identifier   OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"identifier" module:"openconfig-network-instance"`
	Interfaces   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces             `path:"interfaces" module:"openconfig-network-instance"`
	Lsdb         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb                   `path:"lsdb" module:"openconfig-network-instance"`
	Mpls         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls                   `path:"mpls" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State                  `path:"state" module:"openconfig-network-instance"`
	VirtualLinks *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks           `path:"virtual-links" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"identifier": t.Identifier,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/identifier within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/identifier
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/identifier
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config struct {
	Identifier OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"identifier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces) NewInterface(Id string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface{
		Id: &Id,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config       `path:"config" module:"openconfig-network-instance"`
	EnableBfd    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd    `path:"enable-bfd" module:"openconfig-network-instance"`
	Id           *string                                                                                                                            `path:"id" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	LsaFilter    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter    `path:"lsa-filter" module:"openconfig-network-instance"`
	Mpls         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls         `path:"mpls" module:"openconfig-network-instance"`
	Neighbors    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors    `path:"neighbors" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State        `path:"state" module:"openconfig-network-instance"`
	Timers       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers       `path:"timers" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config struct {
	AuthenticationType        *string                                 `path:"authentication-type" module:"openconfig-network-instance"`
	HideNetwork               *bool                                   `path:"hide-network" module:"openconfig-network-instance"`
	Id                        *string                                 `path:"id" module:"openconfig-network-instance"`
	Metric                    *uint16                                 `path:"metric" module:"openconfig-network-instance"`
	MultiAreaAdjacencyPrimary *bool                                   `path:"multi-area-adjacency-primary" module:"openconfig-network-instance"`
	NetworkType               E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE `path:"network-type" module:"openconfig-network-instance"`
	Passive                   *bool                                   `path:"passive" module:"openconfig-network-instance"`
	Priority                  *uint8                                  `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/enable-bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/enable-bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/enable-bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/lsa-filter YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/lsa-filter/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config struct {
	All *bool `path:"all" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/lsa-filter/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State struct {
	All *bool `path:"all" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_LsaFilter_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls struct {
	Config     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config     `path:"config" module:"openconfig-network-instance"`
	IgpLdpSync *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State      `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config struct {
	TrafficEngineeringMetric *uint32 `path:"traffic-engineering-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls/igp-ldp-sync YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls/igp-ldp-sync/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint32 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls/igp-ldp-sync/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint32 `path:"post-session-up-delay" module:"openconfig-network-instance"`
	Synchronized       *bool   `path:"synchronized" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_IgpLdpSync_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/mpls/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State struct {
	TrafficEngineeringMetric *uint32 `path:"traffic-engineering-metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Mpls_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors) NewNeighbor(RouterId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor)
	}

	key := RouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor{
		RouterId: &RouterId,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config `path:"config" module:"openconfig-network-instance"`
	RouterId *string                                                                                                                                         `path:"router-id" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RouterId == nil {
		return nil, fmt.Errorf("nil value for key RouterId")
	}

	return map[string]interface{}{
		"router-id": *t.RouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors/neighbor/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config struct {
	Metric   *uint16 `path:"metric" module:"openconfig-network-instance"`
	RouterId *string `path:"router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State struct {
	AdjacencyState           E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE `path:"adjacency-state" module:"openconfig-network-instance"`
	BackupDesignatedRouter   *string                                   `path:"backup-designated-router" module:"openconfig-network-instance"`
	DeadTime                 *uint64                                   `path:"dead-time" module:"openconfig-network-instance"`
	DesignatedRouter         *string                                   `path:"designated-router" module:"openconfig-network-instance"`
	LastEstablishedTime      *uint64                                   `path:"last-established-time" module:"openconfig-network-instance"`
	Metric                   *uint16                                   `path:"metric" module:"openconfig-network-instance"`
	OptionalCapabilities     *string                                   `path:"optional-capabilities" module:"openconfig-network-instance"`
	Priority                 *uint8                                    `path:"priority" module:"openconfig-network-instance"`
	RetranmissionQueueLength *uint32                                   `path:"retranmission-queue-length" module:"openconfig-network-instance"`
	RouterId                 *string                                   `path:"router-id" module:"openconfig-network-instance"`
	StateChanges             *uint32                                   `path:"state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State struct {
	AuthenticationType        *string                                 `path:"authentication-type" module:"openconfig-network-instance"`
	HideNetwork               *bool                                   `path:"hide-network" module:"openconfig-network-instance"`
	Id                        *string                                 `path:"id" module:"openconfig-network-instance"`
	Metric                    *uint16                                 `path:"metric" module:"openconfig-network-instance"`
	MultiAreaAdjacencyPrimary *bool                                   `path:"multi-area-adjacency-primary" module:"openconfig-network-instance"`
	NetworkType               E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE `path:"network-type" module:"openconfig-network-instance"`
	Passive                   *bool                                   `path:"passive" module:"openconfig-network-instance"`
	Priority                  *uint8                                  `path:"priority" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/timers/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config struct {
	DeadInterval           *uint32 `path:"dead-interval" module:"openconfig-network-instance"`
	HelloInterval          *uint32 `path:"hello-interval" module:"openconfig-network-instance"`
	RetransmissionInterval *uint32 `path:"retransmission-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/timers/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State struct {
	DeadInterval           *uint32 `path:"dead-interval" module:"openconfig-network-instance"`
	HelloInterval          *uint32 `path:"hello-interval" module:"openconfig-network-instance"`
	RetransmissionInterval *uint32 `path:"retransmission-interval" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Interfaces_Interface_Timers_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb struct {
	LsaTypes *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes `path:"lsa-types" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes struct {
	LsaType map[E_OpenconfigOspfTypes_OSPF_LSA_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType `path:"lsa-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes) IsYANGGoStruct() {
}

// NewLsaType creates a new entry in the LsaType list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes) NewLsaType(Type E_OpenconfigOspfTypes_OSPF_LSA_TYPE) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.LsaType == nil {
		t.LsaType = make(map[E_OpenconfigOspfTypes_OSPF_LSA_TYPE]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType)
	}

	key := Type

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.LsaType[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list LsaType", key)
	}

	t.LsaType[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType{
		Type: Type,
	}

	return t.LsaType[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType struct {
	Lsas  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas  `path:"lsas" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State `path:"state" module:"openconfig-network-instance"`
	Type  E_OpenconfigOspfTypes_OSPF_LSA_TYPE                                                                                          `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"type": t.Type,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas struct {
	Lsa map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa `path:"lsa" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas) IsYANGGoStruct() {
}

// NewLsa creates a new entry in the Lsa list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas) NewLsa(LinkStateId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Lsa == nil {
		t.Lsa = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa)
	}

	key := LinkStateId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Lsa[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Lsa", key)
	}

	t.Lsa[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa{
		LinkStateId: &LinkStateId,
	}

	return t.Lsa[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa struct {
	AsExternalLsa   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa   `path:"as-external-lsa" module:"openconfig-network-instance"`
	LinkStateId     *string                                                                                                                                         `path:"link-state-id" module:"openconfig-network-instance"`
	NetworkLsa      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa      `path:"network-lsa" module:"openconfig-network-instance"`
	NssaExternalLsa *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa `path:"nssa-external-lsa" module:"openconfig-network-instance"`
	OpaqueLsa       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa       `path:"opaque-lsa" module:"openconfig-network-instance"`
	RouterLsa       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa       `path:"router-lsa" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State           `path:"state" module:"openconfig-network-instance"`
	SummaryLsa      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa      `path:"summary-lsa" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LinkStateId == nil {
		return nil, fmt.Errorf("nil value for key LinkStateId")
	}

	return map[string]interface{}{
		"link-state-id": *t.LinkStateId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa struct {
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State          `path:"state" module:"openconfig-network-instance"`
	TypesOfService *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService `path:"types-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State struct {
	ExternalRouteTag  *uint32                                                                                                                                                         `path:"external-route-tag" module:"openconfig-network-instance"`
	ForwardingAddress *string                                                                                                                                                         `path:"forwarding-address" module:"openconfig-network-instance"`
	Mask              *uint8                                                                                                                                                          `path:"mask" module:"openconfig-network-instance"`
	Metric            *uint16                                                                                                                                                         `path:"metric" module:"openconfig-network-instance"`
	MetricType        E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType `path:"metric-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/types-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService struct {
	TypeOfService map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService `path:"type-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService) IsYANGGoStruct() {
}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService) NewTypeOfService(Tos uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/types-of-service/type-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State `path:"state" module:"openconfig-network-instance"`
	Tos   *uint8                                                                                                                                                                           `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/types-of-service/type-of-service/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State struct {
	ExternalRouteTag  *uint32 `path:"external-route-tag" module:"openconfig-network-instance"`
	ForwardingAddress *string `path:"forwarding-address" module:"openconfig-network-instance"`
	Metric            *uint16 `path:"metric" module:"openconfig-network-instance"`
	Tos               *uint8  `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_TypesOfService_TypeOfService_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/network-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/network-lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State struct {
	AttachedRouter []string `path:"attached-router" module:"openconfig-network-instance"`
	NetworkMask    *uint8   `path:"network-mask" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NetworkLsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa struct {
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State          `path:"state" module:"openconfig-network-instance"`
	TypesOfService *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService `path:"types-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State struct {
	ExternalRouteTag  *uint32                                                                                                                                                         `path:"external-route-tag" module:"openconfig-network-instance"`
	ForwardingAddress *string                                                                                                                                                         `path:"forwarding-address" module:"openconfig-network-instance"`
	Mask              *uint8                                                                                                                                                          `path:"mask" module:"openconfig-network-instance"`
	Metric            *uint16                                                                                                                                                         `path:"metric" module:"openconfig-network-instance"`
	MetricType        E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType `path:"metric-type" module:"openconfig-network-instance"`
	Propagate         *bool                                                                                                                                                           `path:"propagate" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/types-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService struct {
	TypeOfService map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService `path:"type-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService) IsYANGGoStruct() {
}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService) NewTypeOfService(Tos uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/types-of-service/type-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State `path:"state" module:"openconfig-network-instance"`
	Tos   *uint8                                                                                                                                                                             `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/types-of-service/type-of-service/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State struct {
	ExternalRouteTag  *uint32 `path:"external-route-tag" module:"openconfig-network-instance"`
	ForwardingAddress *string `path:"forwarding-address" module:"openconfig-network-instance"`
	Metric            *uint16 `path:"metric" module:"openconfig-network-instance"`
	Tos               *uint8  `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_NssaExternalLsa_TypesOfService_TypeOfService_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa struct {
	ExtendedLink       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink       `path:"extended-link" module:"openconfig-network-instance"`
	ExtendedPrefix     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix     `path:"extended-prefix" module:"openconfig-network-instance"`
	GraceLsa           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa           `path:"grace-lsa" module:"openconfig-network-instance"`
	RouterInformation  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation  `path:"router-information" module:"openconfig-network-instance"`
	State              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State              `path:"state" module:"openconfig-network-instance"`
	TrafficEngineering *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering `path:"traffic-engineering" module:"openconfig-network-instance"`
	UnknownTlv         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv         `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State `path:"state" module:"openconfig-network-instance"`
	Tlvs  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs  `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State struct {
	LinkData OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union `path:"link-data" module:"openconfig-network-instance"`
	LinkId   *string                                                                                                                                                                    `path:"link-id" module:"openconfig-network-instance"`
	LinkType E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE                                                                                                                              `path:"link-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state/link-data within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state/link-data
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state/link-data
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_State_LinkData_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv struct {
	AdjacencySid *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid `path:"adjacency-sid" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State        `path:"state" module:"openconfig-network-instance"`
	UnknownTlv   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv   `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/adjacency-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/adjacency-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State struct {
	Backup                  *bool                        `path:"backup" module:"openconfig-network-instance"`
	Group                   *bool                        `path:"group" module:"openconfig-network-instance"`
	MultiTopologyIdentifier *uint8                       `path:"multi-topology-identifier" module:"openconfig-network-instance"`
	SidType                 E_OpenconfigOspfv2_SrSidType `path:"sid-type" module:"openconfig-network-instance"`
	SidValue                *uint32                      `path:"sid-value" module:"openconfig-network-instance"`
	Weight                  *uint8                       `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_AdjacencySid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State struct {
	Type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedLink_Tlvs_Tlv_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State `path:"state" module:"openconfig-network-instance"`
	Tlvs  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs  `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State struct {
	AddressFamily E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily `path:"address-family" module:"openconfig-network-instance"`
	Attached      *bool                                                                                                                                                                         `path:"attached" module:"openconfig-network-instance"`
	Node          *bool                                                                                                                                                                         `path:"node" module:"openconfig-network-instance"`
	Prefix        *string                                                                                                                                                                       `path:"prefix" module:"openconfig-network-instance"`
	PrefixLength  *uint8                                                                                                                                                                        `path:"prefix-length" module:"openconfig-network-instance"`
	RouteType     E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType     `path:"route-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv struct {
	ExtendedPrefixRange *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange `path:"extended-prefix-range" module:"openconfig-network-instance"`
	PrefixSid           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid           `path:"prefix-sid" module:"openconfig-network-instance"`
	SidLabelBinding     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding     `path:"sid-label-binding" module:"openconfig-network-instance"`
	State               *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State               `path:"state" module:"openconfig-network-instance"`
	UnknownTlv          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv          `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/extended-prefix-range YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/extended-prefix-range/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State struct {
	AddressFamily E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily `path:"address-family" module:"openconfig-network-instance"`
	InterArea     *bool                                                                                                                                                                         `path:"inter-area" module:"openconfig-network-instance"`
	Prefix        *string                                                                                                                                                                       `path:"prefix" module:"openconfig-network-instance"`
	PrefixLength  *uint8                                                                                                                                                                        `path:"prefix-length" module:"openconfig-network-instance"`
	RangeSize     *uint16                                                                                                                                                                       `path:"range-size" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_ExtendedPrefixRange_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State struct {
	Algorithm               *uint8                                                                                                                                                                                          `path:"algorithm" module:"openconfig-network-instance"`
	ExplicitNull            *bool                                                                                                                                                                                           `path:"explicit-null" module:"openconfig-network-instance"`
	MappingServer           *bool                                                                                                                                                                                           `path:"mapping-server" module:"openconfig-network-instance"`
	MultiTopologyIdentifier *uint8                                                                                                                                                                                          `path:"multi-topology-identifier" module:"openconfig-network-instance"`
	NoPhp                   *bool                                                                                                                                                                                           `path:"no-php" module:"openconfig-network-instance"`
	SidScope                E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope     `path:"sid-scope" module:"openconfig-network-instance"`
	SidValue                *uint32                                                                                                                                                                                         `path:"sid-value" module:"openconfig-network-instance"`
	SidValueType            E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType `path:"sid-value-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State `path:"state" module:"openconfig-network-instance"`
	Tlvs  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs  `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State struct {
	Mirroring               *bool  `path:"mirroring" module:"openconfig-network-instance"`
	MultiTopologyIdentifier *uint8 `path:"multi-topology-identifier" module:"openconfig-network-instance"`
	Weight                  *uint8 `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv struct {
	EroMetric       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric       `path:"ero-metric" module:"openconfig-network-instance"`
	EroPath         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath         `path:"ero-path" module:"openconfig-network-instance"`
	SidLabelBinding *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding `path:"sid-label-binding" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State           `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State struct {
	Metric *uint32 `path:"metric" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath struct {
	Segments *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments `path:"segments" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments struct {
	Segment []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment `path:"segment" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment struct {
	Ipv4Segment   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment   `path:"ipv4-segment" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State         `path:"state" module:"openconfig-network-instance"`
	UnnumberedHop *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop `path:"unnumbered-hop" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/ipv4-segment YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/ipv4-segment/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State struct {
	Address *string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_Ipv4Segment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State struct {
	Loose *bool                                                                `path:"loose" module:"openconfig-network-instance"`
	Type  E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/unnumbered-hop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/unnumbered-hop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State struct {
	InterfaceId *uint32 `path:"interface-id" module:"openconfig-network-instance"`
	RouterId    *string `path:"router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_EroPath_Segments_Segment_UnnumberedHop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/sid-label-binding YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/sid-label-binding/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State struct {
	SidType  E_OpenconfigOspfv2_SrSidType `path:"sid-type" module:"openconfig-network-instance"`
	SidValue *uint32                      `path:"sid-value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_SidLabelBinding_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State struct {
	Type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_SidLabelBinding_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State struct {
	Type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa struct {
	Tlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv struct {
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State      `path:"state" module:"openconfig-network-instance"`
	UnknownTlv *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State struct {
	IpInterfaceAddress *string                                                                                                                                                                   `path:"ip-interface-address" module:"openconfig-network-instance"`
	Period             *uint32                                                                                                                                                                   `path:"period" module:"openconfig-network-instance"`
	Reason             E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason `path:"reason" module:"openconfig-network-instance"`
	Type               E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES                                                                                                                                 `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation struct {
	Tlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv struct {
	InformationalCapabilities   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities   `path:"informational-capabilities" module:"openconfig-network-instance"`
	NodeAdministrativeTags      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags      `path:"node-administrative-tags" module:"openconfig-network-instance"`
	SegmentRoutingAlgorithm     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm     `path:"segment-routing-algorithm" module:"openconfig-network-instance"`
	SegmentRoutingSidLabelRange *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange `path:"segment-routing-sid-label-range" module:"openconfig-network-instance"`
	State                       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State                       `path:"state" module:"openconfig-network-instance"`
	UnknownTlv                  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv                  `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/informational-capabilities YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/informational-capabilities/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State struct {
	ExperimentalTe         *bool `path:"experimental-te" module:"openconfig-network-instance"`
	GracefulRestartCapable *bool `path:"graceful-restart-capable" module:"openconfig-network-instance"`
	GracefulRestartHelper  *bool `path:"graceful-restart-helper" module:"openconfig-network-instance"`
	PointToPointOverLan    *bool `path:"point-to-point-over-lan" module:"openconfig-network-instance"`
	StubRouter             *bool `path:"stub-router" module:"openconfig-network-instance"`
	TrafficEngineering     *bool `path:"traffic-engineering" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_InformationalCapabilities_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/node-administrative-tags YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/node-administrative-tags/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State struct {
	AdministrativeTags []uint32 `path:"administrative-tags" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_NodeAdministrativeTags_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-algorithm YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-algorithm/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State struct {
	SupportedAlgorithms []E_OpenconfigOspfTypes_SR_ALGORITHM `path:"supported-algorithms" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingAlgorithm_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange struct {
	Tlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv struct {
	SidLabel   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel   `path:"sid-label" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State      `path:"state" module:"openconfig-network-instance"`
	UnknownTlv *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/sid-label YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/sid-label/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State struct {
	EntryType  E_OpenconfigOspfv2_SrSidType `path:"entry-type" module:"openconfig-network-instance"`
	FirstValue *uint32                      `path:"first-value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_SidLabel_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State struct {
	RangeSize *uint32                                                                                                                                                                                                                   `path:"range-size" module:"openconfig-network-instance"`
	Type      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state/type within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state/type
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state/type
// is to be set to a E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES struct {
	E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type{v}, nil
	case E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type, E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State struct {
	Type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state/type within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state/type
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state/type
// is to be set to a E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES struct {
	E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type{v}, nil
	case E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union_E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type, E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State struct {
	Scope E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope `path:"scope" module:"openconfig-network-instance"`
	Type  E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE                                                                                                             `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering struct {
	Tlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs `path:"tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs struct {
	Tlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv `path:"tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv struct {
	Link          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link          `path:"link" module:"openconfig-network-instance"`
	NodeAttribute *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute `path:"node-attribute" module:"openconfig-network-instance"`
	RouterAddress *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress `path:"router-address" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State         `path:"state" module:"openconfig-network-instance"`
	UnknownTlv    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv    `path:"unknown-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link struct {
	SubTlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs `path:"sub-tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs struct {
	SubTlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv `path:"sub-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv struct {
	AdministrativeGroups *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups `path:"administrative-groups" module:"openconfig-network-instance"`
	State                *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State                `path:"state" module:"openconfig-network-instance"`
	UnknownSubtlv        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv        `path:"unknown-subtlv" module:"openconfig-network-instance"`
	UnreservedBandwidths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths `path:"unreserved-bandwidths" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/administrative-groups YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups struct {
	AdminGroup map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup `path:"admin-group" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups) IsYANGGoStruct() {
}

// NewAdminGroup creates a new entry in the AdminGroup list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups) NewAdminGroup(BitIndex uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.AdminGroup == nil {
		t.AdminGroup = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup)
	}

	key := BitIndex

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.AdminGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list AdminGroup", key)
	}

	t.AdminGroup[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup{
		BitIndex: &BitIndex,
	}

	return t.AdminGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/administrative-groups/admin-group YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup struct {
	BitIndex *uint8                                                                                                                                                                                                                          `path:"bit-index" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.BitIndex == nil {
		return nil, fmt.Errorf("nil value for key BitIndex")
	}

	return map[string]interface{}{
		"bit-index": *t.BitIndex,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/administrative-groups/admin-group/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State struct {
	BitIndex *uint8 `path:"bit-index" module:"openconfig-network-instance"`
	Set      *bool  `path:"set" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_AdministrativeGroups_AdminGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State struct {
	LinkId                     *string                                                                                                                                                                                                   `path:"link-id" module:"openconfig-network-instance"`
	LinkType                   E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType `path:"link-type" module:"openconfig-network-instance"`
	LocalIpAddress             []string                                                                                                                                                                                                  `path:"local-ip-address" module:"openconfig-network-instance"`
	MaximumBandwidth           Binary                                                                                                                                                                                                    `path:"maximum-bandwidth" module:"openconfig-network-instance"`
	MaximumReservableBandwidth Binary                                                                                                                                                                                                    `path:"maximum-reservable-bandwidth" module:"openconfig-network-instance"`
	Metric                     *uint32                                                                                                                                                                                                   `path:"metric" module:"openconfig-network-instance"`
	RemoteIpAddress            []string                                                                                                                                                                                                  `path:"remote-ip-address" module:"openconfig-network-instance"`
	Type                       OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union `path:"type" module:"openconfig-network-instance"`
	UnknownType                *uint16                                                                                                                                                                                                   `path:"unknown-type" module:"openconfig-network-instance"`
	UnknownValue               Binary                                                                                                                                                                                                    `path:"unknown-value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/type within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/type
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/type
// is to be set to a E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE struct {
	E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type{v}, nil
	case E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type, E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unknown-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unknown-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnknownSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unreserved-bandwidths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths struct {
	UnreservedBandwidth map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth `path:"unreserved-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths) IsYANGGoStruct() {
}

// NewUnreservedBandwidth creates a new entry in the UnreservedBandwidth list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths) NewUnreservedBandwidth(Priority uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.UnreservedBandwidth == nil {
		t.UnreservedBandwidth = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth)
	}

	key := Priority

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.UnreservedBandwidth[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list UnreservedBandwidth", key)
	}

	t.UnreservedBandwidth[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth{
		Priority: &Priority,
	}

	return t.UnreservedBandwidth[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unreserved-bandwidths/unreserved-bandwidth YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth struct {
	Priority *uint8                                                                                                                                                                                                                                   `path:"priority" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Priority == nil {
		return nil, fmt.Errorf("nil value for key Priority")
	}

	return map[string]interface{}{
		"priority": *t.Priority,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/unreserved-bandwidths/unreserved-bandwidth/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State struct {
	Priority            *uint8 `path:"priority" module:"openconfig-network-instance"`
	UnreservedBandwidth Binary `path:"unreserved-bandwidth" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_UnreservedBandwidths_UnreservedBandwidth_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute struct {
	SubTlvs *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs `path:"sub-tlvs" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs struct {
	SubTlv []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv `path:"sub-tlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv struct {
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State         `path:"state" module:"openconfig-network-instance"`
	UnknownSubtlv *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv `path:"unknown-subtlv" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State struct {
	LocalIpv4Addresses []string                                                                                                                                                                                                           `path:"local-ipv4-addresses" module:"openconfig-network-instance"`
	LocalIpv6Addresses []string                                                                                                                                                                                                           `path:"local-ipv6-addresses" module:"openconfig-network-instance"`
	Type               OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state/type within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state/type
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state/type
// is to be set to a E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE struct {
	E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type{v}, nil
	case E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union_E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type, E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/unknown-subtlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/unknown-subtlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_UnknownSubtlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/router-address YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/router-address/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State struct {
	Address *string `path:"address" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_RouterAddress_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State struct {
	Type E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/unknown-tlv YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/unknown-tlv/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State struct {
	Length *uint16 `path:"length" module:"openconfig-network-instance"`
	Type   *uint16 `path:"type" module:"openconfig-network-instance"`
	Value  Binary  `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_UnknownTlv_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa struct {
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State          `path:"state" module:"openconfig-network-instance"`
	TypesOfService *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService `path:"types-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State struct {
	LinkData         OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union `path:"link-data" module:"openconfig-network-instance"`
	LinkId           *string                                                                                                                                                       `path:"link-id" module:"openconfig-network-instance"`
	Metric           *uint16                                                                                                                                                       `path:"metric" module:"openconfig-network-instance"`
	NumberLinks      *uint16                                                                                                                                                       `path:"number-links" module:"openconfig-network-instance"`
	NumberTosMetrics *uint16                                                                                                                                                       `path:"number-tos-metrics" module:"openconfig-network-instance"`
	Type             E_OpenconfigOspfTypes_ROUTER_LSA_TYPES                                                                                                                        `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state/link-data within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state/link-data
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state/link-data
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_State_LinkData_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/types-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService struct {
	TypeOfService map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService `path:"type-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService) IsYANGGoStruct() {
}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService) NewTypeOfService(Tos uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/types-of-service/type-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State `path:"state" module:"openconfig-network-instance"`
	Tos   *uint8                                                                                                                                                                       `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/types-of-service/type-of-service/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State struct {
	Metric *uint16 `path:"metric" module:"openconfig-network-instance"`
	Tos    *uint8  `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_RouterLsa_TypesOfService_TypeOfService_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State struct {
	AdvertisingRouter *string `path:"advertising-router" module:"openconfig-network-instance"`
	Age               *uint16 `path:"age" module:"openconfig-network-instance"`
	Checksum          *uint16 `path:"checksum" module:"openconfig-network-instance"`
	LinkStateId       *string `path:"link-state-id" module:"openconfig-network-instance"`
	SequenceNumber    *int32  `path:"sequence-number" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa struct {
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State          `path:"state" module:"openconfig-network-instance"`
	TypesOfService *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService `path:"types-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State struct {
	NetworkMask *uint8 `path:"network-mask" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa/types-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService struct {
	TypeOfService map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService `path:"type-of-service" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService) IsYANGGoStruct() {
}

// NewTypeOfService creates a new entry in the TypeOfService list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService) NewTypeOfService(Tos uint8) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TypeOfService == nil {
		t.TypeOfService = make(map[uint8]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService)
	}

	key := Tos

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TypeOfService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TypeOfService", key)
	}

	t.TypeOfService[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService{
		Tos: &Tos,
	}

	return t.TypeOfService[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa/types-of-service/type-of-service YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State `path:"state" module:"openconfig-network-instance"`
	Tos   *uint8                                                                                                                                                                        `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Tos == nil {
		return nil, fmt.Errorf("nil value for key Tos")
	}

	return map[string]interface{}{
		"tos": *t.Tos,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/summary-lsa/types-of-service/type-of-service/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State struct {
	Metric *uint16 `path:"metric" module:"openconfig-network-instance"`
	Tos    *uint8  `path:"tos" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_SummaryLsa_TypesOfService_TypeOfService_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State struct {
	Type E_OpenconfigOspfTypes_OSPF_LSA_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State struct {
	Identifier OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union `path:"identifier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/state/identifier within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/state/identifier
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/state/identifier
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_State_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/mpls/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config struct {
	TrafficEngineeringEnabled *bool `path:"traffic-engineering-enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/mpls/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State struct {
	TrafficEngineeringEnabled *bool `path:"traffic-engineering-enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Mpls_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State struct {
	Identifier OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union `path:"identifier" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/state/identifier within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/state/identifier
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/state/identifier
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_State_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks struct {
	VirtualLink map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink `path:"virtual-link" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks) IsYANGGoStruct() {
}

// NewVirtualLink creates a new entry in the VirtualLink list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks) NewVirtualLink(RemoteRouterId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.VirtualLink == nil {
		t.VirtualLink = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink)
	}

	key := RemoteRouterId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.VirtualLink[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list VirtualLink", key)
	}

	t.VirtualLink[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink{
		RemoteRouterId: &RemoteRouterId,
	}

	return t.VirtualLink[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links/virtual-link YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink struct {
	Config         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config `path:"config" module:"openconfig-network-instance"`
	RemoteRouterId *string                                                                                                                          `path:"remote-router-id" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink) ΛListKeyMap() (map[string]interface{}, error) {
	if t.RemoteRouterId == nil {
		return nil, fmt.Errorf("nil value for key RemoteRouterId")
	}

	return map[string]interface{}{
		"remote-router-id": *t.RemoteRouterId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links/virtual-link/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config struct {
	RemoteRouterId *string `path:"remote-router-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links/virtual-link/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State struct {
	AdjacencyState           E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE `path:"adjacency-state" module:"openconfig-network-instance"`
	BackupDesignatedRouter   *string                                   `path:"backup-designated-router" module:"openconfig-network-instance"`
	DeadTime                 *uint64                                   `path:"dead-time" module:"openconfig-network-instance"`
	DesignatedRouter         *string                                   `path:"designated-router" module:"openconfig-network-instance"`
	LastEstablishedTime      *uint64                                   `path:"last-established-time" module:"openconfig-network-instance"`
	OptionalCapabilities     *string                                   `path:"optional-capabilities" module:"openconfig-network-instance"`
	Priority                 *uint8                                    `path:"priority" module:"openconfig-network-instance"`
	RemoteRouterId           *string                                   `path:"remote-router-id" module:"openconfig-network-instance"`
	RetranmissionQueueLength *uint32                                   `path:"retranmission-queue-length" module:"openconfig-network-instance"`
	StateChanges             *uint32                                   `path:"state-changes" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_VirtualLinks_VirtualLink_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global struct {
	Config                       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config                       `path:"config" module:"openconfig-network-instance"`
	GracefulRestart              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart              `path:"graceful-restart" module:"openconfig-network-instance"`
	InterAreaPropagationPolicies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies `path:"inter-area-propagation-policies" module:"openconfig-network-instance"`
	Mpls                         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls                         `path:"mpls" module:"openconfig-network-instance"`
	State                        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State                        `path:"state" module:"openconfig-network-instance"`
	Timers                       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers                       `path:"timers" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config struct {
	HideTransitOnlyNetworks *bool                                                                                                                     `path:"hide-transit-only-networks" module:"openconfig-network-instance"`
	IgpShortcuts            *bool                                                                                                                     `path:"igp-shortcuts" module:"openconfig-network-instance"`
	LogAdjacencyChanges     *bool                                                                                                                     `path:"log-adjacency-changes" module:"openconfig-network-instance"`
	RouterId                *string                                                                                                                   `path:"router-id" module:"openconfig-network-instance"`
	SummaryRouteCostMode    E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode `path:"summary-route-cost-mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/graceful-restart YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/graceful-restart/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config struct {
	Enabled    *bool `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly *bool `path:"helper-only" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/graceful-restart/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State struct {
	Enabled    *bool `path:"enabled" module:"openconfig-network-instance"`
	HelperOnly *bool `path:"helper-only" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_GracefulRestart_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies struct {
	InterAreaPropagationPolicy map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy `path:"inter-area-propagation-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Key represents the key for list InterAreaPropagationPolicy of element /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Key struct {
	SrcArea OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"src-area"`
	DstArea OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"dst-area"`
}

// NewInterAreaPropagationPolicy creates a new entry in the InterAreaPropagationPolicy list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies) NewInterAreaPropagationPolicy(SrcArea OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, DstArea OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.InterAreaPropagationPolicy == nil {
		t.InterAreaPropagationPolicy = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Key{
		SrcArea: SrcArea,
		DstArea: DstArea,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.InterAreaPropagationPolicy[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list InterAreaPropagationPolicy", key)
	}

	t.InterAreaPropagationPolicy[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy{
		SrcArea: SrcArea,
		DstArea: DstArea,
	}

	return t.InterAreaPropagationPolicy[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config `path:"config" module:"openconfig-network-instance"`
	DstArea OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union                                     `path:"dst-area" module:"openconfig-network-instance"`
	SrcArea OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union                                     `path:"src-area" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"dst-area": t.DstArea,
		"src-area": t.SrcArea,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config struct {
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType                                                                             `path:"default-import-policy" module:"openconfig-network-instance"`
	DstArea             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"dst-area" module:"openconfig-network-instance"`
	ImportPolicy        []string                                                                                                                `path:"import-policy" module:"openconfig-network-instance"`
	SrcArea             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"src-area" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State struct {
	DefaultImportPolicy E_OpenconfigRoutingPolicy_DefaultPolicyType                                                                             `path:"default-import-policy" module:"openconfig-network-instance"`
	DstArea             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"dst-area" module:"openconfig-network-instance"`
	ImportPolicy        []string                                                                                                                `path:"import-policy" module:"openconfig-network-instance"`
	SrcArea             OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union `path:"src-area" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_InterAreaPropagationPolicies_InterAreaPropagationPolicy_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Config_Identifier_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls struct {
	Config     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config     `path:"config" module:"openconfig-network-instance"`
	IgpLdpSync *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync `path:"igp-ldp-sync" module:"openconfig-network-instance"`
	State      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State      `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config struct {
	TrafficEngineeringExtensions *bool `path:"traffic-engineering-extensions" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls/igp-ldp-sync YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls/igp-ldp-sync/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint32 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls/igp-ldp-sync/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State struct {
	Enabled            *bool   `path:"enabled" module:"openconfig-network-instance"`
	PostSessionUpDelay *uint32 `path:"post-session-up-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_IgpLdpSync_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/mpls/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State struct {
	TrafficEngineeringExtensions *bool `path:"traffic-engineering-extensions" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Mpls_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State struct {
	HideTransitOnlyNetworks *bool                                                                                                                     `path:"hide-transit-only-networks" module:"openconfig-network-instance"`
	IgpShortcuts            *bool                                                                                                                     `path:"igp-shortcuts" module:"openconfig-network-instance"`
	LogAdjacencyChanges     *bool                                                                                                                     `path:"log-adjacency-changes" module:"openconfig-network-instance"`
	RouterId                *string                                                                                                                   `path:"router-id" module:"openconfig-network-instance"`
	SummaryRouteCostMode    E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode `path:"summary-route-cost-mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers struct {
	LsaGeneration *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration `path:"lsa-generation" module:"openconfig-network-instance"`
	MaxMetric     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric     `path:"max-metric" module:"openconfig-network-instance"`
	Spf           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf           `path:"spf" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/lsa-generation YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/lsa-generation/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config struct {
	InitialDelay *uint32 `path:"initial-delay" module:"openconfig-network-instance"`
	MaximumDelay *uint32 `path:"maximum-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/lsa-generation/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State struct {
	InitialDelay *uint32                                                                                                                            `path:"initial-delay" module:"openconfig-network-instance"`
	MaximumDelay *uint32                                                                                                                            `path:"maximum-delay" module:"openconfig-network-instance"`
	TimerType    E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType `path:"timer-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config struct {
	Include []E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE `path:"include" module:"openconfig-network-instance"`
	Set     *bool                                      `path:"set" module:"openconfig-network-instance"`
	Timeout *uint64                                    `path:"timeout" module:"openconfig-network-instance"`
	Trigger []E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER `path:"trigger" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State struct {
	Include []E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE `path:"include" module:"openconfig-network-instance"`
	Set     *bool                                      `path:"set" module:"openconfig-network-instance"`
	Timeout *uint64                                    `path:"timeout" module:"openconfig-network-instance"`
	Trigger []E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER `path:"trigger" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_MaxMetric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/spf YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/spf/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config struct {
	InitialDelay *uint32 `path:"initial-delay" module:"openconfig-network-instance"`
	MaximumDelay *uint32 `path:"maximum-delay" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/spf/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State struct {
	InitialDelay *uint32                                                                                                                            `path:"initial-delay" module:"openconfig-network-instance"`
	MaximumDelay *uint32                                                                                                                            `path:"maximum-delay" module:"openconfig-network-instance"`
	TimerType    E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType `path:"timer-type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_Spf_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim struct {
	Global     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global     `path:"global" module:"openconfig-network-instance"`
	Interfaces *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces `path:"interfaces" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global struct {
	Config           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config           `path:"config" module:"openconfig-network-instance"`
	RendezvousPoints *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints `path:"rendezvous-points" module:"openconfig-network-instance"`
	SourcesJoined    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined    `path:"sources-joined" module:"openconfig-network-instance"`
	Ssm              *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm              `path:"ssm" module:"openconfig-network-instance"`
	State            *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State            `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config struct {
	MaximumGroups *uint32 `path:"maximum-groups" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/rendezvous-points YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints struct {
	RendezvousPoint map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint `path:"rendezvous-point" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints) IsYANGGoStruct() {
}

// NewRendezvousPoint creates a new entry in the RendezvousPoint list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints) NewRendezvousPoint(Address string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RendezvousPoint == nil {
		t.RendezvousPoint = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RendezvousPoint[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RendezvousPoint", key)
	}

	t.RendezvousPoint[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint{
		Address: &Address,
	}

	return t.RendezvousPoint[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/rendezvous-points/rendezvous-point YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint struct {
	Address *string                                                                                                                           `path:"address" module:"openconfig-network-instance"`
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config `path:"config" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/rendezvous-points/rendezvous-point/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config struct {
	Address         *string `path:"address" module:"openconfig-network-instance"`
	MulticastGroups *string `path:"multicast-groups" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/rendezvous-points/rendezvous-point/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State struct {
	Address         *string `path:"address" module:"openconfig-network-instance"`
	MulticastGroups *string `path:"multicast-groups" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_RendezvousPoints_RendezvousPoint_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/sources-joined YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined struct {
	Source map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source `path:"source" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined) IsYANGGoStruct() {
}

// NewSource creates a new entry in the Source list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined) NewSource(Address string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Source == nil {
		t.Source = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Source[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Source", key)
	}

	t.Source[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source{
		Address: &Address,
	}

	return t.Source[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/sources-joined/source YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source struct {
	Address *string                                                                                                              `path:"address" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/sources-joined/source/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State struct {
	Address             *string `path:"address" module:"openconfig-network-instance"`
	Group               *string `path:"group" module:"openconfig-network-instance"`
	UpstreamInterfaceId *string `path:"upstream-interface-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_SourcesJoined_Source_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/ssm YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/ssm/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config struct {
	SsmRanges *string `path:"ssm-ranges" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/ssm/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State struct {
	SsmRanges *string `path:"ssm-ranges" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_Ssm_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State struct {
	Counters      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters `path:"counters" module:"openconfig-network-instance"`
	MaximumGroups *uint32                                                                                                  `path:"maximum-groups" module:"openconfig-network-instance"`
	NeighborCount *uint8                                                                                                   `path:"neighbor-count" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/global/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters struct {
	BootstrapMessages *uint32 `path:"bootstrap-messages" module:"openconfig-network-instance"`
	HelloMessages     *uint32 `path:"hello-messages" module:"openconfig-network-instance"`
	JoinPruneMessages *uint32 `path:"join-prune-messages" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Global_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces struct {
	Interface map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces) IsYANGGoStruct() {
}

// NewInterface creates a new entry in the Interface list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces) NewInterface(InterfaceId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Interface == nil {
		t.Interface = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface)
	}

	key := InterfaceId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Interface[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Interface", key)
	}

	t.Interface[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface{
		InterfaceId: &InterfaceId,
	}

	return t.Interface[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config       `path:"config" module:"openconfig-network-instance"`
	EnableBfd    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd    `path:"enable-bfd" module:"openconfig-network-instance"`
	InterfaceId  *string                                                                                                              `path:"interface-id" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	Neighbors    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors    `path:"neighbors" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface) ΛListKeyMap() (map[string]interface{}, error) {
	if t.InterfaceId == nil {
		return nil, fmt.Errorf("nil value for key InterfaceId")
	}

	return map[string]interface{}{
		"interface-id": *t.InterfaceId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config struct {
	BorderRouter      *bool                         `path:"border-router" module:"openconfig-network-instance"`
	BsrBorder         *bool                         `path:"bsr-border" module:"openconfig-network-instance"`
	DeadTimer         *uint16                       `path:"dead-timer" module:"openconfig-network-instance"`
	DrPriority        *uint32                       `path:"dr-priority" module:"openconfig-network-instance"`
	Enabled           *bool                         `path:"enabled" module:"openconfig-network-instance"`
	HelloInterval     *uint8                        `path:"hello-interval" module:"openconfig-network-instance"`
	InterfaceId       *string                       `path:"interface-id" module:"openconfig-network-instance"`
	JoinPruneInterval *uint8                        `path:"join-prune-interval" module:"openconfig-network-instance"`
	MaximumGroups     *uint32                       `path:"maximum-groups" module:"openconfig-network-instance"`
	Mode              E_OpenconfigPimTypes_PIM_MODE `path:"mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/enable-bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/enable-bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/enable-bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/neighbors YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors struct {
	Neighbor map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor `path:"neighbor" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors) IsYANGGoStruct() {
}

// NewNeighbor creates a new entry in the Neighbor list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors) NewNeighbor(NeighborAddress string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Neighbor == nil {
		t.Neighbor = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor)
	}

	key := NeighborAddress

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Neighbor[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Neighbor", key)
	}

	t.Neighbor[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor{
		NeighborAddress: &NeighborAddress,
	}

	return t.Neighbor[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/neighbors/neighbor YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor struct {
	NeighborAddress *string                                                                                                                          `path:"neighbor-address" module:"openconfig-network-instance"`
	State           *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor) ΛListKeyMap() (map[string]interface{}, error) {
	if t.NeighborAddress == nil {
		return nil, fmt.Errorf("nil value for key NeighborAddress")
	}

	return map[string]interface{}{
		"neighbor-address": *t.NeighborAddress,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/neighbors/neighbor/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State struct {
	DrAddress           *string                       `path:"dr-address" module:"openconfig-network-instance"`
	Mode                E_OpenconfigPimTypes_PIM_MODE `path:"mode" module:"openconfig-network-instance"`
	NeighborAddress     *string                       `path:"neighbor-address" module:"openconfig-network-instance"`
	NeighborEstablished *uint64                       `path:"neighbor-established" module:"openconfig-network-instance"`
	NeighborExpires     *uint64                       `path:"neighbor-expires" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_Neighbors_Neighbor_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State struct {
	BorderRouter      *bool                                                                                                                  `path:"border-router" module:"openconfig-network-instance"`
	BsrBorder         *bool                                                                                                                  `path:"bsr-border" module:"openconfig-network-instance"`
	Counters          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters `path:"counters" module:"openconfig-network-instance"`
	DeadTimer         *uint16                                                                                                                `path:"dead-timer" module:"openconfig-network-instance"`
	DrPriority        *uint32                                                                                                                `path:"dr-priority" module:"openconfig-network-instance"`
	Enabled           *bool                                                                                                                  `path:"enabled" module:"openconfig-network-instance"`
	HelloInterval     *uint8                                                                                                                 `path:"hello-interval" module:"openconfig-network-instance"`
	InterfaceId       *string                                                                                                                `path:"interface-id" module:"openconfig-network-instance"`
	JoinPruneInterval *uint8                                                                                                                 `path:"join-prune-interval" module:"openconfig-network-instance"`
	MaximumGroups     *uint32                                                                                                                `path:"maximum-groups" module:"openconfig-network-instance"`
	Mode              E_OpenconfigPimTypes_PIM_MODE                                                                                          `path:"mode" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters struct {
	BootstrapMessages *uint32 `path:"bootstrap-messages" module:"openconfig-network-instance"`
	HelloMessages     *uint32 `path:"hello-messages" module:"openconfig-network-instance"`
	JoinPruneMessages *uint32 `path:"join-prune-messages" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Pim_Interfaces_Interface_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State struct {
	DefaultMetric *uint32                                       `path:"default-metric" module:"openconfig-network-instance"`
	Enabled       *bool                                         `path:"enabled" module:"openconfig-network-instance"`
	Identifier    E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"identifier" module:"openconfig-network-instance"`
	Name          *string                                       `path:"name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes struct {
	Static map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static `path:"static" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes) IsYANGGoStruct() {
}

// NewStatic creates a new entry in the Static list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes) NewStatic(Prefix string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Static == nil {
		t.Static = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static)
	}

	key := Prefix

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Static[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Static", key)
	}

	t.Static[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static{
		Prefix: &Prefix,
	}

	return t.Static[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static struct {
	Config   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config   `path:"config" module:"openconfig-network-instance"`
	NextHops *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops `path:"next-hops" module:"openconfig-network-instance"`
	Prefix   *string                                                                                                     `path:"prefix" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Prefix == nil {
		return nil, fmt.Errorf("nil value for key Prefix")
	}

	return map[string]interface{}{
		"prefix": *t.Prefix,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config struct {
	Description *string                                                                                                               `path:"description" module:"openconfig-network-instance"`
	Prefix      *string                                                                                                               `path:"prefix" module:"openconfig-network-instance"`
	SetTag      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union `path:"set-tag" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/config/set-tag within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/config/set-tag
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/config/set-tag
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_Config_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops struct {
	NextHop map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop `path:"next-hop" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops) IsYANGGoStruct() {
}

// NewNextHop creates a new entry in the NextHop list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops) NewNextHop(Index string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop struct {
	Config       *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config       `path:"config" module:"openconfig-network-instance"`
	EnableBfd    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd    `path:"enable-bfd" module:"openconfig-network-instance"`
	Index        *string                                                                                                                          `path:"index" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config struct {
	Index   *string                                                                                                                                 `path:"index" module:"openconfig-network-instance"`
	Metric  *uint32                                                                                                                                 `path:"metric" module:"openconfig-network-instance"`
	NextHop OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union `path:"next-hop" module:"openconfig-network-instance"`
	Recurse *bool                                                                                                                                   `path:"recurse" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/config/next-hop within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/config/next-hop
// is to be set to a E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP struct {
	E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/config/next-hop
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_Config_NextHop_Union, unknown union type, got: %T, want any of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/enable-bfd YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/enable-bfd/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/enable-bfd/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State struct {
	Enabled *bool `path:"enabled" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_EnableBfd_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef struct {
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/interface-ref/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State struct {
	Index   *string                                                                                                                                `path:"index" module:"openconfig-network-instance"`
	Metric  *uint32                                                                                                                                `path:"metric" module:"openconfig-network-instance"`
	NextHop OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union `path:"next-hop" module:"openconfig-network-instance"`
	Recurse *bool                                                                                                                                  `path:"recurse" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state/next-hop within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state/next-hop
// is to be set to a E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP struct {
	E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state/next-hop
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_NextHops_NextHop_State_NextHop_Union, unknown union type, got: %T, want any of [E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP, string]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State represents the /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State struct {
	Description *string                                                                                                              `path:"description" module:"openconfig-network-instance"`
	Prefix      *string                                                                                                              `path:"prefix" module:"openconfig-network-instance"`
	SetTag      OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union `path:"set-tag" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/state/set-tag within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_String is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/state/set-tag
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/protocols/protocol/static-routes/static/state/set-tag
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_StaticRoutes_Static_State_SetTag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits represents the /openconfig-network-instance/network-instances/network-instance/route-limits YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits struct {
	RouteLimit map[E_OpenconfigTypes_ADDRESS_FAMILY]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit `path:"route-limit" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits) IsYANGGoStruct() {}

// NewRouteLimit creates a new entry in the RouteLimit list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits) NewRouteLimit(Afi E_OpenconfigTypes_ADDRESS_FAMILY) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RouteLimit == nil {
		t.RouteLimit = make(map[E_OpenconfigTypes_ADDRESS_FAMILY]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit)
	}

	key := Afi

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RouteLimit[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RouteLimit", key)
	}

	t.RouteLimit[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit{
		Afi: Afi,
	}

	return t.RouteLimit[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit represents the /openconfig-network-instance/network-instances/network-instance/route-limits/route-limit YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit struct {
	Afi    E_OpenconfigTypes_ADDRESS_FAMILY                                                          `path:"afi" module:"openconfig-network-instance"`
	Config *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config `path:"config" module:"openconfig-network-instance"`
	State  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"afi": t.Afi,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config represents the /openconfig-network-instance/network-instances/network-instance/route-limits/route-limit/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config struct {
	Afi            E_OpenconfigTypes_ADDRESS_FAMILY `path:"afi" module:"openconfig-network-instance"`
	AlarmThreshold *uint32                          `path:"alarm-threshold" module:"openconfig-network-instance"`
	Maximum        *uint32                          `path:"maximum" module:"openconfig-network-instance"`
	WarningOnly    *bool                            `path:"warning-only" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State represents the /openconfig-network-instance/network-instances/network-instance/route-limits/route-limit/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State struct {
	Afi               E_OpenconfigTypes_ADDRESS_FAMILY `path:"afi" module:"openconfig-network-instance"`
	AlarmThreshold    *uint32                          `path:"alarm-threshold" module:"openconfig-network-instance"`
	InstalledRoutes   *uint32                          `path:"installed-routes" module:"openconfig-network-instance"`
	Maximum           *uint32                          `path:"maximum" module:"openconfig-network-instance"`
	ThresholdExceeded *bool                            `path:"threshold-exceeded" module:"openconfig-network-instance"`
	WarningOnly       *bool                            `path:"warning-only" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_RouteLimits_RouteLimit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting represents the /openconfig-network-instance/network-instances/network-instance/segment-routing YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting struct {
	Srgbs      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs      `path:"srgbs" module:"openconfig-network-instance"`
	Srlbs      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs      `path:"srlbs" module:"openconfig-network-instance"`
	TePolicies *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies `path:"te-policies" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srgbs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs struct {
	Srgb map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb `path:"srgb" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs) IsYANGGoStruct() {
}

// NewSrgb creates a new entry in the Srgb list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs) NewSrgb(LocalId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srgb == nil {
		t.Srgb = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb)
	}

	key := LocalId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Srgb[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Srgb", key)
	}

	t.Srgb[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb{
		LocalId: &LocalId,
	}

	return t.Srgb[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srgbs/srgb YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config `path:"config" module:"openconfig-network-instance"`
	LocalId *string                                                                                      `path:"local-id" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalId == nil {
		return nil, fmt.Errorf("nil value for key LocalId")
	}

	return map[string]interface{}{
		"local-id": *t.LocalId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srgbs/srgb/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config struct {
	DataplaneType   E_OpenconfigSegmentRouting_SrDataplaneType `path:"dataplane-type" module:"openconfig-network-instance"`
	Ipv6Prefixes    []string                                   `path:"ipv6-prefixes" module:"openconfig-network-instance"`
	LocalId         *string                                    `path:"local-id" module:"openconfig-network-instance"`
	MplsLabelBlocks []string                                   `path:"mpls-label-blocks" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srgbs/srgb/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State struct {
	DataplaneType   E_OpenconfigSegmentRouting_SrDataplaneType `path:"dataplane-type" module:"openconfig-network-instance"`
	Ipv6Prefixes    []string                                   `path:"ipv6-prefixes" module:"openconfig-network-instance"`
	LocalId         *string                                    `path:"local-id" module:"openconfig-network-instance"`
	MplsLabelBlocks []string                                   `path:"mpls-label-blocks" module:"openconfig-network-instance"`
	Size            *uint32                                    `path:"size" module:"openconfig-network-instance"`
	Used            *uint32                                    `path:"used" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srgbs_Srgb_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srlbs YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs struct {
	Srlb map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb `path:"srlb" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs) IsYANGGoStruct() {
}

// NewSrlb creates a new entry in the Srlb list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs) NewSrlb(LocalId string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Srlb == nil {
		t.Srlb = make(map[string]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb)
	}

	key := LocalId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Srlb[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Srlb", key)
	}

	t.Srlb[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb{
		LocalId: &LocalId,
	}

	return t.Srlb[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srlbs/srlb YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config `path:"config" module:"openconfig-network-instance"`
	LocalId *string                                                                                      `path:"local-id" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LocalId == nil {
		return nil, fmt.Errorf("nil value for key LocalId")
	}

	return map[string]interface{}{
		"local-id": *t.LocalId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srlbs/srlb/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config struct {
	DataplaneType  E_OpenconfigSegmentRouting_SrDataplaneType `path:"dataplane-type" module:"openconfig-network-instance"`
	Ipv6Prefix     *string                                    `path:"ipv6-prefix" module:"openconfig-network-instance"`
	LocalId        *string                                    `path:"local-id" module:"openconfig-network-instance"`
	MplsLabelBlock *string                                    `path:"mpls-label-block" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/srlbs/srlb/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State struct {
	DataplaneType  E_OpenconfigSegmentRouting_SrDataplaneType `path:"dataplane-type" module:"openconfig-network-instance"`
	Ipv6Prefix     *string                                    `path:"ipv6-prefix" module:"openconfig-network-instance"`
	LocalId        *string                                    `path:"local-id" module:"openconfig-network-instance"`
	MplsLabelBlock *string                                    `path:"mpls-label-block" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_Srlbs_Srlb_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies struct {
	TePolicy map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy `path:"te-policy" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_Key represents the key for list TePolicy of element /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_Key struct {
	Color    uint32 `path:"color"`
	Endpoint string `path:"endpoint"`
}

// NewTePolicy creates a new entry in the TePolicy list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies) NewTePolicy(Color uint32, Endpoint string) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TePolicy == nil {
		t.TePolicy = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_Key{
		Color:    Color,
		Endpoint: Endpoint,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TePolicy[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TePolicy", key)
	}

	t.TePolicy[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy{
		Color:    &Color,
		Endpoint: &Endpoint,
	}

	return t.TePolicy[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy struct {
	CandidatePaths *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths `path:"candidate-paths" module:"openconfig-network-instance"`
	Color          *uint32                                                                                                       `path:"color" module:"openconfig-network-instance"`
	Endpoint       *string                                                                                                       `path:"endpoint" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State          `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Color == nil {
		return nil, fmt.Errorf("nil value for key Color")
	}

	if t.Endpoint == nil {
		return nil, fmt.Errorf("nil value for key Endpoint")
	}

	return map[string]interface{}{
		"color":    *t.Color,
		"endpoint": *t.Endpoint,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths struct {
	CandidatePath map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath `path:"candidate-path" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_Key represents the key for list CandidatePath of element /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_Key struct {
	ProtocolOrigin E_OpenconfigSrtePolicy_SrteProtocolType `path:"protocol-origin"`
	OriginatorAsn  uint32                                  `path:"originator-asn"`
	OriginatorAddr string                                  `path:"originator-addr"`
	Discriminator  uint32                                  `path:"discriminator"`
}

// NewCandidatePath creates a new entry in the CandidatePath list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths) NewCandidatePath(ProtocolOrigin E_OpenconfigSrtePolicy_SrteProtocolType, OriginatorAsn uint32, OriginatorAddr string, Discriminator uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.CandidatePath == nil {
		t.CandidatePath = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_Key{
		ProtocolOrigin: ProtocolOrigin,
		OriginatorAsn:  OriginatorAsn,
		OriginatorAddr: OriginatorAddr,
		Discriminator:  Discriminator,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.CandidatePath[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list CandidatePath", key)
	}

	t.CandidatePath[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath{
		ProtocolOrigin: ProtocolOrigin,
		OriginatorAsn:  &OriginatorAsn,
		OriginatorAddr: &OriginatorAddr,
		Discriminator:  &Discriminator,
	}

	return t.CandidatePath[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath struct {
	Discriminator  *uint32                                                                                                                                  `path:"discriminator" module:"openconfig-network-instance"`
	OriginatorAddr *string                                                                                                                                  `path:"originator-addr" module:"openconfig-network-instance"`
	OriginatorAsn  *uint32                                                                                                                                  `path:"originator-asn" module:"openconfig-network-instance"`
	ProtocolOrigin E_OpenconfigSrtePolicy_SrteProtocolType                                                                                                  `path:"protocol-origin" module:"openconfig-network-instance"`
	SegmentLists   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists `path:"segment-lists" module:"openconfig-network-instance"`
	State          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Discriminator == nil {
		return nil, fmt.Errorf("nil value for key Discriminator")
	}

	if t.OriginatorAddr == nil {
		return nil, fmt.Errorf("nil value for key OriginatorAddr")
	}

	if t.OriginatorAsn == nil {
		return nil, fmt.Errorf("nil value for key OriginatorAsn")
	}

	return map[string]interface{}{
		"discriminator":   *t.Discriminator,
		"originator-addr": *t.OriginatorAddr,
		"originator-asn":  *t.OriginatorAsn,
		"protocol-origin": t.ProtocolOrigin,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists struct {
	SegmentList map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList `path:"segment-list" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists) IsYANGGoStruct() {
}

// NewSegmentList creates a new entry in the SegmentList list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists) NewSegmentList(Id uint32) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.SegmentList == nil {
		t.SegmentList = make(map[uint32]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.SegmentList[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list SegmentList", key)
	}

	t.SegmentList[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList{
		Id: &Id,
	}

	return t.SegmentList[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList struct {
	Id       *uint32                                                                                                                                                       `path:"id" module:"openconfig-network-instance"`
	NextHops *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops `path:"next-hops" module:"openconfig-network-instance"`
	Sids     *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids     `path:"sids" module:"openconfig-network-instance"`
	State    *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State    `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops struct {
	NextHop map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop `path:"next-hop" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops) IsYANGGoStruct() {
}

// NewNextHop creates a new entry in the NextHop list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops) NewNextHop(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NextHop == nil {
		t.NextHop = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NextHop[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NextHop", key)
	}

	t.NextHop[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop{
		Index: &Index,
	}

	return t.NextHop[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop struct {
	Index        *uint64                                                                                                                                                                            `path:"index" module:"openconfig-network-instance"`
	InterfaceRef *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef `path:"interface-ref" module:"openconfig-network-instance"`
	State        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State        `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/interface-ref YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/interface-ref/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State struct {
	Interface    *string `path:"interface" module:"openconfig-network-instance"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_InterfaceRef_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State struct {
	Counters             *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters                    `path:"counters" module:"openconfig-network-instance"`
	EncapsulateHeader    E_OpenconfigAft_EncapsulationHeaderType                                                                                                                                                                 `path:"encapsulate-header" module:"openconfig-network-instance"`
	Index                *uint64                                                                                                                                                                                                 `path:"index" module:"openconfig-network-instance"`
	IpAddress            *string                                                                                                                                                                                                 `path:"ip-address" module:"openconfig-network-instance"`
	MacAddress           *string                                                                                                                                                                                                 `path:"mac-address" module:"openconfig-network-instance"`
	OriginProtocol       E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                                                                                                                                           `path:"origin-protocol" module:"openconfig-network-instance"`
	PushedMplsLabelStack []OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union `path:"pushed-mpls-label-stack" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/pushed-mpls-label-stack within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/pushed-mpls-label-stack
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/pushed-mpls-label-stack
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_PushedMplsLabelStack_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters struct {
	OutLabeledOctets *uint64 `path:"out-labeled-octets" module:"openconfig-network-instance"`
	OutLabeledPkts   *uint64 `path:"out-labeled-pkts" module:"openconfig-network-instance"`
	OutOctets        *uint64 `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts          *uint64 `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_NextHops_NextHop_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids struct {
	Sid map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid `path:"sid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids) IsYANGGoStruct() {
}

// NewSid creates a new entry in the Sid list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids) NewSid(Index uint64) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Sid == nil {
		t.Sid = make(map[uint64]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Sid[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Sid", key)
	}

	t.Sid[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid{
		Index: &Index,
	}

	return t.Sid[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid struct {
	Index *uint64                                                                                                                                                             `path:"index" module:"openconfig-network-instance"`
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Index == nil {
		return nil, fmt.Errorf("nil value for key Index")
	}

	return map[string]interface{}{
		"index": *t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State struct {
	Index   *uint64                                                                                                                                                                        `path:"index" module:"openconfig-network-instance"`
	MplsTc  *uint8                                                                                                                                                                         `path:"mpls-tc" module:"openconfig-network-instance"`
	MplsTtl *uint8                                                                                                                                                                         `path:"mpls-ttl" module:"openconfig-network-instance"`
	Value   OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union `path:"value" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_String is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State struct {
	Counters      *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters `path:"counters" module:"openconfig-network-instance"`
	Id            *uint32                                                                                                                                                             `path:"id" module:"openconfig-network-instance"`
	InvalidReason E_OpenconfigSrtePolicy_SrteInvalidSlReason                                                                                                                          `path:"invalid-reason" module:"openconfig-network-instance"`
	Valid         *bool                                                                                                                                                               `path:"valid" module:"openconfig-network-instance"`
	Weight        *uint32                                                                                                                                                             `path:"weight" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters struct {
	OutLabeledOctets *uint64 `path:"out-labeled-octets" module:"openconfig-network-instance"`
	OutLabeledPkts   *uint64 `path:"out-labeled-pkts" module:"openconfig-network-instance"`
	OutOctets        *uint64 `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts          *uint64 `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State struct {
	Active            *bool                                   `path:"active" module:"openconfig-network-instance"`
	ActiveSince       *uint64                                 `path:"active-since" module:"openconfig-network-instance"`
	ActiveTransitions *uint64                                 `path:"active-transitions" module:"openconfig-network-instance"`
	Discriminator     *uint32                                 `path:"discriminator" module:"openconfig-network-instance"`
	Enlp              E_OpenconfigSrtePolicy_EnlpType         `path:"enlp" module:"openconfig-network-instance"`
	Name              *string                                 `path:"name" module:"openconfig-network-instance"`
	OriginatorAddr    *string                                 `path:"originator-addr" module:"openconfig-network-instance"`
	OriginatorAsn     *uint32                                 `path:"originator-asn" module:"openconfig-network-instance"`
	Preference        *uint32                                 `path:"preference" module:"openconfig-network-instance"`
	ProtocolOrigin    E_OpenconfigSrtePolicy_SrteProtocolType `path:"protocol-origin" module:"openconfig-network-instance"`
	Valid             *bool                                   `path:"valid" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State struct {
	Active            *bool                                                                                                          `path:"active" module:"openconfig-network-instance"`
	ActiveSince       *uint64                                                                                                        `path:"active-since" module:"openconfig-network-instance"`
	ActiveTransitions *uint64                                                                                                        `path:"active-transitions" module:"openconfig-network-instance"`
	Bsid              OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union `path:"bsid" module:"openconfig-network-instance"`
	Color             *uint32                                                                                                        `path:"color" module:"openconfig-network-instance"`
	Counters          *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters  `path:"counters" module:"openconfig-network-instance"`
	Endpoint          *string                                                                                                        `path:"endpoint" module:"openconfig-network-instance"`
	Name              *string                                                                                                        `path:"name" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid within the YANG schema.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union interface {
	Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union()
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid
// is to be set to a E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid struct {
	E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_String is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid
// is to be set to a string value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_String struct {
	String string
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_String
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_String) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_Uint32 is used when /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid
// is to be set to a uint32 value.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_Uint32
// implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union interface.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_Uint32) Is_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union() {
}

// To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State) To_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union(i interface{}) (OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid{v}, nil
	case string:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_String{v}, nil
	case uint32:
		return &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_Union, unknown union type, got: %T, want any of [E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid, string, uint32]", i, i)
	}
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters represents the /openconfig-network-instance/network-instances/network-instance/segment-routing/te-policies/te-policy/state/counters YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters struct {
	InLabeledOctets  *uint64 `path:"in-labeled-octets" module:"openconfig-network-instance"`
	InLabeledPkts    *uint64 `path:"in-labeled-pkts" module:"openconfig-network-instance"`
	InOctets         *uint64 `path:"in-octets" module:"openconfig-network-instance"`
	InPkts           *uint64 `path:"in-pkts" module:"openconfig-network-instance"`
	OutLabeledOctets *uint64 `path:"out-labeled-octets" module:"openconfig-network-instance"`
	OutLabeledPkts   *uint64 `path:"out-labeled-pkts" module:"openconfig-network-instance"`
	OutOctets        *uint64 `path:"out-octets" module:"openconfig-network-instance"`
	OutPkts          *uint64 `path:"out-pkts" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State represents the /openconfig-network-instance/network-instances/network-instance/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State struct {
	Description            *string                                                `path:"description" module:"openconfig-network-instance"`
	Enabled                *bool                                                  `path:"enabled" module:"openconfig-network-instance"`
	EnabledAddressFamilies []E_OpenconfigTypes_ADDRESS_FAMILY                     `path:"enabled-address-families" module:"openconfig-network-instance"`
	Mtu                    *uint16                                                `path:"mtu" module:"openconfig-network-instance"`
	Name                   *string                                                `path:"name" module:"openconfig-network-instance"`
	RouteDistinguisher     *string                                                `path:"route-distinguisher" module:"openconfig-network-instance"`
	RouterId               *string                                                `path:"router-id" module:"openconfig-network-instance"`
	Type                   E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE `path:"type" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections represents the /openconfig-network-instance/network-instances/network-instance/table-connections YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections struct {
	TableConnection map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection `path:"table-connection" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections) IsYANGGoStruct() {
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Key represents the key for list TableConnection of element /openconfig-network-instance/network-instances/network-instance/table-connections.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Key struct {
	SrcProtocol   E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"src-protocol"`
	DstProtocol   E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"dst-protocol"`
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family"`
}

// NewTableConnection creates a new entry in the TableConnection list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections) NewTableConnection(SrcProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, DstProtocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TableConnection == nil {
		t.TableConnection = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Key{
		SrcProtocol:   SrcProtocol,
		DstProtocol:   DstProtocol,
		AddressFamily: AddressFamily,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TableConnection[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TableConnection", key)
	}

	t.TableConnection[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection{
		SrcProtocol:   SrcProtocol,
		DstProtocol:   DstProtocol,
		AddressFamily: AddressFamily,
	}

	return t.TableConnection[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection represents the /openconfig-network-instance/network-instances/network-instance/table-connections/table-connection YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection struct {
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY                                                                    `path:"address-family" module:"openconfig-network-instance"`
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config `path:"config" module:"openconfig-network-instance"`
	DstProtocol   E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                                       `path:"dst-protocol" module:"openconfig-network-instance"`
	SrcProtocol   E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                                       `path:"src-protocol" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"address-family": t.AddressFamily,
		"dst-protocol":   t.DstProtocol,
		"src-protocol":   t.SrcProtocol,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config represents the /openconfig-network-instance/network-instances/network-instance/table-connections/table-connection/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config struct {
	AddressFamily            E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family" module:"openconfig-network-instance"`
	DefaultImportPolicy      E_OpenconfigRoutingPolicy_DefaultPolicyType   `path:"default-import-policy" module:"openconfig-network-instance"`
	DisableMetricPropagation *bool                                         `path:"disable-metric-propagation" module:"openconfig-network-instance"`
	DstProtocol              E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"dst-protocol" module:"openconfig-network-instance"`
	ImportPolicy             []string                                      `path:"import-policy" module:"openconfig-network-instance"`
	SrcProtocol              E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"src-protocol" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State represents the /openconfig-network-instance/network-instances/network-instance/table-connections/table-connection/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State struct {
	AddressFamily            E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family" module:"openconfig-network-instance"`
	DefaultImportPolicy      E_OpenconfigRoutingPolicy_DefaultPolicyType   `path:"default-import-policy" module:"openconfig-network-instance"`
	DisableMetricPropagation *bool                                         `path:"disable-metric-propagation" module:"openconfig-network-instance"`
	DstProtocol              E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"dst-protocol" module:"openconfig-network-instance"`
	ImportPolicy             []string                                      `path:"import-policy" module:"openconfig-network-instance"`
	SrcProtocol              E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"src-protocol" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_TableConnections_TableConnection_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables represents the /openconfig-network-instance/network-instances/network-instance/tables YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables struct {
	Table map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table `path:"table" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables) IsYANGGoStruct() {}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Key represents the key for list Table of element /openconfig-network-instance/network-instances/network-instance/tables.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Key struct {
	Protocol      E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"protocol"`
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family"`
}

// NewTable creates a new entry in the Table list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables) NewTable(Protocol E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE, AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Table == nil {
		t.Table = make(map[OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Key]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table)
	}

	key := OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Key{
		Protocol:      Protocol,
		AddressFamily: AddressFamily,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Table[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Table", key)
	}

	t.Table[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table{
		Protocol:      Protocol,
		AddressFamily: AddressFamily,
	}

	return t.Table[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table represents the /openconfig-network-instance/network-instances/network-instance/tables/table YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table struct {
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY                                                `path:"address-family" module:"openconfig-network-instance"`
	Config        *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config `path:"config" module:"openconfig-network-instance"`
	Protocol      E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE                                   `path:"protocol" module:"openconfig-network-instance"`
	State         *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State  `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"address-family": t.AddressFamily,
		"protocol":       t.Protocol,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config represents the /openconfig-network-instance/network-instances/network-instance/tables/table/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config struct {
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family" module:"openconfig-network-instance"`
	Protocol      E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"protocol" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State represents the /openconfig-network-instance/network-instances/network-instance/tables/table/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State struct {
	AddressFamily E_OpenconfigTypes_ADDRESS_FAMILY              `path:"address-family" module:"openconfig-network-instance"`
	Protocol      E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"protocol" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Tables_Table_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans represents the /openconfig-network-instance/network-instances/network-instance/vlans YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans struct {
	Vlan map[uint16]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan `path:"vlan" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans) IsYANGGoStruct() {}

// NewVlan creates a new entry in the Vlan list of the
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans) NewVlan(VlanId uint16) (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Vlan == nil {
		t.Vlan = make(map[uint16]*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan)
	}

	key := VlanId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Vlan[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Vlan", key)
	}

	t.Vlan[key] = &OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan{
		VlanId: &VlanId,
	}

	return t.Vlan[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan struct {
	Config  *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config  `path:"config" module:"openconfig-network-instance"`
	Members *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members `path:"members" module:"openconfig-network-instance"`
	State   *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State   `path:"state" module:"openconfig-network-instance"`
	VlanId  *uint16                                                                        `path:"vlan-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan struct, which is a YANG list entry.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan) ΛListKeyMap() (map[string]interface{}, error) {
	if t.VlanId == nil {
		return nil, fmt.Errorf("nil value for key VlanId")
	}

	return map[string]interface{}{
		"vlan-id": *t.VlanId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan/config YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config struct {
	Name   *string                                                                               `path:"name" module:"openconfig-network-instance"`
	Status E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status `path:"status" module:"openconfig-network-instance"`
	VlanId *uint16                                                                               `path:"vlan-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan/members YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members struct {
	Member []*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member `path:"member" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan/members/member YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member struct {
	State *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State `path:"state" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan/members/member/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State struct {
	Interface *string `path:"interface" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Members_Member_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State represents the /openconfig-network-instance/network-instances/network-instance/vlans/vlan/state YANG schema element.
type OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State struct {
	Name   *string                                                                               `path:"name" module:"openconfig-network-instance"`
	Status E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status `path:"status" module:"openconfig-network-instance"`
	VlanId *uint16                                                                               `path:"vlan-id" module:"openconfig-network-instance"`
}

// IsYANGGoStruct ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components represents the /openconfig-platform/components YANG schema element.
type OpenconfigPlatform_Components struct {
	Component map[string]*OpenconfigPlatform_Components_Component `path:"component" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components) IsYANGGoStruct() {}

// NewComponent creates a new entry in the Component list of the
// OpenconfigPlatform_Components struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigPlatform_Components) NewComponent(Name string) (*OpenconfigPlatform_Components_Component, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Component == nil {
		t.Component = make(map[string]*OpenconfigPlatform_Components_Component)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Component[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Component", key)
	}

	t.Component[key] = &OpenconfigPlatform_Components_Component{
		Name: &Name,
	}

	return t.Component[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigPlatform_Components_Component represents the /openconfig-platform/components/component YANG schema element.
type OpenconfigPlatform_Components_Component struct {
	Backplane         *OpenconfigPlatform_Components_Component_Backplane         `path:"backplane" module:"openconfig-platform"`
	Chassis           *OpenconfigPlatform_Components_Component_Chassis           `path:"chassis" module:"openconfig-platform"`
	Config            *OpenconfigPlatform_Components_Component_Config            `path:"config" module:"openconfig-platform"`
	Cpu               *OpenconfigPlatform_Components_Component_Cpu               `path:"cpu" module:"openconfig-platform"`
	Fabric            *OpenconfigPlatform_Components_Component_Fabric            `path:"fabric" module:"openconfig-platform"`
	Fan               *OpenconfigPlatform_Components_Component_Fan               `path:"fan" module:"openconfig-platform"`
	IntegratedCircuit *OpenconfigPlatform_Components_Component_IntegratedCircuit `path:"integrated-circuit" module:"openconfig-platform"`
	Name              *string                                                    `path:"name" module:"openconfig-platform"`
	Port              *OpenconfigPlatform_Components_Component_Port              `path:"port" module:"openconfig-platform"`
	PowerSupply       *OpenconfigPlatform_Components_Component_PowerSupply       `path:"power-supply" module:"openconfig-platform"`
	Properties        *OpenconfigPlatform_Components_Component_Properties        `path:"properties" module:"openconfig-platform"`
	SoftwareModule    *OpenconfigPlatform_Components_Component_SoftwareModule    `path:"software-module" module:"openconfig-platform"`
	State             *OpenconfigPlatform_Components_Component_State             `path:"state" module:"openconfig-platform"`
	Storage           *OpenconfigPlatform_Components_Component_Storage           `path:"storage" module:"openconfig-platform"`
	Subcomponents     *OpenconfigPlatform_Components_Component_Subcomponents     `path:"subcomponents" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigPlatform_Components_Component struct, which is a YANG list entry.
func (t *OpenconfigPlatform_Components_Component) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Backplane represents the /openconfig-platform/components/component/backplane YANG schema element.
type OpenconfigPlatform_Components_Component_Backplane struct {
	Config *OpenconfigPlatform_Components_Component_Backplane_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Backplane_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Backplane implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Backplane) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Backplane) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Backplane"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Backplane) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Backplane_Config represents the /openconfig-platform/components/component/backplane/config YANG schema element.
type OpenconfigPlatform_Components_Component_Backplane_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Backplane_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Backplane_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Backplane_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Backplane_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Backplane_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Backplane_State represents the /openconfig-platform/components/component/backplane/state YANG schema element.
type OpenconfigPlatform_Components_Component_Backplane_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Backplane_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Backplane_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Backplane_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Backplane_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Backplane_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Chassis represents the /openconfig-platform/components/component/chassis YANG schema element.
type OpenconfigPlatform_Components_Component_Chassis struct {
	Config *OpenconfigPlatform_Components_Component_Chassis_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Chassis_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Chassis implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Chassis) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Chassis) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Chassis"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Chassis) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Chassis_Config represents the /openconfig-platform/components/component/chassis/config YANG schema element.
type OpenconfigPlatform_Components_Component_Chassis_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Chassis_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Chassis_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Chassis_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Chassis_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Chassis_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Chassis_State represents the /openconfig-platform/components/component/chassis/state YANG schema element.
type OpenconfigPlatform_Components_Component_Chassis_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Chassis_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Chassis_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Chassis_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Chassis_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Chassis_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Config represents the /openconfig-platform/components/component/config YANG schema element.
type OpenconfigPlatform_Components_Component_Config struct {
	Name *string `path:"name" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Cpu represents the /openconfig-platform/components/component/cpu YANG schema element.
type OpenconfigPlatform_Components_Component_Cpu struct {
	Config *OpenconfigPlatform_Components_Component_Cpu_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Cpu_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Cpu implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Cpu) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Cpu) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Cpu"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Cpu) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Cpu_Config represents the /openconfig-platform/components/component/cpu/config YANG schema element.
type OpenconfigPlatform_Components_Component_Cpu_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Cpu_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Cpu_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Cpu_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Cpu_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Cpu_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Cpu_State represents the /openconfig-platform/components/component/cpu/state YANG schema element.
type OpenconfigPlatform_Components_Component_Cpu_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Cpu_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Cpu_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Cpu_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Cpu_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Cpu_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Fabric represents the /openconfig-platform/components/component/fabric YANG schema element.
type OpenconfigPlatform_Components_Component_Fabric struct {
	Config *OpenconfigPlatform_Components_Component_Fabric_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Fabric_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Fabric implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Fabric) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Fabric) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Fabric"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Fabric) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Fabric_Config represents the /openconfig-platform/components/component/fabric/config YANG schema element.
type OpenconfigPlatform_Components_Component_Fabric_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Fabric_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Fabric_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Fabric_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Fabric_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Fabric_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Fabric_State represents the /openconfig-platform/components/component/fabric/state YANG schema element.
type OpenconfigPlatform_Components_Component_Fabric_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Fabric_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Fabric_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Fabric_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Fabric_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Fabric_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Fan represents the /openconfig-platform/components/component/fan YANG schema element.
type OpenconfigPlatform_Components_Component_Fan struct {
	Config *OpenconfigPlatform_Components_Component_Fan_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Fan_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Fan implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Fan) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Fan) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Fan"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Fan) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Fan_Config represents the /openconfig-platform/components/component/fan/config YANG schema element.
type OpenconfigPlatform_Components_Component_Fan_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Fan_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Fan_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Fan_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Fan_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Fan_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Fan_State represents the /openconfig-platform/components/component/fan/state YANG schema element.
type OpenconfigPlatform_Components_Component_Fan_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Fan_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Fan_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Fan_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Fan_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Fan_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_IntegratedCircuit represents the /openconfig-platform/components/component/integrated-circuit YANG schema element.
type OpenconfigPlatform_Components_Component_IntegratedCircuit struct {
	Config *OpenconfigPlatform_Components_Component_IntegratedCircuit_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_IntegratedCircuit_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_IntegratedCircuit implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_IntegratedCircuit) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_IntegratedCircuit) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_IntegratedCircuit"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_IntegratedCircuit) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_IntegratedCircuit_Config represents the /openconfig-platform/components/component/integrated-circuit/config YANG schema element.
type OpenconfigPlatform_Components_Component_IntegratedCircuit_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_IntegratedCircuit_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_IntegratedCircuit_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_IntegratedCircuit_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_IntegratedCircuit_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_IntegratedCircuit_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_IntegratedCircuit_State represents the /openconfig-platform/components/component/integrated-circuit/state YANG schema element.
type OpenconfigPlatform_Components_Component_IntegratedCircuit_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_IntegratedCircuit_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_IntegratedCircuit_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_IntegratedCircuit_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_IntegratedCircuit_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_IntegratedCircuit_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Port represents the /openconfig-platform/components/component/port YANG schema element.
type OpenconfigPlatform_Components_Component_Port struct {
	Config *OpenconfigPlatform_Components_Component_Port_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Port_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Port implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Port) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Port) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Port"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Port) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Port_Config represents the /openconfig-platform/components/component/port/config YANG schema element.
type OpenconfigPlatform_Components_Component_Port_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Port_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Port_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Port_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Port_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Port_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Port_State represents the /openconfig-platform/components/component/port/state YANG schema element.
type OpenconfigPlatform_Components_Component_Port_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Port_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Port_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Port_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Port_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Port_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_PowerSupply represents the /openconfig-platform/components/component/power-supply YANG schema element.
type OpenconfigPlatform_Components_Component_PowerSupply struct {
	Config *OpenconfigPlatform_Components_Component_PowerSupply_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_PowerSupply_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_PowerSupply implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_PowerSupply) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_PowerSupply) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_PowerSupply"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_PowerSupply) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_PowerSupply_Config represents the /openconfig-platform/components/component/power-supply/config YANG schema element.
type OpenconfigPlatform_Components_Component_PowerSupply_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_PowerSupply_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_PowerSupply_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_PowerSupply_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_PowerSupply_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_PowerSupply_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_PowerSupply_State represents the /openconfig-platform/components/component/power-supply/state YANG schema element.
type OpenconfigPlatform_Components_Component_PowerSupply_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_PowerSupply_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_PowerSupply_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_PowerSupply_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_PowerSupply_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_PowerSupply_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Properties represents the /openconfig-platform/components/component/properties YANG schema element.
type OpenconfigPlatform_Components_Component_Properties struct {
	Property map[string]*OpenconfigPlatform_Components_Component_Properties_Property `path:"property" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Properties implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Properties) IsYANGGoStruct() {}

// NewProperty creates a new entry in the Property list of the
// OpenconfigPlatform_Components_Component_Properties struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigPlatform_Components_Component_Properties) NewProperty(Name string) (*OpenconfigPlatform_Components_Component_Properties_Property, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Property == nil {
		t.Property = make(map[string]*OpenconfigPlatform_Components_Component_Properties_Property)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Property[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Property", key)
	}

	t.Property[key] = &OpenconfigPlatform_Components_Component_Properties_Property{
		Name: &Name,
	}

	return t.Property[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Properties) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Properties"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Properties) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Properties_Property represents the /openconfig-platform/components/component/properties/property YANG schema element.
type OpenconfigPlatform_Components_Component_Properties_Property struct {
	Config *OpenconfigPlatform_Components_Component_Properties_Property_Config `path:"config" module:"openconfig-platform"`
	Name   *string                                                             `path:"name" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Properties_Property_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Properties_Property implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Properties_Property) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigPlatform_Components_Component_Properties_Property struct, which is a YANG list entry.
func (t *OpenconfigPlatform_Components_Component_Properties_Property) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Properties_Property) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Properties_Property"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Properties_Property) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config represents the /openconfig-platform/components/component/properties/property/config YANG schema element.
type OpenconfigPlatform_Components_Component_Properties_Property_Config struct {
	Name  *string                                                                        `path:"name" module:"openconfig-platform"`
	Value OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union `path:"value" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Properties_Property_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Properties_Property_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Properties_Property_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Properties_Property_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Properties_Property_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-platform/components/component/properties/property/config/value within the YANG schema.
type OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union interface {
	Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union()
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Bool is used when /openconfig-platform/components/component/properties/property/config/value
// is to be set to a bool value.
type OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Bool struct {
	Bool bool
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Bool
// implements the OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Bool) Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Float64 is used when /openconfig-platform/components/component/properties/property/config/value
// is to be set to a float64 value.
type OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Float64 struct {
	Float64 float64
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Float64
// implements the OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Float64) Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Int64 is used when /openconfig-platform/components/component/properties/property/config/value
// is to be set to a int64 value.
type OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Int64 struct {
	Int64 int64
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Int64
// implements the OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Int64) Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_String is used when /openconfig-platform/components/component/properties/property/config/value
// is to be set to a string value.
type OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_String struct {
	String string
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_String
// implements the OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_String) Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Uint64 is used when /openconfig-platform/components/component/properties/property/config/value
// is to be set to a uint64 value.
type OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Uint64 struct {
	Uint64 uint64
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Uint64
// implements the OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Uint64) Is_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union() {
}

// To_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigPlatform_Components_Component_Properties_Property_Config) To_OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union(i interface{}) (OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union, error) {
	switch v := i.(type) {
	case bool:
		return &OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Bool{v}, nil
	case float64:
		return &OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Float64{v}, nil
	case int64:
		return &OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Int64{v}, nil
	case string:
		return &OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_String{v}, nil
	case uint64:
		return &OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union_Uint64{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigPlatform_Components_Component_Properties_Property_Config_Value_Union, unknown union type, got: %T, want any of [bool, float64, int64, string, uint64]", i, i)
	}
}

// OpenconfigPlatform_Components_Component_Properties_Property_State represents the /openconfig-platform/components/component/properties/property/state YANG schema element.
type OpenconfigPlatform_Components_Component_Properties_Property_State struct {
	Configurable *bool                                                                         `path:"configurable" module:"openconfig-platform"`
	Name         *string                                                                       `path:"name" module:"openconfig-platform"`
	Value        OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union `path:"value" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Properties_Property_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Properties_Property_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Properties_Property_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Properties_Property_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Properties_Property_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-platform/components/component/properties/property/state/value within the YANG schema.
type OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union interface {
	Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union()
}

// OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Bool is used when /openconfig-platform/components/component/properties/property/state/value
// is to be set to a bool value.
type OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Bool struct {
	Bool bool
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Bool
// implements the OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Bool) Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Float64 is used when /openconfig-platform/components/component/properties/property/state/value
// is to be set to a float64 value.
type OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Float64 struct {
	Float64 float64
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Float64
// implements the OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Float64) Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Int64 is used when /openconfig-platform/components/component/properties/property/state/value
// is to be set to a int64 value.
type OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Int64 struct {
	Int64 int64
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Int64
// implements the OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Int64) Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_String is used when /openconfig-platform/components/component/properties/property/state/value
// is to be set to a string value.
type OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_String struct {
	String string
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_String
// implements the OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_String) Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union() {
}

// OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Uint64 is used when /openconfig-platform/components/component/properties/property/state/value
// is to be set to a uint64 value.
type OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Uint64 struct {
	Uint64 uint64
}

// Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union ensures that OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Uint64
// implements the OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union interface.
func (*OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Uint64) Is_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union() {
}

// To_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigPlatform_Components_Component_Properties_Property_State) To_OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union(i interface{}) (OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union, error) {
	switch v := i.(type) {
	case bool:
		return &OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Bool{v}, nil
	case float64:
		return &OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Float64{v}, nil
	case int64:
		return &OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Int64{v}, nil
	case string:
		return &OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_String{v}, nil
	case uint64:
		return &OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union_Uint64{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigPlatform_Components_Component_Properties_Property_State_Value_Union, unknown union type, got: %T, want any of [bool, float64, int64, string, uint64]", i, i)
	}
}

// OpenconfigPlatform_Components_Component_SoftwareModule represents the /openconfig-platform/components/component/software-module YANG schema element.
type OpenconfigPlatform_Components_Component_SoftwareModule struct {
	Config *OpenconfigPlatform_Components_Component_SoftwareModule_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_SoftwareModule_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_SoftwareModule implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_SoftwareModule) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_SoftwareModule) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_SoftwareModule"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_SoftwareModule) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_SoftwareModule_Config represents the /openconfig-platform/components/component/software-module/config YANG schema element.
type OpenconfigPlatform_Components_Component_SoftwareModule_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_SoftwareModule_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_SoftwareModule_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_SoftwareModule_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_SoftwareModule_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_SoftwareModule_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_SoftwareModule_State represents the /openconfig-platform/components/component/software-module/state YANG schema element.
type OpenconfigPlatform_Components_Component_SoftwareModule_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_SoftwareModule_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_SoftwareModule_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_SoftwareModule_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_SoftwareModule_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_SoftwareModule_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_State represents the /openconfig-platform/components/component/state YANG schema element.
type OpenconfigPlatform_Components_Component_State struct {
	AllocatedPower    *uint32                                                    `path:"allocated-power" module:"openconfig-platform"`
	Description       *string                                                    `path:"description" module:"openconfig-platform"`
	Empty             *bool                                                      `path:"empty" module:"openconfig-platform"`
	EquipmentFailure  *bool                                                      `path:"equipment-failure" module:"openconfig-alarms"`
	EquipmentMismatch *bool                                                      `path:"equipment-mismatch" module:"openconfig-alarms"`
	FirmwareVersion   *string                                                    `path:"firmware-version" module:"openconfig-platform"`
	HardwareVersion   *string                                                    `path:"hardware-version" module:"openconfig-platform"`
	Id                *string                                                    `path:"id" module:"openconfig-platform"`
	Location          *string                                                    `path:"location" module:"openconfig-platform"`
	Memory            *OpenconfigPlatform_Components_Component_State_Memory      `path:"memory" module:"openconfig-platform"`
	MfgDate           *string                                                    `path:"mfg-date" module:"openconfig-platform"`
	MfgName           *string                                                    `path:"mfg-name" module:"openconfig-platform"`
	Name              *string                                                    `path:"name" module:"openconfig-platform"`
	OperStatus        E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS            `path:"oper-status" module:"openconfig-platform"`
	Parent            *string                                                    `path:"parent" module:"openconfig-platform"`
	PartNo            *string                                                    `path:"part-no" module:"openconfig-platform"`
	Removable         *bool                                                      `path:"removable" module:"openconfig-platform"`
	SerialNo          *string                                                    `path:"serial-no" module:"openconfig-platform"`
	SoftwareVersion   *string                                                    `path:"software-version" module:"openconfig-platform"`
	Temperature       *OpenconfigPlatform_Components_Component_State_Temperature `path:"temperature" module:"openconfig-platform"`
	Type              OpenconfigPlatform_Components_Component_State_Type_Union   `path:"type" module:"openconfig-platform"`
	UsedPower         *uint32                                                    `path:"used-power" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_State_Type_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-platform/components/component/state/type within the YANG schema.
type OpenconfigPlatform_Components_Component_State_Type_Union interface {
	Is_OpenconfigPlatform_Components_Component_State_Type_Union()
}

// OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT is used when /openconfig-platform/components/component/state/type
// is to be set to a E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT value.
type OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT struct {
	E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
}

// Is_OpenconfigPlatform_Components_Component_State_Type_Union ensures that OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
// implements the OpenconfigPlatform_Components_Component_State_Type_Union interface.
func (*OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) Is_OpenconfigPlatform_Components_Component_State_Type_Union() {
}

// OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT is used when /openconfig-platform/components/component/state/type
// is to be set to a E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT value.
type OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT struct {
	E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
}

// Is_OpenconfigPlatform_Components_Component_State_Type_Union ensures that OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
// implements the OpenconfigPlatform_Components_Component_State_Type_Union interface.
func (*OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) Is_OpenconfigPlatform_Components_Component_State_Type_Union() {
}

// To_OpenconfigPlatform_Components_Component_State_Type_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigPlatform_Components_Component_State_Type_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigPlatform_Components_Component_State) To_OpenconfigPlatform_Components_Component_State_Type_Union(i interface{}) (OpenconfigPlatform_Components_Component_State_Type_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT:
		return &OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT{v}, nil
	case E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT:
		return &OpenconfigPlatform_Components_Component_State_Type_Union_E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigPlatform_Components_Component_State_Type_Union, unknown union type, got: %T, want any of [E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT, E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT]", i, i)
	}
}

// OpenconfigPlatform_Components_Component_State_Memory represents the /openconfig-platform/components/component/state/memory YANG schema element.
type OpenconfigPlatform_Components_Component_State_Memory struct {
	Available *uint64 `path:"available" module:"openconfig-platform"`
	Utilized  *uint64 `path:"utilized" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_State_Memory implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_State_Memory) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_State_Memory) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_State_Memory"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_State_Memory) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_State_Temperature represents the /openconfig-platform/components/component/state/temperature YANG schema element.
type OpenconfigPlatform_Components_Component_State_Temperature struct {
	AlarmSeverity  E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY `path:"alarm-severity" module:"openconfig-platform"`
	AlarmStatus    *bool                                            `path:"alarm-status" module:"openconfig-platform"`
	AlarmThreshold *uint32                                          `path:"alarm-threshold" module:"openconfig-platform"`
	Avg            *float64                                         `path:"avg" module:"openconfig-platform"`
	Instant        *float64                                         `path:"instant" module:"openconfig-platform"`
	Interval       *uint64                                          `path:"interval" module:"openconfig-platform"`
	Max            *float64                                         `path:"max" module:"openconfig-platform"`
	MaxTime        *uint64                                          `path:"max-time" module:"openconfig-platform"`
	Min            *float64                                         `path:"min" module:"openconfig-platform"`
	MinTime        *uint64                                          `path:"min-time" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_State_Temperature implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_State_Temperature) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_State_Temperature) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_State_Temperature"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_State_Temperature) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Storage represents the /openconfig-platform/components/component/storage YANG schema element.
type OpenconfigPlatform_Components_Component_Storage struct {
	Config *OpenconfigPlatform_Components_Component_Storage_Config `path:"config" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Storage_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Storage implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Storage) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Storage) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Storage"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Storage) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Storage_Config represents the /openconfig-platform/components/component/storage/config YANG schema element.
type OpenconfigPlatform_Components_Component_Storage_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Storage_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Storage_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Storage_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Storage_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Storage_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Storage_State represents the /openconfig-platform/components/component/storage/state YANG schema element.
type OpenconfigPlatform_Components_Component_Storage_State struct {
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Storage_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Storage_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Storage_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Storage_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Storage_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Subcomponents represents the /openconfig-platform/components/component/subcomponents YANG schema element.
type OpenconfigPlatform_Components_Component_Subcomponents struct {
	Subcomponent map[string]*OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent `path:"subcomponent" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Subcomponents implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Subcomponents) IsYANGGoStruct() {}

// NewSubcomponent creates a new entry in the Subcomponent list of the
// OpenconfigPlatform_Components_Component_Subcomponents struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigPlatform_Components_Component_Subcomponents) NewSubcomponent(Name string) (*OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Subcomponent == nil {
		t.Subcomponent = make(map[string]*OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Subcomponent[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Subcomponent", key)
	}

	t.Subcomponent[key] = &OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent{
		Name: &Name,
	}

	return t.Subcomponent[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Subcomponents) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Subcomponents"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Subcomponents) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent represents the /openconfig-platform/components/component/subcomponents/subcomponent YANG schema element.
type OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent struct {
	Config *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config `path:"config" module:"openconfig-platform"`
	Name   *string                                                                    `path:"name" module:"openconfig-platform"`
	State  *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State  `path:"state" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent struct, which is a YANG list entry.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config represents the /openconfig-platform/components/component/subcomponents/subcomponent/config YANG schema element.
type OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config struct {
	Name *string `path:"name" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State represents the /openconfig-platform/components/component/subcomponents/subcomponent/state YANG schema element.
type OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State struct {
	Name *string `path:"name" module:"openconfig-platform"`
}

// IsYANGGoStruct ensures that OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigPlatform_Components_Component_Subcomponents_Subcomponent_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy represents the /openconfig-routing-policy/routing-policy YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy struct {
	DefinedSets       *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets       `path:"defined-sets" module:"openconfig-routing-policy"`
	PolicyDefinitions *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions `path:"policy-definitions" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets represents the /openconfig-routing-policy/routing-policy/defined-sets YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets struct {
	NeighborSets *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets `path:"neighbor-sets" module:"openconfig-routing-policy"`
	PrefixSets   *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets   `path:"prefix-sets" module:"openconfig-routing-policy"`
	TagSets      *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets      `path:"tag-sets" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets represents the /openconfig-routing-policy/routing-policy/defined-sets/neighbor-sets YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets struct {
	NeighborSet map[string]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet `path:"neighbor-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets) IsYANGGoStruct() {}

// NewNeighborSet creates a new entry in the NeighborSet list of the
// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets) NewNeighborSet(Name string) (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NeighborSet == nil {
		t.NeighborSet = make(map[string]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NeighborSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NeighborSet", key)
	}

	t.NeighborSet[key] = &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet{
		Name: &Name,
	}

	return t.NeighborSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet represents the /openconfig-routing-policy/routing-policy/defined-sets/neighbor-sets/neighbor-set YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config `path:"config" module:"openconfig-routing-policy"`
	Name   *string                                                                            `path:"name" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet struct, which is a YANG list entry.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config represents the /openconfig-routing-policy/routing-policy/defined-sets/neighbor-sets/neighbor-set/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config struct {
	Address []string `path:"address" module:"openconfig-routing-policy"`
	Name    *string  `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State represents the /openconfig-routing-policy/routing-policy/defined-sets/neighbor-sets/neighbor-set/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State struct {
	Address []string `path:"address" module:"openconfig-routing-policy"`
	Name    *string  `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_NeighborSets_NeighborSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets struct {
	PrefixSet map[string]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet `path:"prefix-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets) IsYANGGoStruct() {}

// NewPrefixSet creates a new entry in the PrefixSet list of the
// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets) NewPrefixSet(Name string) (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PrefixSet == nil {
		t.PrefixSet = make(map[string]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PrefixSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PrefixSet", key)
	}

	t.PrefixSet[key] = &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet{
		Name: &Name,
	}

	return t.PrefixSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet struct {
	Config   *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config   `path:"config" module:"openconfig-routing-policy"`
	Name     *string                                                                          `path:"name" module:"openconfig-routing-policy"`
	Prefixes *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes `path:"prefixes" module:"openconfig-routing-policy"`
	State    *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State    `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet struct, which is a YANG list entry.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config struct {
	Mode E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode `path:"mode" module:"openconfig-routing-policy"`
	Name *string                                                                              `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/prefixes YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes struct {
	Prefix map[OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Key]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix `path:"prefix" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes) IsYANGGoStruct() {
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Key represents the key for list Prefix of element /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/prefixes.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Key struct {
	IpPrefix        string `path:"ip-prefix"`
	MasklengthRange string `path:"masklength-range"`
}

// NewPrefix creates a new entry in the Prefix list of the
// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes) NewPrefix(IpPrefix string, MasklengthRange string) (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Prefix == nil {
		t.Prefix = make(map[OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Key]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix)
	}

	key := OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Key{
		IpPrefix:        IpPrefix,
		MasklengthRange: MasklengthRange,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Prefix[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Prefix", key)
	}

	t.Prefix[key] = &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix{
		IpPrefix:        &IpPrefix,
		MasklengthRange: &MasklengthRange,
	}

	return t.Prefix[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/prefixes/prefix YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix struct {
	Config          *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config `path:"config" module:"openconfig-routing-policy"`
	IpPrefix        *string                                                                                        `path:"ip-prefix" module:"openconfig-routing-policy"`
	MasklengthRange *string                                                                                        `path:"masklength-range" module:"openconfig-routing-policy"`
	State           *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix struct, which is a YANG list entry.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix) ΛListKeyMap() (map[string]interface{}, error) {
	if t.IpPrefix == nil {
		return nil, fmt.Errorf("nil value for key IpPrefix")
	}

	if t.MasklengthRange == nil {
		return nil, fmt.Errorf("nil value for key MasklengthRange")
	}

	return map[string]interface{}{
		"ip-prefix":        *t.IpPrefix,
		"masklength-range": *t.MasklengthRange,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/prefixes/prefix/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config struct {
	IpPrefix        *string `path:"ip-prefix" module:"openconfig-routing-policy"`
	MasklengthRange *string `path:"masklength-range" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/prefixes/prefix/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State struct {
	IpPrefix        *string `path:"ip-prefix" module:"openconfig-routing-policy"`
	MasklengthRange *string `path:"masklength-range" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Prefixes_Prefix_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State represents the /openconfig-routing-policy/routing-policy/defined-sets/prefix-sets/prefix-set/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State struct {
	Mode E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode `path:"mode" module:"openconfig-routing-policy"`
	Name *string                                                                              `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets represents the /openconfig-routing-policy/routing-policy/defined-sets/tag-sets YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets struct {
	TagSet map[string]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet `path:"tag-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets) IsYANGGoStruct() {}

// NewTagSet creates a new entry in the TagSet list of the
// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets) NewTagSet(Name string) (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.TagSet == nil {
		t.TagSet = make(map[string]*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.TagSet[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list TagSet", key)
	}

	t.TagSet[key] = &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet{
		Name: &Name,
	}

	return t.TagSet[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet represents the /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config `path:"config" module:"openconfig-routing-policy"`
	Name   *string                                                                  `path:"name" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet struct, which is a YANG list entry.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config represents the /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config struct {
	Name     *string                                                                                  `path:"name" module:"openconfig-routing-policy"`
	TagValue []OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union `path:"tag-value" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/config/tag-value within the YANG schema.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union interface {
	Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union()
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_String is used when /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/config/tag-value
// is to be set to a string value.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_String struct {
	String string
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_String
// implements the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_String) Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union() {
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_Uint32 is used when /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/config/tag-value
// is to be set to a uint32 value.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_Uint32
// implements the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_Uint32) Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union() {
}

// To_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config) To_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union(i interface{}) (OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_String{v}, nil
	case uint32:
		return &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_Config_TagValue_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State represents the /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State struct {
	Name     *string                                                                                 `path:"name" module:"openconfig-routing-policy"`
	TagValue []OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union `path:"tag-value" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/state/tag-value within the YANG schema.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union interface {
	Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union()
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_String is used when /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/state/tag-value
// is to be set to a string value.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_String struct {
	String string
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_String
// implements the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_String) Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union() {
}

// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_Uint32 is used when /openconfig-routing-policy/routing-policy/defined-sets/tag-sets/tag-set/state/tag-value
// is to be set to a uint32 value.
type OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_Uint32
// implements the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_Uint32) Is_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union() {
}

// To_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State) To_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union(i interface{}) (OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_String{v}, nil
	case uint32:
		return &OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_TagSets_TagSet_State_TagValue_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions represents the /openconfig-routing-policy/routing-policy/policy-definitions YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions struct {
	PolicyDefinition map[string]*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition `path:"policy-definition" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions) IsYANGGoStruct() {}

// NewPolicyDefinition creates a new entry in the PolicyDefinition list of the
// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions) NewPolicyDefinition(Name string) (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.PolicyDefinition == nil {
		t.PolicyDefinition = make(map[string]*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.PolicyDefinition[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list PolicyDefinition", key)
	}

	t.PolicyDefinition[key] = &OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition{
		Name: &Name,
	}

	return t.PolicyDefinition[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition struct {
	Config     *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config     `path:"config" module:"openconfig-routing-policy"`
	Name       *string                                                                              `path:"name" module:"openconfig-routing-policy"`
	State      *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State      `path:"state" module:"openconfig-routing-policy"`
	Statements *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements `path:"statements" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition struct, which is a YANG list entry.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config struct {
	Name *string `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State struct {
	Name *string `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements struct {
	Statement map[string]*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement `path:"statement" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements) IsYANGGoStruct() {
}

// NewStatement creates a new entry in the Statement list of the
// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements) NewStatement(Name string) (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Statement == nil {
		t.Statement = make(map[string]*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Statement[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Statement", key)
	}

	t.Statement[key] = &OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement{
		Name: &Name,
	}

	return t.Statement[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement struct {
	Actions    *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions    `path:"actions" module:"openconfig-routing-policy"`
	Conditions *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions `path:"conditions" module:"openconfig-routing-policy"`
	Config     *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config     `path:"config" module:"openconfig-routing-policy"`
	Name       *string                                                                                                   `path:"name" module:"openconfig-routing-policy"`
	State      *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State      `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement struct, which is a YANG list entry.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config `path:"config" module:"openconfig-routing-policy"`
	SetTag *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag `path:"set-tag" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config struct {
	PolicyResult E_OpenconfigRoutingPolicy_PolicyResultType `path:"policy-result" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag struct {
	Config    *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config    `path:"config" module:"openconfig-routing-policy"`
	Inline    *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline    `path:"inline" module:"openconfig-routing-policy"`
	Reference *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference `path:"reference" module:"openconfig-routing-policy"`
	State     *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State     `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config struct {
	Mode E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode `path:"mode" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config `path:"config" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config struct {
	Tag []OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union `path:"tag" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/config/tag within the YANG schema.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union interface {
	Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union()
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_String is used when /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/config/tag
// is to be set to a string value.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_String struct {
	String string
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_String
// implements the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_String) Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union() {
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_Uint32 is used when /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/config/tag
// is to be set to a uint32 value.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_Uint32
// implements the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_Uint32) Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union() {
}

// To_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config) To_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union(i interface{}) (OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_String{v}, nil
	case uint32:
		return &OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_Config_Tag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State struct {
	Tag []OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union `path:"tag" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/state/tag within the YANG schema.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union interface {
	Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union()
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_String is used when /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/state/tag
// is to be set to a string value.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_String struct {
	String string
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_String
// implements the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_String) Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union() {
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_Uint32 is used when /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/inline/state/tag
// is to be set to a uint32 value.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_Uint32
// implements the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union interface.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_Uint32) Is_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union() {
}

// To_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State) To_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union(i interface{}) (OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union, error) {
	switch v := i.(type) {
	case string:
		return &OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_String{v}, nil
	case uint32:
		return &OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Inline_State_Tag_Union, unknown union type, got: %T, want any of [string, uint32]", i, i)
	}
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/reference YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config `path:"config" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/reference/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config struct {
	TagSet *string `path:"tag-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/reference/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State struct {
	TagSet *string `path:"tag-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Reference_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State struct {
	Mode E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode `path:"mode" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/actions/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State struct {
	PolicyResult E_OpenconfigRoutingPolicy_PolicyResultType `path:"policy-result" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions struct {
	Config           *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config           `path:"config" module:"openconfig-routing-policy"`
	MatchInterface   *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface   `path:"match-interface" module:"openconfig-routing-policy"`
	MatchNeighborSet *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet `path:"match-neighbor-set" module:"openconfig-routing-policy"`
	MatchPrefixSet   *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet   `path:"match-prefix-set" module:"openconfig-routing-policy"`
	MatchTagSet      *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet      `path:"match-tag-set" module:"openconfig-routing-policy"`
	State            *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State            `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config struct {
	CallPolicy        *string                                       `path:"call-policy" module:"openconfig-routing-policy"`
	InstallProtocolEq E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"install-protocol-eq" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-interface YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config `path:"config" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-interface/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config struct {
	Interface    *string `path:"interface" module:"openconfig-routing-policy"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-interface/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State struct {
	Interface    *string `path:"interface" module:"openconfig-routing-policy"`
	Subinterface *uint32 `path:"subinterface" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchInterface_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config `path:"config" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config struct {
	MatchSetOptions E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType `path:"match-set-options" module:"openconfig-routing-policy"`
	NeighborSet     *string                                                 `path:"neighbor-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State struct {
	MatchSetOptions E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType `path:"match-set-options" module:"openconfig-routing-policy"`
	NeighborSet     *string                                                 `path:"neighbor-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchNeighborSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config `path:"config" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config struct {
	MatchSetOptions E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType `path:"match-set-options" module:"openconfig-routing-policy"`
	PrefixSet       *string                                                 `path:"prefix-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State struct {
	MatchSetOptions E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType `path:"match-set-options" module:"openconfig-routing-policy"`
	PrefixSet       *string                                                 `path:"prefix-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchPrefixSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet struct {
	Config *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config `path:"config" module:"openconfig-routing-policy"`
	State  *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State  `path:"state" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config struct {
	MatchSetOptions E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType `path:"match-set-options" module:"openconfig-routing-policy"`
	TagSet          *string                                                 `path:"tag-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State struct {
	MatchSetOptions E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType `path:"match-set-options" module:"openconfig-routing-policy"`
	TagSet          *string                                                 `path:"tag-set" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_MatchTagSet_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State struct {
	CallPolicy        *string                                       `path:"call-policy" module:"openconfig-routing-policy"`
	InstallProtocolEq E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE `path:"install-protocol-eq" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Conditions_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/config YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config struct {
	Name *string `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State represents the /openconfig-routing-policy/routing-policy/policy-definitions/policy-definition/statements/statement/state YANG schema element.
type OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State struct {
	Name *string `path:"name" module:"openconfig-routing-policy"`
}

// IsYANGGoStruct ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System represents the /openconfig-system/system YANG schema element.
type OpenconfigSystem_System struct {
	Aaa          *OpenconfigSystem_System_Aaa          `path:"aaa" module:"openconfig-system"`
	Alarms       *OpenconfigSystem_System_Alarms       `path:"alarms" module:"openconfig-system"`
	Clock        *OpenconfigSystem_System_Clock        `path:"clock" module:"openconfig-system"`
	Config       *OpenconfigSystem_System_Config       `path:"config" module:"openconfig-system"`
	Cpus         *OpenconfigSystem_System_Cpus         `path:"cpus" module:"openconfig-system"`
	Dns          *OpenconfigSystem_System_Dns          `path:"dns" module:"openconfig-system"`
	GrpcServer   *OpenconfigSystem_System_GrpcServer   `path:"grpc-server" module:"openconfig-system"`
	License      *OpenconfigSystem_System_License      `path:"license" module:"openconfig-system"`
	Logging      *OpenconfigSystem_System_Logging      `path:"logging" module:"openconfig-system"`
	Memory       *OpenconfigSystem_System_Memory       `path:"memory" module:"openconfig-system"`
	Messages     *OpenconfigSystem_System_Messages     `path:"messages" module:"openconfig-system"`
	Ntp          *OpenconfigSystem_System_Ntp          `path:"ntp" module:"openconfig-system"`
	Openflow     *OpenconfigSystem_System_Openflow     `path:"openflow" module:"openconfig-openflow"`
	Processes    *OpenconfigSystem_System_Processes    `path:"processes" module:"openconfig-system"`
	SshServer    *OpenconfigSystem_System_SshServer    `path:"ssh-server" module:"openconfig-system"`
	State        *OpenconfigSystem_System_State        `path:"state" module:"openconfig-system"`
	TelnetServer *OpenconfigSystem_System_TelnetServer `path:"telnet-server" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_Aaa represents the /openconfig-system/system/aaa YANG schema element.
type OpenconfigSystem_System_Aaa struct {
	Accounting     *OpenconfigSystem_System_Aaa_Accounting     `path:"accounting" module:"openconfig-system"`
	Authentication *OpenconfigSystem_System_Aaa_Authentication `path:"authentication" module:"openconfig-system"`
	Authorization  *OpenconfigSystem_System_Aaa_Authorization  `path:"authorization" module:"openconfig-system"`
	Config         *OpenconfigSystem_System_Aaa_Config         `path:"config" module:"openconfig-system"`
	ServerGroups   *OpenconfigSystem_System_Aaa_ServerGroups   `path:"server-groups" module:"openconfig-system"`
	State          *OpenconfigSystem_System_Aaa_State          `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_Aaa_Accounting represents the /openconfig-system/system/aaa/accounting YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting struct {
	Config *OpenconfigSystem_System_Aaa_Accounting_Config `path:"config" module:"openconfig-system"`
	Events *OpenconfigSystem_System_Aaa_Accounting_Events `path:"events" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Aaa_Accounting_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_Config represents the /openconfig-system/system/aaa/accounting/config YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting_Config struct {
	AccountingMethod []OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union `path:"accounting-method" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/accounting/config/accounting-method within the YANG schema.
type OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union interface {
	Is_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union()
}

// OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE is used when /openconfig-system/system/aaa/accounting/config/accounting-method
// is to be set to a E_OpenconfigAaaTypes_AAA_METHOD_TYPE value.
type OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE struct {
	E_OpenconfigAaaTypes_AAA_METHOD_TYPE E_OpenconfigAaaTypes_AAA_METHOD_TYPE
}

// Is_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union ensures that OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Is_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union() {
}

// OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_String is used when /openconfig-system/system/aaa/accounting/config/accounting-method
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union ensures that OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_String
// implements the OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_String) Is_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union() {
}

// To_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Accounting_Config) To_OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union(i interface{}) (OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_AAA_METHOD_TYPE:
		return &OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Accounting_Config_AccountingMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Accounting_Events represents the /openconfig-system/system/aaa/accounting/events YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting_Events struct {
	Event map[E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE]*OpenconfigSystem_System_Aaa_Accounting_Events_Event `path:"event" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting_Events implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting_Events) IsYANGGoStruct() {}

// NewEvent creates a new entry in the Event list of the
// OpenconfigSystem_System_Aaa_Accounting_Events struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events) NewEvent(EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) (*OpenconfigSystem_System_Aaa_Accounting_Events_Event, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Event == nil {
		t.Event = make(map[E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE]*OpenconfigSystem_System_Aaa_Accounting_Events_Event)
	}

	key := EventType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Event[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Event", key)
	}

	t.Event[key] = &OpenconfigSystem_System_Aaa_Accounting_Events_Event{
		EventType: EventType,
	}

	return t.Event[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting_Events"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_Events_Event represents the /openconfig-system/system/aaa/accounting/events/event YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting_Events_Event struct {
	Config    *OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config `path:"config" module:"openconfig-system"`
	EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE              `path:"event-type" module:"openconfig-system"`
	State     *OpenconfigSystem_System_Aaa_Accounting_Events_Event_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting_Events_Event implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting_Events_Event) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Aaa_Accounting_Events_Event struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"event-type": t.EventType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting_Events_Event"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config represents the /openconfig-system/system/aaa/accounting/events/event/config YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config struct {
	EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE                      `path:"event-type" module:"openconfig-system"`
	Record    E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record `path:"record" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_Events_Event_State represents the /openconfig-system/system/aaa/accounting/events/event/state YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting_Events_Event_State struct {
	EventType E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE                      `path:"event-type" module:"openconfig-system"`
	Record    E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record `path:"record" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting_Events_Event_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting_Events_Event_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting_Events_Event_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting_Events_Event_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_State represents the /openconfig-system/system/aaa/accounting/state YANG schema element.
type OpenconfigSystem_System_Aaa_Accounting_State struct {
	AccountingMethod []OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union `path:"accounting-method" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Accounting_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Accounting_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Accounting_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Accounting_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Accounting_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/accounting/state/accounting-method within the YANG schema.
type OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union interface {
	Is_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union()
}

// OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE is used when /openconfig-system/system/aaa/accounting/state/accounting-method
// is to be set to a E_OpenconfigAaaTypes_AAA_METHOD_TYPE value.
type OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE struct {
	E_OpenconfigAaaTypes_AAA_METHOD_TYPE E_OpenconfigAaaTypes_AAA_METHOD_TYPE
}

// Is_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union ensures that OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Is_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union() {
}

// OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_String is used when /openconfig-system/system/aaa/accounting/state/accounting-method
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union ensures that OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_String
// implements the OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_String) Is_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union() {
}

// To_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Accounting_State) To_OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union(i interface{}) (OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_AAA_METHOD_TYPE:
		return &OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Accounting_State_AccountingMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Authentication represents the /openconfig-system/system/aaa/authentication YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication struct {
	AdminUser *OpenconfigSystem_System_Aaa_Authentication_AdminUser `path:"admin-user" module:"openconfig-system"`
	Config    *OpenconfigSystem_System_Aaa_Authentication_Config    `path:"config" module:"openconfig-system"`
	State     *OpenconfigSystem_System_Aaa_Authentication_State     `path:"state" module:"openconfig-system"`
	Users     *OpenconfigSystem_System_Aaa_Authentication_Users     `path:"users" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_AdminUser represents the /openconfig-system/system/aaa/authentication/admin-user YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_AdminUser struct {
	Config *OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Aaa_Authentication_AdminUser_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_AdminUser implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_AdminUser) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_AdminUser) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_AdminUser"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_AdminUser) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config represents the /openconfig-system/system/aaa/authentication/admin-user/config YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config struct {
	AdminPassword       *string `path:"admin-password" module:"openconfig-system"`
	AdminPasswordHashed *string `path:"admin-password-hashed" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_AdminUser_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_AdminUser_State represents the /openconfig-system/system/aaa/authentication/admin-user/state YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_AdminUser_State struct {
	AdminPassword       *string `path:"admin-password" module:"openconfig-system"`
	AdminPasswordHashed *string `path:"admin-password-hashed" module:"openconfig-system"`
	AdminUsername       *string `path:"admin-username" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_AdminUser_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_AdminUser_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_AdminUser_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_AdminUser_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_AdminUser_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_Config represents the /openconfig-system/system/aaa/authentication/config YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_Config struct {
	AuthenticationMethod []OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union `path:"authentication-method" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authentication/config/authentication-method within the YANG schema.
type OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union interface {
	Is_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union()
}

// OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE is used when /openconfig-system/system/aaa/authentication/config/authentication-method
// is to be set to a E_OpenconfigAaaTypes_AAA_METHOD_TYPE value.
type OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE struct {
	E_OpenconfigAaaTypes_AAA_METHOD_TYPE E_OpenconfigAaaTypes_AAA_METHOD_TYPE
}

// Is_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Is_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union() {
}

// OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_String is used when /openconfig-system/system/aaa/authentication/config/authentication-method
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_String
// implements the OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_String) Is_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union() {
}

// To_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Authentication_Config) To_OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union(i interface{}) (OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_AAA_METHOD_TYPE:
		return &OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Authentication_Config_AuthenticationMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Authentication_State represents the /openconfig-system/system/aaa/authentication/state YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_State struct {
	AuthenticationMethod []OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union `path:"authentication-method" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authentication/state/authentication-method within the YANG schema.
type OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union interface {
	Is_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union()
}

// OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE is used when /openconfig-system/system/aaa/authentication/state/authentication-method
// is to be set to a E_OpenconfigAaaTypes_AAA_METHOD_TYPE value.
type OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE struct {
	E_OpenconfigAaaTypes_AAA_METHOD_TYPE E_OpenconfigAaaTypes_AAA_METHOD_TYPE
}

// Is_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Is_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union() {
}

// OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_String is used when /openconfig-system/system/aaa/authentication/state/authentication-method
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_String
// implements the OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_String) Is_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union() {
}

// To_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Authentication_State) To_OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union(i interface{}) (OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_AAA_METHOD_TYPE:
		return &OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Authentication_State_AuthenticationMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Authentication_Users represents the /openconfig-system/system/aaa/authentication/users YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_Users struct {
	User map[string]*OpenconfigSystem_System_Aaa_Authentication_Users_User `path:"user" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_Users implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_Users) IsYANGGoStruct() {}

// NewUser creates a new entry in the User list of the
// OpenconfigSystem_System_Aaa_Authentication_Users struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users) NewUser(Username string) (*OpenconfigSystem_System_Aaa_Authentication_Users_User, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.User == nil {
		t.User = make(map[string]*OpenconfigSystem_System_Aaa_Authentication_Users_User)
	}

	key := Username

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.User[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list User", key)
	}

	t.User[key] = &OpenconfigSystem_System_Aaa_Authentication_Users_User{
		Username: &Username,
	}

	return t.User[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_Users"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User represents the /openconfig-system/system/aaa/authentication/users/user YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_Users_User struct {
	Config   *OpenconfigSystem_System_Aaa_Authentication_Users_User_Config `path:"config" module:"openconfig-system"`
	State    *OpenconfigSystem_System_Aaa_Authentication_Users_User_State  `path:"state" module:"openconfig-system"`
	Username *string                                                       `path:"username" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Aaa_Authentication_Users_User struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Username == nil {
		return nil, fmt.Errorf("nil value for key Username")
	}

	return map[string]interface{}{
		"username": *t.Username,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_Users_User"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_Config represents the /openconfig-system/system/aaa/authentication/users/user/config YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_Config struct {
	Password       *string                                                                 `path:"password" module:"openconfig-system"`
	PasswordHashed *string                                                                 `path:"password-hashed" module:"openconfig-system"`
	Role           OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union `path:"role" module:"openconfig-system"`
	SshKey         *string                                                                 `path:"ssh-key" module:"openconfig-system"`
	Username       *string                                                                 `path:"username" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_Users_User_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authentication/users/user/config/role within the YANG schema.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union interface {
	Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union()
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES is used when /openconfig-system/system/aaa/authentication/users/user/config/role
// is to be set to a E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES value.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES struct {
	E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
}

// Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
// implements the OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union() {
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_String is used when /openconfig-system/system/aaa/authentication/users/user/config/role
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_String
// implements the OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_String) Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union() {
}

// To_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User_Config) To_OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union(i interface{}) (OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES:
		return &OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Authentication_Users_User_Config_Role_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_State represents the /openconfig-system/system/aaa/authentication/users/user/state YANG schema element.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_State struct {
	Password       *string                                                                `path:"password" module:"openconfig-system"`
	PasswordHashed *string                                                                `path:"password-hashed" module:"openconfig-system"`
	Role           OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union `path:"role" module:"openconfig-system"`
	SshKey         *string                                                                `path:"ssh-key" module:"openconfig-system"`
	Username       *string                                                                `path:"username" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authentication_Users_User_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authentication/users/user/state/role within the YANG schema.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union interface {
	Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union()
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES is used when /openconfig-system/system/aaa/authentication/users/user/state/role
// is to be set to a E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES value.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES struct {
	E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
}

// Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
// implements the OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union() {
}

// OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_String is used when /openconfig-system/system/aaa/authentication/users/user/state/role
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union ensures that OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_String
// implements the OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union interface.
func (*OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_String) Is_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union() {
}

// To_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Authentication_Users_User_State) To_OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union(i interface{}) (OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES:
		return &OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Authentication_Users_User_State_Role_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Authorization represents the /openconfig-system/system/aaa/authorization YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization struct {
	Config *OpenconfigSystem_System_Aaa_Authorization_Config `path:"config" module:"openconfig-system"`
	Events *OpenconfigSystem_System_Aaa_Authorization_Events `path:"events" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Aaa_Authorization_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_Config represents the /openconfig-system/system/aaa/authorization/config YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization_Config struct {
	AuthorizationMethod []OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union `path:"authorization-method" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authorization/config/authorization-method within the YANG schema.
type OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union interface {
	Is_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union()
}

// OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE is used when /openconfig-system/system/aaa/authorization/config/authorization-method
// is to be set to a E_OpenconfigAaaTypes_AAA_METHOD_TYPE value.
type OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE struct {
	E_OpenconfigAaaTypes_AAA_METHOD_TYPE E_OpenconfigAaaTypes_AAA_METHOD_TYPE
}

// Is_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Is_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union() {
}

// OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_String is used when /openconfig-system/system/aaa/authorization/config/authorization-method
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_String
// implements the OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_String) Is_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union() {
}

// To_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Authorization_Config) To_OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union(i interface{}) (OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_AAA_METHOD_TYPE:
		return &OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Authorization_Config_AuthorizationMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Authorization_Events represents the /openconfig-system/system/aaa/authorization/events YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization_Events struct {
	Event map[E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE]*OpenconfigSystem_System_Aaa_Authorization_Events_Event `path:"event" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization_Events implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization_Events) IsYANGGoStruct() {}

// NewEvent creates a new entry in the Event list of the
// OpenconfigSystem_System_Aaa_Authorization_Events struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events) NewEvent(EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) (*OpenconfigSystem_System_Aaa_Authorization_Events_Event, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Event == nil {
		t.Event = make(map[E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE]*OpenconfigSystem_System_Aaa_Authorization_Events_Event)
	}

	key := EventType

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Event[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Event", key)
	}

	t.Event[key] = &OpenconfigSystem_System_Aaa_Authorization_Events_Event{
		EventType: EventType,
	}

	return t.Event[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization_Events"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_Events_Event represents the /openconfig-system/system/aaa/authorization/events/event YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization_Events_Event struct {
	Config    *OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config `path:"config" module:"openconfig-system"`
	EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE              `path:"event-type" module:"openconfig-system"`
	State     *OpenconfigSystem_System_Aaa_Authorization_Events_Event_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization_Events_Event implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization_Events_Event) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Aaa_Authorization_Events_Event struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"event-type": t.EventType,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization_Events_Event"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config represents the /openconfig-system/system/aaa/authorization/events/event/config YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config struct {
	EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE `path:"event-type" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_Events_Event_State represents the /openconfig-system/system/aaa/authorization/events/event/state YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization_Events_Event_State struct {
	EventType E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE `path:"event-type" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization_Events_Event_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization_Events_Event_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization_Events_Event_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization_Events_Event_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_State represents the /openconfig-system/system/aaa/authorization/state YANG schema element.
type OpenconfigSystem_System_Aaa_Authorization_State struct {
	AuthorizationMethod []OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union `path:"authorization-method" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Authorization_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Authorization_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Authorization_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Authorization_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Authorization_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/aaa/authorization/state/authorization-method within the YANG schema.
type OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union interface {
	Is_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union()
}

// OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE is used when /openconfig-system/system/aaa/authorization/state/authorization-method
// is to be set to a E_OpenconfigAaaTypes_AAA_METHOD_TYPE value.
type OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE struct {
	E_OpenconfigAaaTypes_AAA_METHOD_TYPE E_OpenconfigAaaTypes_AAA_METHOD_TYPE
}

// Is_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE
// implements the OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE) Is_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union() {
}

// OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_String is used when /openconfig-system/system/aaa/authorization/state/authorization-method
// is to be set to a string value.
type OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union ensures that OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_String
// implements the OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union interface.
func (*OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_String) Is_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union() {
}

// To_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Aaa_Authorization_State) To_OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union(i interface{}) (OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAaaTypes_AAA_METHOD_TYPE:
		return &OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_E_OpenconfigAaaTypes_AAA_METHOD_TYPE{v}, nil
	case string:
		return &OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Aaa_Authorization_State_AuthorizationMethod_Union, unknown union type, got: %T, want any of [E_OpenconfigAaaTypes_AAA_METHOD_TYPE, string]", i, i)
	}
}

// OpenconfigSystem_System_Aaa_Config represents the /openconfig-system/system/aaa/config YANG schema element.
type OpenconfigSystem_System_Aaa_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups represents the /openconfig-system/system/aaa/server-groups YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups struct {
	ServerGroup map[string]*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup `path:"server-group" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups) IsYANGGoStruct() {}

// NewServerGroup creates a new entry in the ServerGroup list of the
// OpenconfigSystem_System_Aaa_ServerGroups struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Aaa_ServerGroups) NewServerGroup(Name string) (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.ServerGroup == nil {
		t.ServerGroup = make(map[string]*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.ServerGroup[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list ServerGroup", key)
	}

	t.ServerGroup[key] = &OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup{
		Name: &Name,
	}

	return t.ServerGroup[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup represents the /openconfig-system/system/aaa/server-groups/server-group YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup struct {
	Config  *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config  `path:"config" module:"openconfig-system"`
	Name    *string                                                       `path:"name" module:"openconfig-system"`
	Servers *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers `path:"servers" module:"openconfig-system"`
	State   *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State   `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config represents the /openconfig-system/system/aaa/server-groups/server-group/config YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config struct {
	Name *string                              `path:"name" module:"openconfig-system"`
	Type E_OpenconfigAaaTypes_AAA_SERVER_TYPE `path:"type" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers represents the /openconfig-system/system/aaa/server-groups/server-group/servers YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers struct {
	Server map[string]*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server `path:"server" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers) IsYANGGoStruct() {}

// NewServer creates a new entry in the Server list of the
// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers) NewServer(Address string) (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Server[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Server", key)
	}

	t.Server[key] = &OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server{
		Address: &Address,
	}

	return t.Server[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server struct {
	Address *string                                                                     `path:"address" module:"openconfig-system"`
	Config  *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config `path:"config" module:"openconfig-system"`
	Radius  *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius `path:"radius" module:"openconfig-system"`
	State   *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State  `path:"state" module:"openconfig-system"`
	Tacacs  *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs `path:"tacacs" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/config YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config struct {
	Address *string `path:"address" module:"openconfig-system"`
	Name    *string `path:"name" module:"openconfig-system"`
	Timeout *uint16 `path:"timeout" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/radius YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius struct {
	Config *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/radius/config YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config struct {
	AcctPort           *uint16 `path:"acct-port" module:"openconfig-system"`
	AuthPort           *uint16 `path:"auth-port" module:"openconfig-system"`
	RetransmitAttempts *uint8  `path:"retransmit-attempts" module:"openconfig-system"`
	SecretKey          *string `path:"secret-key" module:"openconfig-system"`
	SecretKeyHashed    *string `path:"secret-key-hashed" module:"openconfig-system"`
	SourceAddress      *string `path:"source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/radius/state YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State struct {
	AcctPort           *uint16                                                                                    `path:"acct-port" module:"openconfig-system"`
	AuthPort           *uint16                                                                                    `path:"auth-port" module:"openconfig-system"`
	Counters           *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters `path:"counters" module:"openconfig-system"`
	RetransmitAttempts *uint8                                                                                     `path:"retransmit-attempts" module:"openconfig-system"`
	SecretKey          *string                                                                                    `path:"secret-key" module:"openconfig-system"`
	SecretKeyHashed    *string                                                                                    `path:"secret-key-hashed" module:"openconfig-system"`
	SourceAddress      *string                                                                                    `path:"source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/radius/state/counters YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters struct {
	AccessAccepts         *uint64 `path:"access-accepts" module:"openconfig-system"`
	AccessRejects         *uint64 `path:"access-rejects" module:"openconfig-system"`
	RetriedAccessRequests *uint64 `path:"retried-access-requests" module:"openconfig-system"`
	TimeoutAccessRequests *uint64 `path:"timeout-access-requests" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Radius_State_Counters) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/state YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State struct {
	Address            *string `path:"address" module:"openconfig-system"`
	ConnectionAborts   *uint64 `path:"connection-aborts" module:"openconfig-system"`
	ConnectionCloses   *uint64 `path:"connection-closes" module:"openconfig-system"`
	ConnectionFailures *uint64 `path:"connection-failures" module:"openconfig-system"`
	ConnectionOpens    *uint64 `path:"connection-opens" module:"openconfig-system"`
	ConnectionTimeouts *uint64 `path:"connection-timeouts" module:"openconfig-system"`
	ErrorsReceived     *uint64 `path:"errors-received" module:"openconfig-system"`
	MessagesReceived   *uint64 `path:"messages-received" module:"openconfig-system"`
	MessagesSent       *uint64 `path:"messages-sent" module:"openconfig-system"`
	Name               *string `path:"name" module:"openconfig-system"`
	Timeout            *uint16 `path:"timeout" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/tacacs YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs struct {
	Config *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/tacacs/config YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config struct {
	Port            *uint16 `path:"port" module:"openconfig-system"`
	SecretKey       *string `path:"secret-key" module:"openconfig-system"`
	SecretKeyHashed *string `path:"secret-key-hashed" module:"openconfig-system"`
	SourceAddress   *string `path:"source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State represents the /openconfig-system/system/aaa/server-groups/server-group/servers/server/tacacs/state YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State struct {
	Port            *uint16 `path:"port" module:"openconfig-system"`
	SecretKey       *string `path:"secret-key" module:"openconfig-system"`
	SecretKeyHashed *string `path:"secret-key-hashed" module:"openconfig-system"`
	SourceAddress   *string `path:"source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_Servers_Server_Tacacs_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State represents the /openconfig-system/system/aaa/server-groups/server-group/state YANG schema element.
type OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State struct {
	Name *string                              `path:"name" module:"openconfig-system"`
	Type E_OpenconfigAaaTypes_AAA_SERVER_TYPE `path:"type" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_ServerGroups_ServerGroup_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Aaa_State represents the /openconfig-system/system/aaa/state YANG schema element.
type OpenconfigSystem_System_Aaa_State struct {
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Aaa_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Aaa_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Aaa_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Aaa_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Aaa_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Alarms represents the /openconfig-system/system/alarms YANG schema element.
type OpenconfigSystem_System_Alarms struct {
	Alarm map[string]*OpenconfigSystem_System_Alarms_Alarm `path:"alarm" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Alarms implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Alarms) IsYANGGoStruct() {}

// NewAlarm creates a new entry in the Alarm list of the
// OpenconfigSystem_System_Alarms struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Alarms) NewAlarm(Id string) (*OpenconfigSystem_System_Alarms_Alarm, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Alarm == nil {
		t.Alarm = make(map[string]*OpenconfigSystem_System_Alarms_Alarm)
	}

	key := Id

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Alarm[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Alarm", key)
	}

	t.Alarm[key] = &OpenconfigSystem_System_Alarms_Alarm{
		Id: &Id,
	}

	return t.Alarm[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Alarms) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Alarms"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Alarms) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Alarms_Alarm represents the /openconfig-system/system/alarms/alarm YANG schema element.
type OpenconfigSystem_System_Alarms_Alarm struct {
	Config *OpenconfigSystem_System_Alarms_Alarm_Config `path:"config" module:"openconfig-system"`
	Id     *string                                      `path:"id" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Alarms_Alarm_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Alarms_Alarm implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Alarms_Alarm) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Alarms_Alarm struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Alarms_Alarm) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Id == nil {
		return nil, fmt.Errorf("nil value for key Id")
	}

	return map[string]interface{}{
		"id": *t.Id,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Alarms_Alarm) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Alarms_Alarm"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Alarms_Alarm) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Alarms_Alarm_Config represents the /openconfig-system/system/alarms/alarm/config YANG schema element.
type OpenconfigSystem_System_Alarms_Alarm_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Alarms_Alarm_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Alarms_Alarm_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Alarms_Alarm_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Alarms_Alarm_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Alarms_Alarm_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Alarms_Alarm_State represents the /openconfig-system/system/alarms/alarm/state YANG schema element.
type OpenconfigSystem_System_Alarms_Alarm_State struct {
	Id          *string                                                 `path:"id" module:"openconfig-system"`
	Resource    *string                                                 `path:"resource" module:"openconfig-system"`
	Severity    E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY        `path:"severity" module:"openconfig-system"`
	Text        *string                                                 `path:"text" module:"openconfig-system"`
	TimeCreated *uint64                                                 `path:"time-created" module:"openconfig-system"`
	TypeId      OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union `path:"type-id" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Alarms_Alarm_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Alarms_Alarm_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Alarms_Alarm_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Alarms_Alarm_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Alarms_Alarm_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/alarms/alarm/state/type-id within the YANG schema.
type OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union interface {
	Is_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union()
}

// OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID is used when /openconfig-system/system/alarms/alarm/state/type-id
// is to be set to a E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID value.
type OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID struct {
	E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
}

// Is_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union ensures that OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
// implements the OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union interface.
func (*OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) Is_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union() {
}

// OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_String is used when /openconfig-system/system/alarms/alarm/state/type-id
// is to be set to a string value.
type OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union ensures that OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_String
// implements the OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union interface.
func (*OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_String) Is_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union() {
}

// To_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Alarms_Alarm_State) To_OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union(i interface{}) (OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID:
		return &OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID{v}, nil
	case string:
		return &OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Alarms_Alarm_State_TypeId_Union, unknown union type, got: %T, want any of [E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID, string]", i, i)
	}
}

// OpenconfigSystem_System_Clock represents the /openconfig-system/system/clock YANG schema element.
type OpenconfigSystem_System_Clock struct {
	Config *OpenconfigSystem_System_Clock_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Clock_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Clock implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Clock) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Clock) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Clock"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Clock) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_Clock_Config represents the /openconfig-system/system/clock/config YANG schema element.
type OpenconfigSystem_System_Clock_Config struct {
	TimezoneName *string `path:"timezone-name" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Clock_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Clock_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Clock_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Clock_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Clock_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Clock_State represents the /openconfig-system/system/clock/state YANG schema element.
type OpenconfigSystem_System_Clock_State struct {
	TimezoneName *string `path:"timezone-name" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Clock_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Clock_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Clock_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Clock_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Clock_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Config represents the /openconfig-system/system/config YANG schema element.
type OpenconfigSystem_System_Config struct {
	DomainName  *string `path:"domain-name" module:"openconfig-system"`
	Hostname    *string `path:"hostname" module:"openconfig-system"`
	LoginBanner *string `path:"login-banner" module:"openconfig-system"`
	MotdBanner  *string `path:"motd-banner" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus represents the /openconfig-system/system/cpus YANG schema element.
type OpenconfigSystem_System_Cpus struct {
	Cpu map[OpenconfigSystem_System_Cpus_Cpu_State_Index_Union]*OpenconfigSystem_System_Cpus_Cpu `path:"cpu" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus) IsYANGGoStruct() {}

// NewCpu creates a new entry in the Cpu list of the
// OpenconfigSystem_System_Cpus struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Cpus) NewCpu(Index OpenconfigSystem_System_Cpus_Cpu_State_Index_Union) (*OpenconfigSystem_System_Cpus_Cpu, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Cpu == nil {
		t.Cpu = make(map[OpenconfigSystem_System_Cpus_Cpu_State_Index_Union]*OpenconfigSystem_System_Cpus_Cpu)
	}

	key := Index

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Cpu[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Cpu", key)
	}

	t.Cpu[key] = &OpenconfigSystem_System_Cpus_Cpu{
		Index: Index,
	}

	return t.Cpu[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_Cpus_Cpu represents the /openconfig-system/system/cpus/cpu YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu struct {
	Index OpenconfigSystem_System_Cpus_Cpu_State_Index_Union `path:"index" module:"openconfig-system"`
	State *OpenconfigSystem_System_Cpus_Cpu_State            `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Cpus_Cpu struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Cpus_Cpu) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"index": t.Index,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_Index_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/cpus/cpu/index within the YANG schema.
type OpenconfigSystem_System_Cpus_Cpu_State_Index_Union interface {
	Is_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union()
}

// OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_E_OpenconfigSystem_System_Cpus_Cpu_State_Index is used when /openconfig-system/system/cpus/cpu/index
// is to be set to a E_OpenconfigSystem_System_Cpus_Cpu_State_Index value.
type OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_E_OpenconfigSystem_System_Cpus_Cpu_State_Index struct {
	E_OpenconfigSystem_System_Cpus_Cpu_State_Index E_OpenconfigSystem_System_Cpus_Cpu_State_Index
}

// Is_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union ensures that OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_E_OpenconfigSystem_System_Cpus_Cpu_State_Index
// implements the OpenconfigSystem_System_Cpus_Cpu_State_Index_Union interface.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_E_OpenconfigSystem_System_Cpus_Cpu_State_Index) Is_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union() {
}

// OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_Uint32 is used when /openconfig-system/system/cpus/cpu/index
// is to be set to a uint32 value.
type OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_Uint32 struct {
	Uint32 uint32
}

// Is_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union ensures that OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_Uint32
// implements the OpenconfigSystem_System_Cpus_Cpu_State_Index_Union interface.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_Uint32) Is_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union() {
}

// To_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Cpus_Cpu_State_Index_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Cpus_Cpu) To_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union(i interface{}) (OpenconfigSystem_System_Cpus_Cpu_State_Index_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigSystem_System_Cpus_Cpu_State_Index:
		return &OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_E_OpenconfigSystem_System_Cpus_Cpu_State_Index{v}, nil
	case uint32:
		return &OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Cpus_Cpu_State_Index_Union, unknown union type, got: %T, want any of [E_OpenconfigSystem_System_Cpus_Cpu_State_Index, uint32]", i, i)
	}
}

// OpenconfigSystem_System_Cpus_Cpu_State represents the /openconfig-system/system/cpus/cpu/state YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State struct {
	HardwareInterrupt *OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt `path:"hardware-interrupt" module:"openconfig-system"`
	Idle              *OpenconfigSystem_System_Cpus_Cpu_State_Idle              `path:"idle" module:"openconfig-system"`
	Index             OpenconfigSystem_System_Cpus_Cpu_State_Index_Union        `path:"index" module:"openconfig-system"`
	Kernel            *OpenconfigSystem_System_Cpus_Cpu_State_Kernel            `path:"kernel" module:"openconfig-system"`
	Nice              *OpenconfigSystem_System_Cpus_Cpu_State_Nice              `path:"nice" module:"openconfig-system"`
	SoftwareInterrupt *OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt `path:"software-interrupt" module:"openconfig-system"`
	Total             *OpenconfigSystem_System_Cpus_Cpu_State_Total             `path:"total" module:"openconfig-system"`
	User              *OpenconfigSystem_System_Cpus_Cpu_State_User              `path:"user" module:"openconfig-system"`
	Wait              *OpenconfigSystem_System_Cpus_Cpu_State_Wait              `path:"wait" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// To_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_Cpus_Cpu_State_Index_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_Cpus_Cpu_State) To_OpenconfigSystem_System_Cpus_Cpu_State_Index_Union(i interface{}) (OpenconfigSystem_System_Cpus_Cpu_State_Index_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigSystem_System_Cpus_Cpu_State_Index:
		return &OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_E_OpenconfigSystem_System_Cpus_Cpu_State_Index{v}, nil
	case uint32:
		return &OpenconfigSystem_System_Cpus_Cpu_State_Index_Union_Uint32{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_Cpus_Cpu_State_Index_Union, unknown union type, got: %T, want any of [E_OpenconfigSystem_System_Cpus_Cpu_State_Index, uint32]", i, i)
	}
}

// OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt represents the /openconfig-system/system/cpus/cpu/state/hardware-interrupt YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_HardwareInterrupt) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_Idle represents the /openconfig-system/system/cpus/cpu/state/idle YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_Idle struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_Idle implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Idle) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Idle) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_Idle"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Idle) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_Kernel represents the /openconfig-system/system/cpus/cpu/state/kernel YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_Kernel struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_Kernel implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Kernel) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Kernel) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_Kernel"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Kernel) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_Nice represents the /openconfig-system/system/cpus/cpu/state/nice YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_Nice struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_Nice implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Nice) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Nice) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_Nice"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Nice) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt represents the /openconfig-system/system/cpus/cpu/state/software-interrupt YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_SoftwareInterrupt) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_Total represents the /openconfig-system/system/cpus/cpu/state/total YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_Total struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_Total implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Total) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Total) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_Total"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Total) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_User represents the /openconfig-system/system/cpus/cpu/state/user YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_User struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_User implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_User) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_User) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_User"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_User) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Cpus_Cpu_State_Wait represents the /openconfig-system/system/cpus/cpu/state/wait YANG schema element.
type OpenconfigSystem_System_Cpus_Cpu_State_Wait struct {
	Avg      *uint8  `path:"avg" module:"openconfig-system"`
	Instant  *uint8  `path:"instant" module:"openconfig-system"`
	Interval *uint64 `path:"interval" module:"openconfig-system"`
	Max      *uint8  `path:"max" module:"openconfig-system"`
	MaxTime  *uint64 `path:"max-time" module:"openconfig-system"`
	Min      *uint8  `path:"min" module:"openconfig-system"`
	MinTime  *uint64 `path:"min-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Cpus_Cpu_State_Wait implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Cpus_Cpu_State_Wait) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Wait) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Cpus_Cpu_State_Wait"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Cpus_Cpu_State_Wait) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns represents the /openconfig-system/system/dns YANG schema element.
type OpenconfigSystem_System_Dns struct {
	Config      *OpenconfigSystem_System_Dns_Config      `path:"config" module:"openconfig-system"`
	HostEntries *OpenconfigSystem_System_Dns_HostEntries `path:"host-entries" module:"openconfig-system"`
	Servers     *OpenconfigSystem_System_Dns_Servers     `path:"servers" module:"openconfig-system"`
	State       *OpenconfigSystem_System_Dns_State       `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_Dns_Config represents the /openconfig-system/system/dns/config YANG schema element.
type OpenconfigSystem_System_Dns_Config struct {
	Search []string `path:"search" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_HostEntries represents the /openconfig-system/system/dns/host-entries YANG schema element.
type OpenconfigSystem_System_Dns_HostEntries struct {
	HostEntry map[string]*OpenconfigSystem_System_Dns_HostEntries_HostEntry `path:"host-entry" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_HostEntries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_HostEntries) IsYANGGoStruct() {}

// NewHostEntry creates a new entry in the HostEntry list of the
// OpenconfigSystem_System_Dns_HostEntries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Dns_HostEntries) NewHostEntry(Hostname string) (*OpenconfigSystem_System_Dns_HostEntries_HostEntry, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.HostEntry == nil {
		t.HostEntry = make(map[string]*OpenconfigSystem_System_Dns_HostEntries_HostEntry)
	}

	key := Hostname

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.HostEntry[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list HostEntry", key)
	}

	t.HostEntry[key] = &OpenconfigSystem_System_Dns_HostEntries_HostEntry{
		Hostname: &Hostname,
	}

	return t.HostEntry[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_HostEntries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_HostEntries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_HostEntries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_HostEntries_HostEntry represents the /openconfig-system/system/dns/host-entries/host-entry YANG schema element.
type OpenconfigSystem_System_Dns_HostEntries_HostEntry struct {
	Config   *OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config `path:"config" module:"openconfig-system"`
	Hostname *string                                                   `path:"hostname" module:"openconfig-system"`
	State    *OpenconfigSystem_System_Dns_HostEntries_HostEntry_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_HostEntries_HostEntry implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_HostEntries_HostEntry) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Dns_HostEntries_HostEntry struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Hostname == nil {
		return nil, fmt.Errorf("nil value for key Hostname")
	}

	return map[string]interface{}{
		"hostname": *t.Hostname,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_HostEntries_HostEntry"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config represents the /openconfig-system/system/dns/host-entries/host-entry/config YANG schema element.
type OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config struct {
	Alias       []string `path:"alias" module:"openconfig-system"`
	Hostname    *string  `path:"hostname" module:"openconfig-system"`
	Ipv4Address []string `path:"ipv4-address" module:"openconfig-system"`
	Ipv6Address []string `path:"ipv6-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_HostEntries_HostEntry_State represents the /openconfig-system/system/dns/host-entries/host-entry/state YANG schema element.
type OpenconfigSystem_System_Dns_HostEntries_HostEntry_State struct {
	Alias       []string `path:"alias" module:"openconfig-system"`
	Hostname    *string  `path:"hostname" module:"openconfig-system"`
	Ipv4Address []string `path:"ipv4-address" module:"openconfig-system"`
	Ipv6Address []string `path:"ipv6-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_HostEntries_HostEntry_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_HostEntries_HostEntry_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_HostEntries_HostEntry_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_HostEntries_HostEntry_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_Servers represents the /openconfig-system/system/dns/servers YANG schema element.
type OpenconfigSystem_System_Dns_Servers struct {
	Server map[string]*OpenconfigSystem_System_Dns_Servers_Server `path:"server" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_Servers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_Servers) IsYANGGoStruct() {}

// NewServer creates a new entry in the Server list of the
// OpenconfigSystem_System_Dns_Servers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Dns_Servers) NewServer(Address string) (*OpenconfigSystem_System_Dns_Servers_Server, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*OpenconfigSystem_System_Dns_Servers_Server)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Server[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Server", key)
	}

	t.Server[key] = &OpenconfigSystem_System_Dns_Servers_Server{
		Address: &Address,
	}

	return t.Server[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_Servers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_Servers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_Servers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_Servers_Server represents the /openconfig-system/system/dns/servers/server YANG schema element.
type OpenconfigSystem_System_Dns_Servers_Server struct {
	Address *string                                            `path:"address" module:"openconfig-system"`
	Config  *OpenconfigSystem_System_Dns_Servers_Server_Config `path:"config" module:"openconfig-system"`
	State   *OpenconfigSystem_System_Dns_Servers_Server_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_Servers_Server implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_Servers_Server) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Dns_Servers_Server struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Dns_Servers_Server) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_Servers_Server) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_Servers_Server"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_Servers_Server) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_Servers_Server_Config represents the /openconfig-system/system/dns/servers/server/config YANG schema element.
type OpenconfigSystem_System_Dns_Servers_Server_Config struct {
	Address *string `path:"address" module:"openconfig-system"`
	Port    *uint16 `path:"port" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_Servers_Server_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_Servers_Server_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_Servers_Server_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_Servers_Server_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_Servers_Server_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_Servers_Server_State represents the /openconfig-system/system/dns/servers/server/state YANG schema element.
type OpenconfigSystem_System_Dns_Servers_Server_State struct {
	Address *string `path:"address" module:"openconfig-system"`
	Port    *uint16 `path:"port" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_Servers_Server_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_Servers_Server_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_Servers_Server_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_Servers_Server_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_Servers_Server_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Dns_State represents the /openconfig-system/system/dns/state YANG schema element.
type OpenconfigSystem_System_Dns_State struct {
	Search []string `path:"search" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Dns_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Dns_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Dns_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Dns_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Dns_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_GrpcServer represents the /openconfig-system/system/grpc-server YANG schema element.
type OpenconfigSystem_System_GrpcServer struct {
	Config *OpenconfigSystem_System_GrpcServer_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_GrpcServer_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_GrpcServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_GrpcServer) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_GrpcServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_GrpcServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_GrpcServer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_GrpcServer_Config represents the /openconfig-system/system/grpc-server/config YANG schema element.
type OpenconfigSystem_System_GrpcServer_Config struct {
	CertificateId          *string                                                           `path:"certificate-id" module:"openconfig-system"`
	Enable                 *bool                                                             `path:"enable" module:"openconfig-system"`
	ListenAddresses        []OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union `path:"listen-addresses" module:"openconfig-system"`
	MetadataAuthentication *bool                                                             `path:"metadata-authentication" module:"openconfig-system"`
	Port                   *uint16                                                           `path:"port" module:"openconfig-system"`
	TransportSecurity      *bool                                                             `path:"transport-security" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_GrpcServer_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_GrpcServer_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_GrpcServer_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_GrpcServer_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_GrpcServer_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/grpc-server/config/listen-addresses within the YANG schema.
type OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union interface {
	Is_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union()
}

// OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses is used when /openconfig-system/system/grpc-server/config/listen-addresses
// is to be set to a E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses value.
type OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses struct {
	E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses
}

// Is_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union ensures that OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses
// implements the OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union interface.
func (*OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses) Is_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union() {
}

// OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_String is used when /openconfig-system/system/grpc-server/config/listen-addresses
// is to be set to a string value.
type OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union ensures that OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_String
// implements the OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union interface.
func (*OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_String) Is_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union() {
}

// To_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_GrpcServer_Config) To_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union(i interface{}) (OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses:
		return &OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses{v}, nil
	case string:
		return &OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_Union, unknown union type, got: %T, want any of [E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses, string]", i, i)
	}
}

// OpenconfigSystem_System_GrpcServer_State represents the /openconfig-system/system/grpc-server/state YANG schema element.
type OpenconfigSystem_System_GrpcServer_State struct {
	CertificateId          *string                                                          `path:"certificate-id" module:"openconfig-system"`
	Enable                 *bool                                                            `path:"enable" module:"openconfig-system"`
	ListenAddresses        []OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union `path:"listen-addresses" module:"openconfig-system"`
	MetadataAuthentication *bool                                                            `path:"metadata-authentication" module:"openconfig-system"`
	Port                   *uint16                                                          `path:"port" module:"openconfig-system"`
	TransportSecurity      *bool                                                            `path:"transport-security" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_GrpcServer_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_GrpcServer_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_GrpcServer_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_GrpcServer_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_GrpcServer_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/grpc-server/state/listen-addresses within the YANG schema.
type OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union interface {
	Is_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union()
}

// OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses is used when /openconfig-system/system/grpc-server/state/listen-addresses
// is to be set to a E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses value.
type OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses struct {
	E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses
}

// Is_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union ensures that OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses
// implements the OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union interface.
func (*OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses) Is_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union() {
}

// OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_String is used when /openconfig-system/system/grpc-server/state/listen-addresses
// is to be set to a string value.
type OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union ensures that OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_String
// implements the OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union interface.
func (*OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_String) Is_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union() {
}

// To_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_GrpcServer_State) To_OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union(i interface{}) (OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union, error) {
	switch v := i.(type) {
	case E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses:
		return &OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses{v}, nil
	case string:
		return &OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_GrpcServer_State_ListenAddresses_Union, unknown union type, got: %T, want any of [E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses, string]", i, i)
	}
}

// OpenconfigSystem_System_License represents the /openconfig-system/system/license YANG schema element.
type OpenconfigSystem_System_License struct {
	Licenses *OpenconfigSystem_System_License_Licenses `path:"licenses" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_License implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_License) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_License) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_License"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_License) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_License_Licenses represents the /openconfig-system/system/license/licenses YANG schema element.
type OpenconfigSystem_System_License_Licenses struct {
	License map[string]*OpenconfigSystem_System_License_Licenses_License `path:"license" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_License_Licenses implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_License_Licenses) IsYANGGoStruct() {}

// NewLicense creates a new entry in the License list of the
// OpenconfigSystem_System_License_Licenses struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_License_Licenses) NewLicense(LicenseId string) (*OpenconfigSystem_System_License_Licenses_License, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.License == nil {
		t.License = make(map[string]*OpenconfigSystem_System_License_Licenses_License)
	}

	key := LicenseId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.License[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list License", key)
	}

	t.License[key] = &OpenconfigSystem_System_License_Licenses_License{
		LicenseId: &LicenseId,
	}

	return t.License[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_License_Licenses) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_License_Licenses"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_License_Licenses) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_License_Licenses_License represents the /openconfig-system/system/license/licenses/license YANG schema element.
type OpenconfigSystem_System_License_Licenses_License struct {
	Config    *OpenconfigSystem_System_License_Licenses_License_Config `path:"config" module:"openconfig-system"`
	LicenseId *string                                                  `path:"license-id" module:"openconfig-system"`
	State     *OpenconfigSystem_System_License_Licenses_License_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_License_Licenses_License implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_License_Licenses_License) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_License_Licenses_License struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_License_Licenses_License) ΛListKeyMap() (map[string]interface{}, error) {
	if t.LicenseId == nil {
		return nil, fmt.Errorf("nil value for key LicenseId")
	}

	return map[string]interface{}{
		"license-id": *t.LicenseId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_License_Licenses_License) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_License_Licenses_License"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_License_Licenses_License) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_License_Licenses_License_Config represents the /openconfig-system/system/license/licenses/license/config YANG schema element.
type OpenconfigSystem_System_License_Licenses_License_Config struct {
	Active      *bool                                                                     `path:"active" module:"openconfig-system"`
	LicenseData OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union `path:"license-data" module:"openconfig-system"`
	LicenseId   *string                                                                   `path:"license-id" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_License_Licenses_License_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_License_Licenses_License_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_License_Licenses_License_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_License_Licenses_License_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_License_Licenses_License_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/license/licenses/license/config/license-data within the YANG schema.
type OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union interface {
	Is_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union()
}

// OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_Binary is used when /openconfig-system/system/license/licenses/license/config/license-data
// is to be set to a Binary value.
type OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_Binary struct {
	Binary Binary
}

// Is_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union ensures that OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_Binary
// implements the OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union interface.
func (*OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_Binary) Is_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union() {
}

// OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_String is used when /openconfig-system/system/license/licenses/license/config/license-data
// is to be set to a string value.
type OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union ensures that OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_String
// implements the OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union interface.
func (*OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_String) Is_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union() {
}

// To_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_License_Licenses_License_Config) To_OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union(i interface{}) (OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union, error) {
	switch v := i.(type) {
	case Binary:
		return &OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_Binary{v}, nil
	case string:
		return &OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_License_Licenses_License_Config_LicenseData_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
	}
}

// OpenconfigSystem_System_License_Licenses_License_State represents the /openconfig-system/system/license/licenses/license/state YANG schema element.
type OpenconfigSystem_System_License_Licenses_License_State struct {
	Active         *bool                                                                    `path:"active" module:"openconfig-system"`
	Description    *string                                                                  `path:"description" module:"openconfig-system"`
	ExpirationDate *uint64                                                                  `path:"expiration-date" module:"openconfig-system"`
	Expired        *bool                                                                    `path:"expired" module:"openconfig-system"`
	InUse          *bool                                                                    `path:"in-use" module:"openconfig-system"`
	IssueDate      *uint64                                                                  `path:"issue-date" module:"openconfig-system"`
	LicenseData    OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union `path:"license-data" module:"openconfig-system"`
	LicenseId      *string                                                                  `path:"license-id" module:"openconfig-system"`
	Valid          *bool                                                                    `path:"valid" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_License_Licenses_License_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_License_Licenses_License_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_License_Licenses_License_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_License_Licenses_License_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_License_Licenses_License_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union is an interface that is implemented by valid types for the union
// for the leaf /openconfig-system/system/license/licenses/license/state/license-data within the YANG schema.
type OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union interface {
	Is_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union()
}

// OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_Binary is used when /openconfig-system/system/license/licenses/license/state/license-data
// is to be set to a Binary value.
type OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_Binary struct {
	Binary Binary
}

// Is_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union ensures that OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_Binary
// implements the OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union interface.
func (*OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_Binary) Is_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union() {
}

// OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_String is used when /openconfig-system/system/license/licenses/license/state/license-data
// is to be set to a string value.
type OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_String struct {
	String string
}

// Is_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union ensures that OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_String
// implements the OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union interface.
func (*OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_String) Is_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union() {
}

// To_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union takes an input interface{} and attempts to convert it to a struct
// which implements the OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union union. It returns an error if the interface{} supplied
// cannot be converted to a type within the union.
func (t *OpenconfigSystem_System_License_Licenses_License_State) To_OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union(i interface{}) (OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union, error) {
	switch v := i.(type) {
	case Binary:
		return &OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_Binary{v}, nil
	case string:
		return &OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union_String{v}, nil
	default:
		return nil, fmt.Errorf("cannot convert %v to OpenconfigSystem_System_License_Licenses_License_State_LicenseData_Union, unknown union type, got: %T, want any of [Binary, string]", i, i)
	}
}

// OpenconfigSystem_System_Logging represents the /openconfig-system/system/logging YANG schema element.
type OpenconfigSystem_System_Logging struct {
	Console       *OpenconfigSystem_System_Logging_Console       `path:"console" module:"openconfig-system"`
	RemoteServers *OpenconfigSystem_System_Logging_RemoteServers `path:"remote-servers" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console represents the /openconfig-system/system/logging/console YANG schema element.
type OpenconfigSystem_System_Logging_Console struct {
	Config    *OpenconfigSystem_System_Logging_Console_Config    `path:"config" module:"openconfig-system"`
	Selectors *OpenconfigSystem_System_Logging_Console_Selectors `path:"selectors" module:"openconfig-system"`
	State     *OpenconfigSystem_System_Logging_Console_State     `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console_Config represents the /openconfig-system/system/logging/console/config YANG schema element.
type OpenconfigSystem_System_Logging_Console_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console_Selectors represents the /openconfig-system/system/logging/console/selectors YANG schema element.
type OpenconfigSystem_System_Logging_Console_Selectors struct {
	Selector map[OpenconfigSystem_System_Logging_Console_Selectors_Selector_Key]*OpenconfigSystem_System_Logging_Console_Selectors_Selector `path:"selector" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console_Selectors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console_Selectors) IsYANGGoStruct() {}

// OpenconfigSystem_System_Logging_Console_Selectors_Selector_Key represents the key for list Selector of element /openconfig-system/system/logging/console/selectors.
type OpenconfigSystem_System_Logging_Console_Selectors_Selector_Key struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity"`
}

// NewSelector creates a new entry in the Selector list of the
// OpenconfigSystem_System_Logging_Console_Selectors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Logging_Console_Selectors) NewSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) (*OpenconfigSystem_System_Logging_Console_Selectors_Selector, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Selector == nil {
		t.Selector = make(map[OpenconfigSystem_System_Logging_Console_Selectors_Selector_Key]*OpenconfigSystem_System_Logging_Console_Selectors_Selector)
	}

	key := OpenconfigSystem_System_Logging_Console_Selectors_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Selector[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Selector", key)
	}

	t.Selector[key] = &OpenconfigSystem_System_Logging_Console_Selectors_Selector{
		Facility: Facility,
		Severity: Severity,
	}

	return t.Selector[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console_Selectors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console_Selectors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console_Selectors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console_Selectors_Selector represents the /openconfig-system/system/logging/console/selectors/selector YANG schema element.
type OpenconfigSystem_System_Logging_Console_Selectors_Selector struct {
	Config   *OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config `path:"config" module:"openconfig-system"`
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY                          `path:"facility" module:"openconfig-system"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity                           `path:"severity" module:"openconfig-system"`
	State    *OpenconfigSystem_System_Logging_Console_Selectors_Selector_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console_Selectors_Selector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console_Selectors_Selector) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Logging_Console_Selectors_Selector struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"facility": t.Facility,
		"severity": t.Severity,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console_Selectors_Selector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config represents the /openconfig-system/system/logging/console/selectors/selector/config YANG schema element.
type OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility" module:"openconfig-system"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console_Selectors_Selector_State represents the /openconfig-system/system/logging/console/selectors/selector/state YANG schema element.
type OpenconfigSystem_System_Logging_Console_Selectors_Selector_State struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility" module:"openconfig-system"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console_Selectors_Selector_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console_Selectors_Selector_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console_Selectors_Selector_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console_Selectors_Selector_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_Console_State represents the /openconfig-system/system/logging/console/state YANG schema element.
type OpenconfigSystem_System_Logging_Console_State struct {
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_Console_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_Console_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_Console_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_Console_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_Console_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers represents the /openconfig-system/system/logging/remote-servers YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers struct {
	RemoteServer map[string]*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer `path:"remote-server" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers) IsYANGGoStruct() {}

// NewRemoteServer creates a new entry in the RemoteServer list of the
// OpenconfigSystem_System_Logging_RemoteServers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Logging_RemoteServers) NewRemoteServer(Host string) (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.RemoteServer == nil {
		t.RemoteServer = make(map[string]*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer)
	}

	key := Host

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.RemoteServer[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list RemoteServer", key)
	}

	t.RemoteServer[key] = &OpenconfigSystem_System_Logging_RemoteServers_RemoteServer{
		Host: &Host,
	}

	return t.RemoteServer[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer represents the /openconfig-system/system/logging/remote-servers/remote-server YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer struct {
	Config    *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config    `path:"config" module:"openconfig-system"`
	Host      *string                                                               `path:"host" module:"openconfig-system"`
	Selectors *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors `path:"selectors" module:"openconfig-system"`
	State     *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State     `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Logging_RemoteServers_RemoteServer struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Host == nil {
		return nil, fmt.Errorf("nil value for key Host")
	}

	return map[string]interface{}{
		"host": *t.Host,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config represents the /openconfig-system/system/logging/remote-servers/remote-server/config YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config struct {
	Host          *string `path:"host" module:"openconfig-system"`
	RemotePort    *uint16 `path:"remote-port" module:"openconfig-system"`
	SourceAddress *string `path:"source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors represents the /openconfig-system/system/logging/remote-servers/remote-server/selectors YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors struct {
	Selector map[OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Key]*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector `path:"selector" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors) IsYANGGoStruct() {}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Key represents the key for list Selector of element /openconfig-system/system/logging/remote-servers/remote-server/selectors.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Key struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity"`
}

// NewSelector creates a new entry in the Selector list of the
// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors) NewSelector(Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY, Severity E_OpenconfigSystemLogging_SyslogSeverity) (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Selector == nil {
		t.Selector = make(map[OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Key]*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector)
	}

	key := OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Key{
		Facility: Facility,
		Severity: Severity,
	}

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Selector[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Selector", key)
	}

	t.Selector[key] = &OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector{
		Facility: Facility,
		Severity: Severity,
	}

	return t.Selector[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector represents the /openconfig-system/system/logging/remote-servers/remote-server/selectors/selector YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector struct {
	Config   *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config `path:"config" module:"openconfig-system"`
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY                                             `path:"facility" module:"openconfig-system"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity                                              `path:"severity" module:"openconfig-system"`
	State    *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"facility": t.Facility,
		"severity": t.Severity,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config represents the /openconfig-system/system/logging/remote-servers/remote-server/selectors/selector/config YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility" module:"openconfig-system"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State represents the /openconfig-system/system/logging/remote-servers/remote-server/selectors/selector/state YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State struct {
	Facility E_OpenconfigSystemLogging_SYSLOG_FACILITY `path:"facility" module:"openconfig-system"`
	Severity E_OpenconfigSystemLogging_SyslogSeverity  `path:"severity" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_Selectors_Selector_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State represents the /openconfig-system/system/logging/remote-servers/remote-server/state YANG schema element.
type OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State struct {
	Host          *string `path:"host" module:"openconfig-system"`
	RemotePort    *uint16 `path:"remote-port" module:"openconfig-system"`
	SourceAddress *string `path:"source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Logging_RemoteServers_RemoteServer_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Memory represents the /openconfig-system/system/memory YANG schema element.
type OpenconfigSystem_System_Memory struct {
	Config *OpenconfigSystem_System_Memory_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Memory_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Memory implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Memory) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Memory) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Memory"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Memory) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Memory_Config represents the /openconfig-system/system/memory/config YANG schema element.
type OpenconfigSystem_System_Memory_Config struct {
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Memory_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Memory_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Memory_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Memory_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Memory_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Memory_State represents the /openconfig-system/system/memory/state YANG schema element.
type OpenconfigSystem_System_Memory_State struct {
	Physical *uint64 `path:"physical" module:"openconfig-system"`
	Reserved *uint64 `path:"reserved" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Memory_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Memory_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Memory_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Memory_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Memory_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages represents the /openconfig-system/system/messages YANG schema element.
type OpenconfigSystem_System_Messages struct {
	Config       *OpenconfigSystem_System_Messages_Config       `path:"config" module:"openconfig-system"`
	DebugEntries *OpenconfigSystem_System_Messages_DebugEntries `path:"debug-entries" module:"openconfig-system"`
	State        *OpenconfigSystem_System_Messages_State        `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_Config represents the /openconfig-system/system/messages/config YANG schema element.
type OpenconfigSystem_System_Messages_Config struct {
	Severity E_OpenconfigMessages_SyslogSeverity `path:"severity" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_DebugEntries represents the /openconfig-system/system/messages/debug-entries YANG schema element.
type OpenconfigSystem_System_Messages_DebugEntries struct {
	DebugService map[E_OpenconfigMessages_DEBUG_SERVICE]*OpenconfigSystem_System_Messages_DebugEntries_DebugService `path:"debug-service" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_DebugEntries implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_DebugEntries) IsYANGGoStruct() {}

// NewDebugService creates a new entry in the DebugService list of the
// OpenconfigSystem_System_Messages_DebugEntries struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Messages_DebugEntries) NewDebugService(Service E_OpenconfigMessages_DEBUG_SERVICE) (*OpenconfigSystem_System_Messages_DebugEntries_DebugService, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.DebugService == nil {
		t.DebugService = make(map[E_OpenconfigMessages_DEBUG_SERVICE]*OpenconfigSystem_System_Messages_DebugEntries_DebugService)
	}

	key := Service

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.DebugService[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list DebugService", key)
	}

	t.DebugService[key] = &OpenconfigSystem_System_Messages_DebugEntries_DebugService{
		Service: Service,
	}

	return t.DebugService[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_DebugEntries) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_DebugEntries"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_DebugEntries) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_DebugEntries_DebugService represents the /openconfig-system/system/messages/debug-entries/debug-service YANG schema element.
type OpenconfigSystem_System_Messages_DebugEntries_DebugService struct {
	Config  *OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config `path:"config" module:"openconfig-system"`
	Service E_OpenconfigMessages_DEBUG_SERVICE                                 `path:"service" module:"openconfig-system"`
	State   *OpenconfigSystem_System_Messages_DebugEntries_DebugService_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_DebugEntries_DebugService implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_DebugEntries_DebugService) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Messages_DebugEntries_DebugService struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService) ΛListKeyMap() (map[string]interface{}, error) {

	return map[string]interface{}{
		"service": t.Service,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_DebugEntries_DebugService"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config represents the /openconfig-system/system/messages/debug-entries/debug-service/config YANG schema element.
type OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config struct {
	Enabled *bool                              `path:"enabled" module:"openconfig-system"`
	Service E_OpenconfigMessages_DEBUG_SERVICE `path:"service" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_DebugEntries_DebugService_State represents the /openconfig-system/system/messages/debug-entries/debug-service/state YANG schema element.
type OpenconfigSystem_System_Messages_DebugEntries_DebugService_State struct {
	Enabled *bool                              `path:"enabled" module:"openconfig-system"`
	Service E_OpenconfigMessages_DEBUG_SERVICE `path:"service" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_DebugEntries_DebugService_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_DebugEntries_DebugService_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_DebugEntries_DebugService_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_DebugEntries_DebugService_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_State represents the /openconfig-system/system/messages/state YANG schema element.
type OpenconfigSystem_System_Messages_State struct {
	Message  *OpenconfigSystem_System_Messages_State_Message `path:"message" module:"openconfig-system"`
	Severity E_OpenconfigMessages_SyslogSeverity             `path:"severity" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Messages_State_Message represents the /openconfig-system/system/messages/state/message YANG schema element.
type OpenconfigSystem_System_Messages_State_Message struct {
	AppName  *string `path:"app-name" module:"openconfig-system"`
	Msg      *string `path:"msg" module:"openconfig-system"`
	Msgid    *string `path:"msgid" module:"openconfig-system"`
	Priority *uint8  `path:"priority" module:"openconfig-system"`
	Procid   *string `path:"procid" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Messages_State_Message implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Messages_State_Message) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Messages_State_Message) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Messages_State_Message"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Messages_State_Message) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp represents the /openconfig-system/system/ntp YANG schema element.
type OpenconfigSystem_System_Ntp struct {
	Config  *OpenconfigSystem_System_Ntp_Config  `path:"config" module:"openconfig-system"`
	NtpKeys *OpenconfigSystem_System_Ntp_NtpKeys `path:"ntp-keys" module:"openconfig-system"`
	Servers *OpenconfigSystem_System_Ntp_Servers `path:"servers" module:"openconfig-system"`
	State   *OpenconfigSystem_System_Ntp_State   `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_Ntp_Config represents the /openconfig-system/system/ntp/config YANG schema element.
type OpenconfigSystem_System_Ntp_Config struct {
	EnableNtpAuth    *bool   `path:"enable-ntp-auth" module:"openconfig-system"`
	Enabled          *bool   `path:"enabled" module:"openconfig-system"`
	NtpSourceAddress *string `path:"ntp-source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_NtpKeys represents the /openconfig-system/system/ntp/ntp-keys YANG schema element.
type OpenconfigSystem_System_Ntp_NtpKeys struct {
	NtpKey map[uint16]*OpenconfigSystem_System_Ntp_NtpKeys_NtpKey `path:"ntp-key" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_NtpKeys implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_NtpKeys) IsYANGGoStruct() {}

// NewNtpKey creates a new entry in the NtpKey list of the
// OpenconfigSystem_System_Ntp_NtpKeys struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Ntp_NtpKeys) NewNtpKey(KeyId uint16) (*OpenconfigSystem_System_Ntp_NtpKeys_NtpKey, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.NtpKey == nil {
		t.NtpKey = make(map[uint16]*OpenconfigSystem_System_Ntp_NtpKeys_NtpKey)
	}

	key := KeyId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.NtpKey[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list NtpKey", key)
	}

	t.NtpKey[key] = &OpenconfigSystem_System_Ntp_NtpKeys_NtpKey{
		KeyId: &KeyId,
	}

	return t.NtpKey[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_NtpKeys) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_NtpKeys"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_NtpKeys) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_NtpKeys_NtpKey represents the /openconfig-system/system/ntp/ntp-keys/ntp-key YANG schema element.
type OpenconfigSystem_System_Ntp_NtpKeys_NtpKey struct {
	Config *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config `path:"config" module:"openconfig-system"`
	KeyId  *uint16                                            `path:"key-id" module:"openconfig-system"`
	State  *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_NtpKeys_NtpKey implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_NtpKeys_NtpKey) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Ntp_NtpKeys_NtpKey struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey) ΛListKeyMap() (map[string]interface{}, error) {
	if t.KeyId == nil {
		return nil, fmt.Errorf("nil value for key KeyId")
	}

	return map[string]interface{}{
		"key-id": *t.KeyId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_NtpKeys_NtpKey"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config represents the /openconfig-system/system/ntp/ntp-keys/ntp-key/config YANG schema element.
type OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config struct {
	KeyId    *uint16                          `path:"key-id" module:"openconfig-system"`
	KeyType  E_OpenconfigSystem_NTP_AUTH_TYPE `path:"key-type" module:"openconfig-system"`
	KeyValue *string                          `path:"key-value" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State represents the /openconfig-system/system/ntp/ntp-keys/ntp-key/state YANG schema element.
type OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State struct {
	KeyId    *uint16                          `path:"key-id" module:"openconfig-system"`
	KeyType  E_OpenconfigSystem_NTP_AUTH_TYPE `path:"key-type" module:"openconfig-system"`
	KeyValue *string                          `path:"key-value" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_NtpKeys_NtpKey_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_Servers represents the /openconfig-system/system/ntp/servers YANG schema element.
type OpenconfigSystem_System_Ntp_Servers struct {
	Server map[string]*OpenconfigSystem_System_Ntp_Servers_Server `path:"server" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_Servers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_Servers) IsYANGGoStruct() {}

// NewServer creates a new entry in the Server list of the
// OpenconfigSystem_System_Ntp_Servers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Ntp_Servers) NewServer(Address string) (*OpenconfigSystem_System_Ntp_Servers_Server, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Server == nil {
		t.Server = make(map[string]*OpenconfigSystem_System_Ntp_Servers_Server)
	}

	key := Address

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Server[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Server", key)
	}

	t.Server[key] = &OpenconfigSystem_System_Ntp_Servers_Server{
		Address: &Address,
	}

	return t.Server[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_Servers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_Servers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_Servers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_Servers_Server represents the /openconfig-system/system/ntp/servers/server YANG schema element.
type OpenconfigSystem_System_Ntp_Servers_Server struct {
	Address *string                                            `path:"address" module:"openconfig-system"`
	Config  *OpenconfigSystem_System_Ntp_Servers_Server_Config `path:"config" module:"openconfig-system"`
	State   *OpenconfigSystem_System_Ntp_Servers_Server_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_Servers_Server implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_Servers_Server) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Ntp_Servers_Server struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Ntp_Servers_Server) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Address == nil {
		return nil, fmt.Errorf("nil value for key Address")
	}

	return map[string]interface{}{
		"address": *t.Address,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_Servers_Server) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_Servers_Server"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_Servers_Server) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_Servers_Server_Config represents the /openconfig-system/system/ntp/servers/server/config YANG schema element.
type OpenconfigSystem_System_Ntp_Servers_Server_Config struct {
	Address         *string                                                             `path:"address" module:"openconfig-system"`
	AssociationType E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType `path:"association-type" module:"openconfig-system"`
	Iburst          *bool                                                               `path:"iburst" module:"openconfig-system"`
	Port            *uint16                                                             `path:"port" module:"openconfig-system"`
	Prefer          *bool                                                               `path:"prefer" module:"openconfig-system"`
	Version         *uint8                                                              `path:"version" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_Servers_Server_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_Servers_Server_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_Servers_Server_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_Servers_Server_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_Servers_Server_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_Servers_Server_State represents the /openconfig-system/system/ntp/servers/server/state YANG schema element.
type OpenconfigSystem_System_Ntp_Servers_Server_State struct {
	Address         *string                                                             `path:"address" module:"openconfig-system"`
	AssociationType E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType `path:"association-type" module:"openconfig-system"`
	Iburst          *bool                                                               `path:"iburst" module:"openconfig-system"`
	Offset          *uint64                                                             `path:"offset" module:"openconfig-system"`
	PollInterval    *uint32                                                             `path:"poll-interval" module:"openconfig-system"`
	Port            *uint16                                                             `path:"port" module:"openconfig-system"`
	Prefer          *bool                                                               `path:"prefer" module:"openconfig-system"`
	RootDelay       *uint32                                                             `path:"root-delay" module:"openconfig-system"`
	RootDispersion  *uint64                                                             `path:"root-dispersion" module:"openconfig-system"`
	Stratum         *uint8                                                              `path:"stratum" module:"openconfig-system"`
	Version         *uint8                                                              `path:"version" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_Servers_Server_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_Servers_Server_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_Servers_Server_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_Servers_Server_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_Servers_Server_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Ntp_State represents the /openconfig-system/system/ntp/state YANG schema element.
type OpenconfigSystem_System_Ntp_State struct {
	AuthMismatch     *uint64 `path:"auth-mismatch" module:"openconfig-system"`
	EnableNtpAuth    *bool   `path:"enable-ntp-auth" module:"openconfig-system"`
	Enabled          *bool   `path:"enabled" module:"openconfig-system"`
	NtpSourceAddress *string `path:"ntp-source-address" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Ntp_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Ntp_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Ntp_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Ntp_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Ntp_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow represents the /openconfig-system/system/openflow YANG schema element.
type OpenconfigSystem_System_Openflow struct {
	Agent       *OpenconfigSystem_System_Openflow_Agent       `path:"agent" module:"openconfig-openflow"`
	Controllers *OpenconfigSystem_System_Openflow_Controllers `path:"controllers" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Agent represents the /openconfig-system/system/openflow/agent YANG schema element.
type OpenconfigSystem_System_Openflow_Agent struct {
	Config *OpenconfigSystem_System_Openflow_Agent_Config `path:"config" module:"openconfig-openflow"`
	State  *OpenconfigSystem_System_Openflow_Agent_State  `path:"state" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Agent implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Agent) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Agent) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Agent"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Agent) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Agent_Config represents the /openconfig-system/system/openflow/agent/config YANG schema element.
type OpenconfigSystem_System_Openflow_Agent_Config struct {
	BackoffInterval *uint32                          `path:"backoff-interval" module:"openconfig-openflow"`
	DatapathId      *string                          `path:"datapath-id" module:"openconfig-openflow"`
	FailureMode     E_OpenconfigOpenflow_FailureMode `path:"failure-mode" module:"openconfig-openflow"`
	InactivityProbe *uint32                          `path:"inactivity-probe" module:"openconfig-openflow"`
	MaxBackoff      *uint32                          `path:"max-backoff" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Agent_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Agent_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Agent_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Agent_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Agent_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Agent_State represents the /openconfig-system/system/openflow/agent/state YANG schema element.
type OpenconfigSystem_System_Openflow_Agent_State struct {
	BackoffInterval *uint32                          `path:"backoff-interval" module:"openconfig-openflow"`
	DatapathId      *string                          `path:"datapath-id" module:"openconfig-openflow"`
	FailureMode     E_OpenconfigOpenflow_FailureMode `path:"failure-mode" module:"openconfig-openflow"`
	InactivityProbe *uint32                          `path:"inactivity-probe" module:"openconfig-openflow"`
	MaxBackoff      *uint32                          `path:"max-backoff" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Agent_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Agent_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Agent_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Agent_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Agent_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers represents the /openconfig-system/system/openflow/controllers YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers struct {
	Controller map[string]*OpenconfigSystem_System_Openflow_Controllers_Controller `path:"controller" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers) IsYANGGoStruct() {}

// NewController creates a new entry in the Controller list of the
// OpenconfigSystem_System_Openflow_Controllers struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Openflow_Controllers) NewController(Name string) (*OpenconfigSystem_System_Openflow_Controllers_Controller, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Controller == nil {
		t.Controller = make(map[string]*OpenconfigSystem_System_Openflow_Controllers_Controller)
	}

	key := Name

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Controller[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Controller", key)
	}

	t.Controller[key] = &OpenconfigSystem_System_Openflow_Controllers_Controller{
		Name: &Name,
	}

	return t.Controller[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller represents the /openconfig-system/system/openflow/controllers/controller YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller struct {
	Config      *OpenconfigSystem_System_Openflow_Controllers_Controller_Config      `path:"config" module:"openconfig-openflow"`
	Connections *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections `path:"connections" module:"openconfig-openflow"`
	Name        *string                                                              `path:"name" module:"openconfig-openflow"`
	State       *OpenconfigSystem_System_Openflow_Controllers_Controller_State       `path:"state" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Openflow_Controllers_Controller struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Name == nil {
		return nil, fmt.Errorf("nil value for key Name")
	}

	return map[string]interface{}{
		"name": *t.Name,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller_Config represents the /openconfig-system/system/openflow/controllers/controller/config YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller_Config struct {
	Name *string `path:"name" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller_Connections represents the /openconfig-system/system/openflow/controllers/controller/connections YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller_Connections struct {
	Connection map[uint8]*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection `path:"connection" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller_Connections implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections) IsYANGGoStruct() {}

// NewConnection creates a new entry in the Connection list of the
// OpenconfigSystem_System_Openflow_Controllers_Controller_Connections struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections) NewConnection(AuxId uint8) (*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Connection == nil {
		t.Connection = make(map[uint8]*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection)
	}

	key := AuxId

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Connection[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Connection", key)
	}

	t.Connection[key] = &OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection{
		AuxId: &AuxId,
	}

	return t.Connection[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller_Connections"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection represents the /openconfig-system/system/openflow/controllers/controller/connections/connection YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection struct {
	AuxId  *uint8                                                                                 `path:"aux-id" module:"openconfig-openflow"`
	Config *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config `path:"config" module:"openconfig-openflow"`
	State  *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State  `path:"state" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection) IsYANGGoStruct() {
}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection) ΛListKeyMap() (map[string]interface{}, error) {
	if t.AuxId == nil {
		return nil, fmt.Errorf("nil value for key AuxId")
	}

	return map[string]interface{}{
		"aux-id": *t.AuxId,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config represents the /openconfig-system/system/openflow/controllers/controller/connections/connection/config YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config struct {
	Address         *string                        `path:"address" module:"openconfig-openflow"`
	AuxId           *uint8                         `path:"aux-id" module:"openconfig-openflow"`
	CertificateId   *string                        `path:"certificate-id" module:"openconfig-openflow"`
	Port            *uint16                        `path:"port" module:"openconfig-openflow"`
	Priority        *uint8                         `path:"priority" module:"openconfig-openflow"`
	SourceInterface *string                        `path:"source-interface" module:"openconfig-openflow"`
	Transport       E_OpenconfigOpenflow_Transport `path:"transport" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State represents the /openconfig-system/system/openflow/controllers/controller/connections/connection/state YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State struct {
	Address         *string                        `path:"address" module:"openconfig-openflow"`
	AuxId           *uint8                         `path:"aux-id" module:"openconfig-openflow"`
	CertificateId   *string                        `path:"certificate-id" module:"openconfig-openflow"`
	Connected       *bool                          `path:"connected" module:"openconfig-openflow"`
	Port            *uint16                        `path:"port" module:"openconfig-openflow"`
	Priority        *uint8                         `path:"priority" module:"openconfig-openflow"`
	SourceInterface *string                        `path:"source-interface" module:"openconfig-openflow"`
	Transport       E_OpenconfigOpenflow_Transport `path:"transport" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State) IsYANGGoStruct() {
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_Connections_Connection_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Openflow_Controllers_Controller_State represents the /openconfig-system/system/openflow/controllers/controller/state YANG schema element.
type OpenconfigSystem_System_Openflow_Controllers_Controller_State struct {
	Name *string `path:"name" module:"openconfig-openflow"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Openflow_Controllers_Controller_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Openflow_Controllers_Controller_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Openflow_Controllers_Controller_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Openflow_Controllers_Controller_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Processes represents the /openconfig-system/system/processes YANG schema element.
type OpenconfigSystem_System_Processes struct {
	Process map[uint64]*OpenconfigSystem_System_Processes_Process `path:"process" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Processes implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Processes) IsYANGGoStruct() {}

// NewProcess creates a new entry in the Process list of the
// OpenconfigSystem_System_Processes struct. The keys of the list are populated from the input
// arguments.
func (t *OpenconfigSystem_System_Processes) NewProcess(Pid uint64) (*OpenconfigSystem_System_Processes_Process, error) {

	// Initialise the list within the receiver struct if it has not already been
	// created.
	if t.Process == nil {
		t.Process = make(map[uint64]*OpenconfigSystem_System_Processes_Process)
	}

	key := Pid

	// Ensure that this key has not already been used in the
	// list. Keyed YANG lists do not allow duplicate keys to
	// be created.
	if _, ok := t.Process[key]; ok {
		return nil, fmt.Errorf("duplicate key %v for list Process", key)
	}

	t.Process[key] = &OpenconfigSystem_System_Processes_Process{
		Pid: &Pid,
	}

	return t.Process[key], nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Processes) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Processes"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Processes) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Processes_Process represents the /openconfig-system/system/processes/process YANG schema element.
type OpenconfigSystem_System_Processes_Process struct {
	Pid   *uint64                                          `path:"pid" module:"openconfig-system"`
	State *OpenconfigSystem_System_Processes_Process_State `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Processes_Process implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Processes_Process) IsYANGGoStruct() {}

// ΛListKeyMap returns the keys of the OpenconfigSystem_System_Processes_Process struct, which is a YANG list entry.
func (t *OpenconfigSystem_System_Processes_Process) ΛListKeyMap() (map[string]interface{}, error) {
	if t.Pid == nil {
		return nil, fmt.Errorf("nil value for key Pid")
	}

	return map[string]interface{}{
		"pid": *t.Pid,
	}, nil
}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Processes_Process) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Processes_Process"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Processes_Process) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_Processes_Process_State represents the /openconfig-system/system/processes/process/state YANG schema element.
type OpenconfigSystem_System_Processes_Process_State struct {
	Args              []string `path:"args" module:"openconfig-system"`
	CpuUsageSystem    *uint64  `path:"cpu-usage-system" module:"openconfig-system"`
	CpuUsageUser      *uint64  `path:"cpu-usage-user" module:"openconfig-system"`
	CpuUtilization    *uint8   `path:"cpu-utilization" module:"openconfig-system"`
	MemoryUsage       *uint64  `path:"memory-usage" module:"openconfig-system"`
	MemoryUtilization *uint8   `path:"memory-utilization" module:"openconfig-system"`
	Name              *string  `path:"name" module:"openconfig-system"`
	Pid               *uint64  `path:"pid" module:"openconfig-system"`
	StartTime         *uint64  `path:"start-time" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_Processes_Process_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_Processes_Process_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_Processes_Process_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_Processes_Process_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_Processes_Process_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_SshServer represents the /openconfig-system/system/ssh-server YANG schema element.
type OpenconfigSystem_System_SshServer struct {
	Config *OpenconfigSystem_System_SshServer_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_SshServer_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_SshServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_SshServer) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_SshServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_SshServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_SshServer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_SshServer_Config represents the /openconfig-system/system/ssh-server/config YANG schema element.
type OpenconfigSystem_System_SshServer_Config struct {
	Enable          *bool                                                      `path:"enable" module:"openconfig-system"`
	ProtocolVersion E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion `path:"protocol-version" module:"openconfig-system"`
	RateLimit       *uint16                                                    `path:"rate-limit" module:"openconfig-system"`
	SessionLimit    *uint16                                                    `path:"session-limit" module:"openconfig-system"`
	Timeout         *uint16                                                    `path:"timeout" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_SshServer_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_SshServer_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_SshServer_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_SshServer_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_SshServer_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_SshServer_State represents the /openconfig-system/system/ssh-server/state YANG schema element.
type OpenconfigSystem_System_SshServer_State struct {
	Enable          *bool                                                      `path:"enable" module:"openconfig-system"`
	ProtocolVersion E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion `path:"protocol-version" module:"openconfig-system"`
	RateLimit       *uint16                                                    `path:"rate-limit" module:"openconfig-system"`
	SessionLimit    *uint16                                                    `path:"session-limit" module:"openconfig-system"`
	Timeout         *uint16                                                    `path:"timeout" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_SshServer_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_SshServer_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_SshServer_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_SshServer_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_SshServer_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_State represents the /openconfig-system/system/state YANG schema element.
type OpenconfigSystem_System_State struct {
	BootTime        *uint64 `path:"boot-time" module:"openconfig-system"`
	CurrentDatetime *string `path:"current-datetime" module:"openconfig-system"`
	DomainName      *string `path:"domain-name" module:"openconfig-system"`
	Hostname        *string `path:"hostname" module:"openconfig-system"`
	LoginBanner     *string `path:"login-banner" module:"openconfig-system"`
	MotdBanner      *string `path:"motd-banner" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_State) ΛEnumTypeMap() map[string][]reflect.Type { return ΛEnumTypes }

// OpenconfigSystem_System_TelnetServer represents the /openconfig-system/system/telnet-server YANG schema element.
type OpenconfigSystem_System_TelnetServer struct {
	Config *OpenconfigSystem_System_TelnetServer_Config `path:"config" module:"openconfig-system"`
	State  *OpenconfigSystem_System_TelnetServer_State  `path:"state" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_TelnetServer implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_TelnetServer) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_TelnetServer) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_TelnetServer"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_TelnetServer) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_TelnetServer_Config represents the /openconfig-system/system/telnet-server/config YANG schema element.
type OpenconfigSystem_System_TelnetServer_Config struct {
	Enable       *bool   `path:"enable" module:"openconfig-system"`
	RateLimit    *uint16 `path:"rate-limit" module:"openconfig-system"`
	SessionLimit *uint16 `path:"session-limit" module:"openconfig-system"`
	Timeout      *uint16 `path:"timeout" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_TelnetServer_Config implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_TelnetServer_Config) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_TelnetServer_Config) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_TelnetServer_Config"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_TelnetServer_Config) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

// OpenconfigSystem_System_TelnetServer_State represents the /openconfig-system/system/telnet-server/state YANG schema element.
type OpenconfigSystem_System_TelnetServer_State struct {
	Enable       *bool   `path:"enable" module:"openconfig-system"`
	RateLimit    *uint16 `path:"rate-limit" module:"openconfig-system"`
	SessionLimit *uint16 `path:"session-limit" module:"openconfig-system"`
	Timeout      *uint16 `path:"timeout" module:"openconfig-system"`
}

// IsYANGGoStruct ensures that OpenconfigSystem_System_TelnetServer_State implements the yang.GoStruct
// interface. This allows functions that need to handle this struct to
// identify it as being generated by ygen.
func (*OpenconfigSystem_System_TelnetServer_State) IsYANGGoStruct() {}

// Validate validates s against the YANG schema corresponding to its type.
func (t *OpenconfigSystem_System_TelnetServer_State) Validate(opts ...ygot.ValidationOption) error {
	if err := ytypes.Validate(SchemaTree["OpenconfigSystem_System_TelnetServer_State"], t, opts...); err != nil {
		return err
	}
	return nil
}

// ΛEnumTypeMap returns a map, keyed by YANG schema path, of the enumerated types
// that are included in the generated code.
func (t *OpenconfigSystem_System_TelnetServer_State) ΛEnumTypeMap() map[string][]reflect.Type {
	return ΛEnumTypes
}

type Csbi struct {
	schema *ytypes.Schema
	id     uuid.UUID
}

func (sbi *Csbi) SbiIdentifier() string {
	return "plugin sbi"
}

func (sbi *Csbi) SetNode(schema *yang.Entry, root interface{}, path *gpb.Path, val interface{}, opts ...ytypes.SetNodeOpt) error {
	log.WithFields(log.Fields{
		"schema": schema.Name,
		"path":   path,
		"val":    val,
		"opts":   opts,
	}).Trace("entering SetNode()")
	return ytypes.SetNode(schema, root.(*Device), path, val, opts...)
}

func (sbi *Csbi) Schema() *ytypes.Schema {
	schema, err := Schema()
	sbi.schema = schema
	if err != nil {
		log.Fatal(err)
	}
	return schema
}

func (sbi *Csbi) ID() uuid.UUID {
	return sbi.id
}

func (sbi *Csbi) Type() spb.Type {
	return spb.Type_CONTAINERISED
}

func (sbi *Csbi) Unmarshal(bytes []byte, fields []string, goStruct ygot.ValidatedGoStruct, opt ...ytypes.UnmarshalOpt) error {
	log.WithFields(log.Fields{}).Trace("entering Unmarshal()")
	return unmarshal(sbi.Schema(), bytes, fields, goStruct, opt...)
}

// unmarshal parses gNMI response to a go struct.
func unmarshal(schema *ytypes.Schema, bytes []byte, fields []string, goStruct ygot.ValidatedGoStruct, opt ...ytypes.UnmarshalOpt) error {
	defer func() {
		if r := recover(); r != nil {
			log.Error(r.(error))
		}
	}()
	log.WithFields(log.Fields{
		"schema": schema.RootSchema().Name,
		"fields": fields,
		"bytes":  len(bytes),
		"opts":   opt,
	}).Trace("entering unmarshal()")

	// Load SBI definition
	root, err := ygot.DeepCopy(schema.Root)
	if err != nil {
		return err
	}
	validatedDeepCopy, ok := root.(ygot.ValidatedGoStruct)
	if !ok {
		return fmt.Errorf("no validated go struct")
	}
	ygot.BuildEmptyTree(validatedDeepCopy)
	log.Trace("built empty tree")

	var fieldStruct ygot.ValidatedGoStruct
	if len(fields) != 0 {
		log.Trace("fetching fields")
		fieldStruct, err = getField(validatedDeepCopy, fields)
		if err != nil {
			return err
		}
	} else {
		log.Trace("using root struct")
		fieldStruct = validatedDeepCopy
	}

	if err := Unmarshal(bytes, fieldStruct, opt...); err != nil {
		return err
	}
	ygot.PruneEmptyBranches(validatedDeepCopy)
	log.Trace("pruned empty branches")
	log.Trace("merging structs...")
	return ygot.MergeStructInto(goStruct, validatedDeepCopy)
}

// getField traverses the GoStruct and returns the field that represents the
// tail of the path
func getField(inStruct ygot.ValidatedGoStruct, fields []string) (ygot.ValidatedGoStruct, error) {
	defer func() {
		if r := recover(); r != nil {
			log.Error(r.(error))
		}
	}()
	log.WithFields(log.Fields{
		"fields": fields,
	}).Trace("getting field")
	f := fields[0]
	log.Tracef("field name: %v", f)
	s := reflect.ValueOf(inStruct)
	h := reflect.Indirect(s).FieldByName(f).Interface()
	outStruct, ok := h.(ygot.ValidatedGoStruct)
	if !ok {
		t := reflect.TypeOf(h)
		if !(util.IsTypeStruct(t) || util.IsTypeStructPtr(t)) {
			return nil, fmt.Errorf("cannot process entry of type %v, request longer or shorter path", t)
		}
		return nil, fmt.Errorf("expected ValidatedGoStruct got %v", t)
	}
	if len(fields) > 1 {
		log.Trace("fetching fields")
		return getField(outStruct, fields[1:])
	}
	return outStruct, nil
}

// E_IETFInterfaces_InterfaceType is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_InterfaceType. An additional value named
// IETFInterfaces_InterfaceType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_InterfaceType int64

// IsYANGGoEnum ensures that IETFInterfaces_InterfaceType implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_InterfaceType can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_InterfaceType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_InterfaceType.
func (E_IETFInterfaces_InterfaceType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_IETFInterfaces_InterfaceType.
func (e E_IETFInterfaces_InterfaceType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_InterfaceType")
}

const (
	// IETFInterfaces_InterfaceType_UNSET corresponds to the value UNSET of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_UNSET E_IETFInterfaces_InterfaceType = 0
	// IETFInterfaces_InterfaceType_a12MppSwitch corresponds to the value a12MppSwitch of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_a12MppSwitch E_IETFInterfaces_InterfaceType = 1
	// IETFInterfaces_InterfaceType_aal2 corresponds to the value aal2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aal2 E_IETFInterfaces_InterfaceType = 2
	// IETFInterfaces_InterfaceType_aal5 corresponds to the value aal5 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aal5 E_IETFInterfaces_InterfaceType = 3
	// IETFInterfaces_InterfaceType_actelisMetaLOOP corresponds to the value actelisMetaLOOP of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_actelisMetaLOOP E_IETFInterfaces_InterfaceType = 4
	// IETFInterfaces_InterfaceType_adsl corresponds to the value adsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_adsl E_IETFInterfaces_InterfaceType = 5
	// IETFInterfaces_InterfaceType_adsl2 corresponds to the value adsl2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_adsl2 E_IETFInterfaces_InterfaceType = 6
	// IETFInterfaces_InterfaceType_adsl2plus corresponds to the value adsl2plus of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_adsl2plus E_IETFInterfaces_InterfaceType = 7
	// IETFInterfaces_InterfaceType_aflane8023 corresponds to the value aflane8023 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aflane8023 E_IETFInterfaces_InterfaceType = 8
	// IETFInterfaces_InterfaceType_aflane8025 corresponds to the value aflane8025 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aflane8025 E_IETFInterfaces_InterfaceType = 9
	// IETFInterfaces_InterfaceType_aluELP corresponds to the value aluELP of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluELP E_IETFInterfaces_InterfaceType = 10
	// IETFInterfaces_InterfaceType_aluEpon corresponds to the value aluEpon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEpon E_IETFInterfaces_InterfaceType = 11
	// IETFInterfaces_InterfaceType_aluEponLogicalLink corresponds to the value aluEponLogicalLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEponLogicalLink E_IETFInterfaces_InterfaceType = 12
	// IETFInterfaces_InterfaceType_aluEponOnu corresponds to the value aluEponOnu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEponOnu E_IETFInterfaces_InterfaceType = 13
	// IETFInterfaces_InterfaceType_aluEponPhysicalUni corresponds to the value aluEponPhysicalUni of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluEponPhysicalUni E_IETFInterfaces_InterfaceType = 14
	// IETFInterfaces_InterfaceType_aluGponOnu corresponds to the value aluGponOnu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluGponOnu E_IETFInterfaces_InterfaceType = 15
	// IETFInterfaces_InterfaceType_aluGponPhysicalUni corresponds to the value aluGponPhysicalUni of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aluGponPhysicalUni E_IETFInterfaces_InterfaceType = 16
	// IETFInterfaces_InterfaceType_arap corresponds to the value arap of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_arap E_IETFInterfaces_InterfaceType = 17
	// IETFInterfaces_InterfaceType_arcnet corresponds to the value arcnet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_arcnet E_IETFInterfaces_InterfaceType = 18
	// IETFInterfaces_InterfaceType_arcnetPlus corresponds to the value arcnetPlus of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_arcnetPlus E_IETFInterfaces_InterfaceType = 19
	// IETFInterfaces_InterfaceType_async corresponds to the value async of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_async E_IETFInterfaces_InterfaceType = 20
	// IETFInterfaces_InterfaceType_atm corresponds to the value atm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atm E_IETFInterfaces_InterfaceType = 21
	// IETFInterfaces_InterfaceType_atmDxi corresponds to the value atmDxi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmDxi E_IETFInterfaces_InterfaceType = 22
	// IETFInterfaces_InterfaceType_atmFuni corresponds to the value atmFuni of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmFuni E_IETFInterfaces_InterfaceType = 23
	// IETFInterfaces_InterfaceType_atmIma corresponds to the value atmIma of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmIma E_IETFInterfaces_InterfaceType = 24
	// IETFInterfaces_InterfaceType_atmLogical corresponds to the value atmLogical of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmLogical E_IETFInterfaces_InterfaceType = 25
	// IETFInterfaces_InterfaceType_atmRadio corresponds to the value atmRadio of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmRadio E_IETFInterfaces_InterfaceType = 26
	// IETFInterfaces_InterfaceType_atmSubInterface corresponds to the value atmSubInterface of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmSubInterface E_IETFInterfaces_InterfaceType = 27
	// IETFInterfaces_InterfaceType_atmVciEndPt corresponds to the value atmVciEndPt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmVciEndPt E_IETFInterfaces_InterfaceType = 28
	// IETFInterfaces_InterfaceType_atmVirtual corresponds to the value atmVirtual of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmVirtual E_IETFInterfaces_InterfaceType = 29
	// IETFInterfaces_InterfaceType_atmbond corresponds to the value atmbond of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_atmbond E_IETFInterfaces_InterfaceType = 30
	// IETFInterfaces_InterfaceType_aviciOpticalEther corresponds to the value aviciOpticalEther of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_aviciOpticalEther E_IETFInterfaces_InterfaceType = 31
	// IETFInterfaces_InterfaceType_basicISDN corresponds to the value basicISDN of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_basicISDN E_IETFInterfaces_InterfaceType = 32
	// IETFInterfaces_InterfaceType_bgppolicyaccounting corresponds to the value bgppolicyaccounting of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bgppolicyaccounting E_IETFInterfaces_InterfaceType = 33
	// IETFInterfaces_InterfaceType_bits corresponds to the value bits of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bits E_IETFInterfaces_InterfaceType = 34
	// IETFInterfaces_InterfaceType_bridge corresponds to the value bridge of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bridge E_IETFInterfaces_InterfaceType = 35
	// IETFInterfaces_InterfaceType_bsc corresponds to the value bsc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_bsc E_IETFInterfaces_InterfaceType = 36
	// IETFInterfaces_InterfaceType_cableDownstreamRfPort corresponds to the value cableDownstreamRfPort of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cableDownstreamRfPort E_IETFInterfaces_InterfaceType = 37
	// IETFInterfaces_InterfaceType_capwapDot11Bss corresponds to the value capwapDot11Bss of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_capwapDot11Bss E_IETFInterfaces_InterfaceType = 38
	// IETFInterfaces_InterfaceType_capwapDot11Profile corresponds to the value capwapDot11Profile of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_capwapDot11Profile E_IETFInterfaces_InterfaceType = 39
	// IETFInterfaces_InterfaceType_capwapWtpVirtualRadio corresponds to the value capwapWtpVirtualRadio of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_capwapWtpVirtualRadio E_IETFInterfaces_InterfaceType = 40
	// IETFInterfaces_InterfaceType_cblVectaStar corresponds to the value cblVectaStar of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cblVectaStar E_IETFInterfaces_InterfaceType = 41
	// IETFInterfaces_InterfaceType_cctEmul corresponds to the value cctEmul of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cctEmul E_IETFInterfaces_InterfaceType = 42
	// IETFInterfaces_InterfaceType_ces corresponds to the value ces of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ces E_IETFInterfaces_InterfaceType = 43
	// IETFInterfaces_InterfaceType_channel corresponds to the value channel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_channel E_IETFInterfaces_InterfaceType = 44
	// IETFInterfaces_InterfaceType_ciscoISLvlan corresponds to the value ciscoISLvlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ciscoISLvlan E_IETFInterfaces_InterfaceType = 45
	// IETFInterfaces_InterfaceType_cnr corresponds to the value cnr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_cnr E_IETFInterfaces_InterfaceType = 46
	// IETFInterfaces_InterfaceType_coffee corresponds to the value coffee of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_coffee E_IETFInterfaces_InterfaceType = 47
	// IETFInterfaces_InterfaceType_compositeLink corresponds to the value compositeLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_compositeLink E_IETFInterfaces_InterfaceType = 48
	// IETFInterfaces_InterfaceType_dcn corresponds to the value dcn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dcn E_IETFInterfaces_InterfaceType = 49
	// IETFInterfaces_InterfaceType_ddnX25 corresponds to the value ddnX25 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ddnX25 E_IETFInterfaces_InterfaceType = 50
	// IETFInterfaces_InterfaceType_digitalPowerline corresponds to the value digitalPowerline of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_digitalPowerline E_IETFInterfaces_InterfaceType = 51
	// IETFInterfaces_InterfaceType_digitalWrapperOverheadChannel corresponds to the value digitalWrapperOverheadChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_digitalWrapperOverheadChannel E_IETFInterfaces_InterfaceType = 52
	// IETFInterfaces_InterfaceType_dlsw corresponds to the value dlsw of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dlsw E_IETFInterfaces_InterfaceType = 53
	// IETFInterfaces_InterfaceType_docsCableDownstream corresponds to the value docsCableDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableDownstream E_IETFInterfaces_InterfaceType = 54
	// IETFInterfaces_InterfaceType_docsCableMCmtsDownstream corresponds to the value docsCableMCmtsDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableMCmtsDownstream E_IETFInterfaces_InterfaceType = 55
	// IETFInterfaces_InterfaceType_docsCableMaclayer corresponds to the value docsCableMaclayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableMaclayer E_IETFInterfaces_InterfaceType = 56
	// IETFInterfaces_InterfaceType_docsCableNdf corresponds to the value docsCableNdf of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableNdf E_IETFInterfaces_InterfaceType = 57
	// IETFInterfaces_InterfaceType_docsCableNdr corresponds to the value docsCableNdr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableNdr E_IETFInterfaces_InterfaceType = 58
	// IETFInterfaces_InterfaceType_docsCableScte55d1FwdOob corresponds to the value docsCableScte55d1FwdOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d1FwdOob E_IETFInterfaces_InterfaceType = 59
	// IETFInterfaces_InterfaceType_docsCableScte55d1RetOob corresponds to the value docsCableScte55d1RetOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d1RetOob E_IETFInterfaces_InterfaceType = 60
	// IETFInterfaces_InterfaceType_docsCableScte55d2DsOob corresponds to the value docsCableScte55d2DsOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d2DsOob E_IETFInterfaces_InterfaceType = 61
	// IETFInterfaces_InterfaceType_docsCableScte55d2UsOob corresponds to the value docsCableScte55d2UsOob of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableScte55d2UsOob E_IETFInterfaces_InterfaceType = 62
	// IETFInterfaces_InterfaceType_docsCableUpstream corresponds to the value docsCableUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableUpstream E_IETFInterfaces_InterfaceType = 63
	// IETFInterfaces_InterfaceType_docsCableUpstreamChannel corresponds to the value docsCableUpstreamChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableUpstreamChannel E_IETFInterfaces_InterfaceType = 64
	// IETFInterfaces_InterfaceType_docsCableUpstreamRfPort corresponds to the value docsCableUpstreamRfPort of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsCableUpstreamRfPort E_IETFInterfaces_InterfaceType = 65
	// IETFInterfaces_InterfaceType_docsOfdmDownstream corresponds to the value docsOfdmDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsOfdmDownstream E_IETFInterfaces_InterfaceType = 66
	// IETFInterfaces_InterfaceType_docsOfdmaUpstream corresponds to the value docsOfdmaUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_docsOfdmaUpstream E_IETFInterfaces_InterfaceType = 67
	// IETFInterfaces_InterfaceType_ds0 corresponds to the value ds0 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds0 E_IETFInterfaces_InterfaceType = 68
	// IETFInterfaces_InterfaceType_ds0Bundle corresponds to the value ds0Bundle of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds0Bundle E_IETFInterfaces_InterfaceType = 69
	// IETFInterfaces_InterfaceType_ds1 corresponds to the value ds1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds1 E_IETFInterfaces_InterfaceType = 70
	// IETFInterfaces_InterfaceType_ds1FDL corresponds to the value ds1FDL of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds1FDL E_IETFInterfaces_InterfaceType = 71
	// IETFInterfaces_InterfaceType_ds3 corresponds to the value ds3 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ds3 E_IETFInterfaces_InterfaceType = 72
	// IETFInterfaces_InterfaceType_dtm corresponds to the value dtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dtm E_IETFInterfaces_InterfaceType = 73
	// IETFInterfaces_InterfaceType_dvbAsiIn corresponds to the value dvbAsiIn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbAsiIn E_IETFInterfaces_InterfaceType = 74
	// IETFInterfaces_InterfaceType_dvbAsiOut corresponds to the value dvbAsiOut of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbAsiOut E_IETFInterfaces_InterfaceType = 75
	// IETFInterfaces_InterfaceType_dvbRccDownstream corresponds to the value dvbRccDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRccDownstream E_IETFInterfaces_InterfaceType = 76
	// IETFInterfaces_InterfaceType_dvbRccMacLayer corresponds to the value dvbRccMacLayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRccMacLayer E_IETFInterfaces_InterfaceType = 77
	// IETFInterfaces_InterfaceType_dvbRccUpstream corresponds to the value dvbRccUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRccUpstream E_IETFInterfaces_InterfaceType = 78
	// IETFInterfaces_InterfaceType_dvbRcsMacLayer corresponds to the value dvbRcsMacLayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRcsMacLayer E_IETFInterfaces_InterfaceType = 79
	// IETFInterfaces_InterfaceType_dvbRcsTdma corresponds to the value dvbRcsTdma of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbRcsTdma E_IETFInterfaces_InterfaceType = 80
	// IETFInterfaces_InterfaceType_dvbTdm corresponds to the value dvbTdm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_dvbTdm E_IETFInterfaces_InterfaceType = 81
	// IETFInterfaces_InterfaceType_e1 corresponds to the value e1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_e1 E_IETFInterfaces_InterfaceType = 82
	// IETFInterfaces_InterfaceType_econet corresponds to the value econet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_econet E_IETFInterfaces_InterfaceType = 83
	// IETFInterfaces_InterfaceType_eon corresponds to the value eon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_eon E_IETFInterfaces_InterfaceType = 84
	// IETFInterfaces_InterfaceType_eplrs corresponds to the value eplrs of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_eplrs E_IETFInterfaces_InterfaceType = 85
	// IETFInterfaces_InterfaceType_escon corresponds to the value escon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_escon E_IETFInterfaces_InterfaceType = 86
	// IETFInterfaces_InterfaceType_ethernet3Mbit corresponds to the value ethernet3Mbit of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ethernet3Mbit E_IETFInterfaces_InterfaceType = 87
	// IETFInterfaces_InterfaceType_ethernetCsmacd corresponds to the value ethernetCsmacd of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ethernetCsmacd E_IETFInterfaces_InterfaceType = 88
	// IETFInterfaces_InterfaceType_fast corresponds to the value fast of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fast E_IETFInterfaces_InterfaceType = 89
	// IETFInterfaces_InterfaceType_fastEther corresponds to the value fastEther of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fastEther E_IETFInterfaces_InterfaceType = 90
	// IETFInterfaces_InterfaceType_fastEtherFX corresponds to the value fastEtherFX of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fastEtherFX E_IETFInterfaces_InterfaceType = 91
	// IETFInterfaces_InterfaceType_fastdsl corresponds to the value fastdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fastdsl E_IETFInterfaces_InterfaceType = 92
	// IETFInterfaces_InterfaceType_fcipLink corresponds to the value fcipLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fcipLink E_IETFInterfaces_InterfaceType = 93
	// IETFInterfaces_InterfaceType_fddi corresponds to the value fddi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fddi E_IETFInterfaces_InterfaceType = 94
	// IETFInterfaces_InterfaceType_fibreChannel corresponds to the value fibreChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_fibreChannel E_IETFInterfaces_InterfaceType = 95
	// IETFInterfaces_InterfaceType_frDlciEndPt corresponds to the value frDlciEndPt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frDlciEndPt E_IETFInterfaces_InterfaceType = 96
	// IETFInterfaces_InterfaceType_frForward corresponds to the value frForward of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frForward E_IETFInterfaces_InterfaceType = 97
	// IETFInterfaces_InterfaceType_frameRelay corresponds to the value frameRelay of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelay E_IETFInterfaces_InterfaceType = 98
	// IETFInterfaces_InterfaceType_frameRelayInterconnect corresponds to the value frameRelayInterconnect of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelayInterconnect E_IETFInterfaces_InterfaceType = 99
	// IETFInterfaces_InterfaceType_frameRelayMPI corresponds to the value frameRelayMPI of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelayMPI E_IETFInterfaces_InterfaceType = 100
	// IETFInterfaces_InterfaceType_frameRelayService corresponds to the value frameRelayService of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frameRelayService E_IETFInterfaces_InterfaceType = 101
	// IETFInterfaces_InterfaceType_frf16MfrBundle corresponds to the value frf16MfrBundle of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_frf16MfrBundle E_IETFInterfaces_InterfaceType = 102
	// IETFInterfaces_InterfaceType_g703at2mb corresponds to the value g703at2mb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g703at2mb E_IETFInterfaces_InterfaceType = 103
	// IETFInterfaces_InterfaceType_g703at64k corresponds to the value g703at64k of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g703at64k E_IETFInterfaces_InterfaceType = 104
	// IETFInterfaces_InterfaceType_g9981 corresponds to the value g9981 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g9981 E_IETFInterfaces_InterfaceType = 105
	// IETFInterfaces_InterfaceType_g9982 corresponds to the value g9982 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g9982 E_IETFInterfaces_InterfaceType = 106
	// IETFInterfaces_InterfaceType_g9983 corresponds to the value g9983 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_g9983 E_IETFInterfaces_InterfaceType = 107
	// IETFInterfaces_InterfaceType_gfast corresponds to the value gfast of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gfast E_IETFInterfaces_InterfaceType = 108
	// IETFInterfaces_InterfaceType_gfp corresponds to the value gfp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gfp E_IETFInterfaces_InterfaceType = 109
	// IETFInterfaces_InterfaceType_gigabitEthernet corresponds to the value gigabitEthernet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gigabitEthernet E_IETFInterfaces_InterfaceType = 110
	// IETFInterfaces_InterfaceType_gpon corresponds to the value gpon of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gpon E_IETFInterfaces_InterfaceType = 111
	// IETFInterfaces_InterfaceType_gr303IDT corresponds to the value gr303IDT of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gr303IDT E_IETFInterfaces_InterfaceType = 112
	// IETFInterfaces_InterfaceType_gr303RDT corresponds to the value gr303RDT of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gr303RDT E_IETFInterfaces_InterfaceType = 113
	// IETFInterfaces_InterfaceType_gtp corresponds to the value gtp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_gtp E_IETFInterfaces_InterfaceType = 114
	// IETFInterfaces_InterfaceType_h323Gatekeeper corresponds to the value h323Gatekeeper of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_h323Gatekeeper E_IETFInterfaces_InterfaceType = 115
	// IETFInterfaces_InterfaceType_h323Proxy corresponds to the value h323Proxy of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_h323Proxy E_IETFInterfaces_InterfaceType = 116
	// IETFInterfaces_InterfaceType_hdh1822 corresponds to the value hdh1822 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hdh1822 E_IETFInterfaces_InterfaceType = 117
	// IETFInterfaces_InterfaceType_hdlc corresponds to the value hdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hdlc E_IETFInterfaces_InterfaceType = 118
	// IETFInterfaces_InterfaceType_hdsl2 corresponds to the value hdsl2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hdsl2 E_IETFInterfaces_InterfaceType = 119
	// IETFInterfaces_InterfaceType_hiperlan2 corresponds to the value hiperlan2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hiperlan2 E_IETFInterfaces_InterfaceType = 120
	// IETFInterfaces_InterfaceType_hippi corresponds to the value hippi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hippi E_IETFInterfaces_InterfaceType = 121
	// IETFInterfaces_InterfaceType_hippiInterface corresponds to the value hippiInterface of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hippiInterface E_IETFInterfaces_InterfaceType = 122
	// IETFInterfaces_InterfaceType_homepna corresponds to the value homepna of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_homepna E_IETFInterfaces_InterfaceType = 123
	// IETFInterfaces_InterfaceType_hostPad corresponds to the value hostPad of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hostPad E_IETFInterfaces_InterfaceType = 124
	// IETFInterfaces_InterfaceType_hssi corresponds to the value hssi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hssi E_IETFInterfaces_InterfaceType = 125
	// IETFInterfaces_InterfaceType_hyperchannel corresponds to the value hyperchannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_hyperchannel E_IETFInterfaces_InterfaceType = 126
	// IETFInterfaces_InterfaceType_iana_interface_type corresponds to the value iana_interface_type of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iana_interface_type E_IETFInterfaces_InterfaceType = 127
	// IETFInterfaces_InterfaceType_ibm370parChan corresponds to the value ibm370parChan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ibm370parChan E_IETFInterfaces_InterfaceType = 128
	// IETFInterfaces_InterfaceType_idsl corresponds to the value idsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_idsl E_IETFInterfaces_InterfaceType = 129
	// IETFInterfaces_InterfaceType_ieee1394 corresponds to the value ieee1394 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee1394 E_IETFInterfaces_InterfaceType = 130
	// IETFInterfaces_InterfaceType_ieee80211 corresponds to the value ieee80211 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee80211 E_IETFInterfaces_InterfaceType = 131
	// IETFInterfaces_InterfaceType_ieee80212 corresponds to the value ieee80212 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee80212 E_IETFInterfaces_InterfaceType = 132
	// IETFInterfaces_InterfaceType_ieee802154 corresponds to the value ieee802154 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee802154 E_IETFInterfaces_InterfaceType = 133
	// IETFInterfaces_InterfaceType_ieee80216WMAN corresponds to the value ieee80216WMAN of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee80216WMAN E_IETFInterfaces_InterfaceType = 134
	// IETFInterfaces_InterfaceType_ieee8023adLag corresponds to the value ieee8023adLag of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ieee8023adLag E_IETFInterfaces_InterfaceType = 135
	// IETFInterfaces_InterfaceType_if_gsn corresponds to the value if_gsn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_if_gsn E_IETFInterfaces_InterfaceType = 136
	// IETFInterfaces_InterfaceType_ifPwType corresponds to the value ifPwType of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ifPwType E_IETFInterfaces_InterfaceType = 137
	// IETFInterfaces_InterfaceType_ifVfiType corresponds to the value ifVfiType of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ifVfiType E_IETFInterfaces_InterfaceType = 138
	// IETFInterfaces_InterfaceType_ilan corresponds to the value ilan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ilan E_IETFInterfaces_InterfaceType = 139
	// IETFInterfaces_InterfaceType_imt corresponds to the value imt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_imt E_IETFInterfaces_InterfaceType = 140
	// IETFInterfaces_InterfaceType_infiniband corresponds to the value infiniband of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_infiniband E_IETFInterfaces_InterfaceType = 141
	// IETFInterfaces_InterfaceType_interleave corresponds to the value interleave of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_interleave E_IETFInterfaces_InterfaceType = 142
	// IETFInterfaces_InterfaceType_ip corresponds to the value ip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ip E_IETFInterfaces_InterfaceType = 143
	// IETFInterfaces_InterfaceType_ipForward corresponds to the value ipForward of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipForward E_IETFInterfaces_InterfaceType = 144
	// IETFInterfaces_InterfaceType_ipOverAtm corresponds to the value ipOverAtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipOverAtm E_IETFInterfaces_InterfaceType = 145
	// IETFInterfaces_InterfaceType_ipOverCdlc corresponds to the value ipOverCdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipOverCdlc E_IETFInterfaces_InterfaceType = 146
	// IETFInterfaces_InterfaceType_ipOverClaw corresponds to the value ipOverClaw of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipOverClaw E_IETFInterfaces_InterfaceType = 147
	// IETFInterfaces_InterfaceType_ipSwitch corresponds to the value ipSwitch of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ipSwitch E_IETFInterfaces_InterfaceType = 148
	// IETFInterfaces_InterfaceType_isdn corresponds to the value isdn of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isdn E_IETFInterfaces_InterfaceType = 149
	// IETFInterfaces_InterfaceType_isdns corresponds to the value isdns of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isdns E_IETFInterfaces_InterfaceType = 150
	// IETFInterfaces_InterfaceType_isdnu corresponds to the value isdnu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isdnu E_IETFInterfaces_InterfaceType = 151
	// IETFInterfaces_InterfaceType_iso88022llc corresponds to the value iso88022llc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88022llc E_IETFInterfaces_InterfaceType = 152
	// IETFInterfaces_InterfaceType_iso88023Csmacd corresponds to the value iso88023Csmacd of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88023Csmacd E_IETFInterfaces_InterfaceType = 153
	// IETFInterfaces_InterfaceType_iso88024TokenBus corresponds to the value iso88024TokenBus of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88024TokenBus E_IETFInterfaces_InterfaceType = 154
	// IETFInterfaces_InterfaceType_iso88025CRFPInt corresponds to the value iso88025CRFPInt of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025CRFPInt E_IETFInterfaces_InterfaceType = 155
	// IETFInterfaces_InterfaceType_iso88025Dtr corresponds to the value iso88025Dtr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025Dtr E_IETFInterfaces_InterfaceType = 156
	// IETFInterfaces_InterfaceType_iso88025Fiber corresponds to the value iso88025Fiber of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025Fiber E_IETFInterfaces_InterfaceType = 157
	// IETFInterfaces_InterfaceType_iso88025TokenRing corresponds to the value iso88025TokenRing of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88025TokenRing E_IETFInterfaces_InterfaceType = 158
	// IETFInterfaces_InterfaceType_iso88026Man corresponds to the value iso88026Man of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_iso88026Man E_IETFInterfaces_InterfaceType = 159
	// IETFInterfaces_InterfaceType_isup corresponds to the value isup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_isup E_IETFInterfaces_InterfaceType = 160
	// IETFInterfaces_InterfaceType_l2vlan corresponds to the value l2vlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_l2vlan E_IETFInterfaces_InterfaceType = 161
	// IETFInterfaces_InterfaceType_l3ipvlan corresponds to the value l3ipvlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_l3ipvlan E_IETFInterfaces_InterfaceType = 162
	// IETFInterfaces_InterfaceType_l3ipxvlan corresponds to the value l3ipxvlan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_l3ipxvlan E_IETFInterfaces_InterfaceType = 163
	// IETFInterfaces_InterfaceType_lapb corresponds to the value lapb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lapb E_IETFInterfaces_InterfaceType = 164
	// IETFInterfaces_InterfaceType_lapd corresponds to the value lapd of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lapd E_IETFInterfaces_InterfaceType = 165
	// IETFInterfaces_InterfaceType_lapf corresponds to the value lapf of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lapf E_IETFInterfaces_InterfaceType = 166
	// IETFInterfaces_InterfaceType_linegroup corresponds to the value linegroup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_linegroup E_IETFInterfaces_InterfaceType = 167
	// IETFInterfaces_InterfaceType_lmp corresponds to the value lmp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_lmp E_IETFInterfaces_InterfaceType = 168
	// IETFInterfaces_InterfaceType_localTalk corresponds to the value localTalk of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_localTalk E_IETFInterfaces_InterfaceType = 169
	// IETFInterfaces_InterfaceType_macSecControlledIF corresponds to the value macSecControlledIF of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_macSecControlledIF E_IETFInterfaces_InterfaceType = 170
	// IETFInterfaces_InterfaceType_macSecUncontrolledIF corresponds to the value macSecUncontrolledIF of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_macSecUncontrolledIF E_IETFInterfaces_InterfaceType = 171
	// IETFInterfaces_InterfaceType_mediaMailOverIp corresponds to the value mediaMailOverIp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mediaMailOverIp E_IETFInterfaces_InterfaceType = 172
	// IETFInterfaces_InterfaceType_mfSigLink corresponds to the value mfSigLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mfSigLink E_IETFInterfaces_InterfaceType = 173
	// IETFInterfaces_InterfaceType_miox25 corresponds to the value miox25 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_miox25 E_IETFInterfaces_InterfaceType = 174
	// IETFInterfaces_InterfaceType_mocaVersion1 corresponds to the value mocaVersion1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mocaVersion1 E_IETFInterfaces_InterfaceType = 175
	// IETFInterfaces_InterfaceType_modem corresponds to the value modem of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_modem E_IETFInterfaces_InterfaceType = 176
	// IETFInterfaces_InterfaceType_mpc corresponds to the value mpc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mpc E_IETFInterfaces_InterfaceType = 177
	// IETFInterfaces_InterfaceType_mpegTransport corresponds to the value mpegTransport of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mpegTransport E_IETFInterfaces_InterfaceType = 178
	// IETFInterfaces_InterfaceType_mpls corresponds to the value mpls of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mpls E_IETFInterfaces_InterfaceType = 179
	// IETFInterfaces_InterfaceType_mplsTunnel corresponds to the value mplsTunnel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mplsTunnel E_IETFInterfaces_InterfaceType = 180
	// IETFInterfaces_InterfaceType_msdsl corresponds to the value msdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_msdsl E_IETFInterfaces_InterfaceType = 181
	// IETFInterfaces_InterfaceType_mvl corresponds to the value mvl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_mvl E_IETFInterfaces_InterfaceType = 182
	// IETFInterfaces_InterfaceType_myrinet corresponds to the value myrinet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_myrinet E_IETFInterfaces_InterfaceType = 183
	// IETFInterfaces_InterfaceType_nfas corresponds to the value nfas of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_nfas E_IETFInterfaces_InterfaceType = 184
	// IETFInterfaces_InterfaceType_nsip corresponds to the value nsip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_nsip E_IETFInterfaces_InterfaceType = 185
	// IETFInterfaces_InterfaceType_opticalChannel corresponds to the value opticalChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_opticalChannel E_IETFInterfaces_InterfaceType = 186
	// IETFInterfaces_InterfaceType_opticalChannelGroup corresponds to the value opticalChannelGroup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_opticalChannelGroup E_IETFInterfaces_InterfaceType = 187
	// IETFInterfaces_InterfaceType_opticalTransport corresponds to the value opticalTransport of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_opticalTransport E_IETFInterfaces_InterfaceType = 188
	// IETFInterfaces_InterfaceType_other corresponds to the value other of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_other E_IETFInterfaces_InterfaceType = 189
	// IETFInterfaces_InterfaceType_otnOdu corresponds to the value otnOdu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_otnOdu E_IETFInterfaces_InterfaceType = 190
	// IETFInterfaces_InterfaceType_otnOtu corresponds to the value otnOtu of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_otnOtu E_IETFInterfaces_InterfaceType = 191
	// IETFInterfaces_InterfaceType_para corresponds to the value para of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_para E_IETFInterfaces_InterfaceType = 192
	// IETFInterfaces_InterfaceType_pdnEtherLoop1 corresponds to the value pdnEtherLoop1 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pdnEtherLoop1 E_IETFInterfaces_InterfaceType = 193
	// IETFInterfaces_InterfaceType_pdnEtherLoop2 corresponds to the value pdnEtherLoop2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pdnEtherLoop2 E_IETFInterfaces_InterfaceType = 194
	// IETFInterfaces_InterfaceType_pip corresponds to the value pip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pip E_IETFInterfaces_InterfaceType = 195
	// IETFInterfaces_InterfaceType_plc corresponds to the value plc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_plc E_IETFInterfaces_InterfaceType = 196
	// IETFInterfaces_InterfaceType_pon155 corresponds to the value pon155 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pon155 E_IETFInterfaces_InterfaceType = 197
	// IETFInterfaces_InterfaceType_pon622 corresponds to the value pon622 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pon622 E_IETFInterfaces_InterfaceType = 198
	// IETFInterfaces_InterfaceType_pos corresponds to the value pos of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pos E_IETFInterfaces_InterfaceType = 199
	// IETFInterfaces_InterfaceType_ppp corresponds to the value ppp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ppp E_IETFInterfaces_InterfaceType = 200
	// IETFInterfaces_InterfaceType_pppMultilinkBundle corresponds to the value pppMultilinkBundle of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_pppMultilinkBundle E_IETFInterfaces_InterfaceType = 201
	// IETFInterfaces_InterfaceType_primaryISDN corresponds to the value primaryISDN of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_primaryISDN E_IETFInterfaces_InterfaceType = 202
	// IETFInterfaces_InterfaceType_propAtm corresponds to the value propAtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propAtm E_IETFInterfaces_InterfaceType = 203
	// IETFInterfaces_InterfaceType_propBWAp2Mp corresponds to the value propBWAp2Mp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propBWAp2Mp E_IETFInterfaces_InterfaceType = 204
	// IETFInterfaces_InterfaceType_propCnls corresponds to the value propCnls of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propCnls E_IETFInterfaces_InterfaceType = 205
	// IETFInterfaces_InterfaceType_propDocsWirelessDownstream corresponds to the value propDocsWirelessDownstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propDocsWirelessDownstream E_IETFInterfaces_InterfaceType = 206
	// IETFInterfaces_InterfaceType_propDocsWirelessMaclayer corresponds to the value propDocsWirelessMaclayer of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propDocsWirelessMaclayer E_IETFInterfaces_InterfaceType = 207
	// IETFInterfaces_InterfaceType_propDocsWirelessUpstream corresponds to the value propDocsWirelessUpstream of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propDocsWirelessUpstream E_IETFInterfaces_InterfaceType = 208
	// IETFInterfaces_InterfaceType_propMultiplexor corresponds to the value propMultiplexor of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propMultiplexor E_IETFInterfaces_InterfaceType = 209
	// IETFInterfaces_InterfaceType_propPointToPointSerial corresponds to the value propPointToPointSerial of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propPointToPointSerial E_IETFInterfaces_InterfaceType = 210
	// IETFInterfaces_InterfaceType_propVirtual corresponds to the value propVirtual of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propVirtual E_IETFInterfaces_InterfaceType = 211
	// IETFInterfaces_InterfaceType_propWirelessP2P corresponds to the value propWirelessP2P of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_propWirelessP2P E_IETFInterfaces_InterfaceType = 212
	// IETFInterfaces_InterfaceType_proteon10Mbit corresponds to the value proteon10Mbit of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_proteon10Mbit E_IETFInterfaces_InterfaceType = 213
	// IETFInterfaces_InterfaceType_proteon80Mbit corresponds to the value proteon80Mbit of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_proteon80Mbit E_IETFInterfaces_InterfaceType = 214
	// IETFInterfaces_InterfaceType_ptm corresponds to the value ptm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ptm E_IETFInterfaces_InterfaceType = 215
	// IETFInterfaces_InterfaceType_q2931 corresponds to the value q2931 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_q2931 E_IETFInterfaces_InterfaceType = 216
	// IETFInterfaces_InterfaceType_qam corresponds to the value qam of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_qam E_IETFInterfaces_InterfaceType = 217
	// IETFInterfaces_InterfaceType_qllc corresponds to the value qllc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_qllc E_IETFInterfaces_InterfaceType = 218
	// IETFInterfaces_InterfaceType_radioMAC corresponds to the value radioMAC of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_radioMAC E_IETFInterfaces_InterfaceType = 219
	// IETFInterfaces_InterfaceType_radsl corresponds to the value radsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_radsl E_IETFInterfaces_InterfaceType = 220
	// IETFInterfaces_InterfaceType_reachDSL corresponds to the value reachDSL of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_reachDSL E_IETFInterfaces_InterfaceType = 221
	// IETFInterfaces_InterfaceType_regular1822 corresponds to the value regular1822 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_regular1822 E_IETFInterfaces_InterfaceType = 222
	// IETFInterfaces_InterfaceType_rfc1483 corresponds to the value rfc1483 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rfc1483 E_IETFInterfaces_InterfaceType = 223
	// IETFInterfaces_InterfaceType_rfc877x25 corresponds to the value rfc877x25 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rfc877x25 E_IETFInterfaces_InterfaceType = 224
	// IETFInterfaces_InterfaceType_rpr corresponds to the value rpr of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rpr E_IETFInterfaces_InterfaceType = 225
	// IETFInterfaces_InterfaceType_rs232 corresponds to the value rs232 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rs232 E_IETFInterfaces_InterfaceType = 226
	// IETFInterfaces_InterfaceType_rsrb corresponds to the value rsrb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_rsrb E_IETFInterfaces_InterfaceType = 227
	// IETFInterfaces_InterfaceType_sdci corresponds to the value sdci of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sdci E_IETFInterfaces_InterfaceType = 228
	// IETFInterfaces_InterfaceType_sdlc corresponds to the value sdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sdlc E_IETFInterfaces_InterfaceType = 229
	// IETFInterfaces_InterfaceType_sdsl corresponds to the value sdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sdsl E_IETFInterfaces_InterfaceType = 230
	// IETFInterfaces_InterfaceType_shdsl corresponds to the value shdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_shdsl E_IETFInterfaces_InterfaceType = 231
	// IETFInterfaces_InterfaceType_sip corresponds to the value sip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sip E_IETFInterfaces_InterfaceType = 232
	// IETFInterfaces_InterfaceType_sipSig corresponds to the value sipSig of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sipSig E_IETFInterfaces_InterfaceType = 233
	// IETFInterfaces_InterfaceType_sipTg corresponds to the value sipTg of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sipTg E_IETFInterfaces_InterfaceType = 234
	// IETFInterfaces_InterfaceType_sixToFour corresponds to the value sixToFour of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sixToFour E_IETFInterfaces_InterfaceType = 235
	// IETFInterfaces_InterfaceType_slip corresponds to the value slip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_slip E_IETFInterfaces_InterfaceType = 236
	// IETFInterfaces_InterfaceType_smdsDxi corresponds to the value smdsDxi of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_smdsDxi E_IETFInterfaces_InterfaceType = 237
	// IETFInterfaces_InterfaceType_smdsIcip corresponds to the value smdsIcip of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_smdsIcip E_IETFInterfaces_InterfaceType = 238
	// IETFInterfaces_InterfaceType_softwareLoopback corresponds to the value softwareLoopback of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_softwareLoopback E_IETFInterfaces_InterfaceType = 239
	// IETFInterfaces_InterfaceType_sonet corresponds to the value sonet of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonet E_IETFInterfaces_InterfaceType = 240
	// IETFInterfaces_InterfaceType_sonetOverheadChannel corresponds to the value sonetOverheadChannel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonetOverheadChannel E_IETFInterfaces_InterfaceType = 241
	// IETFInterfaces_InterfaceType_sonetPath corresponds to the value sonetPath of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonetPath E_IETFInterfaces_InterfaceType = 242
	// IETFInterfaces_InterfaceType_sonetVT corresponds to the value sonetVT of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_sonetVT E_IETFInterfaces_InterfaceType = 243
	// IETFInterfaces_InterfaceType_srp corresponds to the value srp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_srp E_IETFInterfaces_InterfaceType = 244
	// IETFInterfaces_InterfaceType_ss7SigLink corresponds to the value ss7SigLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ss7SigLink E_IETFInterfaces_InterfaceType = 245
	// IETFInterfaces_InterfaceType_stackToStack corresponds to the value stackToStack of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_stackToStack E_IETFInterfaces_InterfaceType = 246
	// IETFInterfaces_InterfaceType_starLan corresponds to the value starLan of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_starLan E_IETFInterfaces_InterfaceType = 247
	// IETFInterfaces_InterfaceType_tdlc corresponds to the value tdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_tdlc E_IETFInterfaces_InterfaceType = 248
	// IETFInterfaces_InterfaceType_teLink corresponds to the value teLink of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_teLink E_IETFInterfaces_InterfaceType = 249
	// IETFInterfaces_InterfaceType_termPad corresponds to the value termPad of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_termPad E_IETFInterfaces_InterfaceType = 250
	// IETFInterfaces_InterfaceType_tr008 corresponds to the value tr008 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_tr008 E_IETFInterfaces_InterfaceType = 251
	// IETFInterfaces_InterfaceType_transpHdlc corresponds to the value transpHdlc of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_transpHdlc E_IETFInterfaces_InterfaceType = 252
	// IETFInterfaces_InterfaceType_tunnel corresponds to the value tunnel of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_tunnel E_IETFInterfaces_InterfaceType = 253
	// IETFInterfaces_InterfaceType_ultra corresponds to the value ultra of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_ultra E_IETFInterfaces_InterfaceType = 254
	// IETFInterfaces_InterfaceType_usb corresponds to the value usb of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_usb E_IETFInterfaces_InterfaceType = 255
	// IETFInterfaces_InterfaceType_v11 corresponds to the value v11 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v11 E_IETFInterfaces_InterfaceType = 256
	// IETFInterfaces_InterfaceType_v35 corresponds to the value v35 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v35 E_IETFInterfaces_InterfaceType = 257
	// IETFInterfaces_InterfaceType_v36 corresponds to the value v36 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v36 E_IETFInterfaces_InterfaceType = 258
	// IETFInterfaces_InterfaceType_v37 corresponds to the value v37 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_v37 E_IETFInterfaces_InterfaceType = 259
	// IETFInterfaces_InterfaceType_vdsl corresponds to the value vdsl of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vdsl E_IETFInterfaces_InterfaceType = 260
	// IETFInterfaces_InterfaceType_vdsl2 corresponds to the value vdsl2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vdsl2 E_IETFInterfaces_InterfaceType = 261
	// IETFInterfaces_InterfaceType_virtualIpAddress corresponds to the value virtualIpAddress of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_virtualIpAddress E_IETFInterfaces_InterfaceType = 262
	// IETFInterfaces_InterfaceType_virtualTg corresponds to the value virtualTg of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_virtualTg E_IETFInterfaces_InterfaceType = 263
	// IETFInterfaces_InterfaceType_vmwareNicTeam corresponds to the value vmwareNicTeam of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vmwareNicTeam E_IETFInterfaces_InterfaceType = 264
	// IETFInterfaces_InterfaceType_vmwareVirtualNic corresponds to the value vmwareVirtualNic of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_vmwareVirtualNic E_IETFInterfaces_InterfaceType = 265
	// IETFInterfaces_InterfaceType_voiceDID corresponds to the value voiceDID of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceDID E_IETFInterfaces_InterfaceType = 266
	// IETFInterfaces_InterfaceType_voiceEBS corresponds to the value voiceEBS of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEBS E_IETFInterfaces_InterfaceType = 267
	// IETFInterfaces_InterfaceType_voiceEM corresponds to the value voiceEM of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEM E_IETFInterfaces_InterfaceType = 268
	// IETFInterfaces_InterfaceType_voiceEMFGD corresponds to the value voiceEMFGD of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEMFGD E_IETFInterfaces_InterfaceType = 269
	// IETFInterfaces_InterfaceType_voiceEncap corresponds to the value voiceEncap of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceEncap E_IETFInterfaces_InterfaceType = 270
	// IETFInterfaces_InterfaceType_voiceFGDEANA corresponds to the value voiceFGDEANA of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFGDEANA E_IETFInterfaces_InterfaceType = 271
	// IETFInterfaces_InterfaceType_voiceFGDOS corresponds to the value voiceFGDOS of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFGDOS E_IETFInterfaces_InterfaceType = 272
	// IETFInterfaces_InterfaceType_voiceFXO corresponds to the value voiceFXO of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFXO E_IETFInterfaces_InterfaceType = 273
	// IETFInterfaces_InterfaceType_voiceFXS corresponds to the value voiceFXS of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceFXS E_IETFInterfaces_InterfaceType = 274
	// IETFInterfaces_InterfaceType_voiceOverAtm corresponds to the value voiceOverAtm of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverAtm E_IETFInterfaces_InterfaceType = 275
	// IETFInterfaces_InterfaceType_voiceOverCable corresponds to the value voiceOverCable of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverCable E_IETFInterfaces_InterfaceType = 276
	// IETFInterfaces_InterfaceType_voiceOverFrameRelay corresponds to the value voiceOverFrameRelay of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverFrameRelay E_IETFInterfaces_InterfaceType = 277
	// IETFInterfaces_InterfaceType_voiceOverIp corresponds to the value voiceOverIp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_voiceOverIp E_IETFInterfaces_InterfaceType = 278
	// IETFInterfaces_InterfaceType_wwanPP corresponds to the value wwanPP of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_wwanPP E_IETFInterfaces_InterfaceType = 279
	// IETFInterfaces_InterfaceType_wwanPP2 corresponds to the value wwanPP2 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_wwanPP2 E_IETFInterfaces_InterfaceType = 280
	// IETFInterfaces_InterfaceType_x213 corresponds to the value x213 of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x213 E_IETFInterfaces_InterfaceType = 281
	// IETFInterfaces_InterfaceType_x25huntGroup corresponds to the value x25huntGroup of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x25huntGroup E_IETFInterfaces_InterfaceType = 282
	// IETFInterfaces_InterfaceType_x25mlp corresponds to the value x25mlp of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x25mlp E_IETFInterfaces_InterfaceType = 283
	// IETFInterfaces_InterfaceType_x25ple corresponds to the value x25ple of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x25ple E_IETFInterfaces_InterfaceType = 284
	// IETFInterfaces_InterfaceType_x86Laps corresponds to the value x86Laps of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_x86Laps E_IETFInterfaces_InterfaceType = 285
	// IETFInterfaces_InterfaceType_xboxWireless corresponds to the value xboxWireless of IETFInterfaces_InterfaceType
	IETFInterfaces_InterfaceType_xboxWireless E_IETFInterfaces_InterfaceType = 286
)

// E_IETFInterfaces_InterfacesState_Interface_AdminStatus is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_InterfacesState_Interface_AdminStatus. An additional value named
// IETFInterfaces_InterfacesState_Interface_AdminStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_InterfacesState_Interface_AdminStatus int64

// IsYANGGoEnum ensures that IETFInterfaces_InterfacesState_Interface_AdminStatus implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_InterfacesState_Interface_AdminStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_InterfacesState_Interface_AdminStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_InterfacesState_Interface_AdminStatus.
func (E_IETFInterfaces_InterfacesState_Interface_AdminStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IETFInterfaces_InterfacesState_Interface_AdminStatus.
func (e E_IETFInterfaces_InterfacesState_Interface_AdminStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_InterfacesState_Interface_AdminStatus")
}

const (
	// IETFInterfaces_InterfacesState_Interface_AdminStatus_UNSET corresponds to the value UNSET of IETFInterfaces_InterfacesState_Interface_AdminStatus
	IETFInterfaces_InterfacesState_Interface_AdminStatus_UNSET E_IETFInterfaces_InterfacesState_Interface_AdminStatus = 0
	// IETFInterfaces_InterfacesState_Interface_AdminStatus_up corresponds to the value up of IETFInterfaces_InterfacesState_Interface_AdminStatus
	IETFInterfaces_InterfacesState_Interface_AdminStatus_up E_IETFInterfaces_InterfacesState_Interface_AdminStatus = 2
	// IETFInterfaces_InterfacesState_Interface_AdminStatus_down corresponds to the value down of IETFInterfaces_InterfacesState_Interface_AdminStatus
	IETFInterfaces_InterfacesState_Interface_AdminStatus_down E_IETFInterfaces_InterfacesState_Interface_AdminStatus = 3
	// IETFInterfaces_InterfacesState_Interface_AdminStatus_testing corresponds to the value testing of IETFInterfaces_InterfacesState_Interface_AdminStatus
	IETFInterfaces_InterfacesState_Interface_AdminStatus_testing E_IETFInterfaces_InterfacesState_Interface_AdminStatus = 4
)

// E_IETFInterfaces_InterfacesState_Interface_OperStatus is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_InterfacesState_Interface_OperStatus. An additional value named
// IETFInterfaces_InterfacesState_Interface_OperStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_InterfacesState_Interface_OperStatus int64

// IsYANGGoEnum ensures that IETFInterfaces_InterfacesState_Interface_OperStatus implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_InterfacesState_Interface_OperStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_InterfacesState_Interface_OperStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_InterfacesState_Interface_OperStatus.
func (E_IETFInterfaces_InterfacesState_Interface_OperStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IETFInterfaces_InterfacesState_Interface_OperStatus.
func (e E_IETFInterfaces_InterfacesState_Interface_OperStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_InterfacesState_Interface_OperStatus")
}

const (
	// IETFInterfaces_InterfacesState_Interface_OperStatus_UNSET corresponds to the value UNSET of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_UNSET E_IETFInterfaces_InterfacesState_Interface_OperStatus = 0
	// IETFInterfaces_InterfacesState_Interface_OperStatus_up corresponds to the value up of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_up E_IETFInterfaces_InterfacesState_Interface_OperStatus = 2
	// IETFInterfaces_InterfacesState_Interface_OperStatus_down corresponds to the value down of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_down E_IETFInterfaces_InterfacesState_Interface_OperStatus = 3
	// IETFInterfaces_InterfacesState_Interface_OperStatus_testing corresponds to the value testing of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_testing E_IETFInterfaces_InterfacesState_Interface_OperStatus = 4
	// IETFInterfaces_InterfacesState_Interface_OperStatus_unknown corresponds to the value unknown of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_unknown E_IETFInterfaces_InterfacesState_Interface_OperStatus = 5
	// IETFInterfaces_InterfacesState_Interface_OperStatus_dormant corresponds to the value dormant of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_dormant E_IETFInterfaces_InterfacesState_Interface_OperStatus = 6
	// IETFInterfaces_InterfacesState_Interface_OperStatus_not_present corresponds to the value not_present of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_not_present E_IETFInterfaces_InterfacesState_Interface_OperStatus = 7
	// IETFInterfaces_InterfacesState_Interface_OperStatus_lower_layer_down corresponds to the value lower_layer_down of IETFInterfaces_InterfacesState_Interface_OperStatus
	IETFInterfaces_InterfacesState_Interface_OperStatus_lower_layer_down E_IETFInterfaces_InterfacesState_Interface_OperStatus = 8
)

// E_IETFInterfaces_Interfaces_Interface_AdminStatus is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_Interfaces_Interface_AdminStatus. An additional value named
// IETFInterfaces_Interfaces_Interface_AdminStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_Interfaces_Interface_AdminStatus int64

// IsYANGGoEnum ensures that IETFInterfaces_Interfaces_Interface_AdminStatus implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_Interfaces_Interface_AdminStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_Interfaces_Interface_AdminStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_Interfaces_Interface_AdminStatus.
func (E_IETFInterfaces_Interfaces_Interface_AdminStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IETFInterfaces_Interfaces_Interface_AdminStatus.
func (e E_IETFInterfaces_Interfaces_Interface_AdminStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_Interfaces_Interface_AdminStatus")
}

const (
	// IETFInterfaces_Interfaces_Interface_AdminStatus_UNSET corresponds to the value UNSET of IETFInterfaces_Interfaces_Interface_AdminStatus
	IETFInterfaces_Interfaces_Interface_AdminStatus_UNSET E_IETFInterfaces_Interfaces_Interface_AdminStatus = 0
	// IETFInterfaces_Interfaces_Interface_AdminStatus_up corresponds to the value up of IETFInterfaces_Interfaces_Interface_AdminStatus
	IETFInterfaces_Interfaces_Interface_AdminStatus_up E_IETFInterfaces_Interfaces_Interface_AdminStatus = 2
	// IETFInterfaces_Interfaces_Interface_AdminStatus_down corresponds to the value down of IETFInterfaces_Interfaces_Interface_AdminStatus
	IETFInterfaces_Interfaces_Interface_AdminStatus_down E_IETFInterfaces_Interfaces_Interface_AdminStatus = 3
	// IETFInterfaces_Interfaces_Interface_AdminStatus_testing corresponds to the value testing of IETFInterfaces_Interfaces_Interface_AdminStatus
	IETFInterfaces_Interfaces_Interface_AdminStatus_testing E_IETFInterfaces_Interfaces_Interface_AdminStatus = 4
)

// E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable. An additional value named
// IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable int64

// IsYANGGoEnum ensures that IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable.
func (E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable.
func (e E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable")
}

const (
	// IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_UNSET corresponds to the value UNSET of IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable
	IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_UNSET E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable = 0
	// IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_enabled corresponds to the value enabled of IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable
	IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_enabled E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable = 2
	// IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_disabled corresponds to the value disabled of IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable
	IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable_disabled E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable = 3
)

// E_IETFInterfaces_Interfaces_Interface_OperStatus is a derived int64 type which is used to represent
// the enumerated node IETFInterfaces_Interfaces_Interface_OperStatus. An additional value named
// IETFInterfaces_Interfaces_Interface_OperStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_IETFInterfaces_Interfaces_Interface_OperStatus int64

// IsYANGGoEnum ensures that IETFInterfaces_Interfaces_Interface_OperStatus implements the yang.GoEnum
// interface. This ensures that IETFInterfaces_Interfaces_Interface_OperStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_IETFInterfaces_Interfaces_Interface_OperStatus) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  IETFInterfaces_Interfaces_Interface_OperStatus.
func (E_IETFInterfaces_Interfaces_Interface_OperStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_IETFInterfaces_Interfaces_Interface_OperStatus.
func (e E_IETFInterfaces_Interfaces_Interface_OperStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_IETFInterfaces_Interfaces_Interface_OperStatus")
}

const (
	// IETFInterfaces_Interfaces_Interface_OperStatus_UNSET corresponds to the value UNSET of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_UNSET E_IETFInterfaces_Interfaces_Interface_OperStatus = 0
	// IETFInterfaces_Interfaces_Interface_OperStatus_up corresponds to the value up of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_up E_IETFInterfaces_Interfaces_Interface_OperStatus = 2
	// IETFInterfaces_Interfaces_Interface_OperStatus_down corresponds to the value down of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_down E_IETFInterfaces_Interfaces_Interface_OperStatus = 3
	// IETFInterfaces_Interfaces_Interface_OperStatus_testing corresponds to the value testing of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_testing E_IETFInterfaces_Interfaces_Interface_OperStatus = 4
	// IETFInterfaces_Interfaces_Interface_OperStatus_unknown corresponds to the value unknown of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_unknown E_IETFInterfaces_Interfaces_Interface_OperStatus = 5
	// IETFInterfaces_Interfaces_Interface_OperStatus_dormant corresponds to the value dormant of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_dormant E_IETFInterfaces_Interfaces_Interface_OperStatus = 6
	// IETFInterfaces_Interfaces_Interface_OperStatus_not_present corresponds to the value not_present of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_not_present E_IETFInterfaces_Interfaces_Interface_OperStatus = 7
	// IETFInterfaces_Interfaces_Interface_OperStatus_lower_layer_down corresponds to the value lower_layer_down of IETFInterfaces_Interfaces_Interface_OperStatus
	IETFInterfaces_Interfaces_Interface_OperStatus_lower_layer_down E_IETFInterfaces_Interfaces_Interface_OperStatus = 8
)

// E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE.
func (E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE.
func (e E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE
	OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_UNSET E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE = 0
	// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_COMMAND corresponds to the value AAA_ACCOUNTING_EVENT_COMMAND of OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE
	OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_COMMAND E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE = 1
	// OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_LOGIN corresponds to the value AAA_ACCOUNTING_EVENT_LOGIN of OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE
	OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE_AAA_ACCOUNTING_EVENT_LOGIN E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE = 2
)

// E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE.
func (E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE.
func (e E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE
	OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_UNSET E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE = 0
	// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_COMMAND corresponds to the value AAA_AUTHORIZATION_EVENT_COMMAND of OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE
	OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_COMMAND E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE = 1
	// OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_CONFIG corresponds to the value AAA_AUTHORIZATION_EVENT_CONFIG of OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE
	OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE_AAA_AUTHORIZATION_EVENT_CONFIG E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE = 2
)

// E_OpenconfigAaaTypes_AAA_METHOD_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_METHOD_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_METHOD_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_METHOD_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_METHOD_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_METHOD_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_METHOD_TYPE.
func (E_OpenconfigAaaTypes_AAA_METHOD_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_METHOD_TYPE.
func (e E_OpenconfigAaaTypes_AAA_METHOD_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_METHOD_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_UNSET E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 0
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_LOCAL corresponds to the value LOCAL of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_LOCAL E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 1
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_RADIUS_ALL corresponds to the value RADIUS_ALL of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_RADIUS_ALL E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 2
	// OpenconfigAaaTypes_AAA_METHOD_TYPE_TACACS_ALL corresponds to the value TACACS_ALL of OpenconfigAaaTypes_AAA_METHOD_TYPE
	OpenconfigAaaTypes_AAA_METHOD_TYPE_TACACS_ALL E_OpenconfigAaaTypes_AAA_METHOD_TYPE = 3
)

// E_OpenconfigAaaTypes_AAA_SERVER_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_AAA_SERVER_TYPE. An additional value named
// OpenconfigAaaTypes_AAA_SERVER_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_AAA_SERVER_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_AAA_SERVER_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_AAA_SERVER_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_AAA_SERVER_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_AAA_SERVER_TYPE.
func (E_OpenconfigAaaTypes_AAA_SERVER_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_AAA_SERVER_TYPE.
func (e E_OpenconfigAaaTypes_AAA_SERVER_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_AAA_SERVER_TYPE")
}

const (
	// OpenconfigAaaTypes_AAA_SERVER_TYPE_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_AAA_SERVER_TYPE
	OpenconfigAaaTypes_AAA_SERVER_TYPE_UNSET E_OpenconfigAaaTypes_AAA_SERVER_TYPE = 0
	// OpenconfigAaaTypes_AAA_SERVER_TYPE_RADIUS corresponds to the value RADIUS of OpenconfigAaaTypes_AAA_SERVER_TYPE
	OpenconfigAaaTypes_AAA_SERVER_TYPE_RADIUS E_OpenconfigAaaTypes_AAA_SERVER_TYPE = 1
	// OpenconfigAaaTypes_AAA_SERVER_TYPE_TACACS corresponds to the value TACACS of OpenconfigAaaTypes_AAA_SERVER_TYPE
	OpenconfigAaaTypes_AAA_SERVER_TYPE_TACACS E_OpenconfigAaaTypes_AAA_SERVER_TYPE = 2
)

// E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES is a derived int64 type which is used to represent
// the enumerated node OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES. An additional value named
// OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES int64

// IsYANGGoEnum ensures that OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES implements the yang.GoEnum
// interface. This ensures that OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES.
func (E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES.
func (e E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES")
}

const (
	// OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_UNSET corresponds to the value UNSET of OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
	OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_UNSET E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES = 0
	// OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_SYSTEM_ROLE_ADMIN corresponds to the value SYSTEM_ROLE_ADMIN of OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES
	OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES_SYSTEM_ROLE_ADMIN E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES = 1
)

// E_OpenconfigAcl_ACL_COUNTER_CAPABILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_ACL_COUNTER_CAPABILITY. An additional value named
// OpenconfigAcl_ACL_COUNTER_CAPABILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_ACL_COUNTER_CAPABILITY int64

// IsYANGGoEnum ensures that OpenconfigAcl_ACL_COUNTER_CAPABILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_ACL_COUNTER_CAPABILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_ACL_COUNTER_CAPABILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_ACL_COUNTER_CAPABILITY.
func (E_OpenconfigAcl_ACL_COUNTER_CAPABILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAcl_ACL_COUNTER_CAPABILITY.
func (e E_OpenconfigAcl_ACL_COUNTER_CAPABILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_ACL_COUNTER_CAPABILITY")
}

const (
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_UNSET corresponds to the value UNSET of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_UNSET E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 0
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_AGGREGATE_ONLY corresponds to the value AGGREGATE_ONLY of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_AGGREGATE_ONLY E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 1
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_AGGREGATE corresponds to the value INTERFACE_AGGREGATE of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_AGGREGATE E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 2
	// OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_ONLY corresponds to the value INTERFACE_ONLY of OpenconfigAcl_ACL_COUNTER_CAPABILITY
	OpenconfigAcl_ACL_COUNTER_CAPABILITY_INTERFACE_ONLY E_OpenconfigAcl_ACL_COUNTER_CAPABILITY = 3
)

// E_OpenconfigAcl_ACL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_ACL_TYPE. An additional value named
// OpenconfigAcl_ACL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_ACL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigAcl_ACL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_ACL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_ACL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_ACL_TYPE.
func (E_OpenconfigAcl_ACL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigAcl_ACL_TYPE.
func (e E_OpenconfigAcl_ACL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_ACL_TYPE")
}

const (
	// OpenconfigAcl_ACL_TYPE_UNSET corresponds to the value UNSET of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_UNSET E_OpenconfigAcl_ACL_TYPE = 0
	// OpenconfigAcl_ACL_TYPE_ACL_IPV4 corresponds to the value ACL_IPV4 of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_IPV4 E_OpenconfigAcl_ACL_TYPE = 1
	// OpenconfigAcl_ACL_TYPE_ACL_IPV6 corresponds to the value ACL_IPV6 of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_IPV6 E_OpenconfigAcl_ACL_TYPE = 2
	// OpenconfigAcl_ACL_TYPE_ACL_L2 corresponds to the value ACL_L2 of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_L2 E_OpenconfigAcl_ACL_TYPE = 3
	// OpenconfigAcl_ACL_TYPE_ACL_MIXED corresponds to the value ACL_MIXED of OpenconfigAcl_ACL_TYPE
	OpenconfigAcl_ACL_TYPE_ACL_MIXED E_OpenconfigAcl_ACL_TYPE = 4
)

// E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort. An additional value named
// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort int64

// IsYANGGoEnum ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort.
func (E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort.
func (e E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort")
}

const (
	// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_UNSET corresponds to the value UNSET of OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
	OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_UNSET E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort = 0
	// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_ANY corresponds to the value ANY of OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort
	OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort_ANY E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort = 1
)

// E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort. An additional value named
// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort int64

// IsYANGGoEnum ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort.
func (E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort.
func (e E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort")
}

const (
	// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_UNSET corresponds to the value UNSET of OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
	OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_UNSET E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort = 0
	// OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_ANY corresponds to the value ANY of OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort
	OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort_ANY E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort = 1
)

// E_OpenconfigAcl_FORWARDING_ACTION is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_FORWARDING_ACTION. An additional value named
// OpenconfigAcl_FORWARDING_ACTION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_FORWARDING_ACTION int64

// IsYANGGoEnum ensures that OpenconfigAcl_FORWARDING_ACTION implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_FORWARDING_ACTION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_FORWARDING_ACTION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_FORWARDING_ACTION.
func (E_OpenconfigAcl_FORWARDING_ACTION) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAcl_FORWARDING_ACTION.
func (e E_OpenconfigAcl_FORWARDING_ACTION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_FORWARDING_ACTION")
}

const (
	// OpenconfigAcl_FORWARDING_ACTION_UNSET corresponds to the value UNSET of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_UNSET E_OpenconfigAcl_FORWARDING_ACTION = 0
	// OpenconfigAcl_FORWARDING_ACTION_ACCEPT corresponds to the value ACCEPT of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_ACCEPT E_OpenconfigAcl_FORWARDING_ACTION = 1
	// OpenconfigAcl_FORWARDING_ACTION_DROP corresponds to the value DROP of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_DROP E_OpenconfigAcl_FORWARDING_ACTION = 2
	// OpenconfigAcl_FORWARDING_ACTION_REJECT corresponds to the value REJECT of OpenconfigAcl_FORWARDING_ACTION
	OpenconfigAcl_FORWARDING_ACTION_REJECT E_OpenconfigAcl_FORWARDING_ACTION = 3
)

// E_OpenconfigAcl_LOG_ACTION is a derived int64 type which is used to represent
// the enumerated node OpenconfigAcl_LOG_ACTION. An additional value named
// OpenconfigAcl_LOG_ACTION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAcl_LOG_ACTION int64

// IsYANGGoEnum ensures that OpenconfigAcl_LOG_ACTION implements the yang.GoEnum
// interface. This ensures that OpenconfigAcl_LOG_ACTION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAcl_LOG_ACTION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAcl_LOG_ACTION.
func (E_OpenconfigAcl_LOG_ACTION) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigAcl_LOG_ACTION.
func (e E_OpenconfigAcl_LOG_ACTION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAcl_LOG_ACTION")
}

const (
	// OpenconfigAcl_LOG_ACTION_UNSET corresponds to the value UNSET of OpenconfigAcl_LOG_ACTION
	OpenconfigAcl_LOG_ACTION_UNSET E_OpenconfigAcl_LOG_ACTION = 0
	// OpenconfigAcl_LOG_ACTION_LOG_NONE corresponds to the value LOG_NONE of OpenconfigAcl_LOG_ACTION
	OpenconfigAcl_LOG_ACTION_LOG_NONE E_OpenconfigAcl_LOG_ACTION = 1
	// OpenconfigAcl_LOG_ACTION_LOG_SYSLOG corresponds to the value LOG_SYSLOG of OpenconfigAcl_LOG_ACTION
	OpenconfigAcl_LOG_ACTION_LOG_SYSLOG E_OpenconfigAcl_LOG_ACTION = 2
)

// E_OpenconfigAft_EncapsulationHeaderType is a derived int64 type which is used to represent
// the enumerated node OpenconfigAft_EncapsulationHeaderType. An additional value named
// OpenconfigAft_EncapsulationHeaderType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAft_EncapsulationHeaderType int64

// IsYANGGoEnum ensures that OpenconfigAft_EncapsulationHeaderType implements the yang.GoEnum
// interface. This ensures that OpenconfigAft_EncapsulationHeaderType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAft_EncapsulationHeaderType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAft_EncapsulationHeaderType.
func (E_OpenconfigAft_EncapsulationHeaderType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAft_EncapsulationHeaderType.
func (e E_OpenconfigAft_EncapsulationHeaderType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAft_EncapsulationHeaderType")
}

const (
	// OpenconfigAft_EncapsulationHeaderType_UNSET corresponds to the value UNSET of OpenconfigAft_EncapsulationHeaderType
	OpenconfigAft_EncapsulationHeaderType_UNSET E_OpenconfigAft_EncapsulationHeaderType = 0
	// OpenconfigAft_EncapsulationHeaderType_GRE corresponds to the value GRE of OpenconfigAft_EncapsulationHeaderType
	OpenconfigAft_EncapsulationHeaderType_GRE E_OpenconfigAft_EncapsulationHeaderType = 1
	// OpenconfigAft_EncapsulationHeaderType_IPV4 corresponds to the value IPV4 of OpenconfigAft_EncapsulationHeaderType
	OpenconfigAft_EncapsulationHeaderType_IPV4 E_OpenconfigAft_EncapsulationHeaderType = 2
	// OpenconfigAft_EncapsulationHeaderType_IPV6 corresponds to the value IPV6 of OpenconfigAft_EncapsulationHeaderType
	OpenconfigAft_EncapsulationHeaderType_IPV6 E_OpenconfigAft_EncapsulationHeaderType = 3
	// OpenconfigAft_EncapsulationHeaderType_MPLS corresponds to the value MPLS of OpenconfigAft_EncapsulationHeaderType
	OpenconfigAft_EncapsulationHeaderType_MPLS E_OpenconfigAft_EncapsulationHeaderType = 4
)

// E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY. An additional value named
// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY int64

// IsYANGGoEnum ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY implements the yang.GoEnum
// interface. This ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY.
func (e E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY")
}

const (
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNSET corresponds to the value UNSET of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNSET E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 0
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_CRITICAL corresponds to the value CRITICAL of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_CRITICAL E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 1
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MAJOR corresponds to the value MAJOR of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MAJOR E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 2
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MINOR corresponds to the value MINOR of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_MINOR E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 3
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNKNOWN corresponds to the value UNKNOWN of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_UNKNOWN E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 4
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_WARNING corresponds to the value WARNING of OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY_WARNING E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY = 5
)

// E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID is a derived int64 type which is used to represent
// the enumerated node OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID. An additional value named
// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID int64

// IsYANGGoEnum ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID implements the yang.GoEnum
// interface. This ensures that OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID.
func (E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID.
func (e E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID")
}

const (
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_UNSET corresponds to the value UNSET of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_UNSET E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 0
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_AIS corresponds to the value AIS of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_AIS E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 1
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_EQPT corresponds to the value EQPT of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_EQPT E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 2
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_LOS corresponds to the value LOS of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_LOS E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 3
	// OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_OTS corresponds to the value OTS of OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID
	OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID_OTS E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID = 4
)

// E_OpenconfigBfd_BfdDiagnosticCode is a derived int64 type which is used to represent
// the enumerated node OpenconfigBfd_BfdDiagnosticCode. An additional value named
// OpenconfigBfd_BfdDiagnosticCode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBfd_BfdDiagnosticCode int64

// IsYANGGoEnum ensures that OpenconfigBfd_BfdDiagnosticCode implements the yang.GoEnum
// interface. This ensures that OpenconfigBfd_BfdDiagnosticCode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBfd_BfdDiagnosticCode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBfd_BfdDiagnosticCode.
func (E_OpenconfigBfd_BfdDiagnosticCode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBfd_BfdDiagnosticCode.
func (e E_OpenconfigBfd_BfdDiagnosticCode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBfd_BfdDiagnosticCode")
}

const (
	// OpenconfigBfd_BfdDiagnosticCode_UNSET corresponds to the value UNSET of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_UNSET E_OpenconfigBfd_BfdDiagnosticCode = 0
	// OpenconfigBfd_BfdDiagnosticCode_NO_DIAGNOSTIC corresponds to the value NO_DIAGNOSTIC of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_NO_DIAGNOSTIC E_OpenconfigBfd_BfdDiagnosticCode = 1
	// OpenconfigBfd_BfdDiagnosticCode_DETECTION_TIMEOUT corresponds to the value DETECTION_TIMEOUT of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_DETECTION_TIMEOUT E_OpenconfigBfd_BfdDiagnosticCode = 2
	// OpenconfigBfd_BfdDiagnosticCode_ECHO_FAILED corresponds to the value ECHO_FAILED of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_ECHO_FAILED E_OpenconfigBfd_BfdDiagnosticCode = 3
	// OpenconfigBfd_BfdDiagnosticCode_FORWARDING_RESET corresponds to the value FORWARDING_RESET of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_FORWARDING_RESET E_OpenconfigBfd_BfdDiagnosticCode = 4
	// OpenconfigBfd_BfdDiagnosticCode_PATH_DOWN corresponds to the value PATH_DOWN of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_PATH_DOWN E_OpenconfigBfd_BfdDiagnosticCode = 5
	// OpenconfigBfd_BfdDiagnosticCode_CONCATENATED_PATH_DOWN corresponds to the value CONCATENATED_PATH_DOWN of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_CONCATENATED_PATH_DOWN E_OpenconfigBfd_BfdDiagnosticCode = 6
	// OpenconfigBfd_BfdDiagnosticCode_ADMIN_DOWN corresponds to the value ADMIN_DOWN of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_ADMIN_DOWN E_OpenconfigBfd_BfdDiagnosticCode = 7
	// OpenconfigBfd_BfdDiagnosticCode_REVERSE_CONCATENATED_PATH_DOWN corresponds to the value REVERSE_CONCATENATED_PATH_DOWN of OpenconfigBfd_BfdDiagnosticCode
	OpenconfigBfd_BfdDiagnosticCode_REVERSE_CONCATENATED_PATH_DOWN E_OpenconfigBfd_BfdDiagnosticCode = 8
)

// E_OpenconfigBfd_BfdSessionState is a derived int64 type which is used to represent
// the enumerated node OpenconfigBfd_BfdSessionState. An additional value named
// OpenconfigBfd_BfdSessionState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBfd_BfdSessionState int64

// IsYANGGoEnum ensures that OpenconfigBfd_BfdSessionState implements the yang.GoEnum
// interface. This ensures that OpenconfigBfd_BfdSessionState can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBfd_BfdSessionState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBfd_BfdSessionState.
func (E_OpenconfigBfd_BfdSessionState) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBfd_BfdSessionState.
func (e E_OpenconfigBfd_BfdSessionState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBfd_BfdSessionState")
}

const (
	// OpenconfigBfd_BfdSessionState_UNSET corresponds to the value UNSET of OpenconfigBfd_BfdSessionState
	OpenconfigBfd_BfdSessionState_UNSET E_OpenconfigBfd_BfdSessionState = 0
	// OpenconfigBfd_BfdSessionState_UP corresponds to the value UP of OpenconfigBfd_BfdSessionState
	OpenconfigBfd_BfdSessionState_UP E_OpenconfigBfd_BfdSessionState = 1
	// OpenconfigBfd_BfdSessionState_DOWN corresponds to the value DOWN of OpenconfigBfd_BfdSessionState
	OpenconfigBfd_BfdSessionState_DOWN E_OpenconfigBfd_BfdSessionState = 2
	// OpenconfigBfd_BfdSessionState_ADMIN_DOWN corresponds to the value ADMIN_DOWN of OpenconfigBfd_BfdSessionState
	OpenconfigBfd_BfdSessionState_ADMIN_DOWN E_OpenconfigBfd_BfdSessionState = 3
	// OpenconfigBfd_BfdSessionState_INIT corresponds to the value INIT of OpenconfigBfd_BfdSessionState
	OpenconfigBfd_BfdSessionState_INIT E_OpenconfigBfd_BfdSessionState = 4
)

// E_OpenconfigBgpTypes_AFI_SAFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_AFI_SAFI_TYPE. An additional value named
// OpenconfigBgpTypes_AFI_SAFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_AFI_SAFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_AFI_SAFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_AFI_SAFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_AFI_SAFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_AFI_SAFI_TYPE.
func (E_OpenconfigBgpTypes_AFI_SAFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_AFI_SAFI_TYPE.
func (e E_OpenconfigBgpTypes_AFI_SAFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_AFI_SAFI_TYPE")
}

const (
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_UNSET E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 0
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_FLOWSPEC corresponds to the value IPV4_FLOWSPEC of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_FLOWSPEC E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 1
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_LABELED_UNICAST corresponds to the value IPV4_LABELED_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_LABELED_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 2
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_UNICAST corresponds to the value IPV4_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV4_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 3
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_LABELED_UNICAST corresponds to the value IPV6_LABELED_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_LABELED_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 4
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_UNICAST corresponds to the value IPV6_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_IPV6_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 5
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_EVPN corresponds to the value L2VPN_EVPN of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_EVPN E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 6
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_VPLS corresponds to the value L2VPN_VPLS of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L2VPN_VPLS E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 7
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_MULTICAST corresponds to the value L3VPN_IPV4_MULTICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_MULTICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 8
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_UNICAST corresponds to the value L3VPN_IPV4_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV4_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 9
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_MULTICAST corresponds to the value L3VPN_IPV6_MULTICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_MULTICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 10
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_UNICAST corresponds to the value L3VPN_IPV6_UNICAST of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_L3VPN_IPV6_UNICAST E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 11
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE corresponds to the value LINKSTATE of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 12
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_SPF corresponds to the value LINKSTATE_SPF of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_SPF E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 13
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_VPN corresponds to the value LINKSTATE_VPN of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_LINKSTATE_VPN E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 14
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV4 corresponds to the value SRTE_POLICY_IPV4 of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV4 E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 15
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV6 corresponds to the value SRTE_POLICY_IPV6 of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_SRTE_POLICY_IPV6 E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 16
	// OpenconfigBgpTypes_AFI_SAFI_TYPE_VPNV4_FLOWSPEC corresponds to the value VPNV4_FLOWSPEC of OpenconfigBgpTypes_AFI_SAFI_TYPE
	OpenconfigBgpTypes_AFI_SAFI_TYPE_VPNV4_FLOWSPEC E_OpenconfigBgpTypes_AFI_SAFI_TYPE = 17
)

// E_OpenconfigBgpTypes_BGP_CAPABILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_CAPABILITY. An additional value named
// OpenconfigBgpTypes_BGP_CAPABILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_CAPABILITY int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_CAPABILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_CAPABILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_CAPABILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_CAPABILITY.
func (E_OpenconfigBgpTypes_BGP_CAPABILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_CAPABILITY.
func (e E_OpenconfigBgpTypes_BGP_CAPABILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_CAPABILITY")
}

const (
	// OpenconfigBgpTypes_BGP_CAPABILITY_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_UNSET E_OpenconfigBgpTypes_BGP_CAPABILITY = 0
	// OpenconfigBgpTypes_BGP_CAPABILITY_ADD_PATHS corresponds to the value ADD_PATHS of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_ADD_PATHS E_OpenconfigBgpTypes_BGP_CAPABILITY = 1
	// OpenconfigBgpTypes_BGP_CAPABILITY_ASN32 corresponds to the value ASN32 of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_ASN32 E_OpenconfigBgpTypes_BGP_CAPABILITY = 2
	// OpenconfigBgpTypes_BGP_CAPABILITY_EXTENDED_NEXTHOP_ENCODING corresponds to the value EXTENDED_NEXTHOP_ENCODING of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_EXTENDED_NEXTHOP_ENCODING E_OpenconfigBgpTypes_BGP_CAPABILITY = 3
	// OpenconfigBgpTypes_BGP_CAPABILITY_GRACEFUL_RESTART corresponds to the value GRACEFUL_RESTART of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_GRACEFUL_RESTART E_OpenconfigBgpTypes_BGP_CAPABILITY = 4
	// OpenconfigBgpTypes_BGP_CAPABILITY_MPBGP corresponds to the value MPBGP of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_MPBGP E_OpenconfigBgpTypes_BGP_CAPABILITY = 5
	// OpenconfigBgpTypes_BGP_CAPABILITY_ROUTE_REFRESH corresponds to the value ROUTE_REFRESH of OpenconfigBgpTypes_BGP_CAPABILITY
	OpenconfigBgpTypes_BGP_CAPABILITY_ROUTE_REFRESH E_OpenconfigBgpTypes_BGP_CAPABILITY = 6
)

// E_OpenconfigBgpTypes_BGP_ERROR_CODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_ERROR_CODE. An additional value named
// OpenconfigBgpTypes_BGP_ERROR_CODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_ERROR_CODE int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_ERROR_CODE implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_ERROR_CODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_ERROR_CODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_ERROR_CODE.
func (E_OpenconfigBgpTypes_BGP_ERROR_CODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_ERROR_CODE.
func (e E_OpenconfigBgpTypes_BGP_ERROR_CODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_ERROR_CODE")
}

const (
	// OpenconfigBgpTypes_BGP_ERROR_CODE_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_UNSET E_OpenconfigBgpTypes_BGP_ERROR_CODE = 0
	// OpenconfigBgpTypes_BGP_ERROR_CODE_CEASE corresponds to the value CEASE of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_CEASE E_OpenconfigBgpTypes_BGP_ERROR_CODE = 1
	// OpenconfigBgpTypes_BGP_ERROR_CODE_FINITE_STATE_MACHINE_ERROR corresponds to the value FINITE_STATE_MACHINE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_FINITE_STATE_MACHINE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 2
	// OpenconfigBgpTypes_BGP_ERROR_CODE_HOLD_TIMER_EXPIRED corresponds to the value HOLD_TIMER_EXPIRED of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_HOLD_TIMER_EXPIRED E_OpenconfigBgpTypes_BGP_ERROR_CODE = 3
	// OpenconfigBgpTypes_BGP_ERROR_CODE_MESSAGE_HEADER_ERROR corresponds to the value MESSAGE_HEADER_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_MESSAGE_HEADER_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 4
	// OpenconfigBgpTypes_BGP_ERROR_CODE_OPEN_MESSAGE_ERROR corresponds to the value OPEN_MESSAGE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_OPEN_MESSAGE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 5
	// OpenconfigBgpTypes_BGP_ERROR_CODE_ROUTE_REFRESH_MESSAGE_ERROR corresponds to the value ROUTE_REFRESH_MESSAGE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_ROUTE_REFRESH_MESSAGE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 6
	// OpenconfigBgpTypes_BGP_ERROR_CODE_UPDATE_MESSAGE_ERROR corresponds to the value UPDATE_MESSAGE_ERROR of OpenconfigBgpTypes_BGP_ERROR_CODE
	OpenconfigBgpTypes_BGP_ERROR_CODE_UPDATE_MESSAGE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_CODE = 7
)

// E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_ERROR_SUBCODE. An additional value named
// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_ERROR_SUBCODE implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_ERROR_SUBCODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_ERROR_SUBCODE.
func (E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE.
func (e E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE")
}

const (
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSET E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 0
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_RESET corresponds to the value ADMINISTRATIVE_RESET of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_RESET E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 1
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_SHUTDOWN corresponds to the value ADMINISTRATIVE_SHUTDOWN of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ADMINISTRATIVE_SHUTDOWN E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 2
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_FLAGS_ERROR corresponds to the value ATTRIBUTE_FLAGS_ERROR of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_FLAGS_ERROR E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 3
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_LENGTH_ERROR corresponds to the value ATTRIBUTE_LENGTH_ERROR of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ATTRIBUTE_LENGTH_ERROR E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 4
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_BGP_IDENTIFIER corresponds to the value BAD_BGP_IDENTIFIER of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_BGP_IDENTIFIER E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 5
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_LENGTH corresponds to the value BAD_MESSAGE_LENGTH of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_LENGTH E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 6
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_TYPE corresponds to the value BAD_MESSAGE_TYPE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_MESSAGE_TYPE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 7
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_PEER_AS corresponds to the value BAD_PEER_AS of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_BAD_PEER_AS E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 8
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CEASE_SUBCODE corresponds to the value CEASE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CEASE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 9
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_NOT_SYNCHRONIZED corresponds to the value CONNECTION_NOT_SYNCHRONIZED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_NOT_SYNCHRONIZED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 10
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_REJECTED corresponds to the value CONNECTION_REJECTED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONNECTION_REJECTED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 11
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONN_COLLISION_RESOLUTION corresponds to the value CONN_COLLISION_RESOLUTION of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_CONN_COLLISION_RESOLUTION E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 12
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_FINITE_STATE_MACHINE_SUBCODE corresponds to the value FINITE_STATE_MACHINE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_FINITE_STATE_MACHINE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 13
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_MESSAGE_LENGTH corresponds to the value INVALID_MESSAGE_LENGTH of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_MESSAGE_LENGTH E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 14
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NETWORK_FIELD corresponds to the value INVALID_NETWORK_FIELD of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NETWORK_FIELD E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 15
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NEXT_HOP_ATTRIBUTE corresponds to the value INVALID_NEXT_HOP_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_NEXT_HOP_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 16
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_ORIGIN_ATTRIBUTE corresponds to the value INVALID_ORIGIN_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_INVALID_ORIGIN_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 17
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_AS_PATH corresponds to the value MALFORMED_AS_PATH of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_AS_PATH E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 18
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_ATTRIBUTE_LIST corresponds to the value MALFORMED_ATTRIBUTE_LIST of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MALFORMED_ATTRIBUTE_LIST E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 19
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MAX_NUM_PREFIXES_REACHED corresponds to the value MAX_NUM_PREFIXES_REACHED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MAX_NUM_PREFIXES_REACHED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 20
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MESSAGE_HEADER_SUBCODE corresponds to the value MESSAGE_HEADER_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MESSAGE_HEADER_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 21
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MISSING_WELL_KNOWN_ATTRIBUTE corresponds to the value MISSING_WELL_KNOWN_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_MISSING_WELL_KNOWN_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 22
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPEN_MESSAGE_SUBCODE corresponds to the value OPEN_MESSAGE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPEN_MESSAGE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 23
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPTIONAL_ATTRIBUTE_ERROR corresponds to the value OPTIONAL_ATTRIBUTE_ERROR of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OPTIONAL_ATTRIBUTE_ERROR E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 24
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OTHER_CONFIG_CHANGE corresponds to the value OTHER_CONFIG_CHANGE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OTHER_CONFIG_CHANGE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 25
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OUT_OF_RESOURCES corresponds to the value OUT_OF_RESOURCES of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_OUT_OF_RESOURCES E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 26
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_PEER_DE_CONFIGURED corresponds to the value PEER_DE_CONFIGURED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_PEER_DE_CONFIGURED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 27
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED corresponds to the value RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 28
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM corresponds to the value RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 29
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENSENT corresponds to the value RECEIVE_UNEXPECTED_MESSAGE_OPENSENT of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_RECEIVE_UNEXPECTED_MESSAGE_OPENSENT E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 30
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ROUTE_REFRESH_SUBCODE corresponds to the value ROUTE_REFRESH_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_ROUTE_REFRESH_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 31
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNACCEPTABLE_HOLD_TIME corresponds to the value UNACCEPTABLE_HOLD_TIME of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNACCEPTABLE_HOLD_TIME E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 32
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE corresponds to the value UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 33
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSPECIFIC corresponds to the value UNSPECIFIC of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSPECIFIC E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 34
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_CAPABILITY corresponds to the value UNSUPPORTED_CAPABILITY of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_CAPABILITY E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 35
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_OPTIONAL_PARAMETER corresponds to the value UNSUPPORTED_OPTIONAL_PARAMETER of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_OPTIONAL_PARAMETER E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 36
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_VERSION_NUMBER corresponds to the value UNSUPPORTED_VERSION_NUMBER of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UNSUPPORTED_VERSION_NUMBER E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 37
	// OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UPDATE_MESSAGE_SUBCODE corresponds to the value UPDATE_MESSAGE_SUBCODE of OpenconfigBgpTypes_BGP_ERROR_SUBCODE
	OpenconfigBgpTypes_BGP_ERROR_SUBCODE_UPDATE_MESSAGE_SUBCODE E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE = 38
)

// E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY. An additional value named
// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY int64

// IsYANGGoEnum ensures that OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY implements the yang.GoEnum
// interface. This ensures that OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY.
func (E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY.
func (e E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY")
}

const (
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_UNSET corresponds to the value UNSET of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_UNSET E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 0
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NOPEER corresponds to the value NOPEER of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NOPEER E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 1
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_ADVERTISE corresponds to the value NO_ADVERTISE of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_ADVERTISE E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 2
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT corresponds to the value NO_EXPORT of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 3
	// OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT_SUBCONFED corresponds to the value NO_EXPORT_SUBCONFED of OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY
	OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY_NO_EXPORT_SUBCONFED E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY = 4
)

// E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode. An additional value named
// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode int64

// IsYANGGoEnum ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode.
func (E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode.
func (e E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode")
}

const (
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_UNSET corresponds to the value UNSET of OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode
	OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_UNSET E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode = 0
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_HELPER_ONLY corresponds to the value HELPER_ONLY of OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode
	OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_HELPER_ONLY E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode = 1
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_BILATERAL corresponds to the value BILATERAL of OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode
	OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_BILATERAL E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode = 2
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_REMOTE_HELPER corresponds to the value REMOTE_HELPER of OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode
	OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode_REMOTE_HELPER E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode = 3
)

// E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState. An additional value named
// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState int64

// IsYANGGoEnum ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState.
func (E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState.
func (e E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState")
}

const (
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_UNSET corresponds to the value UNSET of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_UNSET E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 0
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_IDLE corresponds to the value IDLE of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_IDLE E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 1
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_CONNECT corresponds to the value CONNECT of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_CONNECT E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 2
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_ACTIVE corresponds to the value ACTIVE of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_ACTIVE E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 3
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_OPENSENT corresponds to the value OPENSENT of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_OPENSENT E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 4
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_OPENCONFIRM corresponds to the value OPENCONFIRM of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_OPENCONFIRM E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 5
	// OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_ESTABLISHED corresponds to the value ESTABLISHED of OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState
	OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState_ESTABLISHED E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState = 6
)

// E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid. An additional value named
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid int64

// IsYANGGoEnum ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid.
func (E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid.
func (e E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid")
}

const (
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_UNSET corresponds to the value UNSET of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_UNSET E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 0
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_IPV4_EXPLICIT_NULL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 1
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_ROUTER_ALERT E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 2
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_IPV6_EXPLICIT_NULL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 3
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_IMPLICIT_NULL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 4
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_ENTROPY_LABEL_INDICATOR E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 8
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_NO_LABEL corresponds to the value NO_LABEL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid_NO_LABEL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid = 9
)

// E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type. An additional value named
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type int64

// IsYANGGoEnum ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type.
func (E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type.
func (e E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type")
}

const (
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_UNSET corresponds to the value UNSET of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_UNSET E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 0
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_MPLS_SID corresponds to the value MPLS_SID of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_MPLS_SID E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 2
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_SID corresponds to the value IPV6_SID of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_SID E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 3
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV4_NODE_ADDRESS corresponds to the value IPV4_NODE_ADDRESS of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV4_NODE_ADDRESS E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 4
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_NODE_ADDRESS corresponds to the value IPV6_NODE_ADDRESS of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_NODE_ADDRESS E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 5
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV4_LOCAL_INTF_ID corresponds to the value IPV4_LOCAL_INTF_ID of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV4_LOCAL_INTF_ID E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 6
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV4_LOCAL_REMOTE_ADDR corresponds to the value IPV4_LOCAL_REMOTE_ADDR of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV4_LOCAL_REMOTE_ADDR E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 7
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_LOCAL_INTF_ID corresponds to the value IPV6_LOCAL_INTF_ID of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_LOCAL_INTF_ID E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 8
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_LOCAL_REMOTE_ADDR corresponds to the value IPV6_LOCAL_REMOTE_ADDR of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type_IPV6_LOCAL_REMOTE_ADDR E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type = 9
)

// E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid. An additional value named
// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid int64

// IsYANGGoEnum ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid.
func (E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid.
func (e E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid")
}

const (
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_UNSET corresponds to the value UNSET of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_UNSET E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 0
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_IPV4_EXPLICIT_NULL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 1
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_ROUTER_ALERT E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 2
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_IPV6_EXPLICIT_NULL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 3
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_IMPLICIT_NULL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 4
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_ENTROPY_LABEL_INDICATOR E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 8
	// OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_NO_LABEL corresponds to the value NO_LABEL of OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid
	OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid_NO_LABEL E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid = 9
)

// E_OpenconfigBgp_CommunityType is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_CommunityType. An additional value named
// OpenconfigBgp_CommunityType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_CommunityType int64

// IsYANGGoEnum ensures that OpenconfigBgp_CommunityType implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_CommunityType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_CommunityType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_CommunityType.
func (E_OpenconfigBgp_CommunityType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigBgp_CommunityType.
func (e E_OpenconfigBgp_CommunityType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_CommunityType")
}

const (
	// OpenconfigBgp_CommunityType_UNSET corresponds to the value UNSET of OpenconfigBgp_CommunityType
	OpenconfigBgp_CommunityType_UNSET E_OpenconfigBgp_CommunityType = 0
	// OpenconfigBgp_CommunityType_STANDARD corresponds to the value STANDARD of OpenconfigBgp_CommunityType
	OpenconfigBgp_CommunityType_STANDARD E_OpenconfigBgp_CommunityType = 1
	// OpenconfigBgp_CommunityType_EXTENDED corresponds to the value EXTENDED of OpenconfigBgp_CommunityType
	OpenconfigBgp_CommunityType_EXTENDED E_OpenconfigBgp_CommunityType = 2
	// OpenconfigBgp_CommunityType_BOTH corresponds to the value BOTH of OpenconfigBgp_CommunityType
	OpenconfigBgp_CommunityType_BOTH E_OpenconfigBgp_CommunityType = 3
	// OpenconfigBgp_CommunityType_NONE corresponds to the value NONE of OpenconfigBgp_CommunityType
	OpenconfigBgp_CommunityType_NONE E_OpenconfigBgp_CommunityType = 4
)

// E_OpenconfigBgp_PeerType is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_PeerType. An additional value named
// OpenconfigBgp_PeerType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_PeerType int64

// IsYANGGoEnum ensures that OpenconfigBgp_PeerType implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_PeerType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_PeerType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_PeerType.
func (E_OpenconfigBgp_PeerType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigBgp_PeerType.
func (e E_OpenconfigBgp_PeerType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_PeerType")
}

const (
	// OpenconfigBgp_PeerType_UNSET corresponds to the value UNSET of OpenconfigBgp_PeerType
	OpenconfigBgp_PeerType_UNSET E_OpenconfigBgp_PeerType = 0
	// OpenconfigBgp_PeerType_INTERNAL corresponds to the value INTERNAL of OpenconfigBgp_PeerType
	OpenconfigBgp_PeerType_INTERNAL E_OpenconfigBgp_PeerType = 1
	// OpenconfigBgp_PeerType_EXTERNAL corresponds to the value EXTERNAL of OpenconfigBgp_PeerType
	OpenconfigBgp_PeerType_EXTERNAL E_OpenconfigBgp_PeerType = 2
)

// E_OpenconfigBgp_RemovePrivateAsOption is a derived int64 type which is used to represent
// the enumerated node OpenconfigBgp_RemovePrivateAsOption. An additional value named
// OpenconfigBgp_RemovePrivateAsOption_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigBgp_RemovePrivateAsOption int64

// IsYANGGoEnum ensures that OpenconfigBgp_RemovePrivateAsOption implements the yang.GoEnum
// interface. This ensures that OpenconfigBgp_RemovePrivateAsOption can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigBgp_RemovePrivateAsOption) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigBgp_RemovePrivateAsOption.
func (E_OpenconfigBgp_RemovePrivateAsOption) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigBgp_RemovePrivateAsOption.
func (e E_OpenconfigBgp_RemovePrivateAsOption) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigBgp_RemovePrivateAsOption")
}

const (
	// OpenconfigBgp_RemovePrivateAsOption_UNSET corresponds to the value UNSET of OpenconfigBgp_RemovePrivateAsOption
	OpenconfigBgp_RemovePrivateAsOption_UNSET E_OpenconfigBgp_RemovePrivateAsOption = 0
	// OpenconfigBgp_RemovePrivateAsOption_PRIVATE_AS_REMOVE_ALL corresponds to the value PRIVATE_AS_REMOVE_ALL of OpenconfigBgp_RemovePrivateAsOption
	OpenconfigBgp_RemovePrivateAsOption_PRIVATE_AS_REMOVE_ALL E_OpenconfigBgp_RemovePrivateAsOption = 1
	// OpenconfigBgp_RemovePrivateAsOption_PRIVATE_AS_REPLACE_ALL corresponds to the value PRIVATE_AS_REPLACE_ALL of OpenconfigBgp_RemovePrivateAsOption
	OpenconfigBgp_RemovePrivateAsOption_PRIVATE_AS_REPLACE_ALL E_OpenconfigBgp_RemovePrivateAsOption = 2
)

// E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE. An additional value named
// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE.
func (E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE.
func (e E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE")
}

const (
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_UNSET E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 0
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV4_ROUTER_ID corresponds to the value IP_REACHABILITY_IPV4_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV4_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 1
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV6_ROUTER_ID corresponds to the value IP_REACHABILITY_IPV6_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_IPV6_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 2
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_FLAGS corresponds to the value IP_REACHABILITY_PREFIX_FLAGS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_FLAGS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 3
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_SID corresponds to the value IP_REACHABILITY_PREFIX_SID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_PREFIX_SID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 4
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_SUBTLVS_TYPE corresponds to the value IP_REACHABILITY_SUBTLVS_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_SUBTLVS_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 5
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG corresponds to the value IP_REACHABILITY_TAG of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 6
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG64 corresponds to the value IP_REACHABILITY_TAG64 of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IP_REACHABILITY_TAG64 E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 7
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_LAN_SID corresponds to the value IS_REACHABILITY_ADJ_LAN_SID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_LAN_SID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 8
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_SID corresponds to the value IS_REACHABILITY_ADJ_SID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADJ_SID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 9
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADMIN_GROUP corresponds to the value IS_REACHABILITY_ADMIN_GROUP of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_ADMIN_GROUP E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 10
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_AVAILABLE_BANDWIDTH corresponds to the value IS_REACHABILITY_AVAILABLE_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_AVAILABLE_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 11
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_BANDWIDTH_CONSTRAINTS corresponds to the value IS_REACHABILITY_BANDWIDTH_CONSTRAINTS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_BANDWIDTH_CONSTRAINTS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 12
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_EXTENDED_ADMIN_GROUP corresponds to the value IS_REACHABILITY_EXTENDED_ADMIN_GROUP of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_EXTENDED_ADMIN_GROUP E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 13
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_INTERFACE_ADDRESS corresponds to the value IS_REACHABILITY_IPV4_INTERFACE_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_INTERFACE_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 14
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS corresponds to the value IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 15
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_INTERFACE_ADDRESS corresponds to the value IS_REACHABILITY_IPV6_INTERFACE_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_INTERFACE_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 16
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS corresponds to the value IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 17
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ATTRIBUTES corresponds to the value IS_REACHABILITY_LINK_ATTRIBUTES of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ATTRIBUTES E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 18
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY corresponds to the value IS_REACHABILITY_LINK_DELAY of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 19
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY_VARIATION corresponds to the value IS_REACHABILITY_LINK_DELAY_VARIATION of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_DELAY_VARIATION E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 20
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ID corresponds to the value IS_REACHABILITY_LINK_ID of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_ID E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 21
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_LOSS corresponds to the value IS_REACHABILITY_LINK_LOSS of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_LOSS E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 22
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_PROTECTION_TYPE corresponds to the value IS_REACHABILITY_LINK_PROTECTION_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_LINK_PROTECTION_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 23
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_LINK_BANDWIDTH corresponds to the value IS_REACHABILITY_MAX_LINK_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_LINK_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 24
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH corresponds to the value IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 25
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MIN_MAX_LINK_DELAY corresponds to the value IS_REACHABILITY_MIN_MAX_LINK_DELAY of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_MIN_MAX_LINK_DELAY E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 26
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_RESIDUAL_BANDWIDTH corresponds to the value IS_REACHABILITY_RESIDUAL_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_RESIDUAL_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 27
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_SUBTLVS_TYPE corresponds to the value IS_REACHABILITY_SUBTLVS_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_SUBTLVS_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 28
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_TE_DEFAULT_METRIC corresponds to the value IS_REACHABILITY_TE_DEFAULT_METRIC of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_TE_DEFAULT_METRIC E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 29
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNCONSTRAINED_LSP corresponds to the value IS_REACHABILITY_UNCONSTRAINED_LSP of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNCONSTRAINED_LSP E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 30
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNRESERVED_BANDWIDTH corresponds to the value IS_REACHABILITY_UNRESERVED_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UNRESERVED_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 31
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UTILIZED_BANDWIDTH corresponds to the value IS_REACHABILITY_UTILIZED_BANDWIDTH of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_IS_REACHABILITY_UTILIZED_BANDWIDTH E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 32
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_ALGORITHM corresponds to the value ROUTER_CAPABILITY_SR_ALGORITHM of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_ALGORITHM E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 33
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_CAPABILITY corresponds to the value ROUTER_CAPABILITY_SR_CAPABILITY of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SR_CAPABILITY E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 34
	// OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SUBTLVS_TYPE corresponds to the value ROUTER_CAPABILITY_SUBTLVS_TYPE of OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE_ROUTER_CAPABILITY_SUBTLVS_TYPE E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE = 35
)

// E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE. An additional value named
// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE.
func (E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE.
func (e E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE")
}

const (
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_UNSET E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 0
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AREA_ADDRESSES corresponds to the value AREA_ADDRESSES of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AREA_ADDRESSES E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 1
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AUTHENTICATION corresponds to the value AUTHENTICATION of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_AUTHENTICATION E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 2
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_DYNAMIC_NAME corresponds to the value DYNAMIC_NAME of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_DYNAMIC_NAME E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 3
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IPV4_REACHABILITY corresponds to the value EXTENDED_IPV4_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IPV4_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 4
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IS_REACHABILITY corresponds to the value EXTENDED_IS_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_EXTENDED_IS_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 5
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IIS_NEIGHBORS corresponds to the value IIS_NEIGHBORS of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IIS_NEIGHBORS E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 6
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_INSTANCE_ID corresponds to the value INSTANCE_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_INSTANCE_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 7
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_EXTERNAL_REACHABILITY corresponds to the value IPV4_EXTERNAL_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_EXTERNAL_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 8
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERFACE_ADDRESSES corresponds to the value IPV4_INTERFACE_ADDRESSES of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERFACE_ADDRESSES E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 9
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERNAL_REACHABILITY corresponds to the value IPV4_INTERNAL_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_INTERNAL_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 10
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_SRLG corresponds to the value IPV4_SRLG of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_SRLG E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 11
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_TE_ROUTER_ID corresponds to the value IPV4_TE_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV4_TE_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 12
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_INTERFACE_ADDRESSES corresponds to the value IPV6_INTERFACE_ADDRESSES of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_INTERFACE_ADDRESSES E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 13
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_REACHABILITY corresponds to the value IPV6_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 14
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_SRLG corresponds to the value IPV6_SRLG of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_SRLG E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 15
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_TE_ROUTER_ID corresponds to the value IPV6_TE_ROUTER_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IPV6_TE_ROUTER_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 16
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ISIS_ALIAS_ID corresponds to the value ISIS_ALIAS_ID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ISIS_ALIAS_ID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 17
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IS_NEIGHBOR_ATTRIBUTE corresponds to the value IS_NEIGHBOR_ATTRIBUTE of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_IS_NEIGHBOR_ATTRIBUTE E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 18
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_LSP_BUFFER_SIZE corresponds to the value LSP_BUFFER_SIZE of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_LSP_BUFFER_SIZE E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 19
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV4_REACHABILITY corresponds to the value MT_IPV4_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV4_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 20
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV6_REACHABILITY corresponds to the value MT_IPV6_REACHABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IPV6_REACHABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 21
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_ISN corresponds to the value MT_ISN of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_ISN E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 22
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IS_NEIGHBOR_ATTRIBUTE corresponds to the value MT_IS_NEIGHBOR_ATTRIBUTE of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MT_IS_NEIGHBOR_ATTRIBUTE E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 23
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MULTI_TOPOLOGY corresponds to the value MULTI_TOPOLOGY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_MULTI_TOPOLOGY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 24
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_NLPID corresponds to the value NLPID of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_NLPID E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 25
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_PURGE_OI corresponds to the value PURGE_OI of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_PURGE_OI E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 26
	// OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ROUTER_CAPABILITY corresponds to the value ROUTER_CAPABILITY of OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE
	OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE_ROUTER_CAPABILITY E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE = 27
)

// E_OpenconfigIsisTypes_AFI_SAFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_AFI_SAFI_TYPE. An additional value named
// OpenconfigIsisTypes_AFI_SAFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_AFI_SAFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_AFI_SAFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_AFI_SAFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_AFI_SAFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_AFI_SAFI_TYPE.
func (E_OpenconfigIsisTypes_AFI_SAFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_AFI_SAFI_TYPE.
func (e E_OpenconfigIsisTypes_AFI_SAFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_AFI_SAFI_TYPE")
}

const (
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_UNSET E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 0
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_MULTICAST corresponds to the value IPV4_MULTICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_MULTICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 1
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_UNICAST corresponds to the value IPV4_UNICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV4_UNICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 2
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_MULTICAST corresponds to the value IPV6_MULTICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_MULTICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 3
	// OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_UNICAST corresponds to the value IPV6_UNICAST of OpenconfigIsisTypes_AFI_SAFI_TYPE
	OpenconfigIsisTypes_AFI_SAFI_TYPE_IPV6_UNICAST E_OpenconfigIsisTypes_AFI_SAFI_TYPE = 4
)

// E_OpenconfigIsisTypes_AFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_AFI_TYPE. An additional value named
// OpenconfigIsisTypes_AFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_AFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_AFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_AFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_AFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_AFI_TYPE.
func (E_OpenconfigIsisTypes_AFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigIsisTypes_AFI_TYPE.
func (e E_OpenconfigIsisTypes_AFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_AFI_TYPE")
}

const (
	// OpenconfigIsisTypes_AFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_AFI_TYPE
	OpenconfigIsisTypes_AFI_TYPE_UNSET E_OpenconfigIsisTypes_AFI_TYPE = 0
	// OpenconfigIsisTypes_AFI_TYPE_IPV4 corresponds to the value IPV4 of OpenconfigIsisTypes_AFI_TYPE
	OpenconfigIsisTypes_AFI_TYPE_IPV4 E_OpenconfigIsisTypes_AFI_TYPE = 1
	// OpenconfigIsisTypes_AFI_TYPE_IPV6 corresponds to the value IPV6 of OpenconfigIsisTypes_AFI_TYPE
	OpenconfigIsisTypes_AFI_TYPE_IPV6 E_OpenconfigIsisTypes_AFI_TYPE = 2
)

// E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE. An additional value named
// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE.
func (E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE.
func (e E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE")
}

const (
	// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE
	OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_UNSET E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE = 0
	// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_BGP corresponds to the value WAIT_FOR_BGP of OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE
	OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_BGP E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE = 1
	// OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_SYSTEM corresponds to the value WAIT_FOR_SYSTEM of OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE
	OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE_WAIT_FOR_SYSTEM E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE = 2
)

// E_OpenconfigIsisTypes_SAFI_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsisTypes_SAFI_TYPE. An additional value named
// OpenconfigIsisTypes_SAFI_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsisTypes_SAFI_TYPE int64

// IsYANGGoEnum ensures that OpenconfigIsisTypes_SAFI_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigIsisTypes_SAFI_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsisTypes_SAFI_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsisTypes_SAFI_TYPE.
func (E_OpenconfigIsisTypes_SAFI_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsisTypes_SAFI_TYPE.
func (e E_OpenconfigIsisTypes_SAFI_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsisTypes_SAFI_TYPE")
}

const (
	// OpenconfigIsisTypes_SAFI_TYPE_UNSET corresponds to the value UNSET of OpenconfigIsisTypes_SAFI_TYPE
	OpenconfigIsisTypes_SAFI_TYPE_UNSET E_OpenconfigIsisTypes_SAFI_TYPE = 0
	// OpenconfigIsisTypes_SAFI_TYPE_MULTICAST corresponds to the value MULTICAST of OpenconfigIsisTypes_SAFI_TYPE
	OpenconfigIsisTypes_SAFI_TYPE_MULTICAST E_OpenconfigIsisTypes_SAFI_TYPE = 1
	// OpenconfigIsisTypes_SAFI_TYPE_UNICAST corresponds to the value UNICAST of OpenconfigIsisTypes_SAFI_TYPE
	OpenconfigIsisTypes_SAFI_TYPE_UNICAST E_OpenconfigIsisTypes_SAFI_TYPE = 2
)

// E_OpenconfigIsis_AdaptiveTimerType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_AdaptiveTimerType. An additional value named
// OpenconfigIsis_AdaptiveTimerType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_AdaptiveTimerType int64

// IsYANGGoEnum ensures that OpenconfigIsis_AdaptiveTimerType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_AdaptiveTimerType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_AdaptiveTimerType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_AdaptiveTimerType.
func (E_OpenconfigIsis_AdaptiveTimerType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsis_AdaptiveTimerType.
func (e E_OpenconfigIsis_AdaptiveTimerType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_AdaptiveTimerType")
}

const (
	// OpenconfigIsis_AdaptiveTimerType_UNSET corresponds to the value UNSET of OpenconfigIsis_AdaptiveTimerType
	OpenconfigIsis_AdaptiveTimerType_UNSET E_OpenconfigIsis_AdaptiveTimerType = 0
	// OpenconfigIsis_AdaptiveTimerType_LINEAR corresponds to the value LINEAR of OpenconfigIsis_AdaptiveTimerType
	OpenconfigIsis_AdaptiveTimerType_LINEAR E_OpenconfigIsis_AdaptiveTimerType = 1
	// OpenconfigIsis_AdaptiveTimerType_EXPONENTIAL corresponds to the value EXPONENTIAL of OpenconfigIsis_AdaptiveTimerType
	OpenconfigIsis_AdaptiveTimerType_EXPONENTIAL E_OpenconfigIsis_AdaptiveTimerType = 2
)

// E_OpenconfigIsis_CircuitType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_CircuitType. An additional value named
// OpenconfigIsis_CircuitType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_CircuitType int64

// IsYANGGoEnum ensures that OpenconfigIsis_CircuitType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_CircuitType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_CircuitType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_CircuitType.
func (E_OpenconfigIsis_CircuitType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigIsis_CircuitType.
func (e E_OpenconfigIsis_CircuitType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_CircuitType")
}

const (
	// OpenconfigIsis_CircuitType_UNSET corresponds to the value UNSET of OpenconfigIsis_CircuitType
	OpenconfigIsis_CircuitType_UNSET E_OpenconfigIsis_CircuitType = 0
	// OpenconfigIsis_CircuitType_POINT_TO_POINT corresponds to the value POINT_TO_POINT of OpenconfigIsis_CircuitType
	OpenconfigIsis_CircuitType_POINT_TO_POINT E_OpenconfigIsis_CircuitType = 1
	// OpenconfigIsis_CircuitType_BROADCAST corresponds to the value BROADCAST of OpenconfigIsis_CircuitType
	OpenconfigIsis_CircuitType_BROADCAST E_OpenconfigIsis_CircuitType = 2
)

// E_OpenconfigIsis_HelloPaddingType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_HelloPaddingType. An additional value named
// OpenconfigIsis_HelloPaddingType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_HelloPaddingType int64

// IsYANGGoEnum ensures that OpenconfigIsis_HelloPaddingType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_HelloPaddingType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_HelloPaddingType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_HelloPaddingType.
func (E_OpenconfigIsis_HelloPaddingType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsis_HelloPaddingType.
func (e E_OpenconfigIsis_HelloPaddingType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_HelloPaddingType")
}

const (
	// OpenconfigIsis_HelloPaddingType_UNSET corresponds to the value UNSET of OpenconfigIsis_HelloPaddingType
	OpenconfigIsis_HelloPaddingType_UNSET E_OpenconfigIsis_HelloPaddingType = 0
	// OpenconfigIsis_HelloPaddingType_STRICT corresponds to the value STRICT of OpenconfigIsis_HelloPaddingType
	OpenconfigIsis_HelloPaddingType_STRICT E_OpenconfigIsis_HelloPaddingType = 1
	// OpenconfigIsis_HelloPaddingType_LOOSE corresponds to the value LOOSE of OpenconfigIsis_HelloPaddingType
	OpenconfigIsis_HelloPaddingType_LOOSE E_OpenconfigIsis_HelloPaddingType = 2
	// OpenconfigIsis_HelloPaddingType_ADAPTIVE corresponds to the value ADAPTIVE of OpenconfigIsis_HelloPaddingType
	OpenconfigIsis_HelloPaddingType_ADAPTIVE E_OpenconfigIsis_HelloPaddingType = 3
	// OpenconfigIsis_HelloPaddingType_DISABLE corresponds to the value DISABLE of OpenconfigIsis_HelloPaddingType
	OpenconfigIsis_HelloPaddingType_DISABLE E_OpenconfigIsis_HelloPaddingType = 4
)

// E_OpenconfigIsis_IsisInterfaceAdjState is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_IsisInterfaceAdjState. An additional value named
// OpenconfigIsis_IsisInterfaceAdjState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_IsisInterfaceAdjState int64

// IsYANGGoEnum ensures that OpenconfigIsis_IsisInterfaceAdjState implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_IsisInterfaceAdjState can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_IsisInterfaceAdjState) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_IsisInterfaceAdjState.
func (E_OpenconfigIsis_IsisInterfaceAdjState) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsis_IsisInterfaceAdjState.
func (e E_OpenconfigIsis_IsisInterfaceAdjState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_IsisInterfaceAdjState")
}

const (
	// OpenconfigIsis_IsisInterfaceAdjState_UNSET corresponds to the value UNSET of OpenconfigIsis_IsisInterfaceAdjState
	OpenconfigIsis_IsisInterfaceAdjState_UNSET E_OpenconfigIsis_IsisInterfaceAdjState = 0
	// OpenconfigIsis_IsisInterfaceAdjState_UP corresponds to the value UP of OpenconfigIsis_IsisInterfaceAdjState
	OpenconfigIsis_IsisInterfaceAdjState_UP E_OpenconfigIsis_IsisInterfaceAdjState = 1
	// OpenconfigIsis_IsisInterfaceAdjState_DOWN corresponds to the value DOWN of OpenconfigIsis_IsisInterfaceAdjState
	OpenconfigIsis_IsisInterfaceAdjState_DOWN E_OpenconfigIsis_IsisInterfaceAdjState = 2
	// OpenconfigIsis_IsisInterfaceAdjState_INIT corresponds to the value INIT of OpenconfigIsis_IsisInterfaceAdjState
	OpenconfigIsis_IsisInterfaceAdjState_INIT E_OpenconfigIsis_IsisInterfaceAdjState = 3
	// OpenconfigIsis_IsisInterfaceAdjState_FAILED corresponds to the value FAILED of OpenconfigIsis_IsisInterfaceAdjState
	OpenconfigIsis_IsisInterfaceAdjState_FAILED E_OpenconfigIsis_IsisInterfaceAdjState = 4
)

// E_OpenconfigIsis_IsisMetricFlags is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_IsisMetricFlags. An additional value named
// OpenconfigIsis_IsisMetricFlags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_IsisMetricFlags int64

// IsYANGGoEnum ensures that OpenconfigIsis_IsisMetricFlags implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_IsisMetricFlags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_IsisMetricFlags) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_IsisMetricFlags.
func (E_OpenconfigIsis_IsisMetricFlags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigIsis_IsisMetricFlags.
func (e E_OpenconfigIsis_IsisMetricFlags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_IsisMetricFlags")
}

const (
	// OpenconfigIsis_IsisMetricFlags_UNSET corresponds to the value UNSET of OpenconfigIsis_IsisMetricFlags
	OpenconfigIsis_IsisMetricFlags_UNSET E_OpenconfigIsis_IsisMetricFlags = 0
	// OpenconfigIsis_IsisMetricFlags_INTERNAL corresponds to the value INTERNAL of OpenconfigIsis_IsisMetricFlags
	OpenconfigIsis_IsisMetricFlags_INTERNAL E_OpenconfigIsis_IsisMetricFlags = 1
	// OpenconfigIsis_IsisMetricFlags_UNSUPPORTED corresponds to the value UNSUPPORTED of OpenconfigIsis_IsisMetricFlags
	OpenconfigIsis_IsisMetricFlags_UNSUPPORTED E_OpenconfigIsis_IsisMetricFlags = 2
)

// E_OpenconfigIsis_LevelType is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_LevelType. An additional value named
// OpenconfigIsis_LevelType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_LevelType int64

// IsYANGGoEnum ensures that OpenconfigIsis_LevelType implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_LevelType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_LevelType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_LevelType.
func (E_OpenconfigIsis_LevelType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigIsis_LevelType.
func (e E_OpenconfigIsis_LevelType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_LevelType")
}

const (
	// OpenconfigIsis_LevelType_UNSET corresponds to the value UNSET of OpenconfigIsis_LevelType
	OpenconfigIsis_LevelType_UNSET E_OpenconfigIsis_LevelType = 0
	// OpenconfigIsis_LevelType_LEVEL_1 corresponds to the value LEVEL_1 of OpenconfigIsis_LevelType
	OpenconfigIsis_LevelType_LEVEL_1 E_OpenconfigIsis_LevelType = 1
	// OpenconfigIsis_LevelType_LEVEL_2 corresponds to the value LEVEL_2 of OpenconfigIsis_LevelType
	OpenconfigIsis_LevelType_LEVEL_2 E_OpenconfigIsis_LevelType = 2
	// OpenconfigIsis_LevelType_LEVEL_1_2 corresponds to the value LEVEL_1_2 of OpenconfigIsis_LevelType
	OpenconfigIsis_LevelType_LEVEL_1_2 E_OpenconfigIsis_LevelType = 3
)

// E_OpenconfigIsis_MetricStyle is a derived int64 type which is used to represent
// the enumerated node OpenconfigIsis_MetricStyle. An additional value named
// OpenconfigIsis_MetricStyle_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigIsis_MetricStyle int64

// IsYANGGoEnum ensures that OpenconfigIsis_MetricStyle implements the yang.GoEnum
// interface. This ensures that OpenconfigIsis_MetricStyle can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigIsis_MetricStyle) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigIsis_MetricStyle.
func (E_OpenconfigIsis_MetricStyle) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigIsis_MetricStyle.
func (e E_OpenconfigIsis_MetricStyle) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigIsis_MetricStyle")
}

const (
	// OpenconfigIsis_MetricStyle_UNSET corresponds to the value UNSET of OpenconfigIsis_MetricStyle
	OpenconfigIsis_MetricStyle_UNSET E_OpenconfigIsis_MetricStyle = 0
	// OpenconfigIsis_MetricStyle_NARROW_METRIC corresponds to the value NARROW_METRIC of OpenconfigIsis_MetricStyle
	OpenconfigIsis_MetricStyle_NARROW_METRIC E_OpenconfigIsis_MetricStyle = 1
	// OpenconfigIsis_MetricStyle_WIDE_METRIC corresponds to the value WIDE_METRIC of OpenconfigIsis_MetricStyle
	OpenconfigIsis_MetricStyle_WIDE_METRIC E_OpenconfigIsis_MetricStyle = 2
)

// E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP is a derived int64 type which is used to represent
// the enumerated node OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP. An additional value named
// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP int64

// IsYANGGoEnum ensures that OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP implements the yang.GoEnum
// interface. This ensures that OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP.
func (E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP.
func (e E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP")
}

const (
	// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_UNSET corresponds to the value UNSET of OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
	OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_UNSET E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP = 0
	// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_DROP corresponds to the value DROP of OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
	OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_DROP E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP = 1
	// OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_LOCAL_LINK corresponds to the value LOCAL_LINK of OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP
	OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP_LOCAL_LINK E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP = 2
)

// E_OpenconfigMessages_DEBUG_SERVICE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMessages_DEBUG_SERVICE. An additional value named
// OpenconfigMessages_DEBUG_SERVICE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMessages_DEBUG_SERVICE int64

// IsYANGGoEnum ensures that OpenconfigMessages_DEBUG_SERVICE implements the yang.GoEnum
// interface. This ensures that OpenconfigMessages_DEBUG_SERVICE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMessages_DEBUG_SERVICE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMessages_DEBUG_SERVICE.
func (E_OpenconfigMessages_DEBUG_SERVICE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMessages_DEBUG_SERVICE.
func (e E_OpenconfigMessages_DEBUG_SERVICE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMessages_DEBUG_SERVICE")
}

const (
	// OpenconfigMessages_DEBUG_SERVICE_UNSET corresponds to the value UNSET of OpenconfigMessages_DEBUG_SERVICE
	OpenconfigMessages_DEBUG_SERVICE_UNSET E_OpenconfigMessages_DEBUG_SERVICE = 0
)

// E_OpenconfigMessages_SyslogSeverity is a derived int64 type which is used to represent
// the enumerated node OpenconfigMessages_SyslogSeverity. An additional value named
// OpenconfigMessages_SyslogSeverity_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMessages_SyslogSeverity int64

// IsYANGGoEnum ensures that OpenconfigMessages_SyslogSeverity implements the yang.GoEnum
// interface. This ensures that OpenconfigMessages_SyslogSeverity can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMessages_SyslogSeverity) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMessages_SyslogSeverity.
func (E_OpenconfigMessages_SyslogSeverity) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMessages_SyslogSeverity.
func (e E_OpenconfigMessages_SyslogSeverity) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMessages_SyslogSeverity")
}

const (
	// OpenconfigMessages_SyslogSeverity_UNSET corresponds to the value UNSET of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_UNSET E_OpenconfigMessages_SyslogSeverity = 0
	// OpenconfigMessages_SyslogSeverity_EMERGENCY corresponds to the value EMERGENCY of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_EMERGENCY E_OpenconfigMessages_SyslogSeverity = 1
	// OpenconfigMessages_SyslogSeverity_ALERT corresponds to the value ALERT of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_ALERT E_OpenconfigMessages_SyslogSeverity = 2
	// OpenconfigMessages_SyslogSeverity_CRITICAL corresponds to the value CRITICAL of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_CRITICAL E_OpenconfigMessages_SyslogSeverity = 3
	// OpenconfigMessages_SyslogSeverity_ERROR corresponds to the value ERROR of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_ERROR E_OpenconfigMessages_SyslogSeverity = 4
	// OpenconfigMessages_SyslogSeverity_WARNING corresponds to the value WARNING of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_WARNING E_OpenconfigMessages_SyslogSeverity = 5
	// OpenconfigMessages_SyslogSeverity_NOTICE corresponds to the value NOTICE of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_NOTICE E_OpenconfigMessages_SyslogSeverity = 6
	// OpenconfigMessages_SyslogSeverity_INFORMATIONAL corresponds to the value INFORMATIONAL of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_INFORMATIONAL E_OpenconfigMessages_SyslogSeverity = 7
	// OpenconfigMessages_SyslogSeverity_DEBUG corresponds to the value DEBUG of OpenconfigMessages_SyslogSeverity
	OpenconfigMessages_SyslogSeverity_DEBUG E_OpenconfigMessages_SyslogSeverity = 8
)

// E_OpenconfigMplsLdp_MplsLdpAdjacencyType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsLdp_MplsLdpAdjacencyType. An additional value named
// OpenconfigMplsLdp_MplsLdpAdjacencyType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsLdp_MplsLdpAdjacencyType int64

// IsYANGGoEnum ensures that OpenconfigMplsLdp_MplsLdpAdjacencyType implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsLdp_MplsLdpAdjacencyType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsLdp_MplsLdpAdjacencyType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsLdp_MplsLdpAdjacencyType.
func (E_OpenconfigMplsLdp_MplsLdpAdjacencyType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsLdp_MplsLdpAdjacencyType.
func (e E_OpenconfigMplsLdp_MplsLdpAdjacencyType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsLdp_MplsLdpAdjacencyType")
}

const (
	// OpenconfigMplsLdp_MplsLdpAdjacencyType_UNSET corresponds to the value UNSET of OpenconfigMplsLdp_MplsLdpAdjacencyType
	OpenconfigMplsLdp_MplsLdpAdjacencyType_UNSET E_OpenconfigMplsLdp_MplsLdpAdjacencyType = 0
	// OpenconfigMplsLdp_MplsLdpAdjacencyType_LINK corresponds to the value LINK of OpenconfigMplsLdp_MplsLdpAdjacencyType
	OpenconfigMplsLdp_MplsLdpAdjacencyType_LINK E_OpenconfigMplsLdp_MplsLdpAdjacencyType = 1
	// OpenconfigMplsLdp_MplsLdpAdjacencyType_TARGETED corresponds to the value TARGETED of OpenconfigMplsLdp_MplsLdpAdjacencyType
	OpenconfigMplsLdp_MplsLdpAdjacencyType_TARGETED E_OpenconfigMplsLdp_MplsLdpAdjacencyType = 2
)

// E_OpenconfigMplsLdp_MplsLdpAfi is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsLdp_MplsLdpAfi. An additional value named
// OpenconfigMplsLdp_MplsLdpAfi_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsLdp_MplsLdpAfi int64

// IsYANGGoEnum ensures that OpenconfigMplsLdp_MplsLdpAfi implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsLdp_MplsLdpAfi can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsLdp_MplsLdpAfi) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsLdp_MplsLdpAfi.
func (E_OpenconfigMplsLdp_MplsLdpAfi) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigMplsLdp_MplsLdpAfi.
func (e E_OpenconfigMplsLdp_MplsLdpAfi) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsLdp_MplsLdpAfi")
}

const (
	// OpenconfigMplsLdp_MplsLdpAfi_UNSET corresponds to the value UNSET of OpenconfigMplsLdp_MplsLdpAfi
	OpenconfigMplsLdp_MplsLdpAfi_UNSET E_OpenconfigMplsLdp_MplsLdpAfi = 0
	// OpenconfigMplsLdp_MplsLdpAfi_IPV4 corresponds to the value IPV4 of OpenconfigMplsLdp_MplsLdpAfi
	OpenconfigMplsLdp_MplsLdpAfi_IPV4 E_OpenconfigMplsLdp_MplsLdpAfi = 1
	// OpenconfigMplsLdp_MplsLdpAfi_IPV6 corresponds to the value IPV6 of OpenconfigMplsLdp_MplsLdpAfi
	OpenconfigMplsLdp_MplsLdpAfi_IPV6 E_OpenconfigMplsLdp_MplsLdpAfi = 2
)

// E_OpenconfigMplsTypes_LSP_METRIC_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_LSP_METRIC_TYPE. An additional value named
// OpenconfigMplsTypes_LSP_METRIC_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_LSP_METRIC_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_LSP_METRIC_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_LSP_METRIC_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_LSP_METRIC_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_LSP_METRIC_TYPE.
func (E_OpenconfigMplsTypes_LSP_METRIC_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_LSP_METRIC_TYPE.
func (e E_OpenconfigMplsTypes_LSP_METRIC_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_LSP_METRIC_TYPE")
}

const (
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_UNSET E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 0
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_ABSOLUTE corresponds to the value LSP_METRIC_ABSOLUTE of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_ABSOLUTE E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 1
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_INHERITED corresponds to the value LSP_METRIC_INHERITED of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_INHERITED E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 2
	// OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_RELATIVE corresponds to the value LSP_METRIC_RELATIVE of OpenconfigMplsTypes_LSP_METRIC_TYPE
	OpenconfigMplsTypes_LSP_METRIC_TYPE_LSP_METRIC_RELATIVE E_OpenconfigMplsTypes_LSP_METRIC_TYPE = 3
)

// E_OpenconfigMplsTypes_LSP_OPER_STATUS is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_LSP_OPER_STATUS. An additional value named
// OpenconfigMplsTypes_LSP_OPER_STATUS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_LSP_OPER_STATUS int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_LSP_OPER_STATUS implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_LSP_OPER_STATUS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_LSP_OPER_STATUS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_LSP_OPER_STATUS.
func (E_OpenconfigMplsTypes_LSP_OPER_STATUS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_LSP_OPER_STATUS.
func (e E_OpenconfigMplsTypes_LSP_OPER_STATUS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_LSP_OPER_STATUS")
}

const (
	// OpenconfigMplsTypes_LSP_OPER_STATUS_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_LSP_OPER_STATUS
	OpenconfigMplsTypes_LSP_OPER_STATUS_UNSET E_OpenconfigMplsTypes_LSP_OPER_STATUS = 0
	// OpenconfigMplsTypes_LSP_OPER_STATUS_DOWN corresponds to the value DOWN of OpenconfigMplsTypes_LSP_OPER_STATUS
	OpenconfigMplsTypes_LSP_OPER_STATUS_DOWN E_OpenconfigMplsTypes_LSP_OPER_STATUS = 1
	// OpenconfigMplsTypes_LSP_OPER_STATUS_UP corresponds to the value UP of OpenconfigMplsTypes_LSP_OPER_STATUS
	OpenconfigMplsTypes_LSP_OPER_STATUS_UP E_OpenconfigMplsTypes_LSP_OPER_STATUS = 2
)

// E_OpenconfigMplsTypes_LSP_ROLE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_LSP_ROLE. An additional value named
// OpenconfigMplsTypes_LSP_ROLE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_LSP_ROLE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_LSP_ROLE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_LSP_ROLE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_LSP_ROLE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_LSP_ROLE.
func (E_OpenconfigMplsTypes_LSP_ROLE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigMplsTypes_LSP_ROLE.
func (e E_OpenconfigMplsTypes_LSP_ROLE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_LSP_ROLE")
}

const (
	// OpenconfigMplsTypes_LSP_ROLE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_UNSET E_OpenconfigMplsTypes_LSP_ROLE = 0
	// OpenconfigMplsTypes_LSP_ROLE_EGRESS corresponds to the value EGRESS of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_EGRESS E_OpenconfigMplsTypes_LSP_ROLE = 1
	// OpenconfigMplsTypes_LSP_ROLE_INGRESS corresponds to the value INGRESS of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_INGRESS E_OpenconfigMplsTypes_LSP_ROLE = 2
	// OpenconfigMplsTypes_LSP_ROLE_TRANSIT corresponds to the value TRANSIT of OpenconfigMplsTypes_LSP_ROLE
	OpenconfigMplsTypes_LSP_ROLE_TRANSIT E_OpenconfigMplsTypes_LSP_ROLE = 3
)

// E_OpenconfigMplsTypes_NULL_LABEL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_NULL_LABEL_TYPE. An additional value named
// OpenconfigMplsTypes_NULL_LABEL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_NULL_LABEL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_NULL_LABEL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_NULL_LABEL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_NULL_LABEL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_NULL_LABEL_TYPE.
func (E_OpenconfigMplsTypes_NULL_LABEL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_NULL_LABEL_TYPE.
func (e E_OpenconfigMplsTypes_NULL_LABEL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_NULL_LABEL_TYPE")
}

const (
	// OpenconfigMplsTypes_NULL_LABEL_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_NULL_LABEL_TYPE
	OpenconfigMplsTypes_NULL_LABEL_TYPE_UNSET E_OpenconfigMplsTypes_NULL_LABEL_TYPE = 0
	// OpenconfigMplsTypes_NULL_LABEL_TYPE_EXPLICIT corresponds to the value EXPLICIT of OpenconfigMplsTypes_NULL_LABEL_TYPE
	OpenconfigMplsTypes_NULL_LABEL_TYPE_EXPLICIT E_OpenconfigMplsTypes_NULL_LABEL_TYPE = 1
	// OpenconfigMplsTypes_NULL_LABEL_TYPE_IMPLICIT corresponds to the value IMPLICIT of OpenconfigMplsTypes_NULL_LABEL_TYPE
	OpenconfigMplsTypes_NULL_LABEL_TYPE_IMPLICIT E_OpenconfigMplsTypes_NULL_LABEL_TYPE = 2
)

// E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PATH_COMPUTATION_METHOD. An additional value named
// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PATH_COMPUTATION_METHOD implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PATH_COMPUTATION_METHOD can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PATH_COMPUTATION_METHOD.
func (E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD.
func (e E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD")
}

const (
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_UNSET E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 0
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXPLICITLY_DEFINED corresponds to the value EXPLICITLY_DEFINED of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXPLICITLY_DEFINED E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 1
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXTERNALLY_QUERIED corresponds to the value EXTERNALLY_QUERIED of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_EXTERNALLY_QUERIED E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 2
	// OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_LOCALLY_COMPUTED corresponds to the value LOCALLY_COMPUTED of OpenconfigMplsTypes_PATH_COMPUTATION_METHOD
	OpenconfigMplsTypes_PATH_COMPUTATION_METHOD_LOCALLY_COMPUTED E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD = 3
)

// E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PATH_SETUP_PROTOCOL. An additional value named
// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PATH_SETUP_PROTOCOL implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PATH_SETUP_PROTOCOL can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PATH_SETUP_PROTOCOL.
func (E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL.
func (e E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL")
}

const (
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_UNSET E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 0
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_LDP corresponds to the value PATH_SETUP_LDP of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_LDP E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 1
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_RSVP corresponds to the value PATH_SETUP_RSVP of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_RSVP E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 2
	// OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_SR corresponds to the value PATH_SETUP_SR of OpenconfigMplsTypes_PATH_SETUP_PROTOCOL
	OpenconfigMplsTypes_PATH_SETUP_PROTOCOL_PATH_SETUP_SR E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL = 3
)

// E_OpenconfigMplsTypes_PROTECTION_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PROTECTION_TYPE. An additional value named
// OpenconfigMplsTypes_PROTECTION_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PROTECTION_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PROTECTION_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PROTECTION_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PROTECTION_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PROTECTION_TYPE.
func (E_OpenconfigMplsTypes_PROTECTION_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PROTECTION_TYPE.
func (e E_OpenconfigMplsTypes_PROTECTION_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PROTECTION_TYPE")
}

const (
	// OpenconfigMplsTypes_PROTECTION_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_UNSET E_OpenconfigMplsTypes_PROTECTION_TYPE = 0
	// OpenconfigMplsTypes_PROTECTION_TYPE_LINK_NODE_PROTECTION_REQUESTED corresponds to the value LINK_NODE_PROTECTION_REQUESTED of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_LINK_NODE_PROTECTION_REQUESTED E_OpenconfigMplsTypes_PROTECTION_TYPE = 1
	// OpenconfigMplsTypes_PROTECTION_TYPE_LINK_PROTECTION_REQUIRED corresponds to the value LINK_PROTECTION_REQUIRED of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_LINK_PROTECTION_REQUIRED E_OpenconfigMplsTypes_PROTECTION_TYPE = 2
	// OpenconfigMplsTypes_PROTECTION_TYPE_UNPROTECTED corresponds to the value UNPROTECTED of OpenconfigMplsTypes_PROTECTION_TYPE
	OpenconfigMplsTypes_PROTECTION_TYPE_UNPROTECTED E_OpenconfigMplsTypes_PROTECTION_TYPE = 3
)

// E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION. An additional value named
// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION.
func (E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION.
func (e E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION")
}

const (
	// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION
	OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_UNSET E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION = 0
	// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_RAW_MODE corresponds to the value PWE_ETHERNET_RAW_MODE of OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION
	OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_RAW_MODE E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION = 1
	// OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_TAGGED_MODE corresponds to the value PWE_ETHERNET_TAGGED_MODE of OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION
	OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION_PWE_ETHERNET_TAGGED_MODE E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION = 2
)

// E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS. An additional value named
// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS.
func (E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS.
func (e E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS")
}

const (
	// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS
	OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_UNSET E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS = 0
	// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_DOWN corresponds to the value ADMIN_DOWN of OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS
	OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_DOWN E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS = 1
	// OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_UP corresponds to the value ADMIN_UP of OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS
	OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS_ADMIN_UP E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS = 2
)

// E_OpenconfigMplsTypes_TUNNEL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigMplsTypes_TUNNEL_TYPE. An additional value named
// OpenconfigMplsTypes_TUNNEL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMplsTypes_TUNNEL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigMplsTypes_TUNNEL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigMplsTypes_TUNNEL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMplsTypes_TUNNEL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMplsTypes_TUNNEL_TYPE.
func (E_OpenconfigMplsTypes_TUNNEL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMplsTypes_TUNNEL_TYPE.
func (e E_OpenconfigMplsTypes_TUNNEL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMplsTypes_TUNNEL_TYPE")
}

const (
	// OpenconfigMplsTypes_TUNNEL_TYPE_UNSET corresponds to the value UNSET of OpenconfigMplsTypes_TUNNEL_TYPE
	OpenconfigMplsTypes_TUNNEL_TYPE_UNSET E_OpenconfigMplsTypes_TUNNEL_TYPE = 0
	// OpenconfigMplsTypes_TUNNEL_TYPE_P2MP corresponds to the value P2MP of OpenconfigMplsTypes_TUNNEL_TYPE
	OpenconfigMplsTypes_TUNNEL_TYPE_P2MP E_OpenconfigMplsTypes_TUNNEL_TYPE = 1
	// OpenconfigMplsTypes_TUNNEL_TYPE_P2P corresponds to the value P2P of OpenconfigMplsTypes_TUNNEL_TYPE
	OpenconfigMplsTypes_TUNNEL_TYPE_P2P E_OpenconfigMplsTypes_TUNNEL_TYPE = 2
)

// E_OpenconfigMpls_CspfTieBreaking is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_CspfTieBreaking. An additional value named
// OpenconfigMpls_CspfTieBreaking_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_CspfTieBreaking int64

// IsYANGGoEnum ensures that OpenconfigMpls_CspfTieBreaking implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_CspfTieBreaking can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_CspfTieBreaking) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_CspfTieBreaking.
func (E_OpenconfigMpls_CspfTieBreaking) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMpls_CspfTieBreaking.
func (e E_OpenconfigMpls_CspfTieBreaking) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_CspfTieBreaking")
}

const (
	// OpenconfigMpls_CspfTieBreaking_UNSET corresponds to the value UNSET of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_UNSET E_OpenconfigMpls_CspfTieBreaking = 0
	// OpenconfigMpls_CspfTieBreaking_RANDOM corresponds to the value RANDOM of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_RANDOM E_OpenconfigMpls_CspfTieBreaking = 1
	// OpenconfigMpls_CspfTieBreaking_LEAST_FILL corresponds to the value LEAST_FILL of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_LEAST_FILL E_OpenconfigMpls_CspfTieBreaking = 2
	// OpenconfigMpls_CspfTieBreaking_MOST_FILL corresponds to the value MOST_FILL of OpenconfigMpls_CspfTieBreaking
	OpenconfigMpls_CspfTieBreaking_MOST_FILL E_OpenconfigMpls_CspfTieBreaking = 3
)

// E_OpenconfigMpls_MplsHopType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_MplsHopType. An additional value named
// OpenconfigMpls_MplsHopType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_MplsHopType int64

// IsYANGGoEnum ensures that OpenconfigMpls_MplsHopType implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_MplsHopType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_MplsHopType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_MplsHopType.
func (E_OpenconfigMpls_MplsHopType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigMpls_MplsHopType.
func (e E_OpenconfigMpls_MplsHopType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_MplsHopType")
}

const (
	// OpenconfigMpls_MplsHopType_UNSET corresponds to the value UNSET of OpenconfigMpls_MplsHopType
	OpenconfigMpls_MplsHopType_UNSET E_OpenconfigMpls_MplsHopType = 0
	// OpenconfigMpls_MplsHopType_LOOSE corresponds to the value LOOSE of OpenconfigMpls_MplsHopType
	OpenconfigMpls_MplsHopType_LOOSE E_OpenconfigMpls_MplsHopType = 1
	// OpenconfigMpls_MplsHopType_STRICT corresponds to the value STRICT of OpenconfigMpls_MplsHopType
	OpenconfigMpls_MplsHopType_STRICT E_OpenconfigMpls_MplsHopType = 2
)

// E_OpenconfigMpls_MplsSrlgFloodingType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_MplsSrlgFloodingType. An additional value named
// OpenconfigMpls_MplsSrlgFloodingType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_MplsSrlgFloodingType int64

// IsYANGGoEnum ensures that OpenconfigMpls_MplsSrlgFloodingType implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_MplsSrlgFloodingType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_MplsSrlgFloodingType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_MplsSrlgFloodingType.
func (E_OpenconfigMpls_MplsSrlgFloodingType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMpls_MplsSrlgFloodingType.
func (e E_OpenconfigMpls_MplsSrlgFloodingType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_MplsSrlgFloodingType")
}

const (
	// OpenconfigMpls_MplsSrlgFloodingType_UNSET corresponds to the value UNSET of OpenconfigMpls_MplsSrlgFloodingType
	OpenconfigMpls_MplsSrlgFloodingType_UNSET E_OpenconfigMpls_MplsSrlgFloodingType = 0
	// OpenconfigMpls_MplsSrlgFloodingType_FLOODED_SRLG corresponds to the value FLOODED_SRLG of OpenconfigMpls_MplsSrlgFloodingType
	OpenconfigMpls_MplsSrlgFloodingType_FLOODED_SRLG E_OpenconfigMpls_MplsSrlgFloodingType = 1
	// OpenconfigMpls_MplsSrlgFloodingType_STATIC_SRLG corresponds to the value STATIC_SRLG of OpenconfigMpls_MplsSrlgFloodingType
	OpenconfigMpls_MplsSrlgFloodingType_STATIC_SRLG E_OpenconfigMpls_MplsSrlgFloodingType = 2
)

// E_OpenconfigMpls_TeBandwidthType is a derived int64 type which is used to represent
// the enumerated node OpenconfigMpls_TeBandwidthType. An additional value named
// OpenconfigMpls_TeBandwidthType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigMpls_TeBandwidthType int64

// IsYANGGoEnum ensures that OpenconfigMpls_TeBandwidthType implements the yang.GoEnum
// interface. This ensures that OpenconfigMpls_TeBandwidthType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigMpls_TeBandwidthType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigMpls_TeBandwidthType.
func (E_OpenconfigMpls_TeBandwidthType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigMpls_TeBandwidthType.
func (e E_OpenconfigMpls_TeBandwidthType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigMpls_TeBandwidthType")
}

const (
	// OpenconfigMpls_TeBandwidthType_UNSET corresponds to the value UNSET of OpenconfigMpls_TeBandwidthType
	OpenconfigMpls_TeBandwidthType_UNSET E_OpenconfigMpls_TeBandwidthType = 0
	// OpenconfigMpls_TeBandwidthType_SPECIFIED corresponds to the value SPECIFIED of OpenconfigMpls_TeBandwidthType
	OpenconfigMpls_TeBandwidthType_SPECIFIED E_OpenconfigMpls_TeBandwidthType = 1
	// OpenconfigMpls_TeBandwidthType_AUTO corresponds to the value AUTO of OpenconfigMpls_TeBandwidthType
	OpenconfigMpls_TeBandwidthType_AUTO E_OpenconfigMpls_TeBandwidthType = 2
)

// E_OpenconfigNetworkInstanceTypes_ENCAPSULATION is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_ENCAPSULATION. An additional value named
// OpenconfigNetworkInstanceTypes_ENCAPSULATION_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_ENCAPSULATION int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_ENCAPSULATION implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_ENCAPSULATION can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_ENCAPSULATION) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_ENCAPSULATION.
func (E_OpenconfigNetworkInstanceTypes_ENCAPSULATION) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_ENCAPSULATION.
func (e E_OpenconfigNetworkInstanceTypes_ENCAPSULATION) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_ENCAPSULATION")
}

const (
	// OpenconfigNetworkInstanceTypes_ENCAPSULATION_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_ENCAPSULATION
	OpenconfigNetworkInstanceTypes_ENCAPSULATION_UNSET E_OpenconfigNetworkInstanceTypes_ENCAPSULATION = 0
	// OpenconfigNetworkInstanceTypes_ENCAPSULATION_MPLS corresponds to the value MPLS of OpenconfigNetworkInstanceTypes_ENCAPSULATION
	OpenconfigNetworkInstanceTypes_ENCAPSULATION_MPLS E_OpenconfigNetworkInstanceTypes_ENCAPSULATION = 1
	// OpenconfigNetworkInstanceTypes_ENCAPSULATION_VXLAN corresponds to the value VXLAN of OpenconfigNetworkInstanceTypes_ENCAPSULATION
	OpenconfigNetworkInstanceTypes_ENCAPSULATION_VXLAN E_OpenconfigNetworkInstanceTypes_ENCAPSULATION = 2
)

// E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE. An additional value named
// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE.
func (E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE.
func (e E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE")
}

const (
	// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE
	OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_UNSET E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE = 0
	// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_LOCAL corresponds to the value LOCAL of OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE
	OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_LOCAL E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE = 1
	// OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_REMOTE corresponds to the value REMOTE of OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE
	OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE_REMOTE E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE = 2
)

// E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE. An additional value named
// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE.
func (E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE.
func (e E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE")
}

const (
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_UNSET E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 0
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_INSTANCE_LABEL corresponds to the value INSTANCE_LABEL of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_INSTANCE_LABEL E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 1
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_NEXTHOP corresponds to the value PER_NEXTHOP of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_NEXTHOP E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 2
	// OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_PREFIX corresponds to the value PER_PREFIX of OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE
	OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE_PER_PREFIX E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE = 3
)

// E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE. An additional value named
// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE.
func (E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE.
func (e E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE")
}

const (
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_UNSET corresponds to the value UNSET of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_UNSET E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 0
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_DEFAULT_INSTANCE corresponds to the value DEFAULT_INSTANCE of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_DEFAULT_INSTANCE E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 1
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2L3 corresponds to the value L2L3 of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2L3 E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 2
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2P2P corresponds to the value L2P2P of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2P2P E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 3
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2VSI corresponds to the value L2VSI of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L2VSI E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 4
	// OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L3VRF corresponds to the value L3VRF of OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE
	OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE_L3VRF E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE = 5
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_STATIC corresponds to the value STATIC of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_STATIC E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_DYNAMIC corresponds to the value DYNAMIC of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType_DYNAMIC E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_ADJ_SID_ONLY corresponds to the value ADJ_SID_ONLY of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_ADJ_SID_ONLY E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_MIXED_MODE corresponds to the value MIXED_MODE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode_MIXED_MODE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_NON_EXISTENT corresponds to the value NON_EXISTENT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_NON_EXISTENT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_INITIALIZED corresponds to the value INITIALIZED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_INITIALIZED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_OPENREC corresponds to the value OPENREC of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_OPENREC E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_OPENSENT corresponds to the value OPENSENT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_OPENSENT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_OPERATIONAL corresponds to the value OPERATIONAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState_OPERATIONAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState = 5
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_ALL corresponds to the value ALL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority_ALL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_UP corresponds to the value UP of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_UP E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_DOWN corresponds to the value DOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus_DOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_IPV4 corresponds to the value IPV4 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_IPV4 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_IPV6 corresponds to the value IPV6 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_IPV6 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_ASN corresponds to the value ASN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_ASN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_ASN4 corresponds to the value ASN4 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_ASN4 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_LABEL corresponds to the value LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 5
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_UNNUMBERED_INTERFACE corresponds to the value UNNUMBERED_INTERFACE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type_UNNUMBERED_INTERFACE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type = 6
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_UP corresponds to the value UP of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_UP E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_DOWN corresponds to the value DOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status_DOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_MIRRORED_UP_DOWN corresponds to the value MIRRORED_UP_DOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_MIRRORED_UP_DOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_SEPARATE_UP_DOWN corresponds to the value SEPARATE_UP_DOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification_SEPARATE_UP_DOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_DELTA corresponds to the value DELTA of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_DELTA E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_THRESHOLD_CROSSED corresponds to the value THRESHOLD_CROSSED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType_THRESHOLD_CROSSED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_IPV4 corresponds to the value IPV4 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_IPV4 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_IPV6 corresponds to the value IPV6 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid_IPV6 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_NO_PHP corresponds to the value NO_PHP of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_NO_PHP E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_EXPLICIT_NULL corresponds to the value EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_PARTITION_REPAIR corresponds to the value PARTITION_REPAIR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_PARTITION_REPAIR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_ERROR corresponds to the value ATTACHED_ERROR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_ERROR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_EXPENSE corresponds to the value ATTACHED_EXPENSE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_EXPENSE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_DELAY corresponds to the value ATTACHED_DELAY of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_DELAY E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_DEFAULT corresponds to the value ATTACHED_DEFAULT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_ATTACHED_DEFAULT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 5
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_OVERLOAD corresponds to the value OVERLOAD of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags_OVERLOAD E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags = 6
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_LEVEL_1 corresponds to the value LEVEL_1 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_LEVEL_1 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_LEVEL_2 corresponds to the value LEVEL_2 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType_LEVEL_2 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_HMAC_MD5 corresponds to the value HMAC_MD5 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_HMAC_MD5 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_CLEARTEXT corresponds to the value CLEARTEXT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType_CLEARTEXT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_EXTERNAL_FLAG corresponds to the value EXTERNAL_FLAG of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_EXTERNAL_FLAG E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_READVERTISEMENT_FLAG corresponds to the value READVERTISEMENT_FLAG of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_READVERTISEMENT_FLAG E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_NODE_FLAG corresponds to the value NODE_FLAG of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags_NODE_FLAG E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags = 3
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_READVERTISEMENT corresponds to the value READVERTISEMENT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_READVERTISEMENT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_NODE corresponds to the value NODE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_NODE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_NO_PHP corresponds to the value NO_PHP of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_NO_PHP E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_EXPLICIT_NULL corresponds to the value EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_VALUE corresponds to the value VALUE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_VALUE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 5
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_LOCAL corresponds to the value LOCAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags_LOCAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags = 6
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_ADDRESS_FAMILY corresponds to the value ADDRESS_FAMILY of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_ADDRESS_FAMILY E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_BACKUP corresponds to the value BACKUP of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_BACKUP E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_VALUE corresponds to the value VALUE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_VALUE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_LOCAL corresponds to the value LOCAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_LOCAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_SET corresponds to the value SET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags_SET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags = 5
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_ADDRESS_FAMILY corresponds to the value ADDRESS_FAMILY of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_ADDRESS_FAMILY E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_BACKUP corresponds to the value BACKUP of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_BACKUP E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_VALUE corresponds to the value VALUE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_VALUE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_LOCAL corresponds to the value LOCAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_LOCAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_SET corresponds to the value SET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags_SET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags = 5
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_LOCAL_PROTECTION corresponds to the value LOCAL_PROTECTION of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_LOCAL_PROTECTION E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_LINK_EXCLUDED corresponds to the value LINK_EXCLUDED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection_LINK_EXCLUDED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_EXTRA_TRAFFIC corresponds to the value EXTRA_TRAFFIC of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_EXTRA_TRAFFIC E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_UNPROTECTED corresponds to the value UNPROTECTED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_UNPROTECTED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_SHARED corresponds to the value SHARED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_SHARED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_ONE_ONE corresponds to the value ONE_ONE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_ONE_ONE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_PLUS_ONE corresponds to the value PLUS_ONE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_PLUS_ONE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 5
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_ENHANCED corresponds to the value ENHANCED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type_ENHANCED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type = 6
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags_INTERNAL corresponds to the value INTERNAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags_INTERNAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags_NUMBERED corresponds to the value NUMBERED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags_NUMBERED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags_NA corresponds to the value NA of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags_NA E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_OVERLOAD corresponds to the value OVERLOAD of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_OVERLOAD E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_ATTACHED corresponds to the value ATTACHED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes_ATTACHED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_IPV4 corresponds to the value IPV4 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_IPV4 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_IPV6 corresponds to the value IPV6 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid_IPV6 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_FLOOD corresponds to the value FLOOD of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_FLOOD E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_DOWN corresponds to the value DOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags_DOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_SPF corresponds to the value SPF of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_SPF E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_STRICT_SPF corresponds to the value STRICT_SPF of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm_STRICT_SPF E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_IPV4_MPLS corresponds to the value IPV4_MPLS of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_IPV4_MPLS E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_IPV6_MPLS corresponds to the value IPV6_MPLS of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_IPV6_MPLS E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_IPV6_SR corresponds to the value IPV6_SR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags_IPV6_SR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags = 3
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_TYPE_1 corresponds to the value TYPE_1 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_TYPE_1 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_TYPE_2 corresponds to the value TYPE_2 of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType_TYPE_2 E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily_IPV4_UNICAST corresponds to the value IPV4_UNICAST of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily_IPV4_UNICAST E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_UNSPECIFIED corresponds to the value UNSPECIFIED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_UNSPECIFIED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_INTRA_AREA corresponds to the value INTRA_AREA of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_INTRA_AREA E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_INTER_AREA corresponds to the value INTER_AREA of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_INTER_AREA E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_AS_EXTERNAL corresponds to the value AS_EXTERNAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_AS_EXTERNAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType = 6
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_NSSA_EXTERNAL corresponds to the value NSSA_EXTERNAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType_NSSA_EXTERNAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType = 8
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_LOCAL corresponds to the value LOCAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_LOCAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_GLOBAL corresponds to the value GLOBAL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope_GLOBAL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_ABSOLUTE corresponds to the value ABSOLUTE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_ABSOLUTE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_INDEX corresponds to the value INDEX of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType_INDEX E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_UNKNOWN corresponds to the value UNKNOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_UNKNOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_SOFTWARE_RESTART corresponds to the value SOFTWARE_RESTART of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_SOFTWARE_RESTART E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_SOFTWARE_RELOAD_UPGRADE corresponds to the value SOFTWARE_RELOAD_UPGRADE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_SOFTWARE_RELOAD_UPGRADE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_CONTROL_PROCESSOR_SWITCH corresponds to the value CONTROL_PROCESSOR_SWITCH of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason_CONTROL_PROCESSOR_SWITCH E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason = 4
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_UNKNOWN corresponds to the value UNKNOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type_UNKNOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_UNKNOWN corresponds to the value UNKNOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type_UNKNOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_LINK corresponds to the value LINK of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_LINK E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_AREA corresponds to the value AREA of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_AREA E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_AS corresponds to the value AS of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope_AS E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope = 3
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_POINT_TO_POINT corresponds to the value POINT_TO_POINT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_POINT_TO_POINT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_MULTI_ACCESS corresponds to the value MULTI_ACCESS of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_MULTI_ACCESS E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_UNKNOWN corresponds to the value UNKNOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType_UNKNOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType = 3
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_UNKNOWN corresponds to the value UNKNOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type_UNKNOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_UNKNOWN corresponds to the value UNKNOWN of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type_UNKNOWN E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type = 1
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_RFC1583_COMPATIBLE corresponds to the value RFC1583_COMPATIBLE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_RFC1583_COMPATIBLE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_RFC2328_COMPATIBLE corresponds to the value RFC2328_COMPATIBLE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode_RFC2328_COMPATIBLE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_LINEAR_BACKOFF corresponds to the value LINEAR_BACKOFF of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_LINEAR_BACKOFF E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_EXPONENTIAL_BACKOFF corresponds to the value EXPONENTIAL_BACKOFF of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType_EXPONENTIAL_BACKOFF E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType = 2
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_IPV4_EXPLICIT_NULL corresponds to the value IPV4_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_IPV4_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_ROUTER_ALERT corresponds to the value ROUTER_ALERT of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_ROUTER_ALERT E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 2
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_IPV6_EXPLICIT_NULL corresponds to the value IPV6_EXPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_IPV6_EXPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 3
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_IMPLICIT_NULL corresponds to the value IMPLICIT_NULL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_IMPLICIT_NULL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 4
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_ENTROPY_LABEL_INDICATOR corresponds to the value ENTROPY_LABEL_INDICATOR of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_ENTROPY_LABEL_INDICATOR E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 8
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_NO_LABEL corresponds to the value NO_LABEL of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid_NO_LABEL E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid = 9
)

// E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status is a derived int64 type which is used to represent
// the enumerated node OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status. An additional value named
// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status int64

// IsYANGGoEnum ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status implements the yang.GoEnum
// interface. This ensures that OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status.
func (E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status.
func (e E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status")
}

const (
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_UNSET corresponds to the value UNSET of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_UNSET E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status = 0
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_ACTIVE corresponds to the value ACTIVE of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_ACTIVE E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status = 1
	// OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_SUSPENDED corresponds to the value SUSPENDED of OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status
	OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status_SUSPENDED E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status = 2
)

// E_OpenconfigOpenflow_FailureMode is a derived int64 type which is used to represent
// the enumerated node OpenconfigOpenflow_FailureMode. An additional value named
// OpenconfigOpenflow_FailureMode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOpenflow_FailureMode int64

// IsYANGGoEnum ensures that OpenconfigOpenflow_FailureMode implements the yang.GoEnum
// interface. This ensures that OpenconfigOpenflow_FailureMode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOpenflow_FailureMode) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOpenflow_FailureMode.
func (E_OpenconfigOpenflow_FailureMode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOpenflow_FailureMode.
func (e E_OpenconfigOpenflow_FailureMode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOpenflow_FailureMode")
}

const (
	// OpenconfigOpenflow_FailureMode_UNSET corresponds to the value UNSET of OpenconfigOpenflow_FailureMode
	OpenconfigOpenflow_FailureMode_UNSET E_OpenconfigOpenflow_FailureMode = 0
	// OpenconfigOpenflow_FailureMode_SECURE corresponds to the value SECURE of OpenconfigOpenflow_FailureMode
	OpenconfigOpenflow_FailureMode_SECURE E_OpenconfigOpenflow_FailureMode = 1
	// OpenconfigOpenflow_FailureMode_STANDALONE corresponds to the value STANDALONE of OpenconfigOpenflow_FailureMode
	OpenconfigOpenflow_FailureMode_STANDALONE E_OpenconfigOpenflow_FailureMode = 2
)

// E_OpenconfigOpenflow_Transport is a derived int64 type which is used to represent
// the enumerated node OpenconfigOpenflow_Transport. An additional value named
// OpenconfigOpenflow_Transport_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOpenflow_Transport int64

// IsYANGGoEnum ensures that OpenconfigOpenflow_Transport implements the yang.GoEnum
// interface. This ensures that OpenconfigOpenflow_Transport can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOpenflow_Transport) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOpenflow_Transport.
func (E_OpenconfigOpenflow_Transport) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigOpenflow_Transport.
func (e E_OpenconfigOpenflow_Transport) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOpenflow_Transport")
}

const (
	// OpenconfigOpenflow_Transport_UNSET corresponds to the value UNSET of OpenconfigOpenflow_Transport
	OpenconfigOpenflow_Transport_UNSET E_OpenconfigOpenflow_Transport = 0
	// OpenconfigOpenflow_Transport_TCP corresponds to the value TCP of OpenconfigOpenflow_Transport
	OpenconfigOpenflow_Transport_TCP E_OpenconfigOpenflow_Transport = 1
	// OpenconfigOpenflow_Transport_TLS corresponds to the value TLS of OpenconfigOpenflow_Transport
	OpenconfigOpenflow_Transport_TLS E_OpenconfigOpenflow_Transport = 2
)

// E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES. An additional value named
// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES.
func (E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES.
func (e E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES")
}

const (
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_UNSET E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 0
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_IP_INTERFACE_ADDRESS corresponds to the value GRACE_IP_INTERFACE_ADDRESS of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_IP_INTERFACE_ADDRESS E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 1
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_PERIOD corresponds to the value GRACE_PERIOD of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_PERIOD E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 2
	// OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_RESTART_REASON corresponds to the value GRACE_RESTART_REASON of OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES
	OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES_GRACE_RESTART_REASON E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES = 3
)

// E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_MAX_METRIC_INCLUDE. An additional value named
// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_MAX_METRIC_INCLUDE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_MAX_METRIC_INCLUDE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_MAX_METRIC_INCLUDE.
func (E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE.
func (e E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE")
}

const (
	// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_MAX_METRIC_INCLUDE
	OpenconfigOspfTypes_MAX_METRIC_INCLUDE_UNSET E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE = 0
	// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_STUB corresponds to the value MAX_METRIC_INCLUDE_STUB of OpenconfigOspfTypes_MAX_METRIC_INCLUDE
	OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_STUB E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE = 1
	// OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_TYPE2_EXTERNAL corresponds to the value MAX_METRIC_INCLUDE_TYPE2_EXTERNAL of OpenconfigOspfTypes_MAX_METRIC_INCLUDE
	OpenconfigOspfTypes_MAX_METRIC_INCLUDE_MAX_METRIC_INCLUDE_TYPE2_EXTERNAL E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE = 2
)

// E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_MAX_METRIC_TRIGGER. An additional value named
// OpenconfigOspfTypes_MAX_METRIC_TRIGGER_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_MAX_METRIC_TRIGGER implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_MAX_METRIC_TRIGGER can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_MAX_METRIC_TRIGGER.
func (E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER.
func (e E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER")
}

const (
	// OpenconfigOspfTypes_MAX_METRIC_TRIGGER_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_MAX_METRIC_TRIGGER
	OpenconfigOspfTypes_MAX_METRIC_TRIGGER_UNSET E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER = 0
	// OpenconfigOspfTypes_MAX_METRIC_TRIGGER_MAX_METRIC_ON_SYSTEM_BOOT corresponds to the value MAX_METRIC_ON_SYSTEM_BOOT of OpenconfigOspfTypes_MAX_METRIC_TRIGGER
	OpenconfigOspfTypes_MAX_METRIC_TRIGGER_MAX_METRIC_ON_SYSTEM_BOOT E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER = 1
)

// E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_ADJACENCY_SID corresponds to the value ADJACENCY_SID of OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE_ADJACENCY_SID E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE = 1
)

// E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_METRIC corresponds to the value ERO_METRIC of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_METRIC E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_PATH corresponds to the value ERO_PATH of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_ERO_PATH E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 2
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_SID_MPLS_LABEL_BINDING corresponds to the value SID_MPLS_LABEL_BINDING of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE_SID_MPLS_LABEL_BINDING E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE = 3
)

// E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_EXTENDED_PREFIX_RANGE corresponds to the value EXTENDED_PREFIX_RANGE of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_EXTENDED_PREFIX_RANGE E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_PREFIX_SID corresponds to the value PREFIX_SID of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_PREFIX_SID E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 2
	// OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_SID_LABEL_BINDING corresponds to the value SID_LABEL_BINDING of OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE_SID_LABEL_BINDING E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE = 3
)

// E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_IPV4_SEGMENT corresponds to the value IPV4_SEGMENT of OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_IPV4_SEGMENT E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNNUMBERED_INTERFACE_SEGMENT corresponds to the value UNNUMBERED_INTERFACE_SEGMENT of OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE
	OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE_UNNUMBERED_INTERFACE_SEGMENT E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE = 2
)

// E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE. An additional value named
// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE.
func (E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE.
func (e E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_UNSET E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 0
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_POINT_TO_POINT_LINK corresponds to the value POINT_TO_POINT_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_POINT_TO_POINT_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 1
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_STUB_NETWORK_LINK corresponds to the value STUB_NETWORK_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_STUB_NETWORK_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 2
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_TRANSIT_NETWORK_LINK corresponds to the value TRANSIT_NETWORK_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_TRANSIT_NETWORK_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 3
	// OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_VIRTUAL_LINK corresponds to the value VIRTUAL_LINK of OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE
	OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE_VIRTUAL_LINK E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE = 4
)

// E_OpenconfigOspfTypes_OSPF_LSA_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_LSA_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_LSA_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_LSA_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_LSA_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_LSA_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_LSA_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_LSA_TYPE.
func (E_OpenconfigOspfTypes_OSPF_LSA_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_LSA_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_LSA_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_LSA_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 0
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_AS_EXTERNAL_LSA corresponds to the value AS_EXTERNAL_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_AS_EXTERNAL_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 1
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_NETWORK_LSA corresponds to the value NETWORK_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_NETWORK_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 2
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_NSSA_AS_EXTERNAL_LSA corresponds to the value NSSA_AS_EXTERNAL_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_NSSA_AS_EXTERNAL_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 3
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AREA_SCOPE_OPAQUE_LSA corresponds to the value OSPFV2_AREA_SCOPE_OPAQUE_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AREA_SCOPE_OPAQUE_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 4
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AS_SCOPE_OPAQUE_LSA corresponds to the value OSPFV2_AS_SCOPE_OPAQUE_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_AS_SCOPE_OPAQUE_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 5
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_LINK_SCOPE_OPAQUE_LSA corresponds to the value OSPFV2_LINK_SCOPE_OPAQUE_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_OSPFV2_LINK_SCOPE_OPAQUE_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 6
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_ROUTER_LSA corresponds to the value ROUTER_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_ROUTER_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 7
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_ASBR_LSA corresponds to the value SUMMARY_ASBR_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_ASBR_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 8
	// OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_IP_NETWORK_LSA corresponds to the value SUMMARY_IP_NETWORK_LSA of OpenconfigOspfTypes_OSPF_LSA_TYPE
	OpenconfigOspfTypes_OSPF_LSA_TYPE_SUMMARY_IP_NETWORK_LSA E_OpenconfigOspfTypes_OSPF_LSA_TYPE = 9
)

// E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE. An additional value named
// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE.
func (E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE.
func (e E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE")
}

const (
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_UNSET E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 0
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_ATTEMPT corresponds to the value ATTEMPT of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_ATTEMPT E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 1
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_DOWN corresponds to the value DOWN of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_DOWN E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 2
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXCHANGE corresponds to the value EXCHANGE of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXCHANGE E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 3
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXSTART corresponds to the value EXSTART of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_EXSTART E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 4
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_FULL corresponds to the value FULL of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_FULL E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 5
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_INIT corresponds to the value INIT of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_INIT E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 6
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_LOADING corresponds to the value LOADING of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_LOADING E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 7
	// OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_TWO_WAY corresponds to the value TWO_WAY of OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE
	OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE_TWO_WAY E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE = 8
)

// E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_NETWORK_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_NETWORK_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_NETWORK_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_NETWORK_TYPE.
func (E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 0
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_BROADCAST_NETWORK corresponds to the value BROADCAST_NETWORK of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_BROADCAST_NETWORK E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 1
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_NON_BROADCAST_NETWORK corresponds to the value NON_BROADCAST_NETWORK of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_NON_BROADCAST_NETWORK E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 2
	// OpenconfigOspfTypes_OSPF_NETWORK_TYPE_POINT_TO_POINT_NETWORK corresponds to the value POINT_TO_POINT_NETWORK of OpenconfigOspfTypes_OSPF_NETWORK_TYPE
	OpenconfigOspfTypes_OSPF_NETWORK_TYPE_POINT_TO_POINT_NETWORK E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE = 3
)

// E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE.
func (E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 0
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_GRACE_LSA corresponds to the value GRACE_LSA of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_GRACE_LSA E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 1
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_LINK corresponds to the value OSPFV2_EXTENDED_LINK of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_LINK E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 2
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_PREFIX corresponds to the value OSPFV2_EXTENDED_PREFIX of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_OSPFV2_EXTENDED_PREFIX E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 3
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_ROUTER_INFORMATION corresponds to the value ROUTER_INFORMATION of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_ROUTER_INFORMATION E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 4
	// OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_TRAFFIC_ENGINEERING corresponds to the value TRAFFIC_ENGINEERING of OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE
	OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE_TRAFFIC_ENGINEERING E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE = 5
)

// E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES. An additional value named
// OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES.
func (E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES.
func (e E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES")
}

const (
	// OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
	OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_UNSET E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES = 0
	// OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_SR_SID_LABEL_TLV corresponds to the value SR_SID_LABEL_TLV of OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES
	OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES_SR_SID_LABEL_TLV E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES = 1
)

// E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE.
func (E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 0
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ADMIN_GROUP corresponds to the value TE_LINK_ADMIN_GROUP of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ADMIN_GROUP E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 1
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ID corresponds to the value TE_LINK_ID of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_ID E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 2
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_LOCAL_IP corresponds to the value TE_LINK_LOCAL_IP of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_LOCAL_IP E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 3
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_BANDWIDTH corresponds to the value TE_LINK_MAXIMUM_BANDWIDTH of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_BANDWIDTH E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 4
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH corresponds to the value TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 5
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_METRIC corresponds to the value TE_LINK_METRIC of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_METRIC E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 6
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_REMOTE_IP corresponds to the value TE_LINK_REMOTE_IP of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_REMOTE_IP E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 7
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_TYPE corresponds to the value TE_LINK_TYPE of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_TYPE E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 8
	// OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_UNRESERVED_BANDWIDTH corresponds to the value TE_LINK_UNRESERVED_BANDWIDTH of OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE_TE_LINK_UNRESERVED_BANDWIDTH E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE = 9
)

// E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE. An additional value named
// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE.
func (E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE.
func (e E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE")
}

const (
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_UNSET E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 0
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK corresponds to the value TE_LINK of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 1
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK_LOCAL corresponds to the value TE_LINK_LOCAL of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_LINK_LOCAL E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 2
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_NODE_ATTRIBUTE corresponds to the value TE_NODE_ATTRIBUTE of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_NODE_ATTRIBUTE E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 3
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_OPTICAL_NODE_PROPERTY corresponds to the value TE_OPTICAL_NODE_PROPERTY of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_OPTICAL_NODE_PROPERTY E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 4
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_ADDRESS corresponds to the value TE_ROUTER_ADDRESS of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_ADDRESS E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 5
	// OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_IPV6_ADDRESS corresponds to the value TE_ROUTER_IPV6_ADDRESS of OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE
	OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE_TE_ROUTER_IPV6_ADDRESS E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE = 6
)

// E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_RI_LSA_TLV_TYPES. An additional value named
// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_RI_LSA_TLV_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_RI_LSA_TLV_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_RI_LSA_TLV_TYPES.
func (E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES.
func (e E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES")
}

const (
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_UNSET E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 0
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_FUNCTIONAL_CAPABILITIES corresponds to the value RI_FUNCTIONAL_CAPABILITIES of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_FUNCTIONAL_CAPABILITIES E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 1
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_INFORMATIONAL_CAPABILITIES corresponds to the value RI_INFORMATIONAL_CAPABILITIES of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_INFORMATIONAL_CAPABILITIES E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 2
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_NODE_ADMIN_TAG corresponds to the value RI_NODE_ADMIN_TAG of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_NODE_ADMIN_TAG E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 3
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_ALGORITHM corresponds to the value RI_SR_ALGORITHM of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_ALGORITHM E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 4
	// OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_SID_LABEL_RANGE corresponds to the value RI_SR_SID_LABEL_RANGE of OpenconfigOspfTypes_RI_LSA_TLV_TYPES
	OpenconfigOspfTypes_RI_LSA_TLV_TYPES_RI_SR_SID_LABEL_RANGE E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES = 5
)

// E_OpenconfigOspfTypes_ROUTER_LSA_TYPES is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_ROUTER_LSA_TYPES. An additional value named
// OpenconfigOspfTypes_ROUTER_LSA_TYPES_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_ROUTER_LSA_TYPES int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_ROUTER_LSA_TYPES implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_ROUTER_LSA_TYPES can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_ROUTER_LSA_TYPES) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_ROUTER_LSA_TYPES.
func (E_OpenconfigOspfTypes_ROUTER_LSA_TYPES) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_ROUTER_LSA_TYPES.
func (e E_OpenconfigOspfTypes_ROUTER_LSA_TYPES) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_ROUTER_LSA_TYPES")
}

const (
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_UNSET E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 0
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_P2P corresponds to the value ROUTER_LSA_P2P of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_P2P E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 1
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_STUB_NETWORK corresponds to the value ROUTER_LSA_STUB_NETWORK of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_STUB_NETWORK E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 2
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_TRANSIT_NETWORK corresponds to the value ROUTER_LSA_TRANSIT_NETWORK of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_TRANSIT_NETWORK E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 3
	// OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_VIRTUAL_LINK corresponds to the value ROUTER_LSA_VIRTUAL_LINK of OpenconfigOspfTypes_ROUTER_LSA_TYPES
	OpenconfigOspfTypes_ROUTER_LSA_TYPES_ROUTER_LSA_VIRTUAL_LINK E_OpenconfigOspfTypes_ROUTER_LSA_TYPES = 4
)

// E_OpenconfigOspfTypes_SR_ALGORITHM is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_SR_ALGORITHM. An additional value named
// OpenconfigOspfTypes_SR_ALGORITHM_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_SR_ALGORITHM int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_SR_ALGORITHM implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_SR_ALGORITHM can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_SR_ALGORITHM) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_SR_ALGORITHM.
func (E_OpenconfigOspfTypes_SR_ALGORITHM) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_SR_ALGORITHM.
func (e E_OpenconfigOspfTypes_SR_ALGORITHM) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_SR_ALGORITHM")
}

const (
	// OpenconfigOspfTypes_SR_ALGORITHM_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_SR_ALGORITHM
	OpenconfigOspfTypes_SR_ALGORITHM_UNSET E_OpenconfigOspfTypes_SR_ALGORITHM = 0
	// OpenconfigOspfTypes_SR_ALGORITHM_SPF corresponds to the value SPF of OpenconfigOspfTypes_SR_ALGORITHM
	OpenconfigOspfTypes_SR_ALGORITHM_SPF E_OpenconfigOspfTypes_SR_ALGORITHM = 1
	// OpenconfigOspfTypes_SR_ALGORITHM_STRICT_SPF corresponds to the value STRICT_SPF of OpenconfigOspfTypes_SR_ALGORITHM
	OpenconfigOspfTypes_SR_ALGORITHM_STRICT_SPF E_OpenconfigOspfTypes_SR_ALGORITHM = 2
)

// E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE. An additional value named
// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE.
func (E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE.
func (e E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE")
}

const (
	// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
	OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_UNSET E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE = 0
	// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV4_LOCAL_ADDRESS corresponds to the value NODE_IPV4_LOCAL_ADDRESS of OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
	OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV4_LOCAL_ADDRESS E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE = 1
	// OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV6_LOCAL_ADDRESS corresponds to the value NODE_IPV6_LOCAL_ADDRESS of OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE
	OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE_NODE_IPV6_LOCAL_ADDRESS E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE = 2
)

// E_OpenconfigOspfv2_SrSidType is a derived int64 type which is used to represent
// the enumerated node OpenconfigOspfv2_SrSidType. An additional value named
// OpenconfigOspfv2_SrSidType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigOspfv2_SrSidType int64

// IsYANGGoEnum ensures that OpenconfigOspfv2_SrSidType implements the yang.GoEnum
// interface. This ensures that OpenconfigOspfv2_SrSidType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigOspfv2_SrSidType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigOspfv2_SrSidType.
func (E_OpenconfigOspfv2_SrSidType) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigOspfv2_SrSidType.
func (e E_OpenconfigOspfv2_SrSidType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigOspfv2_SrSidType")
}

const (
	// OpenconfigOspfv2_SrSidType_UNSET corresponds to the value UNSET of OpenconfigOspfv2_SrSidType
	OpenconfigOspfv2_SrSidType_UNSET E_OpenconfigOspfv2_SrSidType = 0
	// OpenconfigOspfv2_SrSidType_LABEL corresponds to the value LABEL of OpenconfigOspfv2_SrSidType
	OpenconfigOspfv2_SrSidType_LABEL E_OpenconfigOspfv2_SrSidType = 1
	// OpenconfigOspfv2_SrSidType_SID corresponds to the value SID of OpenconfigOspfv2_SrSidType
	OpenconfigOspfv2_SrSidType_SID E_OpenconfigOspfv2_SrSidType = 2
)

// E_OpenconfigPacketMatchTypes_ETHERTYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_ETHERTYPE. An additional value named
// OpenconfigPacketMatchTypes_ETHERTYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_ETHERTYPE int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_ETHERTYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_ETHERTYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_ETHERTYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_ETHERTYPE.
func (E_OpenconfigPacketMatchTypes_ETHERTYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_ETHERTYPE.
func (e E_OpenconfigPacketMatchTypes_ETHERTYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_ETHERTYPE")
}

const (
	// OpenconfigPacketMatchTypes_ETHERTYPE_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_UNSET E_OpenconfigPacketMatchTypes_ETHERTYPE = 0
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ARP corresponds to the value ETHERTYPE_ARP of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ARP E_OpenconfigPacketMatchTypes_ETHERTYPE = 1
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV4 corresponds to the value ETHERTYPE_IPV4 of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV4 E_OpenconfigPacketMatchTypes_ETHERTYPE = 2
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV6 corresponds to the value ETHERTYPE_IPV6 of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_IPV6 E_OpenconfigPacketMatchTypes_ETHERTYPE = 3
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_LLDP corresponds to the value ETHERTYPE_LLDP of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_LLDP E_OpenconfigPacketMatchTypes_ETHERTYPE = 4
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_MPLS corresponds to the value ETHERTYPE_MPLS of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_MPLS E_OpenconfigPacketMatchTypes_ETHERTYPE = 5
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ROCE corresponds to the value ETHERTYPE_ROCE of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_ROCE E_OpenconfigPacketMatchTypes_ETHERTYPE = 6
	// OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_VLAN corresponds to the value ETHERTYPE_VLAN of OpenconfigPacketMatchTypes_ETHERTYPE
	OpenconfigPacketMatchTypes_ETHERTYPE_ETHERTYPE_VLAN E_OpenconfigPacketMatchTypes_ETHERTYPE = 7
)

// E_OpenconfigPacketMatchTypes_IP_PROTOCOL is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_IP_PROTOCOL. An additional value named
// OpenconfigPacketMatchTypes_IP_PROTOCOL_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_IP_PROTOCOL int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_IP_PROTOCOL implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_IP_PROTOCOL can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_IP_PROTOCOL.
func (E_OpenconfigPacketMatchTypes_IP_PROTOCOL) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_IP_PROTOCOL.
func (e E_OpenconfigPacketMatchTypes_IP_PROTOCOL) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_IP_PROTOCOL")
}

const (
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_UNSET E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 0
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_AUTH corresponds to the value IP_AUTH of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_AUTH E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 1
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_GRE corresponds to the value IP_GRE of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_GRE E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 2
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_ICMP corresponds to the value IP_ICMP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_ICMP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 3
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_IGMP corresponds to the value IP_IGMP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_IGMP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 4
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_L2TP corresponds to the value IP_L2TP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_L2TP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 5
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_PIM corresponds to the value IP_PIM of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_PIM E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 6
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_RSVP corresponds to the value IP_RSVP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_RSVP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 7
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_TCP corresponds to the value IP_TCP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_TCP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 8
	// OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_UDP corresponds to the value IP_UDP of OpenconfigPacketMatchTypes_IP_PROTOCOL
	OpenconfigPacketMatchTypes_IP_PROTOCOL_IP_UDP E_OpenconfigPacketMatchTypes_IP_PROTOCOL = 9
)

// E_OpenconfigPacketMatchTypes_TCP_FLAGS is a derived int64 type which is used to represent
// the enumerated node OpenconfigPacketMatchTypes_TCP_FLAGS. An additional value named
// OpenconfigPacketMatchTypes_TCP_FLAGS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPacketMatchTypes_TCP_FLAGS int64

// IsYANGGoEnum ensures that OpenconfigPacketMatchTypes_TCP_FLAGS implements the yang.GoEnum
// interface. This ensures that OpenconfigPacketMatchTypes_TCP_FLAGS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPacketMatchTypes_TCP_FLAGS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPacketMatchTypes_TCP_FLAGS.
func (E_OpenconfigPacketMatchTypes_TCP_FLAGS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPacketMatchTypes_TCP_FLAGS.
func (e E_OpenconfigPacketMatchTypes_TCP_FLAGS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPacketMatchTypes_TCP_FLAGS")
}

const (
	// OpenconfigPacketMatchTypes_TCP_FLAGS_UNSET corresponds to the value UNSET of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_UNSET E_OpenconfigPacketMatchTypes_TCP_FLAGS = 0
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ACK corresponds to the value TCP_ACK of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ACK E_OpenconfigPacketMatchTypes_TCP_FLAGS = 1
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_CWR corresponds to the value TCP_CWR of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_CWR E_OpenconfigPacketMatchTypes_TCP_FLAGS = 2
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ECE corresponds to the value TCP_ECE of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_ECE E_OpenconfigPacketMatchTypes_TCP_FLAGS = 3
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_FIN corresponds to the value TCP_FIN of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_FIN E_OpenconfigPacketMatchTypes_TCP_FLAGS = 4
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_PSH corresponds to the value TCP_PSH of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_PSH E_OpenconfigPacketMatchTypes_TCP_FLAGS = 5
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_RST corresponds to the value TCP_RST of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_RST E_OpenconfigPacketMatchTypes_TCP_FLAGS = 6
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_SYN corresponds to the value TCP_SYN of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_SYN E_OpenconfigPacketMatchTypes_TCP_FLAGS = 7
	// OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_URG corresponds to the value TCP_URG of OpenconfigPacketMatchTypes_TCP_FLAGS
	OpenconfigPacketMatchTypes_TCP_FLAGS_TCP_URG E_OpenconfigPacketMatchTypes_TCP_FLAGS = 8
)

// E_OpenconfigPimTypes_PIM_MODE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPimTypes_PIM_MODE. An additional value named
// OpenconfigPimTypes_PIM_MODE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPimTypes_PIM_MODE int64

// IsYANGGoEnum ensures that OpenconfigPimTypes_PIM_MODE implements the yang.GoEnum
// interface. This ensures that OpenconfigPimTypes_PIM_MODE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPimTypes_PIM_MODE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPimTypes_PIM_MODE.
func (E_OpenconfigPimTypes_PIM_MODE) ΛMap() map[string]map[int64]ygot.EnumDefinition { return ΛEnum }

// String returns a logging-friendly string for E_OpenconfigPimTypes_PIM_MODE.
func (e E_OpenconfigPimTypes_PIM_MODE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPimTypes_PIM_MODE")
}

const (
	// OpenconfigPimTypes_PIM_MODE_UNSET corresponds to the value UNSET of OpenconfigPimTypes_PIM_MODE
	OpenconfigPimTypes_PIM_MODE_UNSET E_OpenconfigPimTypes_PIM_MODE = 0
	// OpenconfigPimTypes_PIM_MODE_PIM_MODE_DENSE corresponds to the value PIM_MODE_DENSE of OpenconfigPimTypes_PIM_MODE
	OpenconfigPimTypes_PIM_MODE_PIM_MODE_DENSE E_OpenconfigPimTypes_PIM_MODE = 1
	// OpenconfigPimTypes_PIM_MODE_PIM_MODE_SPARSE corresponds to the value PIM_MODE_SPARSE of OpenconfigPimTypes_PIM_MODE
	OpenconfigPimTypes_PIM_MODE_PIM_MODE_SPARSE E_OpenconfigPimTypes_PIM_MODE = 2
)

// E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_COMPONENT_OPER_STATUS. An additional value named
// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_COMPONENT_OPER_STATUS implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_COMPONENT_OPER_STATUS can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_COMPONENT_OPER_STATUS.
func (E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS.
func (e E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS")
}

const (
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_UNSET E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 0
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_ACTIVE corresponds to the value ACTIVE of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_ACTIVE E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 1
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_DISABLED corresponds to the value DISABLED of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_DISABLED E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 2
	// OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_INACTIVE corresponds to the value INACTIVE of OpenconfigPlatformTypes_COMPONENT_OPER_STATUS
	OpenconfigPlatformTypes_COMPONENT_OPER_STATUS_INACTIVE E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS = 3
)

// E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT. An additional value named
// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT.
func (E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT.
func (e E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT")
}

const (
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_UNSET E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 0
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_BACKPLANE corresponds to the value BACKPLANE of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_BACKPLANE E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 1
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CHASSIS corresponds to the value CHASSIS of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CHASSIS E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 2
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CONTROLLER_CARD corresponds to the value CONTROLLER_CARD of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CONTROLLER_CARD E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 3
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CPU corresponds to the value CPU of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_CPU E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 4
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FABRIC corresponds to the value FABRIC of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FABRIC E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 5
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FAN corresponds to the value FAN of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FAN E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 6
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FRU corresponds to the value FRU of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_FRU E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 7
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_INTEGRATED_CIRCUIT corresponds to the value INTEGRATED_CIRCUIT of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_INTEGRATED_CIRCUIT E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 8
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_LINECARD corresponds to the value LINECARD of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_LINECARD E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 9
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_PORT corresponds to the value PORT of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_PORT E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 10
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_POWER_SUPPLY corresponds to the value POWER_SUPPLY of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_POWER_SUPPLY E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 11
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_SENSOR corresponds to the value SENSOR of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_SENSOR E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 12
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_STORAGE corresponds to the value STORAGE of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_STORAGE E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 13
	// OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_TRANSCEIVER corresponds to the value TRANSCEIVER of OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT_TRANSCEIVER E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT = 14
)

// E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT is a derived int64 type which is used to represent
// the enumerated node OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT. An additional value named
// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT int64

// IsYANGGoEnum ensures that OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT implements the yang.GoEnum
// interface. This ensures that OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT.
func (E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT.
func (e E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT")
}

const (
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_UNSET corresponds to the value UNSET of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_UNSET E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 0
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_BOOT_LOADER corresponds to the value BOOT_LOADER of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_BOOT_LOADER E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 1
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM corresponds to the value OPERATING_SYSTEM of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 2
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM_UPDATE corresponds to the value OPERATING_SYSTEM_UPDATE of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_OPERATING_SYSTEM_UPDATE E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 3
	// OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_SOFTWARE_MODULE corresponds to the value SOFTWARE_MODULE of OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT
	OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT_SOFTWARE_MODULE E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT = 4
)

// E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE. An additional value named
// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE int64

// IsYANGGoEnum ensures that OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE.
func (E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE.
func (e E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE")
}

const (
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_UNSET corresponds to the value UNSET of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_UNSET E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 0
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_BGP corresponds to the value BGP of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_BGP E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 1
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_DIRECTLY_CONNECTED corresponds to the value DIRECTLY_CONNECTED of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_DIRECTLY_CONNECTED E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 2
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_IGMP corresponds to the value IGMP of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_IGMP E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 3
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_ISIS corresponds to the value ISIS of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_ISIS E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 4
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_LOCAL_AGGREGATE corresponds to the value LOCAL_AGGREGATE of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_LOCAL_AGGREGATE E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 5
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF corresponds to the value OSPF of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 6
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF3 corresponds to the value OSPF3 of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_OSPF3 E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 7
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_PIM corresponds to the value PIM of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_PIM E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 8
	// OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_STATIC corresponds to the value STATIC of OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE
	OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE_STATIC E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE = 9
)

// E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgpTypes_INVALID_ROUTE_REASON. An additional value named
// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON int64

// IsYANGGoEnum ensures that OpenconfigRibBgpTypes_INVALID_ROUTE_REASON implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgpTypes_INVALID_ROUTE_REASON can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgpTypes_INVALID_ROUTE_REASON.
func (E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON.
func (e E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON")
}

const (
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_UNSET corresponds to the value UNSET of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_UNSET E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 0
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_AS_LOOP corresponds to the value INVALID_AS_LOOP of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_AS_LOOP E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 1
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CLUSTER_LOOP corresponds to the value INVALID_CLUSTER_LOOP of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CLUSTER_LOOP E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 2
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CONFED corresponds to the value INVALID_CONFED of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_CONFED E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 3
	// OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_ORIGINATOR corresponds to the value INVALID_ORIGINATOR of OpenconfigRibBgpTypes_INVALID_ROUTE_REASON
	OpenconfigRibBgpTypes_INVALID_ROUTE_REASON_INVALID_ORIGINATOR E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON = 4
)

// E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE. An additional value named
// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE int64

// IsYANGGoEnum ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE.
func (e E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE")
}

const (
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_UNSET corresponds to the value UNSET of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_UNSET E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 0
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_BINDING_SID corresponds to the value SRTE_BINDING_SID of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_BINDING_SID E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 1
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_PREFERENCE corresponds to the value SRTE_PREFERENCE of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_PREFERENCE E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 2
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_SEGMENT_LIST corresponds to the value SRTE_SEGMENT_LIST of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_SRTE_SEGMENT_LIST E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 3
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_COLOR corresponds to the value TUNNEL_COLOR of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_COLOR E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 4
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_REMOTE_ENDPOINT corresponds to the value TUNNEL_REMOTE_ENDPOINT of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE_TUNNEL_REMOTE_ENDPOINT E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE = 5
)

// E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE. An additional value named
// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE int64

// IsYANGGoEnum ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE.
func (E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE.
func (e E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE")
}

const (
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_UNSET corresponds to the value UNSET of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_UNSET E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE = 0
	// OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_SRTE_POLICY_TUNNEL corresponds to the value SRTE_POLICY_TUNNEL of OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE
	OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE_SRTE_POLICY_TUNNEL E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE = 1
)

// E_OpenconfigRibBgp_AsPathSegmentType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgp_AsPathSegmentType. An additional value named
// OpenconfigRibBgp_AsPathSegmentType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgp_AsPathSegmentType int64

// IsYANGGoEnum ensures that OpenconfigRibBgp_AsPathSegmentType implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgp_AsPathSegmentType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgp_AsPathSegmentType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgp_AsPathSegmentType.
func (E_OpenconfigRibBgp_AsPathSegmentType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgp_AsPathSegmentType.
func (e E_OpenconfigRibBgp_AsPathSegmentType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgp_AsPathSegmentType")
}

const (
	// OpenconfigRibBgp_AsPathSegmentType_UNSET corresponds to the value UNSET of OpenconfigRibBgp_AsPathSegmentType
	OpenconfigRibBgp_AsPathSegmentType_UNSET E_OpenconfigRibBgp_AsPathSegmentType = 0
	// OpenconfigRibBgp_AsPathSegmentType_AS_SEQ corresponds to the value AS_SEQ of OpenconfigRibBgp_AsPathSegmentType
	OpenconfigRibBgp_AsPathSegmentType_AS_SEQ E_OpenconfigRibBgp_AsPathSegmentType = 1
	// OpenconfigRibBgp_AsPathSegmentType_AS_SET corresponds to the value AS_SET of OpenconfigRibBgp_AsPathSegmentType
	OpenconfigRibBgp_AsPathSegmentType_AS_SET E_OpenconfigRibBgp_AsPathSegmentType = 2
	// OpenconfigRibBgp_AsPathSegmentType_AS_CONFED_SEQUENCE corresponds to the value AS_CONFED_SEQUENCE of OpenconfigRibBgp_AsPathSegmentType
	OpenconfigRibBgp_AsPathSegmentType_AS_CONFED_SEQUENCE E_OpenconfigRibBgp_AsPathSegmentType = 3
	// OpenconfigRibBgp_AsPathSegmentType_AS_CONFED_SET corresponds to the value AS_CONFED_SET of OpenconfigRibBgp_AsPathSegmentType
	OpenconfigRibBgp_AsPathSegmentType_AS_CONFED_SET E_OpenconfigRibBgp_AsPathSegmentType = 4
)

// E_OpenconfigRibBgp_BgpOriginAttrType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRibBgp_BgpOriginAttrType. An additional value named
// OpenconfigRibBgp_BgpOriginAttrType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRibBgp_BgpOriginAttrType int64

// IsYANGGoEnum ensures that OpenconfigRibBgp_BgpOriginAttrType implements the yang.GoEnum
// interface. This ensures that OpenconfigRibBgp_BgpOriginAttrType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRibBgp_BgpOriginAttrType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRibBgp_BgpOriginAttrType.
func (E_OpenconfigRibBgp_BgpOriginAttrType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRibBgp_BgpOriginAttrType.
func (e E_OpenconfigRibBgp_BgpOriginAttrType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRibBgp_BgpOriginAttrType")
}

const (
	// OpenconfigRibBgp_BgpOriginAttrType_UNSET corresponds to the value UNSET of OpenconfigRibBgp_BgpOriginAttrType
	OpenconfigRibBgp_BgpOriginAttrType_UNSET E_OpenconfigRibBgp_BgpOriginAttrType = 0
	// OpenconfigRibBgp_BgpOriginAttrType_IGP corresponds to the value IGP of OpenconfigRibBgp_BgpOriginAttrType
	OpenconfigRibBgp_BgpOriginAttrType_IGP E_OpenconfigRibBgp_BgpOriginAttrType = 1
	// OpenconfigRibBgp_BgpOriginAttrType_EGP corresponds to the value EGP of OpenconfigRibBgp_BgpOriginAttrType
	OpenconfigRibBgp_BgpOriginAttrType_EGP E_OpenconfigRibBgp_BgpOriginAttrType = 2
	// OpenconfigRibBgp_BgpOriginAttrType_INCOMPLETE corresponds to the value INCOMPLETE of OpenconfigRibBgp_BgpOriginAttrType
	OpenconfigRibBgp_BgpOriginAttrType_INCOMPLETE E_OpenconfigRibBgp_BgpOriginAttrType = 3
)

// E_OpenconfigRoutingPolicy_DefaultPolicyType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_DefaultPolicyType. An additional value named
// OpenconfigRoutingPolicy_DefaultPolicyType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_DefaultPolicyType int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_DefaultPolicyType implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_DefaultPolicyType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_DefaultPolicyType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_DefaultPolicyType.
func (E_OpenconfigRoutingPolicy_DefaultPolicyType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_DefaultPolicyType.
func (e E_OpenconfigRoutingPolicy_DefaultPolicyType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_DefaultPolicyType")
}

const (
	// OpenconfigRoutingPolicy_DefaultPolicyType_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_DefaultPolicyType
	OpenconfigRoutingPolicy_DefaultPolicyType_UNSET E_OpenconfigRoutingPolicy_DefaultPolicyType = 0
	// OpenconfigRoutingPolicy_DefaultPolicyType_ACCEPT_ROUTE corresponds to the value ACCEPT_ROUTE of OpenconfigRoutingPolicy_DefaultPolicyType
	OpenconfigRoutingPolicy_DefaultPolicyType_ACCEPT_ROUTE E_OpenconfigRoutingPolicy_DefaultPolicyType = 1
	// OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE corresponds to the value REJECT_ROUTE of OpenconfigRoutingPolicy_DefaultPolicyType
	OpenconfigRoutingPolicy_DefaultPolicyType_REJECT_ROUTE E_OpenconfigRoutingPolicy_DefaultPolicyType = 2
)

// E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType. An additional value named
// OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType.
func (E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType.
func (e E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType")
}

const (
	// OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType
	OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_UNSET E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType = 0
	// OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_ANY corresponds to the value ANY of OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType
	OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_ANY E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType = 1
	// OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_INVERT corresponds to the value INVERT of OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType
	OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType_INVERT E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType = 2
)

// E_OpenconfigRoutingPolicy_PolicyResultType is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_PolicyResultType. An additional value named
// OpenconfigRoutingPolicy_PolicyResultType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_PolicyResultType int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_PolicyResultType implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_PolicyResultType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_PolicyResultType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_PolicyResultType.
func (E_OpenconfigRoutingPolicy_PolicyResultType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_PolicyResultType.
func (e E_OpenconfigRoutingPolicy_PolicyResultType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_PolicyResultType")
}

const (
	// OpenconfigRoutingPolicy_PolicyResultType_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_PolicyResultType
	OpenconfigRoutingPolicy_PolicyResultType_UNSET E_OpenconfigRoutingPolicy_PolicyResultType = 0
	// OpenconfigRoutingPolicy_PolicyResultType_ACCEPT_ROUTE corresponds to the value ACCEPT_ROUTE of OpenconfigRoutingPolicy_PolicyResultType
	OpenconfigRoutingPolicy_PolicyResultType_ACCEPT_ROUTE E_OpenconfigRoutingPolicy_PolicyResultType = 1
	// OpenconfigRoutingPolicy_PolicyResultType_REJECT_ROUTE corresponds to the value REJECT_ROUTE of OpenconfigRoutingPolicy_PolicyResultType
	OpenconfigRoutingPolicy_PolicyResultType_REJECT_ROUTE E_OpenconfigRoutingPolicy_PolicyResultType = 2
)

// E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode. An additional value named
// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode.
func (E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode.
func (e E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode")
}

const (
	// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_UNSET E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode = 0
	// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_IPV4 corresponds to the value IPV4 of OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_IPV4 E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode = 1
	// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_IPV6 corresponds to the value IPV6 of OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_IPV6 E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode = 2
	// OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_MIXED corresponds to the value MIXED of OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode_MIXED E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode = 3
)

// E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode is a derived int64 type which is used to represent
// the enumerated node OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode. An additional value named
// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode int64

// IsYANGGoEnum ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode implements the yang.GoEnum
// interface. This ensures that OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode) IsYANGGoEnum() {
}

// ΛMap returns the value lookup map associated with  OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode.
func (E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode.
func (e E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode")
}

const (
	// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_UNSET corresponds to the value UNSET of OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_UNSET E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode = 0
	// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_INLINE corresponds to the value INLINE of OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_INLINE E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode = 1
	// OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_REFERENCE corresponds to the value REFERENCE of OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode
	OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode_REFERENCE E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode = 2
)

// E_OpenconfigSegmentRouting_SrDataplaneType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSegmentRouting_SrDataplaneType. An additional value named
// OpenconfigSegmentRouting_SrDataplaneType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSegmentRouting_SrDataplaneType int64

// IsYANGGoEnum ensures that OpenconfigSegmentRouting_SrDataplaneType implements the yang.GoEnum
// interface. This ensures that OpenconfigSegmentRouting_SrDataplaneType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSegmentRouting_SrDataplaneType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSegmentRouting_SrDataplaneType.
func (E_OpenconfigSegmentRouting_SrDataplaneType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSegmentRouting_SrDataplaneType.
func (e E_OpenconfigSegmentRouting_SrDataplaneType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSegmentRouting_SrDataplaneType")
}

const (
	// OpenconfigSegmentRouting_SrDataplaneType_UNSET corresponds to the value UNSET of OpenconfigSegmentRouting_SrDataplaneType
	OpenconfigSegmentRouting_SrDataplaneType_UNSET E_OpenconfigSegmentRouting_SrDataplaneType = 0
	// OpenconfigSegmentRouting_SrDataplaneType_MPLS corresponds to the value MPLS of OpenconfigSegmentRouting_SrDataplaneType
	OpenconfigSegmentRouting_SrDataplaneType_MPLS E_OpenconfigSegmentRouting_SrDataplaneType = 1
	// OpenconfigSegmentRouting_SrDataplaneType_IPV6 corresponds to the value IPV6 of OpenconfigSegmentRouting_SrDataplaneType
	OpenconfigSegmentRouting_SrDataplaneType_IPV6 E_OpenconfigSegmentRouting_SrDataplaneType = 2
)

// E_OpenconfigSrtePolicy_EnlpType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSrtePolicy_EnlpType. An additional value named
// OpenconfigSrtePolicy_EnlpType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSrtePolicy_EnlpType int64

// IsYANGGoEnum ensures that OpenconfigSrtePolicy_EnlpType implements the yang.GoEnum
// interface. This ensures that OpenconfigSrtePolicy_EnlpType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSrtePolicy_EnlpType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSrtePolicy_EnlpType.
func (E_OpenconfigSrtePolicy_EnlpType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSrtePolicy_EnlpType.
func (e E_OpenconfigSrtePolicy_EnlpType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSrtePolicy_EnlpType")
}

const (
	// OpenconfigSrtePolicy_EnlpType_UNSET corresponds to the value UNSET of OpenconfigSrtePolicy_EnlpType
	OpenconfigSrtePolicy_EnlpType_UNSET E_OpenconfigSrtePolicy_EnlpType = 0
	// OpenconfigSrtePolicy_EnlpType_PUSH_IPV4_EXPLICIT_NULL corresponds to the value PUSH_IPV4_EXPLICIT_NULL of OpenconfigSrtePolicy_EnlpType
	OpenconfigSrtePolicy_EnlpType_PUSH_IPV4_EXPLICIT_NULL E_OpenconfigSrtePolicy_EnlpType = 1
	// OpenconfigSrtePolicy_EnlpType_PUSH_IPV6_EXPLICIT_NULL corresponds to the value PUSH_IPV6_EXPLICIT_NULL of OpenconfigSrtePolicy_EnlpType
	OpenconfigSrtePolicy_EnlpType_PUSH_IPV6_EXPLICIT_NULL E_OpenconfigSrtePolicy_EnlpType = 2
	// OpenconfigSrtePolicy_EnlpType_PUSH_IPV46_EXPLICIT_NULL corresponds to the value PUSH_IPV46_EXPLICIT_NULL of OpenconfigSrtePolicy_EnlpType
	OpenconfigSrtePolicy_EnlpType_PUSH_IPV46_EXPLICIT_NULL E_OpenconfigSrtePolicy_EnlpType = 3
	// OpenconfigSrtePolicy_EnlpType_NO_EXPLICIT_NULL corresponds to the value NO_EXPLICIT_NULL of OpenconfigSrtePolicy_EnlpType
	OpenconfigSrtePolicy_EnlpType_NO_EXPLICIT_NULL E_OpenconfigSrtePolicy_EnlpType = 4
)

// E_OpenconfigSrtePolicy_SrteInvalidSlReason is a derived int64 type which is used to represent
// the enumerated node OpenconfigSrtePolicy_SrteInvalidSlReason. An additional value named
// OpenconfigSrtePolicy_SrteInvalidSlReason_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSrtePolicy_SrteInvalidSlReason int64

// IsYANGGoEnum ensures that OpenconfigSrtePolicy_SrteInvalidSlReason implements the yang.GoEnum
// interface. This ensures that OpenconfigSrtePolicy_SrteInvalidSlReason can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSrtePolicy_SrteInvalidSlReason) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSrtePolicy_SrteInvalidSlReason.
func (E_OpenconfigSrtePolicy_SrteInvalidSlReason) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSrtePolicy_SrteInvalidSlReason.
func (e E_OpenconfigSrtePolicy_SrteInvalidSlReason) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSrtePolicy_SrteInvalidSlReason")
}

const (
	// OpenconfigSrtePolicy_SrteInvalidSlReason_UNSET corresponds to the value UNSET of OpenconfigSrtePolicy_SrteInvalidSlReason
	OpenconfigSrtePolicy_SrteInvalidSlReason_UNSET E_OpenconfigSrtePolicy_SrteInvalidSlReason = 0
	// OpenconfigSrtePolicy_SrteInvalidSlReason_EMPTY_SL corresponds to the value EMPTY_SL of OpenconfigSrtePolicy_SrteInvalidSlReason
	OpenconfigSrtePolicy_SrteInvalidSlReason_EMPTY_SL E_OpenconfigSrtePolicy_SrteInvalidSlReason = 1
	// OpenconfigSrtePolicy_SrteInvalidSlReason_ZERO_WEIGHT corresponds to the value ZERO_WEIGHT of OpenconfigSrtePolicy_SrteInvalidSlReason
	OpenconfigSrtePolicy_SrteInvalidSlReason_ZERO_WEIGHT E_OpenconfigSrtePolicy_SrteInvalidSlReason = 2
	// OpenconfigSrtePolicy_SrteInvalidSlReason_FIRST_SID_UNRESOLVABLE corresponds to the value FIRST_SID_UNRESOLVABLE of OpenconfigSrtePolicy_SrteInvalidSlReason
	OpenconfigSrtePolicy_SrteInvalidSlReason_FIRST_SID_UNRESOLVABLE E_OpenconfigSrtePolicy_SrteInvalidSlReason = 3
	// OpenconfigSrtePolicy_SrteInvalidSlReason_OTHER_SID_UNRESOLVABLE corresponds to the value OTHER_SID_UNRESOLVABLE of OpenconfigSrtePolicy_SrteInvalidSlReason
	OpenconfigSrtePolicy_SrteInvalidSlReason_OTHER_SID_UNRESOLVABLE E_OpenconfigSrtePolicy_SrteInvalidSlReason = 4
	// OpenconfigSrtePolicy_SrteInvalidSlReason_VERIFICATION_FAIL corresponds to the value VERIFICATION_FAIL of OpenconfigSrtePolicy_SrteInvalidSlReason
	OpenconfigSrtePolicy_SrteInvalidSlReason_VERIFICATION_FAIL E_OpenconfigSrtePolicy_SrteInvalidSlReason = 5
)

// E_OpenconfigSrtePolicy_SrteProtocolType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSrtePolicy_SrteProtocolType. An additional value named
// OpenconfigSrtePolicy_SrteProtocolType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSrtePolicy_SrteProtocolType int64

// IsYANGGoEnum ensures that OpenconfigSrtePolicy_SrteProtocolType implements the yang.GoEnum
// interface. This ensures that OpenconfigSrtePolicy_SrteProtocolType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSrtePolicy_SrteProtocolType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSrtePolicy_SrteProtocolType.
func (E_OpenconfigSrtePolicy_SrteProtocolType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSrtePolicy_SrteProtocolType.
func (e E_OpenconfigSrtePolicy_SrteProtocolType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSrtePolicy_SrteProtocolType")
}

const (
	// OpenconfigSrtePolicy_SrteProtocolType_UNSET corresponds to the value UNSET of OpenconfigSrtePolicy_SrteProtocolType
	OpenconfigSrtePolicy_SrteProtocolType_UNSET E_OpenconfigSrtePolicy_SrteProtocolType = 0
	// OpenconfigSrtePolicy_SrteProtocolType_PCEP corresponds to the value PCEP of OpenconfigSrtePolicy_SrteProtocolType
	OpenconfigSrtePolicy_SrteProtocolType_PCEP E_OpenconfigSrtePolicy_SrteProtocolType = 11
	// OpenconfigSrtePolicy_SrteProtocolType_BGP corresponds to the value BGP of OpenconfigSrtePolicy_SrteProtocolType
	OpenconfigSrtePolicy_SrteProtocolType_BGP E_OpenconfigSrtePolicy_SrteProtocolType = 21
	// OpenconfigSrtePolicy_SrteProtocolType_CONFIG corresponds to the value CONFIG of OpenconfigSrtePolicy_SrteProtocolType
	OpenconfigSrtePolicy_SrteProtocolType_CONFIG E_OpenconfigSrtePolicy_SrteProtocolType = 31
)

// E_OpenconfigSystemLogging_SYSLOG_FACILITY is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystemLogging_SYSLOG_FACILITY. An additional value named
// OpenconfigSystemLogging_SYSLOG_FACILITY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystemLogging_SYSLOG_FACILITY int64

// IsYANGGoEnum ensures that OpenconfigSystemLogging_SYSLOG_FACILITY implements the yang.GoEnum
// interface. This ensures that OpenconfigSystemLogging_SYSLOG_FACILITY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystemLogging_SYSLOG_FACILITY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystemLogging_SYSLOG_FACILITY.
func (E_OpenconfigSystemLogging_SYSLOG_FACILITY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystemLogging_SYSLOG_FACILITY.
func (e E_OpenconfigSystemLogging_SYSLOG_FACILITY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystemLogging_SYSLOG_FACILITY")
}

const (
	// OpenconfigSystemLogging_SYSLOG_FACILITY_UNSET corresponds to the value UNSET of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_UNSET E_OpenconfigSystemLogging_SYSLOG_FACILITY = 0
	// OpenconfigSystemLogging_SYSLOG_FACILITY_ALL corresponds to the value ALL of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_ALL E_OpenconfigSystemLogging_SYSLOG_FACILITY = 1
	// OpenconfigSystemLogging_SYSLOG_FACILITY_AUDIT corresponds to the value AUDIT of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_AUDIT E_OpenconfigSystemLogging_SYSLOG_FACILITY = 2
	// OpenconfigSystemLogging_SYSLOG_FACILITY_AUTH corresponds to the value AUTH of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_AUTH E_OpenconfigSystemLogging_SYSLOG_FACILITY = 3
	// OpenconfigSystemLogging_SYSLOG_FACILITY_AUTHPRIV corresponds to the value AUTHPRIV of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_AUTHPRIV E_OpenconfigSystemLogging_SYSLOG_FACILITY = 4
	// OpenconfigSystemLogging_SYSLOG_FACILITY_CONSOLE corresponds to the value CONSOLE of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_CONSOLE E_OpenconfigSystemLogging_SYSLOG_FACILITY = 5
	// OpenconfigSystemLogging_SYSLOG_FACILITY_KERNEL corresponds to the value KERNEL of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_KERNEL E_OpenconfigSystemLogging_SYSLOG_FACILITY = 6
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL0 corresponds to the value LOCAL0 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL0 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 7
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL1 corresponds to the value LOCAL1 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL1 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 8
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL2 corresponds to the value LOCAL2 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL2 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 9
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL3 corresponds to the value LOCAL3 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL3 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 10
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL4 corresponds to the value LOCAL4 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL4 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 11
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL5 corresponds to the value LOCAL5 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL5 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 12
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL6 corresponds to the value LOCAL6 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL6 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 13
	// OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL7 corresponds to the value LOCAL7 of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_LOCAL7 E_OpenconfigSystemLogging_SYSLOG_FACILITY = 14
	// OpenconfigSystemLogging_SYSLOG_FACILITY_MAIL corresponds to the value MAIL of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_MAIL E_OpenconfigSystemLogging_SYSLOG_FACILITY = 15
	// OpenconfigSystemLogging_SYSLOG_FACILITY_NTP corresponds to the value NTP of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_NTP E_OpenconfigSystemLogging_SYSLOG_FACILITY = 16
	// OpenconfigSystemLogging_SYSLOG_FACILITY_SYSLOG corresponds to the value SYSLOG of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_SYSLOG E_OpenconfigSystemLogging_SYSLOG_FACILITY = 17
	// OpenconfigSystemLogging_SYSLOG_FACILITY_SYSTEM_DAEMON corresponds to the value SYSTEM_DAEMON of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_SYSTEM_DAEMON E_OpenconfigSystemLogging_SYSLOG_FACILITY = 18
	// OpenconfigSystemLogging_SYSLOG_FACILITY_USER corresponds to the value USER of OpenconfigSystemLogging_SYSLOG_FACILITY
	OpenconfigSystemLogging_SYSLOG_FACILITY_USER E_OpenconfigSystemLogging_SYSLOG_FACILITY = 19
)

// E_OpenconfigSystemLogging_SyslogSeverity is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystemLogging_SyslogSeverity. An additional value named
// OpenconfigSystemLogging_SyslogSeverity_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystemLogging_SyslogSeverity int64

// IsYANGGoEnum ensures that OpenconfigSystemLogging_SyslogSeverity implements the yang.GoEnum
// interface. This ensures that OpenconfigSystemLogging_SyslogSeverity can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystemLogging_SyslogSeverity) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystemLogging_SyslogSeverity.
func (E_OpenconfigSystemLogging_SyslogSeverity) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystemLogging_SyslogSeverity.
func (e E_OpenconfigSystemLogging_SyslogSeverity) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystemLogging_SyslogSeverity")
}

const (
	// OpenconfigSystemLogging_SyslogSeverity_UNSET corresponds to the value UNSET of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_UNSET E_OpenconfigSystemLogging_SyslogSeverity = 0
	// OpenconfigSystemLogging_SyslogSeverity_EMERGENCY corresponds to the value EMERGENCY of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_EMERGENCY E_OpenconfigSystemLogging_SyslogSeverity = 1
	// OpenconfigSystemLogging_SyslogSeverity_ALERT corresponds to the value ALERT of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_ALERT E_OpenconfigSystemLogging_SyslogSeverity = 2
	// OpenconfigSystemLogging_SyslogSeverity_CRITICAL corresponds to the value CRITICAL of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_CRITICAL E_OpenconfigSystemLogging_SyslogSeverity = 3
	// OpenconfigSystemLogging_SyslogSeverity_ERROR corresponds to the value ERROR of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_ERROR E_OpenconfigSystemLogging_SyslogSeverity = 4
	// OpenconfigSystemLogging_SyslogSeverity_WARNING corresponds to the value WARNING of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_WARNING E_OpenconfigSystemLogging_SyslogSeverity = 5
	// OpenconfigSystemLogging_SyslogSeverity_NOTICE corresponds to the value NOTICE of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_NOTICE E_OpenconfigSystemLogging_SyslogSeverity = 6
	// OpenconfigSystemLogging_SyslogSeverity_INFORMATIONAL corresponds to the value INFORMATIONAL of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_INFORMATIONAL E_OpenconfigSystemLogging_SyslogSeverity = 7
	// OpenconfigSystemLogging_SyslogSeverity_DEBUG corresponds to the value DEBUG of OpenconfigSystemLogging_SyslogSeverity
	OpenconfigSystemLogging_SyslogSeverity_DEBUG E_OpenconfigSystemLogging_SyslogSeverity = 8
)

// E_OpenconfigSystem_NTP_AUTH_TYPE is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_NTP_AUTH_TYPE. An additional value named
// OpenconfigSystem_NTP_AUTH_TYPE_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_NTP_AUTH_TYPE int64

// IsYANGGoEnum ensures that OpenconfigSystem_NTP_AUTH_TYPE implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_NTP_AUTH_TYPE can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_NTP_AUTH_TYPE) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_NTP_AUTH_TYPE.
func (E_OpenconfigSystem_NTP_AUTH_TYPE) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_NTP_AUTH_TYPE.
func (e E_OpenconfigSystem_NTP_AUTH_TYPE) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_NTP_AUTH_TYPE")
}

const (
	// OpenconfigSystem_NTP_AUTH_TYPE_UNSET corresponds to the value UNSET of OpenconfigSystem_NTP_AUTH_TYPE
	OpenconfigSystem_NTP_AUTH_TYPE_UNSET E_OpenconfigSystem_NTP_AUTH_TYPE = 0
	// OpenconfigSystem_NTP_AUTH_TYPE_NTP_AUTH_MD5 corresponds to the value NTP_AUTH_MD5 of OpenconfigSystem_NTP_AUTH_TYPE
	OpenconfigSystem_NTP_AUTH_TYPE_NTP_AUTH_MD5 E_OpenconfigSystem_NTP_AUTH_TYPE = 1
)

// E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record. An additional value named
// OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record int64

// IsYANGGoEnum ensures that OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record.
func (E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record.
func (e E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record")
}

const (
	// OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_UNSET corresponds to the value UNSET of OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record
	OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_UNSET E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record = 0
	// OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_START_STOP corresponds to the value START_STOP of OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record
	OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_START_STOP E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record = 1
	// OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_STOP corresponds to the value STOP of OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record
	OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record_STOP E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record = 2
)

// E_OpenconfigSystem_System_Cpus_Cpu_State_Index is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_System_Cpus_Cpu_State_Index. An additional value named
// OpenconfigSystem_System_Cpus_Cpu_State_Index_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_System_Cpus_Cpu_State_Index int64

// IsYANGGoEnum ensures that OpenconfigSystem_System_Cpus_Cpu_State_Index implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_System_Cpus_Cpu_State_Index can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_System_Cpus_Cpu_State_Index) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_System_Cpus_Cpu_State_Index.
func (E_OpenconfigSystem_System_Cpus_Cpu_State_Index) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_System_Cpus_Cpu_State_Index.
func (e E_OpenconfigSystem_System_Cpus_Cpu_State_Index) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_System_Cpus_Cpu_State_Index")
}

const (
	// OpenconfigSystem_System_Cpus_Cpu_State_Index_UNSET corresponds to the value UNSET of OpenconfigSystem_System_Cpus_Cpu_State_Index
	OpenconfigSystem_System_Cpus_Cpu_State_Index_UNSET E_OpenconfigSystem_System_Cpus_Cpu_State_Index = 0
	// OpenconfigSystem_System_Cpus_Cpu_State_Index_ALL corresponds to the value ALL of OpenconfigSystem_System_Cpus_Cpu_State_Index
	OpenconfigSystem_System_Cpus_Cpu_State_Index_ALL E_OpenconfigSystem_System_Cpus_Cpu_State_Index = 1
)

// E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_System_GrpcServer_Config_ListenAddresses. An additional value named
// OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses int64

// IsYANGGoEnum ensures that OpenconfigSystem_System_GrpcServer_Config_ListenAddresses implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_System_GrpcServer_Config_ListenAddresses can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_System_GrpcServer_Config_ListenAddresses.
func (E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses.
func (e E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses")
}

const (
	// OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_UNSET corresponds to the value UNSET of OpenconfigSystem_System_GrpcServer_Config_ListenAddresses
	OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_UNSET E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses = 0
	// OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_ANY corresponds to the value ANY of OpenconfigSystem_System_GrpcServer_Config_ListenAddresses
	OpenconfigSystem_System_GrpcServer_Config_ListenAddresses_ANY E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses = 1
)

// E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType. An additional value named
// OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType int64

// IsYANGGoEnum ensures that OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType.
func (E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType.
func (e E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType")
}

const (
	// OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_UNSET corresponds to the value UNSET of OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType
	OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_UNSET E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType = 0
	// OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_SERVER corresponds to the value SERVER of OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType
	OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_SERVER E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType = 1
	// OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_PEER corresponds to the value PEER of OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType
	OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_PEER E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType = 2
	// OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_POOL corresponds to the value POOL of OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType
	OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType_POOL E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType = 3
)

// E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion is a derived int64 type which is used to represent
// the enumerated node OpenconfigSystem_System_SshServer_Config_ProtocolVersion. An additional value named
// OpenconfigSystem_System_SshServer_Config_ProtocolVersion_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion int64

// IsYANGGoEnum ensures that OpenconfigSystem_System_SshServer_Config_ProtocolVersion implements the yang.GoEnum
// interface. This ensures that OpenconfigSystem_System_SshServer_Config_ProtocolVersion can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigSystem_System_SshServer_Config_ProtocolVersion.
func (E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion.
func (e E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion")
}

const (
	// OpenconfigSystem_System_SshServer_Config_ProtocolVersion_UNSET corresponds to the value UNSET of OpenconfigSystem_System_SshServer_Config_ProtocolVersion
	OpenconfigSystem_System_SshServer_Config_ProtocolVersion_UNSET E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion = 0
	// OpenconfigSystem_System_SshServer_Config_ProtocolVersion_V2 corresponds to the value V2 of OpenconfigSystem_System_SshServer_Config_ProtocolVersion
	OpenconfigSystem_System_SshServer_Config_ProtocolVersion_V2 E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion = 1
	// OpenconfigSystem_System_SshServer_Config_ProtocolVersion_V1 corresponds to the value V1 of OpenconfigSystem_System_SshServer_Config_ProtocolVersion
	OpenconfigSystem_System_SshServer_Config_ProtocolVersion_V1 E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion = 2
	// OpenconfigSystem_System_SshServer_Config_ProtocolVersion_V1_V2 corresponds to the value V1_V2 of OpenconfigSystem_System_SshServer_Config_ProtocolVersion
	OpenconfigSystem_System_SshServer_Config_ProtocolVersion_V1_V2 E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion = 3
)

// E_OpenconfigTypes_ADDRESS_FAMILY is a derived int64 type which is used to represent
// the enumerated node OpenconfigTypes_ADDRESS_FAMILY. An additional value named
// OpenconfigTypes_ADDRESS_FAMILY_UNSET is added to the enumeration which is used as
// the nil value, indicating that the enumeration was not explicitly set by
// the program importing the generated structures.
type E_OpenconfigTypes_ADDRESS_FAMILY int64

// IsYANGGoEnum ensures that OpenconfigTypes_ADDRESS_FAMILY implements the yang.GoEnum
// interface. This ensures that OpenconfigTypes_ADDRESS_FAMILY can be identified as a
// mapped type for a YANG enumeration.
func (E_OpenconfigTypes_ADDRESS_FAMILY) IsYANGGoEnum() {}

// ΛMap returns the value lookup map associated with  OpenconfigTypes_ADDRESS_FAMILY.
func (E_OpenconfigTypes_ADDRESS_FAMILY) ΛMap() map[string]map[int64]ygot.EnumDefinition {
	return ΛEnum
}

// String returns a logging-friendly string for E_OpenconfigTypes_ADDRESS_FAMILY.
func (e E_OpenconfigTypes_ADDRESS_FAMILY) String() string {
	return ygot.EnumLogString(e, int64(e), "E_OpenconfigTypes_ADDRESS_FAMILY")
}

const (
	// OpenconfigTypes_ADDRESS_FAMILY_UNSET corresponds to the value UNSET of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_UNSET E_OpenconfigTypes_ADDRESS_FAMILY = 0
	// OpenconfigTypes_ADDRESS_FAMILY_IPV4 corresponds to the value IPV4 of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_IPV4 E_OpenconfigTypes_ADDRESS_FAMILY = 1
	// OpenconfigTypes_ADDRESS_FAMILY_IPV6 corresponds to the value IPV6 of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_IPV6 E_OpenconfigTypes_ADDRESS_FAMILY = 2
	// OpenconfigTypes_ADDRESS_FAMILY_L2_ETHERNET corresponds to the value L2_ETHERNET of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_L2_ETHERNET E_OpenconfigTypes_ADDRESS_FAMILY = 3
	// OpenconfigTypes_ADDRESS_FAMILY_MPLS corresponds to the value MPLS of OpenconfigTypes_ADDRESS_FAMILY
	OpenconfigTypes_ADDRESS_FAMILY_MPLS E_OpenconfigTypes_ADDRESS_FAMILY = 4
)

// ΛEnum is a map, keyed by the name of the type defined for each enum in the
// generated Go code, which provides a mapping between the constant int64 value
// of each value of the enumeration, and the string that is used to represent it
// in the YANG schema. The map is named ΛEnum in order to avoid clash with any
// valid YANG identifier.
var ΛEnum = map[string]map[int64]ygot.EnumDefinition{
	"E_IETFInterfaces_InterfaceType": {
		1:   {Name: "a12MppSwitch", DefiningModule: "iana-if-type"},
		2:   {Name: "aal2", DefiningModule: "iana-if-type"},
		3:   {Name: "aal5", DefiningModule: "iana-if-type"},
		4:   {Name: "actelisMetaLOOP", DefiningModule: "iana-if-type"},
		5:   {Name: "adsl", DefiningModule: "iana-if-type"},
		6:   {Name: "adsl2", DefiningModule: "iana-if-type"},
		7:   {Name: "adsl2plus", DefiningModule: "iana-if-type"},
		8:   {Name: "aflane8023", DefiningModule: "iana-if-type"},
		9:   {Name: "aflane8025", DefiningModule: "iana-if-type"},
		10:  {Name: "aluELP", DefiningModule: "iana-if-type"},
		11:  {Name: "aluEpon", DefiningModule: "iana-if-type"},
		12:  {Name: "aluEponLogicalLink", DefiningModule: "iana-if-type"},
		13:  {Name: "aluEponOnu", DefiningModule: "iana-if-type"},
		14:  {Name: "aluEponPhysicalUni", DefiningModule: "iana-if-type"},
		15:  {Name: "aluGponOnu", DefiningModule: "iana-if-type"},
		16:  {Name: "aluGponPhysicalUni", DefiningModule: "iana-if-type"},
		17:  {Name: "arap", DefiningModule: "iana-if-type"},
		18:  {Name: "arcnet", DefiningModule: "iana-if-type"},
		19:  {Name: "arcnetPlus", DefiningModule: "iana-if-type"},
		20:  {Name: "async", DefiningModule: "iana-if-type"},
		21:  {Name: "atm", DefiningModule: "iana-if-type"},
		22:  {Name: "atmDxi", DefiningModule: "iana-if-type"},
		23:  {Name: "atmFuni", DefiningModule: "iana-if-type"},
		24:  {Name: "atmIma", DefiningModule: "iana-if-type"},
		25:  {Name: "atmLogical", DefiningModule: "iana-if-type"},
		26:  {Name: "atmRadio", DefiningModule: "iana-if-type"},
		27:  {Name: "atmSubInterface", DefiningModule: "iana-if-type"},
		28:  {Name: "atmVciEndPt", DefiningModule: "iana-if-type"},
		29:  {Name: "atmVirtual", DefiningModule: "iana-if-type"},
		30:  {Name: "atmbond", DefiningModule: "iana-if-type"},
		31:  {Name: "aviciOpticalEther", DefiningModule: "iana-if-type"},
		32:  {Name: "basicISDN", DefiningModule: "iana-if-type"},
		33:  {Name: "bgppolicyaccounting", DefiningModule: "iana-if-type"},
		34:  {Name: "bits", DefiningModule: "iana-if-type"},
		35:  {Name: "bridge", DefiningModule: "iana-if-type"},
		36:  {Name: "bsc", DefiningModule: "iana-if-type"},
		37:  {Name: "cableDownstreamRfPort", DefiningModule: "iana-if-type"},
		38:  {Name: "capwapDot11Bss", DefiningModule: "iana-if-type"},
		39:  {Name: "capwapDot11Profile", DefiningModule: "iana-if-type"},
		40:  {Name: "capwapWtpVirtualRadio", DefiningModule: "iana-if-type"},
		41:  {Name: "cblVectaStar", DefiningModule: "iana-if-type"},
		42:  {Name: "cctEmul", DefiningModule: "iana-if-type"},
		43:  {Name: "ces", DefiningModule: "iana-if-type"},
		44:  {Name: "channel", DefiningModule: "iana-if-type"},
		45:  {Name: "ciscoISLvlan", DefiningModule: "iana-if-type"},
		46:  {Name: "cnr", DefiningModule: "iana-if-type"},
		47:  {Name: "coffee", DefiningModule: "iana-if-type"},
		48:  {Name: "compositeLink", DefiningModule: "iana-if-type"},
		49:  {Name: "dcn", DefiningModule: "iana-if-type"},
		50:  {Name: "ddnX25", DefiningModule: "iana-if-type"},
		51:  {Name: "digitalPowerline", DefiningModule: "iana-if-type"},
		52:  {Name: "digitalWrapperOverheadChannel", DefiningModule: "iana-if-type"},
		53:  {Name: "dlsw", DefiningModule: "iana-if-type"},
		54:  {Name: "docsCableDownstream", DefiningModule: "iana-if-type"},
		55:  {Name: "docsCableMCmtsDownstream", DefiningModule: "iana-if-type"},
		56:  {Name: "docsCableMaclayer", DefiningModule: "iana-if-type"},
		57:  {Name: "docsCableNdf", DefiningModule: "iana-if-type"},
		58:  {Name: "docsCableNdr", DefiningModule: "iana-if-type"},
		59:  {Name: "docsCableScte55d1FwdOob", DefiningModule: "iana-if-type"},
		60:  {Name: "docsCableScte55d1RetOob", DefiningModule: "iana-if-type"},
		61:  {Name: "docsCableScte55d2DsOob", DefiningModule: "iana-if-type"},
		62:  {Name: "docsCableScte55d2UsOob", DefiningModule: "iana-if-type"},
		63:  {Name: "docsCableUpstream", DefiningModule: "iana-if-type"},
		64:  {Name: "docsCableUpstreamChannel", DefiningModule: "iana-if-type"},
		65:  {Name: "docsCableUpstreamRfPort", DefiningModule: "iana-if-type"},
		66:  {Name: "docsOfdmDownstream", DefiningModule: "iana-if-type"},
		67:  {Name: "docsOfdmaUpstream", DefiningModule: "iana-if-type"},
		68:  {Name: "ds0", DefiningModule: "iana-if-type"},
		69:  {Name: "ds0Bundle", DefiningModule: "iana-if-type"},
		70:  {Name: "ds1", DefiningModule: "iana-if-type"},
		71:  {Name: "ds1FDL", DefiningModule: "iana-if-type"},
		72:  {Name: "ds3", DefiningModule: "iana-if-type"},
		73:  {Name: "dtm", DefiningModule: "iana-if-type"},
		74:  {Name: "dvbAsiIn", DefiningModule: "iana-if-type"},
		75:  {Name: "dvbAsiOut", DefiningModule: "iana-if-type"},
		76:  {Name: "dvbRccDownstream", DefiningModule: "iana-if-type"},
		77:  {Name: "dvbRccMacLayer", DefiningModule: "iana-if-type"},
		78:  {Name: "dvbRccUpstream", DefiningModule: "iana-if-type"},
		79:  {Name: "dvbRcsMacLayer", DefiningModule: "iana-if-type"},
		80:  {Name: "dvbRcsTdma", DefiningModule: "iana-if-type"},
		81:  {Name: "dvbTdm", DefiningModule: "iana-if-type"},
		82:  {Name: "e1", DefiningModule: "iana-if-type"},
		83:  {Name: "econet", DefiningModule: "iana-if-type"},
		84:  {Name: "eon", DefiningModule: "iana-if-type"},
		85:  {Name: "eplrs", DefiningModule: "iana-if-type"},
		86:  {Name: "escon", DefiningModule: "iana-if-type"},
		87:  {Name: "ethernet3Mbit", DefiningModule: "iana-if-type"},
		88:  {Name: "ethernetCsmacd", DefiningModule: "iana-if-type"},
		89:  {Name: "fast", DefiningModule: "iana-if-type"},
		90:  {Name: "fastEther", DefiningModule: "iana-if-type"},
		91:  {Name: "fastEtherFX", DefiningModule: "iana-if-type"},
		92:  {Name: "fastdsl", DefiningModule: "iana-if-type"},
		93:  {Name: "fcipLink", DefiningModule: "iana-if-type"},
		94:  {Name: "fddi", DefiningModule: "iana-if-type"},
		95:  {Name: "fibreChannel", DefiningModule: "iana-if-type"},
		96:  {Name: "frDlciEndPt", DefiningModule: "iana-if-type"},
		97:  {Name: "frForward", DefiningModule: "iana-if-type"},
		98:  {Name: "frameRelay", DefiningModule: "iana-if-type"},
		99:  {Name: "frameRelayInterconnect", DefiningModule: "iana-if-type"},
		100: {Name: "frameRelayMPI", DefiningModule: "iana-if-type"},
		101: {Name: "frameRelayService", DefiningModule: "iana-if-type"},
		102: {Name: "frf16MfrBundle", DefiningModule: "iana-if-type"},
		103: {Name: "g703at2mb", DefiningModule: "iana-if-type"},
		104: {Name: "g703at64k", DefiningModule: "iana-if-type"},
		105: {Name: "g9981", DefiningModule: "iana-if-type"},
		106: {Name: "g9982", DefiningModule: "iana-if-type"},
		107: {Name: "g9983", DefiningModule: "iana-if-type"},
		108: {Name: "gfast", DefiningModule: "iana-if-type"},
		109: {Name: "gfp", DefiningModule: "iana-if-type"},
		110: {Name: "gigabitEthernet", DefiningModule: "iana-if-type"},
		111: {Name: "gpon", DefiningModule: "iana-if-type"},
		112: {Name: "gr303IDT", DefiningModule: "iana-if-type"},
		113: {Name: "gr303RDT", DefiningModule: "iana-if-type"},
		114: {Name: "gtp", DefiningModule: "iana-if-type"},
		115: {Name: "h323Gatekeeper", DefiningModule: "iana-if-type"},
		116: {Name: "h323Proxy", DefiningModule: "iana-if-type"},
		117: {Name: "hdh1822", DefiningModule: "iana-if-type"},
		118: {Name: "hdlc", DefiningModule: "iana-if-type"},
		119: {Name: "hdsl2", DefiningModule: "iana-if-type"},
		120: {Name: "hiperlan2", DefiningModule: "iana-if-type"},
		121: {Name: "hippi", DefiningModule: "iana-if-type"},
		122: {Name: "hippiInterface", DefiningModule: "iana-if-type"},
		123: {Name: "homepna", DefiningModule: "iana-if-type"},
		124: {Name: "hostPad", DefiningModule: "iana-if-type"},
		125: {Name: "hssi", DefiningModule: "iana-if-type"},
		126: {Name: "hyperchannel", DefiningModule: "iana-if-type"},
		127: {Name: "iana-interface-type", DefiningModule: "iana-if-type"},
		128: {Name: "ibm370parChan", DefiningModule: "iana-if-type"},
		129: {Name: "idsl", DefiningModule: "iana-if-type"},
		130: {Name: "ieee1394", DefiningModule: "iana-if-type"},
		131: {Name: "ieee80211", DefiningModule: "iana-if-type"},
		132: {Name: "ieee80212", DefiningModule: "iana-if-type"},
		133: {Name: "ieee802154", DefiningModule: "iana-if-type"},
		134: {Name: "ieee80216WMAN", DefiningModule: "iana-if-type"},
		135: {Name: "ieee8023adLag", DefiningModule: "iana-if-type"},
		136: {Name: "if-gsn", DefiningModule: "iana-if-type"},
		137: {Name: "ifPwType", DefiningModule: "iana-if-type"},
		138: {Name: "ifVfiType", DefiningModule: "iana-if-type"},
		139: {Name: "ilan", DefiningModule: "iana-if-type"},
		140: {Name: "imt", DefiningModule: "iana-if-type"},
		141: {Name: "infiniband", DefiningModule: "iana-if-type"},
		142: {Name: "interleave", DefiningModule: "iana-if-type"},
		143: {Name: "ip", DefiningModule: "iana-if-type"},
		144: {Name: "ipForward", DefiningModule: "iana-if-type"},
		145: {Name: "ipOverAtm", DefiningModule: "iana-if-type"},
		146: {Name: "ipOverCdlc", DefiningModule: "iana-if-type"},
		147: {Name: "ipOverClaw", DefiningModule: "iana-if-type"},
		148: {Name: "ipSwitch", DefiningModule: "iana-if-type"},
		149: {Name: "isdn", DefiningModule: "iana-if-type"},
		150: {Name: "isdns", DefiningModule: "iana-if-type"},
		151: {Name: "isdnu", DefiningModule: "iana-if-type"},
		152: {Name: "iso88022llc", DefiningModule: "iana-if-type"},
		153: {Name: "iso88023Csmacd", DefiningModule: "iana-if-type"},
		154: {Name: "iso88024TokenBus", DefiningModule: "iana-if-type"},
		155: {Name: "iso88025CRFPInt", DefiningModule: "iana-if-type"},
		156: {Name: "iso88025Dtr", DefiningModule: "iana-if-type"},
		157: {Name: "iso88025Fiber", DefiningModule: "iana-if-type"},
		158: {Name: "iso88025TokenRing", DefiningModule: "iana-if-type"},
		159: {Name: "iso88026Man", DefiningModule: "iana-if-type"},
		160: {Name: "isup", DefiningModule: "iana-if-type"},
		161: {Name: "l2vlan", DefiningModule: "iana-if-type"},
		162: {Name: "l3ipvlan", DefiningModule: "iana-if-type"},
		163: {Name: "l3ipxvlan", DefiningModule: "iana-if-type"},
		164: {Name: "lapb", DefiningModule: "iana-if-type"},
		165: {Name: "lapd", DefiningModule: "iana-if-type"},
		166: {Name: "lapf", DefiningModule: "iana-if-type"},
		167: {Name: "linegroup", DefiningModule: "iana-if-type"},
		168: {Name: "lmp", DefiningModule: "iana-if-type"},
		169: {Name: "localTalk", DefiningModule: "iana-if-type"},
		170: {Name: "macSecControlledIF", DefiningModule: "iana-if-type"},
		171: {Name: "macSecUncontrolledIF", DefiningModule: "iana-if-type"},
		172: {Name: "mediaMailOverIp", DefiningModule: "iana-if-type"},
		173: {Name: "mfSigLink", DefiningModule: "iana-if-type"},
		174: {Name: "miox25", DefiningModule: "iana-if-type"},
		175: {Name: "mocaVersion1", DefiningModule: "iana-if-type"},
		176: {Name: "modem", DefiningModule: "iana-if-type"},
		177: {Name: "mpc", DefiningModule: "iana-if-type"},
		178: {Name: "mpegTransport", DefiningModule: "iana-if-type"},
		179: {Name: "mpls", DefiningModule: "iana-if-type"},
		180: {Name: "mplsTunnel", DefiningModule: "iana-if-type"},
		181: {Name: "msdsl", DefiningModule: "iana-if-type"},
		182: {Name: "mvl", DefiningModule: "iana-if-type"},
		183: {Name: "myrinet", DefiningModule: "iana-if-type"},
		184: {Name: "nfas", DefiningModule: "iana-if-type"},
		185: {Name: "nsip", DefiningModule: "iana-if-type"},
		186: {Name: "opticalChannel", DefiningModule: "iana-if-type"},
		187: {Name: "opticalChannelGroup", DefiningModule: "iana-if-type"},
		188: {Name: "opticalTransport", DefiningModule: "iana-if-type"},
		189: {Name: "other", DefiningModule: "iana-if-type"},
		190: {Name: "otnOdu", DefiningModule: "iana-if-type"},
		191: {Name: "otnOtu", DefiningModule: "iana-if-type"},
		192: {Name: "para", DefiningModule: "iana-if-type"},
		193: {Name: "pdnEtherLoop1", DefiningModule: "iana-if-type"},
		194: {Name: "pdnEtherLoop2", DefiningModule: "iana-if-type"},
		195: {Name: "pip", DefiningModule: "iana-if-type"},
		196: {Name: "plc", DefiningModule: "iana-if-type"},
		197: {Name: "pon155", DefiningModule: "iana-if-type"},
		198: {Name: "pon622", DefiningModule: "iana-if-type"},
		199: {Name: "pos", DefiningModule: "iana-if-type"},
		200: {Name: "ppp", DefiningModule: "iana-if-type"},
		201: {Name: "pppMultilinkBundle", DefiningModule: "iana-if-type"},
		202: {Name: "primaryISDN", DefiningModule: "iana-if-type"},
		203: {Name: "propAtm", DefiningModule: "iana-if-type"},
		204: {Name: "propBWAp2Mp", DefiningModule: "iana-if-type"},
		205: {Name: "propCnls", DefiningModule: "iana-if-type"},
		206: {Name: "propDocsWirelessDownstream", DefiningModule: "iana-if-type"},
		207: {Name: "propDocsWirelessMaclayer", DefiningModule: "iana-if-type"},
		208: {Name: "propDocsWirelessUpstream", DefiningModule: "iana-if-type"},
		209: {Name: "propMultiplexor", DefiningModule: "iana-if-type"},
		210: {Name: "propPointToPointSerial", DefiningModule: "iana-if-type"},
		211: {Name: "propVirtual", DefiningModule: "iana-if-type"},
		212: {Name: "propWirelessP2P", DefiningModule: "iana-if-type"},
		213: {Name: "proteon10Mbit", DefiningModule: "iana-if-type"},
		214: {Name: "proteon80Mbit", DefiningModule: "iana-if-type"},
		215: {Name: "ptm", DefiningModule: "iana-if-type"},
		216: {Name: "q2931", DefiningModule: "iana-if-type"},
		217: {Name: "qam", DefiningModule: "iana-if-type"},
		218: {Name: "qllc", DefiningModule: "iana-if-type"},
		219: {Name: "radioMAC", DefiningModule: "iana-if-type"},
		220: {Name: "radsl", DefiningModule: "iana-if-type"},
		221: {Name: "reachDSL", DefiningModule: "iana-if-type"},
		222: {Name: "regular1822", DefiningModule: "iana-if-type"},
		223: {Name: "rfc1483", DefiningModule: "iana-if-type"},
		224: {Name: "rfc877x25", DefiningModule: "iana-if-type"},
		225: {Name: "rpr", DefiningModule: "iana-if-type"},
		226: {Name: "rs232", DefiningModule: "iana-if-type"},
		227: {Name: "rsrb", DefiningModule: "iana-if-type"},
		228: {Name: "sdci", DefiningModule: "iana-if-type"},
		229: {Name: "sdlc", DefiningModule: "iana-if-type"},
		230: {Name: "sdsl", DefiningModule: "iana-if-type"},
		231: {Name: "shdsl", DefiningModule: "iana-if-type"},
		232: {Name: "sip", DefiningModule: "iana-if-type"},
		233: {Name: "sipSig", DefiningModule: "iana-if-type"},
		234: {Name: "sipTg", DefiningModule: "iana-if-type"},
		235: {Name: "sixToFour", DefiningModule: "iana-if-type"},
		236: {Name: "slip", DefiningModule: "iana-if-type"},
		237: {Name: "smdsDxi", DefiningModule: "iana-if-type"},
		238: {Name: "smdsIcip", DefiningModule: "iana-if-type"},
		239: {Name: "softwareLoopback", DefiningModule: "iana-if-type"},
		240: {Name: "sonet", DefiningModule: "iana-if-type"},
		241: {Name: "sonetOverheadChannel", DefiningModule: "iana-if-type"},
		242: {Name: "sonetPath", DefiningModule: "iana-if-type"},
		243: {Name: "sonetVT", DefiningModule: "iana-if-type"},
		244: {Name: "srp", DefiningModule: "iana-if-type"},
		245: {Name: "ss7SigLink", DefiningModule: "iana-if-type"},
		246: {Name: "stackToStack", DefiningModule: "iana-if-type"},
		247: {Name: "starLan", DefiningModule: "iana-if-type"},
		248: {Name: "tdlc", DefiningModule: "iana-if-type"},
		249: {Name: "teLink", DefiningModule: "iana-if-type"},
		250: {Name: "termPad", DefiningModule: "iana-if-type"},
		251: {Name: "tr008", DefiningModule: "iana-if-type"},
		252: {Name: "transpHdlc", DefiningModule: "iana-if-type"},
		253: {Name: "tunnel", DefiningModule: "iana-if-type"},
		254: {Name: "ultra", DefiningModule: "iana-if-type"},
		255: {Name: "usb", DefiningModule: "iana-if-type"},
		256: {Name: "v11", DefiningModule: "iana-if-type"},
		257: {Name: "v35", DefiningModule: "iana-if-type"},
		258: {Name: "v36", DefiningModule: "iana-if-type"},
		259: {Name: "v37", DefiningModule: "iana-if-type"},
		260: {Name: "vdsl", DefiningModule: "iana-if-type"},
		261: {Name: "vdsl2", DefiningModule: "iana-if-type"},
		262: {Name: "virtualIpAddress", DefiningModule: "iana-if-type"},
		263: {Name: "virtualTg", DefiningModule: "iana-if-type"},
		264: {Name: "vmwareNicTeam", DefiningModule: "iana-if-type"},
		265: {Name: "vmwareVirtualNic", DefiningModule: "iana-if-type"},
		266: {Name: "voiceDID", DefiningModule: "iana-if-type"},
		267: {Name: "voiceEBS", DefiningModule: "iana-if-type"},
		268: {Name: "voiceEM", DefiningModule: "iana-if-type"},
		269: {Name: "voiceEMFGD", DefiningModule: "iana-if-type"},
		270: {Name: "voiceEncap", DefiningModule: "iana-if-type"},
		271: {Name: "voiceFGDEANA", DefiningModule: "iana-if-type"},
		272: {Name: "voiceFGDOS", DefiningModule: "iana-if-type"},
		273: {Name: "voiceFXO", DefiningModule: "iana-if-type"},
		274: {Name: "voiceFXS", DefiningModule: "iana-if-type"},
		275: {Name: "voiceOverAtm", DefiningModule: "iana-if-type"},
		276: {Name: "voiceOverCable", DefiningModule: "iana-if-type"},
		277: {Name: "voiceOverFrameRelay", DefiningModule: "iana-if-type"},
		278: {Name: "voiceOverIp", DefiningModule: "iana-if-type"},
		279: {Name: "wwanPP", DefiningModule: "iana-if-type"},
		280: {Name: "wwanPP2", DefiningModule: "iana-if-type"},
		281: {Name: "x213", DefiningModule: "iana-if-type"},
		282: {Name: "x25huntGroup", DefiningModule: "iana-if-type"},
		283: {Name: "x25mlp", DefiningModule: "iana-if-type"},
		284: {Name: "x25ple", DefiningModule: "iana-if-type"},
		285: {Name: "x86Laps", DefiningModule: "iana-if-type"},
		286: {Name: "xboxWireless", DefiningModule: "iana-if-type"},
	},
	"E_IETFInterfaces_InterfacesState_Interface_AdminStatus": {
		2: {Name: "up"},
		3: {Name: "down"},
		4: {Name: "testing"},
	},
	"E_IETFInterfaces_InterfacesState_Interface_OperStatus": {
		2: {Name: "up"},
		3: {Name: "down"},
		4: {Name: "testing"},
		5: {Name: "unknown"},
		6: {Name: "dormant"},
		7: {Name: "not-present"},
		8: {Name: "lower-layer-down"},
	},
	"E_IETFInterfaces_Interfaces_Interface_AdminStatus": {
		2: {Name: "up"},
		3: {Name: "down"},
		4: {Name: "testing"},
	},
	"E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable": {
		2: {Name: "enabled"},
		3: {Name: "disabled"},
	},
	"E_IETFInterfaces_Interfaces_Interface_OperStatus": {
		2: {Name: "up"},
		3: {Name: "down"},
		4: {Name: "testing"},
		5: {Name: "unknown"},
		6: {Name: "dormant"},
		7: {Name: "not-present"},
		8: {Name: "lower-layer-down"},
	},
	"E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE": {
		1: {Name: "AAA_ACCOUNTING_EVENT_COMMAND", DefiningModule: "openconfig-aaa-types"},
		2: {Name: "AAA_ACCOUNTING_EVENT_LOGIN", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE": {
		1: {Name: "AAA_AUTHORIZATION_EVENT_COMMAND", DefiningModule: "openconfig-aaa-types"},
		2: {Name: "AAA_AUTHORIZATION_EVENT_CONFIG", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAaaTypes_AAA_METHOD_TYPE": {
		1: {Name: "LOCAL", DefiningModule: "openconfig-aaa-types"},
		2: {Name: "RADIUS_ALL", DefiningModule: "openconfig-aaa-types"},
		3: {Name: "TACACS_ALL", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAaaTypes_AAA_SERVER_TYPE": {
		1: {Name: "RADIUS", DefiningModule: "openconfig-aaa"},
		2: {Name: "TACACS", DefiningModule: "openconfig-aaa"},
	},
	"E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES": {
		1: {Name: "SYSTEM_ROLE_ADMIN", DefiningModule: "openconfig-aaa-types"},
	},
	"E_OpenconfigAcl_ACL_COUNTER_CAPABILITY": {
		1: {Name: "AGGREGATE_ONLY", DefiningModule: "openconfig-acl"},
		2: {Name: "INTERFACE_AGGREGATE", DefiningModule: "openconfig-acl"},
		3: {Name: "INTERFACE_ONLY", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAcl_ACL_TYPE": {
		1: {Name: "ACL_IPV4", DefiningModule: "openconfig-acl"},
		2: {Name: "ACL_IPV6", DefiningModule: "openconfig-acl"},
		3: {Name: "ACL_L2", DefiningModule: "openconfig-acl"},
		4: {Name: "ACL_MIXED", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort": {
		1: {Name: "ANY"},
	},
	"E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort": {
		1: {Name: "ANY"},
	},
	"E_OpenconfigAcl_FORWARDING_ACTION": {
		1: {Name: "ACCEPT", DefiningModule: "openconfig-acl"},
		2: {Name: "DROP", DefiningModule: "openconfig-acl"},
		3: {Name: "REJECT", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAcl_LOG_ACTION": {
		1: {Name: "LOG_NONE", DefiningModule: "openconfig-acl"},
		2: {Name: "LOG_SYSLOG", DefiningModule: "openconfig-acl"},
	},
	"E_OpenconfigAft_EncapsulationHeaderType": {
		1: {Name: "GRE"},
		2: {Name: "IPV4"},
		3: {Name: "IPV6"},
		4: {Name: "MPLS"},
	},
	"E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY": {
		1: {Name: "CRITICAL", DefiningModule: "openconfig-alarm-types"},
		2: {Name: "MAJOR", DefiningModule: "openconfig-alarm-types"},
		3: {Name: "MINOR", DefiningModule: "openconfig-alarm-types"},
		4: {Name: "UNKNOWN", DefiningModule: "openconfig-alarm-types"},
		5: {Name: "WARNING", DefiningModule: "openconfig-alarm-types"},
	},
	"E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID": {
		1: {Name: "AIS", DefiningModule: "openconfig-alarm-types"},
		2: {Name: "EQPT", DefiningModule: "openconfig-alarm-types"},
		3: {Name: "LOS", DefiningModule: "openconfig-alarm-types"},
		4: {Name: "OTS", DefiningModule: "openconfig-alarm-types"},
	},
	"E_OpenconfigBfd_BfdDiagnosticCode": {
		1: {Name: "NO_DIAGNOSTIC"},
		2: {Name: "DETECTION_TIMEOUT"},
		3: {Name: "ECHO_FAILED"},
		4: {Name: "FORWARDING_RESET"},
		5: {Name: "PATH_DOWN"},
		6: {Name: "CONCATENATED_PATH_DOWN"},
		7: {Name: "ADMIN_DOWN"},
		8: {Name: "REVERSE_CONCATENATED_PATH_DOWN"},
	},
	"E_OpenconfigBfd_BfdSessionState": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
		3: {Name: "ADMIN_DOWN"},
		4: {Name: "INIT"},
	},
	"E_OpenconfigBgpTypes_AFI_SAFI_TYPE": {
		1:  {Name: "IPV4_FLOWSPEC", DefiningModule: "openconfig-bgp-types"},
		2:  {Name: "IPV4_LABELED_UNICAST", DefiningModule: "openconfig-bgp-types"},
		3:  {Name: "IPV4_UNICAST", DefiningModule: "openconfig-bgp-types"},
		4:  {Name: "IPV6_LABELED_UNICAST", DefiningModule: "openconfig-bgp-types"},
		5:  {Name: "IPV6_UNICAST", DefiningModule: "openconfig-bgp-types"},
		6:  {Name: "L2VPN_EVPN", DefiningModule: "openconfig-bgp-types"},
		7:  {Name: "L2VPN_VPLS", DefiningModule: "openconfig-bgp-types"},
		8:  {Name: "L3VPN_IPV4_MULTICAST", DefiningModule: "openconfig-bgp-types"},
		9:  {Name: "L3VPN_IPV4_UNICAST", DefiningModule: "openconfig-bgp-types"},
		10: {Name: "L3VPN_IPV6_MULTICAST", DefiningModule: "openconfig-bgp-types"},
		11: {Name: "L3VPN_IPV6_UNICAST", DefiningModule: "openconfig-bgp-types"},
		12: {Name: "LINKSTATE", DefiningModule: "openconfig-bgp-types"},
		13: {Name: "LINKSTATE_SPF", DefiningModule: "openconfig-bgp-types"},
		14: {Name: "LINKSTATE_VPN", DefiningModule: "openconfig-bgp-types"},
		15: {Name: "SRTE_POLICY_IPV4", DefiningModule: "openconfig-bgp-types"},
		16: {Name: "SRTE_POLICY_IPV6", DefiningModule: "openconfig-bgp-types"},
		17: {Name: "VPNV4_FLOWSPEC", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_CAPABILITY": {
		1: {Name: "ADD_PATHS", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "ASN32", DefiningModule: "openconfig-bgp-types"},
		3: {Name: "EXTENDED_NEXTHOP_ENCODING", DefiningModule: "openconfig-bgp-types"},
		4: {Name: "GRACEFUL_RESTART", DefiningModule: "openconfig-bgp-types"},
		5: {Name: "MPBGP", DefiningModule: "openconfig-bgp-types"},
		6: {Name: "ROUTE_REFRESH", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_ERROR_CODE": {
		1: {Name: "CEASE", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "FINITE_STATE_MACHINE_ERROR", DefiningModule: "openconfig-bgp-types"},
		3: {Name: "HOLD_TIMER_EXPIRED", DefiningModule: "openconfig-bgp-types"},
		4: {Name: "MESSAGE_HEADER_ERROR", DefiningModule: "openconfig-bgp-types"},
		5: {Name: "OPEN_MESSAGE_ERROR", DefiningModule: "openconfig-bgp-types"},
		6: {Name: "ROUTE_REFRESH_MESSAGE_ERROR", DefiningModule: "openconfig-bgp-types"},
		7: {Name: "UPDATE_MESSAGE_ERROR", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE": {
		1:  {Name: "ADMINISTRATIVE_RESET", DefiningModule: "openconfig-bgp-types"},
		2:  {Name: "ADMINISTRATIVE_SHUTDOWN", DefiningModule: "openconfig-bgp-types"},
		3:  {Name: "ATTRIBUTE_FLAGS_ERROR", DefiningModule: "openconfig-bgp-types"},
		4:  {Name: "ATTRIBUTE_LENGTH_ERROR", DefiningModule: "openconfig-bgp-types"},
		5:  {Name: "BAD_BGP_IDENTIFIER", DefiningModule: "openconfig-bgp-types"},
		6:  {Name: "BAD_MESSAGE_LENGTH", DefiningModule: "openconfig-bgp-types"},
		7:  {Name: "BAD_MESSAGE_TYPE", DefiningModule: "openconfig-bgp-types"},
		8:  {Name: "BAD_PEER_AS", DefiningModule: "openconfig-bgp-types"},
		9:  {Name: "CEASE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		10: {Name: "CONNECTION_NOT_SYNCHRONIZED", DefiningModule: "openconfig-bgp-types"},
		11: {Name: "CONNECTION_REJECTED", DefiningModule: "openconfig-bgp-types"},
		12: {Name: "CONN_COLLISION_RESOLUTION", DefiningModule: "openconfig-bgp-types"},
		13: {Name: "FINITE_STATE_MACHINE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		14: {Name: "INVALID_MESSAGE_LENGTH", DefiningModule: "openconfig-bgp-types"},
		15: {Name: "INVALID_NETWORK_FIELD", DefiningModule: "openconfig-bgp-types"},
		16: {Name: "INVALID_NEXT_HOP_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		17: {Name: "INVALID_ORIGIN_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		18: {Name: "MALFORMED_AS_PATH", DefiningModule: "openconfig-bgp-types"},
		19: {Name: "MALFORMED_ATTRIBUTE_LIST", DefiningModule: "openconfig-bgp-types"},
		20: {Name: "MAX_NUM_PREFIXES_REACHED", DefiningModule: "openconfig-bgp-types"},
		21: {Name: "MESSAGE_HEADER_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		22: {Name: "MISSING_WELL_KNOWN_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		23: {Name: "OPEN_MESSAGE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		24: {Name: "OPTIONAL_ATTRIBUTE_ERROR", DefiningModule: "openconfig-bgp-types"},
		25: {Name: "OTHER_CONFIG_CHANGE", DefiningModule: "openconfig-bgp-types"},
		26: {Name: "OUT_OF_RESOURCES", DefiningModule: "openconfig-bgp-types"},
		27: {Name: "PEER_DE_CONFIGURED", DefiningModule: "openconfig-bgp-types"},
		28: {Name: "RECEIVE_UNEXPECTED_MESSAGE_ESTABLISHED", DefiningModule: "openconfig-bgp-types"},
		29: {Name: "RECEIVE_UNEXPECTED_MESSAGE_OPENCONFIRM", DefiningModule: "openconfig-bgp-types"},
		30: {Name: "RECEIVE_UNEXPECTED_MESSAGE_OPENSENT", DefiningModule: "openconfig-bgp-types"},
		31: {Name: "ROUTE_REFRESH_SUBCODE", DefiningModule: "openconfig-bgp-types"},
		32: {Name: "UNACCEPTABLE_HOLD_TIME", DefiningModule: "openconfig-bgp-types"},
		33: {Name: "UNRECOGNIZED_WELL_KNOWN_ATTRIBUTE", DefiningModule: "openconfig-bgp-types"},
		34: {Name: "UNSPECIFIC", DefiningModule: "openconfig-bgp-types"},
		35: {Name: "UNSUPPORTED_CAPABILITY", DefiningModule: "openconfig-bgp-types"},
		36: {Name: "UNSUPPORTED_OPTIONAL_PARAMETER", DefiningModule: "openconfig-bgp-types"},
		37: {Name: "UNSUPPORTED_VERSION_NUMBER", DefiningModule: "openconfig-bgp-types"},
		38: {Name: "UPDATE_MESSAGE_SUBCODE", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY": {
		1: {Name: "NOPEER", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "NO_ADVERTISE", DefiningModule: "openconfig-bgp-types"},
		3: {Name: "NO_EXPORT", DefiningModule: "openconfig-bgp-types"},
		4: {Name: "NO_EXPORT_SUBCONFED", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode": {
		1: {Name: "HELPER_ONLY"},
		2: {Name: "BILATERAL"},
		3: {Name: "REMOTE_HELPER"},
	},
	"E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState": {
		1: {Name: "IDLE"},
		2: {Name: "CONNECT"},
		3: {Name: "ACTIVE"},
		4: {Name: "OPENSENT"},
		5: {Name: "OPENCONFIRM"},
		6: {Name: "ESTABLISHED"},
	},
	"E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type": {
		2: {Name: "MPLS_SID"},
		3: {Name: "IPV6_SID"},
		4: {Name: "IPV4_NODE_ADDRESS"},
		5: {Name: "IPV6_NODE_ADDRESS"},
		6: {Name: "IPV4_LOCAL_INTF_ID"},
		7: {Name: "IPV4_LOCAL_REMOTE_ADDR"},
		8: {Name: "IPV6_LOCAL_INTF_ID"},
		9: {Name: "IPV6_LOCAL_REMOTE_ADDR"},
	},
	"E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigBgp_CommunityType": {
		1: {Name: "STANDARD"},
		2: {Name: "EXTENDED"},
		3: {Name: "BOTH"},
		4: {Name: "NONE"},
	},
	"E_OpenconfigBgp_PeerType": {
		1: {Name: "INTERNAL"},
		2: {Name: "EXTERNAL"},
	},
	"E_OpenconfigBgp_RemovePrivateAsOption": {
		1: {Name: "PRIVATE_AS_REMOVE_ALL", DefiningModule: "openconfig-bgp-types"},
		2: {Name: "PRIVATE_AS_REPLACE_ALL", DefiningModule: "openconfig-bgp-types"},
	},
	"E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE": {
		1:  {Name: "IP_REACHABILITY_IPV4_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		2:  {Name: "IP_REACHABILITY_IPV6_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		3:  {Name: "IP_REACHABILITY_PREFIX_FLAGS", DefiningModule: "openconfig-isis-lsdb-types"},
		4:  {Name: "IP_REACHABILITY_PREFIX_SID", DefiningModule: "openconfig-isis-lsdb-types"},
		5:  {Name: "IP_REACHABILITY_SUBTLVS_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
		6:  {Name: "IP_REACHABILITY_TAG", DefiningModule: "openconfig-isis-lsdb-types"},
		7:  {Name: "IP_REACHABILITY_TAG64", DefiningModule: "openconfig-isis-lsdb-types"},
		8:  {Name: "IS_REACHABILITY_ADJ_LAN_SID", DefiningModule: "openconfig-isis-lsdb-types"},
		9:  {Name: "IS_REACHABILITY_ADJ_SID", DefiningModule: "openconfig-isis-lsdb-types"},
		10: {Name: "IS_REACHABILITY_ADMIN_GROUP", DefiningModule: "openconfig-isis-lsdb-types"},
		11: {Name: "IS_REACHABILITY_AVAILABLE_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		12: {Name: "IS_REACHABILITY_BANDWIDTH_CONSTRAINTS", DefiningModule: "openconfig-isis-lsdb-types"},
		13: {Name: "IS_REACHABILITY_EXTENDED_ADMIN_GROUP", DefiningModule: "openconfig-isis-lsdb-types"},
		14: {Name: "IS_REACHABILITY_IPV4_INTERFACE_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		15: {Name: "IS_REACHABILITY_IPV4_NEIGHBOR_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		16: {Name: "IS_REACHABILITY_IPV6_INTERFACE_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		17: {Name: "IS_REACHABILITY_IPV6_NEIGHBOR_ADDRESS", DefiningModule: "openconfig-isis-lsdb-types"},
		18: {Name: "IS_REACHABILITY_LINK_ATTRIBUTES", DefiningModule: "openconfig-isis-lsdb-types"},
		19: {Name: "IS_REACHABILITY_LINK_DELAY", DefiningModule: "openconfig-isis-lsdb-types"},
		20: {Name: "IS_REACHABILITY_LINK_DELAY_VARIATION", DefiningModule: "openconfig-isis-lsdb-types"},
		21: {Name: "IS_REACHABILITY_LINK_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		22: {Name: "IS_REACHABILITY_LINK_LOSS", DefiningModule: "openconfig-isis-lsdb-types"},
		23: {Name: "IS_REACHABILITY_LINK_PROTECTION_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
		24: {Name: "IS_REACHABILITY_MAX_LINK_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		25: {Name: "IS_REACHABILITY_MAX_RESERVABLE_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		26: {Name: "IS_REACHABILITY_MIN_MAX_LINK_DELAY", DefiningModule: "openconfig-isis-lsdb-types"},
		27: {Name: "IS_REACHABILITY_RESIDUAL_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		28: {Name: "IS_REACHABILITY_SUBTLVS_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
		29: {Name: "IS_REACHABILITY_TE_DEFAULT_METRIC", DefiningModule: "openconfig-isis-lsdb-types"},
		30: {Name: "IS_REACHABILITY_UNCONSTRAINED_LSP", DefiningModule: "openconfig-isis-lsdb-types"},
		31: {Name: "IS_REACHABILITY_UNRESERVED_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		32: {Name: "IS_REACHABILITY_UTILIZED_BANDWIDTH", DefiningModule: "openconfig-isis-lsdb-types"},
		33: {Name: "ROUTER_CAPABILITY_SR_ALGORITHM", DefiningModule: "openconfig-isis-lsdb-types"},
		34: {Name: "ROUTER_CAPABILITY_SR_CAPABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		35: {Name: "ROUTER_CAPABILITY_SUBTLVS_TYPE", DefiningModule: "openconfig-isis-lsdb-types"},
	},
	"E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE": {
		1:  {Name: "AREA_ADDRESSES", DefiningModule: "openconfig-isis-lsdb-types"},
		2:  {Name: "AUTHENTICATION", DefiningModule: "openconfig-isis-lsdb-types"},
		3:  {Name: "DYNAMIC_NAME", DefiningModule: "openconfig-isis-lsdb-types"},
		4:  {Name: "EXTENDED_IPV4_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		5:  {Name: "EXTENDED_IS_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		6:  {Name: "IIS_NEIGHBORS", DefiningModule: "openconfig-isis-lsdb-types"},
		7:  {Name: "INSTANCE_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		8:  {Name: "IPV4_EXTERNAL_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		9:  {Name: "IPV4_INTERFACE_ADDRESSES", DefiningModule: "openconfig-isis-lsdb-types"},
		10: {Name: "IPV4_INTERNAL_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		11: {Name: "IPV4_SRLG", DefiningModule: "openconfig-isis-lsdb-types"},
		12: {Name: "IPV4_TE_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		13: {Name: "IPV6_INTERFACE_ADDRESSES", DefiningModule: "openconfig-isis-lsdb-types"},
		14: {Name: "IPV6_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		15: {Name: "IPV6_SRLG", DefiningModule: "openconfig-isis-lsdb-types"},
		16: {Name: "IPV6_TE_ROUTER_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		17: {Name: "ISIS_ALIAS_ID", DefiningModule: "openconfig-isis-lsdb-types"},
		18: {Name: "IS_NEIGHBOR_ATTRIBUTE", DefiningModule: "openconfig-isis-lsdb-types"},
		19: {Name: "LSP_BUFFER_SIZE", DefiningModule: "openconfig-isis-lsdb-types"},
		20: {Name: "MT_IPV4_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		21: {Name: "MT_IPV6_REACHABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
		22: {Name: "MT_ISN", DefiningModule: "openconfig-isis-lsdb-types"},
		23: {Name: "MT_IS_NEIGHBOR_ATTRIBUTE", DefiningModule: "openconfig-isis-lsdb-types"},
		24: {Name: "MULTI_TOPOLOGY", DefiningModule: "openconfig-isis-lsdb-types"},
		25: {Name: "NLPID", DefiningModule: "openconfig-isis-lsdb-types"},
		26: {Name: "PURGE_OI", DefiningModule: "openconfig-isis-lsdb-types"},
		27: {Name: "ROUTER_CAPABILITY", DefiningModule: "openconfig-isis-lsdb-types"},
	},
	"E_OpenconfigIsisTypes_AFI_SAFI_TYPE": {
		1: {Name: "IPV4_MULTICAST", DefiningModule: "openconfig-isis-types"},
		2: {Name: "IPV4_UNICAST", DefiningModule: "openconfig-isis-types"},
		3: {Name: "IPV6_MULTICAST", DefiningModule: "openconfig-isis-types"},
		4: {Name: "IPV6_UNICAST", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsisTypes_AFI_TYPE": {
		1: {Name: "IPV4", DefiningModule: "openconfig-isis-types"},
		2: {Name: "IPV6", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE": {
		1: {Name: "WAIT_FOR_BGP", DefiningModule: "openconfig-isis-types"},
		2: {Name: "WAIT_FOR_SYSTEM", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsisTypes_SAFI_TYPE": {
		1: {Name: "MULTICAST", DefiningModule: "openconfig-isis-types"},
		2: {Name: "UNICAST", DefiningModule: "openconfig-isis-types"},
	},
	"E_OpenconfigIsis_AdaptiveTimerType": {
		1: {Name: "LINEAR"},
		2: {Name: "EXPONENTIAL"},
	},
	"E_OpenconfigIsis_CircuitType": {
		1: {Name: "POINT_TO_POINT"},
		2: {Name: "BROADCAST"},
	},
	"E_OpenconfigIsis_HelloPaddingType": {
		1: {Name: "STRICT"},
		2: {Name: "LOOSE"},
		3: {Name: "ADAPTIVE"},
		4: {Name: "DISABLE"},
	},
	"E_OpenconfigIsis_IsisInterfaceAdjState": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
		3: {Name: "INIT"},
		4: {Name: "FAILED"},
	},
	"E_OpenconfigIsis_IsisMetricFlags": {
		1: {Name: "INTERNAL"},
		2: {Name: "UNSUPPORTED"},
	},
	"E_OpenconfigIsis_LevelType": {
		1: {Name: "LEVEL_1"},
		2: {Name: "LEVEL_2"},
		3: {Name: "LEVEL_1_2"},
	},
	"E_OpenconfigIsis_MetricStyle": {
		1: {Name: "NARROW_METRIC"},
		2: {Name: "WIDE_METRIC"},
	},
	"E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP": {
		1: {Name: "DROP", DefiningModule: "openconfig-local-routing"},
		2: {Name: "LOCAL_LINK", DefiningModule: "openconfig-local-routing"},
	},
	"E_OpenconfigMessages_DEBUG_SERVICE": {},
	"E_OpenconfigMessages_SyslogSeverity": {
		1: {Name: "EMERGENCY"},
		2: {Name: "ALERT"},
		3: {Name: "CRITICAL"},
		4: {Name: "ERROR"},
		5: {Name: "WARNING"},
		6: {Name: "NOTICE"},
		7: {Name: "INFORMATIONAL"},
		8: {Name: "DEBUG"},
	},
	"E_OpenconfigMplsLdp_MplsLdpAdjacencyType": {
		1: {Name: "LINK"},
		2: {Name: "TARGETED"},
	},
	"E_OpenconfigMplsLdp_MplsLdpAfi": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
	},
	"E_OpenconfigMplsTypes_LSP_METRIC_TYPE": {
		1: {Name: "LSP_METRIC_ABSOLUTE", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "LSP_METRIC_INHERITED", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "LSP_METRIC_RELATIVE", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_LSP_OPER_STATUS": {
		1: {Name: "DOWN", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "UP", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_LSP_ROLE": {
		1: {Name: "EGRESS", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "INGRESS", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "TRANSIT", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_NULL_LABEL_TYPE": {
		1: {Name: "EXPLICIT", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "IMPLICIT", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD": {
		1: {Name: "EXPLICITLY_DEFINED", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "EXTERNALLY_QUERIED", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "LOCALLY_COMPUTED", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL": {
		1: {Name: "PATH_SETUP_LDP", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "PATH_SETUP_RSVP", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "PATH_SETUP_SR", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PROTECTION_TYPE": {
		1: {Name: "LINK_NODE_PROTECTION_REQUESTED", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "LINK_PROTECTION_REQUIRED", DefiningModule: "openconfig-mpls-types"},
		3: {Name: "UNPROTECTED", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION": {
		1: {Name: "PWE_ETHERNET_RAW_MODE", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "PWE_ETHERNET_TAGGED_MODE", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS": {
		1: {Name: "ADMIN_DOWN", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "ADMIN_UP", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMplsTypes_TUNNEL_TYPE": {
		1: {Name: "P2MP", DefiningModule: "openconfig-mpls-types"},
		2: {Name: "P2P", DefiningModule: "openconfig-mpls-types"},
	},
	"E_OpenconfigMpls_CspfTieBreaking": {
		1: {Name: "RANDOM"},
		2: {Name: "LEAST_FILL"},
		3: {Name: "MOST_FILL"},
	},
	"E_OpenconfigMpls_MplsHopType": {
		1: {Name: "LOOSE"},
		2: {Name: "STRICT"},
	},
	"E_OpenconfigMpls_MplsSrlgFloodingType": {
		1: {Name: "FLOODED_SRLG"},
		2: {Name: "STATIC_SRLG"},
	},
	"E_OpenconfigMpls_TeBandwidthType": {
		1: {Name: "SPECIFIED"},
		2: {Name: "AUTO"},
	},
	"E_OpenconfigNetworkInstanceTypes_ENCAPSULATION": {
		1: {Name: "MPLS", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "VXLAN", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE": {
		1: {Name: "LOCAL", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "REMOTE", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE": {
		1: {Name: "INSTANCE_LABEL", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "PER_NEXTHOP", DefiningModule: "openconfig-network-instance-types"},
		3: {Name: "PER_PREFIX", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE": {
		1: {Name: "DEFAULT_INSTANCE", DefiningModule: "openconfig-network-instance-types"},
		2: {Name: "L2L3", DefiningModule: "openconfig-network-instance-types"},
		3: {Name: "L2P2P", DefiningModule: "openconfig-network-instance-types"},
		4: {Name: "L2VSI", DefiningModule: "openconfig-network-instance-types"},
		5: {Name: "L3VRF", DefiningModule: "openconfig-network-instance-types"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType": {
		1: {Name: "STATIC"},
		2: {Name: "DYNAMIC"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode": {
		1: {Name: "ADJ_SID_ONLY"},
		2: {Name: "MIXED_MODE"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState": {
		1: {Name: "NON_EXISTENT"},
		2: {Name: "INITIALIZED"},
		3: {Name: "OPENREC"},
		4: {Name: "OPENSENT"},
		5: {Name: "OPERATIONAL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority": {
		1: {Name: "ALL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
		3: {Name: "ASN"},
		4: {Name: "ASN4"},
		5: {Name: "LABEL"},
		6: {Name: "UNNUMBERED_INTERFACE"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status": {
		1: {Name: "UP"},
		2: {Name: "DOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification": {
		1: {Name: "MIRRORED_UP_DOWN"},
		2: {Name: "SEPARATE_UP_DOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType": {
		1: {Name: "DELTA"},
		2: {Name: "THRESHOLD_CROSSED"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions": {
		1: {Name: "NO_PHP"},
		2: {Name: "EXPLICIT_NULL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags": {
		1: {Name: "PARTITION_REPAIR"},
		2: {Name: "ATTACHED_ERROR"},
		3: {Name: "ATTACHED_EXPENSE"},
		4: {Name: "ATTACHED_DELAY"},
		5: {Name: "ATTACHED_DEFAULT"},
		6: {Name: "OVERLOAD"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType": {
		1: {Name: "LEVEL_1"},
		2: {Name: "LEVEL_2"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType": {
		1: {Name: "HMAC_MD5"},
		2: {Name: "CLEARTEXT"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags": {
		1: {Name: "EXTERNAL_FLAG"},
		2: {Name: "READVERTISEMENT_FLAG"},
		3: {Name: "NODE_FLAG"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags": {
		1: {Name: "READVERTISEMENT"},
		2: {Name: "NODE"},
		3: {Name: "NO_PHP"},
		4: {Name: "EXPLICIT_NULL"},
		5: {Name: "VALUE"},
		6: {Name: "LOCAL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags": {
		1: {Name: "ADDRESS_FAMILY"},
		2: {Name: "BACKUP"},
		3: {Name: "VALUE"},
		4: {Name: "LOCAL"},
		5: {Name: "SET"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags": {
		1: {Name: "ADDRESS_FAMILY"},
		2: {Name: "BACKUP"},
		3: {Name: "VALUE"},
		4: {Name: "LOCAL"},
		5: {Name: "SET"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection": {
		1: {Name: "LOCAL_PROTECTION"},
		2: {Name: "LINK_EXCLUDED"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type": {
		1: {Name: "EXTRA_TRAFFIC"},
		2: {Name: "UNPROTECTED"},
		3: {Name: "SHARED"},
		4: {Name: "ONE_ONE"},
		5: {Name: "PLUS_ONE"},
		6: {Name: "ENHANCED"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags": {
		1: {Name: "INTERNAL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags": {
		1: {Name: "NUMBERED"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags": {
		1: {Name: "NA"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes": {
		1: {Name: "OVERLOAD"},
		2: {Name: "ATTACHED"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags": {
		1: {Name: "FLOOD"},
		2: {Name: "DOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm": {
		1: {Name: "SPF"},
		2: {Name: "STRICT_SPF"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags": {
		1: {Name: "IPV4_MPLS"},
		2: {Name: "IPV6_MPLS"},
		3: {Name: "IPV6_SR"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType": {
		1: {Name: "TYPE_1"},
		2: {Name: "TYPE_2"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily": {
		1: {Name: "IPV4_UNICAST"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType": {
		1: {Name: "UNSPECIFIED"},
		2: {Name: "INTRA_AREA"},
		4: {Name: "INTER_AREA"},
		6: {Name: "AS_EXTERNAL"},
		8: {Name: "NSSA_EXTERNAL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope": {
		1: {Name: "LOCAL"},
		2: {Name: "GLOBAL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType": {
		1: {Name: "ABSOLUTE"},
		2: {Name: "INDEX"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason": {
		1: {Name: "UNKNOWN"},
		2: {Name: "SOFTWARE_RESTART"},
		3: {Name: "SOFTWARE_RELOAD_UPGRADE"},
		4: {Name: "CONTROL_PROCESSOR_SWITCH"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type": {
		1: {Name: "UNKNOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type": {
		1: {Name: "UNKNOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope": {
		1: {Name: "LINK"},
		2: {Name: "AREA"},
		3: {Name: "AS"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType": {
		1: {Name: "POINT_TO_POINT"},
		2: {Name: "MULTI_ACCESS"},
		3: {Name: "UNKNOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type": {
		1: {Name: "UNKNOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type": {
		1: {Name: "UNKNOWN"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode": {
		1: {Name: "RFC1583_COMPATIBLE"},
		2: {Name: "RFC2328_COMPATIBLE"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType": {
		1: {Name: "LINEAR_BACKOFF"},
		2: {Name: "EXPONENTIAL_BACKOFF"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid": {
		1: {Name: "IPV4_EXPLICIT_NULL"},
		2: {Name: "ROUTER_ALERT"},
		3: {Name: "IPV6_EXPLICIT_NULL"},
		4: {Name: "IMPLICIT_NULL"},
		8: {Name: "ENTROPY_LABEL_INDICATOR"},
		9: {Name: "NO_LABEL"},
	},
	"E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status": {
		1: {Name: "ACTIVE"},
		2: {Name: "SUSPENDED"},
	},
	"E_OpenconfigOpenflow_FailureMode": {
		1: {Name: "SECURE"},
		2: {Name: "STANDALONE"},
	},
	"E_OpenconfigOpenflow_Transport": {
		1: {Name: "TCP"},
		2: {Name: "TLS"},
	},
	"E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES": {
		1: {Name: "GRACE_IP_INTERFACE_ADDRESS", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "GRACE_PERIOD", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "GRACE_RESTART_REASON", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE": {
		1: {Name: "MAX_METRIC_INCLUDE_STUB", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "MAX_METRIC_INCLUDE_TYPE2_EXTERNAL", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER": {
		1: {Name: "MAX_METRIC_ON_SYSTEM_BOOT", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE": {
		1: {Name: "ADJACENCY_SID", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE": {
		1: {Name: "ERO_METRIC", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "ERO_PATH", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "SID_MPLS_LABEL_BINDING", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE": {
		1: {Name: "EXTENDED_PREFIX_RANGE", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "PREFIX_SID", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "SID_LABEL_BINDING", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE": {
		1: {Name: "IPV4_SEGMENT", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "UNNUMBERED_INTERFACE_SEGMENT", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE": {
		1: {Name: "POINT_TO_POINT_LINK", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "STUB_NETWORK_LINK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "TRANSIT_NETWORK_LINK", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "VIRTUAL_LINK", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_LSA_TYPE": {
		1: {Name: "AS_EXTERNAL_LSA", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "NETWORK_LSA", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "NSSA_AS_EXTERNAL_LSA", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "OSPFV2_AREA_SCOPE_OPAQUE_LSA", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "OSPFV2_AS_SCOPE_OPAQUE_LSA", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "OSPFV2_LINK_SCOPE_OPAQUE_LSA", DefiningModule: "openconfig-ospf-types"},
		7: {Name: "ROUTER_LSA", DefiningModule: "openconfig-ospf-types"},
		8: {Name: "SUMMARY_ASBR_LSA", DefiningModule: "openconfig-ospf-types"},
		9: {Name: "SUMMARY_IP_NETWORK_LSA", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE": {
		1: {Name: "ATTEMPT", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "DOWN", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "EXCHANGE", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "EXSTART", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "FULL", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "INIT", DefiningModule: "openconfig-ospf-types"},
		7: {Name: "LOADING", DefiningModule: "openconfig-ospf-types"},
		8: {Name: "TWO_WAY", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE": {
		1: {Name: "BROADCAST_NETWORK", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "NON_BROADCAST_NETWORK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "POINT_TO_POINT_NETWORK", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE": {
		1: {Name: "GRACE_LSA", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "OSPFV2_EXTENDED_LINK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "OSPFV2_EXTENDED_PREFIX", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "ROUTER_INFORMATION", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "TRAFFIC_ENGINEERING", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES": {
		1: {Name: "SR_SID_LABEL_TLV", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE": {
		1: {Name: "TE_LINK_ADMIN_GROUP", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "TE_LINK_ID", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "TE_LINK_LOCAL_IP", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "TE_LINK_MAXIMUM_BANDWIDTH", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "TE_LINK_MAXIMUM_RESERVABLE_BANDWIDTH", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "TE_LINK_METRIC", DefiningModule: "openconfig-ospf-types"},
		7: {Name: "TE_LINK_REMOTE_IP", DefiningModule: "openconfig-ospf-types"},
		8: {Name: "TE_LINK_TYPE", DefiningModule: "openconfig-ospf-types"},
		9: {Name: "TE_LINK_UNRESERVED_BANDWIDTH", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE": {
		1: {Name: "TE_LINK", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "TE_LINK_LOCAL", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "TE_NODE_ATTRIBUTE", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "TE_OPTICAL_NODE_PROPERTY", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "TE_ROUTER_ADDRESS", DefiningModule: "openconfig-ospf-types"},
		6: {Name: "TE_ROUTER_IPV6_ADDRESS", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES": {
		1: {Name: "RI_FUNCTIONAL_CAPABILITIES", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "RI_INFORMATIONAL_CAPABILITIES", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "RI_NODE_ADMIN_TAG", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "RI_SR_ALGORITHM", DefiningModule: "openconfig-ospf-types"},
		5: {Name: "RI_SR_SID_LABEL_RANGE", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_ROUTER_LSA_TYPES": {
		1: {Name: "ROUTER_LSA_P2P", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "ROUTER_LSA_STUB_NETWORK", DefiningModule: "openconfig-ospf-types"},
		3: {Name: "ROUTER_LSA_TRANSIT_NETWORK", DefiningModule: "openconfig-ospf-types"},
		4: {Name: "ROUTER_LSA_VIRTUAL_LINK", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_SR_ALGORITHM": {
		1: {Name: "SPF", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "STRICT_SPF", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE": {
		1: {Name: "NODE_IPV4_LOCAL_ADDRESS", DefiningModule: "openconfig-ospf-types"},
		2: {Name: "NODE_IPV6_LOCAL_ADDRESS", DefiningModule: "openconfig-ospf-types"},
	},
	"E_OpenconfigOspfv2_SrSidType": {
		1: {Name: "LABEL"},
		2: {Name: "SID"},
	},
	"E_OpenconfigPacketMatchTypes_ETHERTYPE": {
		1: {Name: "ETHERTYPE_ARP", DefiningModule: "openconfig-packet-match-types"},
		2: {Name: "ETHERTYPE_IPV4", DefiningModule: "openconfig-packet-match-types"},
		3: {Name: "ETHERTYPE_IPV6", DefiningModule: "openconfig-packet-match-types"},
		4: {Name: "ETHERTYPE_LLDP", DefiningModule: "openconfig-packet-match-types"},
		5: {Name: "ETHERTYPE_MPLS", DefiningModule: "openconfig-packet-match-types"},
		6: {Name: "ETHERTYPE_ROCE", DefiningModule: "openconfig-packet-match-types"},
		7: {Name: "ETHERTYPE_VLAN", DefiningModule: "openconfig-packet-match-types"},
	},
	"E_OpenconfigPacketMatchTypes_IP_PROTOCOL": {
		1: {Name: "IP_AUTH", DefiningModule: "openconfig-packet-match-types"},
		2: {Name: "IP_GRE", DefiningModule: "openconfig-packet-match-types"},
		3: {Name: "IP_ICMP", DefiningModule: "openconfig-packet-match-types"},
		4: {Name: "IP_IGMP", DefiningModule: "openconfig-packet-match-types"},
		5: {Name: "IP_L2TP", DefiningModule: "openconfig-packet-match-types"},
		6: {Name: "IP_PIM", DefiningModule: "openconfig-packet-match-types"},
		7: {Name: "IP_RSVP", DefiningModule: "openconfig-packet-match-types"},
		8: {Name: "IP_TCP", DefiningModule: "openconfig-packet-match-types"},
		9: {Name: "IP_UDP", DefiningModule: "openconfig-packet-match-types"},
	},
	"E_OpenconfigPacketMatchTypes_TCP_FLAGS": {
		1: {Name: "TCP_ACK", DefiningModule: "openconfig-packet-match-types"},
		2: {Name: "TCP_CWR", DefiningModule: "openconfig-packet-match-types"},
		3: {Name: "TCP_ECE", DefiningModule: "openconfig-packet-match-types"},
		4: {Name: "TCP_FIN", DefiningModule: "openconfig-packet-match-types"},
		5: {Name: "TCP_PSH", DefiningModule: "openconfig-packet-match-types"},
		6: {Name: "TCP_RST", DefiningModule: "openconfig-packet-match-types"},
		7: {Name: "TCP_SYN", DefiningModule: "openconfig-packet-match-types"},
		8: {Name: "TCP_URG", DefiningModule: "openconfig-packet-match-types"},
	},
	"E_OpenconfigPimTypes_PIM_MODE": {
		1: {Name: "PIM_MODE_DENSE", DefiningModule: "openconfig-pim-types"},
		2: {Name: "PIM_MODE_SPARSE", DefiningModule: "openconfig-pim-types"},
	},
	"E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS": {
		1: {Name: "ACTIVE", DefiningModule: "openconfig-platform-types"},
		2: {Name: "DISABLED", DefiningModule: "openconfig-platform-types"},
		3: {Name: "INACTIVE", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT": {
		1:  {Name: "BACKPLANE", DefiningModule: "openconfig-platform-types"},
		2:  {Name: "CHASSIS", DefiningModule: "openconfig-platform-types"},
		3:  {Name: "CONTROLLER_CARD", DefiningModule: "openconfig-platform-types"},
		4:  {Name: "CPU", DefiningModule: "openconfig-platform-types"},
		5:  {Name: "FABRIC", DefiningModule: "openconfig-platform-types"},
		6:  {Name: "FAN", DefiningModule: "openconfig-platform-types"},
		7:  {Name: "FRU", DefiningModule: "openconfig-platform-types"},
		8:  {Name: "INTEGRATED_CIRCUIT", DefiningModule: "openconfig-platform-types"},
		9:  {Name: "LINECARD", DefiningModule: "openconfig-platform-types"},
		10: {Name: "PORT", DefiningModule: "openconfig-platform-types"},
		11: {Name: "POWER_SUPPLY", DefiningModule: "openconfig-platform-types"},
		12: {Name: "SENSOR", DefiningModule: "openconfig-platform-types"},
		13: {Name: "STORAGE", DefiningModule: "openconfig-platform-types"},
		14: {Name: "TRANSCEIVER", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT": {
		1: {Name: "BOOT_LOADER", DefiningModule: "openconfig-platform-types"},
		2: {Name: "OPERATING_SYSTEM", DefiningModule: "openconfig-platform-types"},
		3: {Name: "OPERATING_SYSTEM_UPDATE", DefiningModule: "openconfig-platform-types"},
		4: {Name: "SOFTWARE_MODULE", DefiningModule: "openconfig-platform-types"},
	},
	"E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE": {
		1: {Name: "BGP", DefiningModule: "openconfig-policy-types"},
		2: {Name: "DIRECTLY_CONNECTED", DefiningModule: "openconfig-policy-types"},
		3: {Name: "IGMP", DefiningModule: "openconfig-policy-types"},
		4: {Name: "ISIS", DefiningModule: "openconfig-policy-types"},
		5: {Name: "LOCAL_AGGREGATE", DefiningModule: "openconfig-policy-types"},
		6: {Name: "OSPF", DefiningModule: "openconfig-policy-types"},
		7: {Name: "OSPF3", DefiningModule: "openconfig-policy-types"},
		8: {Name: "PIM", DefiningModule: "openconfig-policy-types"},
		9: {Name: "STATIC", DefiningModule: "openconfig-policy-types"},
	},
	"E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON": {
		1: {Name: "INVALID_AS_LOOP", DefiningModule: "openconfig-rib-bgp-types"},
		2: {Name: "INVALID_CLUSTER_LOOP", DefiningModule: "openconfig-rib-bgp-types"},
		3: {Name: "INVALID_CONFED", DefiningModule: "openconfig-rib-bgp-types"},
		4: {Name: "INVALID_ORIGINATOR", DefiningModule: "openconfig-rib-bgp-types"},
	},
	"E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE": {
		1: {Name: "SRTE_BINDING_SID", DefiningModule: "openconfig-rib-bgp-types"},
		2: {Name: "SRTE_PREFERENCE", DefiningModule: "openconfig-rib-bgp-types"},
		3: {Name: "SRTE_SEGMENT_LIST", DefiningModule: "openconfig-rib-bgp-types"},
		4: {Name: "TUNNEL_COLOR", DefiningModule: "openconfig-rib-bgp-types"},
		5: {Name: "TUNNEL_REMOTE_ENDPOINT", DefiningModule: "openconfig-rib-bgp-types"},
	},
	"E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE": {
		1: {Name: "SRTE_POLICY_TUNNEL", DefiningModule: "openconfig-rib-bgp-types"},
	},
	"E_OpenconfigRibBgp_AsPathSegmentType": {
		1: {Name: "AS_SEQ"},
		2: {Name: "AS_SET"},
		3: {Name: "AS_CONFED_SEQUENCE"},
		4: {Name: "AS_CONFED_SET"},
	},
	"E_OpenconfigRibBgp_BgpOriginAttrType": {
		1: {Name: "IGP"},
		2: {Name: "EGP"},
		3: {Name: "INCOMPLETE"},
	},
	"E_OpenconfigRoutingPolicy_DefaultPolicyType": {
		1: {Name: "ACCEPT_ROUTE"},
		2: {Name: "REJECT_ROUTE"},
	},
	"E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType": {
		1: {Name: "ANY"},
		2: {Name: "INVERT"},
	},
	"E_OpenconfigRoutingPolicy_PolicyResultType": {
		1: {Name: "ACCEPT_ROUTE"},
		2: {Name: "REJECT_ROUTE"},
	},
	"E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode": {
		1: {Name: "IPV4"},
		2: {Name: "IPV6"},
		3: {Name: "MIXED"},
	},
	"E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode": {
		1: {Name: "INLINE"},
		2: {Name: "REFERENCE"},
	},
	"E_OpenconfigSegmentRouting_SrDataplaneType": {
		1: {Name: "MPLS"},
		2: {Name: "IPV6"},
	},
	"E_OpenconfigSrtePolicy_EnlpType": {
		1: {Name: "PUSH_IPV4_EXPLICIT_NULL"},
		2: {Name: "PUSH_IPV6_EXPLICIT_NULL"},
		3: {Name: "PUSH_IPV46_EXPLICIT_NULL"},
		4: {Name: "NO_EXPLICIT_NULL"},
	},
	"E_OpenconfigSrtePolicy_SrteInvalidSlReason": {
		1: {Name: "EMPTY_SL"},
		2: {Name: "ZERO_WEIGHT"},
		3: {Name: "FIRST_SID_UNRESOLVABLE"},
		4: {Name: "OTHER_SID_UNRESOLVABLE"},
		5: {Name: "VERIFICATION_FAIL"},
	},
	"E_OpenconfigSrtePolicy_SrteProtocolType": {
		11: {Name: "PCEP"},
		21: {Name: "BGP"},
		31: {Name: "CONFIG"},
	},
	"E_OpenconfigSystemLogging_SYSLOG_FACILITY": {
		1:  {Name: "ALL", DefiningModule: "openconfig-system-logging"},
		2:  {Name: "AUDIT", DefiningModule: "openconfig-system-logging"},
		3:  {Name: "AUTH", DefiningModule: "openconfig-system-logging"},
		4:  {Name: "AUTHPRIV", DefiningModule: "openconfig-system-logging"},
		5:  {Name: "CONSOLE", DefiningModule: "openconfig-system-logging"},
		6:  {Name: "KERNEL", DefiningModule: "openconfig-system-logging"},
		7:  {Name: "LOCAL0", DefiningModule: "openconfig-system-logging"},
		8:  {Name: "LOCAL1", DefiningModule: "openconfig-system-logging"},
		9:  {Name: "LOCAL2", DefiningModule: "openconfig-system-logging"},
		10: {Name: "LOCAL3", DefiningModule: "openconfig-system-logging"},
		11: {Name: "LOCAL4", DefiningModule: "openconfig-system-logging"},
		12: {Name: "LOCAL5", DefiningModule: "openconfig-system-logging"},
		13: {Name: "LOCAL6", DefiningModule: "openconfig-system-logging"},
		14: {Name: "LOCAL7", DefiningModule: "openconfig-system-logging"},
		15: {Name: "MAIL", DefiningModule: "openconfig-system-logging"},
		16: {Name: "NTP", DefiningModule: "openconfig-system-logging"},
		17: {Name: "SYSLOG", DefiningModule: "openconfig-system-logging"},
		18: {Name: "SYSTEM_DAEMON", DefiningModule: "openconfig-system-logging"},
		19: {Name: "USER", DefiningModule: "openconfig-system-logging"},
	},
	"E_OpenconfigSystemLogging_SyslogSeverity": {
		1: {Name: "EMERGENCY"},
		2: {Name: "ALERT"},
		3: {Name: "CRITICAL"},
		4: {Name: "ERROR"},
		5: {Name: "WARNING"},
		6: {Name: "NOTICE"},
		7: {Name: "INFORMATIONAL"},
		8: {Name: "DEBUG"},
	},
	"E_OpenconfigSystem_NTP_AUTH_TYPE": {
		1: {Name: "NTP_AUTH_MD5", DefiningModule: "openconfig-system"},
	},
	"E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record": {
		1: {Name: "START_STOP"},
		2: {Name: "STOP"},
	},
	"E_OpenconfigSystem_System_Cpus_Cpu_State_Index": {
		1: {Name: "ALL"},
	},
	"E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses": {
		1: {Name: "ANY"},
	},
	"E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType": {
		1: {Name: "SERVER"},
		2: {Name: "PEER"},
		3: {Name: "POOL"},
	},
	"E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion": {
		1: {Name: "V2"},
		2: {Name: "V1"},
		3: {Name: "V1_V2"},
	},
	"E_OpenconfigTypes_ADDRESS_FAMILY": {
		1: {Name: "IPV4", DefiningModule: "openconfig-types"},
		2: {Name: "IPV6", DefiningModule: "openconfig-types"},
		3: {Name: "L2_ETHERNET", DefiningModule: "openconfig-types"},
		4: {Name: "MPLS", DefiningModule: "openconfig-types"},
	},
}

var (
	// ySchema is a byte slice contain a gzip compressed representation of the
	// YANG schema from which the Go code was generated. When uncompressed the
	// contents of the byte slice is a JSON document containing an object, keyed
	// on the name of the generated struct, and containing the JSON marshalled
	// contents of a goyang yang.Entry struct, which defines the schema for the
	// fields within the struct.
	ySchema = []byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xec, 0xbd, 0x6b, 0x53, 0xdb, 0x48,
		0xfa, 0xfe, 0xff, 0x3c, 0xaf, 0x82, 0x72, 0xed, 0x83, 0xa4, 0x2a, 0x0a, 0x60, 0x8c, 0x09, 0xa9,
		0xfa, 0x3f, 0x20, 0x19, 0x32, 0x5f, 0x7e, 0x4b, 0x02, 0x15, 0x48, 0x76, 0xa7, 0x32, 0x2c, 0x25,
		0x6c, 0x41, 0x54, 0x6b, 0xcb, 0x5e, 0x59, 0x66, 0x42, 0x4d, 0x78, 0xef, 0xff, 0xf2, 0x11, 0x1f,
		0xb1, 0xd4, 0x7d, 0xb7, 0xd4, 0x92, 0x3e, 0xa9, 0xdd, 0x09, 0x01, 0xdc, 0xb6, 0xfa, 0x70, 0xf5,
		0x75, 0x5f, 0xf7, 0xe9, 0xef, 0x17, 0x5b, 0x5b, 0x5b, 0x5b, 0x95, 0xcf, 0x6e, 0xdb, 0xab, 0xbc,
		0xdb, 0xaa, 0x34, 0xbd, 0x7b, 0xbf, 0xe1, 0x55, 0x5e, 0x8f, 0xbe, 0xfb, 0x4f, 0x3f, 0x68, 0x56,
		0xde, 0x6d, 0xed, 0x8e, 0xff, 0xf9, 0xa1, 0x13, 0xdc, 0xfa, 0x77, 0x95, 0x77, 0x5b, 0x3b, 0xe3,
		0x6f, 0xfc, 0xe6, 0x87, 0x95, 0x77, 0x5b, 0xa3, 0x21, 0x86, 0xdf, 0x70, 0x1b, 0xad, 0xb9, 0x6f,
		0xcc, 0x8d, 0x3d, 0xf8, 0xe1, 0xeb, 0xf9, 0x1f, 0xcd, 0xbf, 0xc1, 0xf4, 0xdb, 0x8b, 0x6f, 0x34,
		0xfd, 0xc1, 0x79, 0xe8, 0xdd, 0xfa, 0x3f, 0x97, 0xde, 0x62, 0xee, 0x6d, 0x3a, 0x0d, 0x67, 0xf9,
		0x9d, 0x86, 0xbf, 0x71, 0xd1, 0xe9, 0x87, 0x0d, 0x6f, 0xe5, 0xab, 0x47, 0x9f, 0xc6, 0x7b, 0xf8,
		0xab, 0x13, 0x0e, 0x3e, 0x50, 0xa5, 0x3b, 0x7a, 0xa3, 0xd7, 0xab, 0x7f, 0xf1, 0xff, 0xdc, 0xde,
		0x51, 0x78, 0xd7, 0x6f, 0x7b, 0x41, 0x54, 0x79, 0xb7, 0x15, 0x85, 0x7d, 0x6f, 0xcd, 0x2f, 0xce,
		0xfc, 0xd6, 0xe4, 0x73, 0x2d, 0xfd, 0xe2, 0xe3, 0xdc, 0x77, 0x1e, 0x17, 0x9e, 0x78, 0x71, 0x8a,
		0x67, 0xa7, 0xda, 0xe9, 0x79, 0x51, 0x6f, 0xfd, 0xe3, 0xcc, 0xcc, 0xfb, 0xe8, 0x37, 0xd7, 0x7c,
		0xc8, 0xd5, 0x8b, 0xb0, 0x71, 0x31, 0xe2, 0x2c, 0x4a, 0xfc, 0xc5, 0x89, 0xbb, 0x48, 0x89, 0x17,
		0x2b, 0xf1, 0xa2, 0x25, 0x5a, 0xbc, 0xd5, 0x8b, 0xb8, 0x66, 0x31, 0x37, 0x2e, 0xea, 0xe2, 0xe2,
		0x6e, 0x9e, 0x85, 0x85, 0x35, 0xde, 0x34, 0x07, 0xcf, 0x2f, 0x75, 0xec, 0x25, 0x4f, 0xb2, 0xf4,
		0xc9, 0xb7, 0x40, 0xd2, 0xad, 0xa0, 0xbc, 0x25, 0x94, 0xb7, 0x86, 0xd2, 0x16, 0x79, 0x7e, 0xab,
		0x6c, 0xd8, 0x32, 0xb1, 0xb7, 0xce, 0xdc, 0x16, 0xf2, 0x82, 0x28, 0xf4, 0xbd, 0x5e, 0xfc, 0x19,
		0x9c, 0xdd, 0x4e, 0x93, 0x17, 0xc7, 0x9c, 0x8a, 0x78, 0x5b, 0x2b, 0xf1, 0x16, 0x53, 0xd9, 0x6a,
		0xea, 0x5b, 0x4e, 0x75, 0xeb, 0x69, 0x6f, 0x41, 0xed, 0xad, 0xa8, 0xb5, 0x25, 0xe3, 0x6d, 0xcd,
		0x98, 0x5b, 0x34, 0xf1, 0x56, 0x5d, 0xda, 0xb2, 0x0f, 0xc9, 0xe7, 0x7d, 0x71, 0xe3, 0x3e, 0x24,
		0x9d, 0xf7, 0x64, 0xdb, 0x57, 0x79, 0x1b, 0xeb, 0x6c, 0x67, 0xfd, 0x6d, 0xad, 0xbb, 0xbd, 0xc5,
		0xb6, 0xb9, 0xd8, 0x76, 0x17, 0xd9, 0xf6, 0xc9, 0xb6, 0x7f, 0xc2, 0x63, 0xa0, 0x7c, 0x1c, 0x66,
		0x8e, 0x45, 0xe4, 0x77, 0x82, 0x9e, 0xfa, 0x6a, 0x3d, 0x1d, 0x8e, 0xd1, 0x40, 0x8a, 0x53, 0xac,
		0x76, 0x44, 0xb4, 0x8f, 0x8a, 0xc4, 0x91, 0x91, 0x3b, 0x3a, 0x52, 0x47, 0x48, 0xfc, 0x28, 0x89,
		0x1f, 0x29, 0xd1, 0xa3, 0xa5, 0x76, 0xc4, 0x14, 0x8f, 0x9a, 0xf6, 0x91, 0x9b, 0x0e, 0xd0, 0x98,
		0xec, 0x59, 0xcd, 0x45, 0x9e, 0x6c, 0xbb, 0xf1, 0x78, 0x9a, 0x0b, 0xa2, 0x77, 0x10, 0xc5, 0x0e,
		0xa4, 0xe4, 0xc1, 0x94, 0x3f, 0xa0, 0xd2, 0x07, 0xd5, 0xd8, 0x81, 0x35, 0x76, 0x70, 0x8d, 0x1c,
		0x60, 0xbd, 0x83, 0xac, 0x79, 0xa0, 0xc5, 0x0e, 0xf6, 0x74, 0xa0, 0xdb, 0x4e, 0xf8, 0x97, 0x1b,
		0x36, 0xfd, 0xe0, 0xce, 0x19, 0xdd, 0x8e, 0x72, 0xfb, 0x64, 0xb2, 0x93, 0x97, 0xdf, 0x42, 0x68,
		0x59, 0xc7, 0x30, 0xb0, 0x23, 0x34, 0x9c, 0x14, 0x1c, 0x98, 0x80, 0x05, 0x73, 0xf0, 0x60, 0x0a,
		0x26, 0x8c, 0xc3, 0x85, 0x71, 0xd8, 0x30, 0x0a, 0x1f, 0x32, 0x30, 0x22, 0x04, 0x27, 0xd3, 0x27,
		0xfd, 0xe4, 0x06, 0x4d, 0x37, 0xea, 0x0c, 0x0d, 0xd0, 0x5d, 0xa1, 0x31, 0x2f, 0x1f, 0xba, 0x9e,
		0x99, 0x33, 0xe0, 0x37, 0xbd, 0x20, 0xf2, 0xa3, 0x87, 0xd0, 0xbb, 0x95, 0x3c, 0x08, 0x13, 0x76,
		0xb1, 0x2f, 0x38, 0xe6, 0xc9, 0xf8, 0xa3, 0xbe, 0x77, 0x7b, 0x06, 0x8e, 0xd8, 0x64, 0x42, 0x3e,
		0x9e, 0x7d, 0xf9, 0xd7, 0xd1, 0x97, 0xdf, 0x4e, 0x3e, 0xff, 0x7e, 0x7d, 0xf4, 0xe1, 0xf2, 0xe4,
		0xec, 0xb3, 0xf4, 0x51, 0xfb, 0xe6, 0xb6, 0xfa, 0x43, 0x39, 0xed, 0xbb, 0xe8, 0xb8, 0x83, 0x3f,
		0x7f, 0x8b, 0x8f, 0x38, 0x37, 0x35, 0x47, 0x1f, 0x3e, 0x1c, 0x9f, 0x5f, 0x56, 0xc4, 0xdf, 0xe4,
		0xf1, 0x75, 0xde, 0x66, 0xe2, 0xcb, 0xf1, 0xff, 0x3b, 0xfe, 0xc0, 0x4c, 0xbc, 0xdb, 0xaa, 0xfc,
		0xf6, 0xe5, 0xec, 0xdc, 0xc0, 0x3c, 0x88, 0x8e, 0x78, 0x65, 0xdb, 0x4d, 0xf3, 0xc2, 0x82, 0x7d,
		0x52, 0x69, 0x75, 0xcc, 0xd1, 0xd5, 0x99, 0xb1, 0x85, 0x6e, 0xc0, 0xdf, 0xbc, 0x5b, 0xb7, 0xdf,
		0x1a, 0xd2, 0x87, 0xd3, 0xb3, 0xdf, 0xaf, 0x3f, 0x9f, 0x7d, 0x3e, 0x86, 0x02, 0x43, 0x81, 0xa1,
		0xc0, 0x36, 0x52, 0x60, 0xe8, 0x6a, 0x6a, 0x74, 0x75, 0x00, 0x86, 0xf0, 0xd4, 0xe5, 0x39, 0x19,
		0x5e, 0x10, 0xf0, 0xb3, 0xe1, 0x5c, 0x5c, 0xfc, 0x71, 0x71, 0x7a, 0xf6, 0x3b, 0x2c, 0x2d, 0x75,
		0x96, 0x96, 0xa9, 0xbc, 0x79, 0x14, 0x04, 0x9d, 0xc8, 0x15, 0xe3, 0x77, 0x95, 0x5e, 0xe3, 0x87,
		0xd7, 0x76, 0xbb, 0x6e, 0xf4, 0x63, 0xb0, 0xaf, 0xb6, 0x3b, 0x5d, 0x2f, 0x18, 0x79, 0x22, 0x06,
		0x37, 0xd9, 0xf6, 0xf8, 0xff, 0xc3, 0x18, 0xb1, 0xc9, 0x17, 0xdb, 0x33, 0x11, 0x20, 0xd3, 0xaf,
		0x1f, 0xb6, 0xc7, 0x1e, 0xc4, 0x6d, 0x11, 0x3f, 0xc6, 0xe8, 0xa3, 0x45, 0x61, 0xbf, 0x11, 0x05,
		0xe3, 0x2d, 0x7f, 0x36, 0xfd, 0x64, 0x47, 0x8d, 0xd6, 0xf5, 0xf8, 0xff, 0x17, 0x5e, 0xd4, 0x1b,
		0xff, 0x3d, 0xf8, 0xeb, 0x78, 0xf4, 0xa9, 0x26, 0x5f, 0x3e, 0x5c, 0x1f, 0x8d, 0x3e, 0xd4, 0xf5,
		0x98, 0xbd, 0xbd, 0xc8, 0x66, 0xdd, 0x35, 0xd6, 0xbc, 0xd2, 0x8b, 0xdc, 0xc8, 0x93, 0xf3, 0x32,
		0x8d, 0x86, 0xb3, 0xcc, 0xc9, 0x54, 0xc5, 0xc9, 0x64, 0x01, 0x65, 0xc6, 0xc9, 0x94, 0xc0, 0x6e,
		0xc5, 0xc9, 0x84, 0x85, 0x8d, 0x85, 0x8d, 0x85, 0x2d, 0x6b, 0x61, 0xe3, 0x64, 0xc2, 0xc9, 0x54,
		0x4c, 0xe3, 0x1d, 0x27, 0x13, 0x4e, 0xa6, 0xc5, 0x99, 0xc0, 0xc9, 0x94, 0x89, 0x7c, 0x81, 0x93,
		0x09, 0x27, 0x13, 0x14, 0x18, 0x0a, 0x6c, 0x27, 0x05, 0x86, 0xae, 0xe2, 0x64, 0xca, 0x90, 0x93,
		0xe0, 0x64, 0xc2, 0xc9, 0x64, 0x05, 0x4b, 0xc3, 0xc9, 0xf4, 0x9c, 0x93, 0x49, 0xc2, 0x8d, 0xb1,
		0x25, 0xec, 0x63, 0xba, 0x18, 0x7e, 0xa6, 0xac, 0x5c, 0x4c, 0xa9, 0x26, 0x4f, 0x09, 0xed, 0x0f,
		0xf1, 0x7d, 0x51, 0xd1, 0x72, 0xb4, 0x49, 0xed, 0x04, 0xb5, 0x3d, 0x90, 0x7c, 0x05, 0x15, 0x56,
		0x4f, 0x37, 0x6b, 0x4d, 0x26, 0x5b, 0x8d, 0x74, 0x51, 0x13, 0x66, 0x0f, 0xe9, 0xa2, 0x06, 0x11,
		0x4f, 0x3b, 0x5d, 0xb4, 0xe9, 0xf5, 0x1a, 0xa1, 0xdf, 0x15, 0xb9, 0x53, 0x67, 0x4a, 0x32, 0x3d,
		0x0d, 0x2a, 0xe3, 0xd3, 0xdf, 0x21, 0x71, 0x34, 0x03, 0xa5, 0x02, 0x9f, 0xbe, 0x05, 0xa4, 0x57,
		0x4c, 0x79, 0x98, 0x09, 0xb6, 0x09, 0xfd, 0x40, 0x24, 0x14, 0x6a, 0x72, 0x61, 0xbe, 0xcd, 0x63,
		0x04, 0x93, 0xf7, 0xbf, 0xbe, 0x17, 0x34, 0x3c, 0xc7, 0x6f, 0x0a, 0xc6, 0x31, 0xcd, 0x0c, 0x0a,
		0xf2, 0x81, 0x7c, 0x20, 0x9f, 0x55, 0xc8, 0xd7, 0xf7, 0x83, 0x68, 0xaf, 0x2a, 0x88, 0x7c, 0x07,
		0x02, 0x43, 0x7d, 0x71, 0x83, 0x3b, 0x4f, 0x4c, 0x94, 0x14, 0x54, 0xa8, 0x3f, 0xf9, 0x81, 0x01,
		0xa7, 0x87, 0xa8, 0x6b, 0x6a, 0x3a, 0xec, 0x50, 0xda, 0x35, 0x30, 0xee, 0xc7, 0x70, 0x64, 0xc3,
		0xff, 0xe6, 0xdf, 0xf9, 0xc3, 0xca, 0x95, 0x3b, 0x72, 0x9a, 0x9e, 0xa0, 0x32, 0xff, 0xc9, 0xfd,
		0x99, 0xbb, 0xa5, 0xaa, 0x55, 0x0f, 0x6b, 0x87, 0xf5, 0x83, 0xea, 0xe1, 0x7e, 0x8e, 0xd6, 0xcc,
		0x12, 0x1d, 0xf6, 0x0a, 0x3d, 0x2f, 0x0b, 0x3d, 0x4f, 0x3b, 0x89, 0x40, 0x42, 0xce, 0xd3, 0x49,
		0x1a, 0x48, 0x47, 0xcd, 0xf3, 0x83, 0x6e, 0x3f, 0x72, 0xfc, 0x20, 0xf2, 0xc2, 0x5b, 0x57, 0xa7,
		0x68, 0xdf, 0xd4, 0x47, 0xba, 0x30, 0x20, 0xfa, 0x1e, 0xfa, 0x1e, 0xfa, 0x5e, 0x9c, 0x01, 0x28,
		0x07, 0x87, 0x6d, 0x8b, 0x6d, 0x6b, 0x9f, 0x6d, 0x6b, 0xad, 0x2b, 0x7b, 0xe1, 0xaa, 0xb5, 0x2b,
		0x6f, 0xf2, 0x64, 0xf0, 0xe1, 0x4e, 0x26, 0x9f, 0x2d, 0xc7, 0xe9, 0x93, 0xd3, 0xf9, 0x75, 0x42,
		0xef, 0x56, 0x0e, 0x9d, 0xe7, 0x87, 0x05, 0xa4, 0xe3, 0x80, 0xb4, 0x7f, 0x0b, 0x46, 0x1b, 0xc0,
		0x68, 0xff, 0x96, 0x64, 0x4a, 0x59, 0x0e, 0x66, 0x86, 0x8b, 0x09, 0x1f, 0x77, 0xf1, 0x63, 0x6f,
		0xe2, 0xf8, 0x1b, 0x83, 0x01, 0x53, 0x70, 0x60, 0x1c, 0x16, 0x8c, 0xc3, 0x83, 0x49, 0x98, 0x10,
		0x16, 0xe7, 0xa4, 0xd2, 0x3b, 0x84, 0xe0, 0x63, 0x99, 0x33, 0x98, 0x0b, 0xbd, 0xd6, 0x55, 0x58,
		0x36, 0x81, 0x8b, 0xb4, 0x94, 0x2c, 0x0d, 0x32, 0x26, 0xc1, 0xc6, 0x38, 0xe8, 0x98, 0x06, 0x9f,
		0xd4, 0x40, 0x28, 0x35, 0x30, 0x4a, 0x03, 0x94, 0x64, 0xc1, 0x49, 0x18, 0xa4, 0xa6, 0x13, 0x20,
		0x9e, 0xde, 0xb2, 0xb4, 0xdb, 0x5b, 0x9e, 0x7b, 0x2b, 0x9b, 0xe2, 0xb2, 0xc4, 0x5c, 0x0e, 0x0c,
		0x8c, 0x7d, 0x3e, 0xb5, 0xa8, 0x07, 0xdb, 0xe2, 0xdd, 0x14, 0x20, 0x7b, 0x8b, 0xdf, 0x18, 0xff,
		0x7b, 0x68, 0xde, 0xbe, 0xb0, 0x73, 0xe3, 0x48, 0x3a, 0x1c, 0x7b, 0xfd, 0x9b, 0x14, 0xee, 0xa3,
		0xb9, 0x77, 0xe1, 0x4a, 0xe2, 0x4a, 0xe2, 0x4a, 0xe2, 0x4a, 0xe2, 0x4a, 0x8a, 0x79, 0x25, 0x7d,
		0x7f, 0xba, 0x92, 0xfe, 0xbf, 0x46, 0x3f, 0x0c, 0xbd, 0x20, 0x7a, 0xf9, 0x6a, 0xfb, 0xcd, 0x9b,
		0xed, 0xe9, 0x6f, 0x5c, 0x8d, 0x5f, 0x32, 0x8b, 0xb3, 0xbd, 0x15, 0xdf, 0x9b, 0x8e, 0xdc, 0xf4,
		0x7e, 0x5a, 0x7b, 0xbb, 0x59, 0x65, 0xfd, 0x1d, 0xff, 0x8c, 0x64, 0x13, 0x4d, 0xcd, 0x09, 0x09,
		0x9d, 0x86, 0xe3, 0xfd, 0x8c, 0xde, 0x45, 0x5e, 0xcb, 0x6b, 0x7b, 0x51, 0xf8, 0xe0, 0x74, 0x02,
		0xa7, 0xf1, 0x63, 0x18, 0x94, 0x66, 0x54, 0x5c, 0xb8, 0x75, 0x5b, 0x3d, 0x93, 0xea, 0x82, 0x6d,
		0xc2, 0xc2, 0x95, 0x94, 0xd0, 0x2a, 0xeb, 0x3a, 0x7a, 0xa2, 0x74, 0xa6, 0x5c, 0x48, 0x73, 0x5e,
		0x89, 0x6d, 0x51, 0xd5, 0x72, 0xcb, 0x8c, 0x63, 0x69, 0xfa, 0xd5, 0x17, 0xef, 0x56, 0xc4, 0xcb,
		0x24, 0xb7, 0x93, 0x1e, 0x45, 0x3c, 0x71, 0x12, 0xc5, 0x3b, 0x97, 0xd9, 0xba, 0x50, 0xf6, 0xeb,
		0x96, 0x49, 0x39, 0xba, 0x8a, 0x1c, 0x9d, 0x1f, 0xda, 0x8d, 0x1c, 0x8d, 0x1c, 0x8d, 0xed, 0x8f,
		0xed, 0x8f, 0xed, 0x8f, 0xed, 0x8f, 0xed, 0x8f, 0x1c, 0xbd, 0x9e, 0xd1, 0x22, 0x47, 0x73, 0x25,
		0x71, 0x25, 0x71, 0x25, 0x71, 0x25, 0x59, 0x7b, 0x25, 0x21, 0x47, 0x67, 0x67, 0xfd, 0xe5, 0x5c,
		0x33, 0x94, 0x54, 0x96, 0xd2, 0x90, 0x0c, 0x05, 0x6a, 0xae, 0x09, 0x2a, 0x86, 0x24, 0x3a, 0x24,
		0xde, 0x71, 0x76, 0xe6, 0x3b, 0xcc, 0xee, 0x31, 0x9a, 0x46, 0xd1, 0x34, 0x2a, 0x01, 0x8f, 0x26,
		0x15, 0x8d, 0x54, 0xb4, 0xbc, 0x23, 0xb4, 0x4d, 0xd5, 0x55, 0x17, 0x90, 0x99, 0x22, 0xab, 0xd6,
		0x6c, 0x93, 0x8c, 0xab, 0x33, 0xcc, 0x6f, 0x0c, 0xab, 0xab, 0x34, 0x74, 0xef, 0x6b, 0x02, 0xa5,
		0x19, 0x06, 0xa3, 0x50, 0x8f, 0x61, 0x70, 0x17, 0x74, 0xff, 0x1b, 0x39, 0x6d, 0x37, 0x6a, 0xfc,
		0xa0, 0x2a, 0x83, 0xc2, 0x4d, 0xfa, 0x34, 0x7b, 0xd4, 0x66, 0x50, 0xdb, 0x82, 0xd4, 0x66, 0x48,
		0xf9, 0xb0, 0x42, 0x8b, 0x0d, 0x1e, 0x66, 0x3b, 0xc8, 0xb1, 0x58, 0x12, 0x70, 0xd3, 0xeb, 0x45,
		0x7e, 0x30, 0xe4, 0x4d, 0x8e, 0xdb, 0x6c, 0x86, 0x5e, 0xaf, 0x27, 0x1f, 0x81, 0xb5, 0xea, 0x4d,
		0x68, 0x29, 0x65, 0x1b, 0x5c, 0x98, 0x82, 0x0d, 0xe3, 0xf0, 0x61, 0x1c, 0x46, 0x52, 0x80, 0x13,
		0x39, 0x5d, 0x75, 0x2b, 0x1f, 0xed, 0xa5, 0xba, 0xf7, 0x35, 0x47, 0x7c, 0x17, 0x3c, 0x55, 0x7e,
		0x16, 0x1c, 0xf3, 0xdc, 0x8d, 0x22, 0x2f, 0x0c, 0xc4, 0xfb, 0x33, 0x55, 0x5e, 0xbe, 0xfc, 0xbe,
		0xe3, 0x1c, 0x5e, 0xfd, 0xfa, 0xbe, 0xeb, 0x1c, 0x5e, 0x8d, 0xbe, 0xdc, 0x1d, 0xfe, 0x35, 0xfa,
		0xba, 0xfa, 0x7d, 0xc7, 0xa9, 0x4d, 0xbe, 0xde, 0xff, 0xbe, 0xe3, 0xec, 0x5f, 0xbd, 0xfa, 0xf3,
		0xcf, 0x37, 0xaf, 0xfe, 0xde, 0x7b, 0x4c, 0xfe, 0xc2, 0xed, 0xf1, 0x9b, 0xbd, 0xfa, 0xf5, 0xf2,
		0xfb, 0xae, 0x53, 0xbd, 0x9a, 0xfc, 0x63, 0xef, 0xfb, 0x8e, 0x53, 0xbd, 0x7a, 0xf5, 0x4a, 0x6e,
		0x07, 0x5f, 0x49, 0x4e, 0xfd, 0xd9, 0xc5, 0xc9, 0xbf, 0x8d, 0xcd, 0xff, 0x7f, 0x6c, 0x5a, 0x80,
		0x7f, 0x08, 0xae, 0x40, 0x81, 0x62, 0xc2, 0x9b, 0xbd, 0x46, 0xd7, 0x00, 0x21, 0x19, 0x8c, 0x0a,
		0x03, 0x81, 0x81, 0xc0, 0x40, 0x4a, 0xcb, 0x40, 0x04, 0x31, 0x60, 0x16, 0x07, 0x24, 0x1b, 0x5b,
		0xca, 0x96, 0x60, 0x9f, 0xfc, 0x31, 0x10, 0x2b, 0x64, 0xa2, 0x24, 0xbb, 0x21, 0x80, 0x5d, 0x1a,
		0xde, 0x50, 0x89, 0xf6, 0xe9, 0xf8, 0x06, 0xcb, 0x7e, 0x0b, 0x1f, 0xb6, 0xf9, 0x25, 0x75, 0x7f,
		0xe6, 0x7e, 0x49, 0xeb, 0x7b, 0x39, 0x5e, 0x53, 0x4b, 0x03, 0xc8, 0x8a, 0x44, 0x2e, 0x7f, 0x74,
		0xba, 0x4e, 0xcb, 0x6f, 0xfb, 0x91, 0x3c, 0xc3, 0x7c, 0x1a, 0x1a, 0x9a, 0x09, 0xcd, 0x84, 0x66,
		0x96, 0x96, 0x66, 0xf6, 0xfd, 0x20, 0x7a, 0x0b, 0xcf, 0x84, 0x67, 0xc2, 0x33, 0x0b, 0xcb, 0x33,
		0xab, 0xfb, 0xfb, 0x10, 0x4d, 0x88, 0xe6, 0xfa, 0x65, 0xec, 0x86, 0x9d, 0xa8, 0xd3, 0xe8, 0xb4,
		0xe4, 0x79, 0xe6, 0x74, 0x64, 0x68, 0x26, 0x34, 0x13, 0x9a, 0x59, 0x5a, 0x9a, 0xe9, 0x77, 0x9d,
		0x09, 0x14, 0x38, 0xd1, 0xe0, 0x5d, 0x0c, 0x38, 0x55, 0x0f, 0x05, 0xc7, 0x1c, 0xcf, 0x84, 0xf5,
		0x8c, 0xd3, 0x14, 0x8d, 0x37, 0x48, 0xe7, 0x0d, 0xd3, 0x7a, 0x73, 0x93, 0x9d, 0x0a, 0xcd, 0x4f,
		0x89, 0x1b, 0xa6, 0x45, 0xfb, 0xd3, 0x64, 0x8a, 0x06, 0xcd, 0x80, 0x54, 0xcc, 0x81, 0xac, 0x96,
		0xbe, 0xba, 0x5f, 0x2b, 0xd0, 0xe2, 0xbf, 0xc8, 0xc7, 0xa8, 0x57, 0x36, 0xa7, 0xed, 0x1b, 0xbc,
		0xa8, 0xfc, 0xa6, 0x17, 0x44, 0x7e, 0xf4, 0x60, 0x38, 0x65, 0xdf, 0xc4, 0x7d, 0x75, 0x32, 0xfe,
		0xe8, 0xef, 0xdd, 0x9e, 0xc1, 0x22, 0x18, 0x93, 0x89, 0x3a, 0x39, 0xbf, 0x3e, 0xff, 0x72, 0x76,
		0x79, 0xf6, 0xe1, 0xec, 0xb4, 0x62, 0x52, 0x1f, 0xe8, 0x19, 0xbb, 0x81, 0xcd, 0xde, 0xc2, 0x8b,
		0x93, 0x75, 0xf9, 0xe1, 0xbc, 0x92, 0xc7, 0x2b, 0x25, 0xbd, 0x19, 0x3a, 0x3f, 0xf9, 0xc4, 0x0c,
		0x3d, 0x3b, 0x43, 0x47, 0x5f, 0x2f, 0xff, 0x8f, 0x29, 0x7a, 0x76, 0x8a, 0xbe, 0xfe, 0xc6, 0x31,
		0x7b, 0x7e, 0x86, 0x4e, 0x3e, 0x7c, 0x62, 0x8a, 0x9e, 0x9f, 0xa2, 0xd3, 0xea, 0x25, 0x53, 0xb4,
		0x61, 0x17, 0xfd, 0xce, 0x2e, 0xda, 0x30, 0x45, 0x5f, 0x2e, 0xbe, 0x31, 0x45, 0xcf, 0x4f, 0xd1,
		0xef, 0x5f, 0x8e, 0x2b, 0x39, 0x33, 0xb5, 0xae, 0xf0, 0x20, 0xa5, 0xfc, 0x79, 0x44, 0x6a, 0xa3,
		0x0f, 0x7d, 0x08, 0xe6, 0x52, 0xf4, 0x16, 0xc6, 0xc7, 0x9b, 0xa4, 0x3d, 0xa3, 0x78, 0x93, 0x16,
		0xde, 0x00, 0x6f, 0x92, 0xec, 0xcd, 0x47, 0x76, 0x1e, 0xd9, 0x79, 0xc9, 0xef, 0x44, 0xb2, 0xf3,
		0xc8, 0xce, 0x13, 0x18, 0xa1, 0xb8, 0xd5, 0xbd, 0xba, 0xf7, 0x35, 0xb9, 0x66, 0x40, 0x22, 0xa5,
		0x9b, 0xba, 0xf7, 0x35, 0x91, 0x6e, 0x3f, 0x54, 0x57, 0x5c, 0xbc, 0x88, 0x0a, 0x5e, 0x5d, 0x91,
		0x62, 0x32, 0x14, 0x93, 0x89, 0xf1, 0x5c, 0x14, 0x93, 0xc1, 0x5c, 0xc5, 0x5c, 0xc5, 0x5c, 0xc5,
		0x5c, 0xc5, 0x5c, 0xc5, 0x5c, 0xc5, 0x5c, 0xb5, 0xd3, 0x5c, 0xa5, 0x98, 0x0c, 0x0c, 0x04, 0x06,
		0x02, 0x03, 0xb1, 0x92, 0x81, 0x50, 0x4c, 0x46, 0x6e, 0x57, 0x92, 0xe4, 0xbb, 0x7e, 0x7c, 0x92,
		0x7c, 0x33, 0x5b, 0x52, 0x8a, 0xc9, 0xc8, 0x8f, 0x46, 0x31, 0x99, 0x58, 0xb7, 0x0b, 0xc5, 0x64,
		0xa0, 0x99, 0xd0, 0x4c, 0x68, 0x26, 0xc5, 0x64, 0xe0, 0x99, 0xf0, 0xcc, 0x82, 0xf3, 0x4c, 0x8a,
		0xc9, 0x40, 0x34, 0x9f, 0x5d, 0x46, 0x8a, 0xc9, 0x40, 0x33, 0xa1, 0x99, 0xd0, 0x4c, 0x8a, 0xc9,
		0x2c, 0xcc, 0x04, 0xc5, 0x64, 0x28, 0x26, 0x93, 0x2e, 0xcd, 0x4f, 0x89, 0x1b, 0xa6, 0x45, 0xfb,
		0xd3, 0x64, 0x8a, 0x06, 0xcd, 0x80, 0x54, 0xcc, 0x81, 0xac, 0x96, 0x9e, 0x62, 0x32, 0x19, 0x8c,
		0x4a, 0x31, 0x19, 0x8a, 0xc9, 0x3c, 0x3b, 0x51, 0x14, 0x93, 0x49, 0x36, 0x59, 0x14, 0x93, 0xd9,
		0xb8, 0x9d, 0x28, 0x26, 0xb3, 0x61, 0x86, 0x28, 0x26, 0xb3, 0x71, 0x8a, 0x28, 0x26, 0xb3, 0x69,
		0x86, 0x28, 0x26, 0xb3, 0x71, 0x8a, 0x28, 0x26, 0xb3, 0x79, 0x17, 0x51, 0x4c, 0x66, 0xd3, 0x14,
		0x51, 0x4c, 0x66, 0xe3, 0x14, 0x51, 0x4c, 0x06, 0x0f, 0x52, 0x1a, 0x3b, 0x9d, 0x62, 0x32, 0x78,
		0x93, 0xc6, 0xe3, 0xe3, 0x4d, 0x5a, 0xf7, 0x06, 0x78, 0x93, 0xc4, 0x44, 0x24, 0xb2, 0xf3, 0xc8,
		0xce, 0xdb, 0x3c, 0xf5, 0x64, 0xe7, 0xe5, 0x99, 0x95, 0x50, 0x4c, 0x66, 0x6d, 0x31, 0x19, 0x89,
		0x8a, 0x25, 0x5b, 0x92, 0xb5, 0x64, 0x2e, 0x86, 0x1f, 0x28, 0xab, 0x52, 0x32, 0x2f, 0x52, 0xdc,
		0x21, 0x52, 0x3b, 0x43, 0x76, 0x47, 0x54, 0xb4, 0xaa, 0xe9, 0x88, 0xec, 0x01, 0xb5, 0xd5, 0x4f,
		0xbe, 0x76, 0x0a, 0xeb, 0x36, 0xe0, 0x0b, 0x75, 0xe5, 0xd5, 0x9a, 0x65, 0x1d, 0x75, 0xc5, 0x89,
		0xd6, 0x2c, 0x0f, 0xa4, 0x6d, 0x59, 0x48, 0x58, 0x12, 0xd2, 0x96, 0x83, 0x94, 0xa5, 0x20, 0x6e,
		0x19, 0x88, 0x5b, 0x02, 0x06, 0x98, 0x7f, 0xba, 0x98, 0xa7, 0x5b, 0xce, 0xa7, 0xd2, 0x98, 0xec,
		0x5f, 0xa1, 0x92, 0x5d, 0x22, 0xd5, 0xd4, 0xc4, 0x6b, 0x76, 0xed, 0x50, 0xb3, 0xcb, 0x1a, 0xb3,
		0x9e, 0x9a, 0x5d, 0x69, 0x1f, 0xf2, 0xe9, 0x40, 0xd4, 0xec, 0x42, 0x15, 0x44, 0x15, 0x44, 0x15,
		0xcc, 0x40, 0x15, 0xac, 0xa3, 0x0a, 0x7e, 0xdf, 0x71, 0x0e, 0x5d, 0xe7, 0xf6, 0xc8, 0xf9, 0x78,
		0xf5, 0xf7, 0xee, 0xeb, 0xda, 0xe3, 0xbb, 0x57, 0x7f, 0x1f, 0x3c, 0x2e, 0x7e, 0xf3, 0xd7, 0xaa,
		0x5f, 0xdb, 0x7d, 0x7d, 0xf0, 0xf8, 0x6e, 0xcd, 0x4f, 0xea, 0x8f, 0xef, 0x62, 0x8e, 0xb1, 0xff,
		0xf8, 0x72, 0xe9, 0x57, 0x07, 0xdf, 0xaf, 0xae, 0x7b, 0x41, 0x6d, 0xcd, 0x0b, 0xf6, 0xd6, 0xbd,
		0x60, 0x6f, 0xcd, 0x0b, 0xd6, 0x7e, 0xa4, 0xea, 0x9a, 0x17, 0xec, 0x3f, 0xfe, 0x5a, 0xfa, 0xfd,
		0x97, 0xab, 0x7f, 0xb5, 0xfe, 0xf8, 0xea, 0xd7, 0xba, 0x9f, 0x1d, 0x3c, 0xfe, 0x7a, 0xf7, 0xea,
		0xd5, 0xf6, 0xcb, 0xdd, 0xea, 0xf7, 0x1d, 0xe7, 0xed, 0x48, 0xcc, 0xdb, 0xbd, 0x5a, 0xd2, 0xf8,
		0x46, 0x9a, 0x5d, 0x89, 0xa5, 0x52, 0x76, 0xa5, 0xb5, 0xbb, 0x92, 0xea, 0x6e, 0x1b, 0x99, 0xec,
		0x6d, 0xab, 0xf3, 0x97, 0xd3, 0x72, 0x6f, 0xbc, 0x96, 0x59, 0x32, 0x3b, 0xf3, 0x3e, 0xf0, 0x59,
		0xf8, 0x2c, 0x7c, 0xb6, 0xdc, 0x7c, 0x56, 0x1c, 0x0e, 0x66, 0x21, 0xe1, 0x80, 0x22, 0x1d, 0xc2,
		0x83, 0x53, 0xa4, 0x23, 0xa5, 0x73, 0x37, 0xbf, 0xa4, 0x05, 0x28, 0xd2, 0xb1, 0xbb, 0x53, 0x7b,
		0xbb, 0x7f, 0x40, 0xa1, 0x0e, 0xf1, 0xd1, 0x28, 0x37, 0xbc, 0x91, 0x7e, 0x52, 0x6e, 0x18, 0xb2,
		0x09, 0xd9, 0x2c, 0x35, 0xd9, 0xa4, 0xdc, 0x30, 0x0c, 0x13, 0x86, 0x59, 0x68, 0x86, 0x49, 0xb9,
		0x61, 0xc8, 0xe5, 0x73, 0xcb, 0x48, 0xb9, 0x61, 0x68, 0x26, 0x34, 0x13, 0x9a, 0x49, 0xb9, 0x61,
		0x78, 0x26, 0x3c, 0x13, 0x9e, 0xa9, 0xba, 0xa4, 0x94, 0x1b, 0x86, 0x68, 0x3e, 0xbb, 0x8c, 0x94,
		0x1b, 0x86, 0x66, 0x42, 0x33, 0xa1, 0x99, 0x94, 0x1b, 0x5e, 0x98, 0x09, 0xca, 0x0d, 0x53, 0x6e,
		0x38, 0x5d, 0x9a, 0x9f, 0x12, 0x37, 0x4c, 0x8b, 0xf6, 0xa7, 0xc9, 0x14, 0x0d, 0x9a, 0x01, 0xa9,
		0x98, 0x03, 0x59, 0x2d, 0x3d, 0xe5, 0x86, 0x33, 0x18, 0x95, 0x72, 0xc3, 0x94, 0x1b, 0x7e, 0x76,
		0xa2, 0x28, 0x37, 0x9c, 0x6c, 0xb2, 0x28, 0x37, 0xbc, 0x71, 0x3b, 0x51, 0x6e, 0x78, 0xc3, 0x0c,
		0x51, 0x6e, 0x78, 0xe3, 0x14, 0x51, 0x6e, 0x78, 0xd3, 0x0c, 0x51, 0x6e, 0x78, 0xe3, 0x14, 0x51,
		0x6e, 0x78, 0xf3, 0x2e, 0xa2, 0xdc, 0xf0, 0xa6, 0x29, 0xa2, 0xdc, 0xf0, 0xc6, 0x29, 0xa2, 0xdc,
		0x30, 0x1e, 0xa4, 0x34, 0x76, 0x3a, 0xe5, 0x86, 0xf1, 0x26, 0x8d, 0xc7, 0xc7, 0x9b, 0xb4, 0xee,
		0x0d, 0xf0, 0x26, 0x89, 0x89, 0x48, 0x14, 0x16, 0xa1, 0xb0, 0x08, 0x85, 0x45, 0x94, 0xf6, 0x23,
		0x85, 0x45, 0x28, 0x2c, 0x02, 0x7f, 0x5d, 0xc3, 0x5f, 0x4d, 0xd6, 0x14, 0x59, 0x7e, 0x0b, 0x58,
		0x2c, 0x2c, 0x16, 0x16, 0x5b, 0x6e, 0x16, 0x4b, 0x39, 0x11, 0x69, 0xf9, 0x8b, 0x20, 0xfc, 0xf5,
		0xe3, 0x13, 0x84, 0x9f, 0xd9, 0x92, 0x52, 0x4e, 0xa4, 0xe8, 0x32, 0x2a, 0xfd, 0x51, 0xd6, 0x74,
		0xc3, 0xa8, 0x6f, 0x8b, 0x94, 0x87, 0xdf, 0x92, 0x6b, 0x8e, 0x51, 0xbf, 0x1e, 0xb3, 0xdc, 0xac,
		0x3a, 0xa4, 0x68, 0xb5, 0x07, 0x71, 0x23, 0x4f, 0xae, 0x72, 0xbf, 0x44, 0xeb, 0x1a, 0xf1, 0xc2,
		0xfd, 0x55, 0x0a, 0xf7, 0x5b, 0x63, 0x5a, 0x50, 0xb8, 0x3f, 0xe9, 0x73, 0x51, 0xb8, 0x1f, 0x65,
		0x02, 0x65, 0x02, 0x65, 0x22, 0xdf, 0xca, 0x04, 0xfe, 0x35, 0x3c, 0x19, 0xf8, 0xd7, 0x12, 0xef,
		0x47, 0xfc, 0x6b, 0xf8, 0xd7, 0x0a, 0x26, 0x6c, 0x50, 0xb8, 0x1f, 0x3e, 0x0b, 0x9f, 0x85, 0xcf,
		0xe6, 0x9b, 0xcf, 0xe2, 0x69, 0x13, 0xfe, 0x83, 0xa7, 0xed, 0x99, 0xf1, 0xf1, 0xb4, 0x65, 0xb6,
		0xa4, 0x78, 0xda, 0x0c, 0x8d, 0x46, 0xe1, 0xfe, 0x8d, 0xf4, 0x93, 0xc2, 0xfd, 0x90, 0x4d, 0xc8,
		0x66, 0xa9, 0xc9, 0x26, 0x85, 0xfb, 0x61, 0x98, 0x30, 0xcc, 0x42, 0x33, 0x4c, 0x0a, 0xf7, 0x43,
		0x2e, 0x9f, 0x5b, 0x46, 0x0a, 0xf7, 0x43, 0x33, 0xa1, 0x99, 0xd0, 0x4c, 0x0a, 0xf7, 0xc3, 0x33,
		0xe1, 0x99, 0xf0, 0x4c, 0xd5, 0x25, 0xa5, 0x70, 0x3f, 0x44, 0xf3, 0xd9, 0x65, 0xa4, 0x70, 0x3f,
		0x34, 0x13, 0x9a, 0x09, 0xcd, 0xa4, 0x70, 0xff, 0xc2, 0x4c, 0x50, 0xb8, 0x9f, 0xc2, 0xfd, 0xe9,
		0xd2, 0xfc, 0x94, 0xb8, 0x61, 0x5a, 0xb4, 0x3f, 0x4d, 0xa6, 0x68, 0xd0, 0x0c, 0x48, 0xc5, 0x1c,
		0xc8, 0x6a, 0xe9, 0x29, 0xdc, 0x9f, 0xc1, 0xa8, 0x14, 0xee, 0xa7, 0x70, 0xff, 0xb3, 0x13, 0x45,
		0xe1, 0xfe, 0x64, 0x93, 0x45, 0xe1, 0xfe, 0x8d, 0xdb, 0x89, 0xc2, 0xfd, 0x1b, 0x66, 0x88, 0xc2,
		0xfd, 0x1b, 0xa7, 0x88, 0xc2, 0xfd, 0x9b, 0x66, 0x88, 0xc2, 0xfd, 0x1b, 0xa7, 0x88, 0xc2, 0xfd,
		0x9b, 0x77, 0x11, 0x85, 0xfb, 0x37, 0x4d, 0x11, 0x85, 0xfb, 0x37, 0x4e, 0x11, 0x85, 0xfb, 0xf1,
		0x20, 0xa5, 0xb1, 0xd3, 0x29, 0xdc, 0x8f, 0x37, 0x69, 0x3c, 0x3e, 0xde, 0xa4, 0x75, 0x6f, 0x80,
		0x37, 0x49, 0x4c, 0x44, 0xa2, 0xb0, 0x08, 0x85, 0x45, 0x28, 0x2c, 0xa2, 0xb4, 0x1f, 0x29, 0x2c,
		0x42, 0x61, 0x11, 0xf8, 0xeb, 0x1a, 0xfe, 0x4a, 0xe1, 0x7e, 0x58, 0x2c, 0x2c, 0x16, 0x16, 0x9b,
		0x1e, 0x8b, 0xa5, 0x9c, 0x88, 0xb4, 0xfc, 0x45, 0x10, 0xfe, 0xfa, 0xf1, 0x09, 0xc2, 0xcf, 0x6c,
		0x49, 0x29, 0x27, 0x52, 0x74, 0x19, 0x95, 0xc2, 0xfd, 0x6b, 0x0b, 0xf7, 0x4b, 0x54, 0x87, 0xdf,
		0x92, 0xac, 0xdb, 0x7f, 0x31, 0xfc, 0x40, 0x59, 0x95, 0xed, 0x7f, 0x91, 0xe2, 0x0e, 0x91, 0xda,
		0x19, 0xb2, 0x3b, 0xa2, 0xa2, 0xd5, 0xb9, 0x40, 0x64, 0x0f, 0xa8, 0xad, 0x7e, 0xf2, 0xb5, 0x53,
		0x58, 0xb7, 0x4a, 0xab, 0xaa, 0xbc, 0x56, 0x53, 0x7a, 0xd9, 0xaa, 0x2a, 0x4e, 0xb2, 0x66, 0x1b,
		0x06, 0x6d, 0x03, 0x52, 0xc2, 0x60, 0x94, 0x36, 0x10, 0xa5, 0x0c, 0x42, 0x71, 0x03, 0x50, 0xdc,
		0xe0, 0x33, 0x60, 0xe0, 0xa5, 0x8b, 0x77, 0xba, 0x6d, 0x13, 0x2a, 0x8d, 0xc9, 0xfe, 0x15, 0x6a,
		0x8d, 0x22, 0xd2, 0xb5, 0x46, 0xbc, 0x37, 0xca, 0x0e, 0xbd, 0x51, 0xac, 0x51, 0x6f, 0xe8, 0x8d,
		0x92, 0xf6, 0x21, 0x9f, 0x0e, 0x34, 0x5b, 0xe9, 0xb9, 0xed, 0x36, 0xcc, 0x96, 0x92, 0x1e, 0xbc,
		0x01, 0xa2, 0xaf, 0x6d, 0x30, 0x61, 0x0a, 0x2e, 0x8c, 0xc3, 0x86, 0x71, 0xf8, 0x48, 0x01, 0x46,
		0x64, 0xf5, 0x00, 0xfb, 0x45, 0xdf, 0xb6, 0xdb, 0x10, 0x8e, 0x62, 0xda, 0xca, 0x5d, 0xe8, 0xc2,
		0xac, 0x13, 0x73, 0xd1, 0x37, 0x5a, 0x7d, 0x7c, 0xf5, 0xf7, 0xfe, 0x63, 0x29, 0x7d, 0xe7, 0x9b,
		0xa7, 0x05, 0xe7, 0x6d, 0x9c, 0x3b, 0xdc, 0x69, 0xbb, 0xbd, 0xff, 0x1a, 0xbf, 0xc8, 0x47, 0xef,
		0xc2, 0x6d, 0xce, 0x6d, 0xce, 0x6d, 0xce, 0x6d, 0xce, 0x6d, 0xce, 0x6d, 0xce, 0x6d, 0x2e, 0x72,
		0x9b, 0x7b, 0xd1, 0x0f, 0x2f, 0x8c, 0x24, 0x8f, 0xec, 0xf4, 0xb8, 0x3e, 0x0d, 0xcd, 0xbd, 0xcd,
		0xbd, 0xcd, 0xbd, 0x5d, 0xda, 0x7b, 0x7b, 0x0a, 0x04, 0x14, 0xa3, 0x12, 0xdc, 0x9f, 0xb3, 0xc5,
		0xa8, 0x76, 0xeb, 0x06, 0xcb, 0x7b, 0xd4, 0xa9, 0x46, 0xf5, 0xf4, 0xc1, 0x8b, 0x58, 0x8d, 0x6a,
		0x77, 0x7f, 0xaf, 0x4e, 0x41, 0xaa, 0x58, 0xab, 0x5f, 0xc0, 0x82, 0x54, 0xf5, 0xfd, 0xfd, 0xbd,
		0x7d, 0x4a, 0x52, 0xa5, 0x3d, 0x2a, 0x25, 0xa9, 0x28, 0x49, 0xf5, 0xec, 0x44, 0x1d, 0x5f, 0xfe,
		0xdf, 0xf1, 0x97, 0xcb, 0x3f, 0xce, 0x8f, 0x29, 0x48, 0x15, 0x7b, 0xaa, 0xae, 0x4f, 0x4f, 0xa9,
		0x98, 0x13, 0x6f, 0xa6, 0xbe, 0x9d, 0x1e, 0x7d, 0x66, 0xa6, 0xe2, 0xcc, 0xd4, 0xa7, 0xf3, 0xd3,
		0x0b, 0x66, 0x2a, 0xce, 0x4c, 0x9d, 0x9c, 0x7f, 0xab, 0x31, 0x53, 0x71, 0x66, 0xea, 0xe8, 0x0b,
		0x30, 0x15, 0x77, 0x4b, 0xd5, 0x99, 0xa9, 0x38, 0x33, 0xf5, 0xe5, 0xec, 0x03, 0xe5, 0x87, 0xc8,
		0x9b, 0x31, 0xbf, 0xe3, 0x27, 0xb9, 0xd5, 0x46, 0x02, 0xf8, 0x66, 0xc6, 0xc6, 0x6b, 0xa0, 0x3d,
		0x9b, 0x78, 0x0d, 0x16, 0xde, 0x00, 0xaf, 0x81, 0xec, 0xcd, 0x87, 0xb7, 0x1f, 0x6f, 0xff, 0xaa,
		0x09, 0xc1, 0xdb, 0x6f, 0xf9, 0xcd, 0x6d, 0x28, 0x6c, 0x6f, 0xf1, 0x0d, 0xb8, 0xc3, 0xb9, 0xc3,
		0xb9, 0xc3, 0xb9, 0xc3, 0xb9, 0xc3, 0xb9, 0xc3, 0xb9, 0xc3, 0xa9, 0x5a, 0xb1, 0xba, 0x46, 0x41,
		0xab, 0xba, 0x2d, 0x92, 0xb6, 0xbb, 0x25, 0x54, 0xb0, 0xe0, 0xb4, 0x7a, 0x3d, 0xa6, 0x08, 0x59,
		0xd5, 0xac, 0xd0, 0x2a, 0xd8, 0xe0, 0x46, 0x9e, 0x5c, 0x3e, 0xb5, 0x44, 0x31, 0x11, 0xf1, 0x74,
		0xea, 0x2a, 0xe9, 0xd4, 0xd6, 0xf0, 0x32, 0xd2, 0xa9, 0x93, 0x3e, 0x17, 0xe9, 0xd4, 0x98, 0x73,
		0x98, 0x73, 0x98, 0x73, 0x98, 0x73, 0x98, 0x73, 0x98, 0x73, 0x79, 0x36, 0xe7, 0x48, 0xa7, 0xe6,
		0x36, 0xe7, 0x36, 0xe7, 0x36, 0xe7, 0x36, 0xe7, 0x36, 0xe7, 0x36, 0xe7, 0x36, 0x27, 0x9d, 0x9a,
		0x7b, 0x9b, 0x7b, 0x9b, 0x7b, 0x9b, 0x74, 0xea, 0xc5, 0x79, 0x20, 0x9d, 0x9a, 0x74, 0xea, 0x15,
		0x1f, 0x9c, 0x74, 0x6a, 0xa5, 0xb7, 0x22, 0x9d, 0xda, 0xda, 0xd5, 0x27, 0x9d, 0x3a, 0x93, 0x51,
		0x49, 0xa7, 0x26, 0x9d, 0xfa, 0xd9, 0x89, 0x22, 0x9d, 0x3a, 0xf9, 0x54, 0x91, 0x4e, 0x1d, 0x7b,
		0xa6, 0x48, 0xa7, 0x8e, 0x3b, 0x53, 0xa4, 0x53, 0xc7, 0x9d, 0x29, 0xd2, 0xa9, 0xe3, 0xce, 0x14,
		0xe9, 0xd4, 0xf1, 0xb7, 0x14, 0xe9, 0xd4, 0xb1, 0x66, 0x8a, 0x74, 0xea, 0x2d, 0xd2, 0xa9, 0xd3,
		0xd8, 0xf1, 0xa4, 0x53, 0xe3, 0x35, 0xc0, 0x6b, 0xb0, 0xe6, 0x0d, 0xf0, 0x1a, 0x48, 0xed, 0x5d,
		0xbc, 0xfd, 0x78, 0xfb, 0x57, 0x8f, 0x8e, 0xb7, 0x5f, 0xff, 0xe6, 0x26, 0x9d, 0x9a, 0x3b, 0x9c,
		0x3b, 0x9c, 0x3b, 0x9c, 0x3b, 0x9c, 0x3b, 0x9c, 0x3b, 0x3c, 0xb5, 0x3b, 0x9c, 0x74, 0xea, 0x35,
		0xe9, 0xd4, 0x12, 0x59, 0xbb, 0x5b, 0x72, 0xd9, 0xd4, 0x17, 0xc3, 0x8f, 0x93, 0x55, 0x32, 0x75,
		0xaa, 0x0d, 0xb1, 0x85, 0x76, 0x85, 0xe4, 0x6e, 0xc8, 0xb8, 0xfd, 0xff, 0x69, 0xd5, 0xe6, 0xe6,
		0xff, 0x3d, 0xef, 0x7f, 0x7d, 0x2f, 0x68, 0x78, 0x8e, 0xdf, 0x54, 0x5e, 0xb0, 0x27, 0xbe, 0x3e,
		0x33, 0x98, 0xe2, 0xfe, 0xd1, 0xe3, 0xe6, 0xda, 0x5c, 0x5c, 0x82, 0x7b, 0xcf, 0x72, 0x6d, 0xb7,
		0xd1, 0xd2, 0xd9, 0x7e, 0x42, 0xac, 0x5a, 0x9c, 0x45, 0x8b, 0xb3, 0xe6, 0x45, 0x96, 0x3c, 0x98,
		0xb7, 0x9c, 0x20, 0x9e, 0x36, 0xdf, 0x9d, 0xee, 0x97, 0x96, 0xe7, 0xde, 0xea, 0x05, 0xb2, 0x4c,
		0xb9, 0xec, 0x81, 0xc6, 0x18, 0xe7, 0x63, 0xd0, 0x7d, 0xf3, 0x66, 0x5c, 0x96, 0x64, 0x7b, 0xf6,
		0x5c, 0xdb, 0x8c, 0x65, 0x5a, 0xa5, 0x3f, 0x44, 0x4a, 0x7e, 0x68, 0x96, 0xfa, 0xd0, 0x2e, 0xf1,
		0x01, 0x7e, 0x81, 0x5f, 0x09, 0x3f, 0xb9, 0x6e, 0x39, 0x8e, 0x4a, 0xd3, 0xeb, 0x35, 0x42, 0xbf,
		0x2b, 0x62, 0x09, 0xcc, 0x66, 0xec, 0x4e, 0x07, 0x95, 0xa9, 0xbe, 0xb3, 0x23, 0x55, 0x7d, 0x67,
		0xc7, 0xce, 0xea, 0x3b, 0x7a, 0x47, 0xd5, 0x94, 0x90, 0x97, 0xff, 0xba, 0x3b, 0x5a, 0x47, 0xd9,
		0x0e, 0x53, 0x5d, 0x4c, 0x92, 0x9b, 0xb9, 0x23, 0x43, 0x3f, 0x10, 0xa9, 0x57, 0x36, 0x55, 0xdf,
		0x72, 0x58, 0x6b, 0x6c, 0xa8, 0xe3, 0x7a, 0x4d, 0xa7, 0xd3, 0x88, 0xbc, 0x61, 0x20, 0xba, 0x10,
		0xf8, 0x2d, 0x8c, 0x0b, 0xfe, 0x81, 0x7f, 0xe0, 0x9f, 0x55, 0xf8, 0xd7, 0xe8, 0xf4, 0x83, 0xc8,
		0x0b, 0xeb, 0x35, 0x41, 0x08, 0x14, 0xf0, 0x3f, 0x08, 0x67, 0xc2, 0x09, 0xfa, 0x70, 0x4c, 0x64,
		0xba, 0x19, 0xca, 0x6d, 0x9a, 0xe6, 0x32, 0x49, 0x8f, 0x6b, 0x30, 0x6f, 0x49, 0x30, 0xf4, 0xd4,
		0x48, 0x5a, 0x9a, 0xe9, 0xa5, 0xda, 0x7d, 0x5b, 0xab, 0xd5, 0x0f, 0x6a, 0xb5, 0x9d, 0x83, 0xbd,
		0x83, 0x9d, 0xc3, 0xfd, 0xfd, 0xdd, 0xba, 0x74, 0xce, 0x8e, 0xd1, 0xd5, 0xb3, 0xc4, 0xa1, 0x74,
		0x95, 0x63, 0x0e, 0xd6, 0x75, 0x1b, 0xff, 0x35, 0x42, 0xc2, 0x26, 0x03, 0xc3, 0xc2, 0x60, 0x61,
		0xb0, 0x30, 0x58, 0x18, 0x2c, 0x0c, 0x16, 0x06, 0x0b, 0x83, 0x85, 0xc1, 0xc2, 0x66, 0x96, 0x45,
		0x22, 0x8c, 0x60, 0x09, 0xde, 0xf5, 0xc3, 0x09, 0x60, 0x5f, 0xb0, 0x2f, 0xd8, 0x97, 0x21, 0xf6,
		0xd5, 0xf7, 0x83, 0x68, 0xaf, 0x2a, 0x48, 0xbd, 0x0e, 0xa0, 0x5e, 0x50, 0x2f, 0xa8, 0x97, 0xd2,
		0x52, 0xd5, 0xaa, 0x87, 0xb5, 0xc3, 0xfa, 0x41, 0xf5, 0x10, 0xc2, 0x95, 0x1f, 0xc2, 0x55, 0xee,
		0xc8, 0x5c, 0xdd, 0x20, 0x6d, 0x89, 0xe0, 0x5c, 0x8d, 0xc8, 0xec, 0x74, 0x62, 0xda, 0xa2, 0xd0,
		0x0d, 0x7a, 0xdd, 0x4e, 0x18, 0xe9, 0xc7, 0xb5, 0x3d, 0x0d, 0x95, 0x71, 0x6c, 0x9b, 0x25, 0xb1,
		0xb9, 0x12, 0x79, 0x70, 0xe5, 0x8d, 0x70, 0x13, 0xc8, 0x63, 0xcb, 0x59, 0x9c, 0x5b, 0x63, 0xb2,
		0x7f, 0x85, 0xcc, 0x5b, 0x91, 0x9e, 0x7f, 0xe2, 0xbd, 0xe5, 0x76, 0xe8, 0x2d, 0x57, 0x3e, 0xfb,
		0x96, 0xde, 0x72, 0x8b, 0x03, 0xcd, 0x76, 0x8c, 0xd1, 0xba, 0x7e, 0xd7, 0x6e, 0xea, 0xa5, 0x77,
		0x20, 0xbb, 0xdd, 0x36, 0xa0, 0x30, 0x05, 0x18, 0xc6, 0x81, 0xc3, 0x38, 0x80, 0xa4, 0x00, 0x24,
		0xc2, 0x56, 0xa2, 0xf5, 0xd9, 0xed, 0x03, 0x0c, 0x70, 0x82, 0x7e, 0xdb, 0x09, 0x87, 0x12, 0x16,
		0x75, 0xed, 0x45, 0x67, 0x57, 0x2c, 0x60, 0x79, 0xed, 0xec, 0xbe, 0x35, 0x30, 0xb6, 0xa9, 0x84,
		0xf9, 0xe9, 0x1b, 0xbc, 0xac, 0xef, 0xef, 0xef, 0x7d, 0xdf, 0x71, 0xf6, 0xaf, 0x7e, 0xd5, 0xf7,
		0xf7, 0xbf, 0xef, 0x38, 0xd5, 0xab, 0xef, 0x3b, 0xce, 0xe1, 0xe0, 0x5f, 0xdf, 0x77, 0x9c, 0xda,
		0xe8, 0x1f, 0x7f, 0x57, 0x1f, 0x7f, 0xd5, 0x67, 0xfe, 0xb9, 0xf7, 0xf8, 0x6b, 0xf8, 0x92, 0xd1,
		0xbf, 0x6a, 0xc3, 0x7f, 0x1d, 0x5e, 0xfd, 0xbd, 0xfb, 0xba, 0xf6, 0xf8, 0xea, 0xcf, 0x3f, 0xdf,
		0xfc, 0xf9, 0xe7, 0x1b, 0xf1, 0x61, 0xe5, 0x4b, 0x11, 0x5e, 0x99, 0x58, 0x2e, 0x93, 0x45, 0x0e,
		0xa6, 0xef, 0xf2, 0x9f, 0xbc, 0x2c, 0xda, 0x3f, 0x2a, 0xd4, 0x39, 0x17, 0xbe, 0x1c, 0x6e, 0xbc,
		0x90, 0xde, 0x1c, 0x46, 0xa7, 0x7c, 0xfa, 0xc1, 0x8b, 0xd8, 0x9b, 0x63, 0x87, 0xc6, 0x1c, 0xb1,
		0x96, 0x9e, 0xc6, 0x1c, 0xd6, 0x2f, 0x3f, 0x8d, 0x39, 0xac, 0xbe, 0xb0, 0xbc, 0xa0, 0xdf, 0xf6,
		0x42, 0x57, 0x20, 0x7f, 0xf7, 0x59, 0xd2, 0x5d, 0x33, 0x30, 0xf6, 0x71, 0xd0, 0x6f, 0x0f, 0x8e,
		0x3f, 0xc5, 0x9f, 0x8d, 0x6f, 0xc6, 0x49, 0x85, 0x47, 0x33, 0x0a, 0xdb, 0xec, 0xe0, 0x88, 0x6b,
		0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b,
		0xd8, 0x2a, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b,
		0x88, 0x6b, 0x45, 0x13, 0xd7, 0xa2, 0x46, 0xd7, 0xb9, 0x6d, 0xb9, 0x77, 0x3d, 0x79, 0x69, 0xed,
		0x69, 0x68, 0x84, 0x35, 0x84, 0x35, 0x84, 0xb5, 0xd2, 0x0a, 0x6b, 0x66, 0x1a, 0xb0, 0x9b, 0x68,
		0xbc, 0x6e, 0xb6, 0xe1, 0xfa, 0x74, 0x42, 0x2e, 0x3f, 0x9c, 0x5f, 0x7f, 0x3c, 0x3d, 0xfa, 0xfd,
		0xa2, 0x62, 0x22, 0xd3, 0xcf, 0x4c, 0x83, 0x75, 0xc3, 0xbd, 0xe7, 0x87, 0x53, 0x72, 0x62, 0xa0,
		0x3f, 0xb8, 0x01, 0x33, 0x25, 0x85, 0xa9, 0xf8, 0xf0, 0xaf, 0x2f, 0x4c, 0xc5, 0x68, 0x2a, 0xce,
		0x2f, 0xfe, 0x8f, 0xa9, 0x18, 0x4d, 0xc5, 0xc5, 0x1f, 0x1c, 0x90, 0xf1, 0x54, 0x1c, 0x9b, 0x68,
		0x3d, 0x9d, 0xcf, 0xa9, 0x38, 0xfa, 0xf0, 0x4f, 0xa6, 0x62, 0x34, 0x15, 0x5f, 0x2e, 0x2e, 0x99,
		0x8a, 0xd1, 0x54, 0x7c, 0xfd, 0xf2, 0x7b, 0xc5, 0xf2, 0x5e, 0xe7, 0x57, 0x05, 0x65, 0xd2, 0xa7,
		0x7e, 0x2f, 0x3a, 0x8a, 0xa2, 0x50, 0x96, 0x4d, 0x7f, 0xf2, 0x83, 0xe3, 0x96, 0x37, 0xb0, 0x48,
		0x7a, 0xb2, 0xaa, 0x65, 0xe5, 0x93, 0xfb, 0x73, 0x66, 0x64, 0xb3, 0x05, 0xba, 0x2a, 0x67, 0x61,
		0xd3, 0x0b, 0xbd, 0xe6, 0xfb, 0x87, 0xca, 0xbb, 0xad, 0xa0, 0xdf, 0x6a, 0xd1, 0x27, 0xcf, 0xe6,
		0x3e, 0x79, 0xd3, 0x7a, 0x00, 0xdb, 0x22, 0x99, 0xc8, 0x5b, 0x42, 0x25, 0x19, 0x2e, 0x27, 0x1f,
		0xeb, 0x7a, 0x2c, 0xe2, 0xe4, 0xb1, 0x1c, 0x9a, 0x56, 0x27, 0xa2, 0x25, 0xcc, 0x97, 0x68, 0x67,
		0x28, 0x9e, 0x28, 0x5e, 0x25, 0x51, 0xdc, 0x1a, 0xe5, 0x8c, 0x44, 0xf1, 0xa4, 0xcf, 0x45, 0xa2,
		0x38, 0x92, 0x3b, 0x92, 0xbb, 0x79, 0x00, 0x49, 0x01, 0x48, 0xec, 0x34, 0x14, 0x88, 0x65, 0x9d,
		0x9b, 0x07, 0x62, 0x59, 0x89, 0x65, 0x25, 0x96, 0x75, 0xba, 0x5c, 0xc4, 0xb2, 0x12, 0xcb, 0x6a,
		0x04, 0xbe, 0x88, 0x65, 0x4d, 0x6b, 0xca, 0x67, 0xc5, 0x3b, 0x62, 0x59, 0x13, 0xbe, 0x0f, 0xb1,
		0xac, 0xd6, 0x2e, 0x3d, 0xb1, 0xac, 0x99, 0x8c, 0x4a, 0x2c, 0x2b, 0xb1, 0xac, 0xc2, 0x5b, 0x8b,
		0x44, 0xf1, 0xb8, 0x36, 0x1f, 0x89, 0xe2, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88,
		0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0xd8, 0x2a, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88,
		0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x88, 0x6b, 0x05, 0x16, 0xd7, 0x48, 0x14, 0x47, 0x58,
		0x43, 0x58, 0x43, 0x58, 0x23, 0x51, 0x7c, 0x8b, 0x44, 0xf1, 0xf4, 0x0d, 0x3d, 0x12, 0xc5, 0x57,
		0x4f, 0x05, 0x89, 0xe2, 0x24, 0x8a, 0x2f, 0x4f, 0x05, 0x89, 0xe2, 0x24, 0x8a, 0x2f, 0x4f, 0x05,
		0x89, 0xe2, 0x24, 0x8a, 0x2f, 0x4f, 0x05, 0x89, 0xe2, 0x99, 0x31, 0x69, 0x12, 0xc5, 0x9f, 0x79,
		0x33, 0x12, 0xc5, 0x57, 0xd9, 0x9a, 0xf6, 0x27, 0x8a, 0x4b, 0x24, 0x22, 0x6f, 0x89, 0xe7, 0x89,
		0x6b, 0x34, 0xf1, 0xd7, 0x5f, 0xf9, 0x74, 0x9b, 0x98, 0x0b, 0xed, 0x11, 0x03, 0x7b, 0xa3, 0xa2,
		0x95, 0x2e, 0x2f, 0xb7, 0x1b, 0xd4, 0xf6, 0x41, 0xf2, 0x55, 0x4c, 0xf6, 0x8a, 0x84, 0xeb, 0x5d,
		0xf9, 0xa7, 0xf7, 0x30, 0x8c, 0x97, 0xf1, 0xfe, 0xd7, 0xf7, 0x82, 0x86, 0xe7, 0xf8, 0xcd, 0x84,
		0xf3, 0xab, 0x77, 0xff, 0xe8, 0xdf, 0x33, 0x46, 0xee, 0x13, 0xbd, 0x7b, 0x23, 0xe9, 0x1a, 0x68,
		0x9e, 0x35, 0xb1, 0x33, 0xa6, 0x70, 0xb2, 0x04, 0x4e, 0x54, 0xb2, 0x73, 0x14, 0xff, 0x34, 0xc4,
		0xfb, 0xcd, 0x98, 0x6b, 0xa5, 0xba, 0x46, 0x9a, 0x6b, 0x93, 0x60, 0x45, 0xd4, 0x57, 0x22, 0xde,
		0x02, 0x6c, 0x9e, 0xce, 0x18, 0x53, 0x59, 0x69, 0x4c, 0xbc, 0x20, 0xf1, 0xa6, 0x70, 0x6a, 0x63,
		0x24, 0x2a, 0x1c, 0x93, 0xb0, 0x02, 0x49, 0x62, 0xd7, 0x8c, 0x8a, 0xeb, 0x65, 0xd6, 0xb5, 0xe2,
		0x36, 0x5a, 0x49, 0x16, 0x56, 0xd1, 0x69, 0xa2, 0xed, 0x14, 0xd1, 0x76, 0x7a, 0x2c, 0x3a, 0x35,
		0x06, 0xcf, 0x9d, 0xd1, 0xf1, 0x4d, 0x5a, 0x85, 0xa3, 0xd2, 0xf4, 0x7a, 0x8d, 0xd0, 0xef, 0x2a,
		0x81, 0xf2, 0x6c, 0x41, 0x8d, 0xe9, 0x20, 0x49, 0xef, 0x65, 0x25, 0xef, 0xa3, 0xb2, 0x97, 0x51,
		0xc7, 0x9b, 0xa8, 0xbe, 0xb5, 0x75, 0xb7, 0xb8, 0xd8, 0x56, 0x17, 0xdb, 0xf2, 0x22, 0x5b, 0x3f,
		0x1d, 0xe6, 0xa7, 0xec, 0x81, 0xd3, 0x0f, 0xb2, 0x7e, 0x0a, 0xa2, 0x36, 0x75, 0xf7, 0x27, 0x80,
		0xd7, 0xf1, 0x8d, 0xa9, 0x78, 0xc4, 0x87, 0xaf, 0xe6, 0x6c, 0x73, 0xb6, 0x39, 0xdb, 0x16, 0x9e,
		0xed, 0x48, 0x65, 0x1e, 0x9e, 0x42, 0x8a, 0x06, 0xaf, 0xe6, 0x6c, 0x73, 0xb6, 0x0b, 0x76, 0xb6,
		0xf5, 0x22, 0x64, 0x74, 0x22, 0x61, 0x64, 0x22, 0x5e, 0xa6, 0x0f, 0x72, 0xf4, 0xe1, 0xf4, 0xfa,
		0xf2, 0x8f, 0xf3, 0x63, 0xd5, 0x5d, 0x23, 0x10, 0xc0, 0x22, 0x54, 0x78, 0x73, 0xf0, 0x24, 0x27,
		0xe7, 0xdf, 0x6a, 0x95, 0x2c, 0xaa, 0x88, 0x0a, 0x3e, 0xc3, 0xa7, 0x93, 0x7f, 0x1f, 0xff, 0x96,
		0xf7, 0x87, 0x38, 0xad, 0xe6, 0xfd, 0x09, 0x4e, 0xce, 0xbf, 0xd5, 0x2b, 0x29, 0x7b, 0x1a, 0xae,
		0x4c, 0xe3, 0x64, 0xf1, 0x95, 0xbf, 0xc4, 0xe5, 0x91, 0x93, 0x8a, 0x7e, 0x49, 0x0a, 0x1d, 0xcb,
		0x08, 0x7e, 0x89, 0xac, 0x2b, 0x15, 0xab, 0x2a, 0x21, 0xe3, 0x42, 0xec, 0x2b, 0xbe, 0xd8, 0x97,
		0x98, 0x21, 0x4d, 0xd7, 0xab, 0xe5, 0xb9, 0xb7, 0xc9, 0x58, 0xd1, 0x94, 0x0d, 0x1d, 0x24, 0x78,
		0xcd, 0xf9, 0x18, 0x14, 0xde, 0xbc, 0x19, 0x1f, 0xf9, 0xed, 0xe1, 0x86, 0x4f, 0xf1, 0x58, 0x26,
		0xab, 0x1b, 0xae, 0x54, 0x1f, 0x5c, 0x59, 0x85, 0xaf, 0x72, 0x30, 0x0b, 0x7a, 0x30, 0x51, 0xe1,
		0xb1, 0xe6, 0xb1, 0xe6, 0x51, 0xea, 0x74, 0x79, 0xa2, 0x0e, 0x5f, 0xe4, 0x6c, 0x73, 0xb6, 0x39,
		0xdb, 0xa9, 0x9e, 0x6d, 0x54, 0x78, 0xce, 0x36, 0x67, 0x7b, 0x71, 0xbd, 0x51, 0xe1, 0xc7, 0xe3,
		0xa0, 0xc2, 0x4b, 0x3f, 0x03, 0x2a, 0x3c, 0x2a, 0xbc, 0x29, 0x9c, 0x2c, 0xbe, 0x0a, 0x9f, 0x34,
		0xf7, 0x24, 0xa9, 0x08, 0x9f, 0x20, 0x8b, 0x44, 0x46, 0xec, 0x4b, 0xc4, 0xbf, 0x54, 0x78, 0x17,
		0x1a, 0x3c, 0x52, 0x9f, 0x2e, 0x3f, 0xca, 0x5e, 0x83, 0x1f, 0x6e, 0x78, 0xa9, 0x63, 0xf9, 0x42,
		0x63, 0x12, 0x27, 0x49, 0x39, 0x03, 0x44, 0xd9, 0x8a, 0x71, 0x0c, 0x93, 0xa5, 0xe0, 0x24, 0x4f,
		0xb9, 0x11, 0x49, 0xb1, 0x49, 0x96, 0x52, 0xb3, 0x69, 0x86, 0x12, 0x5e, 0x07, 0x0a, 0xd7, 0x40,
		0x25, 0x96, 0x17, 0x25, 0x09, 0xf0, 0x3f, 0xbf, 0xb7, 0xd6, 0xef, 0x98, 0xd5, 0x3f, 0x59, 0x33,
		0x43, 0x71, 0x67, 0x26, 0xc1, 0x8c, 0x3c, 0x33, 0x13, 0x71, 0x67, 0x60, 0xf5, 0xa3, 0x2f, 0x3f,
		0xd8, 0x8a, 0x87, 0xda, 0x94, 0x32, 0x12, 0x2f, 0x45, 0x64, 0x83, 0x33, 0x6a, 0xe3, 0x8d, 0x14,
		0xe7, 0x06, 0x8a, 0x7f, 0xe3, 0xc4, 0xbd, 0x61, 0x12, 0xdf, 0x28, 0x89, 0x6f, 0x90, 0x44, 0x37,
		0x46, 0x56, 0x1b, 0x71, 0x63, 0x58, 0xc4, 0xc6, 0x6d, 0xf8, 0x5c, 0xdc, 0x43, 0xbc, 0x5d, 0xe8,
		0x07, 0x91, 0x17, 0xde, 0xba, 0x0d, 0xaf, 0xb7, 0x79, 0x27, 0xce, 0xfc, 0x2e, 0xbb, 0xd1, 0x92,
		0xdd, 0xb8, 0xc9, 0xf5, 0xf8, 0xb4, 0x68, 0x9b, 0xe7, 0x61, 0x69, 0x9d, 0x37, 0xcd, 0x43, 0x3c,
		0x4f, 0x78, 0x6c, 0x5a, 0x9c, 0x84, 0x0e, 0x27, 0xa7, 0xc1, 0x49, 0xe9, 0xaf, 0x32, 0xed, 0x55,
		0xa6, 0xbb, 0x4a, 0x34, 0x57, 0x8f, 0x91, 0xc5, 0xf5, 0x5c, 0x93, 0xe0, 0x88, 0xbd, 0x95, 0x89,
		0xbd, 0x95, 0x38, 0xb4, 0xc2, 0x6f, 0xaa, 0xbb, 0x64, 0x92, 0x17, 0x09, 0xc0, 0x21, 0x93, 0xe6,
		0xc6, 0x16, 0xdb, 0xe0, 0x22, 0x1b, 0x5d, 0x51, 0x68, 0x4c, 0xdf, 0x21, 0x33, 0xb9, 0xce, 0x93,
		0x17, 0xc1, 0xd8, 0x4a, 0xc5, 0xe5, 0x9a, 0x13, 0x41, 0xf5, 0x89, 0xfe, 0x3e, 0x7d, 0x69, 0x20,
		0xb4, 0xf9, 0x64, 0xfa, 0x36, 0x4f, 0x5f, 0x66, 0x10, 0xe0, 0xec, 0xdd, 0x85, 0x5e, 0xaf, 0xe7,
		0x4c, 0x8d, 0xe5, 0xc4, 0x37, 0xff, 0xe2, 0x00, 0x50, 0x00, 0x28, 0x40, 0x3a, 0x14, 0x60, 0x7e,
		0xe7, 0xa9, 0xd3, 0x81, 0x85, 0x71, 0xd4, 0xa8, 0xc1, 0x2e, 0xd4, 0x00, 0x6a, 0x60, 0x86, 0x1a,
		0x24, 0x3d, 0x18, 0xd3, 0x17, 0xce, 0x56, 0xe2, 0xd1, 0x0e, 0x93, 0x50, 0x2b, 0xeb, 0x23, 0x70,
		0x54, 0x96, 0x8f, 0x4c, 0x55, 0x71, 0x00, 0x81, 0x96, 0x03, 0xfa, 0x47, 0x48, 0xea, 0x28, 0x89,
		0x1f, 0x29, 0xf1, 0xa3, 0x25, 0x7a, 0xc4, 0xd4, 0x8e, 0x9a, 0xe2, 0x91, 0xd3, 0x3e, 0x7a, 0x4b,
		0x47, 0xf0, 0x41, 0x7f, 0x9d, 0x17, 0x0f, 0xe2, 0x83, 0xee, 0x3a, 0xeb, 0x1d, 0x47, 0xed, 0x9b,
		0xcc, 0xc4, 0xf1, 0x94, 0x3f, 0xa6, 0xd2, 0xc7, 0xd5, 0xd8, 0xb1, 0x35, 0x76, 0x7c, 0x8d, 0x1c,
		0x63, 0xbd, 0xe3, 0xac, 0x79, 0xac, 0xc5, 0x8e, 0xf7, 0x93, 0xb1, 0x37, 0x53, 0x7f, 0x52, 0xbe,
		0xeb, 0xb6, 0x72, 0x71, 0x4b, 0x61, 0x3d, 0xcb, 0x38, 0x04, 0x98, 0x80, 0x02, 0x73, 0x90, 0x60,
		0x0a, 0x1a, 0x8c, 0x43, 0x84, 0x71, 0xa8, 0x30, 0x0a, 0x19, 0x32, 0xd0, 0x21, 0x04, 0x21, 0xfa,
		0xfa, 0xdd, 0xc6, 0xfd, 0x9a, 0x3c, 0xa0, 0x28, 0xf6, 0xcd, 0x7f, 0x20, 0x38, 0xe6, 0x4c, 0x40,
		0xd2, 0x30, 0x02, 0x71, 0x7b, 0x16, 0xb6, 0x0a, 0xd4, 0x03, 0x2e, 0x59, 0xea, 0x71, 0x7c, 0x90,
		0x17, 0xaa, 0x18, 0x2e, 0xc8, 0xec, 0xc4, 0x0c, 0x2f, 0xe0, 0x1d, 0x78, 0xcf, 0x39, 0xbc, 0x4b,
		0x31, 0xc5, 0xe9, 0x80, 0xc3, 0xee, 0x78, 0x5e, 0xd3, 0xe9, 0x34, 0xa2, 0x24, 0xb2, 0x7b, 0xe2,
		0xe3, 0xb0, 0xf0, 0x3e, 0xc2, 0x1b, 0xc0, 0x4c, 0x57, 0x60, 0x71, 0x3e, 0x69, 0x12, 0x78, 0xcc,
		0x03, 0x90, 0x69, 0x20, 0x4a, 0x0d, 0x90, 0x52, 0x03, 0xa6, 0x54, 0x00, 0x4a, 0x16, 0xa8, 0x84,
		0x01, 0xcb, 0x1c, 0x2f, 0x5d, 0xda, 0xef, 0x8d, 0x4e, 0x3f, 0x88, 0xbc, 0xb0, 0x5e, 0x33, 0xd8,
		0x39, 0xf9, 0x2d, 0xad, 0xfe, 0x9f, 0x3e, 0x38, 0xad, 0xfe, 0x93, 0xbf, 0x0f, 0xad, 0xfe, 0xad,
		0x5d, 0x7a, 0xb3, 0x2d, 0xb4, 0x32, 0xdf, 0x0d, 0xe5, 0xec, 0xfc, 0xff, 0xc2, 0xc2, 0xd3, 0x34,
		0xe5, 0xc2, 0x5d, 0xb7, 0xf1, 0xdf, 0x54, 0x48, 0xf7, 0xe4, 0x8d, 0x60, 0xdd, 0xb0, 0x6e, 0x58,
		0x37, 0xac, 0x1b, 0xd6, 0x0d, 0xeb, 0x86, 0x75, 0xc3, 0xba, 0x61, 0xdd, 0xb0, 0xee, 0xd2, 0xb0,
		0x6e, 0x13, 0xb1, 0x11, 0x4b, 0xd7, 0xa1, 0x7c, 0x8c, 0x04, 0x6c, 0x1b, 0xb6, 0x0d, 0xdb, 0x86,
		0x6d, 0x1b, 0x8a, 0xc1, 0x58, 0x84, 0x17, 0xc9, 0x58, 0x8c, 0x27, 0x28, 0x98, 0xa4, 0x39, 0xad,
		0xaa, 0x10, 0xf2, 0x3d, 0x70, 0xdb, 0xde, 0xff, 0xd7, 0xe8, 0x87, 0xa1, 0x17, 0x44, 0x2f, 0x5f,
		0x6d, 0xbf, 0x79, 0xf3, 0xf4, 0xbf, 0x9e, 0x17, 0x39, 0x83, 0x1f, 0x5f, 0x7d, 0x8f, 0x1e, 0xba,
		0xeb, 0x7e, 0x69, 0xf0, 0xa3, 0xab, 0x35, 0xed, 0xae, 0xc5, 0x83, 0x3f, 0x0c, 0xdc, 0x71, 0x56,
		0x39, 0x98, 0x85, 0x9b, 0xda, 0x3f, 0xdd, 0xbe, 0x6a, 0xf9, 0x6e, 0x0b, 0x59, 0x5d, 0x0b, 0xff,
		0x5e, 0xb7, 0xe8, 0x82, 0x31, 0x2c, 0x5b, 0xca, 0x39, 0x74, 0xc7, 0xc3, 0x8f, 0x3a, 0xa9, 0x5d,
		0x33, 0xfb, 0xaf, 0x95, 0x0d, 0xd1, 0x05, 0x9a, 0xe2, 0xcb, 0xed, 0xa8, 0x6c, 0xc3, 0x61, 0xb5,
		0x9b, 0xa9, 0x2f, 0x8d, 0xa8, 0xd5, 0x5c, 0x7d, 0x95, 0x09, 0xae, 0xd7, 0x6c, 0x7d, 0x95, 0x65,
		0x27, 0xde, 0x7c, 0x7d, 0xe9, 0x4d, 0xb4, 0x9a, 0xb1, 0x4b, 0xaf, 0xb1, 0x30, 0xce, 0xa4, 0x89,
		0x2f, 0x15, 0x91, 0xe8, 0x3d, 0xe3, 0x88, 0xa2, 0x87, 0x25, 0x8f, 0x39, 0xc9, 0x8c, 0x11, 0xda,
		0x47, 0xe6, 0xf7, 0x8f, 0x4e, 0x8a, 0x96, 0xb9, 0xdd, 0xa2, 0xb6, 0x49, 0x92, 0x2f, 0xb1, 0xc2,
		0xf2, 0x26, 0xad, 0x01, 0xb3, 0x96, 0x34, 0x27, 0xce, 0x99, 0x5f, 0xc9, 0x8b, 0x75, 0x93, 0x05,
		0x77, 0x48, 0x16, 0x34, 0x68, 0xfe, 0x92, 0x2c, 0xf8, 0xf4, 0xc9, 0xb5, 0x93, 0x05, 0x27, 0x56,
		0x97, 0x5c, 0xae, 0xe0, 0x74, 0x44, 0x99, 0x54, 0xc1, 0x1d, 0x52, 0x05, 0x33, 0xd0, 0xb0, 0x48,
		0x15, 0xb4, 0xc0, 0x36, 0x12, 0xd3, 0x98, 0x0c, 0x68, 0x4a, 0x92, 0x1a, 0xd2, 0x6c, 0x1e, 0xcf,
		0xc2, 0xff, 0xd6, 0xf4, 0xfb, 0x4c, 0xd0, 0xfc, 0xcf, 0x00, 0xe9, 0xd5, 0xb8, 0x53, 0x23, 0x89,
		0x25, 0xd5, 0xe9, 0xf3, 0x02, 0xcc, 0x02, 0xb3, 0xc0, 0x2c, 0x30, 0xfb, 0x3c, 0xcc, 0xae, 0xd0,
		0xe9, 0xa7, 0xf2, 0x7c, 0xf2, 0xda, 0xef, 0xe8, 0x0e, 0x26, 0x75, 0x07, 0x2d, 0x93, 0xd7, 0x88,
		0xe4, 0x90, 0xa4, 0xa2, 0x5c, 0x36, 0x72, 0x83, 0xb6, 0xd5, 0x23, 0x65, 0xed, 0x68, 0x5e, 0xbf,
		0x48, 0x0e, 0x48, 0x0e, 0x69, 0xa3, 0xa1, 0xf6, 0x75, 0x29, 0x78, 0x4d, 0x4a, 0x5c, 0x8f, 0x2b,
		0xda, 0x9a, 0x4c, 0x0f, 0xb5, 0xcd, 0x10, 0xa6, 0x55, 0x13, 0x40, 0xa4, 0x06, 0x00, 0xc5, 0xd5,
		0x00, 0x2f, 0xf4, 0x52, 0xf4, 0x52, 0x0c, 0x79, 0x0c, 0x79, 0x0c, 0x79, 0xf4, 0x52, 0xf4, 0x52,
		0x60, 0x16, 0x98, 0x05, 0x66, 0xd1, 0x4b, 0xd1, 0x4b, 0xed, 0xd5, 0x4b, 0x75, 0x23, 0x86, 0xc5,
		0xe5, 0x52, 0x8d, 0x68, 0xe0, 0x74, 0xa4, 0x06, 0xad, 0x4b, 0x58, 0xe2, 0xf2, 0x45, 0x25, 0x45,
		0x68, 0x40, 0x25, 0xb5, 0x4d, 0x25, 0x55, 0xbf, 0xd0, 0x1e, 0x2d, 0xeb, 0x76, 0x31, 0x4d, 0x42,
		0x18, 0x5d, 0xd9, 0x5b, 0x0a, 0x50, 0xa5, 0x97, 0x76, 0xa0, 0x9f, 0x66, 0x60, 0x24, 0xad, 0x40,
		0x2f, 0x8d, 0x20, 0xe9, 0x2a, 0x68, 0xd2, 0x06, 0x33, 0x74, 0xa1, 0xa2, 0x24, 0xcd, 0x8b, 0x12,
		0x84, 0x0a, 0xcd, 0xd1, 0x36, 0xae, 0x9a, 0xf1, 0x2e, 0x69, 0x73, 0xcb, 0x93, 0x66, 0xb3, 0xb4,
		0x04, 0x19, 0xec, 0xc9, 0x9b, 0x4d, 0x26, 0x24, 0x56, 0xb4, 0x44, 0x33, 0x44, 0x7c, 0x2c, 0x6a,
		0x89, 0x96, 0x98, 0xb8, 0x68, 0x10, 0x15, 0x15, 0x62, 0xb2, 0x82, 0x88, 0xc4, 0xcd, 0xf7, 0x15,
		0x3a, 0x90, 0x81, 0x6e, 0xfb, 0xc2, 0xa5, 0x11, 0xe8, 0x5f, 0xc8, 0x61, 0x55, 0x3a, 0xac, 0xc9,
		0x5b, 0x18, 0x07, 0x42, 0x0d, 0x0c, 0x17, 0x07, 0xa2, 0x83, 0xa1, 0x39, 0x83, 0x9d, 0x0e, 0x86,
		0x74, 0x30, 0x24, 0xc8, 0x06, 0xed, 0x8b, 0x0e, 0x86, 0xfa, 0x07, 0x91, 0x0e, 0x86, 0x69, 0x1c,
		0x53, 0xe9, 0xe3, 0x6a, 0xec, 0xd8, 0x1a, 0x3b, 0xbe, 0x46, 0x8e, 0xb1, 0xde, 0x71, 0xd6, 0x3c,
		0xd6, 0x62, 0xc7, 0xfb, 0x49, 0x88, 0xa1, 0x83, 0x21, 0x1d, 0x0c, 0x69, 0x71, 0x95, 0x0a, 0x64,
		0xc8, 0x40, 0x87, 0x10, 0x84, 0xa8, 0x8b, 0x4d, 0x06, 0xc5, 0x28, 0x13, 0x62, 0x55, 0x12, 0x31,
		0x8b, 0x0e, 0x86, 0x0a, 0x20, 0x4f, 0x07, 0x43, 0xe0, 0x1d, 0x78, 0xb7, 0x15, 0xde, 0xe9, 0x60,
		0x98, 0x02, 0x8f, 0x34, 0xc6, 0x27, 0x4d, 0x02, 0x8f, 0x79, 0x00, 0x32, 0x0d, 0x44, 0xa9, 0x01,
		0x52, 0x6a, 0xc0, 0x94, 0x0a, 0x40, 0xc9, 0x02, 0x95, 0x30, 0x60, 0x99, 0xe3, 0xa5, 0x4b, 0xfb,
		0x9d, 0x5e, 0x2a, 0xab, 0xfe, 0xd0, 0x4b, 0x25, 0xd6, 0xdb, 0xd0, 0x4b, 0x25, 0xd9, 0xd2, 0xd3,
		0x4b, 0x25, 0x6f, 0xbb, 0x81, 0x5e, 0x2a, 0xb6, 0x9c, 0x26, 0x3a, 0x18, 0xc2, 0xba, 0x61, 0xdd,
		0xb0, 0x6e, 0x58, 0x37, 0xac, 0x1b, 0xd6, 0x0d, 0xeb, 0x86, 0x75, 0xc3, 0xba, 0x61, 0xdd, 0xc6,
		0x59, 0x37, 0x1d, 0x0c, 0x61, 0xdb, 0xb0, 0x6d, 0xd8, 0x76, 0x9e, 0xd9, 0x36, 0x1d, 0x0c, 0xe9,
		0x60, 0x68, 0x74, 0x2f, 0xdb, 0xd6, 0xc1, 0x70, 0x31, 0xb1, 0x6b, 0xf1, 0x1b, 0x56, 0xf7, 0x30,
		0x3c, 0x09, 0xe6, 0x32, 0x90, 0xe7, 0xfe, 0x49, 0x17, 0xc3, 0x8d, 0xf7, 0x23, 0x5d, 0x0c, 0xe9,
		0x62, 0x68, 0x2f, 0xc6, 0x64, 0xd6, 0xc7, 0x30, 0x29, 0xaa, 0x50, 0x21, 0xcb, 0xb2, 0x3d, 0x94,
		0x7a, 0xa5, 0xac, 0x98, 0x3b, 0x86, 0x6e, 0x86, 0x71, 0x39, 0x32, 0x45, 0xb3, 0x48, 0x1c, 0xcc,
		0x07, 0x2c, 0x52, 0x9d, 0x3b, 0x2d, 0xfd, 0x8b, 0xb4, 0x41, 0xd2, 0x06, 0x53, 0xe6, 0xcf, 0x94,
		0x8d, 0xa5, 0x3a, 0xf7, 0xb3, 0xcb, 0x49, 0x75, 0x6e, 0x60, 0x16, 0x98, 0x05, 0x66, 0xc5, 0x61,
		0x96, 0xea, 0xdc, 0x79, 0xd2, 0x1e, 0x32, 0xea, 0x67, 0xf8, 0xac, 0xec, 0x40, 0x47, 0xc3, 0xb4,
		0xae, 0x60, 0x64, 0x07, 0x64, 0x07, 0x6a, 0x75, 0xd3, 0xd1, 0x50, 0x03, 0xbf, 0xe8, 0x68, 0x08,
		0x78, 0xa1, 0x99, 0xa2, 0x99, 0x62, 0xcc, 0x63, 0xcc, 0x63, 0xcc, 0xa3, 0x99, 0xa2, 0x99, 0x02,
		0xb3, 0xc0, 0x2c, 0x30, 0x0b, 0xcc, 0xa2, 0x99, 0x16, 0x54, 0x33, 0xcd, 0xa6, 0xa7, 0xe1, 0xb3,
		0x92, 0x29, 0x5d, 0x0d, 0x51, 0x4a, 0x11, 0x1b, 0x50, 0x4a, 0xf3, 0xa6, 0x94, 0xd2, 0xd5, 0x70,
		0x76, 0x0c, 0xba, 0x1a, 0xea, 0xae, 0x42, 0x46, 0x5d, 0x0d, 0x37, 0x51, 0x86, 0xd4, 0xfa, 0x1a,
		0x3e, 0x47, 0x12, 0xe8, 0x6c, 0x18, 0x63, 0xe5, 0x8c, 0xb7, 0x36, 0x9c, 0x5f, 0xa1, 0x74, 0x5b,
		0xa9, 0x8d, 0x3f, 0x83, 0x33, 0xb8, 0x0a, 0x14, 0xfa, 0xa8, 0xcd, 0xbe, 0xbc, 0x18, 0x4d, 0xd4,
		0xfc, 0xdb, 0x52, 0xf6, 0x50, 0xf3, 0x6f, 0x73, 0xd3, 0x42, 0x4d, 0x31, 0xb9, 0x43, 0x2f, 0xa9,
		0x23, 0xaf, 0x0d, 0xd3, 0xfc, 0x5b, 0xfa, 0xa5, 0x69, 0x6e, 0xf7, 0x74, 0xc8, 0xa2, 0x72, 0xbb,
		0xb4, 0x29, 0x08, 0xeb, 0xdb, 0xd2, 0x4f, 0x43, 0x61, 0x50, 0x2b, 0x1f, 0x1e, 0xec, 0x69, 0x95,
		0xc3, 0x85, 0x39, 0x2d, 0x6a, 0x4e, 0x6f, 0x0f, 0x97, 0xe1, 0xdd, 0x0c, 0xbf, 0x5d, 0xf8, 0xc6,
		0xf8, 0xdf, 0xd6, 0x87, 0x24, 0xf5, 0x6f, 0x04, 0xf1, 0x6d, 0x6e, 0x34, 0x20, 0x0e, 0x88, 0x03,
		0xe2, 0x0a, 0x0c, 0x71, 0xdf, 0x9f, 0x20, 0x6e, 0xde, 0x8f, 0x36, 0xfd, 0x8d, 0xab, 0xf1, 0x4b,
		0x66, 0x71, 0xa1, 0xb7, 0xe2, 0x7b, 0xd3, 0x91, 0x9b, 0xde, 0xcf, 0x62, 0x48, 0x93, 0xc7, 0x3f,
		0x87, 0x7a, 0x5e, 0xf2, 0x72, 0xa6, 0xfa, 0x06, 0x41, 0xa7, 0xe1, 0x78, 0x3f, 0xa3, 0x77, 0x91,
		0xd7, 0xf2, 0xda, 0x5e, 0x14, 0x3e, 0x38, 0x9d, 0xc0, 0x69, 0xfc, 0x18, 0xd6, 0x57, 0x15, 0x31,
		0x12, 0x6e, 0xdd, 0x56, 0x4f, 0xc2, 0x4a, 0x30, 0x6d, 0x20, 0x5c, 0xe5, 0x45, 0xc7, 0x9c, 0xd1,
		0x78, 0xd4, 0x73, 0x43, 0x54, 0x95, 0xb1, 0xf1, 0x57, 0x5f, 0xbc, 0x5b, 0xa5, 0x1c, 0x90, 0x04,
		0x92, 0x65, 0x22, 0x95, 0x4f, 0x25, 0x50, 0x5a, 0x2b, 0x40, 0x5a, 0x5b, 0x7f, 0xa8, 0xa2, 0x3f,
		0xa0, 0x3f, 0xa0, 0x3f, 0x40, 0xce, 0x21, 0xe7, 0x90, 0x73, 0xf4, 0x07, 0xf4, 0x07, 0x20, 0x0e,
		0x88, 0x03, 0xe2, 0xd0, 0x1f, 0x32, 0x61, 0x9b, 0x56, 0x18, 0xb3, 0xaa, 0x41, 0xbb, 0x02, 0xb6,
		0xac, 0x42, 0x70, 0x6e, 0x69, 0xa2, 0x6f, 0x92, 0xc7, 0x94, 0xc8, 0x2c, 0x4a, 0x9a, 0x81, 0x37,
		0xc9, 0x14, 0x04, 0x25, 0xe5, 0x40, 0x39, 0xd0, 0xa6, 0x9a, 0x4e, 0xa0, 0x4d, 0xb2, 0x68, 0xe5,
		0xe2, 0x44, 0xda, 0x24, 0x8a, 0x36, 0xce, 0x38, 0xd4, 0x46, 0xa1, 0xf7, 0xc9, 0x93, 0x31, 0xdf,
		0x54, 0x94, 0xb8, 0x76, 0x72, 0x16, 0x62, 0xa3, 0x16, 0x76, 0x5f, 0x7c, 0x8d, 0x4b, 0x29, 0xac,
		0xde, 0x2c, 0xed, 0x50, 0x26, 0xa3, 0x2b, 0x42, 0x1e, 0x95, 0x4a, 0xcc, 0x4f, 0x41, 0xf9, 0x2d,
		0x77, 0xff, 0xf2, 0xdd, 0x9f, 0x94, 0x90, 0xa9, 0xdd, 0xf9, 0x09, 0xb8, 0x57, 0x8c, 0xcb, 0xfe,
		0x85, 0xc6, 0x3c, 0x4f, 0x32, 0x04, 0x36, 0x6e, 0xa5, 0x64, 0x69, 0x00, 0xc9, 0xc3, 0xfe, 0x45,
		0xc2, 0xfc, 0x93, 0x85, 0xf5, 0x6f, 0x9a, 0x9a, 0x84, 0x5b, 0x4f, 0x71, 0xcb, 0x55, 0x62, 0x71,
		0xb5, 0xe4, 0x9b, 0xec, 0xf9, 0xed, 0xb5, 0x7e, 0xd3, 0xac, 0xfe, 0xc9, 0x9a, 0xb9, 0x8a, 0x3b,
		0x47, 0x89, 0xe6, 0xe6, 0x99, 0x19, 0x49, 0x30, 0x13, 0xab, 0x9f, 0x7f, 0xf9, 0xe9, 0x56, 0x3c,
		0xd9, 0x06, 0x6e, 0x1c, 0x8b, 0x0b, 0x6f, 0xe0, 0xbe, 0x1b, 0xb9, 0x6e, 0x1c, 0x6a, 0x10, 0x9f,
		0x02, 0xc4, 0xbd, 0xea, 0x13, 0x5f, 0xe9, 0x89, 0xaf, 0xee, 0x44, 0x57, 0x74, 0xb2, 0xbd, 0xb8,
		0x89, 0x5b, 0x4e, 0x5a, 0xbf, 0x3a, 0x0d, 0xb7, 0xeb, 0xde, 0xf8, 0x2d, 0x3f, 0x7a, 0xd8, 0x3c,
		0x21, 0x0b, 0x6d, 0x63, 0x67, 0x5f, 0xbb, 0x09, 0x59, 0x63, 0x71, 0xc9, 0xd8, 0xdc, 0x31, 0x09,
		0x57, 0x4c, 0xce, 0x0d, 0x93, 0x72, 0x41, 0x65, 0xee, 0xa7, 0xcc, 0xf5, 0x94, 0xb8, 0x9d, 0xde,
		0xdd, 0x18, 0x9b, 0xab, 0xcd, 0x58, 0x1c, 0x5e, 0x10, 0xf9, 0xd1, 0x43, 0x3c, 0xe1, 0x60, 0x8a,
		0x11, 0x71, 0xae, 0xb6, 0x93, 0xf1, 0xd0, 0xef, 0xdd, 0x9e, 0x82, 0xd9, 0x7e, 0xf4, 0xe1, 0xf4,
		0xfa, 0xc3, 0xd9, 0xd7, 0xcf, 0x97, 0xc7, 0x5f, 0xae, 0x3f, 0x1c, 0x9d, 0x1f, 0xbd, 0x3f, 0x39,
		0x3d, 0xb9, 0xfc, 0x23, 0xee, 0x9a, 0x0d, 0x7b, 0x9f, 0x26, 0x8b, 0xd6, 0x51, 0x34, 0xd9, 0x8e,
		0x7e, 0xff, 0xfd, 0xcb, 0xf1, 0xef, 0x47, 0x97, 0xc7, 0xd7, 0x67, 0x9f, 0x4f, 0xff, 0xa8, 0x98,
		0x88, 0x9d, 0x50, 0xfc, 0x64, 0x27, 0x83, 0xb9, 0xfb, 0x78, 0xf4, 0xc1, 0xe6, 0x4f, 0x36, 0x9d,
		0x3d, 0x69, 0xf3, 0xfe, 0x4a, 0xf7, 0xa4, 0x59, 0x47, 0x37, 0x36, 0x11, 0xfd, 0x8d, 0x4c, 0xe3,
		0x19, 0x0e, 0xbf, 0x82, 0x64, 0xbc, 0x78, 0xe6, 0xe9, 0x36, 0x3d, 0xd5, 0xe6, 0xa7, 0xa9, 0xac,
		0xe4, 0x30, 0xcf, 0x7e, 0xfe, 0xf9, 0x4f, 0xfe, 0xf4, 0xf9, 0x66, 0x3e, 0x5b, 0xe5, 0xe6, 0x76,
		0x59, 0x7c, 0x99, 0xee, 0xba, 0xc1, 0x0f, 0x17, 0x9e, 0x63, 0x35, 0xe5, 0x59, 0x7b, 0xc3, 0x3d,
		0x77, 0xa3, 0xcd, 0xde, 0x60, 0xcb, 0xef, 0x14, 0xe7, 0xc6, 0x8a, 0x7d, 0x43, 0xc5, 0xbe, 0x91,
		0x16, 0x6f, 0xa0, 0xc1, 0xe7, 0x4a, 0xb8, 0xd2, 0xeb, 0x28, 0x4a, 0x65, 0x86, 0xfd, 0x6e, 0xa4,
		0x9d, 0x1b, 0x99, 0x72, 0x6c, 0xee, 0xb9, 0x23, 0xc3, 0x3d, 0x57, 0x2f, 0x90, 0xfd, 0xdc, 0x73,
		0xe5, 0x02, 0x1a, 0xe2, 0x9e, 0xf1, 0x7d, 0xf8, 0x89, 0x63, 0x91, 0x62, 0xca, 0xec, 0xc6, 0x99,
		0xe6, 0xf3, 0xdb, 0x20, 0xbf, 0x4c, 0xf3, 0xd9, 0x6d, 0x22, 0xc3, 0x34, 0xe3, 0xca, 0xe2, 0x49,
		0x33, 0x4f, 0xd5, 0x32, 0x4e, 0x6d, 0x4f, 0x90, 0x8e, 0xb7, 0xd1, 0x8a, 0xe7, 0xb7, 0x89, 0xb5,
		0x11, 0x2d, 0xf1, 0xdb, 0x34, 0xbd, 0x9e, 0x1f, 0x7a, 0x4d, 0xa7, 0xed, 0x07, 0x7e, 0xbb, 0xdf,
		0x76, 0xa2, 0x9f, 0xce, 0x10, 0xcf, 0xee, 0xdd, 0x96, 0xba, 0x43, 0xe7, 0xb9, 0x41, 0xcb, 0xe1,
		0xe9, 0x49, 0xb6, 0xf5, 0xcb, 0xe3, 0xe9, 0x49, 0x74, 0x34, 0xf2, 0xe2, 0xe9, 0xe9, 0xfb, 0x41,
		0xb4, 0x57, 0xd5, 0xf0, 0xf1, 0x28, 0x04, 0x19, 0x55, 0xbe, 0x0c, 0xf3, 0x60, 0x54, 0x12, 0x73,
		0xb6, 0x94, 0x93, 0x73, 0x26, 0x2e, 0x03, 0x81, 0x30, 0x3a, 0x99, 0x42, 0xa6, 0x43, 0xc1, 0x43,
		0x60, 0x9c, 0x8f, 0xa1, 0xdb, 0x18, 0xd8, 0x75, 0xbf, 0xf9, 0x77, 0xfe, 0xc8, 0x13, 0x92, 0x49,
		0xc1, 0xd9, 0x4f, 0xee, 0x4f, 0xeb, 0xa6, 0xb6, 0x56, 0x3d, 0xac, 0x1d, 0xd6, 0x0f, 0xaa, 0x87,
		0xfb, 0x16, 0xcd, 0x71, 0x4a, 0x91, 0x6d, 0x57, 0x16, 0x64, 0x10, 0x35, 0xbd, 0xc8, 0x1b, 0xce,
		0x9b, 0xd3, 0xee, 0xb7, 0x22, 0xbf, 0xdb, 0xf2, 0xbd, 0x50, 0xe7, 0x66, 0x5e, 0x31, 0x1a, 0x57,
		0x32, 0x57, 0x72, 0x01, 0xaf, 0xe4, 0xb7, 0x1a, 0x37, 0xf2, 0x3e, 0x37, 0xb2, 0xde, 0xb5, 0xb1,
		0xcb, 0x8d, 0xbc, 0x38, 0xb5, 0x7b, 0x05, 0x24, 0x3b, 0x25, 0xba, 0x88, 0xbd, 0xc0, 0xbd, 0x69,
		0x79, 0x4e, 0xd7, 0x0b, 0x9d, 0xb6, 0xd7, 0xbe, 0xf1, 0x42, 0xa7, 0xe5, 0x07, 0xff, 0x55, 0xbf,
		0x8a, 0xd7, 0x8c, 0x97, 0x34, 0x19, 0xd3, 0xbb, 0x75, 0xfb, 0xad, 0x21, 0x96, 0x0f, 0xd3, 0xd9,
		0xb9, 0xcc, 0xb9, 0xcc, 0x8b, 0x76, 0x99, 0xdf, 0x74, 0x3a, 0x2d, 0xcf, 0x0d, 0x74, 0x82, 0x28,
		0x77, 0xad, 0x01, 0x90, 0xa6, 0x2e, 0x62, 0x34, 0x39, 0xe2, 0x1c, 0x71, 0x8e, 0xb8, 0x95, 0x47,
		0x9c, 0x2c, 0x08, 0x0e, 0x36, 0x07, 0x7b, 0x3e, 0xf6, 0x36, 0xf4, 0x83, 0x3b, 0x2b, 0xf3, 0x1f,
		0x12, 0x9c, 0xeb, 0x56, 0xa7, 0xe1, 0xb6, 0x1c, 0xb7, 0xd9, 0x0c, 0xbd, 0x5e, 0x4f, 0xfd, 0x88,
		0xcf, 0x0f, 0xc3, 0x69, 0xe7, 0xb4, 0x17, 0xec, 0xb4, 0xfb, 0x5d, 0xc5, 0xdd, 0x3d, 0x77, 0xe2,
		0x0f, 0x15, 0x5e, 0x3b, 0xfe, 0xec, 0xa9, 0x6b, 0x6f, 0x4f, 0x4f, 0x7e, 0x5f, 0xd3, 0x78, 0xf6,
		0x65, 0xd4, 0xd3, 0xab, 0x3b, 0x10, 0x79, 0x61, 0xa0, 0x3c, 0x1d, 0xd3, 0x81, 0x5e, 0xbe, 0xfc,
		0xbe, 0xe3, 0x1c, 0x5e, 0xfd, 0xfa, 0xbe, 0xeb, 0x1c, 0x5e, 0x8d, 0xbe, 0xdc, 0x1d, 0xfe, 0x35,
		0xfa, 0xba, 0xfa, 0x7d, 0xc7, 0xa9, 0x4d, 0xbe, 0xde, 0xff, 0xbe, 0xe3, 0xec, 0x5f, 0xbd, 0xfa,
		0xf3, 0xcf, 0x37, 0xaf, 0xfe, 0xde, 0x7b, 0x4c, 0xfe, 0x42, 0xf5, 0x2a, 0x15, 0x57, 0x3a, 0x53,
		0x75, 0x76, 0x71, 0xf2, 0x6f, 0xb1, 0xf9, 0xfa, 0x4f, 0x9a, 0x13, 0xf6, 0x0f, 0x8d, 0x19, 0x4b,
		0xb3, 0xae, 0x87, 0xcc, 0xe1, 0xaa, 0x17, 0xf4, 0x70, 0xb9, 0xce, 0xed, 0x91, 0xf3, 0xf1, 0xea,
		0xef, 0xdd, 0xd7, 0xb5, 0xc7, 0x77, 0xaf, 0xfe, 0x3e, 0x78, 0x5c, 0xfc, 0xe6, 0xaf, 0x55, 0xbf,
		0xb6, 0xfb, 0xfa, 0xe0, 0xf1, 0xdd, 0x9a, 0x9f, 0xd4, 0x1f, 0xdf, 0xc5, 0x1c, 0x63, 0xff, 0xf1,
		0xe5, 0xd2, 0xaf, 0x0e, 0xbe, 0x5f, 0x5d, 0xf7, 0x82, 0xda, 0x9a, 0x17, 0xec, 0xad, 0x7b, 0xc1,
		0xde, 0x9a, 0x17, 0xac, 0xfd, 0x48, 0xd5, 0x35, 0x2f, 0xd8, 0x7f, 0xfc, 0xb5, 0xf4, 0xfb, 0x2f,
		0x57, 0xff, 0x6a, 0xfd, 0xf1, 0xd5, 0xaf, 0x75, 0x3f, 0x3b, 0x78, 0xfc, 0xf5, 0xee, 0x55, 0x91,
		0xa0, 0x86, 0xed, 0x93, 0xfe, 0xf6, 0x49, 0x1f, 0x78, 0x73, 0xe9, 0x2f, 0x09, 0xbd, 0xff, 0xf5,
		0xe7, 0xa2, 0x00, 0x43, 0xaf, 0xe1, 0xf9, 0xf7, 0x1a, 0xd5, 0x50, 0xd7, 0x8e, 0x88, 0x25, 0x85,
		0x25, 0x55, 0x30, 0x4b, 0x8a, 0x98, 0x42, 0xd5, 0x07, 0x27, 0xa6, 0x70, 0x7e, 0x6a, 0x89, 0x29,
		0x34, 0x74, 0xc9, 0x5a, 0x76, 0x35, 0x5b, 0x5e, 0xce, 0xe5, 0xe6, 0xb6, 0xb9, 0x3d, 0xf8, 0xff,
		0xca, 0x72, 0x2e, 0x89, 0x8b, 0xc5, 0xaf, 0x4d, 0x9b, 0x7c, 0x7f, 0xdb, 0xbc, 0x1e, 0xfc, 0x7f,
		0x65, 0x3d, 0x97, 0x24, 0x75, 0xe1, 0x85, 0xda, 0x26, 0x36, 0x15, 0x7a, 0x25, 0x36, 0x13, 0xe6,
		0xff, 0xec, 0x90, 0xff, 0x43, 0xfe, 0x8f, 0x22, 0xf1, 0xd0, 0xa8, 0x99, 0xaa, 0x52, 0x23, 0x75,
		0x45, 0x17, 0x67, 0xbf, 0x49, 0x1f, 0xd3, 0x4c, 0x8f, 0x29, 0x7d, 0x4c, 0x53, 0x3e, 0xa4, 0xf4,
		0x31, 0x35, 0x69, 0x26, 0xd3, 0x47, 0x44, 0x7b, 0xbb, 0xa7, 0x63, 0x24, 0xd3, 0x47, 0x84, 0x22,
		0xfb, 0x66, 0x0f, 0x93, 0xf8, 0xa1, 0x92, 0x3c, 0x5c, 0x9a, 0x86, 0x27, 0x45, 0xf6, 0xe7, 0x09,
		0x25, 0x7d, 0x44, 0x56, 0x2d, 0x12, 0x7d, 0x44, 0x80, 0x38, 0x20, 0xae, 0x2c, 0x10, 0x47, 0x1f,
		0x91, 0xf5, 0x93, 0x48, 0x1f, 0xd3, 0x8d, 0xa7, 0xbc, 0x3c, 0x7d, 0x4c, 0x9f, 0x15, 0xa3, 0x4d,
		0xf7, 0x31, 0x7d, 0x56, 0xa2, 0xa6, 0x8f, 0xa9, 0x98, 0xfe, 0x40, 0x1f, 0x53, 0xf4, 0x07, 0xf4,
		0x07, 0xc8, 0x39, 0xe4, 0x1c, 0x72, 0x8e, 0xfe, 0x80, 0xfe, 0x00, 0xc4, 0x01, 0x71, 0x40, 0x1c,
		0xfa, 0x43, 0x36, 0x6c, 0xd3, 0x0a, 0x63, 0x56, 0xbc, 0x8f, 0x69, 0x7c, 0x5b, 0xb6, 0xd4, 0x7d,
		0x4c, 0xe3, 0x2f, 0x91, 0xf1, 0x18, 0xb8, 0xac, 0xfa, 0x98, 0xb6, 0xfd, 0x46, 0xd8, 0x19, 0x4c,
		0x84, 0xd3, 0xf3, 0x7a, 0x3d, 0xbf, 0x13, 0xf4, 0x92, 0x47, 0xdf, 0xac, 0x18, 0x83, 0x4a, 0xd9,
		0x29, 0x5e, 0xfa, 0xa5, 0xae, 0x94, 0xbd, 0xb4, 0xf9, 0xd4, 0xe5, 0xb0, 0xe5, 0xa1, 0xca, 0x11,
		0x9a, 0x43, 0x06, 0x8b, 0xc0, 0x31, 0xb0, 0x5c, 0x1c, 0x53, 0x8c, 0x55, 0x5b, 0xda, 0x2e, 0xca,
		0xba, 0xbb, 0xc6, 0x01, 0xb1, 0xd6, 0x66, 0x54, 0x3b, 0x38, 0x18, 0x8d, 0x4a, 0x07, 0x2b, 0x1b,
		0xab, 0x51, 0xf5, 0xc0, 0x4d, 0x07, 0xd0, 0xab, 0x51, 0xb3, 0xde, 0x06, 0xd5, 0xa8, 0x59, 0x23,
		0x2c, 0xe5, 0x88, 0x1d, 0x4f, 0xc9, 0x63, 0x2a, 0x7f, 0x5c, 0xa5, 0x8f, 0xad, 0xb1, 0xe3, 0x6b,
		0xec, 0x18, 0x1b, 0x39, 0xce, 0x7a, 0xc7, 0x5a, 0xf3, 0x78, 0xcb, 0x89, 0x43, 0x4b, 0xfb, 0x4d,
		0xab, 0xe6, 0xce, 0xda, 0x8b, 0xf3, 0x50, 0x60, 0x2c, 0xad, 0x9a, 0x3c, 0x8b, 0x7f, 0x64, 0xce,
		0xc0, 0x96, 0x81, 0x9a, 0x3d, 0x6b, 0xe7, 0xf0, 0xad, 0xe0, 0x98, 0x52, 0x85, 0x23, 0x96, 0x06,
		0xce, 0x47, 0x8d, 0x9f, 0xc5, 0x3f, 0x57, 0x92, 0x53, 0x2b, 0x59, 0x98, 0x63, 0x69, 0xf4, 0xbc,
		0xd4, 0x04, 0x5a, 0x9a, 0x61, 0x91, 0x91, 0x1e, 0x5f, 0x5b, 0x7c, 0xf8, 0xeb, 0x1c, 0x7e, 0x8a,
		0xc8, 0xe4, 0xae, 0x06, 0x51, 0xee, 0xa1, 0x90, 0xed, 0x96, 0xab, 0x9a, 0x45, 0x86, 0x2e, 0x86,
		0x17, 0xd9, 0x7e, 0x8e, 0xc7, 0x4c, 0x8a, 0x71, 0x8c, 0x1b, 0x3d, 0xe8, 0x07, 0x58, 0x2c, 0x4b,
		0xca, 0x8b, 0x23, 0x63, 0xa9, 0x63, 0xa9, 0x63, 0xa9, 0x5b, 0x65, 0xa9, 0xeb, 0x87, 0x73, 0x2c,
		0xb1, 0xcc, 0x03, 0x81, 0xb1, 0x92, 0x46, 0xb0, 0x8d, 0xeb, 0x36, 0xe8, 0x86, 0xb3, 0x65, 0x8b,
		0xc4, 0xa1, 0xd7, 0xee, 0x44, 0x9e, 0xbc, 0x5c, 0xba, 0x30, 0x2e, 0x28, 0x0c, 0x0a, 0x83, 0xc2,
		0xe8, 0xa5, 0xe8, 0xa5, 0xe8, 0xa5, 0xe8, 0xa5, 0xe8, 0xa5, 0xe8, 0xa5, 0xe8, 0xa5, 0x08, 0x58,
		0xe8, 0xa5, 0xe8, 0xa5, 0xe8, 0xa5, 0x65, 0xd1, 0x4b, 0x53, 0x0d, 0xa3, 0xd2, 0x4c, 0xb3, 0x98,
		0x8e, 0xa3, 0x18, 0xcb, 0xbf, 0x1c, 0xa1, 0xbe, 0xfc, 0xad, 0x6d, 0xad, 0xd0, 0xc6, 0x2d, 0xe5,
		0xc8, 0xff, 0x4f, 0x83, 0x0f, 0xf2, 0xfe, 0xb6, 0x79, 0x31, 0xfe, 0x64, 0x8b, 0xdf, 0x50, 0x2a,
		0x37, 0xa0, 0xbe, 0xca, 0x2a, 0xc9, 0x89, 0x62, 0xfa, 0xb9, 0xb4, 0x6e, 0x5e, 0xb4, 0x24, 0x45,
		0x02, 0x4e, 0x33, 0x50, 0x5c, 0x48, 0x53, 0x14, 0x49, 0x53, 0x7c, 0x2a, 0x2d, 0xbc, 0x74, 0xb8,
		0x6d, 0xce, 0xbb, 0x56, 0xaa, 0xb0, 0xb2, 0xb4, 0x16, 0xaa, 0x19, 0x7e, 0x5b, 0x92, 0x51, 0xf3,
		0x55, 0x40, 0x0c, 0x10, 0x4b, 0x05, 0xc4, 0xb4, 0xa3, 0xe6, 0xdd, 0xde, 0x43, 0xd0, 0x90, 0x73,
		0xff, 0x8c, 0x86, 0x93, 0xf1, 0xfa, 0xec, 0xe2, 0xf5, 0x49, 0xf1, 0x98, 0x1a, 0x3b, 0xae, 0xc6,
		0x8e, 0xad, 0x91, 0xe3, 0x2b, 0x63, 0x6f, 0xea, 0x7a, 0x7d, 0x74, 0x8f, 0xf5, 0x74, 0xa0, 0x96,
		0xdb, 0x8b, 0x9c, 0xae, 0xdb, 0xf8, 0xaf, 0x17, 0x4d, 0xba, 0x85, 0x35, 0xe5, 0xb6, 0xca, 0x94,
		0x00, 0xad, 0x7a, 0x17, 0xa1, 0xc5, 0x95, 0x71, 0x01, 0x8b, 0x83, 0x82, 0x09, 0x70, 0x30, 0x07,
		0x12, 0xa6, 0xc0, 0xc2, 0x38, 0x68, 0x18, 0x07, 0x0f, 0xa3, 0x20, 0x22, 0x27, 0x5e, 0x6d, 0xc9,
		0xf9, 0x46, 0xe4, 0x5c, 0xca, 0x4b, 0xfb, 0xb5, 0xef, 0x07, 0x51, 0xbd, 0x66, 0xc0, 0x3b, 0x22,
		0xe9, 0x1c, 0xd1, 0x6b, 0xf2, 0xb6, 0xee, 0x8f, 0xec, 0x79, 0xda, 0x92, 0x6a, 0x0a, 0x97, 0x12,
		0xac, 0x2e, 0x0d, 0x2f, 0xd4, 0x44, 0x6e, 0xed, 0xf8, 0x82, 0x8d, 0xcf, 0x0c, 0x1f, 0xb7, 0xf9,
		0x25, 0x75, 0x7f, 0xe6, 0x7e, 0x49, 0x77, 0xdf, 0xd6, 0x6a, 0xf5, 0x83, 0x5a, 0x6d, 0xe7, 0x60,
		0xef, 0x60, 0xe7, 0x70, 0x7f, 0x7f, 0xb7, 0xbe, 0xbb, 0x9f, 0xe3, 0x55, 0x7e, 0x61, 0xe7, 0x68,
		0xb6, 0x78, 0x4d, 0x04, 0x4e, 0xc1, 0x1c, 0x3d, 0x8c, 0x42, 0x37, 0xe8, 0xb5, 0xfd, 0x28, 0x32,
		0xcd, 0x43, 0x67, 0xdf, 0x08, 0x2a, 0x0a, 0x15, 0x85, 0x8a, 0x42, 0x45, 0xa1, 0xa2, 0x50, 0x51,
		0xa8, 0x28, 0x54, 0x14, 0x2a, 0x5a, 0x56, 0x2a, 0x3a, 0x51, 0x27, 0xc7, 0x2c, 0xb1, 0x27, 0xcf,
		0x41, 0x97, 0xde, 0x01, 0xf2, 0x09, 0xf9, 0x84, 0x7c, 0x42, 0x3e, 0x21, 0x9f, 0x90, 0x4f, 0xc8,
		0x27, 0xe4, 0x13, 0xf2, 0x59, 0x56, 0xf2, 0x39, 0x23, 0x49, 0x9a, 0xe3, 0x9f, 0xab, 0xde, 0x04,
		0x0a, 0x0a, 0x05, 0x85, 0x82, 0x42, 0x41, 0xa1, 0xa0, 0x50, 0x50, 0x28, 0x28, 0x14, 0x14, 0x0a,
		0x5a, 0x56, 0x0a, 0xda, 0xef, 0x8e, 0x1c, 0xe3, 0x7e, 0x94, 0xa8, 0x03, 0x4d, 0xfc, 0x6b, 0x67,
		0x7e, 0x7c, 0x88, 0x27, 0xc4, 0x13, 0xe2, 0x09, 0xf1, 0x84, 0x78, 0x42, 0x3c, 0x21, 0x9e, 0x10,
		0x4f, 0x88, 0x67, 0x2e, 0x89, 0x67, 0xa6, 0xb9, 0x50, 0x42, 0x15, 0x2d, 0xa6, 0xe3, 0x99, 0xac,
		0x6c, 0x31, 0xcc, 0x3e, 0xde, 0x96, 0x48, 0x82, 0xdc, 0x32, 0x57, 0xe6, 0x62, 0xd8, 0x89, 0xf4,
		0xfa, 0x68, 0xf8, 0x21, 0x73, 0x58, 0xb9, 0xb4, 0xe9, 0xb5, 0xdd, 0xa0, 0xe9, 0xb4, 0x3b, 0x4d,
		0xcf, 0x09, 0xbd, 0xff, 0xf5, 0xbd, 0x9e, 0x44, 0x2c, 0xf1, 0x94, 0xbf, 0xac, 0x1e, 0x9e, 0x3a,
		0xa6, 0xe9, 0x19, 0x2a, 0x64, 0xb4, 0x52, 0xc7, 0x34, 0xc6, 0x7e, 0xbb, 0xe9, 0x74, 0x5a, 0x9e,
		0x1b, 0x48, 0x16, 0x31, 0xdd, 0xcd, 0x21, 0x1c, 0xde, 0xba, 0x7e, 0xab, 0x1f, 0x7a, 0xa2, 0xb2,
		0xce, 0x74, 0x8e, 0x57, 0x0d, 0x0e, 0x14, 0x02, 0x85, 0x40, 0xa1, 0x55, 0x50, 0x28, 0xa6, 0xb9,
		0x08, 0x6a, 0x2d, 0xc2, 0x1a, 0x8b, 0xa0, 0x52, 0x65, 0x42, 0x53, 0x31, 0x64, 0x78, 0x9b, 0xd2,
		0x50, 0x4c, 0x5a, 0xd5, 0x82, 0x9a, 0x89, 0x11, 0xad, 0xc4, 0xf4, 0x52, 0x99, 0xd7, 0x46, 0x8c,
		0xae, 0x1e, 0xdd, 0x8d, 0x94, 0x97, 0x65, 0x98, 0x7e, 0x3a, 0xa5, 0x4c, 0x7e, 0x5b, 0xb0, 0xbd,
		0xd1, 0xf2, 0xd0, 0xd0, 0x30, 0x68, 0x18, 0x34, 0xcc, 0x2a, 0x1a, 0x36, 0x38, 0x97, 0x91, 0xdf,
		0xf8, 0x6f, 0xcf, 0x3a, 0x2e, 0xf6, 0x35, 0x18, 0xdd, 0x13, 0x95, 0xc0, 0x0d, 0x3a, 0x3d, 0xaf,
		0xd1, 0x09, 0x9a, 0x22, 0xdd, 0x3f, 0xe0, 0x78, 0x70, 0x3c, 0x38, 0x1e, 0x1c, 0xaf, 0x44, 0x1c,
		0xaf, 0xd3, 0x70, 0x5b, 0xf2, 0x6d, 0xd3, 0xe6, 0x87, 0x85, 0xdb, 0xc1, 0xed, 0xe0, 0x76, 0x56,
		0x71, 0x3b, 0xba, 0xa6, 0xa9, 0xcf, 0x1c, 0x5d, 0xd3, 0xe8, 0x9a, 0x46, 0xd7, 0x34, 0x03, 0x14,
		0x48, 0x98, 0x8e, 0xd3, 0x35, 0x8d, 0xae, 0x69, 0x74, 0x4d, 0x2b, 0x08, 0x14, 0xb2, 0xdd, 0xe8,
		0x9a, 0x56, 0x6a, 0x1b, 0xbd, 0xe9, 0xbb, 0x77, 0x41, 0xa7, 0x17, 0xf9, 0x0d, 0xa7, 0xd1, 0x69,
		0x7a, 0xd2, 0xb6, 0xfa, 0xe2, 0xf0, 0xd8, 0xec, 0xd8, 0xec, 0xd8, 0xec, 0x56, 0xd9, 0xec, 0x37,
		0xb7, 0x4d, 0xe1, 0x63, 0x3a, 0xc7, 0x3d, 0x6b, 0x02, 0x63, 0x1d, 0x07, 0xfd, 0xf6, 0xe0, 0xa1,
		0x1f, 0x73, 0x0c, 0xb3, 0xbd, 0x46, 0xe8, 0xb7, 0xfd, 0xc0, 0x8d, 0x3a, 0xa1, 0x3c, 0xc8, 0xce,
		0x0e, 0x0e, 0xc4, 0x02, 0xb1, 0x40, 0xac, 0x55, 0x10, 0xdb, 0x8b, 0x42, 0x3f, 0xb8, 0x93, 0x44,
		0xd5, 0xb7, 0x39, 0x44, 0x42, 0xb1, 0xb6, 0xac, 0x4b, 0xf3, 0x2b, 0xd4, 0x9e, 0x15, 0x0c, 0x04,
		0x03, 0xc1, 0x40, 0x43, 0x18, 0xa8, 0xdf, 0xfe, 0x75, 0x09, 0x04, 0x0f, 0x04, 0xc6, 0x3a, 0x9f,
		0x66, 0x38, 0x36, 0x1c, 0xff, 0xf6, 0xdd, 0x4c, 0x52, 0xe3, 0xc2, 0x37, 0xc6, 0xff, 0x1e, 0xf7,
		0x8c, 0x1d, 0xfd, 0x63, 0x98, 0x73, 0x98, 0x43, 0x24, 0x0e, 0xbd, 0x76, 0x27, 0xf2, 0xe4, 0xfd,
		0xf3, 0x0b, 0xe3, 0x82, 0xc2, 0xa0, 0x30, 0x28, 0x6c, 0x15, 0x0a, 0xe3, 0xa0, 0x57, 0x9f, 0x39,
		0x1c, 0xf4, 0x38, 0xe8, 0x71, 0xd0, 0xaf, 0x9e, 0x61, 0x1c, 0xf4, 0x65, 0x39, 0xfc, 0x78, 0x4c,
		0x71, 0xd0, 0xa7, 0x08, 0x85, 0x6c, 0x37, 0x1c, 0xf4, 0x25, 0x75, 0xd0, 0x4f, 0xac, 0xe9, 0x7e,
		0xf4, 0xc3, 0x0b, 0x22, 0xbf, 0x31, 0xac, 0xee, 0xe4, 0x78, 0x81, 0x7b, 0xd3, 0x92, 0x2c, 0xe5,
		0xf3, 0xfc, 0xdb, 0x60, 0xc3, 0x63, 0xc3, 0x63, 0xc3, 0x5b, 0x65, 0xc3, 0x53, 0xd2, 0x67, 0x16,
		0x1e, 0x1b, 0x9d, 0x20, 0x0a, 0x3b, 0x2d, 0xa7, 0xdb, 0x72, 0x03, 0xcf, 0xf1, 0x83, 0xa6, 0xd7,
		0xf5, 0x82, 0xe6, 0x68, 0x0b, 0xc9, 0x22, 0xe4, 0xfa, 0x77, 0x02, 0x24, 0x01, 0x49, 0x40, 0x12,
		0x90, 0xb4, 0x16, 0x24, 0x8d, 0x45, 0x79, 0xae, 0x19, 0x1f, 0x40, 0x04, 0x10, 0x01, 0x44, 0xbb,
		0x00, 0x91, 0x30, 0xcf, 0x54, 0x80, 0xd6, 0x48, 0x9c, 0xe7, 0xca, 0xd1, 0x01, 0x59, 0x40, 0x16,
		0x90, 0xb5, 0x0a, 0x64, 0x09, 0xf4, 0x9c, 0xc1, 0xc2, 0xb6, 0x1f, 0xf8, 0xed, 0x7e, 0xdb, 0x19,
		0xf7, 0x7a, 0x1f, 0x85, 0x67, 0xde, 0xbb, 0x2d, 0x71, 0x58, 0x5c, 0xfb, 0x46, 0x20, 0x24, 0x08,
		0x09, 0x42, 0x5a, 0x85, 0x90, 0x7d, 0x3f, 0x88, 0xf6, 0xaa, 0x82, 0x08, 0x79, 0x40, 0x81, 0xb6,
		0x4c, 0x60, 0x6d, 0x69, 0x58, 0x0a, 0xb4, 0xe5, 0x6e, 0xa9, 0x6a, 0xd5, 0xc3, 0xda, 0x61, 0xfd,
		0xa0, 0x7a, 0x48, 0x59, 0xb6, 0xc4, 0x7f, 0x72, 0xec, 0x51, 0x1e, 0xf7, 0xe1, 0x71, 0x86, 0x7d,
		0x78, 0xc4, 0xd9, 0xd8, 0xfc, 0xe8, 0x50, 0x30, 0x28, 0x18, 0x14, 0xcc, 0x3a, 0x25, 0x50, 0xf2,
		0x90, 0xa2, 0x03, 0xce, 0x7c, 0x76, 0x43, 0xd8, 0x0a, 0xa8, 0x02, 0xaa, 0x80, 0x2a, 0xa0, 0x9a,
		0x63, 0x50, 0x7d, 0x91, 0xe2, 0x42, 0x4b, 0xb5, 0xc3, 0x34, 0xdf, 0x06, 0xb3, 0xa2, 0x73, 0xd7,
		0x98, 0x6b, 0x7c, 0xa9, 0x76, 0xc0, 0x93, 0xaf, 0x71, 0xb2, 0x57, 0x24, 0xdc, 0x0d, 0x03, 0xa8,
		0x15, 0x28, 0x0f, 0x50, 0x39, 0xf5, 0x7b, 0xd1, 0x51, 0x14, 0xa9, 0xf9, 0xf3, 0x2a, 0x9f, 0xfc,
		0xe0, 0xb8, 0xe5, 0x0d, 0xf0, 0xb3, 0xa7, 0x76, 0x57, 0x56, 0x3e, 0xb9, 0x3f, 0x67, 0x46, 0x90,
		0xa9, 0xaa, 0x5e, 0x39, 0x0b, 0x9b, 0x5e, 0xe8, 0x35, 0xdf, 0x0f, 0x66, 0x28, 0xe8, 0xb7, 0x5a,
		0x46, 0x17, 0x42, 0xf3, 0x38, 0x9a, 0x3c, 0x86, 0x0a, 0x07, 0xd0, 0xcc, 0xc1, 0x4b, 0x76, 0xe4,
		0xe2, 0x1f, 0x9c, 0x78, 0xbf, 0x19, 0x73, 0x45, 0x55, 0x57, 0x52, 0x6e, 0x05, 0x13, 0xac, 0x97,
		0xcc, 0x3a, 0xc5, 0x5b, 0x97, 0xcd, 0xb3, 0x1c, 0x63, 0x86, 0x2b, 0x5d, 0xcf, 0x0b, 0xe3, 0xe7,
		0xe3, 0x4f, 0xc9, 0xc7, 0xe8, 0x65, 0x31, 0x57, 0x70, 0x42, 0x2a, 0x62, 0xfe, 0x7a, 0x52, 0x96,
		0xaf, 0xc2, 0xe6, 0xd5, 0x59, 0xbb, 0x2a, 0x3b, 0xd7, 0x66, 0xe1, 0xda, 0x6c, 0x5b, 0x8b, 0x55,
		0xcb, 0x9e, 0xe9, 0xdf, 0xfc, 0x64, 0x57, 0xdb, 0x70, 0xbf, 0x25, 0x9f, 0xf2, 0xd9, 0xdd, 0x9a,
		0x74, 0xb6, 0x93, 0x6d, 0xda, 0xe5, 0xcd, 0x5b, 0x4d, 0xf8, 0x42, 0x0d, 0x93, 0x54, 0xdf, 0x04,
		0xd5, 0x35, 0x39, 0xc5, 0x4c, 0x4c, 0x31, 0x93, 0x52, 0xc4, 0x84, 0x34, 0xcb, 0x15, 0x93, 0x1e,
		0x82, 0xe9, 0x0b, 0x25, 0x0b, 0xfc, 0x19, 0x28, 0xec, 0xa7, 0xa9, 0xf6, 0x68, 0xab, 0x3c, 0x12,
		0xea, 0x8e, 0x9c, 0xaa, 0x23, 0xa5, 0xe6, 0x88, 0xab, 0x38, 0xe2, 0xea, 0x8d, 0xa8, 0x6a, 0x93,
		0xae, 0xf1, 0xae, 0xad, 0xce, 0x08, 0x16, 0x9d, 0x92, 0x28, 0x36, 0x35, 0x2d, 0x32, 0xf5, 0xe6,
		0xcd, 0xc8, 0xe8, 0xdf, 0x5e, 0x75, 0xbc, 0xd3, 0xb2, 0xb8, 0x95, 0xec, 0x1d, 0x1d, 0x31, 0x7b,
		0x26, 0x3a, 0x4e, 0x5d, 0xf0, 0x50, 0x64, 0x00, 0xda, 0x4c, 0x00, 0x18, 0x03, 0xc6, 0x14, 0x77,
		0x8c, 0x2a, 0xa3, 0x98, 0x0e, 0xe0, 0xf6, 0x1e, 0x82, 0x86, 0x9c, 0x0f, 0x69, 0x34, 0x9c, 0x8c,
		0xef, 0x68, 0x17, 0xdf, 0x51, 0x8a, 0xc7, 0xd4, 0xd8, 0x71, 0x35, 0x76, 0x6c, 0x8d, 0x1c, 0x5f,
		0xbd, 0x63, 0xac, 0x79, 0x9c, 0xc5, 0x8e, 0xf5, 0x93, 0xe1, 0xe0, 0xf6, 0x22, 0xa7, 0xeb, 0x36,
		0xfe, 0xeb, 0x45, 0x93, 0xd0, 0xe5, 0xa6, 0xdc, 0x56, 0x99, 0xeb, 0x89, 0xbd, 0xf8, 0x2e, 0x42,
		0x8b, 0x2b, 0x1b, 0x9e, 0x26, 0x06, 0x0a, 0x26, 0xc0, 0xc1, 0x1c, 0x48, 0x98, 0x02, 0x0b, 0xe3,
		0xa0, 0x61, 0x1c, 0x3c, 0x8c, 0x82, 0x88, 0x0c, 0x98, 0x08, 0x81, 0x8a, 0x9c, 0xe9, 0xb3, 0x76,
		0xbf, 0xf6, 0xfd, 0x20, 0x12, 0xe9, 0xb8, 0xbd, 0x78, 0xfa, 0x25, 0x6b, 0x97, 0xc9, 0x06, 0x62,
		0x4f, 0xfe, 0xc8, 0x9e, 0xa7, 0x2d, 0x53, 0x81, 0xd9, 0x86, 0x60, 0x75, 0x69, 0x78, 0x43, 0x81,
		0xda, 0xd3, 0xf1, 0x0d, 0x06, 0xff, 0x0a, 0x1f, 0xb7, 0xf9, 0x25, 0x35, 0x10, 0xc0, 0x9d, 0xf6,
		0x92, 0x9a, 0xef, 0xb8, 0x9d, 0xea, 0x2a, 0xbf, 0xb0, 0x73, 0x34, 0x5b, 0x8a, 0x9a, 0x09, 0x9c,
		0x82, 0x39, 0x7a, 0x18, 0x85, 0x6e, 0xd0, 0x6b, 0xfb, 0x51, 0x64, 0x9a, 0x87, 0xce, 0xbe, 0x11,
		0x54, 0x14, 0x2a, 0x0a, 0x15, 0x85, 0x8a, 0x42, 0x45, 0xa1, 0xa2, 0x50, 0x51, 0xa8, 0x28, 0x54,
		0xb4, 0xac, 0x54, 0x74, 0xa2, 0x4e, 0x8e, 0x59, 0x62, 0x4f, 0x9e, 0x83, 0x2e, 0xbd, 0x03, 0xe4,
		0x13, 0xf2, 0x09, 0xf9, 0x84, 0x7c, 0x42, 0x3e, 0x21, 0x9f, 0x90, 0x4f, 0xc8, 0x27, 0xe4, 0xb3,
		0xac, 0xe4, 0x73, 0x46, 0x92, 0x34, 0xc7, 0x3f, 0x57, 0xbd, 0x09, 0x14, 0x14, 0x0a, 0x0a, 0x05,
		0x85, 0x82, 0x42, 0x41, 0xa1, 0xa0, 0x50, 0x50, 0x28, 0x28, 0x14, 0xb4, 0xac, 0x14, 0xb4, 0xdf,
		0x1d, 0x39, 0xc6, 0xfd, 0x68, 0x98, 0x76, 0x2c, 0xce, 0x3e, 0x17, 0xc6, 0x87, 0x78, 0x42, 0x3c,
		0x21, 0x9e, 0x10, 0x4f, 0x88, 0x27, 0xc4, 0x13, 0xe2, 0x09, 0xf1, 0x84, 0x78, 0xe6, 0x92, 0x78,
		0x66, 0x9a, 0x0b, 0x25, 0x54, 0x66, 0x6d, 0x3a, 0x9e, 0x62, 0x95, 0xa0, 0x61, 0xfd, 0x9b, 0xe1,
		0x7f, 0xc7, 0xf9, 0xd5, 0x12, 0xa9, 0x8e, 0x5b, 0xca, 0x15, 0x84, 0xce, 0x07, 0x1f, 0x67, 0xf8,
		0xdf, 0x51, 0x31, 0xb5, 0xeb, 0xa3, 0xe1, 0xc7, 0xc9, 0x61, 0x35, 0xd3, 0xa6, 0xd7, 0x76, 0x83,
		0xa6, 0xd3, 0xee, 0x34, 0x3d, 0x27, 0xf4, 0xfe, 0xd7, 0xf7, 0x7a, 0x91, 0x64, 0xeb, 0xe1, 0xd5,
		0xc3, 0x53, 0xdd, 0x34, 0x3d, 0xc3, 0x83, 0x0c, 0x55, 0xaa, 0x9b, 0xc6, 0xd8, 0x6f, 0x74, 0xd3,
		0x1c, 0x7e, 0x76, 0xaf, 0xf1, 0xa3, 0x23, 0x87, 0x7e, 0xc3, 0xd1, 0x48, 0xc7, 0x07, 0xec, 0x00,
		0x3b, 0x8d, 0x27, 0x12, 0x4b, 0xc7, 0x1f, 0x98, 0x32, 0xf7, 0x9e, 0xbc, 0xec, 0x3a, 0x1e, 0x17,
		0xb9, 0xd5, 0x1e, 0x20, 0x30, 0x05, 0x08, 0xc6, 0x81, 0xc1, 0x38, 0x40, 0x18, 0x05, 0x0a, 0x59,
		0x2b, 0xdc, 0x7e, 0xb9, 0x55, 0x8e, 0x35, 0x09, 0xb3, 0x27, 0x41, 0xf9, 0xe1, 0x35, 0x75, 0x50,
		0x00, 0x65, 0x40, 0x19, 0x50, 0xce, 0x0b, 0x28, 0xe3, 0x03, 0x93, 0xdc, 0x91, 0xf8, 0xc0, 0xd6,
		0x8f, 0x8f, 0x0f, 0x2c, 0xb3, 0x25, 0xc5, 0x07, 0x96, 0xc6, 0x68, 0xd4, 0x41, 0xd1, 0xe4, 0xa1,
		0xd4, 0x41, 0x81, 0x8a, 0x42, 0x45, 0xa1, 0xa2, 0x50, 0x51, 0xa8, 0x28, 0x54, 0x14, 0x2a, 0x0a,
		0x15, 0x85, 0x8a, 0x52, 0x07, 0x05, 0xf2, 0x09, 0xf9, 0x84, 0x7c, 0x42, 0x3e, 0x21, 0x9f, 0x90,
		0x4f, 0xc8, 0x27, 0xe4, 0x13, 0xf2, 0x99, 0x22, 0xf9, 0xa4, 0x0e, 0x0a, 0x14, 0x14, 0x0a, 0x0a,
		0x05, 0x85, 0x82, 0x42, 0x41, 0xa1, 0xa0, 0x50, 0x50, 0x28, 0x28, 0x14, 0x34, 0x65, 0x0a, 0x4a,
		0x1d, 0x14, 0x88, 0x27, 0xc4, 0x13, 0xe2, 0x09, 0xf1, 0x84, 0x78, 0x42, 0x3c, 0x21, 0x9e, 0x10,
		0x4f, 0x88, 0xa7, 0xe1, 0x11, 0x8a, 0x5a, 0x07, 0x45, 0x20, 0xc5, 0x7c, 0x4b, 0xae, 0x0c, 0xca,
		0xf1, 0xe0, 0xd3, 0xe4, 0x30, 0xed, 0xff, 0xd6, 0xf5, 0x5b, 0xfd, 0xd0, 0x13, 0xb5, 0x4a, 0xa6,
		0x5c, 0x64, 0xd5, 0xe0, 0x54, 0x40, 0x49, 0xcf, 0xe4, 0xa0, 0x28, 0x00, 0x15, 0x50, 0xd2, 0x34,
		0x19, 0x04, 0x4d, 0x05, 0x61, 0x13, 0x41, 0xd0, 0xd0, 0x32, 0x61, 0x12, 0x18, 0xe2, 0x8d, 0xa6,
		0x4c, 0x00, 0x93, 0xa4, 0x50, 0x90, 0xf2, 0x1b, 0xa1, 0xfa, 0xa6, 0x97, 0xca, 0x3c, 0xb5, 0x37,
		0xba, 0x7a, 0x96, 0x50, 0xe6, 0xab, 0x1c, 0x52, 0xb1, 0x61, 0xf6, 0xd4, 0x94, 0x32, 0xf9, 0x6d,
		0x4f, 0x8e, 0x88, 0x2d, 0x0f, 0x0d, 0x0d, 0x83, 0x86, 0x41, 0xc3, 0xac, 0xa2, 0x61, 0x83, 0x73,
		0x19, 0xf9, 0x8d, 0xff, 0xf6, 0xac, 0xe3, 0x62, 0x5f, 0x83, 0xd1, 0x3d, 0x51, 0x09, 0xdc, 0xa0,
		0xd3, 0xf3, 0x1a, 0x9d, 0xa0, 0x29, 0xe1, 0x5b, 0x82, 0xe3, 0xc1, 0xf1, 0xe0, 0x78, 0x70, 0xbc,
		0x32, 0x71, 0xbc, 0x4e, 0xc3, 0x6d, 0x39, 0x6e, 0xb3, 0x19, 0x7a, 0x3d, 0x41, 0xa1, 0x6d, 0x7e,
		0x58, 0xb8, 0x1d, 0xdc, 0x0e, 0x6e, 0x67, 0x15, 0xb7, 0xf3, 0xbb, 0x42, 0xa7, 0x73, 0xf6, 0x84,
		0xee, 0x1e, 0x0a, 0x8c, 0x35, 0x7e, 0x56, 0xeb, 0x28, 0xd8, 0xd3, 0xcc, 0xdd, 0xd7, 0x04, 0xe7,
		0x6e, 0x69, 0x0e, 0x25, 0xc3, 0x1a, 0xce, 0xdd, 0x28, 0xf2, 0xc2, 0x40, 0x3c, 0xb0, 0xa1, 0xf2,
		0xf2, 0xe5, 0xf7, 0x1d, 0xe7, 0xf0, 0xea, 0xd7, 0xf7, 0x5d, 0xe7, 0xf0, 0x6a, 0xf4, 0xe5, 0xee,
		0xf0, 0xaf, 0xd1, 0xd7, 0xd5, 0xef, 0x3b, 0x4e, 0x6d, 0xf2, 0xf5, 0xfe, 0xf7, 0x1d, 0x67, 0xff,
		0xea, 0xd5, 0x9f, 0x7f, 0xbe, 0x79, 0xf5, 0xf7, 0xde, 0x63, 0xf2, 0x17, 0xca, 0x85, 0xdc, 0x5c,
		0x49, 0x4e, 0xed, 0xd9, 0xc5, 0xc9, 0xbf, 0x8d, 0xcd, 0xef, 0x7f, 0xd2, 0x9c, 0xe0, 0x7f, 0x54,
		0x6c, 0xf3, 0x50, 0xbf, 0xb6, 0xf8, 0xf0, 0xd7, 0x39, 0xfc, 0xc3, 0x2d, 0xe6, 0x3a, 0xb7, 0x47,
		0xce, 0xc7, 0xab, 0xbf, 0x77, 0x5f, 0xd7, 0x1e, 0xdf, 0xbd, 0xfa, 0xfb, 0xe0, 0x71, 0xf1, 0x9b,
		0xbf, 0x56, 0xfd, 0xda, 0xee, 0xeb, 0x83, 0xc7, 0x77, 0x6b, 0x7e, 0x52, 0x7f, 0x7c, 0x17, 0x73,
		0x8c, 0xfd, 0xc7, 0x97, 0x4b, 0xbf, 0x3a, 0xf8, 0x7e, 0x75, 0xdd, 0x0b, 0x6a, 0x6b, 0x5e, 0xb0,
		0xb7, 0xee, 0x05, 0x7b, 0x6b, 0x5e, 0xb0, 0xf6, 0x23, 0x55, 0xd7, 0xbc, 0x60, 0xff, 0xf1, 0xd7,
		0xd2, 0xef, 0xbf, 0x5c, 0xfd, 0xab, 0xf5, 0xc7, 0x57, 0xbf, 0xd6, 0xfd, 0xec, 0xe0, 0xf1, 0xd7,
		0xbb, 0x57, 0x65, 0x86, 0x42, 0xb6, 0x5b, 0xfa, 0xdb, 0xcd, 0xbe, 0x8b, 0xa1, 0xc4, 0x36, 0x7a,
		0xd3, 0x77, 0xef, 0x82, 0x4e, 0x2f, 0xf2, 0x1b, 0x4e, 0xa3, 0xd3, 0xf4, 0xa4, 0x6d, 0xf5, 0xc5,
		0xe1, 0xb1, 0xd9, 0xb1, 0xd9, 0xb1, 0xd9, 0xad, 0xb2, 0xd9, 0x6f, 0x6e, 0x9b, 0xc2, 0xc7, 0x74,
		0x8e, 0x7b, 0xd6, 0x04, 0xc6, 0x3a, 0x0e, 0xfa, 0xed, 0xc1, 0x43, 0x3f, 0xe6, 0x18, 0x66, 0x7b,
		0x8d, 0xd0, 0x6f, 0xfb, 0x81, 0x1b, 0x75, 0x42, 0x79, 0x90, 0x9d, 0x1d, 0x1c, 0x88, 0x05, 0x62,
		0x81, 0x58, 0xab, 0x20, 0xb6, 0x17, 0x85, 0x7e, 0x70, 0x27, 0x89, 0xaa, 0x6f, 0x73, 0x88, 0x84,
		0xa1, 0xd7, 0xee, 0x44, 0x9e, 0xbc, 0x57, 0x68, 0x61, 0x5c, 0xf0, 0x0f, 0xfc, 0x03, 0xff, 0xac,
		0xc2, 0x3f, 0xdc, 0x42, 0x1a, 0xca, 0x30, 0x6e, 0x21, 0xdc, 0x42, 0xb8, 0x85, 0x0c, 0xaa, 0x7f,
		0xb8, 0x85, 0xec, 0x3f, 0xfc, 0xe8, 0xf4, 0xb8, 0x85, 0x52, 0x84, 0x42, 0xb6, 0x1b, 0x6e, 0xa1,
		0x92, 0xba, 0x85, 0x26, 0xd6, 0x74, 0x3f, 0xfa, 0xe1, 0x05, 0x91, 0xdf, 0x18, 0xa6, 0xc4, 0x3b,
		0x5e, 0xe0, 0xde, 0xb4, 0x04, 0x7a, 0x29, 0x2d, 0x19, 0xed, 0xab, 0xdf, 0x06, 0x1b, 0x1e, 0x1b,
		0x1e, 0x1b, 0xde, 0x2a, 0x1b, 0x5e, 0xae, 0x13, 0xb2, 0x50, 0x07, 0xe4, 0x4c, 0xe1, 0xb1, 0xd1,
		0x09, 0xa2, 0xb0, 0xd3, 0x72, 0xba, 0x2d, 0x37, 0xf0, 0x1c, 0x3f, 0x68, 0x7a, 0x5d, 0x2f, 0x68,
		0x8e, 0xb6, 0x90, 0x2c, 0x42, 0xae, 0x7f, 0x27, 0x40, 0x12, 0x90, 0x04, 0x24, 0x01, 0x49, 0x6b,
		0x41, 0xd2, 0x58, 0x6c, 0xd1, 0x9a, 0xf1, 0x01, 0x44, 0x00, 0x11, 0x40, 0xb4, 0x0b, 0x10, 0x09,
		0x2e, 0x4a, 0x05, 0x68, 0x8d, 0x44, 0x17, 0xad, 0x1c, 0x1d, 0x90, 0x05, 0x64, 0x01, 0x59, 0xab,
		0x40, 0x96, 0xf0, 0xa2, 0x19, 0x2c, 0x6c, 0xfb, 0x81, 0xdf, 0xee, 0xb7, 0x9d, 0x71, 0x83, 0x4c,
		0x67, 0x58, 0x5a, 0xf3, 0xde, 0x6d, 0x89, 0xc3, 0xe2, 0xda, 0x37, 0x02, 0x21, 0x41, 0x48, 0x10,
		0xd2, 0x2a, 0x84, 0xec, 0xfb, 0x41, 0xb4, 0x57, 0x15, 0x44, 0xc8, 0x03, 0xca, 0x02, 0x65, 0x02,
		0x6b, 0x4b, 0xc3, 0x52, 0x16, 0x28, 0x77, 0x4b, 0x55, 0xab, 0x1e, 0xd6, 0x0e, 0xeb, 0x07, 0xd5,
		0x43, 0x8a, 0x01, 0x25, 0xfe, 0x93, 0x63, 0x8f, 0x72, 0xcf, 0xeb, 0xf5, 0xfc, 0x4e, 0xe0, 0x0c,
		0xcb, 0x9a, 0x8b, 0xb3, 0xb1, 0xf9, 0xd1, 0xa1, 0x60, 0x50, 0x30, 0x28, 0x98, 0x75, 0x4a, 0xa0,
		0xe4, 0x21, 0x45, 0x07, 0x9c, 0xf9, 0xec, 0x86, 0xb0, 0x15, 0x50, 0x05, 0x54, 0x01, 0x55, 0x40,
		0xb5, 0xa4, 0xa0, 0xda, 0xbf, 0xe9, 0x35, 0x42, 0xff, 0xc6, 0x6b, 0x3a, 0xdd, 0xb0, 0x13, 0x75,
		0x1a, 0x9d, 0x96, 0x60, 0xd6, 0xe2, 0xca, 0xd1, 0x81, 0x58, 0x20, 0x16, 0x88, 0xb5, 0x0a, 0x62,
		0xfd, 0xa6, 0x17, 0x44, 0x7e, 0xf4, 0x10, 0x7a, 0xb7, 0x92, 0xe0, 0x2a, 0xa0, 0x7d, 0x54, 0x4e,
		0xc6, 0x1f, 0xed, 0xbd, 0xdb, 0xf3, 0xe4, 0x7b, 0xec, 0x9e, 0x7c, 0xbe, 0xb8, 0x3c, 0x3a, 0x3d,
		0xbd, 0x3e, 0xff, 0x72, 0x76, 0x79, 0xf6, 0xe1, 0xec, 0xf4, 0xfa, 0xf2, 0x8f, 0xf3, 0x63, 0xa9,
		0x2d, 0x3d, 0xd4, 0x82, 0x7a, 0xa2, 0xf9, 0x1b, 0xc2, 0x22, 0xd8, 0x64, 0x1a, 0x7e, 0x3b, 0xf9,
		0x72, 0xfc, 0xe1, 0xf2, 0xf4, 0x8f, 0xeb, 0x0f, 0x67, 0x9f, 0x3f, 0x1f, 0x7f, 0xb8, 0x3c, 0xfe,
		0xad, 0x62, 0xa3, 0x12, 0x68, 0xe8, 0xe9, 0xdf, 0xff, 0x7e, 0x5e, 0xa6, 0xc7, 0x3d, 0xf9, 0xfd,
		0x53, 0xa9, 0x9e, 0xf7, 0xfc, 0xe4, 0x53, 0x99, 0x1e, 0xf7, 0xe2, 0xf2, 0xe8, 0xf2, 0xe4, 0x43,
		0x99, 0x9e, 0xf8, 0xec, 0xe2, 0xfc, 0x63, 0xd9, 0x9e, 0x77, 0xaf, 0x54, 0x88, 0x75, 0x71, 0x72,
		0x51, 0xa6, 0xe7, 0x3d, 0x3d, 0xfb, 0x70, 0x74, 0x7a, 0x7d, 0xf4, 0xfb, 0xef, 0x5f, 0x8e, 0x7f,
		0x3f, 0xba, 0x3c, 0xb6, 0xad, 0x71, 0xfa, 0x55, 0xce, 0xf9, 0xf3, 0xa9, 0xdf, 0x8b, 0x8e, 0xa2,
		0x28, 0x94, 0xe1, 0xd0, 0x9f, 0xfc, 0xe0, 0xb8, 0xe5, 0x0d, 0x2c, 0x8c, 0x9e, 0x8c, 0x3f, 0xb1,
		0xf2, 0xc9, 0xfd, 0x39, 0x33, 0xa2, 0x99, 0x06, 0x23, 0x95, 0xb3, 0xb0, 0xe9, 0x85, 0x5e, 0xf3,
		0xfd, 0x43, 0xe5, 0xdd, 0x56, 0xd0, 0x6f, 0xb5, 0xb2, 0xd2, 0x2e, 0x5e, 0xa4, 0xb8, 0x03, 0xa4,
		0xfa, 0x1f, 0x4b, 0xf5, 0x3d, 0xae, 0xe8, 0x08, 0x37, 0x12, 0xad, 0x8e, 0xd5, 0x90, 0x25, 0xf9,
		0x9a, 0x25, 0x7b, 0x45, 0xc2, 0xd5, 0xad, 0xfc, 0xd3, 0x7b, 0x90, 0xa9, 0x13, 0xa8, 0x87, 0x0c,
		0xfa, 0x48, 0x60, 0xe4, 0xe4, 0xeb, 0x9d, 0xf4, 0xa4, 0x6b, 0xa1, 0x79, 0xc2, 0xf4, 0x4f, 0x96,
		0xc2, 0x99, 0xd2, 0x3d, 0x4b, 0xc9, 0x4e, 0x51, 0xfc, 0xb3, 0x10, 0xef, 0x37, 0x63, 0xae, 0x90,
		0xea, 0xca, 0x68, 0xad, 0x48, 0x82, 0xc5, 0xd0, 0x58, 0x84, 0x78, 0xf3, 0xbf, 0x79, 0x36, 0x63,
		0xcc, 0x64, 0x25, 0x99, 0xf3, 0x71, 0x26, 0x7a, 0x39, 0x3e, 0xdc, 0x4f, 0xe5, 0xb3, 0x98, 0xbf,
		0x3e, 0x55, 0xb2, 0xab, 0x31, 0x5f, 0xa0, 0xa0, 0x58, 0xab, 0x2b, 0xd3, 0xaa, 0x0a, 0xb4, 0xb6,
		0xd2, 0xac, 0xad, 0x28, 0x6b, 0x29, 0xc7, 0xb2, 0x67, 0xf7, 0x37, 0x3f, 0xd9, 0x95, 0x54, 0x69,
		0x7a, 0x3d, 0x3f, 0xf4, 0x9a, 0xd3, 0xf8, 0xed, 0xe8, 0xa7, 0x7a, 0x8c, 0xf8, 0x74, 0xed, 0x9f,
		0x1b, 0x34, 0xe9, 0x95, 0xad, 0xe4, 0xc4, 0x51, 0x76, 0xda, 0xe8, 0x38, 0x69, 0xf4, 0x9d, 0x32,
		0xba, 0x4e, 0x18, 0x31, 0xa7, 0x8b, 0x98, 0x93, 0x45, 0xc4, 0xa9, 0x62, 0x96, 0x14, 0x2a, 0x3b,
		0x49, 0xf4, 0xe3, 0xa9, 0x35, 0xe2, 0xa7, 0x35, 0xe3, 0xa5, 0x35, 0x4c, 0x1a, 0x89, 0x78, 0x68,
		0x29, 0xdf, 0xac, 0x50, 0xbc, 0xb3, 0x64, 0xac, 0xac, 0x8e, 0x8f, 0x5d, 0x22, 0x7e, 0x59, 0x7a,
		0x6a, 0xa5, 0xe2, 0x93, 0x45, 0xe7, 0x38, 0x25, 0x6b, 0xf4, 0xca, 0x14, 0x5f, 0x7f, 0x9d, 0xe4,
		0x82, 0x8e, 0xbc, 0xe1, 0xbc, 0x39, 0xed, 0x7e, 0x2b, 0xf2, 0xbb, 0x2d, 0xdf, 0x0b, 0x75, 0x6e,
		0xe6, 0x15, 0xa3, 0x71, 0x25, 0x73, 0x25, 0x17, 0xf0, 0x4a, 0x7e, 0xab, 0x71, 0x23, 0xef, 0x73,
		0x23, 0xeb, 0x5d, 0x1b, 0xbb, 0xdc, 0xc8, 0x8b, 0x53, 0xbb, 0x57, 0x40, 0xb2, 0x53, 0xa2, 0x8b,
		0x78, 0x54, 0x8d, 0xd1, 0xe9, 0x7a, 0xa1, 0xd3, 0xf6, 0xda, 0x37, 0x5e, 0xe8, 0xb4, 0xfc, 0xe0,
		0xbf, 0xea, 0x57, 0xf1, 0x9a, 0xf1, 0x12, 0x42, 0xe5, 0x6f, 0xde, 0xad, 0xdb, 0x6f, 0x0d, 0xb1,
		0xfc, 0xd6, 0x6d, 0xf5, 0x3c, 0x2e, 0x73, 0x2e, 0xf3, 0xa2, 0x5d, 0xe6, 0xea, 0x75, 0xc4, 0x14,
		0xeb, 0x86, 0x99, 0x04, 0x90, 0xa6, 0x2e, 0x62, 0x34, 0x39, 0xe2, 0x1c, 0x71, 0x8e, 0xb8, 0x95,
		0x47, 0xdc, 0xd7, 0x38, 0xdd, 0x3e, 0x07, 0x9b, 0x83, 0x5d, 0xb8, 0x83, 0xad, 0x5c, 0x8d, 0x49,
		0xb1, 0xfa, 0x92, 0x99, 0x73, 0x3d, 0x8a, 0x18, 0x51, 0xed, 0xd5, 0xb6, 0xd0, 0xa0, 0x52, 0xad,
		0x87, 0x09, 0xa7, 0x9d, 0xd3, 0x6e, 0xfd, 0x69, 0xd7, 0x6a, 0x6d, 0xa6, 0xd3, 0xca, 0x4c, 0xaf,
		0x75, 0x99, 0x86, 0xf6, 0x26, 0xdc, 0x9a, 0x4c, 0xa2, 0x1b, 0x91, 0x58, 0xf7, 0xa1, 0x9c, 0xb4,
		0x1a, 0xbb, 0xd2, 0x99, 0x2a, 0xc9, 0xfe, 0x39, 0xb9, 0x69, 0x1d, 0x76, 0x95, 0x66, 0x2c, 0xad,
		0xcc, 0xe1, 0xaa, 0x17, 0xf4, 0x70, 0xd1, 0x5b, 0x29, 0x4f, 0xad, 0xbc, 0xac, 0x83, 0x1a, 0xb6,
		0x4f, 0xae, 0x5a, 0x73, 0x5d, 0x95, 0xc8, 0x5f, 0x12, 0x7a, 0xff, 0xeb, 0xcf, 0x45, 0x01, 0x8e,
		0x4b, 0xc3, 0xaa, 0x9b, 0x4f, 0x6b, 0x47, 0xc4, 0x92, 0xc2, 0x92, 0x2a, 0x98, 0x25, 0x45, 0x4c,
		0xa1, 0xea, 0x83, 0x13, 0x53, 0x38, 0x3f, 0xb5, 0xc4, 0x14, 0x1a, 0xba, 0x64, 0x2d, 0xbb, 0x9a,
		0xf3, 0x9c, 0x03, 0x94, 0x34, 0xc9, 0x51, 0x2d, 0x07, 0x28, 0x41, 0x26, 0x63, 0x8c, 0x1c, 0xa0,
		0x17, 0x1a, 0xf3, 0x3c, 0xc9, 0x44, 0xdc, 0xe8, 0xf3, 0x49, 0x96, 0x68, 0x98, 0x3c, 0xb1, 0x50,
		0x24, 0x91, 0x30, 0x59, 0xe2, 0xe0, 0xa6, 0xa9, 0x49, 0xb8, 0xf5, 0x14, 0xb7, 0x5c, 0x25, 0x56,
		0x0a, 0x57, 0xf2, 0x4d, 0xf6, 0xfc, 0xf6, 0x5a, 0xbf, 0x69, 0x56, 0xff, 0x64, 0xcd, 0x5c, 0xc5,
		0x9d, 0xa3, 0x44, 0x73, 0xf3, 0xcc, 0x8c, 0x24, 0x98, 0x89, 0xd5, 0xcf, 0xbf, 0xfc, 0x74, 0xf3,
		0xdf, 0x59, 0x78, 0xce, 0x4d, 0xcf, 0xb7, 0xf9, 0xb9, 0x56, 0x3c, 0xcc, 0xa6, 0x87, 0x98, 0xff,
		0xe4, 0x4f, 0x9f, 0x6f, 0xe6, 0xb3, 0x55, 0x6e, 0xee, 0xba, 0x4b, 0x1f, 0xe8, 0xc9, 0x87, 0x7d,
		0xd7, 0x5d, 0x78, 0xdb, 0x35, 0x09, 0x7a, 0x6b, 0x2d, 0x89, 0xe7, 0x2c, 0x85, 0x39, 0x4b, 0x60,
		0xe9, 0x9d, 0xe2, 0x30, 0xfd, 0xd8, 0x4c, 0x3e, 0x36, 0x53, 0x5f, 0x62, 0xe2, 0x77, 0xdd, 0x4a,
		0xc2, 0x95, 0x5e, 0x97, 0xb0, 0x56, 0xb9, 0x6b, 0x75, 0x6e, 0x9e, 0xc9, 0x41, 0x9b, 0x4e, 0xc7,
		0xf8, 0xf7, 0xd6, 0x7c, 0xc0, 0xe7, 0x33, 0x24, 0x37, 0x9a, 0x74, 0x71, 0x4c, 0xb7, 0xcd, 0x0b,
		0x93, 0xd4, 0x14, 0x4b, 0x6c, 0x72, 0x25, 0x36, 0xad, 0x62, 0x2d, 0x9c, 0x1a, 0x34, 0x6d, 0xca,
		0x40, 0xac, 0xb8, 0xb7, 0xbe, 0xd3, 0x73, 0x6f, 0xfd, 0xcd, 0x7e, 0xd4, 0xe9, 0xcc, 0x3e, 0xbd,
		0x64, 0xd3, 0xb5, 0x1a, 0x2b, 0x21, 0x36, 0xb6, 0x25, 0x9f, 0xc4, 0x72, 0x8f, 0xbf, 0x0d, 0x54,
		0x2d, 0x73, 0x65, 0x4b, 0x5c, 0xd9, 0xf2, 0x4e, 0xb4, 0x4d, 0x64, 0x88, 0x51, 0xdc, 0x04, 0xd6,
		0xe9, 0x9e, 0x48, 0x9e, 0x62, 0x3d, 0x7d, 0xa5, 0xe1, 0x2c, 0xeb, 0x9d, 0x94, 0xb2, 0xac, 0x63,
		0x6d, 0x36, 0x5d, 0x39, 0xc8, 0xc2, 0x2c, 0xeb, 0x38, 0x9b, 0xd1, 0x8c, 0x75, 0x94, 0x38, 0xcb,
		0xda, 0x6d, 0x36, 0x9d, 0x01, 0x5b, 0xd1, 0x88, 0x1d, 0x79, 0x1a, 0x42, 0x4d, 0xed, 0xdc, 0xcd,
		0x9b, 0xda, 0x99, 0x68, 0x5b, 0x97, 0x48, 0xed, 0x4c, 0xb2, 0xed, 0xd3, 0x51, 0x3b, 0x93, 0x1e,
		0x87, 0xe9, 0x0b, 0x1b, 0x93, 0x3d, 0xa6, 0xb8, 0x58, 0x93, 0xed, 0x32, 0x1e, 0x47, 0x71, 0x82,
		0xd5, 0x0e, 0x88, 0xf6, 0x41, 0x91, 0x38, 0x30, 0x72, 0x07, 0x47, 0xea, 0x00, 0x89, 0x1f, 0x24,
		0xf1, 0x03, 0x25, 0x7a, 0xb0, 0x34, 0xd5, 0x43, 0xc5, 0x1d, 0xa3, 0x7a, 0xe0, 0xa6, 0x03, 0x78,
		0x2d, 0xff, 0xce, 0x1f, 0x66, 0x1f, 0x0d, 0x97, 0xc6, 0xe9, 0x76, 0x5a, 0x7e, 0xe3, 0x41, 0xae,
		0x9c, 0xfb, 0x9a, 0xf1, 0x29, 0xe8, 0x6e, 0xfe, 0x00, 0x4b, 0x1f, 0x64, 0x63, 0x07, 0xda, 0xd8,
		0xc1, 0x36, 0x72, 0xc0, 0xf5, 0x0e, 0xba, 0xe6, 0x81, 0x9f, 0x3e, 0x91, 0x7c, 0x41, 0xf7, 0x96,
		0xe7, 0xde, 0x0a, 0x17, 0x73, 0x97, 0xe8, 0x06, 0x79, 0x3e, 0x95, 0xf6, 0x1a, 0x4e, 0xd8, 0xed,
		0xb4, 0xde, 0x85, 0x9d, 0x7e, 0xe4, 0x07, 0x77, 0x63, 0x24, 0x99, 0x7e, 0x7b, 0xf4, 0x4f, 0xa7,
		0xe9, 0xdd, 0xfa, 0x81, 0x1f, 0xf9, 0x9d, 0xa0, 0xb7, 0xfe, 0x47, 0xd3, 0x9f, 0x0c, 0x25, 0xc0,
		0x5c, 0xb6, 0x8e, 0x53, 0x0b, 0xa0, 0x58, 0xbb, 0xf8, 0x6a, 0xf1, 0x13, 0xcb, 0xd7, 0x91, 0x5e,
		0x0e, 0x2a, 0x38, 0x0f, 0xce, 0x83, 0xf3, 0x86, 0x71, 0x5e, 0x3d, 0xc1, 0x6e, 0x2d, 0xce, 0xef,
		0xe6, 0xb2, 0x35, 0x5c, 0xd0, 0x94, 0xec, 0x08, 0x17, 0x34, 0x01, 0x4f, 0xc0, 0x13, 0xf0, 0x04,
		0x3c, 0x4b, 0x02, 0x9e, 0x4e, 0x5b, 0x22, 0x9e, 0x6c, 0x16, 0x40, 0x87, 0x23, 0x02, 0x7a, 0x80,
		0x1e, 0xa0, 0x67, 0x15, 0xe8, 0xa9, 0x96, 0x50, 0x5b, 0x77, 0x38, 0x25, 0x7a, 0x51, 0xe8, 0x05,
		0x28, 0x2f, 0xfe, 0x91, 0x6b, 0xca, 0x22, 0x12, 0xc0, 0x6c, 0x08, 0xd5, 0x96, 0x86, 0x15, 0x0a,
		0x70, 0x5e, 0x1a, 0x57, 0x30, 0x18, 0x57, 0xf8, 0x74, 0xcc, 0x2f, 0x95, 0xfb, 0x33, 0x77, 0x4b,
		0x55, 0xdd, 0xdf, 0xcf, 0xd1, 0x62, 0xbd, 0xb0, 0x63, 0x94, 0x2b, 0x3a, 0xd5, 0x24, 0x21, 0x77,
		0xeb, 0x43, 0x2a, 0xef, 0xba, 0xdb, 0x83, 0xff, 0x8f, 0x22, 0xed, 0xb6, 0xa7, 0xc1, 0x58, 0xd3,
		0xaf, 0xb6, 0xa7, 0xb1, 0x09, 0xdb, 0x5a, 0x9e, 0xd8, 0xad, 0x67, 0xa3, 0x34, 0xef, 0xba, 0xd7,
		0x83, 0xff, 0xff, 0x3e, 0xfc, 0x14, 0xd7, 0x47, 0xb7, 0xfe, 0xc5, 0xe0, 0x43, 0x4c, 0xbe, 0xb8,
		0x3e, 0x6a, 0x36, 0xcf, 0x07, 0x1f, 0xe1, 0x7a, 0x4c, 0xe2, 0xd2, 0x6a, 0x58, 0xa3, 0xd4, 0x45,
		0x44, 0xa7, 0x2f, 0xbd, 0x52, 0xab, 0x88, 0xb5, 0x76, 0x88, 0xae, 0xd3, 0xbb, 0x8a, 0xd3, 0xdb,
		0x20, 0x13, 0xc6, 0xe9, 0x3d, 0x23, 0x94, 0xe1, 0xf4, 0xc6, 0xb4, 0xc5, 0xb4, 0xc5, 0xb4, 0xd5,
		0xdf, 0x6f, 0x38, 0xbd, 0xf3, 0x23, 0x3a, 0xe2, 0xf4, 0x06, 0xe7, 0xc1, 0x79, 0x70, 0x5e, 0x65,
		0xbf, 0xe1, 0xb7, 0xd9, 0xc2, 0xe9, 0x0d, 0x78, 0x02, 0x9e, 0x80, 0x27, 0xe0, 0xa9, 0x01, 0x9e,
		0x38, 0xbd, 0x01, 0x3d, 0x40, 0xaf, 0x0c, 0xa0, 0x87, 0xd3, 0x3b, 0xc1, 0x07, 0xc3, 0xe9, 0x8d,
		0xd3, 0x1b, 0xa7, 0xb7, 0x04, 0x10, 0xca, 0x8d, 0x82, 0xd3, 0x3b, 0x11, 0xb9, 0x13, 0x71, 0x7a,
		0xeb, 0x38, 0x62, 0xb7, 0x44, 0x7c, 0xde, 0x09, 0x2a, 0x9b, 0xe9, 0x2f, 0x9c, 0xd9, 0x64, 0x72,
		0xcd, 0xa5, 0x95, 0x59, 0xd2, 0x8a, 0x92, 0x57, 0x5f, 0x6f, 0x11, 0x2b, 0x16, 0xd4, 0xec, 0x9d,
		0xcc, 0x84, 0x33, 0x7e, 0x0c, 0xd5, 0x5a, 0x15, 0x73, 0xc3, 0x94, 0xa4, 0x3a, 0x2f, 0xf5, 0x2a,
		0xe4, 0xcc, 0x0c, 0xdb, 0xab, 0xf3, 0xaa, 0x3b, 0x10, 0x75, 0x1c, 0x86, 0x53, 0x07, 0xe1, 0x9b,
		0x37, 0xe3, 0x40, 0xab, 0xed, 0xf9, 0x93, 0x66, 0x01, 0x82, 0x28, 0x96, 0xf4, 0xd0, 0x2b, 0xe5,
		0x41, 0x8d, 0x1b, 0x30, 0xc3, 0xd6, 0x1a, 0x37, 0x7a, 0x57, 0xaa, 0xe8, 0xd5, 0x2a, 0x64, 0xb8,
		0x51, 0xf1, 0x26, 0x1d, 0x45, 0x90, 0xe0, 0x3f, 0x41, 0xa5, 0x6f, 0xa6, 0xcd, 0xa6, 0x17, 0x44,
		0x7e, 0xf4, 0xa0, 0x17, 0xff, 0x33, 0xbd, 0x71, 0x34, 0x24, 0x8a, 0xca, 0xc9, 0xf8, 0xa3, 0xbc,
		0x77, 0x7b, 0x82, 0xf1, 0x2d, 0x47, 0x1f, 0x4f, 0xae, 0x2f, 0x06, 0xff, 0xb9, 0xfc, 0xe3, 0xfc,
		0xb8, 0x22, 0x51, 0xb1, 0xbd, 0x27, 0x22, 0x3e, 0x0a, 0xe9, 0xee, 0x93, 0xc7, 0xbc, 0xf8, 0x72,
		0x79, 0x7c, 0x7d, 0x7e, 0x76, 0x7a, 0xf2, 0xe1, 0x8f, 0xeb, 0x93, 0xf3, 0x6f, 0x75, 0x01, 0x2d,
		0xfb, 0xb5, 0x6d, 0xcf, 0x78, 0xba, 0xf7, 0xed, 0xfc, 0xf3, 0xe0, 0xe9, 0x6a, 0xd7, 0x5f, 0x3f,
		0x9f, 0x7c, 0x38, 0xba, 0xb8, 0x2c, 0xe4, 0x53, 0x9e, 0x7c, 0xfe, 0xe7, 0xc5, 0xe5, 0xd1, 0xe5,
		0xf1, 0xf5, 0xc5, 0xf9, 0xc7, 0x82, 0x2f, 0xe3, 0xa7, 0xaf, 0xa7, 0x97, 0x85, 0x5d, 0xc8, 0x6f,
		0xe7, 0x9f, 0xbf, 0xd5, 0xae, 0x3f, 0x9e, 0x9e, 0xfd, 0xeb, 0xe2, 0xfc, 0xf8, 0x43, 0x11, 0x9f,
		0x70, 0x01, 0x74, 0x6a, 0x85, 0xdc, 0xad, 0xd5, 0xc1, 0x6e, 0xfd, 0x76, 0x7e, 0x7a, 0x51, 0xdc,
		0xa7, 0x3b, 0xfe, 0x76, 0xfe, 0xb9, 0xd0, 0x50, 0x5a, 0xc4, 0x87, 0x1b, 0x02, 0xe8, 0xe9, 0xd1,
		0xfb, 0xe3, 0xd3, 0xe3, 0xdf, 0xca, 0x71, 0x1f, 0x16, 0x75, 0x97, 0x4e, 0xee, 0xc3, 0x7a, 0xb1,
		0xef, 0xc3, 0xe1, 0x86, 0x2d, 0xf2, 0x75, 0x38, 0x5c, 0xc2, 0x32, 0x9c, 0xc8, 0xa7, 0x0d, 0x5b,
		0xe0, 0xa7, 0x2c, 0xba, 0x9d, 0x21, 0xbc, 0x7e, 0x5a, 0x23, 0x5c, 0x59, 0xdf, 0xa7, 0x4c, 0x25,
		0xb1, 0xd9, 0x0b, 0xdc, 0x9b, 0x96, 0xd7, 0xd4, 0x57, 0x39, 0x27, 0x03, 0xa9, 0xa6, 0x8a, 0xca,
		0x84, 0x97, 0xa3, 0x93, 0xce, 0x8d, 0x84, 0x4e, 0x9a, 0xe2, 0x79, 0xcd, 0x5c, 0x27, 0xd5, 0x0f,
		0xff, 0xd6, 0x0c, 0xfb, 0x26, 0x30, 0xe5, 0x29, 0x30, 0x45, 0xb9, 0xac, 0x86, 0x72, 0x54, 0x8a,
		0x4a, 0x15, 0x0d, 0x33, 0x1e, 0xe5, 0xbb, 0xd0, 0x6d, 0x78, 0xb7, 0xfd, 0x96, 0x13, 0x7a, 0xbd,
		0xc8, 0x0d, 0x23, 0x75, 0xdf, 0xf2, 0xd2, 0x48, 0x78, 0x99, 0xcd, 0xc1, 0x3d, 0x5e, 0x66, 0x3a,
		0xa9, 0xc0, 0x97, 0xe0, 0x4b, 0x76, 0xf3, 0x25, 0xfd, 0xa2, 0x32, 0x9a, 0x26, 0x8f, 0xb0, 0xe9,
		0x23, 0x6d, 0x02, 0x09, 0x99, 0x42, 0x62, 0x47, 0x5c, 0xf2, 0xa8, 0xcb, 0x1f, 0x79, 0xe9, 0xa3,
		0x6f, 0x0c, 0x02, 0x8c, 0x41, 0x81, 0x11, 0x48, 0x90, 0x91, 0x5c, 0xc8, 0xb0, 0x35, 0x38, 0xc1,
		0xe5, 0x4b, 0xff, 0x58, 0x34, 0x26, 0x32, 0x2c, 0x7d, 0xf8, 0xfb, 0xf8, 0xa3, 0x7c, 0x19, 0x7d,
		0x12, 0x2a, 0x20, 0xa6, 0x4a, 0x56, 0xa9, 0x80, 0x08, 0x59, 0x85, 0xac, 0x42, 0x56, 0x21, 0xab,
		0x90, 0x55, 0xc8, 0x2a, 0x64, 0x35, 0x17, 0x64, 0x35, 0xb3, 0x94, 0xe5, 0x45, 0xae, 0x4a, 0xe6,
		0xb2, 0x91, 0x05, 0x4e, 0xd3, 0x55, 0xb4, 0xb0, 0xa4, 0x36, 0xf8, 0x8c, 0xfc, 0xee, 0x7d, 0xcd,
		0x69, 0xb9, 0x37, 0x5e, 0xcb, 0x6b, 0x3a, 0xfd, 0xc0, 0x6f, 0xb8, 0x3d, 0x0d, 0xbf, 0xd1, 0xca,
		0xd1, 0xf0, 0x1d, 0x99, 0xa3, 0x14, 0xf8, 0x8e, 0xd2, 0xf4, 0x1d, 0x8d, 0xcb, 0x95, 0xb7, 0xfc,
		0xb6, 0x1f, 0xe9, 0xdb, 0xe4, 0x73, 0xa3, 0xe1, 0x47, 0xc2, 0x34, 0xc7, 0x34, 0x8f, 0x33, 0x80,
		0xa6, 0x03, 0x77, 0x69, 0xdb, 0x69, 0xab, 0x91, 0x02, 0x07, 0x11, 0x43, 0x1a, 0x43, 0x3a, 0xef,
		0x86, 0xb4, 0xee, 0xc1, 0x9e, 0x0e, 0xd4, 0x76, 0x7f, 0x8e, 0x1b, 0x83, 0x0c, 0xf3, 0x69, 0x85,
		0x63, 0x9b, 0xe7, 0x46, 0x17, 0x5a, 0x4c, 0xd9, 0xf2, 0x6e, 0x62, 0x20, 0x60, 0x02, 0x0c, 0xcc,
		0x81, 0x82, 0x29, 0x70, 0x30, 0x0e, 0x12, 0xc6, 0xc1, 0xc2, 0x28, 0x68, 0xc8, 0x80, 0x87, 0x10,
		0x88, 0xc8, 0xab, 0x72, 0x4b, 0xfb, 0xb5, 0xef, 0x07, 0xd1, 0x5e, 0x55, 0x72, 0xbf, 0x8e, 0x4f,
		0xff, 0x81, 0xe0, 0x90, 0xb2, 0x85, 0x4c, 0x27, 0x7f, 0x64, 0xcf, 0xd3, 0x96, 0xa9, 0xc2, 0xa6,
		0x86, 0x60, 0x75, 0x69, 0x78, 0x43, 0x85, 0x4e, 0xa7, 0xe3, 0x1b, 0xac, 0xa1, 0x29, 0x7c, 0xdc,
		0xe6, 0x97, 0xd4, 0x40, 0x01, 0xd4, 0xb4, 0x97, 0xb4, 0x56, 0x3d, 0xac, 0x1d, 0xd6, 0x0f, 0xaa,
		0x87, 0xfb, 0x39, 0x5e, 0xdb, 0x17, 0x76, 0x8e, 0x76, 0x65, 0x49, 0xfd, 0x56, 0x81, 0xbd, 0x3f,
		0xe0, 0x01, 0xf7, 0x5e, 0x10, 0x39, 0x91, 0xe7, 0x86, 0xcd, 0xce, 0x5f, 0x81, 0x3c, 0xdd, 0x5c,
		0x7a, 0x07, 0xa1, 0x0b, 0x52, 0xd8, 0x11, 0x0c, 0x95, 0x85, 0xca, 0x42, 0x65, 0x73, 0x46, 0x65,
		0xe5, 0x1c, 0xcd, 0x4b, 0x32, 0xd6, 0x6e, 0x81, 0x40, 0x7e, 0xec, 0xe8, 0x73, 0x22, 0xbf, 0xed,
		0x85, 0xf2, 0x08, 0x3f, 0x3f, 0x3c, 0x30, 0x0c, 0x0c, 0x03, 0xc3, 0xa5, 0x82, 0xe1, 0xa6, 0xd7,
		0xf0, 0xdb, 0x6e, 0xab, 0x5e, 0x33, 0x01, 0xc4, 0x55, 0xc1, 0x31, 0x97, 0x8c, 0x96, 0x2a, 0x92,
		0x85, 0x19, 0xfb, 0xb6, 0x8a, 0x64, 0x51, 0x34, 0xc9, 0x62, 0x8f, 0x25, 0x45, 0xa9, 0xc8, 0x8e,
		0xc4, 0xfe, 0xe5, 0x86, 0x81, 0x1f, 0xdc, 0x39, 0xd1, 0x8f, 0xd0, 0xeb, 0xfd, 0xe8, 0xb4, 0x9a,
		0x4e, 0xb7, 0x11, 0xc9, 0x93, 0xd9, 0xd5, 0x6f, 0x03, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x4b, 0x45,
		0x6a, 0xbb, 0x5e, 0xd8, 0xf0, 0x82, 0xc8, 0xbd, 0xf3, 0x0c, 0xb0, 0xda, 0x7d, 0x78, 0xa7, 0x19,
		0x92, 0x82, 0xab, 0xac, 0x70, 0xbc, 0xd3, 0xf4, 0x92, 0xee, 0xee, 0xc0, 0x3c, 0x8b, 0xcb, 0x3c,
		0x33, 0x8d, 0x08, 0x13, 0xca, 0xe7, 0x99, 0x8e, 0xa7, 0x93, 0xf6, 0xb1, 0x2a, 0x33, 0x61, 0x7b,
		0x36, 0x02, 0x7b, 0x5b, 0x24, 0x0e, 0x74, 0x4b, 0x27, 0x3d, 0xe4, 0xa4, 0x7b, 0x5f, 0x3b, 0x1d,
		0x7d, 0xc4, 0xaf, 0xa3, 0x4f, 0x78, 0x3d, 0xa2, 0xa4, 0xa7, 0x83, 0x0f, 0xa8, 0x95, 0xac, 0xae,
		0xbf, 0x21, 0xb4, 0x3a, 0x83, 0x6b, 0x25, 0xb1, 0x2f, 0x71, 0x13, 0xdd, 0x94, 0xac, 0x2d, 0x13,
		0x01, 0xbb, 0x55, 0x02, 0x76, 0x2d, 0x30, 0x32, 0x08, 0xd8, 0x8d, 0xff, 0x44, 0x04, 0xec, 0xa2,
		0x44, 0xa0, 0x44, 0xa0, 0x44, 0x58, 0xae, 0x44, 0x10, 0xb0, 0x8b, 0x0a, 0x81, 0x0a, 0x51, 0x70,
		0x15, 0x82, 0x80, 0xdd, 0x12, 0x88, 0x11, 0x04, 0xec, 0x12, 0xb0, 0x0b, 0x95, 0x85, 0xca, 0x96,
		0x96, 0xca, 0x12, 0xb0, 0x1b, 0xeb, 0x99, 0x08, 0xd8, 0x05, 0x86, 0x81, 0x61, 0x60, 0x98, 0x80,
		0x5d, 0x02, 0x76, 0x09, 0xd8, 0x45, 0xb2, 0x50, 0x5b, 0x52, 0x02, 0x76, 0x51, 0x2a, 0x32, 0x24,
		0xb1, 0x04, 0xec, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0xda, 0xb4, 0x48, 0x2d, 0x01, 0xbb, 0x79, 0xe4,
		0x9d, 0xb8, 0xca, 0x0a, 0xc7, 0x3b, 0x09, 0xd8, 0x85, 0x79, 0x66, 0x34, 0x42, 0xb9, 0x02, 0x76,
		0x25, 0xc2, 0x40, 0xb7, 0x0c, 0xc6, 0xeb, 0x6a, 0x14, 0xec, 0xd7, 0xdf, 0x0e, 0xe5, 0xeb, 0xdc,
		0xb0, 0x71, 0xc3, 0x64, 0xd1, 0xc4, 0xe1, 0xf9, 0x2d, 0x42, 0x37, 0x07, 0x13, 0x8b, 0x9e, 0x66,
		0x47, 0x87, 0xe5, 0xf5, 0xb5, 0xa6, 0xa9, 0x83, 0x4c, 0x33, 0x07, 0x9a, 0x38, 0x98, 0xb7, 0xec,
		0x69, 0xe2, 0x40, 0x03, 0xf0, 0x94, 0xa5, 0x34, 0x1a, 0x37, 0x64, 0x23, 0x7d, 0x95, 0xb9, 0x71,
		0x43, 0xcf, 0x0b, 0x9a, 0x4e, 0x73, 0x14, 0x06, 0xe7, 0x84, 0x9d, 0xbe, 0x68, 0x4a, 0xd8, 0xf2,
		0xd8, 0x74, 0x5a, 0x34, 0x0d, 0x00, 0xf2, 0x40, 0x20, 0x0d, 0x08, 0xc6, 0x80, 0xc1, 0x18, 0x40,
		0x18, 0x01, 0x0a, 0x3b, 0xd4, 0x05, 0x3a, 0x2d, 0x62, 0xaf, 0x2f, 0x9a, 0x6e, 0x13, 0x3b, 0x3d,
		0xbb, 0x96, 0xe0, 0x03, 0x0b, 0x6e, 0x62, 0x9a, 0xdb, 0xdf, 0x0e, 0x9c, 0x0e, 0x64, 0x10, 0x59,
		0x88, 0x6c, 0xc6, 0x44, 0x96, 0x0e, 0x64, 0x10, 0x4c, 0x08, 0xa6, 0x7d, 0x04, 0x93, 0x82, 0x06,
		0x44, 0x6a, 0x89, 0x8c, 0x4c, 0xa4, 0x56, 0x9a, 0xa0, 0x21, 0x03, 0x1e, 0x42, 0x20, 0x22, 0x6f,
		0xad, 0x2e, 0xed, 0x57, 0x0a, 0x1a, 0x48, 0xee, 0x48, 0xa2, 0xb4, 0xd6, 0x8f, 0x4f, 0x94, 0x56,
		0x66, 0x4b, 0x4a, 0x41, 0x03, 0x73, 0xa3, 0x51, 0xd0, 0x20, 0xa1, 0xc8, 0x43, 0x41, 0x03, 0xa8,
		0x2c, 0x54, 0x16, 0x2a, 0x2b, 0xbe, 0x5f, 0x29, 0x68, 0x10, 0xeb, 0x99, 0x28, 0x68, 0x00, 0x0c,
		0x03, 0xc3, 0xc0, 0x30, 0x05, 0x0d, 0x28, 0x68, 0x40, 0x41, 0x03, 0x24, 0x0b, 0xb5, 0x25, 0xa5,
		0xa0, 0x01, 0x4a, 0x45, 0x86, 0x24, 0x96, 0x82, 0x06, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x36, 0x2d,
		0x52, 0x4b, 0x41, 0x83, 0x3c, 0xf2, 0x4e, 0x5c, 0x65, 0x85, 0xe3, 0x9d, 0x14, 0x34, 0x80, 0x79,
		0x66, 0x34, 0x42, 0xe1, 0x0a, 0x1a, 0x58, 0xdc, 0x79, 0x8c, 0x96, 0x63, 0xcf, 0x90, 0x11, 0x5a,
		0x8e, 0xa5, 0x6d, 0x65, 0x10, 0xa1, 0x4b, 0x84, 0xee, 0xfa, 0x81, 0x88, 0xd0, 0x45, 0x7a, 0x40,
		0x7a, 0x40, 0x7a, 0x20, 0x42, 0x17, 0xd9, 0x01, 0xd9, 0x01, 0xd9, 0x41, 0x61, 0x49, 0x89, 0xd0,
		0x2d, 0x81, 0xfa, 0x40, 0x84, 0x2e, 0x11, 0xba, 0x50, 0x59, 0xa8, 0x6c, 0x69, 0xa9, 0x2c, 0x11,
		0xba, 0xb1, 0x9e, 0x89, 0x08, 0x5d, 0x60, 0x18, 0x18, 0x06, 0x86, 0x89, 0xd0, 0x25, 0x42, 0x97,
		0x08, 0x5d, 0x24, 0x0b, 0xb5, 0x25, 0x25, 0x42, 0x17, 0xa5, 0x22, 0x43, 0x12, 0x4b, 0x84, 0x2e,
		0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x4d, 0x8b, 0xd4, 0x12, 0xa1, 0x9b, 0x47, 0xde, 0x89, 0xab, 0xac,
		0x70, 0xbc, 0x93, 0x08, 0x5d, 0x98, 0x67, 0x46, 0x23, 0x94, 0x23, 0x42, 0xd7, 0x8a, 0x56, 0x63,
		0xf4, 0x18, 0xb3, 0xab, 0x66, 0xb9, 0x0d, 0xbd, 0xc5, 0xb2, 0x6c, 0x2a, 0xa6, 0xd4, 0x66, 0x4b,
		0x27, 0x2a, 0x5b, 0x24, 0x1a, 0x5b, 0xac, 0x60, 0x79, 0x95, 0x82, 0xe5, 0x06, 0x2d, 0x42, 0x0a,
		0x96, 0x3f, 0x7d, 0x72, 0x3a, 0xef, 0x58, 0x40, 0x92, 0x29, 0x8c, 0x6e, 0x97, 0x54, 0x44, 0xda,
		0x45, 0x06, 0x12, 0x10, 0x9d, 0x77, 0x0a, 0xc7, 0x62, 0x75, 0x4d, 0x1b, 0x11, 0xfa, 0xaa, 0x61,
		0xc6, 0xd0, 0x0d, 0x77, 0xf5, 0xc2, 0xa6, 0xdd, 0x05, 0xd7, 0xae, 0xf6, 0xb7, 0xf5, 0xa5, 0xa6,
		0xc0, 0x3a, 0x6d, 0x70, 0xeb, 0x9a, 0x2d, 0x86, 0x69, 0x87, 0x9b, 0x09, 0x65, 0xa0, 0x1d, 0x6e,
		0x8c, 0x17, 0xd2, 0x51, 0x0c, 0x03, 0x1d, 0x03, 0x3d, 0x63, 0x03, 0x9d, 0x8e, 0x62, 0x18, 0xce,
		0x18, 0xce, 0xf6, 0x19, 0xce, 0xd4, 0x2b, 0x20, 0x10, 0x4b, 0x64, 0x64, 0x02, 0xb1, 0xd2, 0x04,
		0x0d, 0x19, 0xf0, 0x10, 0x02, 0x11, 0x79, 0x15, 0x6e, 0x69, 0xbf, 0x52, 0xaf, 0x40, 0x72, 0x47,
		0x12, 0x84, 0xb5, 0x7e, 0x7c, 0x82, 0xb0, 0x32, 0x5b, 0x52, 0xea, 0x15, 0x98, 0x1b, 0x8d, 0x7a,
		0x05, 0x09, 0x45, 0x1e, 0xea, 0x15, 0x40, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0xf1, 0xfd, 0x4a, 0xbd,
		0x82, 0x58, 0xcf, 0x44, 0xbd, 0x02, 0x60, 0x18, 0x18, 0x06, 0x86, 0xa9, 0x57, 0x40, 0xbd, 0x02,
		0xea, 0x15, 0x20, 0x59, 0xa8, 0x2d, 0x29, 0xf5, 0x0a, 0x50, 0x2a, 0x32, 0x24, 0xb1, 0xd4, 0x2b,
		0x80, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x69, 0x91, 0x5a, 0xea, 0x15, 0xe4, 0x91, 0x77, 0xe2, 0x2a,
		0x2b, 0x1c, 0xef, 0xa4, 0x5e, 0x01, 0xcc, 0x33, 0xa3, 0x11, 0x0a, 0x56, 0xaf, 0x60, 0x29, 0x33,
		0xc1, 0xc2, 0xce, 0x62, 0xf5, 0xd3, 0xd1, 0x47, 0xa4, 0xc1, 0xd8, 0x33, 0xdc, 0x84, 0x06, 0x63,
		0x69, 0x1b, 0x1d, 0x04, 0xec, 0x12, 0xb0, 0xbb, 0x7e, 0x20, 0x02, 0x76, 0x51, 0x22, 0x50, 0x22,
		0x50, 0x22, 0x08, 0xd8, 0x45, 0x85, 0x40, 0x85, 0x40, 0x85, 0x50, 0x58, 0x52, 0x02, 0x76, 0x4b,
		0x20, 0x46, 0x10, 0xb0, 0x4b, 0xc0, 0x2e, 0x54, 0x16, 0x2a, 0x5b, 0x5a, 0x2a, 0x4b, 0xc0, 0x6e,
		0xac, 0x67, 0x22, 0x60, 0x17, 0x18, 0x06, 0x86, 0x81, 0x61, 0x02, 0x76, 0x09, 0xd8, 0x25, 0x60,
		0x17, 0xc9, 0x42, 0x6d, 0x49, 0x09, 0xd8, 0x45, 0xa9, 0xc8, 0x90, 0xc4, 0x12, 0xb0, 0x0b, 0xa9,
		0x85, 0xd4, 0x42, 0x6a, 0xd3, 0x22, 0xb5, 0x04, 0xec, 0xe6, 0x91, 0x77, 0xe2, 0x2a, 0x2b, 0x1c,
		0xef, 0x24, 0x60, 0x17, 0xe6, 0x99, 0xd1, 0x08, 0xe5, 0x0a, 0xd8, 0xb5, 0xa1, 0xd1, 0xd8, 0x73,
		0xf1, 0xba, 0xf4, 0x1b, 0xb3, 0x6b, 0xc3, 0x64, 0xd4, 0xb8, 0xe1, 0x99, 0x2d, 0x42, 0x17, 0x07,
		0x13, 0x8b, 0x9e, 0x72, 0x37, 0x87, 0x85, 0xf5, 0xb5, 0xa6, 0xa9, 0x83, 0x4c, 0x33, 0x07, 0x9a,
		0x38, 0x98, 0xb7, 0xec, 0x69, 0xe2, 0x90, 0x66, 0x13, 0x07, 0xcd, 0xfa, 0xf1, 0x32, 0x75, 0xe3,
		0x69, 0xdc, 0x60, 0x42, 0x1a, 0xa3, 0x71, 0x83, 0x41, 0x8e, 0x47, 0x67, 0x45, 0x0b, 0xd4, 0x01,
		0x1a, 0x44, 0xd8, 0x01, 0x0c, 0xc6, 0x00, 0xc2, 0x08, 0x50, 0xd8, 0xa1, 0x2e, 0xd0, 0x59, 0x11,
		0x7b, 0x7d, 0xd1, 0x74, 0x9b, 0xd8, 0xe9, 0xda, 0xc9, 0xd7, 0x5a, 0x16, 0xdc, 0xc4, 0x34, 0xd7,
		0xc9, 0xb0, 0x4e, 0xa7, 0x29, 0x38, 0x1d, 0xc8, 0x20, 0xb2, 0x10, 0xd9, 0x8c, 0x89, 0x2c, 0x1d,
		0xc8, 0x20, 0x98, 0x10, 0x4c, 0xfb, 0x08, 0x26, 0x05, 0x0d, 0x88, 0xd4, 0x12, 0x19, 0x99, 0x48,
		0xad, 0x34, 0x41, 0x43, 0x06, 0x3c, 0x84, 0x40, 0x44, 0xde, 0x5a, 0x5d, 0xda, 0xaf, 0x14, 0x34,
		0x90, 0xdc, 0x91, 0x44, 0x69, 0xad, 0x1f, 0x9f, 0x28, 0xad, 0xcc, 0x96, 0x94, 0x82, 0x06, 0xe6,
		0x46, 0xa3, 0xa0, 0x41, 0x42, 0x91, 0x87, 0x82, 0x06, 0x50, 0x59, 0xa8, 0x2c, 0x54, 0x56, 0x7c,
		0xbf, 0x52, 0xd0, 0x20, 0xd6, 0x33, 0x51, 0xd0, 0x00, 0x18, 0x06, 0x86, 0x81, 0x61, 0x0a, 0x1a,
		0x50, 0xd0, 0x80, 0x82, 0x06, 0x48, 0x16, 0x6a, 0x4b, 0x4a, 0x41, 0x03, 0x94, 0x8a, 0x0c, 0x49,
		0x2c, 0x05, 0x0d, 0x20, 0xb5, 0x90, 0x5a, 0x48, 0x6d, 0x5a, 0xa4, 0x96, 0x82, 0x06, 0x79, 0xe4,
		0x9d, 0xb8, 0xca, 0x0a, 0xc7, 0x3b, 0x29, 0x68, 0x00, 0xf3, 0xcc, 0x68, 0x84, 0xc2, 0x15, 0x34,
		0xb0, 0xb8, 0xf3, 0x18, 0x2d, 0xc7, 0x9e, 0x21, 0x23, 0xb4, 0x1c, 0x4b, 0xdb, 0xca, 0x20, 0x42,
		0x97, 0x08, 0xdd, 0xf5, 0x03, 0x11, 0xa1, 0x8b, 0xf4, 0x80, 0xf4, 0x80, 0xf4, 0x40, 0x84, 0x2e,
		0xb2, 0x03, 0xb2, 0x03, 0xb2, 0x83, 0xc2, 0x92, 0x12, 0xa1, 0x5b, 0x02, 0xf5, 0x81, 0x08, 0x5d,
		0x22, 0x74, 0xa1, 0xb2, 0x50, 0xd9, 0xd2, 0x52, 0x59, 0x22, 0x74, 0x63, 0x3d, 0x13, 0x11, 0xba,
		0xc0, 0x30, 0x30, 0x0c, 0x0c, 0x13, 0xa1, 0x4b, 0x84, 0x2e, 0x11, 0xba, 0x48, 0x16, 0x6a, 0x4b,
		0x4a, 0x84, 0x2e, 0x4a, 0x45, 0x86, 0x24, 0x96, 0x08, 0x5d, 0x48, 0x2d, 0xa4, 0x16, 0x52, 0x9b,
		0x16, 0xa9, 0x25, 0x42, 0x37, 0x8f, 0xbc, 0x13, 0x57, 0x59, 0xe1, 0x78, 0x27, 0x11, 0xba, 0x30,
		0xcf, 0x8c, 0x46, 0x28, 0x47, 0x84, 0xae, 0x15, 0xad, 0xc6, 0xe8, 0x31, 0x66, 0x57, 0xcd, 0x72,
		0x1b, 0x7a, 0x8b, 0x65, 0xd9, 0x54, 0x4c, 0xa9, 0xcd, 0x96, 0x4e, 0x54, 0xb6, 0x48, 0x34, 0xb6,
		0x58, 0xc1, 0xf2, 0x2a, 0x05, 0xcb, 0x0d, 0x5a, 0x84, 0x14, 0x2c, 0x7f, 0xfa, 0xe4, 0x74, 0xde,
		0xb1, 0x80, 0x24, 0x53, 0x18, 0xdd, 0x2e, 0xa9, 0x88, 0xb4, 0x8b, 0x0c, 0x24, 0x20, 0x3a, 0xef,
		0x14, 0x8e, 0xc5, 0xea, 0x9a, 0x36, 0x22, 0xf4, 0x55, 0xc3, 0x8c, 0xa1, 0x1b, 0xee, 0xea, 0x85,
		0x4d, 0xbb, 0x0b, 0xae, 0x45, 0xed, 0x6f, 0x5b, 0xd5, 0xfb, 0x6e, 0xe0, 0x78, 0xf7, 0xdd, 0x40,
		0xbd, 0xf9, 0xed, 0xcc, 0x18, 0xb4, 0xbe, 0x35, 0x47, 0x17, 0x68, 0x7d, 0x9b, 0x66, 0xeb, 0x5b,
		0xba, 0x87, 0x61, 0x8c, 0x63, 0x8c, 0x67, 0x6c, 0x8c, 0xd3, 0x3d, 0x0c, 0x23, 0x19, 0x23, 0xd9,
		0x3e, 0x23, 0x99, 0xda, 0x04, 0x04, 0x5d, 0x89, 0x8c, 0x4c, 0xd0, 0x55, 0x9a, 0xa0, 0x21, 0x03,
		0x1e, 0x42, 0x20, 0x22, 0xaf, 0xb8, 0x2d, 0xed, 0x57, 0x6a, 0x13, 0x48, 0xee, 0x48, 0x02, 0xae,
		0xd6, 0x8f, 0x4f, 0xc0, 0x55, 0x66, 0x4b, 0x4a, 0x6d, 0x02, 0x73, 0xa3, 0x51, 0x9b, 0x20, 0xa1,
		0xc8, 0x43, 0x6d, 0x02, 0xa8, 0x2c, 0x54, 0x16, 0x2a, 0x2b, 0xbe, 0x5f, 0xa9, 0x4d, 0x10, 0xeb,
		0x99, 0xa8, 0x4d, 0x00, 0x0c, 0x03, 0xc3, 0xc0, 0x30, 0xb5, 0x09, 0xa8, 0x4d, 0x40, 0x6d, 0x02,
		0x24, 0x0b, 0xb5, 0x25, 0xa5, 0x36, 0x01, 0x4a, 0x45, 0x86, 0x24, 0x96, 0xda, 0x04, 0x90, 0x5a,
		0x48, 0x2d, 0xa4, 0x36, 0x2d, 0x52, 0x4b, 0x6d, 0x82, 0x3c, 0xf2, 0x4e, 0x5c, 0x65, 0x85, 0xe3,
		0x9d, 0xd4, 0x26, 0x80, 0x79, 0x66, 0x34, 0x42, 0x91, 0x6a, 0x13, 0x3c, 0xe5, 0x23, 0xd8, 0xd6,
		0x3b, 0xec, 0xb4, 0xfa, 0xad, 0x1b, 0x1c, 0xdf, 0x77, 0x03, 0x3a, 0x87, 0xad, 0x22, 0x22, 0x74,
		0x0e, 0x4b, 0xdb, 0xc2, 0x20, 0x3a, 0x97, 0xe8, 0xdc, 0xf5, 0x03, 0x11, 0x9d, 0x8b, 0xec, 0x80,
		0xec, 0x80, 0xec, 0x40, 0x74, 0x2e, 0x92, 0x03, 0x92, 0x03, 0x92, 0x83, 0xc2, 0x92, 0x12, 0x9d,
		0x5b, 0x02, 0xe5, 0x81, 0xe8, 0x5c, 0xa2, 0x73, 0xa1, 0xb2, 0x50, 0xd9, 0xd2, 0x52, 0x59, 0xa2,
		0x73, 0x63, 0x3d, 0x13, 0xd1, 0xb9, 0xc0, 0x30, 0x30, 0x0c, 0x0c, 0x13, 0x9d, 0x4b, 0x74, 0x2e,
		0xd1, 0xb9, 0x48, 0x16, 0x6a, 0x4b, 0x4a, 0x74, 0x2e, 0x4a, 0x45, 0x86, 0x24, 0x96, 0xe8, 0x5c,
		0x48, 0x2d, 0xa4, 0x16, 0x52, 0x9b, 0x16, 0xa9, 0x25, 0x3a, 0x37, 0x8f, 0xbc, 0x13, 0x57, 0x59,
		0xe1, 0x78, 0x27, 0xd1, 0xb9, 0x30, 0xcf, 0x8c, 0x46, 0x28, 0x43, 0x74, 0x6e, 0xe6, 0x7d, 0xc3,
		0x56, 0x07, 0xe7, 0xd2, 0x35, 0xcc, 0x86, 0xdd, 0x91, 0x45, 0xd3, 0x85, 0x95, 0xfb, 0x81, 0xc6,
		0x0b, 0x72, 0x2b, 0x9c, 0x66, 0xdb, 0x85, 0xe9, 0x62, 0xda, 0xd3, 0x74, 0xe1, 0xbe, 0xdb, 0xea,
		0xe9, 0x36, 0x5d, 0x18, 0x8e, 0x41, 0xd3, 0x05, 0x73, 0xc6, 0x39, 0x4d, 0x17, 0x68, 0xba, 0x40,
		0xd3, 0x05, 0x61, 0xa5, 0x8b, 0xa6, 0x0b, 0x06, 0x59, 0x1c, 0x4d, 0x17, 0x4c, 0x1e, 0x48, 0xc9,
		0x83, 0x29, 0x7f, 0x40, 0xa5, 0x0f, 0xaa, 0xb1, 0x03, 0x6b, 0xec, 0xe0, 0x1a, 0x39, 0xc0, 0x76,
		0x18, 0xf1, 0xa4, 0x75, 0xe1, 0xaf, 0x12, 0x19, 0x19, 0x7f, 0x55, 0x9a, 0xa0, 0x21, 0xab, 0x69,
		0x92, 0xd6, 0x25, 0x32, 0x24, 0xbe, 0x2a, 0x7c, 0x55, 0x29, 0x1e, 0xb7, 0xf9, 0x25, 0x25, 0xad,
		0xcb, 0x8e, 0xb5, 0xc5, 0x65, 0x65, 0x7a, 0xef, 0x93, 0xd6, 0x05, 0x95, 0x85, 0xca, 0x42, 0x65,
		0x73, 0x4a, 0x65, 0x49, 0xeb, 0x8a, 0xf5, 0x4c, 0xa4, 0x75, 0x01, 0xc3, 0xc0, 0x30, 0x30, 0x4c,
		0x5a, 0x17, 0x69, 0x5d, 0xa4, 0x75, 0x21, 0x59, 0xa8, 0x2d, 0x29, 0x69, 0x5d, 0x28, 0x15, 0x19,
		0x92, 0x58, 0xd2, 0xba, 0x20, 0xb5, 0x90, 0x5a, 0x48, 0x6d, 0x5a, 0xa4, 0x96, 0xb4, 0xae, 0x3c,
		0xf2, 0x4e, 0x5c, 0x65, 0x85, 0xe3, 0x9d, 0xa4, 0x75, 0xc1, 0x3c, 0x33, 0x1a, 0xa1, 0x78, 0x69,
		0x5d, 0xf7, 0xdd, 0x56, 0xcf, 0xca, 0xa6, 0x0b, 0xdf, 0xba, 0xad, 0x1e, 0x4d, 0x17, 0x56, 0x11,
		0x11, 0x9a, 0x2e, 0xa4, 0x6d, 0x61, 0x10, 0x9d, 0x4b, 0x74, 0xee, 0xfa, 0x81, 0x88, 0xce, 0x45,
		0x76, 0x40, 0x76, 0x40, 0x76, 0x20, 0x3a, 0x17, 0xc9, 0x01, 0xc9, 0x01, 0xc9, 0x41, 0x61, 0x49,
		0x89, 0xce, 0x2d, 0x81, 0xf2, 0x40, 0x74, 0x2e, 0xd1, 0xb9, 0x50, 0x59, 0xa8, 0x6c, 0x69, 0xa9,
		0x2c, 0xd1, 0xb9, 0xb1, 0x9e, 0x89, 0xe8, 0x5c, 0x60, 0x18, 0x18, 0x06, 0x86, 0x89, 0xce, 0x25,
		0x3a, 0x97, 0xe8, 0x5c, 0x24, 0x0b, 0xb5, 0x25, 0x25, 0x3a, 0x17, 0xa5, 0x22, 0x43, 0x12, 0x4b,
		0x74, 0x2e, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x4d, 0x8b, 0xd4, 0x12, 0x9d, 0x9b, 0x47, 0xde, 0x89,
		0xab, 0xac, 0x70, 0xbc, 0x93, 0xe8, 0x5c, 0x98, 0x67, 0x46, 0x23, 0x94, 0x21, 0x3a, 0xd7, 0x8e,
		0xa6, 0x0b, 0x4b, 0xc1, 0xb9, 0x34, 0x5d, 0xb0, 0x61, 0x77, 0x64, 0xd6, 0x74, 0x61, 0x71, 0x3f,
		0xd0, 0x74, 0x41, 0x6e, 0x85, 0x53, 0x6f, 0xba, 0x30, 0x58, 0x4c, 0x2b, 0x9a, 0x2e, 0xec, 0x0d,
		0xa6, 0xc0, 0xef, 0xde, 0xd7, 0x9c, 0x76, 0xbf, 0x15, 0xf9, 0x0d, 0xb7, 0x17, 0x69, 0xb4, 0x5f,
		0x58, 0x35, 0x1a, 0x8d, 0x18, 0xcc, 0x19, 0xec, 0x34, 0x62, 0xa0, 0x11, 0x03, 0x8d, 0x18, 0x84,
		0xd5, 0x2f, 0x1a, 0x31, 0x18, 0x64, 0x76, 0x34, 0x62, 0x30, 0x79, 0x20, 0x25, 0x0f, 0xa6, 0xfc,
		0x01, 0x95, 0x3e, 0xa8, 0xc6, 0x0e, 0xac, 0xb1, 0x83, 0x6b, 0xe4, 0x00, 0xdb, 0x61, 0xd8, 0x93,
		0xea, 0x85, 0x0f, 0x4b, 0x64, 0x64, 0x7c, 0x58, 0x69, 0x82, 0x86, 0xac, 0xce, 0x49, 0xaa, 0x97,
		0xc8, 0x90, 0xf8, 0xaf, 0xf0, 0x5f, 0xa5, 0x78, 0xdc, 0xe6, 0x97, 0x94, 0x54, 0x2f, 0x3b, 0xd6,
		0x16, 0x37, 0x96, 0xe9, 0xbd, 0x4f, 0xaa, 0x17, 0x54, 0x16, 0x2a, 0x0b, 0x95, 0xcd, 0x29, 0x95,
		0x25, 0xd5, 0x2b, 0xd6, 0x33, 0x91, 0xea, 0x05, 0x0c, 0x03, 0xc3, 0xc0, 0x30, 0xa9, 0x5e, 0xa4,
		0x7a, 0x91, 0xea, 0x85, 0x64, 0xa1, 0xb6, 0xa4, 0xa4, 0x7a, 0xa1, 0x54, 0x64, 0x48, 0x62, 0x49,
		0xf5, 0x82, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x69, 0x91, 0x5a, 0x52, 0xbd, 0xf2, 0xc8, 0x3b, 0x71,
		0x95, 0x15, 0x8e, 0x77, 0x92, 0xea, 0x05, 0xf3, 0xcc, 0x68, 0x84, 0x42, 0xa5, 0x7a, 0xad, 0xc8,
		0x4c, 0xb0, 0xae, 0x25, 0xc3, 0xde, 0xb7, 0x6e, 0x70, 0xd2, 0xbd, 0xaf, 0x7d, 0x9a, 0x7c, 0x42,
		0x7a, 0x33, 0xac, 0xe2, 0x26, 0xf4, 0x66, 0x48, 0xdb, 0xe8, 0x20, 0x60, 0x97, 0x80, 0xdd, 0xf5,
		0x03, 0x11, 0xb0, 0x8b, 0x12, 0x81, 0x12, 0x81, 0x12, 0x41, 0xc0, 0x2e, 0x2a, 0x04, 0x2a, 0x04,
		0x2a, 0x84, 0xc2, 0x92, 0x12, 0xb0, 0x5b, 0x02, 0x31, 0x82, 0x80, 0x5d, 0x02, 0x76, 0xa1, 0xb2,
		0x50, 0xd9, 0xd2, 0x52, 0x59, 0x02, 0x76, 0x63, 0x3d, 0x13, 0x01, 0xbb, 0xc0, 0x30, 0x30, 0x0c,
		0x0c, 0x13, 0xb0, 0x4b, 0xc0, 0x2e, 0x01, 0xbb, 0x48, 0x16, 0x6a, 0x4b, 0x4a, 0xc0, 0x2e, 0x4a,
		0x45, 0x86, 0x24, 0x96, 0x80, 0x5d, 0x48, 0x2d, 0xa4, 0x16, 0x52, 0x9b, 0x16, 0xa9, 0x25, 0x60,
		0x37, 0x8f, 0xbc, 0x13, 0x57, 0x59, 0xe1, 0x78, 0x27, 0x01, 0xbb, 0x30, 0xcf, 0x8c, 0x46, 0x28,
		0x57, 0xc0, 0x6e, 0xf6, 0x5d, 0x1a, 0x9e, 0x8f, 0xd7, 0xa5, 0x5d, 0x83, 0x5d, 0x1b, 0x26, 0x93,
		0xc6, 0x0d, 0xcf, 0x6e, 0x11, 0x3a, 0x38, 0x98, 0x58, 0xf4, 0x54, 0x7b, 0x39, 0x2c, 0xad, 0xaf,
		0x65, 0x4d, 0x1d, 0xfa, 0x81, 0x5c, 0x4b, 0x87, 0xc9, 0x58, 0x34, 0x74, 0x30, 0x67, 0xe5, 0xd3,
		0xd0, 0x81, 0x86, 0x0e, 0x34, 0x74, 0x10, 0x96, 0xcc, 0x68, 0xe8, 0x60, 0x90, 0xfb, 0xd1, 0xd0,
		0xc1, 0xe4, 0x81, 0x94, 0x3c, 0x98, 0xf2, 0x07, 0x54, 0xfa, 0xa0, 0x1a, 0x3b, 0xb0, 0xc6, 0x0e,
		0xae, 0x91, 0x03, 0x6c, 0x87, 0x1a, 0x40, 0x7e, 0x18, 0x8e, 0x2f, 0x91, 0x91, 0x71, 0x7c, 0xa5,
		0x09, 0x1a, 0xb2, 0xe2, 0x28, 0xf9, 0x61, 0x22, 0x43, 0xe2, 0xf4, 0xc2, 0xe9, 0x95, 0xe2, 0x71,
		0x9b, 0x5f, 0x52, 0xf2, 0xc3, 0xec, 0x58, 0x5b, 0x7c, 0x5f, 0xa6, 0xf7, 0x3e, 0xf9, 0x61, 0x50,
		0x59, 0xa8, 0x2c, 0x54, 0x36, 0xa7, 0x54, 0x96, 0xfc, 0xb0, 0x58, 0xcf, 0x44, 0x7e, 0x18, 0x30,
		0x0c, 0x0c, 0x03, 0xc3, 0xe4, 0x87, 0x91, 0x1f, 0x46, 0x7e, 0x18, 0x92, 0x85, 0xda, 0x92, 0x92,
		0x1f, 0x86, 0x52, 0x91, 0x21, 0x89, 0x25, 0x3f, 0x0c, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xa6, 0x45,
		0x6a, 0xc9, 0x0f, 0xcb, 0x23, 0xef, 0xc4, 0x55, 0x56, 0x38, 0xde, 0x49, 0x7e, 0x18, 0xcc, 0x33,
		0xa3, 0x11, 0x0a, 0x9a, 0x1f, 0x36, 0xce, 0x4b, 0xb0, 0xb6, 0x9d, 0xc3, 0xd7, 0x80, 0x66, 0x0e,
		0x6b, 0x79, 0x09, 0xcd, 0x1c, 0xd2, 0x36, 0x38, 0x08, 0xd6, 0x25, 0x58, 0x77, 0xfd, 0x40, 0x04,
		0xeb, 0xa2, 0x42, 0xa0, 0x42, 0xa0, 0x42, 0x10, 0xac, 0x8b, 0x02, 0x81, 0x02, 0x81, 0x02, 0xa1,
		0xb0, 0xa4, 0x04, 0xeb, 0x96, 0x40, 0x88, 0x20, 0x58, 0x97, 0x60, 0x5d, 0xa8, 0x2c, 0x54, 0xb6,
		0xb4, 0x54, 0x96, 0x60, 0xdd, 0x58, 0xcf, 0x44, 0xb0, 0x2e, 0x30, 0x0c, 0x0c, 0x03, 0xc3, 0x04,
		0xeb, 0x12, 0xac, 0x4b, 0xb0, 0x2e, 0x92, 0x85, 0xda, 0x92, 0x12, 0xac, 0x8b, 0x52, 0x91, 0x21,
		0x89, 0x25, 0x58, 0x17, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xa6, 0x45, 0x6a, 0x09, 0xd6, 0xcd, 0x23,
		0xef, 0xc4, 0x55, 0x56, 0x38, 0xde, 0x49, 0xb0, 0x2e, 0xcc, 0x33, 0xa3, 0x11, 0xca, 0x14, 0xac,
		0x6b, 0x4f, 0x2b, 0x87, 0x55, 0xb1, 0xba, 0x34, 0x72, 0xb0, 0x69, 0xb3, 0x64, 0xda, 0xc6, 0x61,
		0xc5, 0xf6, 0xa0, 0x89, 0x83, 0xfc, 0x82, 0x67, 0xd2, 0xc2, 0x61, 0xbc, 0xb6, 0x56, 0x35, 0x70,
		0xa8, 0xcf, 0xb4, 0xb5, 0xd0, 0x6f, 0xe1, 0x50, 0x57, 0x6e, 0x92, 0x41, 0x13, 0x87, 0x4c, 0xac,
		0x78, 0x9a, 0x38, 0xc4, 0x78, 0x21, 0x4d, 0x1c, 0x0c, 0x48, 0x69, 0x34, 0x71, 0xc8, 0x58, 0xfa,
		0xa2, 0x89, 0x03, 0x4d, 0x1c, 0xd2, 0x39, 0xa0, 0xd2, 0x07, 0xd5, 0xd8, 0x81, 0x35, 0x76, 0x70,
		0x8d, 0x1c, 0x60, 0x3b, 0x54, 0x00, 0xf2, 0xc2, 0x70, 0x78, 0x89, 0x8c, 0x8c, 0xc3, 0x2b, 0x4d,
		0xd0, 0x90, 0x15, 0x45, 0xc9, 0x0b, 0x13, 0x19, 0x12, 0x67, 0x17, 0xce, 0xae, 0x14, 0x8f, 0xdb,
		0xfc, 0x92, 0x92, 0x17, 0x66, 0xc7, 0xda, 0xe2, 0xf3, 0x32, 0xbd, 0xf7, 0xc9, 0x0b, 0x83, 0xca,
		0x42, 0x65, 0xa1, 0xb2, 0x39, 0xa5, 0xb2, 0xe4, 0x85, 0xc5, 0x7a, 0x26, 0xf2, 0xc2, 0x80, 0x61,
		0x60, 0x18, 0x18, 0x26, 0x2f, 0x8c, 0xbc, 0x30, 0xf2, 0xc2, 0x90, 0x2c, 0xd4, 0x96, 0x94, 0xbc,
		0x30, 0x94, 0x8a, 0x0c, 0x49, 0x2c, 0x79, 0x61, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x36, 0x2d, 0x52,
		0x4b, 0x5e, 0x58, 0x1e, 0x79, 0x27, 0xae, 0xb2, 0xc2, 0xf1, 0x4e, 0xf2, 0xc2, 0x60, 0x9e, 0x19,
		0x8d, 0x50, 0xc8, 0xbc, 0xb0, 0x99, 0xcc, 0x04, 0x5b, 0xdb, 0x38, 0xd4, 0x3f, 0x4d, 0x3e, 0x21,
		0x8d, 0x1c, 0x56, 0x71, 0x13, 0x1a, 0x39, 0xa4, 0x6d, 0x74, 0x10, 0xb0, 0x4b, 0xc0, 0xee, 0xfa,
		0x81, 0x08, 0xd8, 0x45, 0x89, 0x40, 0x89, 0x40, 0x89, 0x20, 0x60, 0x17, 0x15, 0x02, 0x15, 0x02,
		0x15, 0x42, 0x61, 0x49, 0x09, 0xd8, 0x2d, 0x81, 0x18, 0x41, 0xc0, 0x2e, 0x01, 0xbb, 0x50, 0x59,
		0xa8, 0x6c, 0x69, 0xa9, 0x2c, 0x01, 0xbb, 0xb1, 0x9e, 0x89, 0x80, 0x5d, 0x60, 0x18, 0x18, 0x06,
		0x86, 0x09, 0xd8, 0x25, 0x60, 0x97, 0x80, 0x5d, 0x24, 0x0b, 0xb5, 0x25, 0x25, 0x60, 0x17, 0xa5,
		0x22, 0x43, 0x12, 0x4b, 0xc0, 0x2e, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x4d, 0x8b, 0xd4, 0x12, 0xb0,
		0x9b, 0x47, 0xde, 0x89, 0xab, 0xac, 0x70, 0xbc, 0x93, 0x80, 0x5d, 0x98, 0x67, 0x46, 0x23, 0x94,
		0x2b, 0x60, 0xd7, 0x9a, 0x56, 0x0e, 0x6b, 0xe2, 0x75, 0x69, 0xe6, 0x60, 0xd7, 0x86, 0xc9, 0xb2,
		0x9d, 0xc3, 0xea, 0x2d, 0x42, 0x43, 0x07, 0x13, 0x8b, 0x9e, 0x45, 0x4b, 0x87, 0xa7, 0xf5, 0xb5,
		0xac, 0xa9, 0xc3, 0xa4, 0xcd, 0x85, 0x44, 0x4b, 0x07, 0xb5, 0x96, 0x19, 0x34, 0x74, 0xc8, 0xc4,
		0x9a, 0xa7, 0xa1, 0x43, 0x8c, 0x17, 0xd2, 0xd0, 0xc1, 0x80, 0xa4, 0x46, 0x43, 0x87, 0x8c, 0x25,
		0x30, 0x1a, 0x3a, 0xd0, 0xd0, 0x21, 0x9d, 0x03, 0x2a, 0x7d, 0x50, 0x8d, 0x1d, 0x58, 0x63, 0x07,
		0xd7, 0xc8, 0x01, 0xb6, 0x43, 0x0d, 0x20, 0x3f, 0x0c, 0xc7, 0x97, 0xc8, 0xc8, 0x38, 0xbe, 0xd2,
		0x04, 0x0d, 0x59, 0x71, 0x94, 0xfc, 0x30, 0x91, 0x21, 0x71, 0x7a, 0xe1, 0xf4, 0x4a, 0xf1, 0xb8,
		0xcd, 0x2f, 0x29, 0xf9, 0x61, 0x76, 0xac, 0x2d, 0xbe, 0x2f, 0xd3, 0x7b, 0x9f, 0xfc, 0x30, 0xa8,
		0x2c, 0x54, 0x16, 0x2a, 0x9b, 0x53, 0x2a, 0x4b, 0x7e, 0x58, 0xac, 0x67, 0x22, 0x3f, 0x0c, 0x18,
		0x06, 0x86, 0x81, 0x61, 0xf2, 0xc3, 0xc8, 0x0f, 0x23, 0x3f, 0x0c, 0xc9, 0x42, 0x6d, 0x49, 0xc9,
		0x0f, 0x43, 0xa9, 0xc8, 0x90, 0xc4, 0x92, 0x1f, 0x06, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0xd3, 0x22,
		0xb5, 0xe4, 0x87, 0xe5, 0x91, 0x77, 0xe2, 0x2a, 0x2b, 0x1c, 0xef, 0x24, 0x3f, 0x0c, 0xe6, 0x99,
		0xd1, 0x08, 0x05, 0xcd, 0x0f, 0x1b, 0xe7, 0x25, 0x58, 0xdb, 0xce, 0xe1, 0x6b, 0x40, 0x33, 0x87,
		0xb5, 0xbc, 0x84, 0x66, 0x0e, 0x69, 0x1b, 0x1c, 0x04, 0xeb, 0x12, 0xac, 0xbb, 0x7e, 0x20, 0x82,
		0x75, 0x51, 0x21, 0x50, 0x21, 0x50, 0x21, 0x08, 0xd6, 0x45, 0x81, 0x40, 0x81, 0x40, 0x81, 0x50,
		0x58, 0x52, 0x82, 0x75, 0x4b, 0x20, 0x44, 0x10, 0xac, 0x4b, 0xb0, 0x2e, 0x54, 0x16, 0x2a, 0x5b,
		0x5a, 0x2a, 0x4b, 0xb0, 0x6e, 0xac, 0x67, 0x22, 0x58, 0x17, 0x18, 0x06, 0x86, 0x81, 0x61, 0x82,
		0x75, 0x09, 0xd6, 0x25, 0x58, 0x17, 0xc9, 0x42, 0x6d, 0x49, 0x09, 0xd6, 0x45, 0xa9, 0xc8, 0x90,
		0xc4, 0x12, 0xac, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0xd3, 0x22, 0xb5, 0x04, 0xeb, 0xe6, 0x91,
		0x77, 0xe2, 0x2a, 0x2b, 0x1c, 0xef, 0x24, 0x58, 0x17, 0xe6, 0x99, 0xd1, 0x08, 0x65, 0x0a, 0xd6,
		0xb5, 0xa7, 0x95, 0xc3, 0xaa, 0x58, 0x5d, 0x1a, 0x39, 0xd8, 0xb4, 0x59, 0x32, 0x6d, 0xe3, 0xb0,
		0x62, 0x7b, 0xd0, 0xc4, 0x41, 0x7e, 0xc1, 0x33, 0x69, 0xe1, 0x30, 0x5e, 0x5b, 0x1b, 0x1a, 0x38,
		0x84, 0x9d, 0x7e, 0xe4, 0x39, 0x3d, 0xaf, 0xe5, 0x0d, 0xef, 0x70, 0xa7, 0xd3, 0x1d, 0xfc, 0xd5,
		0x53, 0xef, 0xe2, 0xb0, 0x6e, 0x40, 0x5a, 0x39, 0x98, 0xb3, 0xf1, 0x69, 0xe5, 0x90, 0x66, 0x2b,
		0x07, 0xcd, 0x2a, 0xf2, 0x32, 0xd5, 0xe3, 0x69, 0xdf, 0x60, 0x42, 0x24, 0xa3, 0x7d, 0x83, 0x41,
		0xc6, 0xa7, 0xdd, 0xbe, 0xc1, 0x6d, 0xde, 0x7b, 0x61, 0xe4, 0xf7, 0x3c, 0xc7, 0x0f, 0x06, 0x26,
		0xe7, 0xbd, 0xe7, 0x0c, 0x6f, 0x9b, 0x9e, 0x5c, 0x8e, 0xd8, 0xfa, 0xb7, 0xd0, 0xcd, 0x9a, 0x91,
		0x8d, 0xe3, 0x13, 0x52, 0x0d, 0x68, 0x1a, 0x61, 0x07, 0x4c, 0x18, 0x83, 0x0b, 0x23, 0xb0, 0x61,
		0x87, 0xea, 0x20, 0xa6, 0x89, 0x1b, 0x88, 0xb3, 0x13, 0x8a, 0xaf, 0xcb, 0x26, 0xed, 0xd6, 0x6d,
		0xfd, 0xe5, 0x3e, 0xf4, 0x9c, 0x46, 0xa7, 0xdd, 0x75, 0x43, 0xcf, 0x69, 0x7b, 0x4d, 0x41, 0x7c,
		0x5d, 0x1e, 0x1b, 0x60, 0x05, 0x58, 0x01, 0x56, 0x80, 0xb5, 0xf8, 0xc0, 0xea, 0x05, 0xee, 0x4d,
		0xcb, 0x73, 0x5c, 0xff, 0xae, 0x2b, 0x87, 0xa8, 0xb3, 0x83, 0x02, 0xa5, 0x40, 0x29, 0x50, 0x0a,
		0x94, 0x96, 0x00, 0x4a, 0x7f, 0x46, 0x5e, 0x18, 0xb8, 0xad, 0x29, 0x93, 0x1c, 0x5a, 0xe9, 0xa1,
		0xe3, 0x0b, 0x72, 0xd5, 0x67, 0xde, 0x43, 0x0e, 0x68, 0x07, 0xc7, 0x07, 0x9c, 0x05, 0x67, 0xc1,
		0x59, 0x70, 0xd6, 0x42, 0x9c, 0xf5, 0xef, 0x82, 0x4e, 0xe8, 0x39, 0x6e, 0xcf, 0xe9, 0xba, 0xd1,
		0x0f, 0xa7, 0xe5, 0x05, 0x77, 0x43, 0xbf, 0xab, 0x10, 0xc4, 0xae, 0x1e, 0x1e, 0x1a, 0x0b, 0xbc,
		0x02, 0xaf, 0xc0, 0x6b, 0x69, 0xe0, 0x35, 0xf0, 0x7e, 0x46, 0xce, 0x8f, 0x4e, 0xd7, 0xf1, 0xef,
		0xba, 0x4e, 0xdb, 0x8b, 0x42, 0xbf, 0x21, 0x8e, 0xb1, 0xab, 0xde, 0x03, 0xa0, 0x05, 0x68, 0x01,
		0x5a, 0x80, 0x36, 0x27, 0x40, 0x5b, 0xba, 0xf8, 0xd4, 0x35, 0xb1, 0x74, 0xfa, 0x15, 0x87, 0x95,
		0x43, 0x18, 0xbf, 0x0c, 0x3e, 0xd1, 0xc5, 0xe4, 0x03, 0x9d, 0x8d, 0x3e, 0x8f, 0x56, 0x89, 0x61,
		0x85, 0xf0, 0x54, 0xa5, 0x90, 0x4d, 0x9d, 0x52, 0xc2, 0x22, 0x25, 0x84, 0xc5, 0x22, 0xb6, 0xaa,
		0x44, 0x6c, 0x19, 0xbc, 0xb6, 0x88, 0xd8, 0x9a, 0x21, 0x78, 0x44, 0x6c, 0xc1, 0x6e, 0x61, 0xb7,
		0xb0, 0x5b, 0xd8, 0xad, 0xd5, 0x32, 0x02, 0x11, 0x5b, 0x00, 0x2b, 0xc0, 0x0a, 0xb0, 0x02, 0xac,
		0xc2, 0xc0, 0x4a, 0xc4, 0x16, 0x50, 0x0a, 0x94, 0x02, 0xa5, 0x40, 0xa9, 0x3e, 0x94, 0x12, 0xb1,
		0x05, 0xce, 0x82, 0xb3, 0xe0, 0x2c, 0x38, 0x6b, 0x14, 0x67, 0x89, 0xd8, 0x02, 0x5e, 0x81, 0x57,
		0xe0, 0x15, 0x78, 0x35, 0x09, 0xaf, 0x44, 0x6c, 0x01, 0xb4, 0x00, 0x2d, 0x40, 0x0b, 0xd0, 0xca,
		0xbf, 0xb2, 0x88, 0x11, 0x5b, 0xba, 0x65, 0x27, 0x85, 0x03, 0xb6, 0x34, 0xea, 0x4c, 0x52, 0x4e,
		0x70, 0xe3, 0x6a, 0xa7, 0x59, 0x53, 0x70, 0xe5, 0xfa, 0xda, 0x50, 0x58, 0xb0, 0x17, 0x46, 0x9e,
		0xd3, 0xed, 0xb4, 0xfc, 0xc6, 0x83, 0xe3, 0x77, 0xef, 0x6b, 0xea, 0x15, 0x05, 0x97, 0x46, 0xa2,
		0x94, 0xa0, 0x39, 0x92, 0x41, 0x29, 0xc1, 0x34, 0x4b, 0x09, 0xce, 0x55, 0x9b, 0xd5, 0x8e, 0x4e,
		0x15, 0xa8, 0x5d, 0x4b, 0x59, 0x41, 0x13, 0x8c, 0x9d, 0x20, 0x55, 0x83, 0xb4, 0x4f, 0x3b, 0x48,
		0x55, 0xb3, 0x9e, 0xe7, 0xd2, 0xb6, 0xd3, 0x8e, 0xce, 0x17, 0x38, 0x88, 0x98, 0xd6, 0x98, 0xd6,
		0x79, 0x37, 0xad, 0x75, 0x0f, 0xf6, 0x74, 0xa0, 0xb6, 0xfb, 0xd3, 0x19, 0xad, 0xa2, 0x40, 0xe0,
		0xf9, 0xd2, 0x26, 0x9e, 0x1b, 0x9d, 0x0e, 0x5a, 0xf6, 0x80, 0x82, 0x29, 0x70, 0x30, 0x0e, 0x12,
		0xc6, 0xc1, 0xc2, 0x28, 0x68, 0xc8, 0x80, 0x87, 0x10, 0x88, 0xc8, 0xeb, 0x74, 0x4b, 0xfb, 0xb5,
		0xef, 0x07, 0xd1, 0x5e, 0xd5, 0x40, 0xf7, 0xac, 0x03, 0xba, 0x67, 0x09, 0x0f, 0x4e, 0xf7, 0xac,
		0x94, 0x8e, 0xdb, 0xfc, 0x92, 0x16, 0xa0, 0x7b, 0x56, 0xad, 0x7a, 0x58, 0x3b, 0xac, 0x1f, 0x54,
		0x0f, 0xf7, 0x69, 0xa2, 0x25, 0x3d, 0x5a, 0x91, 0xda, 0xb7, 0x76, 0x43, 0xef, 0xde, 0x0b, 0x22,
		0x27, 0xf2, 0xdc, 0xb0, 0xd9, 0xf9, 0x2b, 0x90, 0xa7, 0x9b, 0x4b, 0xef, 0x20, 0x74, 0x41, 0x0a,
		0xbb, 0x86, 0xa1, 0xb2, 0x50, 0x59, 0xa8, 0x6c, 0xce, 0xa8, 0xac, 0x9c, 0xeb, 0x79, 0x49, 0xc6,
		0xda, 0x2d, 0x10, 0xc8, 0x87, 0x5e, 0x2f, 0x72, 0xc3, 0xc8, 0x89, 0xfc, 0xb6, 0x17, 0xca, 0x23,
		0xfc, 0xfc, 0xf0, 0xc0, 0x30, 0x30, 0x0c, 0x0c, 0x97, 0x0a, 0x86, 0x9b, 0x5e, 0xc3, 0x6f, 0xbb,
		0xad, 0x7a, 0xcd, 0x04, 0x10, 0x57, 0x05, 0xc7, 0x5c, 0x32, 0x5a, 0xaa, 0x48, 0x16, 0x66, 0xec,
		0xdb, 0x2a, 0x92, 0x45, 0xd1, 0x24, 0x8b, 0x3d, 0x96, 0x14, 0xa5, 0x22, 0x3b, 0x12, 0xfb, 0x97,
		0x1b, 0x06, 0x7e, 0x70, 0xe7, 0x44, 0x3f, 0x42, 0xaf, 0xf7, 0xa3, 0xd3, 0x6a, 0x3a, 0xdd, 0x46,
		0x24, 0x4f, 0x66, 0x57, 0xbf, 0x0d, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x2d, 0x15, 0xa9, 0xed, 0x7a,
		0x61, 0xc3, 0x0b, 0x22, 0xf7, 0xce, 0x33, 0xc0, 0x6a, 0xf7, 0xe1, 0x9d, 0x66, 0x48, 0x0a, 0xae,
		0xb2, 0xc2, 0xf1, 0x4e, 0xd3, 0x4b, 0xba, 0xbb, 0x03, 0xf3, 0x2c, 0x2e, 0xf3, 0xcc, 0x34, 0x22,
		0x4c, 0x28, 0xc3, 0x67, 0x3a, 0x9e, 0x4e, 0xee, 0xc7, 0x62, 0x56, 0xc2, 0xf6, 0x6c, 0xf4, 0xf5,
		0xb6, 0x48, 0x0c, 0xe8, 0x96, 0x4e, 0x62, 0xc8, 0x45, 0x18, 0x79, 0xe7, 0xc3, 0x8f, 0x77, 0xd2,
		0xbd, 0xaf, 0x5d, 0x8f, 0xa8, 0xe8, 0xe9, 0xe0, 0xc3, 0x69, 0x95, 0x6b, 0xd6, 0xdf, 0x08, 0x8f,
		0x5a, 0x59, 0x50, 0x3a, 0x65, 0x9c, 0x97, 0x38, 0x89, 0x6e, 0x56, 0xd6, 0x96, 0x89, 0x40, 0xdd,
		0x2a, 0x81, 0xba, 0x16, 0x18, 0x17, 0x04, 0xea, 0xc6, 0x7f, 0x22, 0x02, 0x75, 0x51, 0x20, 0x50,
		0x20, 0x50, 0x20, 0x2c, 0x57, 0x20, 0x08, 0xd4, 0x45, 0x7d, 0x40, 0x7d, 0x28, 0xb8, 0xfa, 0x40,
		0xa0, 0x6e, 0x09, 0x44, 0x08, 0x02, 0x75, 0x09, 0xd4, 0x85, 0xca, 0x42, 0x65, 0x4b, 0x4b, 0x65,
		0x09, 0xd4, 0x8d, 0xf5, 0x4c, 0x04, 0xea, 0x02, 0xc3, 0xc0, 0x30, 0x30, 0x4c, 0xa0, 0x2e, 0x81,
		0xba, 0x04, 0xea, 0x22, 0x59, 0xa8, 0x2d, 0x29, 0x81, 0xba, 0x28, 0x15, 0x19, 0x92, 0x58, 0x02,
		0x75, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x6d, 0x5a, 0xa4, 0x96, 0x40, 0xdd, 0x3c, 0xf2, 0x4e, 0x5c,
		0x65, 0x85, 0xe3, 0x9d, 0x04, 0xea, 0xc2, 0x3c, 0x33, 0x1a, 0xa1, 0x3c, 0x81, 0xba, 0x12, 0x21,
		0xa0, 0x5b, 0x86, 0xe2, 0x74, 0x35, 0xaa, 0xf4, 0xeb, 0x6f, 0x83, 0xf2, 0xf5, 0x6e, 0x78, 0x76,
		0xa3, 0x64, 0xd1, 0xbb, 0x61, 0xfd, 0xd6, 0xa0, 0x75, 0x83, 0xf4, 0x62, 0xa7, 0xd9, 0xb3, 0x61,
		0x7e, 0x5d, 0x2d, 0x6c, 0xd6, 0x50, 0x17, 0x6b, 0xd6, 0x50, 0xa7, 0x59, 0x83, 0x41, 0x4b, 0x9e,
		0x66, 0x0d, 0x34, 0x6b, 0xa0, 0x59, 0x83, 0xb0, 0x2c, 0x46, 0xb3, 0x06, 0x83, 0x3c, 0x8f, 0x66,
		0x0d, 0x26, 0x0f, 0xa4, 0xe4, 0xc1, 0x94, 0x3f, 0xa0, 0xd2, 0x07, 0xd5, 0xd8, 0x81, 0x35, 0x76,
		0x70, 0x8d, 0x1c, 0x60, 0x3b, 0x2c, 0x7e, 0x72, 0xc0, 0x70, 0x6e, 0x89, 0x8c, 0x8c, 0x73, 0x2b,
		0x4d, 0xd0, 0x90, 0x15, 0x40, 0xc9, 0x01, 0x13, 0x19, 0x12, 0xc7, 0x16, 0x8e, 0xad, 0x14, 0x8f,
		0xdb, 0xfc, 0x92, 0x92, 0x03, 0x66, 0xc7, 0xda, 0xe2, 0xdf, 0x32, 0xbd, 0xf7, 0xc9, 0x01, 0x83,
		0xca, 0x42, 0x65, 0xa1, 0xb2, 0x39, 0xa5, 0xb2, 0xe4, 0x80, 0xc5, 0x7a, 0x26, 0x72, 0xc0, 0x80,
		0x61, 0x60, 0x18, 0x18, 0x26, 0x07, 0x8c, 0x1c, 0x30, 0x72, 0xc0, 0x90, 0x2c, 0xd4, 0x96, 0x94,
		0x1c, 0x30, 0x94, 0x8a, 0x0c, 0x49, 0x2c, 0x39, 0x60, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x36, 0x2d,
		0x52, 0x4b, 0x0e, 0x58, 0x1e, 0x79, 0x27, 0xae, 0xb2, 0xc2, 0xf1, 0x4e, 0x72, 0xc0, 0x60, 0x9e,
		0x19, 0x8d, 0x50, 0xe0, 0x1c, 0xb0, 0xba, 0xd5, 0xcd, 0x1a, 0xea, 0x34, 0x6b, 0x58, 0xc5, 0x49,
		0x68, 0xd6, 0x90, 0xb6, 0xb1, 0x41, 0xa0, 0x2e, 0x81, 0xba, 0xeb, 0x07, 0x22, 0x50, 0x17, 0x05,
		0x02, 0x05, 0x02, 0x05, 0x82, 0x40, 0x5d, 0xd4, 0x07, 0xd4, 0x07, 0xd4, 0x07, 0x85, 0x25, 0x25,
		0x50, 0xb7, 0x04, 0x22, 0x04, 0x81, 0xba, 0x04, 0xea, 0x42, 0x65, 0xa1, 0xb2, 0xa5, 0xa5, 0xb2,
		0x04, 0xea, 0xc6, 0x7a, 0x26, 0x02, 0x75, 0x81, 0x61, 0x60, 0x18, 0x18, 0x26, 0x50, 0x97, 0x40,
		0x5d, 0x02, 0x75, 0x91, 0x2c, 0xd4, 0x96, 0x94, 0x40, 0x5d, 0x94, 0x8a, 0x0c, 0x49, 0x2c, 0x81,
		0xba, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x36, 0x2d, 0x52, 0x4b, 0xa0, 0x6e, 0x1e, 0x79, 0x27, 0xae,
		0xb2, 0xc2, 0xf1, 0x4e, 0x02, 0x75, 0x61, 0x9e, 0x19, 0x8d, 0x50, 0x9e, 0x40, 0x5d, 0xbb, 0x9a,
		0x35, 0xd4, 0x69, 0xd6, 0x60, 0x4d, 0xb3, 0x86, 0xba, 0x5d, 0xcd, 0x1a, 0xea, 0x34, 0x6b, 0x30,
		0xb9, 0xd8, 0x99, 0x35, 0x6b, 0xa8, 0x5b, 0xd1, 0xac, 0x41, 0x29, 0xae, 0x5e, 0x2b, 0x8e, 0x5e,
		0xbb, 0x2d, 0x43, 0x95, 0xb6, 0x0c, 0x59, 0xda, 0xe0, 0x45, 0x6e, 0xcb, 0x30, 0x41, 0x09, 0x67,
		0x7c, 0xb6, 0x35, 0xfb, 0x32, 0xcc, 0x0f, 0xa7, 0xd7, 0x98, 0x61, 0x87, 0xc6, 0x0c, 0x34, 0x66,
		0xc8, 0x07, 0xa7, 0xd3, 0x96, 0xa8, 0xa6, 0xfb, 0xc5, 0x6f, 0x7a, 0x41, 0xe4, 0x47, 0x0f, 0xa1,
		0x77, 0xab, 0xb3, 0x69, 0x26, 0x37, 0x8e, 0x86, 0x08, 0x55, 0x39, 0x19, 0x7f, 0x94, 0xf7, 0x6e,
		0x4f, 0x30, 0x11, 0xed, 0xe8, 0xe3, 0xc9, 0xf5, 0xc5, 0xe0, 0x3f, 0x97, 0x7f, 0x9c, 0x1f, 0xeb,
		0x6e, 0xc1, 0xa1, 0x7d, 0xdf, 0x13, 0x11, 0xc6, 0x84, 0x7d, 0x0c, 0x17, 0x5f, 0x2e, 0x8f, 0xaf,
		0xcf, 0xcf, 0x4e, 0x4f, 0x3e, 0xfc, 0x71, 0x7d, 0x72, 0xfe, 0xad, 0x5e, 0xb1, 0xc1, 0xc1, 0x22,
		0xfc, 0x8c, 0xa7, 0x7b, 0xdf, 0xce, 0x3f, 0x0f, 0x9e, 0xae, 0x76, 0xfd, 0xf5, 0xf3, 0xc9, 0x87,
		0xa3, 0x8b, 0xcb, 0x42, 0x3e, 0xe5, 0xc9, 0xe7, 0x7f, 0x5e, 0x5c, 0x1e, 0x5d, 0x1e, 0x5f, 0x5f,
		0x9c, 0x7f, 0x2c, 0xf8, 0x32, 0x7e, 0xfa, 0x7a, 0x7a, 0x59, 0xd8, 0x85, 0xfc, 0x76, 0xfe, 0xf9,
		0x5b, 0xed, 0xfa, 0xe3, 0xe9, 0xd9, 0xbf, 0x2e, 0xce, 0x8f, 0x3f, 0x14, 0xf1, 0x09, 0x17, 0x40,
		0xa7, 0x56, 0xc8, 0xdd, 0x5a, 0x1d, 0xec, 0xd6, 0x6f, 0xe7, 0xa7, 0x17, 0xc5, 0x7d, 0xba, 0xe3,
		0x6f, 0xe7, 0x9f, 0x0b, 0x0d, 0xa5, 0x45, 0x7c, 0xb8, 0x21, 0x80, 0x9e, 0x1e, 0xbd, 0x3f, 0x3e,
		0x3d, 0xfe, 0xad, 0x1c, 0xf7, 0x61, 0x51, 0x77, 0xe9, 0xe4, 0x3e, 0xac, 0x17, 0xfb, 0x3e, 0x1c,
		0x6e, 0xd8, 0x22, 0x5f, 0x87, 0xc3, 0x25, 0x2c, 0xc3, 0x89, 0x7c, 0xda, 0xb0, 0x05, 0x7e, 0xca,
		0xa2, 0xdb, 0x19, 0xc2, 0xeb, 0xa7, 0x35, 0xc2, 0x55, 0xda, 0xba, 0xcb, 0x8b, 0x14, 0xd6, 0xaf,
		0xe2, 0x05, 0xee, 0x4d, 0xcb, 0x6b, 0xea, 0xab, 0x9c, 0x93, 0x81, 0x54, 0xdb, 0x78, 0xca, 0xa4,
		0x35, 0xa2, 0x93, 0xce, 0x8d, 0x84, 0x4e, 0x9a, 0xe2, 0x79, 0xcd, 0x5c, 0x27, 0xd5, 0x4f, 0x0b,
		0xd4, 0x4c, 0x03, 0x4c, 0x07, 0xb2, 0xa2, 0x4e, 0xe4, 0xb6, 0x9c, 0xae, 0x1b, 0xfd, 0xe8, 0xe9,
		0xc3, 0xd6, 0xec, 0x60, 0x40, 0x0e, 0x90, 0x03, 0xe4, 0x24, 0xda, 0x2f, 0xda, 0x45, 0x75, 0x04,
		0x8a, 0xe8, 0x08, 0x45, 0x02, 0x0b, 0xc4, 0xa9, 0x49, 0x46, 0xfa, 0x4a, 0x27, 0x4d, 0x08, 0x47,
		0xf2, 0x9a, 0x08, 0xf2, 0x94, 0x48, 0x97, 0x91, 0x8c, 0xcc, 0x35, 0xb5, 0x04, 0xd2, 0x45, 0x6a,
		0x8c, 0xac, 0x45, 0x46, 0x71, 0x87, 0x57, 0xf6, 0x13, 0x0f, 0xdd, 0x0a, 0x85, 0x8b, 0xdc, 0x43,
		0xaf, 0x26, 0x21, 0xf4, 0x03, 0xfa, 0x01, 0xfd, 0x80, 0x7e, 0x40, 0x3f, 0xa0, 0x1f, 0xd0, 0x8f,
		0xdc, 0xd0, 0x8f, 0xe2, 0x46, 0xd6, 0x2b, 0x66, 0xd4, 0xa8, 0x87, 0xd3, 0x27, 0x4f, 0x93, 0x31,
		0x13, 0x45, 0xdf, 0xef, 0x79, 0x4e, 0xbb, 0xdf, 0x8a, 0xfc, 0x6e, 0xcb, 0x53, 0x94, 0xa7, 0x9e,
		0x2e, 0xb6, 0xe5, 0xb1, 0x52, 0x8e, 0xaf, 0xdf, 0x21, 0xbe, 0x3e, 0x4b, 0x9a, 0x57, 0xe4, 0xf8,
		0xfa, 0xc6, 0x64, 0x8f, 0x69, 0xda, 0x4f, 0x5a, 0x5d, 0x36, 0x34, 0x1b, 0x37, 0x60, 0x37, 0x61,
		0x37, 0xa5, 0x6d, 0x37, 0xe9, 0x36, 0x5a, 0xd0, 0x76, 0xf6, 0x2e, 0xed, 0x3b, 0x3d, 0xa7, 0xef,
		0xd3, 0x83, 0xc9, 0xd6, 0xb4, 0x15, 0x22, 0xce, 0x62, 0x75, 0x66, 0xe8, 0xc9, 0x42, 0x4f, 0x96,
		0x74, 0x6d, 0x51, 0xb9, 0xfa, 0x30, 0x06, 0x6a, 0xce, 0x0a, 0xd5, 0x9a, 0x25, 0xb7, 0x3d, 0xbe,
		0x51, 0xb6, 0x6c, 0x4e, 0xe8, 0xb7, 0x28, 0x53, 0x36, 0xd8, 0xbe, 0xf6, 0xbc, 0x4f, 0xe3, 0xcf,
		0x72, 0x3e, 0xf8, 0x28, 0x5a, 0x0d, 0xc9, 0x52, 0x8a, 0x92, 0x1a, 0x40, 0x82, 0x7e, 0x88, 0x94,
		0x3a, 0x60, 0xc3, 0x56, 0x61, 0xab, 0x65, 0x63, 0xab, 0x9a, 0x66, 0xa2, 0xac, 0xb9, 0x28, 0x74,
		0x10, 0xe1, 0x96, 0x70, 0x4b, 0xfa, 0xfd, 0x8d, 0x07, 0x72, 0x5b, 0xad, 0xce, 0x5f, 0x4f, 0xbc,
		0xc4, 0x35, 0xd0, 0xf4, 0x6f, 0xf9, 0x2d, 0x68, 0xc3, 0x62, 0x0b, 0xdc, 0x98, 0x83, 0x1d, 0x53,
		0xf0, 0x63, 0x1c, 0x86, 0x8c, 0xc3, 0x91, 0x51, 0x58, 0x92, 0x81, 0x27, 0x21, 0x98, 0x92, 0x37,
		0x85, 0x0d, 0x9a, 0xc4, 0xc2, 0xa6, 0xb1, 0xdc, 0x42, 0x48, 0xf8, 0xc4, 0xdb, 0xee, 0x4f, 0xbf,
		0xdd, 0x6f, 0x6b, 0x46, 0x6c, 0xaf, 0x5d, 0x85, 0xf9, 0xe1, 0xe5, 0xe1, 0x7d, 0x17, 0x68, 0x07,
		0xda, 0x81, 0xf6, 0x72, 0x41, 0x3b, 0xcd, 0x62, 0x25, 0x77, 0x24, 0x15, 0xb0, 0xd7, 0x8f, 0x4f,
		0x05, 0xec, 0xcc, 0x96, 0x94, 0x66, 0xb1, 0xe6, 0x46, 0xa3, 0x10, 0xb6, 0x6d, 0x85, 0xb0, 0x57,
		0xf8, 0x80, 0xbc, 0xc1, 0x2b, 0x44, 0x64, 0xd1, 0x2d, 0x51, 0x87, 0xd0, 0xf1, 0xcd, 0x5d, 0x57,
		0xcb, 0x2b, 0xa4, 0xbf, 0xfa, 0x8f, 0x5a, 0x8e, 0x31, 0x95, 0x72, 0xba, 0x6b, 0xb9, 0x88, 0x44,
		0x8d, 0x72, 0x71, 0xd9, 0xba, 0x8a, 0x6c, 0x6d, 0x81, 0x51, 0x81, 0x6c, 0x9d, 0xc0, 0xa4, 0x47,
		0xb6, 0x46, 0xb6, 0x46, 0xdb, 0x40, 0xdb, 0x28, 0xbb, 0xb6, 0x81, 0x6c, 0x1d, 0xeb, 0x99, 0x90,
		0xad, 0x81, 0x76, 0xa0, 0x1d, 0x68, 0xcf, 0x13, 0xb4, 0x23, 0x5b, 0x4b, 0xee, 0x48, 0x64, 0xeb,
		0xf5, 0xe3, 0x23, 0x5b, 0x67, 0xb6, 0xa4, 0xc8, 0xd6, 0xe6, 0x46, 0x43, 0xb6, 0xce, 0x8b, 0x6c,
		0x9d, 0x79, 0xe7, 0xc6, 0xd5, 0xaa, 0x35, 0x4d, 0x1b, 0x6d, 0xd8, 0x1d, 0x56, 0xa4, 0xb5, 0x1c,
		0x2b, 0x53, 0xd8, 0x74, 0x92, 0x5a, 0x7c, 0x91, 0xa4, 0x16, 0x9f, 0xa4, 0x16, 0x92, 0x5a, 0x32,
		0x34, 0xf5, 0x48, 0x6a, 0x21, 0xa9, 0x25, 0x5d, 0x2d, 0x07, 0xef, 0x20, 0xde, 0xc1, 0xf5, 0x03,
		0x21, 0x1b, 0x9b, 0x30, 0x86, 0x91, 0x8d, 0x91, 0x8d, 0xd3, 0x83, 0x22, 0x59, 0x5d, 0x01, 0xd9,
		0x58, 0x64, 0x48, 0x64, 0x63, 0x64, 0xe3, 0x14, 0x8f, 0xdb, 0xfc, 0x92, 0x22, 0x1b, 0xdb, 0xb1,
		0xb6, 0xc8, 0xc6, 0x16, 0x73, 0x68, 0xcb, 0x65, 0x63, 0xdf, 0xd2, 0x68, 0xe7, 0x13, 0xa2, 0x9d,
		0x89, 0x76, 0x46, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf,
		0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x40, 0xcf, 0x78, 0x4e,
		0xcf, 0xb0, 0x2f, 0x0c, 0xee, 0x84, 0x30, 0x38, 0x5b, 0x76, 0x87, 0x15, 0x61, 0x70, 0x27, 0x96,
		0x87, 0xc1, 0xe9, 0xe9, 0x57, 0x22, 0xba, 0x95, 0x58, 0x20, 0x5c, 0x95, 0x40, 0x38, 0x83, 0xc6,
		0x20, 0x81, 0x70, 0x72, 0xfa, 0x12, 0xbd, 0x48, 0xb2, 0xd1, 0x8b, 0x90, 0xa2, 0x91, 0xa2, 0x53,
		0xa6, 0xd1, 0xf4, 0x22, 0x81, 0xab, 0x3e, 0xcf, 0x55, 0x75, 0x8d, 0x18, 0x39, 0xb2, 0xaa, 0x61,
		0xb7, 0xd0, 0x04, 0xf4, 0xb9, 0x35, 0x4e, 0xb3, 0x23, 0xe8, 0xe2, 0xaa, 0x1a, 0x6b, 0x0e, 0xfa,
		0x42, 0x70, 0xdd, 0x06, 0x57, 0xd5, 0xb0, 0xf4, 0xcf, 0x78, 0x0e, 0x9d, 0xe1, 0x73, 0xc7, 0x7c,
		0xed, 0xa9, 0xdf, 0x8b, 0x8e, 0xa2, 0x28, 0x19, 0x25, 0xab, 0x7c, 0xf2, 0x83, 0xe3, 0x96, 0x37,
		0xb8, 0x6c, 0x7a, 0xc9, 0x88, 0x45, 0xe5, 0x93, 0xfb, 0x73, 0xe6, 0x95, 0xbb, 0x6f, 0x6b, 0xb5,
		0xfa, 0x41, 0xad, 0xb6, 0x73, 0xb0, 0x77, 0xb0, 0x73, 0xb8, 0xbf, 0xbf, 0x5b, 0xdf, 0x4d, 0xa0,
		0xc9, 0x55, 0xce, 0xc2, 0xa6, 0x17, 0x7a, 0xcd, 0xf7, 0x83, 0xc7, 0x0f, 0xfa, 0xad, 0x96, 0xe8,
		0xac, 0x2a, 0x9e, 0x02, 0x9d, 0xdd, 0x9f, 0x60, 0xab, 0xab, 0x6e, 0xf1, 0x78, 0x3b, 0x7a, 0xf3,
		0xfe, 0x7c, 0xfe, 0x37, 0x36, 0xcc, 0x71, 0xd2, 0xb9, 0x55, 0x98, 0xd3, 0x18, 0x53, 0x99, 0x74,
		0x0a, 0x9f, 0x9f, 0xba, 0xf5, 0x13, 0xf2, 0xcc, 0x64, 0x0c, 0x93, 0x70, 0xbc, 0xa6, 0x17, 0xc6,
		0x9b, 0x8b, 0xb9, 0xdc, 0x9d, 0xa7, 0x97, 0x6d, 0x98, 0xec, 0x78, 0x12, 0x41, 0x6c, 0x3b, 0x21,
		0x89, 0x1d, 0x90, 0x9c, 0xe7, 0x27, 0xe5, 0xf1, 0xca, 0x3c, 0x5d, 0x99, 0x87, 0x2b, 0xf1, 0x6c,
		0xbd, 0xe3, 0x12, 0xd7, 0x64, 0x4e, 0x9a, 0x23, 0xa6, 0x96, 0x0b, 0x96, 0x50, 0x73, 0x4a, 0x6c,
		0x80, 0xaa, 0x18, 0x9a, 0xea, 0x06, 0xa5, 0xaa, 0xe1, 0xa8, 0x6d, 0x20, 0x6a, 0x1b, 0x82, 0x5a,
		0x06, 0x9f, 0x2c, 0x03, 0x49, 0xaa, 0xe9, 0x54, 0xfc, 0xa6, 0x17, 0x44, 0xfe, 0xad, 0xef, 0x85,
		0xea, 0x9d, 0xce, 0x67, 0xc6, 0x50, 0xeb, 0x70, 0xbe, 0x43, 0x87, 0xf3, 0x34, 0x95, 0x90, 0x32,
		0x75, 0x38, 0x57, 0x56, 0x2e, 0x9e, 0x0a, 0x79, 0xf6, 0x9c, 0xa0, 0xdf, 0xbe, 0x49, 0xbc, 0xb9,
		0xb7, 0xf4, 0x82, 0x4e, 0x34, 0x83, 0x4b, 0x34, 0x94, 0x01, 0x89, 0x60, 0x11, 0x29, 0xcd, 0x54,
		0x28, 0xf8, 0x43, 0x32, 0x10, 0x40, 0x27, 0xd0, 0x5a, 0x22, 0x68, 0x43, 0x7a, 0x6a, 0xa5, 0x82,
		0x30, 0x44, 0xe7, 0x38, 0x25, 0xf9, 0xe6, 0xca, 0x94, 0xac, 0x90, 0x80, 0xf6, 0xb4, 0xbd, 0x01,
		0xb8, 0xa8, 0xd4, 0x20, 0x7e, 0x8a, 0xc0, 0x9d, 0x0e, 0xc1, 0xfd, 0xcb, 0xfd, 0xcb, 0xfd, 0xcb,
		0xfd, 0xcb, 0xfd, 0xcb, 0xfd, 0x5b, 0xbc, 0xfb, 0x37, 0x21, 0xf6, 0x28, 0x49, 0xea, 0xb3, 0xc7,
		0x50, 0x4d, 0x5a, 0x9f, 0xdd, 0x6d, 0x62, 0x12, 0xfb, 0x74, 0x50, 0x25, 0xa9, 0x5d, 0x81, 0xc1,
		0xe4, 0x4b, 0xc2, 0x9f, 0xd3, 0x61, 0x93, 0x67, 0x88, 0xc6, 0x55, 0xa0, 0x3f, 0xcc, 0xbe, 0x4d,
		0xa2, 0x84, 0xcf, 0x18, 0x42, 0x7e, 0x2c, 0xa1, 0x3c, 0x49, 0xa0, 0x9b, 0x52, 0x60, 0x9b, 0xb2,
		0xa8, 0x58, 0x45, 0x54, 0x44, 0x54, 0x44, 0x54, 0xc4, 0xa8, 0xc1, 0xa8, 0xc1, 0xa8, 0xc1, 0xa8,
		0xc1, 0xa8, 0xc1, 0xa8, 0x41, 0x54, 0xe4, 0xfe, 0xe5, 0xfe, 0xe5, 0xfe, 0xe5, 0xfe, 0xe5, 0xfe,
		0xe5, 0xfe, 0x45, 0x54, 0x44, 0x54, 0xcc, 0xb1, 0xa8, 0x98, 0x34, 0xc3, 0x41, 0x4d, 0x53, 0x4c,
		0x90, 0xbd, 0x90, 0xdb, 0xd8, 0xe0, 0x24, 0x41, 0xb3, 0xca, 0x33, 0x69, 0x2a, 0x48, 0x38, 0x46,
		0x54, 0x67, 0xb2, 0x68, 0x4e, 0xc2, 0x82, 0x65, 0xf9, 0xac, 0xcd, 0x61, 0xc1, 0x09, 0xec, 0xb1,
		0x19, 0xaa, 0x9a, 0x50, 0xb9, 0xdf, 0x21, 0x1c, 0x18, 0xe5, 0x7e, 0x42, 0x16, 0x82, 0xa6, 0x1b,
		0x75, 0xc2, 0x87, 0x04, 0x0e, 0x9d, 0xc4, 0xc6, 0x95, 0x96, 0x51, 0xa5, 0x60, 0x4c, 0x29, 0x1a,
		0x51, 0x6a, 0x6c, 0x4d, 0xc3, 0xb0, 0xd7, 0x62, 0xf4, 0xba, 0x46, 0x92, 0x04, 0x71, 0x7f, 0x54,
		0xa3, 0xa7, 0x99, 0x4f, 0x99, 0xae, 0xf1, 0x23, 0x32, 0x77, 0x86, 0x28, 0xf4, 0x55, 0x8a, 0xde,
		0xe6, 0xb0, 0xd3, 0x8f, 0xbc, 0xd0, 0xf1, 0x9b, 0xc9, 0x2f, 0xad, 0xa7, 0x97, 0x72, 0x77, 0x71,
		0x77, 0x29, 0xdd, 0x5d, 0xea, 0xf7, 0x50, 0xb3, 0x13, 0x45, 0x5e, 0xd3, 0xf9, 0x5f, 0xdf, 0x6d,
		0x2a, 0xdc, 0x44, 0xbb, 0x6f, 0x13, 0xbc, 0xe6, 0xdc, 0x8d, 0x22, 0x2f, 0x0c, 0x12, 0x5f, 0x46,
		0x95, 0x97, 0x2f, 0xbf, 0xef, 0x38, 0x87, 0x57, 0xbf, 0xbe, 0xef, 0x3a, 0x87, 0x57, 0xa3, 0x2f,
		0x77, 0x87, 0x7f, 0x8d, 0xbe, 0xae, 0x7e, 0xdf, 0x71, 0x6a, 0x93, 0xaf, 0xf7, 0xbf, 0xef, 0x38,
		0xfb, 0x57, 0xaf, 0xfe, 0xfc, 0xf3, 0xcd, 0xab, 0xbf, 0xf7, 0x1e, 0x93, 0xbf, 0x30, 0xfe, 0x0a,
		0x5e, 0x25, 0x79, 0xf4, 0xb3, 0x8b, 0x93, 0x7f, 0x2b, 0x3f, 0xff, 0x7f, 0xd2, 0x9c, 0x80, 0x7f,
		0x54, 0xd2, 0xc7, 0x57, 0x7b, 0x4d, 0xef, 0x58, 0x91, 0x51, 0x49, 0x6c, 0xee, 0x4d, 0x31, 0x50,
		0x6a, 0xc6, 0x76, 0x73, 0x54, 0xc5, 0xc7, 0x19, 0x5e, 0x25, 0x4e, 0xd3, 0xef, 0x45, 0x6e, 0x10,
		0x03, 0x53, 0x9f, 0x50, 0x60, 0xf5, 0xeb, 0x31, 0xc6, 0x31, 0xc6, 0x13, 0xa9, 0x39, 0x6a, 0xaa,
		0x4e, 0xc2, 0x0d, 0x05, 0xb1, 0x29, 0x0f, 0xb1, 0x49, 0x1c, 0x4e, 0xe7, 0xfd, 0x1c, 0xdc, 0xb1,
		0x6e, 0x2b, 0x29, 0x14, 0xae, 0x5d, 0xf7, 0x75, 0x03, 0xe2, 0xe8, 0x97, 0xdf, 0xfa, 0x62, 0x47,
		0x40, 0xec, 0x28, 0x88, 0x1c, 0x09, 0x45, 0x3b, 0x37, 0x75, 0x47, 0x7f, 0xdf, 0x0f, 0xa2, 0xb7,
		0x1a, 0x4e, 0xfe, 0x7d, 0x9c, 0xfc, 0x5b, 0x5a, 0x62, 0xcc, 0x2e, 0x4e, 0x7e, 0x53, 0x53, 0x5b,
		0xdd, 0xc7, 0xbb, 0x2f, 0x36, 0x7e, 0x92, 0xe8, 0x3a, 0x3f, 0x10, 0xbe, 0x90, 0xd7, 0x0d, 0xc8,
		0x85, 0xcc, 0x85, 0xcc, 0x85, 0xcc, 0x85, 0xcc, 0x85, 0xcc, 0x85, 0x5c, 0xba, 0x0b, 0x39, 0x5f,
		0xc1, 0x62, 0xab, 0xe5, 0x46, 0x73, 0xa9, 0xa8, 0xe3, 0x22, 0xe7, 0x5f, 0x06, 0x6f, 0xf7, 0xdb,
		0xf8, 0xdd, 0xc8, 0x48, 0x25, 0x23, 0x15, 0x09, 0x0d, 0x09, 0x0d, 0xc6, 0x0e, 0x63, 0x87, 0xb1,
		0xc3, 0xd8, 0x61, 0xec, 0x30, 0x76, 0x24, 0x34, 0x2e, 0x64, 0x2e, 0x64, 0x2e, 0x64, 0x2e, 0x64,
		0x2e, 0x64, 0x2e, 0x64, 0x24, 0xb4, 0xfc, 0x49, 0x68, 0xa6, 0x12, 0x2f, 0x57, 0x2a, 0x68, 0x65,
		0xc8, 0xbf, 0x54, 0x8a, 0x8c, 0xd4, 0x9d, 0x59, 0x23, 0x21, 0xa2, 0x0f, 0x81, 0xdb, 0xf6, 0x1b,
		0x4e, 0xe0, 0xf9, 0x77, 0x3f, 0x6e, 0x3a, 0xa1, 0x33, 0x22, 0x21, 0x5e, 0x2f, 0x41, 0x94, 0xe8,
		0xda, 0x21, 0x08, 0x14, 0x25, 0x50, 0xf4, 0xd9, 0x6d, 0x96, 0x5c, 0xf5, 0x5e, 0x37, 0x10, 0xa1,
		0xa4, 0x29, 0xda, 0x1c, 0xa5, 0xd6, 0xc1, 0x13, 0xc6, 0x3c, 0x2f, 0x2d, 0x73, 0x62, 0x77, 0xd6,
		0x96, 0x7a, 0x6f, 0x6c, 0x8c, 0x6a, 0x8c, 0xea, 0xb8, 0x9f, 0x50, 0xb5, 0x97, 0x75, 0xa5, 0xeb,
		0x79, 0xa1, 0x73, 0x17, 0x76, 0xfa, 0x5d, 0xfd, 0xfe, 0xf1, 0x33, 0x63, 0xbd, 0xce, 0x24, 0x01,
		0x56, 0xb7, 0xc3, 0x34, 0x4d, 0xe4, 0xd3, 0x3d, 0x58, 0xa2, 0x07, 0x4c, 0xd3, 0x68, 0x55, 0xdc,
		0x31, 0xda, 0x9d, 0xa1, 0xa7, 0xfb, 0xa5, 0xe5, 0xb9, 0xb7, 0xa1, 0x77, 0xab, 0xb3, 0x61, 0x26,
		0xf7, 0xcc, 0x81, 0xc6, 0x18, 0xe7, 0x63, 0xfb, 0xe9, 0xcd, 0x9b, 0xed, 0xd9, 0xff, 0x3d, 0x9d,
		0xed, 0xde, 0xcc, 0xd7, 0xe3, 0xf0, 0x8e, 0x99, 0xef, 0x8c, 0x7a, 0xbe, 0xa6, 0xd5, 0x7d, 0x58,
		0xe1, 0x76, 0xea, 0xea, 0x1d, 0xf1, 0x27, 0xb0, 0xd3, 0xba, 0x9a, 0x00, 0x3a, 0x80, 0xae, 0xac,
		0x40, 0xe7, 0x77, 0x1d, 0xed, 0xd5, 0x99, 0x42, 0xdd, 0xa1, 0xc6, 0x18, 0xe3, 0x47, 0xfa, 0xae,
		0xb5, 0xa4, 0x7f, 0xeb, 0x37, 0xf0, 0x7f, 0x9a, 0x98, 0xfb, 0x9a, 0x23, 0xb2, 0x71, 0xb7, 0x14,
		0xf3, 0xf9, 0x9f, 0xbb, 0x15, 0x94, 0xf2, 0xdc, 0xd7, 0x0e, 0x98, 0x66, 0xfa, 0xfb, 0xf6, 0xf8,
		0xcd, 0x5e, 0xfd, 0x7a, 0xf9, 0x7d, 0xd7, 0xa9, 0x5e, 0x4d, 0xfe, 0xb1, 0xf7, 0x7d, 0xc7, 0xa9,
		0x5e, 0xbd, 0x7a, 0x55, 0xd1, 0x7e, 0xa4, 0x2b, 0x89, 0x29, 0xd6, 0xa9, 0x27, 0xb0, 0x76, 0xd4,
		0xff, 0xd8, 0x34, 0xd1, 0xff, 0x10, 0x98, 0x69, 0xad, 0x11, 0x1e, 0x5f, 0x5b, 0x74, 0xd6, 0xeb,
		0xe5, 0x3a, 0xeb, 0xae, 0x73, 0x7b, 0xe4, 0x7c, 0xbc, 0xfa, 0x7b, 0xf7, 0x75, 0xed, 0xf1, 0xdd,
		0xab, 0xbf, 0x0f, 0x1e, 0x17, 0xbf, 0xf9, 0x6b, 0xd5, 0xaf, 0xed, 0xbe, 0x3e, 0x78, 0x7c, 0xb7,
		0xe6, 0x27, 0xf5, 0xc7, 0x77, 0x31, 0xc7, 0xd8, 0x7f, 0x7c, 0xb9, 0xf4, 0xab, 0x83, 0xef, 0x57,
		0xd7, 0xbd, 0xa0, 0xb6, 0xe6, 0x05, 0x7b, 0xeb, 0x5e, 0xb0, 0xb7, 0xe6, 0x05, 0x6b, 0x3f, 0x52,
		0x75, 0xcd, 0x0b, 0xf6, 0x1f, 0x7f, 0x2d, 0xfd, 0xfe, 0xcb, 0xd5, 0xbf, 0x5a, 0x7f, 0x7c, 0xf5,
		0x6b, 0xdd, 0xcf, 0x0e, 0x1e, 0x7f, 0xbd, 0x7b, 0xf5, 0x6a, 0xfb, 0xe5, 0xee, 0xe0, 0x9c, 0xbe,
		0x1d, 0x1d, 0xdd, 0xdd, 0xab, 0xa5, 0x13, 0x3d, 0x3a, 0xa1, 0x25, 0x00, 0x40, 0x76, 0x9f, 0xb5,
		0xbb, 0x2f, 0xfb, 0x5b, 0xe1, 0x45, 0xba, 0xef, 0xfb, 0x68, 0x99, 0x78, 0xa8, 0xe8, 0xd8, 0x9e,
		0xbe, 0x3e, 0xbe, 0xe3, 0x75, 0x9d, 0xb3, 0x71, 0xdd, 0x4f, 0xb6, 0x95, 0xf4, 0xf6, 0xad, 0x24,
		0xae, 0xda, 0xd1, 0x1b, 0x7f, 0x1e, 0xbf, 0xef, 0xf9, 0xf8, 0x03, 0xad, 0xfe, 0x7e, 0xa2, 0xfc,
		0x92, 0xe4, 0x6b, 0x97, 0x24, 0x7e, 0x50, 0x51, 0xc6, 0xd0, 0x93, 0x2f, 0x88, 0x0e, 0xc4, 0x91,
		0x61, 0x7d, 0x74, 0xa0, 0xba, 0x8e, 0xaa, 0xa3, 0x9f, 0xce, 0xea, 0xa6, 0x13, 0x51, 0x74, 0xb4,
		0xe6, 0x16, 0x80, 0x45, 0xb2, 0x24, 0xb5, 0xa5, 0x19, 0x4d, 0x1a, 0x80, 0xb4, 0x25, 0xe1, 0xf3,
		0xac, 0x02, 0x15, 0x40, 0xc5, 0xb3, 0x9f, 0x10, 0x9f, 0x27, 0xae, 0x00, 0x5c, 0x01, 0xb9, 0x76,
		0x05, 0xe0, 0xf3, 0xc4, 0xe7, 0x09, 0xd0, 0x01, 0x74, 0x85, 0x07, 0x3a, 0x7c, 0x9e, 0x6b, 0x27,
		0x06, 0x9f, 0x27, 0x3e, 0x4f, 0x7c, 0x9e, 0xf2, 0x2a, 0xb3, 0x26, 0xf8, 0x99, 0x39, 0xeb, 0xf8,
		0x3c, 0xf1, 0x3a, 0xe1, 0xf3, 0x4c, 0x09, 0x00, 0xd9, 0x7d, 0xf8, 0x3c, 0x65, 0x89, 0xf4, 0x16,
		0x3e, 0xcf, 0x89, 0xa4, 0x6e, 0xce, 0xe7, 0xa9, 0x22, 0xb7, 0x6f, 0x19, 0x73, 0x79, 0x26, 0x48,
		0x08, 0x56, 0x70, 0x62, 0x88, 0x66, 0x83, 0xfd, 0xd3, 0x7b, 0x48, 0x9e, 0xb0, 0xa9, 0xd4, 0xcf,
		0x58, 0xbd, 0x8f, 0xb1, 0x68, 0xff, 0x62, 0xb5, 0xbe, 0xc5, 0xf6, 0xe4, 0xbb, 0x27, 0x3d, 0x1a,
		0x26, 0x92, 0xe0, 0x93, 0x1c, 0x86, 0xa2, 0xe7, 0xc5, 0x2b, 0xe6, 0x82, 0x0b, 0xcc, 0xb7, 0x89,
		0xec, 0xf8, 0xbb, 0xd0, 0x6d, 0x78, 0xb7, 0xfd, 0x96, 0x13, 0x7a, 0xbd, 0xc8, 0x0d, 0xa3, 0xf8,
		0x49, 0xf1, 0x4b, 0xaf, 0x24, 0x17, 0x9e, 0x5c, 0xf8, 0xd1, 0x2f, 0xd2, 0x34, 0x89, 0x4c, 0xf7,
		0x2c, 0xb8, 0x4d, 0xf2, 0x8a, 0xaf, 0x81, 0x7b, 0xd3, 0xf2, 0x9a, 0x1a, 0x15, 0x5e, 0xc7, 0x03,
		0x10, 0x22, 0x66, 0xce, 0x8b, 0x43, 0xdc, 0x47, 0x26, 0x21, 0x62, 0x37, 0x9d, 0x4e, 0xcb, 0x73,
		0x03, 0x9d, 0x10, 0xb1, 0x5d, 0x0b, 0xc2, 0xba, 0x7e, 0x78, 0xad, 0xae, 0x17, 0x3a, 0x9d, 0xa0,
		0xf5, 0xa0, 0x7e, 0xcc, 0x67, 0x07, 0xe1, 0xa8, 0x73, 0xd4, 0x39, 0xea, 0x36, 0x1e, 0xf5, 0xb1,
		0x21, 0xe2, 0x44, 0x7e, 0x5b, 0x23, 0x90, 0x73, 0x6e, 0x14, 0x0e, 0x3b, 0x87, 0xbd, 0x60, 0x87,
		0xbd, 0xef, 0x07, 0xd1, 0x6e, 0x5d, 0xe3, 0xac, 0xd7, 0xa9, 0x0c, 0xab, 0x36, 0xcc, 0xa4, 0x7c,
		0xe9, 0x0e, 0x95, 0x61, 0x4d, 0x4d, 0x6d, 0x6d, 0xe7, 0xb0, 0x4e, 0x69, 0xd8, 0x2c, 0x2e, 0xdf,
		0x5e, 0xe4, 0xb6, 0xbc, 0x51, 0xb5, 0xd0, 0x9e, 0xe6, 0x0d, 0xbc, 0x3c, 0x14, 0xd7, 0x30, 0xd7,
		0x70, 0xc1, 0xae, 0xe1, 0xa6, 0xd7, 0xf0, 0xdb, 0x6e, 0xab, 0x5e, 0xd3, 0x61, 0xdd, 0x55, 0x85,
		0xd7, 0x2e, 0xe1, 0x5b, 0xb5, 0xac, 0xf7, 0x79, 0x95, 0xfb, 0xdc, 0xd4, 0x7d, 0xbe, 0x57, 0xc0,
		0xa9, 0xa5, 0xce, 0xfb, 0x2c, 0x44, 0x9b, 0xf6, 0x7b, 0x2f, 0xba, 0x17, 0xcd, 0x35, 0x49, 0xfc,
		0x7d, 0xfc, 0x4e, 0x5f, 0x46, 0x6f, 0x44, 0x7f, 0x44, 0xfa, 0x23, 0x9a, 0xe3, 0x38, 0x78, 0xcb,
		0xf0, 0x96, 0x41, 0xe7, 0x91, 0xd0, 0x57, 0x20, 0x33, 0xde, 0x32, 0x8e, 0x3a, 0x47, 0x9d, 0xa3,
		0x9e, 0xd2, 0x51, 0xc7, 0x5b, 0xc6, 0x61, 0xe7, 0xb0, 0x6f, 0x5a, 0x6f, 0xbc, 0x65, 0xaa, 0x0f,
		0x8e, 0xb7, 0xcc, 0x98, 0xba, 0x86, 0xb7, 0xcc, 0x4a, 0x81, 0x0d, 0x6f, 0x19, 0xd7, 0x30, 0xd7,
		0xb0, 0x91, 0x6b, 0x18, 0x6f, 0x59, 0xe6, 0xf7, 0x39, 0xde, 0x32, 0x63, 0xf7, 0x39, 0xde, 0x32,
		0xfb, 0x2e, 0xf3, 0x9c, 0x7b, 0xcb, 0x4c, 0xf5, 0x43, 0x5e, 0x74, 0x96, 0x95, 0xa1, 0x15, 0x72,
		0xc2, 0x4c, 0x47, 0x8d, 0xe9, 0x34, 0x91, 0xe1, 0x39, 0x6a, 0xe0, 0xdc, 0xf3, 0x5a, 0xde, 0xf0,
		0x6c, 0x3b, 0x9d, 0xee, 0xe0, 0xaf, 0x04, 0xdd, 0x8f, 0xd7, 0x0d, 0x40, 0xbe, 0x27, 0xf9, 0x9e,
		0xa3, 0x5f, 0x24, 0xdf, 0x13, 0x0f, 0x76, 0x16, 0xd7, 0x6a, 0x62, 0x0f, 0xb6, 0xdb, 0xbc, 0xf7,
		0xc2, 0xc8, 0xef, 0x79, 0x8e, 0x1f, 0x0c, 0xa8, 0xce, 0xfd, 0xc4, 0x70, 0x56, 0x37, 0xbf, 0xd7,
		0x0f, 0x99, 0xb4, 0x52, 0xf3, 0xa8, 0x1f, 0xfe, 0x60, 0xcc, 0x5b, 0xb7, 0xd5, 0xc3, 0x8c, 0xc7,
		0x8c, 0xc7, 0x75, 0xb6, 0x8c, 0xfe, 0x36, 0xb8, 0xce, 0xdc, 0xd6, 0x5f, 0xee, 0x43, 0xcf, 0x69,
		0x74, 0xda, 0x5d, 0x37, 0xf4, 0x9c, 0xb6, 0x4e, 0x4c, 0xcc, 0x8a, 0xb1, 0x00, 0x0e, 0x80, 0x03,
		0xe0, 0x28, 0x22, 0x70, 0x8c, 0x02, 0xe0, 0x1c, 0xd7, 0xbf, 0xeb, 0xea, 0x46, 0xd1, 0x8d, 0x06,
		0x01, 0x2a, 0x80, 0x0a, 0xa0, 0xa2, 0x90, 0x50, 0xf1, 0x33, 0xf2, 0xc2, 0xc0, 0x6d, 0x4d, 0x99,
		0xc1, 0xd0, 0xaa, 0x08, 0x1d, 0x5f, 0x27, 0xfe, 0x76, 0xfd, 0x98, 0xea, 0x40, 0x32, 0xd8, 0x8e,
		0xe0, 0x08, 0x38, 0x02, 0x8e, 0x58, 0x89, 0x23, 0xfe, 0x5d, 0xd0, 0x09, 0x3d, 0xc7, 0xed, 0x39,
		0x5d, 0x37, 0xfa, 0xe1, 0xb4, 0xbc, 0xe0, 0x6e, 0x28, 0x78, 0x2b, 0x42, 0xc8, 0xea, 0xe1, 0xa0,
		0x21, 0xc0, 0x07, 0xf0, 0x51, 0x60, 0xf8, 0x08, 0xbc, 0x9f, 0x91, 0xf3, 0xa3, 0xd3, 0x75, 0xfc,
		0xbb, 0xae, 0xd3, 0xf6, 0xa2, 0xd0, 0x6f, 0x68, 0x63, 0xc8, 0xaa, 0x31, 0x01, 0x12, 0x80, 0x04,
		0x20, 0xc9, 0x0d, 0x90, 0xe4, 0x2b, 0x48, 0x62, 0x8d, 0x23, 0xdb, 0x5c, 0x66, 0xf1, 0x97, 0xc1,
		0x1b, 0x5e, 0x4c, 0xde, 0xef, 0x6c, 0xf4, 0x76, 0xe4, 0x17, 0x93, 0x5f, 0x6c, 0x0e, 0x1a, 0xf1,
		0xce, 0x6e, 0xe1, 0x9d, 0x85, 0x69, 0xc0, 0x34, 0xca, 0x6b, 0xb2, 0xe0, 0x9d, 0x05, 0x38, 0x00,
		0x0e, 0x80, 0x23, 0x31, 0x70, 0xe0, 0x9d, 0x05, 0x2a, 0x80, 0x0a, 0xa0, 0x22, 0x0e, 0x54, 0xe0,
		0x9d, 0x05, 0x47, 0xc0, 0x11, 0x70, 0x44, 0x13, 0x47, 0xf0, 0xce, 0x02, 0x1f, 0xc0, 0x07, 0xf0,
		0xa1, 0x07, 0x1f, 0x78, 0x67, 0x01, 0x12, 0x80, 0x04, 0x20, 0x51, 0xf9, 0x4d, 0xeb, 0xbd, 0xb3,
		0xa6, 0x32, 0xd9, 0x57, 0x3b, 0x67, 0xcb, 0x90, 0xcf, 0xae, 0x96, 0xd0, 0xad, 0x3d, 0xb7, 0x26,
		0x92, 0xdb, 0xe3, 0x79, 0xb6, 0x13, 0x79, 0xb4, 0x13, 0x27, 0xae, 0x57, 0x49, 0x5c, 0x17, 0xbf,
		0x06, 0x52, 0x4a, 0x5c, 0x77, 0x7b, 0xc9, 0xa3, 0x22, 0xdc, 0x5e, 0xc2, 0x90, 0x88, 0x1d, 0x12,
		0xd6, 0x09, 0x89, 0x18, 0x7d, 0x92, 0x4f, 0x6e, 0xd0, 0x74, 0xa3, 0x4e, 0xf8, 0x90, 0x20, 0x52,
		0x26, 0x31, 0x47, 0x99, 0xd9, 0xa9, 0x4e, 0xd0, 0x6f, 0xdf, 0x78, 0x61, 0x92, 0x65, 0x1e, 0x6f,
		0xda, 0x83, 0x04, 0x2f, 0x51, 0x2b, 0x6f, 0xa5, 0x40, 0xba, 0x74, 0xca, 0x59, 0x69, 0xd6, 0x4e,
		0xd4, 0xad, 0xb1, 0x24, 0x51, 0x5b, 0x49, 0xa1, 0x5c, 0x95, 0x56, 0x99, 0x2a, 0xa9, 0x29, 0xab,
		0x55, 0x0f, 0x6b, 0x87, 0xf5, 0x83, 0xea, 0xe1, 0x7e, 0x86, 0x73, 0x67, 0x88, 0x64, 0x5f, 0xa5,
		0x18, 0xc6, 0x97, 0xdc, 0xc7, 0x30, 0x5f, 0xc3, 0x27, 0x81, 0x2b, 0x81, 0xbb, 0x8b, 0xbb, 0x4b,
		0xec, 0x1e, 0x6a, 0x76, 0xa2, 0xc8, 0x6b, 0x3a, 0xff, 0xeb, 0xbb, 0x4d, 0x85, 0x9b, 0x68, 0xf7,
		0x6d, 0x82, 0xd7, 0x9c, 0xbb, 0x51, 0xe4, 0x85, 0x41, 0xe2, 0xcb, 0xa8, 0xf2, 0xf2, 0xe5, 0xf7,
		0x1d, 0xe7, 0xf0, 0xea, 0xd7, 0xf7, 0x5d, 0xe7, 0xf0, 0x6a, 0xf4, 0xe5, 0xee, 0xf0, 0xaf, 0xd1,
		0xd7, 0xd5, 0xef, 0x3b, 0x4e, 0x6d, 0xf2, 0xf5, 0xfe, 0xf7, 0x1d, 0x67, 0xff, 0xea, 0xd5, 0x9f,
		0x7f, 0xbe, 0x79, 0xf5, 0xf7, 0xde, 0x63, 0xf2, 0x17, 0xc6, 0x5f, 0xc1, 0xab, 0x24, 0x8f, 0x7e,
		0x76, 0x71, 0xf2, 0x6f, 0xe5, 0xe7, 0xff, 0x4f, 0x9a, 0x13, 0xf0, 0x8f, 0x8a, 0x95, 0xf8, 0x1a,
		0x75, 0x22, 0xb7, 0x35, 0xf4, 0x9c, 0x28, 0x98, 0x05, 0xb3, 0x2f, 0x06, 0x63, 0xc1, 0xd8, 0x94,
		0x31, 0xb6, 0xef, 0x07, 0xd1, 0x5e, 0x15, 0xa2, 0x0f, 0xd1, 0x87, 0xe8, 0xe7, 0x9e, 0xe8, 0x8f,
		0xef, 0x92, 0x21, 0x1a, 0x7a, 0xea, 0x77, 0xd1, 0xe4, 0xf5, 0x5c, 0x47, 0x5c, 0x47, 0x5c, 0x47,
		0x5c, 0x47, 0x5c, 0x47, 0x5c, 0x47, 0xc9, 0x7e, 0x23, 0x33, 0x17, 0x65, 0x5c, 0xa7, 0x6f, 0x5c,
		0x87, 0x64, 0x0c, 0xb7, 0xae, 0x9a, 0x03, 0xb2, 0xdf, 0xf3, 0x9c, 0x76, 0xbf, 0x15, 0xf9, 0xdd,
		0x96, 0x17, 0xd3, 0x74, 0x7c, 0x02, 0xc9, 0xe5, 0xd7, 0x52, 0x53, 0x1b, 0xd7, 0xe4, 0xe8, 0x17,
		0xa9, 0xa9, 0x0d, 0xe7, 0xcb, 0x82, 0xf3, 0xe5, 0xa6, 0x2b, 0x34, 0xd1, 0x85, 0x49, 0x46, 0x20,
		0xba, 0x50, 0x80, 0x9d, 0x11, 0x5d, 0x68, 0x0a, 0x75, 0x8c, 0x47, 0x17, 0x2e, 0x73, 0x2d, 0x73,
		0x65, 0x5f, 0xbe, 0xf6, 0xbc, 0x4f, 0xe3, 0xb7, 0x3a, 0x1f, 0xbc, 0x53, 0x06, 0x15, 0x5f, 0xbc,
		0x9b, 0x04, 0x39, 0xac, 0x4f, 0x48, 0x1c, 0x1f, 0x5c, 0x60, 0x0e, 0x30, 0x07, 0x5d, 0xe6, 0x90,
		0x90, 0xe2, 0xea, 0x51, 0x5d, 0xc5, 0x8d, 0xcb, 0xbd, 0xcf, 0xbd, 0x9f, 0xf4, 0xde, 0x4f, 0x7a,
		0x10, 0xa6, 0x2f, 0x74, 0x5b, 0xad, 0xce, 0x5f, 0x4f, 0xd7, 0x94, 0xdb, 0x53, 0x5f, 0xb7, 0xa7,
		0x02, 0x26, 0x8b, 0x43, 0x2a, 0x4e, 0xbb, 0x26, 0xdd, 0x96, 0xd2, 0xf6, 0x54, 0x8f, 0xa1, 0xc4,
		0x71, 0x94, 0x3b, 0x96, 0x52, 0xc7, 0x53, 0xfc, 0x98, 0x8a, 0x1f, 0x57, 0xd1, 0x63, 0xab, 0x76,
		0x7c, 0x35, 0x64, 0x6c, 0x3d, 0x1a, 0x2f, 0x48, 0xe7, 0x35, 0x69, 0xbd, 0xfa, 0xc4, 0xa9, 0x68,
		0xff, 0x6d, 0xf7, 0xa7, 0xdf, 0xee, 0xb7, 0x13, 0x46, 0xd2, 0xac, 0x9d, 0xb5, 0xf9, 0xe1, 0xf4,
		0xe1, 0x6b, 0x17, 0xe8, 0x02, 0xba, 0x80, 0xae, 0x64, 0xfb, 0x25, 0xb1, 0x43, 0x77, 0xdd, 0xe9,
		0x39, 0xd0, 0x18, 0x42, 0xaf, 0x8f, 0xf6, 0xe4, 0x8f, 0xde, 0x7e, 0xdd, 0x92, 0xea, 0xab, 0x2d,
		0x04, 0x2b, 0x4b, 0xc3, 0x09, 0x35, 0x83, 0x9e, 0x8e, 0x27, 0xd8, 0x14, 0x5a, 0x73, 0x3b, 0xcf,
		0x2f, 0x81, 0x40, 0xff, 0x6d, 0xd3, 0x4b, 0xa0, 0xeb, 0x80, 0x4e, 0x65, 0x2d, 0x5e, 0x64, 0xf3,
		0xea, 0xab, 0xb4, 0x08, 0x8c, 0x51, 0x53, 0x4f, 0x51, 0xb7, 0x14, 0xd1, 0x2f, 0xbd, 0xc1, 0x8f,
		0x95, 0x34, 0x10, 0x2d, 0x31, 0xf3, 0xf8, 0xe6, 0xae, 0x9b, 0x48, 0xd1, 0x4c, 0xbe, 0x12, 0x8f,
		0x89, 0x34, 0xd9, 0x24, 0xb5, 0xad, 0x97, 0xee, 0xb5, 0xa4, 0xd9, 0xe5, 0x22, 0x12, 0x52, 0x15,
		0x09, 0x09, 0x09, 0x09, 0x09, 0x09, 0x3b, 0x0c, 0x3b, 0x0c, 0x3b, 0x0c, 0x09, 0x09, 0x09, 0x09,
		0xe8, 0x02, 0xba, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x90, 0x52,
		0x95, 0x90, 0x54, 0x24, 0x10, 0x7d, 0x05, 0x29, 0x41, 0xa1, 0x3d, 0x05, 0x01, 0x29, 0xf7, 0xc1,
		0x89, 0x5e, 0xc2, 0x00, 0x36, 0x9d, 0xb5, 0x48, 0x33, 0x30, 0xd1, 0x57, 0x0a, 0x4c, 0xf4, 0x09,
		0x4c, 0x24, 0x30, 0x51, 0xf9, 0xfc, 0x12, 0x98, 0x28, 0x6d, 0x0b, 0xa2, 0x2a, 0x1b, 0xb2, 0xf1,
		0x2c, 0x55, 0x95, 0x91, 0x63, 0x90, 0x63, 0x90, 0x63, 0x90, 0x63, 0x90, 0x63, 0x90, 0x63, 0x90,
		0x63, 0x90, 0x63, 0x90, 0x63, 0x8c, 0x18, 0xfd, 0x7e, 0x36, 0x11, 0x3d, 0x27, 0x44, 0xf4, 0x10,
		0xd1, 0x83, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85,
		0xed, 0x85, 0xed, 0x85, 0xed, 0x55, 0x3a, 0xdb, 0x2b, 0x75, 0x57, 0xf8, 0x09, 0xae, 0xf0, 0x58,
		0x2b, 0x93, 0x86, 0x2b, 0xfc, 0x24, 0x65, 0x57, 0x78, 0x32, 0x3b, 0x57, 0xc9, 0xbe, 0x55, 0x76,
		0x86, 0x57, 0x71, 0x86, 0x4b, 0x92, 0x60, 0xea, 0xfb, 0x51, 0xdf, 0x0f, 0x49, 0xa7, 0x68, 0x92,
		0x0e, 0xf5, 0xfd, 0xac, 0xe6, 0x0d, 0xa6, 0x1a, 0x07, 0x2f, 0x11, 0x87, 0x32, 0xf4, 0x0c, 0x4e,
		0x5c, 0xab, 0x5a, 0x67, 0x46, 0x95, 0x0b, 0x75, 0xbf, 0x48, 0x30, 0x67, 0x71, 0xe7, 0x2a, 0xf6,
		0x1c, 0x55, 0x9e, 0xed, 0x53, 0x1c, 0x67, 0x22, 0x56, 0x3f, 0xf7, 0xf2, 0x53, 0xad, 0x78, 0xa2,
		0x4a, 0xe0, 0xf9, 0x77, 0x3f, 0x6e, 0x3a, 0xe1, 0x7a, 0x89, 0x78, 0x8a, 0x3a, 0x4f, 0xbf, 0xba,
		0x66, 0x66, 0x9e, 0x67, 0x8d, 0x1b, 0xaf, 0xc8, 0x38, 0x57, 0x61, 0xfc, 0x2b, 0x2f, 0xee, 0xd5,
		0x96, 0xf8, 0x0a, 0x4b, 0x7c, 0x55, 0x25, 0xba, 0x92, 0x92, 0xed, 0xc5, 0x4d, 0xac, 0x6c, 0xba,
		0x66, 0xf1, 0xab, 0xcb, 0x4f, 0x5f, 0x41, 0x4d, 0x79, 0x6a, 0xca, 0x8f, 0x7e, 0xd1, 0xbd, 0xf5,
		0x9d, 0x9e, 0x7b, 0xeb, 0xab, 0x74, 0xbd, 0x9e, 0xbe, 0x94, 0x30, 0x6c, 0x2c, 0xcf, 0x74, 0x2c,
		0xcf, 0xc9, 0x9e, 0x53, 0x37, 0x3d, 0xa7, 0x23, 0x10, 0x8a, 0x8d, 0xed, 0x68, 0x95, 0xed, 0xa8,
		0x5e, 0xe0, 0xa3, 0xd9, 0x94, 0x0a, 0x05, 0x78, 0x1a, 0x4a, 0xcf, 0x85, 0xbf, 0x8b, 0x0b, 0x1f,
		0x17, 0xbe, 0xea, 0x60, 0xe9, 0xba, 0xf0, 0x55, 0x8f, 0xdd, 0x74, 0x00, 0xc5, 0xd4, 0xa0, 0xb5,
		0xdb, 0x4e, 0x39, 0xda, 0x4f, 0xf0, 0x20, 0x8a, 0x1d, 0x48, 0xc9, 0x83, 0x29, 0x7f, 0x40, 0xa5,
		0x0f, 0xaa, 0xb1, 0x03, 0x6b, 0xec, 0xe0, 0x1a, 0x39, 0xc0, 0x7a, 0x07, 0x59, 0xf3, 0x40, 0x8b,
		0x1d, 0xec, 0xe9, 0x40, 0x5e, 0xcb, 0xbf, 0xf3, 0x6f, 0x5a, 0xde, 0xb8, 0x7d, 0xaa, 0xd3, 0xed,
		0xb4, 0xfc, 0xc6, 0x83, 0xdc, 0x66, 0x99, 0x7a, 0x45, 0x56, 0xbf, 0xcf, 0x6b, 0x2b, 0x43, 0x30,
		0xa4, 0x80, 0xc1, 0x04, 0x40, 0x98, 0x03, 0x0a, 0x53, 0x80, 0x61, 0x1c, 0x38, 0x8c, 0x03, 0x88,
		0x51, 0x20, 0x91, 0x01, 0x14, 0x21, 0x60, 0x99, 0x3e, 0xa9, 0x76, 0xf0, 0xdf, 0xda, 0xfd, 0xda,
		0xf2, 0xdc, 0xdb, 0xd0, 0xbb, 0x95, 0xdc, 0xb0, 0x13, 0x3e, 0x70, 0x20, 0x38, 0xe6, 0xf9, 0x54,
		0x00, 0x6f, 0x38, 0x61, 0xb7, 0xd3, 0x7a, 0x17, 0x76, 0xfa, 0x91, 0x1f, 0xdc, 0x8d, 0x91, 0x6b,
		0xfa, 0xed, 0xd1, 0x3f, 0x9d, 0xa6, 0x77, 0xeb, 0x07, 0x7e, 0xe4, 0x77, 0x82, 0xde, 0xfa, 0x1f,
		0x4d, 0x7f, 0x32, 0x54, 0xc6, 0x5f, 0xd8, 0xb1, 0x6b, 0x24, 0xe2, 0xe9, 0x42, 0xaf, 0xe1, 0xf9,
		0xf7, 0x9e, 0xfc, 0xb5, 0x31, 0x19, 0x58, 0x68, 0x57, 0x0b, 0x95, 0x64, 0xe4, 0xfe, 0xe1, 0xfe,
		0xe1, 0xfe, 0xc9, 0xe9, 0xfd, 0xa3, 0x5f, 0x52, 0x72, 0xed, 0xfd, 0xb3, 0x5b, 0x20, 0x48, 0xef,
		0x79, 0x41, 0x53, 0x1e, 0xcf, 0x87, 0xa3, 0x02, 0xe6, 0x80, 0x39, 0x60, 0x0e, 0x98, 0x03, 0xe6,
		0x69, 0x82, 0xb9, 0xd3, 0x96, 0x4c, 0x7a, 0x99, 0x05, 0xf4, 0xe1, 0xc8, 0x80, 0x2f, 0xe0, 0x0b,
		0xf8, 0x96, 0x0a, 0x7c, 0xfb, 0x7e, 0x10, 0xbd, 0x35, 0x00, 0xbd, 0xfb, 0x82, 0x43, 0xca, 0x64,
		0x7d, 0x2e, 0xfe, 0x91, 0x3d, 0x4e, 0x5b, 0xd2, 0x59, 0xa1, 0x86, 0x51, 0x75, 0x69, 0x78, 0xe1,
		0xac, 0xd1, 0xa5, 0xf1, 0x0d, 0x64, 0x2e, 0x1a, 0x3a, 0x6d, 0xf3, 0x4b, 0xea, 0xfe, 0xcc, 0xfd,
		0x92, 0x56, 0xf7, 0xf7, 0x73, 0xbc, 0xa8, 0x2f, 0xec, 0x1c, 0xed, 0xca, 0x16, 0x6a, 0x99, 0xa9,
		0x0f, 0x53, 0x33, 0xfd, 0x75, 0x99, 0xe4, 0x6e, 0x0c, 0x5c, 0x9f, 0x46, 0x82, 0x4f, 0xbf, 0xda,
		0x9e, 0x06, 0x7a, 0x4e, 0xbf, 0xda, 0x9e, 0xc6, 0x09, 0x6d, 0x8b, 0x44, 0x2b, 0x6c, 0xc5, 0x09,
		0x88, 0xff, 0x3c, 0xf9, 0x64, 0xd3, 0xaf, 0xae, 0x8f, 0x6e, 0xfd, 0x8b, 0xc1, 0x07, 0x9b, 0x7c,
		0x71, 0x7d, 0xd4, 0x6c, 0x8e, 0x12, 0x30, 0x54, 0x6a, 0x17, 0xc9, 0x2d, 0xbd, 0xc6, 0xb2, 0x2b,
		0xd6, 0x3a, 0x5a, 0x6f, 0x7c, 0x28, 0xe6, 0x2f, 0xaf, 0xb4, 0xf7, 0xa4, 0x82, 0x49, 0xaa, 0x04,
		0x93, 0x58, 0x60, 0x49, 0x10, 0x4c, 0x12, 0xff, 0x89, 0x08, 0x26, 0x41, 0x82, 0x40, 0x82, 0x40,
		0x82, 0xc8, 0xa1, 0x04, 0x41, 0x30, 0x09, 0xc1, 0x24, 0xb1, 0x37, 0x0b, 0xc1, 0x24, 0xdc, 0x3f,
		0xdc, 0x3f, 0xdc, 0x3f, 0x82, 0xfb, 0x15, 0xff, 0x63, 0x3c, 0xbb, 0x9f, 0x60, 0x12, 0xc0, 0x1c,
		0x30, 0x07, 0xcc, 0x01, 0xf3, 0x62, 0x80, 0x39, 0xc1, 0x24, 0x80, 0x2f, 0xe0, 0x0b, 0xf8, 0xca,
		0xed, 0x57, 0x82, 0x49, 0x04, 0x37, 0x24, 0xc1, 0x24, 0xeb, 0xc7, 0x27, 0x98, 0x24, 0xb3, 0x25,
		0x25, 0x98, 0xc4, 0xc0, 0x68, 0x04, 0x93, 0xe4, 0x23, 0x98, 0x44, 0x22, 0x58, 0x61, 0x4b, 0x3c,
		0x96, 0x44, 0xa1, 0x18, 0xbb, 0xdc, 0xc2, 0xa7, 0x5b, 0x0c, 0x45, 0x68, 0x8b, 0xc8, 0x6f, 0x8d,
		0x8a, 0x56, 0x44, 0x8d, 0xdc, 0x66, 0xa8, 0xa4, 0xd5, 0x55, 0x41, 0xa1, 0x68, 0xd7, 0x64, 0xd6,
		0x9c, 0xf1, 0xa3, 0xea, 0xd6, 0x82, 0x9a, 0x1b, 0x8e, 0x96, 0x4e, 0xd4, 0x83, 0xca, 0xc8, 0xdc,
		0xcb, 0x6b, 0x4b, 0x27, 0x7d, 0xc7, 0xbb, 0x84, 0xa3, 0x7d, 0xea, 0x58, 0x7f, 0xf3, 0x66, 0x1c,
		0xac, 0xb9, 0x3d, 0x7f, 0xb2, 0x6d, 0x46, 0xb4, 0x6e, 0xb7, 0xf5, 0xa0, 0x1b, 0x22, 0xf5, 0x04,
		0x68, 0xb3, 0xa3, 0x51, 0xdf, 0xae, 0x32, 0x0e, 0x8e, 0x00, 0xd0, 0x14, 0x00, 0x6d, 0x38, 0x71,
		0x54, 0xb8, 0x53, 0xdb, 0x78, 0x54, 0xb8, 0x4b, 0xef, 0x88, 0x4a, 0x1f, 0x55, 0x63, 0x47, 0xd6,
		0xd8, 0xd1, 0x35, 0x73, 0x84, 0xed, 0x30, 0xe9, 0xc5, 0xc2, 0x92, 0x9b, 0x23, 0xdf, 0xbe, 0xe3,
		0xfd, 0xec, 0x76, 0xc2, 0xc8, 0x58, 0x54, 0xf2, 0xea, 0xb7, 0x91, 0x8f, 0x4f, 0xf8, 0x72, 0xfc,
		0xff, 0x8e, 0x3f, 0x5c, 0x5e, 0x7f, 0x39, 0xfb, 0x7a, 0x79, 0x8c, 0xa7, 0xcc, 0x26, 0x1c, 0x32,
		0x85, 0x47, 0xc6, 0x71, 0xc9, 0x38, 0x3e, 0x99, 0xc5, 0x29, 0x59, 0x51, 0xd5, 0x7e, 0x5f, 0xd9,
		0x04, 0x69, 0xc6, 0x31, 0xc1, 0xd1, 0xe0, 0x8d, 0x0c, 0x04, 0x2d, 0xd4, 0x04, 0xc7, 0x3c, 0x0e,
		0xfa, 0xed, 0xc1, 0x64, 0x3c, 0x16, 0x28, 0x10, 0x62, 0xb2, 0x0c, 0x7e, 0x3b, 0x95, 0x7b, 0x65,
		0xfe, 0x6d, 0xb8, 0x57, 0xb8, 0x57, 0xb8, 0x57, 0xb8, 0x57, 0xb8, 0x57, 0x0a, 0x77, 0xaf, 0x18,
		0xb6, 0x53, 0x8c, 0xd8, 0x27, 0x00, 0x3d, 0x40, 0x0f, 0xd0, 0xe7, 0x05, 0xe8, 0x49, 0x9b, 0x14,
		0x4d, 0x9b, 0x14, 0x5a, 0xef, 0x53, 0xbf, 0x17, 0x1d, 0x45, 0x51, 0x28, 0xbb, 0xe6, 0x9f, 0xfc,
		0xe0, 0xb8, 0xe5, 0x0d, 0x8e, 0x4c, 0x4f, 0x36, 0xc4, 0xab, 0xf2, 0xc9, 0xfd, 0x39, 0x33, 0xf2,
		0xee, 0xdb, 0x5a, 0xad, 0x7e, 0x50, 0xab, 0xed, 0x1c, 0xec, 0x1d, 0xec, 0x1c, 0xee, 0xef, 0xef,
		0xd6, 0x77, 0x25, 0x63, 0x2f, 0xcf, 0xc2, 0xa6, 0x17, 0x7a, 0xcd, 0xf7, 0x0f, 0xf2, 0xa0, 0x38,
		0x0d, 0x41, 0xed, 0x79, 0xa1, 0x34, 0x1e, 0x1a, 0x02, 0xf2, 0x45, 0x30, 0xef, 0x8c, 0x66, 0xc7,
		0xb9, 0x79, 0xa8, 0x18, 0x88, 0x3d, 0x34, 0x0d, 0xea, 0x4b, 0xc0, 0x3e, 0x5c, 0x09, 0x4b, 0xe3,
		0xed, 0x8a, 0xc4, 0x34, 0x0d, 0x2b, 0x17, 0x46, 0x14, 0x0b, 0x98, 0x26, 0x4c, 0x13, 0xa6, 0x09,
		0xd3, 0x84, 0x69, 0xc2, 0x34, 0x61, 0x9a, 0x30, 0x4d, 0x98, 0xa6, 0x71, 0xa6, 0x49, 0x66, 0xc7,
		0xaa, 0xf0, 0xfd, 0x99, 0x88, 0x4b, 0xdb, 0x2a, 0x85, 0x0e, 0x3e, 0xda, 0xf9, 0xf0, 0x93, 0x51,
		0x2c, 0x94, 0x62, 0xa1, 0x99, 0x19, 0x19, 0xc4, 0xe5, 0x11, 0x97, 0xf7, 0xcc, 0x40, 0xc4, 0xe5,
		0x21, 0x76, 0x20, 0x76, 0x20, 0x76, 0x14, 0x46, 0xec, 0x20, 0x7e, 0x82, 0xb8, 0x3c, 0xee, 0x15,
		0xee, 0x15, 0xee, 0x15, 0xee, 0x15, 0xee, 0x15, 0xe2, 0xf2, 0x92, 0xad, 0x32, 0x71, 0x79, 0x00,
		0x3d, 0x40, 0x5f, 0x6a, 0xa0, 0xc7, 0x5b, 0x8a, 0xb7, 0x54, 0x60, 0x64, 0xbc, 0xa5, 0x59, 0x01,
		0xf9, 0x16, 0xde, 0xd2, 0x2c, 0x90, 0x7d, 0x8b, 0xb8, 0xbc, 0x24, 0x07, 0x8a, 0xb8, 0x3c, 0x98,
		0x26, 0x4c, 0x13, 0xa6, 0x09, 0xd3, 0x84, 0x69, 0xc2, 0x34, 0x61, 0x9a, 0x30, 0xcd, 0x7c, 0x32,
		0x4d, 0xe2, 0xf2, 0x36, 0xc5, 0xe5, 0xd9, 0x55, 0x74, 0x79, 0x26, 0x2c, 0x8f, 0xba, 0xcb, 0x56,
		0x6c, 0x90, 0xcc, 0x4b, 0x2f, 0x3f, 0x6d, 0x09, 0x9b, 0x6b, 0x95, 0x6a, 0x16, 0x49, 0x94, 0x29,
		0x8e, 0x58, 0xb4, 0xfa, 0xa4, 0xd4, 0x5b, 0x56, 0x33, 0xf8, 0x72, 0x54, 0x6f, 0x59, 0xbb, 0x3a,
		0xa9, 0x4c, 0xd9, 0xf3, 0xa5, 0xdd, 0x27, 0x51, 0xfe, 0x5c, 0x58, 0xf8, 0xb1, 0xbe, 0x56, 0xa9,
		0x4c, 0x37, 0x2d, 0x42, 0xa2, 0x8d, 0x74, 0xcb, 0xca, 0x96, 0x0a, 0x8b, 0xc9, 0x34, 0x4f, 0x0a,
		0x6d, 0xd3, 0x0b, 0x22, 0x3f, 0x7a, 0x90, 0x91, 0x68, 0xa6, 0x37, 0xa7, 0x80, 0x39, 0x5e, 0x39,
		0x19, 0x7f, 0xb4, 0xf7, 0x6e, 0xcf, 0x40, 0x8f, 0xee, 0xa3, 0x8f, 0x27, 0xd7, 0x17, 0x83, 0xff,
		0x5c, 0xfe, 0x71, 0x2e, 0x16, 0xed, 0x36, 0xec, 0x3f, 0xd4, 0x13, 0x6d, 0xdc, 0x65, 0x48, 0x80,
		0xb8, 0xf8, 0x72, 0x79, 0x7c, 0x7d, 0x7e, 0x76, 0x7a, 0xf2, 0xe1, 0x8f, 0xeb, 0x93, 0xf3, 0x6f,
		0x75, 0x41, 0x61, 0xf3, 0xb5, 0xed, 0xcf, 0x7e, 0xba, 0xf7, 0xed, 0xfc, 0xf3, 0xe0, 0xa9, 0x6b,
		0xd7, 0x5f, 0x3f, 0x9f, 0x7c, 0x38, 0xba, 0xb8, 0x2c, 0xd5, 0xd3, 0x9f, 0x7c, 0xfe, 0xe7, 0xc5,
		0xe5, 0xd1, 0xe5, 0xf1, 0xf5, 0xc5, 0xf9, 0xc7, 0x92, 0x2e, 0xfb, 0xa7, 0xaf, 0xa7, 0x97, 0xa5,
		0x5b, 0xf8, 0x6f, 0xe7, 0x9f, 0xbf, 0xd5, 0xae, 0x3f, 0x9e, 0x9e, 0xfd, 0xeb, 0xe2, 0xfc, 0xf8,
		0x43, 0x99, 0x9e, 0x7c, 0x01, 0xec, 0x6a, 0xa5, 0xda, 0xf5, 0xd5, 0xc1, 0xae, 0xff, 0x76, 0x7e,
		0x7a, 0x51, 0xbe, 0xa7, 0x3e, 0xfe, 0x76, 0xfe, 0xb9, 0x94, 0xd0, 0x5e, 0xa6, 0x87, 0x1e, 0x02,
		0xfa, 0xe9, 0xd1, 0xfb, 0xe3, 0xd3, 0xe3, 0xdf, 0xca, 0x7d, 0x9f, 0x97, 0x6d, 0xb7, 0x4f, 0xee,
		0xf3, 0x7a, 0x39, 0xef, 0xf3, 0xe1, 0xc6, 0x2f, 0xe3, 0x75, 0x3e, 0x5c, 0xf2, 0x32, 0x9f, 0xf8,
		0xa7, 0x8d, 0x5f, 0xc2, 0xa7, 0x2f, 0xab, 0xdd, 0x66, 0x68, 0xbd, 0x45, 0x46, 0xba, 0xca, 0x5a,
		0x57, 0xcb, 0xa4, 0x6e, 0x88, 0x17, 0xb8, 0x37, 0x2d, 0xaf, 0x29, 0xa7, 0x96, 0x4f, 0x06, 0xd4,
		0xad, 0x9b, 0xf0, 0x94, 0xd2, 0x79, 0xeb, 0xb6, 0x7a, 0xe8, 0xee, 0x31, 0xa6, 0x1e, 0xdd, 0x1d,
		0xdd, 0x7d, 0xfd, 0x13, 0xc9, 0xeb, 0xee, 0x37, 0x9d, 0x4e, 0xcb, 0x73, 0x03, 0x49, 0xcd, 0x7d,
		0x97, 0x20, 0x8f, 0x04, 0xe3, 0x48, 0x05, 0x79, 0x68, 0x17, 0xe4, 0x12, 0x09, 0xef, 0xd0, 0x29,
		0xbe, 0x95, 0x4e, 0x64, 0xc7, 0x5d, 0xe8, 0x36, 0xbc, 0xdb, 0x7e, 0xcb, 0x09, 0xbd, 0x5e, 0xe4,
		0x86, 0x91, 0x7e, 0x8c, 0xc7, 0xd2, 0x88, 0x44, 0x7b, 0x10, 0xed, 0x91, 0xd1, 0x35, 0x45, 0x2f,
		0x5a, 0x7a, 0xd1, 0xc2, 0x33, 0xe1, 0x99, 0xb6, 0x54, 0xbc, 0x93, 0x32, 0x4d, 0x0d, 0x99, 0xa8,
		0xa6, 0x4c, 0x55, 0x61, 0x93, 0x55, 0x1c, 0x52, 0x4c, 0x40, 0x8b, 0x39, 0x88, 0x31, 0x05, 0x35,
		0xc6, 0x21, 0xc7, 0x38, 0xf4, 0x18, 0x85, 0x20, 0x59, 0x69, 0xce, 0xfe, 0x0c, 0x41, 0x39, 0x53,
		0x58, 0xd8, 0x24, 0x96, 0x5b, 0x08, 0x12, 0x68, 0x56, 0x99, 0xce, 0x8b, 0x06, 0x9c, 0x65, 0xc5,
		0xad, 0x7f, 0x1f, 0x7f, 0xbc, 0x2f, 0xa3, 0x4f, 0x47, 0x81, 0x6b, 0x0a, 0x5c, 0x43, 0xf6, 0x21,
		0xfb, 0xf6, 0x91, 0x7d, 0xb7, 0x79, 0xef, 0x85, 0x91, 0xdf, 0x33, 0xc1, 0xf7, 0x67, 0xc6, 0x86,
		0x9a, 0x43, 0xcd, 0xa1, 0xe6, 0x50, 0xf3, 0x82, 0x51, 0xf3, 0xd7, 0xa8, 0x2d, 0x40, 0x3a, 0x90,
		0x0e, 0xa4, 0x03, 0xe9, 0x40, 0xfa, 0xf4, 0x99, 0x42, 0xaf, 0xe1, 0xf9, 0xf7, 0x26, 0x30, 0x7d,
		0x3a, 0x32, 0xe0, 0x0b, 0xf8, 0x02, 0xbe, 0x80, 0x6f, 0xc1, 0xc0, 0x17, 0xa9, 0x3b, 0x8e, 0xd4,
		0x6d, 0x55, 0xbd, 0xa8, 0x45, 0xa5, 0x9b, 0x9a, 0x51, 0xd6, 0x6c, 0x94, 0xac, 0x03, 0x0b, 0x17,
		0xb6, 0x86, 0xcd, 0x11, 0x86, 0x7e, 0xf7, 0xbe, 0xe6, 0xb4, 0xdc, 0x1b, 0xaf, 0xe5, 0x35, 0x9d,
		0x7e, 0xe0, 0x37, 0xdc, 0x9e, 0x40, 0x94, 0xe1, 0xca, 0x51, 0x89, 0x34, 0x24, 0xd2, 0x30, 0x23,
		0xea, 0x94, 0xb3, 0x48, 0xc3, 0xd1, 0x8a, 0x38, 0x2d, 0xbf, 0xed, 0x47, 0x72, 0x1e, 0xc8, 0xb9,
		0x51, 0x89, 0x3a, 0x4c, 0xcf, 0x4e, 0xc2, 0x11, 0x89, 0x23, 0x72, 0xfd, 0x40, 0x42, 0x61, 0xc5,
		0x4b, 0xdb, 0x57, 0x2c, 0x2e, 0x44, 0xf0, 0xc0, 0x23, 0x98, 0x20, 0x98, 0x20, 0x98, 0xc8, 0x02,
		0xc8, 0x74, 0xc0, 0xb6, 0xfb, 0xd3, 0x19, 0xad, 0xfa, 0xb0, 0x9a, 0x9a, 0xa1, 0x8c, 0xea, 0xb9,
		0x77, 0x11, 0x5e, 0x7c, 0x59, 0x55, 0xd6, 0x18, 0xd8, 0x98, 0x04, 0x1d, 0xf3, 0xe0, 0x63, 0x1a,
		0x84, 0x52, 0x03, 0xa3, 0xd4, 0x40, 0x29, 0x15, 0x70, 0x92, 0x05, 0x29, 0x61, 0xb0, 0x9a, 0xce,
		0x80, 0xb8, 0xca, 0xbb, 0xb4, 0xdf, 0xfb, 0x7e, 0x10, 0xed, 0x55, 0x4d, 0xec, 0xf7, 0x31, 0xba,
		0x1c, 0x18, 0x18, 0xfa, 0x8b, 0x1b, 0xdc, 0x79, 0xa2, 0x15, 0x2c, 0x67, 0xff, 0x98, 0x39, 0x9f,
		0x5b, 0xe3, 0xe6, 0x23, 0xc6, 0x00, 0xc0, 0x30, 0xac, 0x2f, 0xbd, 0xcd, 0xb0, 0x8e, 0x68, 0x0a,
		0xef, 0xf3, 0x31, 0x74, 0x1b, 0x91, 0xdf, 0x09, 0x7e, 0xf3, 0xef, 0xfc, 0x51, 0xcf, 0x16, 0x63,
		0xef, 0xf7, 0xf8, 0xda, 0xe0, 0xd2, 0xbb, 0x3f, 0x0b, 0xb7, 0xf4, 0xb5, 0xea, 0x61, 0xed, 0xb0,
		0x7e, 0x50, 0x3d, 0xdc, 0x2f, 0xd0, 0x1e, 0x78, 0x91, 0x8f, 0x51, 0xaf, 0x6c, 0xed, 0x07, 0x23,
		0x68, 0xb7, 0x75, 0x43, 0xef, 0xde, 0x0b, 0x22, 0x27, 0xf2, 0xdc, 0xb0, 0xd9, 0xf9, 0x2b, 0x30,
		0x47, 0xb3, 0x97, 0xde, 0x49, 0xf8, 0x22, 0x37, 0x14, 0xd5, 0x06, 0x95, 0x87, 0xca, 0x43, 0xe5,
		0xa1, 0xf2, 0x86, 0x02, 0x37, 0x16, 0xe1, 0x45, 0x28, 0x80, 0xc3, 0xee, 0x4b, 0x67, 0xec, 0xd4,
		0x76, 0x22, 0xbf, 0xed, 0x85, 0xe6, 0x6e, 0x9c, 0xf9, 0xb7, 0xe1, 0x3a, 0xe0, 0x3a, 0xe0, 0x3a,
		0xe0, 0x3a, 0x10, 0xdc, 0xef, 0x4d, 0xaf, 0xe1, 0xb7, 0xdd, 0x56, 0xbd, 0x66, 0xf2, 0x42, 0xa8,
		0x1a, 0x18, 0x7b, 0xc9, 0xd8, 0xab, 0x22, 0x21, 0x65, 0x23, 0x21, 0x55, 0x91, 0x90, 0xca, 0x2a,
		0x21, 0xed, 0xb1, 0xf4, 0x28, 0x47, 0xf9, 0x25, 0xf1, 0x7f, 0xb9, 0x61, 0xe0, 0x07, 0x77, 0x4e,
		0xf4, 0x23, 0xf4, 0x7a, 0x3f, 0x3a, 0xad, 0xa6, 0xd3, 0x6d, 0x44, 0xe6, 0xc8, 0xfc, 0xea, 0xb7,
		0x83, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0xc1, 0xfd, 0xde, 0xf5, 0xc2, 0x86, 0x17, 0x44,
		0xee, 0x9d, 0x67, 0x90, 0xd5, 0xef, 0xc3, 0xb7, 0xb3, 0xe1, 0xdb, 0xb8, 0x6c, 0x4b, 0xcb, 0xb7,
		0xd3, 0x5a, 0xfa, 0xdd, 0x1d, 0x18, 0x37, 0x8c, 0x5b, 0x74, 0x24, 0xa9, 0x08, 0x4d, 0xe1, 0xbc,
		0xc8, 0xe9, 0xb8, 0x52, 0x69, 0x6f, 0xab, 0xb2, 0xac, 0xb6, 0x67, 0xb3, 0x3c, 0xb6, 0x45, 0x63,
		0xc0, 0xb7, 0xa4, 0xd2, 0xe3, 0x4e, 0xba, 0xf7, 0xb5, 0xd3, 0xd1, 0xc7, 0xfe, 0x3a, 0xfa, 0xd4,
		0xd7, 0x23, 0x6a, 0x7e, 0x3a, 0xf8, 0xd0, 0x22, 0x25, 0x03, 0xe5, 0x36, 0xd4, 0xa3, 0x48, 0xba,
		0xa9, 0x44, 0x29, 0xc1, 0x25, 0xee, 0x25, 0x95, 0x0e, 0xbb, 0x65, 0x32, 0xc0, 0xbf, 0x4a, 0x80,
		0x7f, 0x8e, 0x8c, 0x34, 0x02, 0xfc, 0x09, 0xf0, 0x27, 0xc0, 0x1f, 0xc5, 0x08, 0xc5, 0x08, 0xc5,
		0xc8, 0xd0, 0x7e, 0x27, 0xc0, 0x1f, 0xb5, 0x08, 0xb5, 0x08, 0xb5, 0x48, 0x69, 0xe9, 0x09, 0xf0,
		0x47, 0x34, 0x32, 0x78, 0x86, 0x08, 0xf0, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x58,
		0xfb, 0x9d, 0x00, 0x7f, 0x91, 0x67, 0x25, 0xc0, 0x9f, 0xeb, 0x80, 0xeb, 0x80, 0xeb, 0x20, 0xef,
		0xd7, 0x01, 0x01, 0xfe, 0x48, 0x48, 0x9a, 0xcb, 0x4b, 0x80, 0x7f, 0x69, 0x25, 0x24, 0x02, 0xfc,
		0x51, 0x8e, 0x72, 0x4c, 0xe2, 0x09, 0xf0, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x45, 0x23, 0xf5,
		0x04, 0xf8, 0x17, 0x99, 0x6f, 0xe3, 0xb2, 0x2d, 0x2d, 0xdf, 0x26, 0xc0, 0x1f, 0xc6, 0x9d, 0x3e,
		0xe3, 0x26, 0xc0, 0x5f, 0x34, 0xc0, 0x5f, 0x32, 0x04, 0x7c, 0x2b, 0xa5, 0xf8, 0x7e, 0x81, 0x46,
		0x49, 0x72, 0xdb, 0x89, 0xce, 0x5b, 0x4a, 0x1b, 0xcf, 0x96, 0x26, 0x5c, 0xcf, 0x6f, 0x35, 0xba,
		0x71, 0xd9, 0xb2, 0x79, 0xb2, 0xee, 0xc8, 0xb5, 0xbc, 0x4f, 0xac, 0x6f, 0xca, 0x25, 0xdb, 0x8c,
		0x8b, 0x26, 0x5c, 0x34, 0xe1, 0xca, 0x58, 0x61, 0xc9, 0x59, 0x13, 0x2e, 0xa1, 0xbe, 0x3c, 0xb2,
		0xfd, 0x78, 0x68, 0xbc, 0x95, 0xa5, 0xa4, 0x4a, 0xe3, 0x2d, 0x0b, 0x38, 0xb3, 0x58, 0xe3, 0xad,
		0x9e, 0x17, 0x34, 0x9d, 0xe6, 0x28, 0x4c, 0xd6, 0x09, 0x3b, 0x7d, 0x23, 0x29, 0xba, 0xcb, 0xef,
		0x21, 0x95, 0x5d, 0x68, 0x26, 0xbe, 0x97, 0xce, 0xe8, 0xe4, 0x01, 0x93, 0x07, 0x2c, 0xaa, 0x32,
		0xd1, 0x19, 0x1d, 0x7d, 0xc6, 0x84, 0x89, 0x3d, 0xd1, 0x65, 0xc4, 0x8a, 0x7c, 0x88, 0x59, 0xda,
		0x13, 0x29, 0x46, 0xa2, 0x92, 0x87, 0x86, 0x0a, 0xf3, 0x9a, 0x0e, 0xbc, 0x18, 0x02, 0x18, 0x02,
		0x18, 0x02, 0xe9, 0x58, 0xfa, 0x66, 0x2c, 0x7e, 0xe1, 0x03, 0x0f, 0x31, 0x87, 0x98, 0x43, 0xcc,
		0x65, 0x01, 0x64, 0x3a, 0x20, 0x05, 0x7a, 0x52, 0x02, 0x1b, 0x93, 0xa0, 0x63, 0x1e, 0x7c, 0x4c,
		0x83, 0x50, 0x6a, 0x60, 0x94, 0x1a, 0x28, 0xa5, 0x02, 0x4e, 0xb2, 0x20, 0x25, 0x0c, 0x56, 0xe6,
		0xd4, 0x84, 0xa5, 0xfd, 0x4e, 0x81, 0x9e, 0xa5, 0x3f, 0x44, 0x7b, 0xc6, 0x7a, 0x1b, 0xa2, 0x3d,
		0x93, 0x2d, 0x3d, 0x05, 0x7a, 0xf2, 0xb1, 0x07, 0x08, 0xfa, 0xb4, 0xe5, 0x0c, 0x51, 0xa0, 0x07,
		0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x63, 0xed, 0x77, 0x0a, 0xf4, 0x88, 0x3c, 0x2b, 0x05,
		0x7a, 0xb8, 0x0e, 0xb8, 0x0e, 0xb8, 0x0e, 0xf2, 0x7e, 0x1d, 0x50, 0xa0, 0x07, 0x09, 0x49, 0x73,
		0x79, 0x29, 0xd0, 0x53, 0x5a, 0x09, 0x89, 0x02, 0x3d, 0x28, 0x47, 0x39, 0x26, 0xf1, 0x14, 0xe8,
		0x81, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x45, 0x23, 0xf5, 0x14, 0xe8, 0x29, 0x32, 0xdf, 0xc6, 0x65,
		0x5b, 0x5a, 0xbe, 0x4d, 0x81, 0x1e, 0x18, 0x77, 0xfa, 0x8c, 0x9b, 0x02, 0x3d, 0xaa, 0x79, 0x38,
		0x39, 0xe9, 0xbc, 0x4b, 0xcb, 0x5d, 0x0d, 0xb2, 0x45, 0xcb, 0x5d, 0x5b, 0xad, 0x34, 0x22, 0xfa,
		0x33, 0xb1, 0xc2, 0x88, 0xe8, 0x17, 0x38, 0x0c, 0x44, 0xf4, 0x23, 0x11, 0x21, 0x11, 0x21, 0x11,
		0x99, 0xda, 0xef, 0x44, 0xf4, 0x23, 0x0f, 0x21, 0x0f, 0x21, 0x0f, 0x29, 0x2d, 0x3d, 0x11, 0xfd,
		0xa8, 0x44, 0x06, 0xcf, 0x10, 0x11, 0xfd, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x1f, 0x6b,
		0xbf, 0x13, 0xd1, 0x2f, 0xf2, 0xac, 0x44, 0xf4, 0x73, 0x1d, 0x70, 0x1d, 0x70, 0x1d, 0xe4, 0xfd,
		0x3a, 0x20, 0xa2, 0x1f, 0x09, 0x49, 0x73, 0x79, 0x89, 0xe8, 0x2f, 0xad, 0x84, 0x44, 0x44, 0x3f,
		0xca, 0x51, 0x8e, 0x49, 0x3c, 0x11, 0xfd, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0xbe, 0x68, 0xa4, 0x9e,
		0x88, 0xfe, 0x22, 0xf3, 0x6d, 0x5c, 0xb6, 0xa5, 0xe5, 0xdb, 0x44, 0xf4, 0xc3, 0xb8, 0xd3, 0x67,
		0xdc, 0x44, 0xf4, 0x8b, 0x44, 0xf4, 0x5b, 0xdb, 0x6a, 0x97, 0x1e, 0xbb, 0x69, 0xee, 0x38, 0xf3,
		0x3b, 0xcd, 0xc6, 0x4e, 0x2e, 0x36, 0x34, 0xd5, 0xd5, 0x6a, 0x21, 0x2b, 0x91, 0x0d, 0x22, 0x9a,
		0x05, 0x22, 0xde, 0xc0, 0xa5, 0x4a, 0x03, 0x17, 0x0b, 0x2c, 0x73, 0x1a, 0xb8, 0xc4, 0x7f, 0x22,
		0x3a, 0x39, 0x6e, 0xd1, 0xc9, 0x91, 0xf4, 0x32, 0xd2, 0xcb, 0xf2, 0x62, 0xbc, 0xd0, 0xc9, 0x11,
		0x2b, 0xc0, 0xa4, 0x15, 0x20, 0x65, 0x62, 0x8a, 0xd3, 0x7f, 0x01, 0x73, 0xf2, 0x31, 0x27, 0x7d,
		0xe3, 0x85, 0x36, 0x8a, 0x91, 0x0d, 0x52, 0xd1, 0x32, 0x81, 0x44, 0xb7, 0x84, 0xda, 0x66, 0x48,
		0xbe, 0x94, 0x0a, 0xcb, 0x58, 0xf1, 0xbb, 0xf7, 0x75, 0xa7, 0xe5, 0xde, 0x78, 0x2d, 0xaf, 0x39,
		0x9d, 0x3a, 0xd5, 0xc5, 0x9c, 0x42, 0xf4, 0xca, 0x51, 0x15, 0x37, 0x99, 0x9e, 0xed, 0xa7, 0x4d,
		0xc5, 0x24, 0xa8, 0x97, 0x1c, 0xd5, 0x92, 0xa2, 0x56, 0xe2, 0x54, 0x4a, 0x9c, 0x3a, 0x89, 0x52,
		0xa5, 0x74, 0x61, 0x51, 0xd7, 0x56, 0xa3, 0xa3, 0x2e, 0x82, 0x0c, 0x82, 0x4c, 0x59, 0x04, 0x19,
		0x3a, 0xea, 0x22, 0x90, 0x20, 0x90, 0x94, 0x4f, 0x20, 0xa1, 0xfe, 0xce, 0x3a, 0x90, 0x21, 0xa0,
		0x93, 0x80, 0x4e, 0x9b, 0x40, 0x29, 0x15, 0x70, 0x92, 0x05, 0x29, 0x61, 0xb0, 0x9a, 0xce, 0x00,
		0xf5, 0x77, 0x56, 0x0e, 0x4d, 0x30, 0x67, 0xfa, 0xb0, 0xbe, 0xf4, 0x36, 0x04, 0x73, 0x26, 0x5b,
		0x7a, 0xea, 0xef, 0xe4, 0x63, 0x0f, 0x10, 0xd3, 0x69, 0xcb, 0x19, 0xa2, 0xfe, 0x0e, 0x54, 0x1e,
		0x2a, 0x0f, 0x95, 0x87, 0xca, 0xc7, 0xda, 0xef, 0xd4, 0xdf, 0x11, 0x79, 0x56, 0xea, 0xef, 0x70,
		0x1d, 0x70, 0x1d, 0x70, 0x1d, 0xe4, 0xfd, 0x3a, 0xa0, 0xfe, 0x0e, 0x12, 0x92, 0xe6, 0xf2, 0x52,
		0x7f, 0xa7, 0xb4, 0x12, 0x12, 0xf5, 0x77, 0x50, 0x8e, 0x72, 0x4c, 0xe2, 0xa9, 0xbf, 0x03, 0xa9,
		0x87, 0xd4, 0x43, 0xea, 0x8b, 0x46, 0xea, 0xa9, 0xbf, 0x53, 0x64, 0xbe, 0x8d, 0xcb, 0xb6, 0xb4,
		0x7c, 0x9b, 0xfa, 0x3b, 0x30, 0xee, 0xf4, 0x19, 0x37, 0xf5, 0x77, 0x92, 0xa5, 0xbb, 0x2d, 0x65,
		0x59, 0xe5, 0xa4, 0xb3, 0x6e, 0xfd, 0x74, 0xf4, 0xb1, 0x69, 0xb0, 0xab, 0xc1, 0xbd, 0x68, 0xb0,
		0x6b, 0xab, 0xd1, 0x46, 0x80, 0x7f, 0x26, 0x46, 0x19, 0x01, 0xfe, 0x02, 0x87, 0x81, 0x00, 0x7f,
		0x14, 0x23, 0x14, 0x23, 0x14, 0x23, 0x53, 0xfb, 0x9d, 0x00, 0x7f, 0xd4, 0x22, 0xd4, 0x22, 0xd4,
		0x22, 0xa5, 0xa5, 0x27, 0xc0, 0x1f, 0xd1, 0xc8, 0xe0, 0x19, 0x22, 0xc0, 0x1f, 0x2a, 0x0f, 0x95,
		0x87, 0xca, 0x43, 0xe5, 0x63, 0xed, 0x77, 0x02, 0xfc, 0x45, 0x9e, 0x95, 0x00, 0x7f, 0xae, 0x03,
		0xae, 0x03, 0xae, 0x83, 0xbc, 0x5f, 0x07, 0x04, 0xf8, 0x23, 0x21, 0x69, 0x2e, 0x2f, 0x01, 0xfe,
		0xa5, 0x95, 0x90, 0x08, 0xf0, 0x47, 0x39, 0xca, 0x31, 0x89, 0x27, 0xc0, 0x1f, 0x52, 0x0f, 0xa9,
		0x87, 0xd4, 0x17, 0x8d, 0xd4, 0x13, 0xe0, 0x5f, 0x64, 0xbe, 0x8d, 0xcb, 0xb6, 0xb4, 0x7c, 0x9b,
		0x00, 0x7f, 0x18, 0x77, 0xfa, 0x8c, 0x9b, 0x00, 0x7f, 0xd1, 0x00, 0x7f, 0x5b, 0x1b, 0xed, 0x3e,
		0x17, 0xdf, 0x4f, 0xbf, 0x5d, 0x53, 0x1b, 0x30, 0xbd, 0x8d, 0x67, 0x51, 0xe3, 0xad, 0x67, 0xb6,
		0x1a, 0x5d, 0xb8, 0x6c, 0xd9, 0x3c, 0x16, 0x74, 0xe3, 0x5a, 0xd8, 0x27, 0xd6, 0x37, 0xe5, 0x92,
		0x6d, 0xc6, 0x45, 0x13, 0x2e, 0x9a, 0x70, 0x65, 0xac, 0xb0, 0xe4, 0xac, 0x09, 0x97, 0x50, 0x5f,
		0x1e, 0xd9, 0x7e, 0x3c, 0x34, 0xde, 0xca, 0x52, 0x52, 0xa5, 0xf1, 0x96, 0x05, 0x9c, 0x99, 0x4e,
		0xe8, 0x5b, 0x74, 0x42, 0x27, 0x0f, 0x98, 0x3c, 0xe0, 0xbc, 0xa8, 0x4c, 0x74, 0x42, 0x47, 0x9f,
		0x31, 0x61, 0x62, 0x4f, 0x74, 0x19, 0xb1, 0x22, 0x1f, 0x62, 0x96, 0xf6, 0x44, 0x8a, 0x91, 0xa8,
		0xe4, 0xa1, 0xa1, 0xc2, 0xbc, 0xa6, 0x03, 0x2f, 0x86, 0x00, 0x86, 0x00, 0x86, 0x40, 0x3a, 0x96,
		0xbe, 0x19, 0x8b, 0x5f, 0xf8, 0xc0, 0x43, 0xcc, 0x21, 0xe6, 0x10, 0x73, 0x59, 0x00, 0x99, 0x0e,
		0x48, 0x81, 0x9e, 0x94, 0xc0, 0xc6, 0x24, 0xe8, 0x98, 0x07, 0x1f, 0xd3, 0x20, 0x94, 0x1a, 0x18,
		0xa5, 0x06, 0x4a, 0xa9, 0x80, 0x93, 0x2c, 0x48, 0x09, 0x83, 0x95, 0x39, 0x35, 0x61, 0x69, 0xbf,
		0x53, 0xa0, 0x67, 0xe9, 0x0f, 0xd1, 0x9e, 0xb1, 0xde, 0x86, 0x68, 0xcf, 0x64, 0x4b, 0x4f, 0x81,
		0x9e, 0x7c, 0xec, 0x01, 0x82, 0x3e, 0x6d, 0x39, 0x43, 0x14, 0xe8, 0x81, 0xca, 0x43, 0xe5, 0xa1,
		0xf2, 0x50, 0xf9, 0x58, 0xfb, 0x9d, 0x02, 0x3d, 0x22, 0xcf, 0x4a, 0x81, 0x1e, 0xae, 0x03, 0xae,
		0x03, 0xae, 0x83, 0xbc, 0x5f, 0x07, 0x14, 0xe8, 0x41, 0x42, 0xd2, 0x5c, 0x5e, 0x0a, 0xf4, 0x94,
		0x56, 0x42, 0xa2, 0x40, 0x0f, 0xca, 0x51, 0x8e, 0x49, 0x3c, 0x05, 0x7a, 0x20, 0xf5, 0x90, 0x7a,
		0x48, 0x7d, 0xd1, 0x48, 0x3d, 0x05, 0x7a, 0x8a, 0xcc, 0xb7, 0x71, 0xd9, 0x96, 0x96, 0x6f, 0x53,
		0xa0, 0x07, 0xc6, 0x9d, 0x3e, 0xe3, 0xa6, 0x40, 0x8f, 0x6a, 0x1e, 0x4e, 0x4e, 0x3a, 0xef, 0xd2,
		0x72, 0x57, 0x83, 0x6c, 0xd1, 0x72, 0xd7, 0x56, 0x2b, 0x8d, 0x88, 0xfe, 0x4c, 0xac, 0x30, 0x22,
		0xfa, 0x05, 0x0e, 0x03, 0x11, 0xfd, 0x48, 0x44, 0x48, 0x44, 0x48, 0x44, 0xa6, 0xf6, 0x3b, 0x11,
		0xfd, 0xc8, 0x43, 0xc8, 0x43, 0xc8, 0x43, 0x4a, 0x4b, 0x4f, 0x44, 0x3f, 0x2a, 0x91, 0xc1, 0x33,
		0x44, 0x44, 0x3f, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0xc7, 0xda, 0xef, 0x44, 0xf4, 0x8b,
		0x3c, 0x2b, 0x11, 0xfd, 0x5c, 0x07, 0x5c, 0x07, 0x5c, 0x07, 0x79, 0xbf, 0x0e, 0x88, 0xe8, 0x47,
		0x42, 0xd2, 0x5c, 0x5e, 0x22, 0xfa, 0x4b, 0x2b, 0x21, 0x11, 0xd1, 0x8f, 0x72, 0x94, 0x63, 0x12,
		0x4f, 0x44, 0x3f, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x2f, 0x1a, 0xa9, 0x27, 0xa2, 0xbf, 0xc8, 0x7c,
		0x1b, 0x97, 0x6d, 0x69, 0xf9, 0x36, 0x11, 0xfd, 0x30, 0xee, 0xf4, 0x19, 0x37, 0x11, 0xfd, 0x22,
		0x11, 0xfd, 0xd6, 0xb6, 0xda, 0xa5, 0xc7, 0x6e, 0x9a, 0x3b, 0xce, 0xfc, 0x4e, 0xb3, 0xb1, 0x93,
		0x8b, 0x0d, 0x4d, 0x75, 0xb5, 0x5a, 0xc8, 0x4a, 0x64, 0x83, 0x88, 0x66, 0x81, 0x88, 0x37, 0x70,
		0xa9, 0xd2, 0xc0, 0xc5, 0x02, 0xcb, 0x9c, 0x06, 0x2e, 0xf1, 0x9f, 0x88, 0x4e, 0x8e, 0x5b, 0x74,
		0x72, 0x24, 0xbd, 0x8c, 0xf4, 0xb2, 0xbc, 0x18, 0x2f, 0x74, 0x72, 0xc4, 0x0a, 0x30, 0x69, 0x05,
		0x48, 0x99, 0x98, 0xe2, 0xf4, 0x5f, 0xc0, 0x9c, 0x7c, 0xcc, 0x49, 0xdf, 0x78, 0xa1, 0x8d, 0x62,
		0x64, 0x83, 0x54, 0xb4, 0x4c, 0x20, 0xd1, 0x2d, 0xa1, 0xb6, 0x19, 0x92, 0x2f, 0xa5, 0xc2, 0x32,
		0x56, 0x5a, 0xd5, 0xfb, 0x6e, 0xe0, 0x78, 0xf7, 0x5d, 0xf5, 0x25, 0x9c, 0x02, 0xf3, 0xcc, 0x58,
		0x8a, 0x1b, 0x4a, 0xcf, 0xce, 0xd3, 0xa6, 0x5d, 0x12, 0x34, 0x4b, 0x8e, 0x56, 0x49, 0xd1, 0x28,
		0x71, 0xda, 0x24, 0x4e, 0x93, 0x44, 0x69, 0x51, 0xba, 0x10, 0xa8, 0x6b, 0x97, 0xd1, 0x3d, 0x17,
		0xf1, 0x05, 0xf1, 0xa5, 0x2c, 0xe2, 0x0b, 0xdd, 0x73, 0x11, 0x43, 0x10, 0x43, 0xca, 0x27, 0x86,
		0x50, 0x6b, 0x67, 0x1d, 0xc8, 0x10, 0xbc, 0x49, 0xf0, 0xa6, 0x4d, 0xa0, 0x94, 0x0a, 0x38, 0xc9,
		0x82, 0x94, 0x30, 0x58, 0x4d, 0x67, 0x80, 0x5a, 0x3b, 0x2b, 0x87, 0x26, 0x70, 0x33, 0x7d, 0x58,
		0x5f, 0x7a, 0x1b, 0x02, 0x37, 0x93, 0x2d, 0x3d, 0xb5, 0x76, 0xf2, 0xb1, 0x07, 0x88, 0xdf, 0xb4,
		0xe5, 0x0c, 0x51, 0x6b, 0x07, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x63, 0xed, 0x77, 0x6a,
		0xed, 0x88, 0x3c, 0x2b, 0xb5, 0x76, 0xb8, 0x0e, 0xb8, 0x0e, 0xb8, 0x0e, 0xf2, 0x7e, 0x1d, 0x50,
		0x6b, 0x07, 0x09, 0x49, 0x73, 0x79, 0xa9, 0xb5, 0x53, 0x5a, 0x09, 0x89, 0x5a, 0x3b, 0x28, 0x47,
		0x39, 0x26, 0xf1, 0xd4, 0xda, 0x81, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x45, 0x23, 0xf5, 0xd4, 0xda,
		0x29, 0x32, 0xdf, 0xc6, 0x65, 0x5b, 0x5a, 0xbe, 0x4d, 0xad, 0x1d, 0x18, 0x77, 0xfa, 0x8c, 0x9b,
		0x5a, 0x3b, 0x09, 0x52, 0xdb, 0x9e, 0x72, 0xab, 0xf2, 0xd0, 0x3b, 0xf7, 0xb4, 0xfa, 0xad, 0x1b,
		0x1c, 0xdf, 0x77, 0x03, 0x3a, 0xe7, 0xaa, 0x10, 0x2d, 0x3a, 0xe7, 0xda, 0x6a, 0xa1, 0x11, 0xcd,
		0x9f, 0x89, 0x05, 0x46, 0x34, 0xbf, 0xc0, 0x61, 0x20, 0x9a, 0x1f, 0x79, 0x08, 0x79, 0x08, 0x79,
		0xc8, 0xd4, 0x7e, 0x27, 0x9a, 0x1f, 0x69, 0x08, 0x69, 0x08, 0x69, 0x48, 0x69, 0xe9, 0x89, 0xe6,
		0x47, 0x21, 0x32, 0x78, 0x86, 0x88, 0xe6, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x58,
		0xfb, 0x9d, 0x68, 0x7e, 0x91, 0x67, 0x25, 0x9a, 0x9f, 0xeb, 0x80, 0xeb, 0x80, 0xeb, 0x20, 0xef,
		0xd7, 0x01, 0xd1, 0xfc, 0x48, 0x48, 0x9a, 0xcb, 0x4b, 0x34, 0x7f, 0x69, 0x25, 0x24, 0xa2, 0xf9,
		0x51, 0x8e, 0x72, 0x4c, 0xe2, 0x89, 0xe6, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x45, 0x23, 0xf5,
		0x44, 0xf3, 0x17, 0x99, 0x6f, 0xe3, 0xb2, 0x2d, 0x2d, 0xdf, 0x26, 0x9a, 0x1f, 0xc6, 0x9d, 0x3e,
		0xe3, 0x26, 0x9a, 0x5f, 0x20, 0x9a, 0xdf, 0xca, 0xbe, 0xb9, 0xab, 0x83, 0xf9, 0xe9, 0x9a, 0x6b,
		0x6a, 0xb7, 0x99, 0xde, 0x65, 0xb6, 0x34, 0xcd, 0x5a, 0xb9, 0xaf, 0x68, 0x9c, 0x95, 0xed, 0x4e,
		0xc9, 0xba, 0x6d, 0xd6, 0x74, 0x53, 0xd8, 0xdf, 0x34, 0xeb, 0xbe, 0xdb, 0xea, 0x49, 0x35, 0xcd,
		0x1a, 0x8e, 0x45, 0xd3, 0x2c, 0x9a, 0x66, 0x65, 0x24, 0x92, 0xd0, 0x34, 0x8b, 0xa6, 0x59, 0xd9,
		0x29, 0xa6, 0x34, 0xcd, 0xa2, 0x69, 0xd6, 0xfa, 0x81, 0x68, 0x9a, 0x25, 0x31, 0x20, 0x69, 0xb6,
		0xa4, 0xd9, 0xe6, 0x4b, 0xc4, 0x21, 0xcd, 0x76, 0x1d, 0xc8, 0xe0, 0xb7, 0xc5, 0x6f, 0x6b, 0x13,
		0x28, 0xa5, 0x02, 0x4e, 0xb2, 0x20, 0x25, 0x0c, 0x56, 0xd3, 0x19, 0x20, 0xcd, 0x76, 0xe5, 0xd0,
		0xf8, 0x6c, 0xd3, 0x87, 0xf5, 0xa5, 0xb7, 0xc1, 0x67, 0x9b, 0x6c, 0xe9, 0x49, 0xb3, 0xcd, 0xc7,
		0x1e, 0xc0, 0x75, 0x6b, 0xcb, 0x19, 0x22, 0xcd, 0x16, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5,
		0x63, 0xed, 0x77, 0xd2, 0x6c, 0x45, 0x9e, 0x95, 0x34, 0x5b, 0xae, 0x03, 0xae, 0x03, 0xae, 0x83,
		0xbc, 0x5f, 0x07, 0xa4, 0xd9, 0x22, 0x21, 0x69, 0x2e, 0x2f, 0x69, 0xb6, 0xa5, 0x95, 0x90, 0x48,
		0xb3, 0x45, 0x39, 0xca, 0x31, 0x89, 0x27, 0xcd, 0x16, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x17, 0x8d,
		0xd4, 0x93, 0x66, 0x5b, 0x64, 0xbe, 0x8d, 0xcb, 0xb6, 0xb4, 0x7c, 0x9b, 0x34, 0x5b, 0x18, 0x77,
		0xfa, 0x8c, 0x9b, 0x34, 0xdb, 0xc4, 0x69, 0x6d, 0xf7, 0xdd, 0x56, 0x2f, 0x37, 0x4d, 0xb3, 0xbe,
		0x75, 0x5b, 0x3d, 0x9a, 0x66, 0xa9, 0x10, 0x2d, 0x9a, 0x66, 0xd9, 0x6a, 0xa1, 0x11, 0xcd, 0x9f,
		0x89, 0x05, 0x46, 0x34, 0xbf, 0xc0, 0x61, 0x20, 0x9a, 0x1f, 0x79, 0x08, 0x79, 0x08, 0x79, 0xc8,
		0xd4, 0x7e, 0x27, 0x9a, 0x1f, 0x69, 0x08, 0x69, 0x08, 0x69, 0x48, 0x69, 0xe9, 0x89, 0xe6, 0x47,
		0x21, 0x32, 0x78, 0x86, 0x88, 0xe6, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0x58, 0xfb,
		0x9d, 0x68, 0x7e, 0x91, 0x67, 0x25, 0x9a, 0x9f, 0xeb, 0x80, 0xeb, 0x80, 0xeb, 0x20, 0xef, 0xd7,
		0x01, 0xd1, 0xfc, 0x48, 0x48, 0x9a, 0xcb, 0x4b, 0x34, 0x7f, 0x69, 0x25, 0x24, 0xa2, 0xf9, 0x51,
		0x8e, 0x72, 0x4c, 0xe2, 0x89, 0xe6, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x45, 0x23, 0xf5, 0x44,
		0xf3, 0x17, 0x99, 0x6f, 0xe3, 0xb2, 0x2d, 0x2d, 0xdf, 0x26, 0x9a, 0x1f, 0xc6, 0x9d, 0x3e, 0xe3,
		0x26, 0x9a, 0x5f, 0x20, 0x9a, 0xdf, 0xde, 0xa6, 0x59, 0x4b, 0xc1, 0xfc, 0x34, 0xcd, 0x32, 0xb5,
		0xdb, 0x4c, 0xef, 0x32, 0xab, 0x9a, 0x66, 0x2d, 0xee, 0x2b, 0x9a, 0x66, 0x65, 0xbb, 0x53, 0xac,
		0x68, 0x9a, 0x35, 0xd8, 0x14, 0x56, 0x37, 0xcd, 0xda, 0x1b, 0x4c, 0x97, 0xdf, 0xbd, 0xaf, 0x39,
		0xed, 0x7e, 0x2b, 0xf2, 0x1b, 0x6e, 0x2f, 0x12, 0x68, 0x9f, 0xb5, 0x6a, 0x54, 0x1a, 0x69, 0xd1,
		0x48, 0x2b, 0x23, 0xe1, 0x84, 0x46, 0x5a, 0x34, 0xd2, 0xca, 0x4e, 0x45, 0xa5, 0x91, 0x16, 0x8d,
		0xb4, 0xd6, 0x0f, 0x44, 0x23, 0x2d, 0x89, 0x01, 0x49, 0xbd, 0x25, 0xf5, 0x36, 0x5f, 0xc2, 0x0e,
		0xa9, 0xb7, 0xeb, 0x40, 0x06, 0x5f, 0x2e, 0xbe, 0x5c, 0x9b, 0x40, 0x29, 0x15, 0x70, 0x92, 0x05,
		0x29, 0x61, 0xb0, 0x9a, 0xce, 0x00, 0xa9, 0xb7, 0x2b, 0x87, 0xc6, 0x8f, 0x9b, 0x3e, 0xac, 0x2f,
		0xbd, 0x0d, 0x7e, 0xdc, 0x64, 0x4b, 0x4f, 0xea, 0x6d, 0x3e, 0xf6, 0x00, 0xee, 0x5c, 0x5b, 0xce,
		0x10, 0xa9, 0xb7, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x1f, 0x6b, 0xbf, 0x93, 0x7a, 0x2b,
		0xf2, 0xac, 0xa4, 0xde, 0x72, 0x1d, 0x70, 0x1d, 0x70, 0x1d, 0xe4, 0xfd, 0x3a, 0x20, 0xf5, 0x16,
		0x09, 0x49, 0x73, 0x79, 0x49, 0xbd, 0x2d, 0xad, 0x84, 0x44, 0xea, 0x2d, 0xca, 0x51, 0x8e, 0x49,
		0x3c, 0xa9, 0xb7, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0xbe, 0x68, 0xa4, 0x9e, 0xd4, 0xdb, 0x22, 0xf3,
		0x6d, 0x5c, 0xb6, 0xa5, 0xe5, 0xdb, 0xa4, 0xde, 0xc2, 0xb8, 0xd3, 0x67, 0xdc, 0xa4, 0xde, 0x26,
		0x49, 0x75, 0x5b, 0x91, 0x65, 0x95, 0x8b, 0x96, 0x5a, 0x7b, 0xdf, 0xba, 0xc1, 0x49, 0xf7, 0xbe,
		0xf6, 0x69, 0xf2, 0xa9, 0xe9, 0xad, 0xa5, 0xc2, 0xbd, 0xe8, 0xad, 0x65, 0xab, 0xd1, 0x46, 0x80,
		0x7f, 0x26, 0x46, 0x19, 0x01, 0xfe, 0x02, 0x87, 0x81, 0x00, 0x7f, 0x14, 0x23, 0x14, 0x23, 0x14,
		0x23, 0x53, 0xfb, 0x9d, 0x00, 0x7f, 0xd4, 0x22, 0xd4, 0x22, 0xd4, 0x22, 0xa5, 0xa5, 0x27, 0xc0,
		0x1f, 0xd1, 0xc8, 0xe0, 0x19, 0x22, 0xc0, 0x1f, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x63,
		0xed, 0x77, 0x02, 0xfc, 0x45, 0x9e, 0x95, 0x00, 0x7f, 0xae, 0x03, 0xae, 0x03, 0xae, 0x83, 0xbc,
		0x5f, 0x07, 0x04, 0xf8, 0x23, 0x21, 0x69, 0x2e, 0x2f, 0x01, 0xfe, 0xa5, 0x95, 0x90, 0x08, 0xf0,
		0x47, 0x39, 0xca, 0x31, 0x89, 0x27, 0xc0, 0x1f, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x17, 0x8d, 0xd4,
		0x13, 0xe0, 0x5f, 0x64, 0xbe, 0x8d, 0xcb, 0xb6, 0xb4, 0x7c, 0x9b, 0x00, 0x7f, 0x18, 0x77, 0xfa,
		0x8c, 0x9b, 0x00, 0x7f, 0xd1, 0x00, 0x7f, 0x3b, 0xbb, 0x6c, 0x3d, 0x1f, 0xdf, 0x4f, 0xbb, 0x2d,
		0x53, 0x1b, 0x30, 0xbd, 0x8d, 0x67, 0x4d, 0xe3, 0xad, 0x67, 0xb7, 0x1a, 0x1d, 0xb8, 0x6c, 0xd9,
		0x3c, 0x99, 0xf7, 0xe2, 0x5a, 0xda, 0x27, 0x39, 0x69, 0xca, 0xd5, 0x0f, 0xe4, 0x5b, 0x72, 0x4d,
		0xc6, 0xa4, 0x21, 0x17, 0x0d, 0xb9, 0x32, 0x52, 0x5b, 0x68, 0xc8, 0x45, 0x43, 0xae, 0xec, 0xa4,
		0x57, 0x1a, 0x72, 0xd1, 0x90, 0x6b, 0xfd, 0x40, 0x34, 0xe4, 0x92, 0x18, 0x90, 0x7c, 0x5d, 0xf2,
		0x75, 0xf3, 0xa5, 0x06, 0x91, 0xaf, 0xbb, 0x0e, 0x64, 0x70, 0x00, 0xe3, 0x00, 0xb6, 0x09, 0x94,
		0x52, 0x01, 0x27, 0x59, 0x90, 0x12, 0x06, 0xab, 0xe9, 0x0c, 0x90, 0xaf, 0xbb, 0x72, 0x68, 0x9c,
		0xbf, 0xe9, 0xc3, 0xfa, 0xd2, 0xdb, 0xe0, 0xfc, 0x4d, 0xb6, 0xf4, 0xe4, 0xeb, 0xe6, 0x63, 0x0f,
		0xe0, 0x03, 0xb6, 0xe5, 0x0c, 0x91, 0xaf, 0x0b, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0xb1,
		0xf6, 0x3b, 0xf9, 0xba, 0x22, 0xcf, 0x4a, 0xbe, 0x2e, 0xd7, 0x01, 0xd7, 0x01, 0xd7, 0x41, 0xde,
		0xaf, 0x03, 0xf2, 0x75, 0x91, 0x90, 0x34, 0x97, 0x97, 0x7c, 0xdd, 0xd2, 0x4a, 0x48, 0xe4, 0xeb,
		0xa2, 0x1c, 0xe5, 0x98, 0xc4, 0x93, 0xaf, 0x0b, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x8b, 0x46, 0xea,
		0xc9, 0xd7, 0x2d, 0x32, 0xdf, 0xc6, 0x65, 0x5b, 0x5a, 0xbe, 0x4d, 0xbe, 0x2e, 0x8c, 0x3b, 0x7d,
		0xc6, 0x4d, 0xbe, 0xae, 0x5a, 0xe6, 0xdb, 0x38, 0xc7, 0x2a, 0x57, 0xed, 0xb8, 0xbe, 0x06, 0x34,
		0xe3, 0x52, 0xe6, 0x5d, 0x34, 0xe3, 0xb2, 0xd5, 0x60, 0x23, 0xb8, 0x3f, 0x13, 0x83, 0x8c, 0xe0,
		0x7e, 0x81, 0xc3, 0x40, 0x70, 0x3f, 0x6a, 0x11, 0x6a, 0x11, 0x6a, 0x91, 0xa9, 0xfd, 0x4e, 0x70,
		0x3f, 0x4a, 0x11, 0x4a, 0x11, 0x4a, 0x91, 0xd2, 0xd2, 0x13, 0xdc, 0x8f, 0x60, 0x64, 0xf0, 0x0c,
		0x11, 0xdc, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0xb1, 0xf6, 0x3b, 0xc1, 0xfd, 0x22,
		0xcf, 0x4a, 0x70, 0x3f, 0xd7, 0x01, 0xd7, 0x01, 0xd7, 0x41, 0xde, 0xaf, 0x03, 0x82, 0xfb, 0x91,
		0x90, 0x34, 0x97, 0x97, 0xe0, 0xfe, 0xd2, 0x4a, 0x48, 0x04, 0xf7, 0xa3, 0x1c, 0xe5, 0x98, 0xc4,
		0x13, 0xdc, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x8b, 0x46, 0xea, 0x09, 0xee, 0x2f, 0x32, 0xdf,
		0xc6, 0x65, 0x5b, 0x5a, 0xbe, 0x4d, 0x70, 0x3f, 0x8c, 0x3b, 0x7d, 0xc6, 0x4d, 0x70, 0xbf, 0x60,
		0x70, 0xbf, 0xdd, 0xad, 0xb8, 0x56, 0xc5, 0xf6, 0xd3, 0x88, 0xcb, 0xd4, 0xe6, 0x4b, 0x6b, 0xd3,
		0x59, 0xd7, 0x86, 0x6b, 0xc5, 0x36, 0xa3, 0x09, 0x97, 0x1d, 0x1b, 0xc7, 0x9a, 0x16, 0x5c, 0xe3,
		0x3d, 0x92, 0x8b, 0x06, 0x5c, 0xf5, 0x99, 0x16, 0x66, 0x72, 0x2d, 0xb8, 0xea, 0xda, 0x8d, 0xd1,
		0x68, 0xc2, 0x65, 0x42, 0xad, 0xa1, 0x09, 0x97, 0x41, 0x84, 0xa4, 0x09, 0x57, 0x5a, 0x87, 0xd3,
		0x84, 0x04, 0x4b, 0x13, 0x2e, 0x9a, 0x70, 0xa5, 0x70, 0xc8, 0xa7, 0x03, 0xd1, 0x84, 0x4b, 0x62,
		0x40, 0xf2, 0x74, 0xc9, 0xd3, 0xcd, 0x97, 0x0a, 0x44, 0x9e, 0xee, 0x3a, 0x90, 0xc1, 0xf1, 0x8b,
		0xe3, 0xd7, 0x26, 0x50, 0x4a, 0x05, 0x9c, 0x64, 0x41, 0x4a, 0x18, 0xac, 0xa6, 0x33, 0x40, 0x9e,
		0xee, 0xca, 0xa1, 0x71, 0xfa, 0xa6, 0x0f, 0xeb, 0x4b, 0x6f, 0x83, 0xd3, 0x37, 0xd9, 0xd2, 0x93,
		0xa7, 0x9b, 0x8f, 0x3d, 0x80, 0xef, 0xd7, 0x96, 0x33, 0x44, 0x9e, 0x2e, 0x54, 0x1e, 0x2a, 0x0f,
		0x95, 0x87, 0xca, 0xc7, 0xda, 0xef, 0xe4, 0xe9, 0x8a, 0x3c, 0x2b, 0x79, 0xba, 0x5c, 0x07, 0x5c,
		0x07, 0x5c, 0x07, 0x79, 0xbf, 0x0e, 0xc8, 0xd3, 0x45, 0x42, 0xd2, 0x5c, 0x5e, 0xf2, 0x74, 0x4b,
		0x2b, 0x21, 0x91, 0xa7, 0x8b, 0x72, 0x94, 0x63, 0x12, 0x4f, 0x9e, 0x2e, 0xa4, 0x1e, 0x52, 0x0f,
		0xa9, 0x2f, 0x1a, 0xa9, 0x27, 0x4f, 0xb7, 0xc8, 0x7c, 0x1b, 0x97, 0x6d, 0x69, 0xf9, 0x36, 0x79,
		0xba, 0x30, 0xee, 0xf4, 0x19, 0x37, 0x79, 0xba, 0x2a, 0x99, 0x6f, 0x33, 0x59, 0x56, 0x79, 0x6a,
		0xc3, 0x55, 0xff, 0x34, 0xf9, 0xd4, 0x34, 0xe2, 0x52, 0xe1, 0x5e, 0x34, 0xe2, 0xb2, 0xd5, 0x68,
		0x23, 0xc0, 0x3f, 0x13, 0xa3, 0x8c, 0x00, 0x7f, 0x81, 0xc3, 0x40, 0x80, 0x3f, 0x8a, 0x11, 0x8a,
		0x11, 0x8a, 0x91, 0xa9, 0xfd, 0x4e, 0x80, 0x3f, 0x6a, 0x11, 0x6a, 0x11, 0x6a, 0x91, 0xd2, 0xd2,
		0x13, 0xe0, 0x8f, 0x68, 0x64, 0xf0, 0x0c, 0x11, 0xe0, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1,
		0xf2, 0xb1, 0xf6, 0x3b, 0x01, 0xfe, 0x22, 0xcf, 0x4a, 0x80, 0x3f, 0xd7, 0x01, 0xd7, 0x01, 0xd7,
		0x41, 0xde, 0xaf, 0x03, 0x02, 0xfc, 0x91, 0x90, 0x34, 0x97, 0x97, 0x00, 0xff, 0xd2, 0x4a, 0x48,
		0x04, 0xf8, 0xa3, 0x1c, 0xe5, 0x98, 0xc4, 0x13, 0xe0, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x8b,
		0x46, 0xea, 0x09, 0xf0, 0x2f, 0x32, 0xdf, 0xc6, 0x65, 0x5b, 0x5a, 0xbe, 0x4d, 0x80, 0x3f, 0x8c,
		0x3b, 0x7d, 0xc6, 0x4d, 0x80, 0xbf, 0x68, 0x80, 0xbf, 0xd5, 0xad, 0xb8, 0xd6, 0xc4, 0xf7, 0xd3,
		0x8c, 0xcb, 0xd4, 0x06, 0x4c, 0x6f, 0xe3, 0xd9, 0xd6, 0x8e, 0x6b, 0xf5, 0x56, 0xa3, 0x21, 0x97,
		0x2d, 0x9b, 0xc7, 0x96, 0x96, 0x5c, 0x4f, 0xfb, 0x24, 0x27, 0x4d, 0xb9, 0x26, 0x2d, 0xcd, 0x24,
		0x5b, 0x72, 0xe9, 0xb5, 0x49, 0xa3, 0x21, 0x97, 0x09, 0xd5, 0x86, 0x86, 0x5c, 0x06, 0x11, 0x92,
		0x86, 0x5c, 0x69, 0x1d, 0x4e, 0x13, 0x52, 0x2c, 0x0d, 0xb9, 0x68, 0xc8, 0x95, 0xc2, 0x21, 0x9f,
		0x0e, 0x44, 0x43, 0x2e, 0x89, 0x01, 0xc9, 0xd7, 0x25, 0x5f, 0x37, 0x5f, 0x6a, 0x10, 0xf9, 0xba,
		0xeb, 0x40, 0x06, 0x07, 0x30, 0x0e, 0x60, 0x9b, 0x40, 0x29, 0x15, 0x70, 0x92, 0x05, 0x29, 0x61,
		0xb0, 0x9a, 0xce, 0x00, 0xf9, 0xba, 0x2b, 0x87, 0xc6, 0xf9, 0x9b, 0x3e, 0xac, 0x2f, 0xbd, 0x0d,
		0xce, 0xdf, 0x64, 0x4b, 0x4f, 0xbe, 0x6e, 0x3e, 0xf6, 0x00, 0x3e, 0x60, 0x5b, 0xce, 0x10, 0xf9,
		0xba, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x1f, 0x6b, 0xbf, 0x93, 0xaf, 0x2b, 0xf2, 0xac,
		0xe4, 0xeb, 0x72, 0x1d, 0x70, 0x1d, 0x70, 0x1d, 0xe4, 0xfd, 0x3a, 0x20, 0x5f, 0x17, 0x09, 0x49,
		0x73, 0x79, 0xc9, 0xd7, 0x2d, 0xad, 0x84, 0x44, 0xbe, 0x2e, 0xca, 0x51, 0x8e, 0x49, 0x3c, 0xf9,
		0xba, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0xbe, 0x68, 0xa4, 0x9e, 0x7c, 0xdd, 0x22, 0xf3, 0x6d, 0x5c,
		0xb6, 0xa5, 0xe5, 0xdb, 0xe4, 0xeb, 0xc2, 0xb8, 0xd3, 0x67, 0xdc, 0xe4, 0xeb, 0xaa, 0x65, 0xbe,
		0x8d, 0x73, 0xac, 0x72, 0xd5, 0x8e, 0xeb, 0x6b, 0x40, 0x33, 0x2e, 0x65, 0xde, 0x45, 0x33, 0x2e,
		0x5b, 0x0d, 0x36, 0x82, 0xfb, 0x33, 0x31, 0xc8, 0x08, 0xee, 0x17, 0x38, 0x0c, 0x04, 0xf7, 0xa3,
		0x16, 0xa1, 0x16, 0xa1, 0x16, 0x99, 0xda, 0xef, 0x04, 0xf7, 0xa3, 0x14, 0xa1, 0x14, 0xa1, 0x14,
		0x29, 0x2d, 0x3d, 0xc1, 0xfd, 0x08, 0x46, 0x06, 0xcf, 0x10, 0xc1, 0xfd, 0x50, 0x79, 0xa8, 0x3c,
		0x54, 0x1e, 0x2a, 0x1f, 0x6b, 0xbf, 0x13, 0xdc, 0x2f, 0xf2, 0xac, 0x04, 0xf7, 0x73, 0x1d, 0x70,
		0x1d, 0x70, 0x1d, 0xe4, 0xfd, 0x3a, 0x20, 0xb8, 0x1f, 0x09, 0x49, 0x73, 0x79, 0x09, 0xee, 0x2f,
		0xad, 0x84, 0x44, 0x70, 0x3f, 0xca, 0x51, 0x8e, 0x49, 0x3c, 0xc1, 0xfd, 0x90, 0x7a, 0x48, 0x3d,
		0xa4, 0xbe, 0x68, 0xa4, 0x9e, 0xe0, 0xfe, 0x22, 0xf3, 0x6d, 0x5c, 0xb6, 0xa5, 0xe5, 0xdb, 0x04,
		0xf7, 0xc3, 0xb8, 0xd3, 0x67, 0xdc, 0x04, 0xf7, 0x0b, 0x06, 0xf7, 0xdb, 0xdd, 0x8a, 0x6b, 0x55,
		0x6c, 0x3f, 0x8d, 0xb8, 0x4c, 0x6d, 0xbe, 0xb4, 0x36, 0x9d, 0x75, 0x6d, 0xb8, 0x56, 0x6c, 0x33,
		0x9a, 0x70, 0xd9, 0xb1, 0x71, 0xac, 0x69, 0xc1, 0x35, 0xde, 0x23, 0x36, 0x37, 0xe0, 0xea, 0x85,
		0x91, 0xe7, 0x74, 0x3b, 0x2d, 0xbf, 0xf1, 0x30, 0x98, 0xc3, 0x9a, 0x7e, 0xfb, 0xad, 0xa5, 0x11,
		0x69, 0xbe, 0x45, 0xf3, 0xad, 0x8c, 0xd4, 0x15, 0x9a, 0x6f, 0xd1, 0x7c, 0x2b, 0x3b, 0xa9, 0x95,
		0xe6, 0x5b, 0x34, 0xdf, 0x5a, 0x3f, 0x10, 0xcd, 0xb7, 0x24, 0x06, 0x24, 0x3f, 0x97, 0xfc, 0xdc,
		0x7c, 0xa9, 0x3f, 0xe4, 0xe7, 0xae, 0x03, 0x19, 0x1c, 0xbe, 0x38, 0x7c, 0x6d, 0x02, 0xa5, 0x54,
		0xc0, 0x49, 0x16, 0xa4, 0x84, 0xc1, 0x6a, 0x3a, 0x03, 0xe4, 0xe7, 0xae, 0x1c, 0x1a, 0x67, 0x6f,
		0xfa, 0xb0, 0xbe, 0xf4, 0x36, 0x38, 0x7b, 0x93, 0x2d, 0x3d, 0xf9, 0xb9, 0xf9, 0xd8, 0x03, 0xf8,
		0x7c, 0x6d, 0x39, 0x43, 0xe4, 0xe7, 0x42, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0xac, 0xfd,
		0x4e, 0x7e, 0xae, 0xc8, 0xb3, 0x92, 0x9f, 0xcb, 0x75, 0xc0, 0x75, 0xc0, 0x75, 0x90, 0xf7, 0xeb,
		0x80, 0xfc, 0x5c, 0x24, 0x24, 0xcd, 0xe5, 0x25, 0x3f, 0xb7, 0xb4, 0x12, 0x12, 0xf9, 0xb9, 0x28,
		0x47, 0x39, 0x26, 0xf1, 0xe4, 0xe7, 0x42, 0xea, 0x21, 0xf5, 0x90, 0xfa, 0xa2, 0x91, 0x7a, 0xf2,
		0x73, 0x8b, 0xcc, 0xb7, 0x71, 0xd9, 0x96, 0x96, 0x6f, 0x93, 0x9f, 0x0b, 0xe3, 0x4e, 0x9f, 0x71,
		0x93, 0x9f, 0x9b, 0x20, 0xe3, 0x6d, 0x31, 0xc3, 0x2a, 0x0f, 0xad, 0xb7, 0x2e, 0xc2, 0xc8, 0x3b,
		0x1f, 0x7e, 0xe4, 0x93, 0xee, 0x7d, 0x8d, 0xc6, 0x5b, 0x2a, 0x9c, 0x8b, 0xc6, 0x5b, 0xb6, 0x1a,
		0x6b, 0x04, 0xf6, 0x67, 0x62, 0x8c, 0x11, 0xd8, 0x2f, 0x70, 0x18, 0x08, 0xec, 0x47, 0x29, 0x42,
		0x29, 0x42, 0x29, 0x32, 0xb5, 0xdf, 0x09, 0xec, 0x47, 0x25, 0x42, 0x25, 0x42, 0x25, 0x52, 0x5a,
		0x7a, 0x02, 0xfb, 0x11, 0x8b, 0x0c, 0x9e, 0x21, 0x02, 0xfb, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x3c,
		0x54, 0x3e, 0xd6, 0x7e, 0x27, 0xb0, 0x5f, 0xe4, 0x59, 0x09, 0xec, 0xe7, 0x3a, 0xe0, 0x3a, 0xe0,
		0x3a, 0xc8, 0xfb, 0x75, 0x40, 0x60, 0x3f, 0x12, 0x92, 0xe6, 0xf2, 0x12, 0xd8, 0x5f, 0x5a, 0x09,
		0x89, 0xc0, 0x7e, 0x94, 0xa3, 0x1c, 0x93, 0x78, 0x02, 0xfb, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x7d,
		0xd1, 0x48, 0x3d, 0x81, 0xfd, 0x45, 0xe6, 0xdb, 0xb8, 0x6c, 0x4b, 0xcb, 0xb7, 0x09, 0xec, 0x87,
		0x71, 0xa7, 0xcf, 0xb8, 0x09, 0xec, 0x17, 0x0b, 0xec, 0xb7, 0xb2, 0xed, 0xd6, 0x33, 0x71, 0xfd,
		0x34, 0xdd, 0x32, 0xb5, 0xf1, 0xd2, 0xd9, 0x70, 0xb6, 0xb4, 0xdc, 0x5a, 0xbf, 0xc5, 0x68, 0xb8,
		0x65, 0xc3, 0xa6, 0xc9, 0xba, 0xdd, 0xd6, 0xfc, 0xfe, 0xc8, 0x51, 0xb3, 0xad, 0xba, 0x78, 0xb3,
		0xad, 0x3a, 0xcd, 0xb6, 0x68, 0xb6, 0x95, 0x95, 0xa2, 0x42, 0xb3, 0x2d, 0x9a, 0x6d, 0x65, 0x27,
		0xaf, 0xd2, 0x6c, 0x8b, 0x66, 0x5b, 0xeb, 0x07, 0xa2, 0xd9, 0x96, 0xc4, 0x80, 0xe4, 0xe4, 0x92,
		0x93, 0x9b, 0x2f, 0xc5, 0x87, 0x9c, 0xdc, 0x75, 0x20, 0x83, 0x93, 0x17, 0x27, 0xaf, 0x4d, 0xa0,
		0x94, 0x0a, 0x38, 0xc9, 0x82, 0x94, 0x30, 0x58, 0x4d, 0x67, 0x80, 0x9c, 0xdc, 0x95, 0x43, 0xe3,
		0xe0, 0x4d, 0x1f, 0xd6, 0x97, 0xde, 0x06, 0x07, 0x6f, 0xb2, 0xa5, 0x27, 0x27, 0x37, 0x1f, 0x7b,
		0x00, 0x3f, 0xaf, 0x2d, 0x67, 0x88, 0x9c, 0x5c, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x8f,
		0xb5, 0xdf, 0xc9, 0xc9, 0x15, 0x79, 0x56, 0x72, 0x72, 0xb9, 0x0e, 0xb8, 0x0e, 0xb8, 0x0e, 0xf2,
		0x7e, 0x1d, 0x90, 0x93, 0x8b, 0x84, 0xa4, 0xb9, 0xbc, 0xe4, 0xe4, 0x96, 0x56, 0x42, 0x22, 0x27,
		0x17, 0xe5, 0x28, 0xc7, 0x24, 0x9e, 0x9c, 0x5c, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x5f, 0x34, 0x52,
		0x4f, 0x4e, 0x6e, 0x91, 0xf9, 0x36, 0x2e, 0xdb, 0xd2, 0xf2, 0x6d, 0x72, 0x72, 0x61, 0xdc, 0xe9,
		0x33, 0x6e, 0x72, 0x72, 0xd5, 0xb3, 0xdd, 0xea, 0xb9, 0x6b, 0xb6, 0x55, 0xa7, 0xd9, 0x96, 0x0a,
		0xe7, 0xa2, 0xd9, 0x96, 0xad, 0xc6, 0x1a, 0x81, 0xfd, 0x99, 0x18, 0x63, 0x04, 0xf6, 0x0b, 0x1c,
		0x06, 0x02, 0xfb, 0x51, 0x8a, 0x50, 0x8a, 0x50, 0x8a, 0x4c, 0xed, 0x77, 0x02, 0xfb, 0x51, 0x89,
		0x50, 0x89, 0x50, 0x89, 0x94, 0x96, 0x9e, 0xc0, 0x7e, 0xc4, 0x22, 0x83, 0x67, 0x88, 0xc0, 0x7e,
		0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x8f, 0xb5, 0xdf, 0x09, 0xec, 0x17, 0x79, 0x56, 0x02,
		0xfb, 0xb9, 0x0e, 0xb8, 0x0e, 0xb8, 0x0e, 0xf2, 0x7e, 0x1d, 0x10, 0xd8, 0x8f, 0x84, 0xa4, 0xb9,
		0xbc, 0x04, 0xf6, 0x97, 0x56, 0x42, 0x22, 0xb0, 0x1f, 0xe5, 0x28, 0xc7, 0x24, 0x9e, 0xc0, 0x7e,
		0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x5f, 0x34, 0x52, 0x4f, 0x60, 0x7f, 0x91, 0xf9, 0x36, 0x2e, 0xdb,
		0xd2, 0xf2, 0x6d, 0x02, 0xfb, 0x61, 0xdc, 0xe9, 0x33, 0x6e, 0x02, 0xfb, 0xc5, 0x02, 0xfb, 0xed,
		0x6f, 0xb6, 0x55, 0xa7, 0xd9, 0x56, 0x2a, 0x1b, 0x2f, 0x9d, 0x0d, 0x67, 0x65, 0xb3, 0xad, 0x3a,
		0xcd, 0xb6, 0x6c, 0xdb, 0x34, 0x56, 0x35, 0xdb, 0xaa, 0x5b, 0xdd, 0x6c, 0x4b, 0x2b, 0x2f, 0x48,
		0x24, 0x0f, 0x48, 0xac, 0xad, 0x56, 0x95, 0xb6, 0x5a, 0x06, 0xb5, 0x16, 0xda, 0x6a, 0x3d, 0x7d,
		0x72, 0xed, 0xb6, 0x5a, 0x03, 0x6b, 0xe1, 0xde, 0x93, 0x6b, 0xa8, 0x35, 0x1e, 0x4f, 0xa6, 0x95,
		0xd6, 0x0e, 0xad, 0xb4, 0x32, 0x10, 0x4b, 0x69, 0xa5, 0x65, 0x01, 0x2b, 0x16, 0x13, 0x33, 0x0d,
		0x04, 0xa8, 0x09, 0x05, 0xa4, 0x69, 0x70, 0x4c, 0x8d, 0x5b, 0x6d, 0x42, 0xd5, 0x9c, 0x31, 0xb1,
		0x92, 0xc2, 0xbd, 0xb9, 0x61, 0x81, 0x3f, 0xe0, 0x0f, 0xf8, 0xb3, 0x0a, 0xfe, 0xfc, 0xa6, 0x17,
		0x44, 0x7e, 0xf4, 0x10, 0x7a, 0xb7, 0x92, 0x10, 0x28, 0xe0, 0xad, 0xa9, 0x9c, 0x8c, 0x3f, 0xda,
		0x7b, 0xb7, 0x67, 0xa0, 0x32, 0xc2, 0xd1, 0xc7, 0x93, 0xeb, 0x8b, 0xc1, 0x7f, 0x2e, 0xff, 0x38,
		0x3f, 0x96, 0xda, 0xca, 0x43, 0x41, 0xbb, 0x27, 0xea, 0x51, 0x32, 0x14, 0x1c, 0x70, 0xf1, 0xe5,
		0xf2, 0xf8, 0xfa, 0xfc, 0xec, 0xf4, 0xe4, 0xc3, 0x1f, 0xd7, 0x27, 0xe7, 0xdf, 0xea, 0x15, 0x1b,
		0x23, 0x26, 0x0c, 0x3d, 0xfb, 0xe9, 0xde, 0xb7, 0xf3, 0xcf, 0x83, 0xa7, 0xae, 0x5d, 0x7f, 0xfd,
		0x7c, 0xf2, 0xe1, 0xe8, 0xe2, 0xb2, 0x54, 0x4f, 0x7f, 0xf2, 0xf9, 0x9f, 0x17, 0x97, 0x47, 0x97,
		0xc7, 0xd7, 0x17, 0xe7, 0x1f, 0x4b, 0xba, 0xec, 0x9f, 0xbe, 0x9e, 0x5e, 0x96, 0x6e, 0xe1, 0xbf,
		0x9d, 0x7f, 0xfe, 0x56, 0xbb, 0xfe, 0x78, 0x7a, 0xf6, 0xaf, 0x8b, 0xf3, 0xe3, 0x0f, 0x65, 0x7a,
		0xf2, 0x05, 0xb0, 0xab, 0x95, 0x6a, 0xd7, 0x57, 0x07, 0xbb, 0xfe, 0xdb, 0xf9, 0xe9, 0x45, 0xf9,
		0x9e, 0xfa, 0xf8, 0xdb, 0xf9, 0xe7, 0x52, 0x42, 0x7b, 0x99, 0x1e, 0x7a, 0x08, 0xe8, 0xa7, 0x47,
		0xef, 0x8f, 0x4f, 0x8f, 0x7f, 0x2b, 0xf7, 0x7d, 0x5e, 0xb6, 0xdd, 0x3e, 0xb9, 0xcf, 0xeb, 0xe5,
		0xbc, 0xcf, 0x87, 0x1b, 0xbf, 0x8c, 0xd7, 0xf9, 0x70, 0xc9, 0xcb, 0x7c, 0xe2, 0x9f, 0x36, 0x7e,
		0x09, 0x9f, 0xbe, 0xac, 0x76, 0x9b, 0xa1, 0xf5, 0x16, 0x19, 0xe9, 0x2a, 0x6b, 0x5d, 0x2d, 0x13,
		0xcd, 0xdc, 0x0b, 0xdc, 0x9b, 0x96, 0xd7, 0x94, 0x53, 0xcb, 0x27, 0x03, 0x6a, 0xaa, 0x84, 0xc2,
		0x75, 0x3d, 0xd0, 0xdd, 0x13, 0x8d, 0x88, 0xee, 0x8e, 0xee, 0xbe, 0x79, 0xbf, 0xe1, 0x76, 0xdc,
		0x1a, 0x17, 0x53, 0x92, 0xa9, 0x55, 0x3a, 0x5b, 0x34, 0x49, 0xa2, 0x2e, 0xa9, 0x50, 0xb1, 0x63,
		0x40, 0x0f, 0xd0, 0xcb, 0x2b, 0xe8, 0x49, 0x15, 0x27, 0xae, 0xf8, 0x41, 0x2f, 0x72, 0x5b, 0x12,
		0x4c, 0x69, 0x69, 0x07, 0x3f, 0x0d, 0x2d, 0x5b, 0xe3, 0x7c, 0x47, 0xba, 0xc6, 0xf9, 0x0e, 0x35,
		0xce, 0x05, 0x6d, 0x22, 0x6a, 0x9c, 0x9b, 0xb7, 0xe9, 0xa4, 0x32, 0x68, 0xc4, 0xf3, 0x4f, 0xcd,
		0x95, 0x09, 0x36, 0x50, 0x1e, 0xd8, 0x50, 0x8e, 0xa9, 0x81, 0x6c, 0x5e, 0x93, 0x39, 0xa5, 0x86,
		0x13, 0x0a, 0x4d, 0xe7, 0x90, 0xa6, 0x91, 0x3e, 0x68, 0x20, 0x67, 0xd4, 0x68, 0xae, 0x68, 0x5a,
		0x4b, 0x6a, 0xba, 0x9c, 0x6f, 0x2a, 0x6b, 0x6b, 0x69, 0xaa, 0xe5, 0x55, 0x81, 0x1a, 0xe8, 0x84,
		0x5e, 0xc3, 0xf3, 0xef, 0x4d, 0x70, 0xcc, 0xe9, 0xc8, 0x50, 0x4c, 0x28, 0x26, 0x14, 0x13, 0x8a,
		0x09, 0xc5, 0x84, 0x62, 0x42, 0x31, 0xa1, 0x98, 0x50, 0xcc, 0x72, 0x52, 0x4c, 0xa7, 0x1b, 0x4e,
		0xb2, 0xd9, 0xcd, 0xb1, 0xcd, 0xd9, 0x37, 0x81, 0x78, 0x42, 0x3c, 0x21, 0x9e, 0x10, 0x4f, 0x88,
		0x27, 0xc4, 0x13, 0xe2, 0x09, 0xf1, 0x84, 0x78, 0x96, 0x8b, 0x78, 0xf6, 0x46, 0x97, 0xa9, 0x74,
		0x6f, 0xf0, 0xc1, 0xa8, 0x50, 0x4b, 0xa8, 0x25, 0xd4, 0x12, 0x6a, 0x09, 0xb5, 0x84, 0x5a, 0x42,
		0x2d, 0xa1, 0x96, 0x50, 0xcb, 0x1c, 0x51, 0x4b, 0x0a, 0xd4, 0xae, 0xaa, 0x35, 0x1a, 0xb9, 0x91,
		0xb7, 0x2d, 0x14, 0x06, 0xbe, 0x25, 0x56, 0x71, 0x74, 0xf0, 0xa9, 0xc6, 0x85, 0x68, 0xbd, 0x1e,
		0x55, 0x68, 0x33, 0xdb, 0x19, 0x99, 0x97, 0x9e, 0x55, 0x2f, 0x71, 0x9d, 0x4e, 0xc5, 0xd9, 0x7e,
		0xcf, 0x73, 0xda, 0xfd, 0x56, 0xe4, 0x77, 0x5b, 0x9e, 0x33, 0x98, 0xf4, 0x9e, 0x7e, 0xf9, 0xd9,
		0x15, 0x63, 0x66, 0x5c, 0x8b, 0x76, 0x87, 0x5a, 0xb4, 0x06, 0x0d, 0x43, 0x6a, 0xd1, 0x3e, 0x7d,
		0x72, 0xed, 0x5a, 0xb4, 0x8d, 0xc9, 0x9e, 0x15, 0xca, 0x90, 0x1a, 0x8f, 0x47, 0x7e, 0x54, 0x7a,
		0xca, 0x0e, 0xf9, 0x51, 0xe4, 0x47, 0xad, 0x1f, 0x48, 0x2a, 0x8f, 0x7c, 0x69, 0xff, 0xca, 0xe4,
		0x93, 0x3f, 0x3d, 0xb0, 0x6c, 0x5e, 0xb9, 0x21, 0x93, 0x18, 0xf1, 0x18, 0xf1, 0x38, 0x3d, 0x08,
		0x92, 0x55, 0x17, 0xec, 0x17, 0x8f, 0xe5, 0xf2, 0xd6, 0x97, 0x98, 0xc4, 0x2e, 0xb2, 0x8a, 0xc5,
		0xb2, 0xca, 0xb2, 0x09, 0xb7, 0x2d, 0x42, 0x24, 0xc5, 0x0c, 0xeb, 0xaf, 0x3d, 0xef, 0xd3, 0xf8,
		0xf3, 0x9d, 0x0f, 0x3e, 0xde, 0xf5, 0xf8, 0x1e, 0xc8, 0x63, 0x61, 0x99, 0x01, 0x34, 0xc9, 0x55,
		0x95, 0xd1, 0xbf, 0x60, 0x60, 0xfb, 0xb0, 0x7d, 0xd8, 0xbe, 0xcc, 0x76, 0x13, 0x32, 0xe7, 0xcd,
		0x98, 0xf5, 0xc2, 0x07, 0x1e, 0x4e, 0x0e, 0x27, 0x87, 0x93, 0xcb, 0x02, 0xc8, 0x74, 0x40, 0xb7,
		0xd5, 0xea, 0xfc, 0xf5, 0xc4, 0xc9, 0xdc, 0x9e, 0xfc, 0xfe, 0x9a, 0xb6, 0x71, 0x59, 0x7a, 0x2b,
		0xe1, 0x6d, 0x60, 0x48, 0x5a, 0x30, 0x24, 0x31, 0x18, 0x83, 0x35, 0x93, 0xf0, 0x66, 0x1e, 0xe6,
		0x4c, 0xc3, 0x5d, 0x6a, 0xb0, 0x97, 0x1a, 0xfc, 0xa5, 0x02, 0x83, 0xb2, 0x70, 0x28, 0x0c, 0x8b,
		0xe6, 0x24, 0x8b, 0x14, 0xa4, 0x0b, 0x43, 0x12, 0x86, 0xfc, 0x82, 0xd1, 0x53, 0x5b, 0x53, 0xea,
		0x18, 0xd8, 0xd0, 0xdb, 0xa2, 0x0c, 0xdb, 0x9c, 0xee, 0x71, 0x7c, 0x73, 0xd7, 0x15, 0x11, 0x3f,
		0x04, 0x25, 0x35, 0x11, 0x8d, 0x48, 0xa7, 0x13, 0xee, 0x5a, 0x54, 0x90, 0x6c, 0x91, 0x6e, 0xcc,
		0x6a, 0xaa, 0x62, 0x35, 0x61, 0x35, 0x61, 0x35, 0x61, 0x35, 0x61, 0x35, 0x61, 0x35, 0x61, 0x35,
		0x61, 0x35, 0x61, 0x35, 0x61, 0x35, 0xe5, 0xc4, 0x6a, 0x92, 0x24, 0xd8, 0x86, 0x8d, 0x26, 0x8d,
		0xd8, 0x6c, 0x03, 0x36, 0x13, 0x61, 0x08, 0xf1, 0x77, 0x99, 0xb5, 0x41, 0x08, 0xc7, 0xda, 0x97,
		0x52, 0x36, 0x21, 0x08, 0x32, 0xd6, 0xb6, 0xa8, 0x95, 0x2d, 0x1e, 0x84, 0x50, 0x25, 0x08, 0xc1,
		0x02, 0xfa, 0x48, 0x10, 0x42, 0xfa, 0xd6, 0x30, 0x21, 0xc7, 0x84, 0x1c, 0x23, 0xd4, 0x21, 0xd4,
		0x11, 0x72, 0x0c, 0xd7, 0xcf, 0x15, 0xd7, 0x97, 0x32, 0x26, 0xcd, 0x90, 0x7d, 0x01, 0xfb, 0x91,
		0xdc, 0x6e, 0xa9, 0xbd, 0x92, 0x75, 0xa2, 0xf7, 0xe2, 0xee, 0x48, 0x2d, 0xe7, 0xfb, 0x85, 0xc1,
		0xf5, 0x1f, 0x5c, 0xc9, 0x43, 0xd7, 0xc6, 0x78, 0xde, 0x9d, 0xe1, 0x1c, 0x25, 0x1c, 0xe3, 0xd4,
		0xef, 0x45, 0x47, 0x51, 0xa4, 0x46, 0x65, 0x2b, 0x9f, 0xfc, 0xe0, 0xb8, 0xe5, 0x0d, 0x2e, 0xd5,
		0x9e, 0x1a, 0xe1, 0xaa, 0x7c, 0x72, 0x7f, 0xce, 0x8c, 0xb0, 0xfb, 0xb6, 0x56, 0xab, 0x1f, 0xd4,
		0x6a, 0x3b, 0x07, 0x7b, 0x07, 0x3b, 0x87, 0xfb, 0xfb, 0xbb, 0xf5, 0x5d, 0x85, 0x9a, 0x29, 0x95,
		0xb3, 0xb0, 0xe9, 0x85, 0x5e, 0xf3, 0xfd, 0x60, 0x7a, 0x82, 0x7e, 0xab, 0x65, 0x74, 0x15, 0x34,
		0x4f, 0x9f, 0xd4, 0xa9, 0x53, 0x38, 0x62, 0x12, 0x47, 0x2b, 0xd9, 0x49, 0x8a, 0x7f, 0x1e, 0xe2,
		0xfd, 0x66, 0xcc, 0xb5, 0x52, 0x5d, 0x23, 0xcd, 0xb5, 0x49, 0xb0, 0x24, 0x3a, 0x4b, 0x11, 0x6f,
		0x09, 0x36, 0x4f, 0x68, 0x8c, 0xc9, 0xac, 0xb8, 0xdd, 0x6e, 0xeb, 0x21, 0x69, 0xbd, 0xed, 0x27,
		0x27, 0xec, 0xec, 0xab, 0x63, 0x2e, 0x5d, 0x32, 0xa1, 0x29, 0xb1, 0xf5, 0xa7, 0x62, 0xdd, 0xcd,
		0x5a, 0x6f, 0x61, 0xb7, 0xd3, 0x4a, 0xb2, 0xce, 0x8a, 0xe6, 0x99, 0xb6, 0xf9, 0xa5, 0x6d, 0x5e,
		0x2d, 0x9a, 0x4f, 0xc3, 0x07, 0xcf, 0xe8, 0x38, 0x27, 0x95, 0x5e, 0x54, 0xf3, 0x3c, 0xf4, 0xf2,
		0x39, 0x14, 0x35, 0x52, 0x65, 0x01, 0x43, 0x47, 0xa8, 0xd0, 0xd8, 0xd2, 0x52, 0xca, 0x83, 0x98,
		0xc2, 0x20, 0xa6, 0x24, 0xe8, 0x6d, 0xf9, 0x74, 0x38, 0xa0, 0xaa, 0x0a, 0x59, 0x69, 0x8e, 0xd4,
		0x3c, 0xc7, 0xfb, 0xd9, 0xed, 0x84, 0x91, 0x6e, 0x0b, 0x85, 0xe9, 0xfe, 0x59, 0x3d, 0xac, 0x6a,
		0xb9, 0x96, 0x27, 0xc5, 0xf1, 0xcb, 0xf1, 0xff, 0x3b, 0xfe, 0x70, 0x79, 0xfd, 0xe5, 0xec, 0xeb,
		0xe5, 0xb1, 0x66, 0xbd, 0xa2, 0x9d, 0x82, 0xd4, 0x2b, 0x52, 0x3c, 0xa7, 0xd2, 0x4a, 0x61, 0xfe,
		0x0a, 0x16, 0xa9, 0x9d, 0xe3, 0x6c, 0x6c, 0x7b, 0x6d, 0x29, 0x6f, 0xe9, 0x64, 0x8e, 0x8e, 0xa4,
		0x13, 0x0d, 0x06, 0xd6, 0xd8, 0x3d, 0x93, 0xcb, 0xad, 0xa6, 0x31, 0xc6, 0x71, 0xd0, 0x6f, 0x0f,
		0x1e, 0xee, 0xd1, 0xe2, 0x12, 0x6c, 0x93, 0x69, 0xf3, 0xdb, 0x46, 0x70, 0x72, 0x7e, 0x58, 0x70,
		0x12, 0x9c, 0x04, 0x27, 0xc1, 0xc9, 0x1c, 0xe2, 0xa4, 0x30, 0x8f, 0x14, 0xe1, 0x8f, 0x00, 0x19,
		0x40, 0x56, 0x5e, 0x20, 0x6b, 0x79, 0xee, 0x6d, 0xe8, 0xdd, 0x4a, 0x80, 0x97, 0x46, 0x37, 0x81,
		0xca, 0xf9, 0x54, 0x3d, 0x1d, 0x2d, 0xc4, 0xbb, 0xb0, 0xd3, 0x8f, 0xfc, 0xe0, 0x6e, 0x7c, 0xb6,
		0xa7, 0xdf, 0x1e, 0xe3, 0x6d, 0xd3, 0xbb, 0xf5, 0x03, 0x3f, 0xf2, 0x3b, 0x41, 0x6f, 0xfd, 0x8f,
		0xa6, 0x3f, 0x19, 0x0a, 0xa6, 0xa9, 0xae, 0x8f, 0x96, 0xc3, 0x64, 0x3a, 0x8a, 0xb6, 0xe3, 0xe4,
		0x69, 0x24, 0x03, 0x0e, 0x94, 0xe9, 0xe0, 0xb3, 0x8e, 0x14, 0xa1, 0xe8, 0xc3, 0x7e, 0xcf, 0x0b,
		0x75, 0xf1, 0x42, 0x30, 0xc6, 0x65, 0x16, 0xcc, 0x3a, 0xa3, 0xa7, 0x75, 0x6e, 0x24, 0xba, 0x3c,
		0x1a, 0x89, 0x67, 0x99, 0x03, 0xb6, 0xe1, 0x4c, 0xe6, 0xcb, 0xc1, 0x9d, 0x0a, 0x13, 0x11, 0xb6,
		0xd4, 0x44, 0x2c, 0x34, 0x98, 0x08, 0x4c, 0x04, 0x26, 0x02, 0x13, 0x81, 0x89, 0xc0, 0x44, 0x60,
		0x22, 0xb9, 0x64, 0x22, 0x05, 0x0c, 0x22, 0x9a, 0x09, 0xc7, 0x50, 0x2f, 0xa8, 0xa2, 0x14, 0xba,
		0x32, 0x78, 0xe7, 0xf3, 0xe1, 0x1b, 0x2b, 0x55, 0x47, 0x49, 0x10, 0x47, 0x94, 0x28, 0x06, 0x47,
		0x25, 0xcf, 0x4a, 0x2b, 0xaf, 0x4a, 0x3b, 0x46, 0xa0, 0x4a, 0x8c, 0x40, 0xa6, 0x98, 0x48, 0x8c,
		0x40, 0xf2, 0xfd, 0x43, 0x8c, 0x00, 0x86, 0x1a, 0x86, 0x9a, 0x8d, 0x86, 0x1a, 0xbe, 0x2f, 0x62,
		0x04, 0xc0, 0x49, 0x70, 0x12, 0x9c, 0x04, 0x27, 0x0d, 0xe0, 0x24, 0x31, 0x02, 0x00, 0x19, 0x40,
		0x66, 0x13, 0x90, 0xa1, 0xcc, 0x9b, 0x58, 0x1f, 0x94, 0x79, 0xbd, 0x5d, 0x89, 0x32, 0x2f, 0x05,
		0x6c, 0xc4, 0x08, 0xac, 0x9e, 0x23, 0x62, 0x04, 0x60, 0x22, 0x30, 0x11, 0x98, 0x08, 0x4c, 0x04,
		0x26, 0x02, 0x13, 0x81, 0x89, 0x08, 0x31, 0x91, 0x82, 0xc7, 0x08, 0xa8, 0x56, 0x7c, 0xd2, 0x0d,
		0x11, 0x50, 0xa8, 0xe5, 0x54, 0x8e, 0x4a, 0x23, 0xc9, 0xeb, 0x69, 0x08, 0x2c, 0x47, 0xaa, 0xf5,
		0x46, 0x7a, 0xc3, 0x02, 0x52, 0x4e, 0xa7, 0x3b, 0xbc, 0x63, 0x15, 0x4a, 0x8e, 0x2c, 0x0c, 0x50,
		0x8c, 0xaa, 0x23, 0xc9, 0x6a, 0x46, 0x16, 0xa7, 0xe8, 0x48, 0xa2, 0x9a, 0x8d, 0xd4, 0x1c, 0x31,
		0x6f, 0x3c, 0x4a, 0xc5, 0x13, 0xa9, 0x15, 0x41, 0x2d, 0x7e, 0x38, 0x91, 0x52, 0x91, 0x52, 0x4b,
		0xa3, 0x89, 0x46, 0x2d, 0x78, 0x3a, 0x7f, 0x05, 0x3a, 0x8d, 0x7e, 0x16, 0x1a, 0xfa, 0x8c, 0x47,
		0xd3, 0xf7, 0x89, 0xef, 0xa0, 0xda, 0x08, 0x54, 0x23, 0x2e, 0xaf, 0x68, 0xa3, 0x55, 0x4d, 0x38,
		0xaf, 0x9a, 0x4d, 0xdf, 0x0f, 0xa2, 0xb7, 0x02, 0x8a, 0x8d, 0x8e, 0xd1, 0xff, 0xc5, 0x0d, 0xee,
		0x06, 0x1f, 0xe6, 0xbb, 0xd6, 0x72, 0x0a, 0x98, 0xe6, 0x9f, 0xfc, 0x40, 0xb0, 0xc0, 0xbf, 0x6c,
		0x4d, 0xf4, 0x6f, 0x6e, 0xab, 0xef, 0x09, 0x8e, 0xf7, 0x31, 0x74, 0x1b, 0x03, 0x3e, 0xfd, 0x9b,
		0x7f, 0xe7, 0x8f, 0x34, 0x21, 0x2b, 0xda, 0x52, 0x7e, 0x72, 0x7f, 0x5a, 0xbf, 0x04, 0xd5, 0xfd,
		0x7d, 0x8b, 0x17, 0x21, 0x23, 0x81, 0xe6, 0xca, 0xe6, 0xe0, 0x3e, 0xbf, 0xe7, 0xde, 0xb4, 0x3c,
		0xa7, 0xeb, 0x79, 0xa1, 0xe3, 0xf6, 0x9c, 0x5b, 0xbf, 0x15, 0x79, 0xa1, 0x40, 0x74, 0xdf, 0xea,
		0x71, 0xf5, 0xa9, 0x8c, 0x4e, 0x73, 0x06, 0xe8, 0x0c, 0x74, 0xa6, 0xb4, 0x74, 0x46, 0xbf, 0xb9,
		0x81, 0x66, 0x33, 0x83, 0x74, 0x00, 0x2d, 0xf4, 0xba, 0x2d, 0xb7, 0x31, 0x05, 0x1e, 0x7d, 0x24,
		0x5b, 0x1c, 0x10, 0x08, 0x03, 0xc2, 0x80, 0x30, 0x20, 0xcc, 0x06, 0xb5, 0x2a, 0x1b, 0xa7, 0xd9,
		0xbc, 0xd3, 0x21, 0xe5, 0xdc, 0xda, 0xde, 0xb9, 0x1b, 0xfd, 0x38, 0x1b, 0xbd, 0x35, 0xd9, 0xb5,
		0x79, 0xcc, 0xae, 0x45, 0x0d, 0x17, 0x84, 0x74, 0xd4, 0xf0, 0xe4, 0xfc, 0x0b, 0x35, 0x1c, 0xee,
		0x05, 0xf7, 0x4a, 0xb8, 0x5f, 0x50, 0xc3, 0x67, 0x3e, 0x08, 0x6a, 0xb8, 0xd6, 0x1f, 0xd4, 0x70,
		0x1b, 0x16, 0x01, 0x35, 0x7c, 0x69, 0x9a, 0x51, 0xc3, 0xa1, 0x33, 0xd0, 0x19, 0xa4, 0x24, 0x3b,
		0xa5, 0x24, 0xd4, 0x70, 0x20, 0x0c, 0x08, 0x03, 0xc2, 0x50, 0xc3, 0xd7, 0x6c, 0x0a, 0x1b, 0xd4,
		0xf0, 0x54, 0xb3, 0x48, 0xe6, 0xc4, 0x70, 0xf2, 0x48, 0x62, 0xad, 0x90, 0xe9, 0x54, 0x92, 0xd9,
		0x35, 0x49, 0x33, 0x99, 0x24, 0x61, 0x44, 0xbe, 0x5a, 0x24, 0x3e, 0xa9, 0x23, 0x5b, 0xa4, 0x8e,
		0x2c, 0x50, 0xb9, 0xa4, 0xa9, 0x23, 0x6e, 0x3f, 0xfa, 0xe1, 0x74, 0xdd, 0x5e, 0x6f, 0x3c, 0x85,
		0x8a, 0x2e, 0xb3, 0xf9, 0x61, 0xd4, 0x5c, 0x67, 0x3b, 0x24, 0x92, 0xa4, 0xc9, 0x07, 0xcb, 0xe4,
		0x3a, 0x53, 0xe6, 0x79, 0x4f, 0xa6, 0xd6, 0x24, 0x37, 0x5f, 0x6d, 0x8f, 0xcf, 0xc1, 0xf5, 0x5b,
		0x0b, 0x5c, 0xe4, 0x4d, 0xaf, 0xd7, 0x08, 0xfd, 0xae, 0x12, 0x3f, 0x9b, 0xa9, 0x4d, 0xf7, 0x34,
		0x08, 0x67, 0x9e, 0x33, 0x5f, 0xb0, 0x33, 0xdf, 0x8b, 0x42, 0x3f, 0xb8, 0xcb, 0xfb, 0x49, 0xf7,
		0x02, 0xf7, 0xa6, 0xe5, 0x69, 0xdc, 0xed, 0x93, 0x01, 0x92, 0x86, 0x2b, 0x3c, 0xa9, 0x4a, 0x83,
		0x7d, 0x06, 0x40, 0x00, 0x10, 0x45, 0x03, 0x08, 0x75, 0xd1, 0x47, 0x51, 0xec, 0x31, 0x83, 0x10,
		0xad, 0x4e, 0xc3, 0x6d, 0xa9, 0x08, 0xd2, 0x4f, 0x15, 0x95, 0x26, 0x23, 0x70, 0xc8, 0x39, 0xe4,
		0x05, 0x3b, 0xe4, 0x6e, 0xcf, 0x09, 0xfa, 0xed, 0x1b, 0x25, 0x0f, 0xf1, 0x64, 0x83, 0x2b, 0x94,
		0x09, 0xd3, 0x8c, 0xaf, 0xd1, 0x2b, 0xc1, 0x25, 0xe0, 0xb5, 0x10, 0x09, 0xe2, 0x90, 0x8a, 0x9f,
		0x91, 0x0c, 0xd9, 0x78, 0xd4, 0xab, 0x49, 0x66, 0xdd, 0xd4, 0xd6, 0xaa, 0x87, 0xb5, 0xc3, 0xfa,
		0x41, 0xf5, 0x70, 0xdf, 0xa2, 0x39, 0x4e, 0xc9, 0x05, 0x72, 0x65, 0xc1, 0xed, 0x3b, 0x91, 0xc6,
		0x1d, 0xb7, 0xd9, 0x0c, 0xbd, 0x9e, 0xc6, 0x2d, 0xbc, 0x34, 0x12, 0xb7, 0x31, 0xb7, 0x71, 0xc1,
		0x6e, 0x63, 0xbf, 0xab, 0xb8, 0xbb, 0xe7, 0x58, 0xf7, 0xa1, 0xc2, 0x6b, 0xc7, 0x9f, 0x3d, 0xf5,
		0xeb, 0xf8, 0xe9, 0xc9, 0xef, 0x6b, 0x1a, 0xcf, 0xbe, 0xac, 0x4d, 0xe8, 0x95, 0x2e, 0x8d, 0xbc,
		0x30, 0xd0, 0x8e, 0xfe, 0xad, 0xbc, 0x7c, 0xf9, 0x7d, 0xc7, 0x39, 0xbc, 0xfa, 0xf5, 0x7d, 0xd7,
		0x39, 0xbc, 0x1a, 0x7d, 0xb9, 0x3b, 0xfc, 0x6b, 0xf4, 0x75, 0xf5, 0xfb, 0x8e, 0x53, 0x9b, 0x7c,
		0xbd, 0xff, 0x7d, 0xc7, 0xd9, 0xbf, 0x7a, 0xf5, 0xe7, 0x9f, 0x6f, 0x5e, 0xfd, 0xbd, 0xf7, 0x98,
		0xfc, 0x85, 0xea, 0x41, 0x09, 0x57, 0x3a, 0x53, 0x75, 0x76, 0x71, 0xf2, 0x6f, 0xb1, 0xf9, 0xfa,
		0x4f, 0x9a, 0x13, 0xf6, 0x8f, 0x4a, 0xda, 0x71, 0xa5, 0xaf, 0x33, 0x3c, 0x5c, 0xf5, 0x82, 0x1e,
		0x2e, 0xd7, 0xb9, 0x3d, 0x72, 0x3e, 0x5e, 0xfd, 0xbd, 0xfb, 0xba, 0xf6, 0xf8, 0xee, 0xd5, 0xdf,
		0x07, 0x8f, 0x8b, 0xdf, 0xfc, 0xb5, 0xea, 0xd7, 0x76, 0x5f, 0x1f, 0x3c, 0xbe, 0x5b, 0xf3, 0x93,
		0xfa, 0xe3, 0xbb, 0x98, 0x63, 0xec, 0x3f, 0xbe, 0x5c, 0xfa, 0xd5, 0xc1, 0xf7, 0xab, 0xeb, 0x5e,
		0x50, 0x5b, 0xf3, 0x82, 0xbd, 0x75, 0x2f, 0xd8, 0x5b, 0xf3, 0x82, 0xb5, 0x1f, 0xa9, 0xba, 0xe6,
		0x05, 0xfb, 0x8f, 0xbf, 0x96, 0x7e, 0xff, 0xe5, 0xea, 0x5f, 0xad, 0x3f, 0xbe, 0xfa, 0xb5, 0xee,
		0x67, 0x07, 0x8f, 0xbf, 0xde, 0xbd, 0x2a, 0x12, 0xd4, 0xb0, 0x7d, 0xd2, 0xdf, 0x3e, 0xe9, 0x03,
		0x6f, 0x2e, 0x2d, 0x27, 0xd5, 0x38, 0xda, 0x29, 0xea, 0xab, 0xc5, 0xcd, 0x62, 0x27, 0x61, 0x27,
		0xa1, 0x5a, 0xa2, 0x5a, 0xa2, 0x5a, 0xa2, 0x5a, 0x96, 0x56, 0xb5, 0x1c, 0x5e, 0x9d, 0x77, 0x61,
		0xa7, 0xdf, 0xd5, 0xbc, 0x7e, 0x47, 0x63, 0x70, 0x03, 0x73, 0x03, 0x17, 0xec, 0x06, 0x56, 0xef,
		0x32, 0xa4, 0xd3, 0x5d, 0x68, 0xda, 0x55, 0xe8, 0xcd, 0x9b, 0xed, 0xe9, 0xff, 0x9e, 0x0e, 0x5a,
		0x6f, 0xe6, 0xeb, 0x99, 0x2f, 0x9d, 0xe4, 0xed, 0x82, 0x0c, 0xc2, 0x4a, 0xa4, 0x32, 0xf7, 0xf3,
		0xa8, 0xa2, 0xd0, 0x26, 0x17, 0x50, 0x01, 0x54, 0xac, 0x07, 0x15, 0xd5, 0xcd, 0xbd, 0xa5, 0xd9,
		0xfb, 0x59, 0xb1, 0xe7, 0xb3, 0x19, 0x90, 0x08, 0xbd, 0x76, 0xe7, 0xde, 0x73, 0xba, 0xa1, 0x7f,
		0xef, 0x46, 0x9e, 0x96, 0x02, 0xb0, 0x3c, 0x14, 0xa0, 0x01, 0x68, 0x14, 0x0c, 0x34, 0x96, 0x36,
		0xf9, 0x38, 0xfb, 0x4e, 0x07, 0x43, 0x14, 0xcc, 0xae, 0xca, 0x49, 0xd3, 0x0b, 0x22, 0x3f, 0x7a,
		0x78, 0xef, 0xf6, 0x3c, 0xfd, 0xe4, 0xf7, 0x2f, 0xc7, 0x9f, 0xce, 0xbe, 0x1d, 0x5f, 0x9f, 0x7f,
		0x39, 0xf9, 0x76, 0x74, 0x79, 0x7c, 0x7d, 0x74, 0x71, 0x7d, 0x76, 0x7e, 0x79, 0x72, 0xf6, 0x59,
		0x75, 0x4b, 0x0d, 0x2d, 0xcb, 0x9e, 0x96, 0x6e, 0x2e, 0xd4, 0x09, 0x70, 0xe6, 0x91, 0xc6, 0x0f,
		0x79, 0x74, 0x7a, 0x5a, 0xc9, 0xc2, 0xf4, 0x37, 0xf1, 0x40, 0xe7, 0xa7, 0x47, 0x1f, 0x74, 0x9f,
		0x48, 0xe9, 0x95, 0x57, 0xa6, 0x0f, 0xb6, 0x99, 0xcb, 0xae, 0xd3, 0x8f, 0x3c, 0xe7, 0xb6, 0xe5,
		0x76, 0x9d, 0xa6, 0xdb, 0xee, 0xfa, 0x81, 0x46, 0x9f, 0xa7, 0x15, 0x63, 0xa9, 0x07, 0xf5, 0xab,
		0x94, 0x8a, 0xe0, 0xba, 0xe4, 0xba, 0x24, 0xaa, 0x3f, 0x1d, 0xe0, 0xe8, 0x79, 0x41, 0xd3, 0x69,
		0x74, 0xda, 0xed, 0x7e, 0xe0, 0x47, 0x0f, 0x1a, 0xd5, 0x70, 0xe7, 0xc7, 0x51, 0x07, 0x8c, 0xcf,
		0x67, 0x9f, 0x8f, 0xc1, 0x0b, 0xf0, 0xa2, 0x68, 0x78, 0x31, 0x3d, 0x1b, 0xc5, 0x34, 0xcc, 0xf3,
		0x5b, 0x6b, 0x24, 0x71, 0x2d, 0x74, 0x95, 0x12, 0x23, 0x49, 0xaa, 0x9e, 0xcb, 0xd4, 0x16, 0xf1,
		0x6e, 0xee, 0xba, 0x4e, 0xbb, 0xdf, 0x8a, 0xfc, 0x1f, 0x9d, 0x6e, 0xf2, 0x12, 0x23, 0xf3, 0x2f,
		0xa7, 0xd2, 0x48, 0x8a, 0xf8, 0x4a, 0x93, 0x5a, 0x9a, 0xd4, 0x42, 0x20, 0x0a, 0x46, 0x20, 0x94,
		0xcb, 0xf2, 0xab, 0x26, 0xe6, 0x2f, 0x23, 0xba, 0x52, 0x82, 0xbe, 0x94, 0x4d, 0xaf, 0xc9, 0xd5,
		0xb5, 0x8f, 0x9c, 0xc4, 0xd1, 0x93, 0x3b, 0x82, 0x52, 0x47, 0x51, 0xfc, 0x48, 0x8a, 0x1f, 0x4d,
		0xd1, 0x23, 0xaa, 0xa7, 0xec, 0x51, 0xfe, 0x31, 0xa5, 0x0a, 0xb6, 0x13, 0xda, 0xe8, 0x44, 0x51,
		0x4b, 0x1f, 0xb7, 0xe6, 0x46, 0x03, 0x74, 0x00, 0x1d, 0x40, 0x27, 0xd1, 0x7e, 0xa1, 0x0b, 0xc8,
		0xcc, 0x07, 0xa1, 0x0b, 0x88, 0xd6, 0x1f, 0xba, 0x80, 0xd8, 0xb0, 0x08, 0x45, 0xef, 0x02, 0x52,
		0xbc, 0x8a, 0xd3, 0x73, 0x6a, 0x5a, 0xba, 0xdd, 0x17, 0x8f, 0x6f, 0xee, 0xba, 0x9f, 0xc6, 0xef,
		0x4c, 0xf3, 0x45, 0x9a, 0x2f, 0xa2, 0xf2, 0xa0, 0xf2, 0xa0, 0xf2, 0x60, 0x70, 0x61, 0x70, 0xa1,
		0xf2, 0xa0, 0xf2, 0x00, 0x3a, 0x80, 0x0e, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a, 0x0f, 0x2a,
		0x0f, 0x2a, 0x8f, 0xa0, 0xca, 0x93, 0x66, 0x57, 0xb1, 0x39, 0x91, 0x87, 0xa6, 0x62, 0x31, 0x96,
		0xc7, 0x70, 0xbc, 0xdf, 0xec, 0x82, 0xa4, 0x1a, 0xf5, 0x37, 0x34, 0xff, 0x9d, 0x9b, 0xdb, 0xa6,
		0x42, 0xc8, 0xdf, 0xd3, 0x6b, 0x0b, 0x12, 0xef, 0x77, 0xdb, 0x2c, 0x67, 0xbc, 0xdf, 0x6d, 0x93,
		0x78, 0x3f, 0xc1, 0x8d, 0xab, 0x6d, 0x21, 0x8a, 0x29, 0xc1, 0xb7, 0x4d, 0x94, 0x60, 0xdd, 0x0d,
		0x9f, 0x0e, 0x01, 0xc9, 0xbd, 0x12, 0x5c, 0x34, 0x31, 0xe5, 0xb6, 0x89, 0x98, 0x92, 0xd6, 0xd1,
		0x42, 0xc1, 0xa5, 0x4d, 0xb3, 0x00, 0x5f, 0x9f, 0xf2, 0xd1, 0x94, 0x3d, 0xe6, 0xc3, 0xf7, 0x7d,
		0x7f, 0xdb, 0xc4, 0x5d, 0x9e, 0x4b, 0x77, 0x39, 0x24, 0x09, 0x92, 0x04, 0x49, 0x82, 0x24, 0x41,
		0x92, 0x20, 0x49, 0x65, 0x22, 0x49, 0xa9, 0x0a, 0xce, 0x53, 0x8e, 0x84, 0xda, 0xbc, 0x69, 0x61,
		0x4c, 0x4b, 0xcd, 0x93, 0xa5, 0x48, 0x55, 0x67, 0x0e, 0xc3, 0x4e, 0xe8, 0xfc, 0x70, 0x83, 0x66,
		0x2b, 0x49, 0xad, 0xa1, 0xa7, 0x7b, 0x77, 0xfe, 0xf5, 0xe4, 0x97, 0xe7, 0x5a, 0x6f, 0x26, 0xbf,
		0xbc, 0xa0, 0x7a, 0x33, 0x91, 0xc7, 0xfa, 0x1b, 0xde, 0x72, 0x53, 0x2a, 0x0a, 0x3d, 0x37, 0x72,
		0xdc, 0x9e, 0xf3, 0x97, 0x1f, 0xfd, 0x68, 0x86, 0xee, 0x5f, 0xfa, 0x46, 0xd5, 0xf2, 0x90, 0x44,
		0x23, 0x13, 0x18, 0x68, 0x81, 0x99, 0x46, 0x34, 0x32, 0x66, 0x5a, 0x46, 0x66, 0xda, 0x1c, 0xdf,
		0x4d, 0x59, 0xcf, 0x1e, 0xbc, 0xf7, 0xff, 0x8d, 0xdf, 0x1a, 0x4d, 0x9b, 0x14, 0x30, 0x88, 0x98,
		0x95, 0x9a, 0x76, 0x18, 0x76, 0x02, 0xaf, 0xd3, 0xef, 0x39, 0xfd, 0x6e, 0xd3, 0x8d, 0x3c, 0xa7,
		0xed, 0xf5, 0x7a, 0xee, 0x9d, 0xd7, 0x13, 0x50, 0xb9, 0xd7, 0x0e, 0x0d, 0xa1, 0x82, 0x50, 0x41,
		0xa8, 0x12, 0xed, 0x97, 0xbe, 0x1f, 0x44, 0x7b, 0x55, 0x01, 0x3e, 0x75, 0x40, 0xaa, 0x85, 0x28,
		0xac, 0x2c, 0x0d, 0x47, 0xaa, 0x85, 0x35, 0x4b, 0x20, 0xd5, 0x88, 0xcf, 0xe8, 0x5a, 0x14, 0x3d,
		0xe3, 0xe2, 0x35, 0xea, 0x10, 0x64, 0x06, 0x32, 0x03, 0x99, 0x41, 0x1d, 0xb2, 0x5a, 0x1d, 0x4a,
		0xd5, 0x91, 0x3f, 0x27, 0x0e, 0xe1, 0xcc, 0x8f, 0xb3, 0x40, 0xa6, 0x1d, 0xfa, 0xb3, 0x4b, 0x92,
		0xa6, 0x53, 0xff, 0x2e, 0x74, 0x1b, 0xde, 0x6d, 0xbf, 0xe5, 0x84, 0x5e, 0x2f, 0x72, 0xc3, 0x28,
		0xb9, 0x5b, 0x7f, 0x69, 0x04, 0x1c, 0xfb, 0x29, 0x5e, 0x99, 0x38, 0xf6, 0x71, 0xec, 0x9b, 0xe4,
		0x88, 0xe8, 0xc9, 0x19, 0x10, 0x12, 0x62, 0xa4, 0x31, 0xaf, 0x30, 0xaf, 0x30, 0xaf, 0x6c, 0x2e,
		0x05, 0xf6, 0xc3, 0x6b, 0x75, 0xbd, 0xd0, 0xe9, 0x04, 0xad, 0x07, 0x7d, 0xb8, 0x99, 0x1d, 0x0c,
		0xc8, 0x01, 0x72, 0x80, 0x1c, 0x20, 0x67, 0xf9, 0x33, 0x8e, 0x0d, 0x4c, 0x27, 0xf2, 0xdb, 0x02,
		0x5d, 0xa2, 0xe7, 0x46, 0x03, 0x74, 0x00, 0x1d, 0x40, 0x27, 0xd1, 0x7e, 0xe9, 0xfb, 0x41, 0xb4,
		0x5b, 0x17, 0xc0, 0x9c, 0x3a, 0x3e, 0x71, 0x51, 0x58, 0x59, 0x1a, 0x0e, 0x9f, 0xb8, 0x35, 0x4b,
		0x50, 0xdb, 0x39, 0xac, 0xe3, 0x0d, 0x5f, 0xfc, 0x63, 0xb3, 0x37, 0xbc, 0x17, 0xb9, 0x2d, 0xcf,
		0x19, 0xf6, 0xc7, 0xef, 0x09, 0x31, 0x8f, 0xe5, 0x21, 0xa1, 0x1f, 0xd0, 0x0f, 0xe8, 0x47, 0xa2,
		0xfd, 0xd2, 0xf4, 0x1a, 0x7e, 0xdb, 0x6d, 0xd5, 0x6b, 0x12, 0x56, 0x4f, 0x55, 0x63, 0x8c, 0x25,
		0x1c, 0xae, 0xc2, 0x67, 0x56, 0x4f, 0x73, 0x15, 0x3e, 0x93, 0x35, 0x9f, 0xd9, 0x2b, 0xd1, 0x12,
		0x50, 0x4c, 0x59, 0x7d, 0x43, 0x66, 0x13, 0x13, 0xb3, 0x18, 0x4a, 0x90, 0x6e, 0xce, 0xd4, 0xef,
		0xe3, 0x77, 0xff, 0x32, 0x7a, 0x73, 0xb2, 0xa6, 0xc8, 0x9a, 0x4a, 0x9d, 0x33, 0xe2, 0xe5, 0x8e,
		0xf1, 0x42, 0xbc, 0xdc, 0x98, 0x5f, 0x98, 0x5f, 0xd9, 0x9a, 0x5f, 0x78, 0xb9, 0x93, 0xcf, 0x19,
		0x5e, 0x6e, 0x20, 0x07, 0xc8, 0x01, 0x72, 0x9e, 0xff, 0x8c, 0xad, 0x4e, 0xc3, 0x9d, 0x5a, 0x40,
		0x49, 0x0a, 0xad, 0xad, 0x9d, 0xb8, 0xa5, 0x11, 0x01, 0x1f, 0xc0, 0x07, 0xf0, 0x01, 0x7c, 0x96,
		0x3f, 0x63, 0xbb, 0xd3, 0x14, 0x70, 0x70, 0x0d, 0x47, 0x01, 0x64, 0x00, 0x19, 0x40, 0x26, 0xa1,
		0x1e, 0xd1, 0x6f, 0x7b, 0xe1, 0x48, 0x75, 0x15, 0x00, 0x9a, 0x9a, 0xc6, 0x18, 0xc7, 0x41, 0xbf,
		0x3d, 0x78, 0xa8, 0x47, 0x8b, 0xc1, 0xaa, 0xeb, 0x79, 0xa1, 0x23, 0x1b, 0x14, 0xb8, 0x3c, 0x24,
		0x30, 0x06, 0x8c, 0x01, 0x63, 0x89, 0xf6, 0x0b, 0x91, 0x81, 0xb3, 0x1f, 0x84, 0xc8, 0x40, 0xad,
		0x3f, 0x44, 0x06, 0x5a, 0xb1, 0x0a, 0x44, 0x06, 0x3e, 0x4b, 0x3f, 0x44, 0x74, 0x9a, 0xc5, 0x01,
		0xa1, 0x1e, 0x50, 0x0f, 0xa8, 0x07, 0x32, 0xcd, 0xf2, 0x67, 0x24, 0x13, 0x0a, 0xd0, 0x01, 0x74,
		0xb0, 0x77, 0xb0, 0x77, 0xb0, 0x77, 0xb0, 0x77, 0xb0, 0x77, 0xc8, 0x84, 0x82, 0x7e, 0x40, 0x3f,
		0xc8, 0x84, 0x22, 0x13, 0x2a, 0x1f, 0x7c, 0x86, 0x4c, 0xa8, 0xcc, 0xf9, 0x0c, 0x99, 0x50, 0xc5,
		0x21, 0x33, 0x25, 0xc8, 0x84, 0x4a, 0xb3, 0x3e, 0xf0, 0x62, 0x22, 0x14, 0x15, 0x82, 0xe3, 0x2d,
		0x92, 0xe1, 0x1a, 0xc1, 0x0b, 0xcb, 0x92, 0x66, 0x95, 0xe0, 0x56, 0xe7, 0xee, 0xce, 0x0f, 0xee,
		0x9c, 0x4e, 0x77, 0x30, 0xb5, 0xbd, 0xe4, 0x45, 0x82, 0x17, 0x07, 0xa0, 0x46, 0x70, 0x8a, 0x34,
		0x9c, 0x1a, 0xc1, 0xd4, 0x08, 0x36, 0x69, 0x77, 0x92, 0x3d, 0x99, 0x01, 0x2d, 0x51, 0xce, 0x9e,
		0x6c, 0x75, 0xee, 0x9c, 0xc9, 0x15, 0xe6, 0x0c, 0x69, 0x85, 0xd3, 0xf8, 0x31, 0x30, 0xb6, 0x7a,
		0x12, 0x99, 0x06, 0x6b, 0xc7, 0xd6, 0x6f, 0xf8, 0x32, 0x58, 0x4e, 0xf4, 0x21, 0xf4, 0x21, 0xf4,
		0xa1, 0x64, 0xfb, 0x85, 0x7e, 0x2f, 0x36, 0x58, 0x74, 0x0b, 0x0c, 0x38, 0xdd, 0xd2, 0x16, 0xa7,
		0xa3, 0x37, 0x3f, 0x1b, 0xbd, 0x37, 0x95, 0x2d, 0xa8, 0x6c, 0x01, 0x37, 0x83, 0x9b, 0xc1, 0xcd,
		0xe0, 0x66, 0x70, 0x33, 0xb8, 0x19, 0xdc, 0x6c, 0x81, 0x9b, 0xa5, 0x29, 0xb6, 0x2f, 0x50, 0x33,
		0xb4, 0xf6, 0x58, 0x4b, 0x64, 0x58, 0x6a, 0x9f, 0x5f, 0x94, 0x34, 0x95, 0xf6, 0xe9, 0x0d, 0xed,
		0x36, 0x9b, 0xa1, 0xd7, 0x53, 0x90, 0xda, 0x97, 0x46, 0x48, 0xa6, 0xb5, 0xef, 0xa0, 0xb5, 0xa3,
		0xb5, 0x2b, 0x5e, 0x73, 0x4f, 0x5c, 0xd3, 0x73, 0x6f, 0x43, 0xef, 0x36, 0xc9, 0x82, 0x4d, 0xae,
		0xb1, 0x04, 0x1d, 0xf2, 0x2b, 0xe7, 0x63, 0x0c, 0x79, 0xf3, 0x66, 0x6c, 0x4e, 0x6f, 0x2f, 0x6d,
		0xfe, 0x14, 0x8f, 0xee, 0x30, 0x8c, 0xcd, 0x09, 0xbd, 0xdb, 0x96, 0xd7, 0x88, 0x3a, 0x61, 0xf2,
		0x93, 0xbb, 0x38, 0x00, 0x4e, 0x32, 0x0e, 0xae, 0xd2, 0xc1, 0xc5, 0x49, 0x86, 0x10, 0x83, 0x10,
		0xa3, 0x23, 0xc4, 0x2c, 0x40, 0xb1, 0xd3, 0x68, 0xf9, 0xa3, 0x07, 0xd5, 0x4d, 0xb5, 0x5a, 0x3d,
		0xae, 0xbe, 0x00, 0x73, 0xeb, 0xb6, 0x7a, 0x28, 0x30, 0x28, 0x30, 0x28, 0x30, 0x25, 0x50, 0x60,
		0x5e, 0x4b, 0x00, 0x5a, 0xbf, 0x17, 0x79, 0xa1, 0xe3, 0x37, 0x4d, 0x80, 0xda, 0x74, 0x6c, 0x00,
		0x09, 0x40, 0x02, 0x90, 0x92, 0x9d, 0xa6, 0xd9, 0x03, 0xe4, 0x44, 0x83, 0x71, 0x05, 0xb0, 0xe9,
		0x50, 0x63, 0x8c, 0xf1, 0xb3, 0x65, 0x9e, 0x89, 0x31, 0x9b, 0x6f, 0xbb, 0x57, 0xad, 0x08, 0x24,
		0x16, 0x8c, 0x67, 0xe7, 0x40, 0x60, 0x28, 0x99, 0x7c, 0x15, 0xb9, 0xd9, 0x9a, 0x7e, 0x30, 0xc9,
		0xfc, 0x15, 0x21, 0x80, 0x5e, 0x3b, 0xac, 0x70, 0x32, 0xc5, 0x74, 0x5c, 0x03, 0x49, 0x15, 0x9a,
		0x80, 0xb1, 0x7a, 0xa9, 0x04, 0xf3, 0x5c, 0xd2, 0x5a, 0xaa, 0x5a, 0xf5, 0xb0, 0x76, 0x58, 0x3f,
		0xa8, 0x1e, 0xee, 0xe7, 0x68, 0xcd, 0x5e, 0xd8, 0x31, 0xca, 0xd5, 0x8b, 0x0c, 0x77, 0x9e, 0x20,
		0x20, 0xfb, 0xdd, 0xfb, 0x5a, 0x42, 0x77, 0x43, 0xac, 0x4b, 0xeb, 0xad, 0xc0, 0x58, 0xe7, 0xff,
		0x3f, 0x7b, 0x6f, 0xfb, 0x9c, 0xb6, 0x92, 0xbc, 0x81, 0x7e, 0xcf, 0x5f, 0xe1, 0xa2, 0xf6, 0x43,
		0x5c, 0x15, 0xc5, 0x06, 0xf3, 0x12, 0xe7, 0x1b, 0xb1, 0x49, 0x0e, 0xbf, 0xb5, 0x0d, 0x17, 0x70,
		0xf6, 0xec, 0x75, 0x38, 0x94, 0x0c, 0x63, 0x47, 0x7b, 0x40, 0xe2, 0x4a, 0xc2, 0x27, 0xae, 0x98,
		0xff, 0xfd, 0x16, 0x6f, 0xb2, 0xb1, 0x20, 0x01, 0xa9, 0xa7, 0x67, 0x24, 0x3d, 0xa9, 0x93, 0x0d,
		0x9b, 0x98, 0x19, 0x69, 0xa6, 0xa7, 0xfb, 0xe9, 0x67, 0xfa, 0xc5, 0xf4, 0x7d, 0xe1, 0xda, 0x64,
		0x9a, 0x39, 0xf7, 0xf6, 0xed, 0xcd, 0xb1, 0x71, 0xda, 0x7d, 0xba, 0xc9, 0x1b, 0xa7, 0xdd, 0xc5,
		0xc7, 0xfc, 0xfc, 0x8f, 0xc5, 0xe7, 0xc2, 0xcd, 0xb1, 0x51, 0x5c, 0x7d, 0x2e, 0xdd, 0x1c, 0x1b,
		0xa5, 0xee, 0xe1, 0xb7, 0x6f, 0xef, 0x0f, 0x7f, 0x9e, 0x4c, 0xf7, 0xff, 0x62, 0x2e, 0xbe, 0x88,
		0x51, 0x2c, 0x61, 0xa3, 0x5d, 0xff, 0x93, 0x7c, 0x1d, 0xff, 0xe2, 0x5c, 0xc8, 0x7f, 0xe5, 0x54,
		0x1f, 0x56, 0x64, 0xd1, 0xf1, 0xdf, 0xeb, 0xbf, 0x72, 0x4c, 0x79, 0x63, 0x2e, 0x5b, 0xb3, 0xc9,
		0x5b, 0xab, 0xb9, 0x11, 0x73, 0x89, 0x98, 0x4b, 0x76, 0x47, 0x1d, 0x54, 0x7f, 0x24, 0x66, 0x0c,
		0x54, 0x3f, 0x98, 0x35, 0x30, 0x6b, 0xe9, 0x63, 0xd6, 0x40, 0xf5, 0x83, 0xea, 0x87, 0x42, 0x82,
		0x42, 0xd2, 0x46, 0x21, 0x81, 0xea, 0xff, 0xdd, 0x0a, 0x81, 0xea, 0xdf, 0xe7, 0xc1, 0x40, 0xf5,
		0x83, 0xea, 0x07, 0xd5, 0x4f, 0xc4, 0xbb, 0xd1, 0x8e, 0x02, 0xaa, 0xff, 0xd7, 0x46, 0x0b, 0x54,
		0x3f, 0xa8, 0x7e, 0x50, 0xfd, 0xa0, 0xfa, 0xa9, 0xa8, 0x7e, 0xce, 0x14, 0xbe, 0x57, 0x4c, 0x3f,
		0x52, 0xf8, 0x76, 0xda, 0x22, 0xc9, 0x29, 0x7c, 0xeb, 0x9b, 0xc2, 0x99, 0x07, 0xb4, 0xdf, 0xfd,
		0x4a, 0xa4, 0x7b, 0x95, 0xc8, 0x39, 0x3f, 0x05, 0xe4, 0xfc, 0x50, 0xb2, 0x1a, 0x49, 0xce, 0xf9,
		0x31, 0x27, 0xfe, 0x77, 0x63, 0x6c, 0x7a, 0xde, 0x72, 0x09, 0x23, 0x5e, 0x07, 0xae, 0x0f, 0x13,
		0xed, 0x5a, 0xf0, 0x18, 0x19, 0x40, 0x9c, 0xa4, 0x5e, 0x96, 0xae, 0x05, 0x23, 0x93, 0x75, 0x6b,
		0x94, 0xb7, 0x65, 0xdf, 0x47, 0x95, 0xf1, 0x75, 0x2f, 0x47, 0x83, 0xeb, 0xff, 0x81, 0xf0, 0xfa,
		0xae, 0x35, 0x8e, 0x84, 0xcf, 0x5e, 0xd4, 0x9c, 0x7f, 0x1e, 0x04, 0x67, 0x1e, 0x67, 0x3e, 0x65,
		0x67, 0xde, 0xf3, 0xdd, 0x68, 0x0d, 0x18, 0xf5, 0x3a, 0xe9, 0x8f, 0xb6, 0x39, 0xb2, 0xfa, 0xe6,
		0x70, 0xf8, 0x68, 0x2c, 0xf0, 0xf2, 0xc4, 0x15, 0x31, 0x4c, 0xfd, 0x96, 0xf1, 0xf6, 0x0d, 0xd4,
		0x88, 0x17, 0xc9, 0x00, 0xfd, 0x01, 0xfd, 0xa1, 0xbd, 0xfe, 0x88, 0x1e, 0x69, 0x10, 0x31, 0xc2,
		0x40, 0x8e, 0x02, 0x11, 0xb6, 0x79, 0x3b, 0x8c, 0xa3, 0x31, 0x56, 0x03, 0x44, 0x57, 0x11, 0x11,
		0x0a, 0xcb, 0x41, 0x43, 0x40, 0x43, 0x40, 0x43, 0x30, 0x69, 0x08, 0xcf, 0x37, 0x6f, 0x87, 0x96,
		0xf7, 0x5d, 0x0c, 0x0c, 0xdf, 0x35, 0x6d, 0xcf, 0xda, 0xaf, 0x41, 0x44, 0x58, 0x63, 0x6c, 0x19,
		0x10, 0x2a, 0x00, 0x2a, 0x20, 0x65, 0x2a, 0xa0, 0xef, 0x4c, 0x6c, 0x5f, 0xb8, 0x91, 0xfa, 0xb6,
		0xad, 0x04, 0x3c, 0xc2, 0xb5, 0x69, 0xcc, 0xf0, 0x95, 0x18, 0x61, 0x4f, 0x14, 0xe1, 0x29, 0x44,
		0x31, 0x0e, 0x54, 0xe1, 0x27, 0x94, 0xa1, 0x0b, 0x31, 0x2e, 0xf9, 0x49, 0xc2, 0x49, 0xa8, 0x97,
		0x36, 0xff, 0xa1, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xe3, 0xca, 0x49, 0xe5, 0xf8, 0xb4, 0x54, 0xca,
		0x97, 0xf3, 0x25, 0x8d, 0x56, 0x9b, 0xe9, 0xae, 0xb5, 0xab, 0x81, 0x95, 0x1e, 0x9a, 0x9e, 0x6f,
		0xbc, 0xb0, 0xac, 0xd1, 0xcd, 0x73, 0x68, 0x24, 0xd8, 0x65, 0xd8, 0xe5, 0x94, 0xd9, 0x65, 0xdf,
		0x1a, 0x09, 0xdf, 0xea, 0xff, 0xed, 0xb1, 0x5b, 0xe6, 0x6b, 0x7b, 0xa1, 0xd5, 0x72, 0xb6, 0x69,
		0x3b, 0x9e, 0xe8, 0x3b, 0xf6, 0x20, 0x4a, 0x90, 0x15, 0x2c, 0x3c, 0x2c, 0x3c, 0x2c, 0x7c, 0xb6,
		0x2c, 0xbc, 0xd3, 0x37, 0x87, 0x86, 0x19, 0xc3, 0xf1, 0x0e, 0x46, 0x80, 0x45, 0x87, 0x45, 0x4f,
		0x99, 0x45, 0x37, 0x3d, 0xc3, 0x9e, 0x8c, 0x6e, 0x85, 0x1b, 0xc3, 0x9e, 0x57, 0x60, 0x87, 0x61,
		0x87, 0x35, 0xb5, 0xc3, 0x54, 0x89, 0x19, 0xb0, 0xbe, 0xd1, 0xac, 0xef, 0x48, 0x78, 0x9e, 0x19,
		0xa5, 0x49, 0x53, 0xa0, 0xa1, 0x82, 0x11, 0x50, 0x42, 0x1b, 0xd6, 0x57, 0x2b, 0xeb, 0x1b, 0xbd,
		0xae, 0x86, 0xe8, 0x0b, 0xeb, 0x41, 0x50, 0x24, 0x9d, 0xaf, 0x46, 0x8a, 0x97, 0x62, 0x9e, 0x47,
		0x8a, 0x39, 0x52, 0xcc, 0x99, 0xcd, 0x59, 0xd4, 0x6a, 0x2f, 0x11, 0x0f, 0xdd, 0xb3, 0xb8, 0x34,
		0x3a, 0xf5, 0xcf, 0xf5, 0xb3, 0x6a, 0xa7, 0xde, 0xb8, 0x8a, 0xbf, 0xd5, 0x2b, 0xe1, 0x5b, 0x1b,
		0xf5, 0x9d, 0x16, 0x10, 0x28, 0xee, 0xe1, 0xa4, 0x3c, 0xa4, 0xf4, 0x87, 0x95, 0xfa, 0xd0, 0x4a,
		0x3b, 0xbc, 0xd2, 0x0e, 0xb1, 0x94, 0xc3, 0x1c, 0xef, 0x50, 0x13, 0x78, 0x11, 0x07, 0x24, 0x75,
		0x24, 0x42, 0xf2, 0x36, 0xb1, 0x6c, 0x3f, 0x12, 0x69, 0xbd, 0xed, 0x74, 0x7e, 0x40, 0xb5, 0x04,
		0x25, 0x6a, 0x4d, 0x96, 0x13, 0x2d, 0xd3, 0xe1, 0x23, 0x3e, 0x1e, 0xe4, 0x4e, 0x37, 0xf7, 0x56,
		0xd1, 0x93, 0xe3, 0xac, 0xbb, 0x97, 0x8e, 0xba, 0x09, 0x4a, 0x28, 0xa2, 0xeb, 0xe6, 0x79, 0xb5,
		0x53, 0xa3, 0x83, 0x5d, 0xcb, 0xf1, 0x00, 0xb8, 0x00, 0xb8, 0x00, 0xb8, 0x00, 0xb8, 0x00, 0xb8,
		0x00, 0xb8, 0x00, 0xb8, 0x00, 0xb8, 0x00, 0xb8, 0x56, 0xdb, 0x32, 0x8f, 0x4a, 0xb4, 0x1d, 0xdf,
		0xba, 0xb3, 0xfa, 0xf3, 0x6a, 0x26, 0x86, 0x70, 0x5d, 0xc7, 0x35, 0xfa, 0xce, 0x40, 0xd0, 0xc1,
		0xb0, 0x5f, 0xce, 0x02, 0x70, 0x06, 0x70, 0x06, 0x70, 0xa6, 0x15, 0x38, 0xb3, 0x06, 0xc2, 0xf6,
		0x2d, 0xff, 0x71, 0xbf, 0x46, 0xe4, 0xbf, 0x3b, 0xa2, 0x14, 0x36, 0x25, 0x57, 0x5f, 0x3e, 0xda,
		0x27, 0xd3, 0x23, 0x14, 0xe3, 0xd5, 0x8b, 0x7f, 0xfa, 0xd2, 0xec, 0xd5, 0x5a, 0xad, 0x46, 0xab,
		0x77, 0xd6, 0x38, 0xaf, 0x51, 0xc9, 0xf2, 0xdc, 0xcc, 0x7a, 0x64, 0xb8, 0x92, 0x16, 0x5b, 0xae,
		0xbd, 0xff, 0x65, 0xad, 0xdd, 0xae, 0x7e, 0xa9, 0xf5, 0xfe, 0xa8, 0x55, 0xcf, 0x6b, 0xad, 0xc5,
		0x52, 0xe4, 0x74, 0x84, 0x59, 0x92, 0xde, 0xbf, 0xd1, 0xac, 0x5d, 0xf5, 0x56, 0x8b, 0x90, 0xb9,
		0xb7, 0x6f, 0x35, 0xae, 0x3b, 0xb5, 0x5e, 0xab, 0xf6, 0xb9, 0x55, 0x6b, 0xff, 0x91, 0xdd, 0x65,
		0x58, 0x90, 0x46, 0xd9, 0x7d, 0xff, 0xcf, 0xf5, 0xab, 0x7a, 0xa7, 0xd6, 0x6b, 0x77, 0xe6, 0xab,
		0x50, 0x3d, 0xfb, 0xa3, 0x7e, 0x95, 0xc1, 0x55, 0xf8, 0xa3, 0x71, 0x71, 0xde, 0xeb, 0xd4, 0x2f,
		0x67, 0x6a, 0xf0, 0xcf, 0x66, 0xbd, 0x55, 0x3b, 0xcf, 0xd2, 0xdb, 0x9f, 0xd5, 0xaa, 0xed, 0x5a,
		0x4e, 0x33, 0x17, 0xad, 0xab, 0x1a, 0xa8, 0x69, 0xe5, 0xa2, 0x79, 0x93, 0x5b, 0x1e, 0x2f, 0x6d,
		0x35, 0x11, 0x1c, 0x35, 0x38, 0x6a, 0x70, 0xd4, 0xe0, 0xa8, 0xe9, 0xe5, 0xa8, 0xb5, 0xaf, 0x3f,
		0x65, 0xd3, 0x57, 0xbb, 0xbe, 0x6a, 0x37, 0x6b, 0x67, 0xf5, 0xcf, 0xf5, 0xb3, 0xcc, 0x7a, 0x68,
		0xb4, 0x7b, 0x2f, 0x53, 0x06, 0xe4, 0xac, 0xca, 0x06, 0x99, 0xa8, 0x9e, 0x9d, 0xd5, 0x9a, 0x9d,
		0xea, 0xa7, 0x8b, 0x5a, 0x2f, 0x40, 0xb0, 0x39, 0xf2, 0x49, 0xa7, 0xef, 0x92, 0xb7, 0x32, 0xed,
		0xeb, 0x66, 0xb3, 0xd1, 0xea, 0xd4, 0xce, 0x7b, 0x5f, 0x6b, 0xad, 0x76, 0xbd, 0x71, 0xd5, 0xbb,
		0xba, 0xbe, 0xfc, 0x54, 0x6b, 0x61, 0x75, 0xd6, 0x57, 0xe7, 0xac, 0xda, 0xac, 0x7e, 0xaa, 0x5f,
		0xd4, 0x3b, 0xff, 0xc5, 0xca, 0xac, 0xaf, 0x4c, 0xa3, 0xd9, 0xa9, 0x37, 0xae, 0xaa, 0x17, 0xbd,
		0x66, 0xb5, 0x55, 0xbd, 0xac, 0x75, 0x20, 0x3b, 0x73, 0x53, 0x5c, 0x3d, 0xef, 0xcd, 0xcc, 0x71,
		0xfd, 0xbc, 0x76, 0xd5, 0xa9, 0x7f, 0xae, 0x63, 0x55, 0x56, 0xab, 0xd2, 0xac, 0xd5, 0x5a, 0xbd,
		0x6a, 0x5b, 0xc2, 0x72, 0x90, 0x8e, 0xd8, 0xcd, 0x12, 0xb7, 0x27, 0xd9, 0x40, 0x26, 0x61, 0x05,
		0xe4, 0x1b, 0xc2, 0x64, 0xad, 0x82, 0x0c, 0x83, 0x97, 0xac, 0x15, 0x90, 0x69, 0xd8, 0xf4, 0x5f,
		0x09, 0x99, 0x06, 0x2c, 0x19, 0x6f, 0x4f, 0x6e, 0xa8, 0x12, 0x77, 0xc9, 0x03, 0x4f, 0xf2, 0xd5,
		0xfa, 0x5c, 0x56, 0x2f, 0x3e, 0x37, 0x5a, 0x97, 0xb5, 0xf3, 0x5e, 0xb5, 0xdd, 0x6b, 0x56, 0x3b,
		0x7f, 0x00, 0xd4, 0x1d, 0xe4, 0xaa, 0x9d, 0x4e, 0xab, 0xfe, 0xe9, 0xba, 0x53, 0xeb, 0x7d, 0xbe,
		0xa8, 0x7e, 0x69, 0x53, 0x5f, 0x8a, 0x25, 0x77, 0x61, 0x02, 0x03, 0xf2, 0xbc, 0x42, 0x58, 0x9b,
		0xe5, 0xda, 0xd4, 0xaf, 0xbe, 0x56, 0x2f, 0xea, 0xe7, 0xbd, 0xab, 0x5a, 0xe7, 0x3f, 0x8d, 0xd6,
		0xbf, 0x7b, 0x9f, 0xeb, 0xb5, 0x8b, 0x73, 0x2c, 0xcc, 0x0c, 0x81, 0xb4, 0x6a, 0x67, 0x8d, 0x2f,
		0x57, 0xf5, 0xff, 0xb7, 0x76, 0xde, 0xfb, 0x4f, 0xed, 0xe2, 0xa2, 0xf7, 0xef, 0xab, 0xc6, 0x7f,
		0xae, 0x9e, 0x65, 0x08, 0x8b, 0x74, 0x90, 0xbb, 0xac, 0xb7, 0xdb, 0xf5, 0xab, 0x2f, 0x58, 0x9f,
		0xdf, 0xaa, 0xe4, 0x8b, 0xda, 0xd5, 0x97, 0xce, 0x1f, 0xd0, 0x3b, 0x1b, 0x2c, 0xf8, 0xf3, 0x1a,
		0xd5, 0xdb, 0x1d, 0xac, 0xcd, 0xb3, 0x4e, 0x6e, 0xb4, 0xea, 0x5f, 0xea, 0x38, 0x51, 0x5b, 0xec,
		0xd5, 0x9f, 0x9d, 0xde, 0x1f, 0x8d, 0xa6, 0xd4, 0xd5, 0x01, 0x91, 0xa5, 0x1f, 0x3e, 0xd7, 0xff,
		0xe5, 0x25, 0xe3, 0xf0, 0x24, 0xdc, 0x82, 0xca, 0xc6, 0xdb, 0xfa, 0xaf, 0x81, 0x64, 0x5c, 0x9d,
		0x04, 0x06, 0x8f, 0x0d, 0x3f, 0x27, 0x40, 0x1f, 0xb2, 0xe0, 0xe4, 0x24, 0xa9, 0x46, 0x39, 0x78,
		0x38, 0x51, 0x96, 0x51, 0x12, 0xee, 0x4d, 0x8e, 0x6e, 0x94, 0x87, 0x6f, 0x93, 0x64, 0x1f, 0xe4,
		0xe1, 0xd8, 0xa4, 0xe5, 0x74, 0x80, 0xe6, 0xde, 0x22, 0x24, 0xab, 0x7b, 0x80, 0x85, 0xd2, 0x84,
		0xa3, 0xa3, 0xdf, 0x31, 0x96, 0xb5, 0x43, 0x09, 0x30, 0x68, 0xeb, 0x49, 0x79, 0x38, 0xc3, 0xaf,
		0xd6, 0xe7, 0x53, 0xf5, 0x59, 0x3a, 0x3a, 0xff, 0x6d, 0x82, 0xc4, 0xf9, 0x78, 0x90, 0x3b, 0x6b,
		0x5c, 0x5d, 0xd5, 0xce, 0x3a, 0xf3, 0xe0, 0x8e, 0x46, 0xa7, 0xd7, 0xfe, 0xef, 0xd5, 0xd9, 0x1f,
		0xad, 0xc6, 0xdc, 0x55, 0xc0, 0xf2, 0xac, 0x8b, 0x0c, 0x54, 0xbe, 0x6e, 0x0a, 0x4f, 0xde, 0x81,
		0x4e, 0x40, 0xe2, 0x1d, 0xc7, 0xc1, 0x4d, 0x96, 0x08, 0x64, 0xcf, 0xe2, 0x6f, 0xcc, 0xc0, 0x85,
		0xdd, 0x7f, 0xed, 0xda, 0xd4, 0xce, 0x6a, 0xf5, 0xaf, 0xb5, 0xde, 0xf5, 0x55, 0xed, 0xcf, 0x66,
		0xed, 0xac, 0x53, 0x7b, 0x16, 0x99, 0x46, 0xb3, 0x76, 0x75, 0xd6, 0xb8, 0xfa, 0x5c, 0x6f, 0x5d,
		0xc2, 0xdc, 0xfd, 0x72, 0xa5, 0x6a, 0xed, 0x4e, 0xf5, 0xd3, 0x45, 0xbd, 0xfd, 0x07, 0x80, 0xc1,
		0x0e, 0x32, 0xd5, 0xae, 0x5d, 0x75, 0x80, 0x14, 0x34, 0x62, 0x37, 0x98, 0x55, 0x40, 0xa2, 0x57,
		0x44, 0xca, 0x51, 0x4f, 0xbc, 0x8c, 0xd0, 0x1e, 0xe9, 0x84, 0x54, 0x76, 0x00, 0x98, 0x78, 0xbd,
		0x2c, 0x8d, 0xce, 0x1f, 0xb5, 0x56, 0x6f, 0xae, 0x30, 0xbe, 0xf4, 0xce, 0xfe, 0xa8, 0x5e, 0x7d,
		0x01, 0x8f, 0x30, 0x5b, 0x96, 0xeb, 0x4e, 0xaf, 0xf1, 0xb9, 0xd7, 0xaa, 0xb5, 0x1b, 0xd7, 0xad,
		0xb3, 0x5a, 0x1b, 0x6b, 0x72, 0x90, 0x9b, 0x47, 0xcb, 0x9f, 0xd7, 0x96, 0xc2, 0x72, 0xdd, 0x02,
		0x72, 0x5a, 0x5c, 0xbb, 0xfd, 0xd9, 0xbb, 0xba, 0xbe, 0xec, 0x35, 0x5b, 0xb5, 0xcf, 0xf5, 0x3f,
		0x6b, 0xed, 0x5e, 0xab, 0x56, 0x3d, 0x03, 0xaa, 0x0c, 0x9c, 0xfa, 0xde, 0x59, 0xe3, 0xe2, 0xa2,
		0x3e, 0x4f, 0xb7, 0x9a, 0x9d, 0xa6, 0x8b, 0xeb, 0x79, 0x2b, 0x18, 0x2c, 0x4e, 0xae, 0x7a, 0x7e,
		0x59, 0xbf, 0xaa, 0xb7, 0x3b, 0xad, 0x6a, 0x67, 0x66, 0xa6, 0x5b, 0xb5, 0x76, 0x0d, 0x31, 0x8a,
		0xeb, 0x4c, 0x50, 0xab, 0xf6, 0x7f, 0x73, 0xe0, 0x82, 0x65, 0x09, 0x89, 0x4b, 0xfb, 0x8f, 0xeb,
		0xce, 0x79, 0xe3, 0x3f, 0x57, 0xf0, 0xca, 0xf4, 0x81, 0x98, 0x52, 0xb1, 0x54, 0x02, 0x5e, 0x5f,
		0x1a, 0x66, 0xd2, 0xff, 0xdd, 0x65, 0x62, 0xa3, 0x24, 0x84, 0x1e, 0xc9, 0xc6, 0x40, 0xc9, 0xb8,
		0xc0, 0x90, 0x8c, 0x75, 0x12, 0x10, 0x85, 0x27, 0x15, 0xd3, 0x24, 0xea, 0x16, 0x8b, 0x1e, 0xbb,
		0x24, 0x6e, 0xfb, 0xe9, 0x31, 0x0a, 0xea, 0x69, 0x52, 0xd6, 0xd3, 0xf4, 0xad, 0x91, 0xd4, 0x32,
		0x9a, 0xf3, 0xf1, 0x51, 0x3d, 0xf3, 0xb7, 0x2b, 0x87, 0xea, 0x99, 0xa8, 0x9e, 0xb9, 0xfd, 0x8d,
		0xe8, 0xab, 0x67, 0xce, 0xce, 0xa5, 0x6f, 0xf5, 0xff, 0xf6, 0xb4, 0x6b, 0x44, 0x75, 0x6d, 0x2f,
		0x9a, 0xe4, 0xe4, 0x6c, 0xd3, 0x76, 0x3c, 0xd1, 0x77, 0xec, 0x81, 0x97, 0x43, 0x83, 0x2b, 0x25,
		0x3a, 0x33, 0x34, 0x2c, 0x1a, 0x5c, 0xa1, 0xc1, 0x15, 0xef, 0xee, 0x65, 0xbd, 0xc1, 0x15, 0x6b,
		0x07, 0xf9, 0xaa, 0x6d, 0x3b, 0xfe, 0x1c, 0xb8, 0xc5, 0x6b, 0x24, 0xef, 0xf5, 0xbf, 0x8b, 0x91,
		0x39, 0x36, 0xfd, 0xef, 0x33, 0x45, 0x7e, 0xe4, 0x8c, 0x85, 0xdd, 0x9f, 0xa3, 0xaf, 0x99, 0x31,
		0x3e, 0x9a, 0xfd, 0xb6, 0x85, 0x75, 0xff, 0xfd, 0xd6, 0x71, 0xbd, 0xe0, 0xd3, 0x91, 0xe7, 0x9b,
		0xbe, 0x38, 0x1a, 0x09, 0xcf, 0x33, 0xef, 0x85, 0x77, 0xe4, 0x8a, 0xbe, 0xb0, 0x1e, 0xc4, 0x20,
		0x86, 0xee, 0xcf, 0x79, 0xbe, 0x3b, 0xe9, 0xfb, 0xf6, 0x8a, 0x9c, 0x0a, 0x1e, 0xe3, 0xd3, 0xfd,
		0xb8, 0x37, 0xfb, 0x7d, 0xb5, 0x7a, 0x8a, 0xe0, 0x53, 0xaf, 0x3d, 0x7b, 0x8a, 0xde, 0xe5, 0xf2,
		0x29, 0x7a, 0xad, 0xd5, 0x53, 0xbc, 0xe1, 0xd9, 0xbd, 0x08, 0x3b, 0x97, 0xf3, 0x16, 0x58, 0x27,
		0xda, 0x7e, 0x05, 0x88, 0x60, 0x3e, 0x4a, 0x44, 0xb9, 0x59, 0x15, 0xcf, 0x8e, 0xf8, 0xf5, 0xb8,
		0xc8, 0x9c, 0x02, 0x91, 0xd3, 0x21, 0x71, 0x2a, 0x04, 0x4e, 0x8e, 0xbc, 0xc9, 0x11, 0x37, 0x29,
		0xd2, 0xe6, 0xd5, 0x74, 0xe7, 0x96, 0x1b, 0x53, 0x5c, 0x1a, 0x9d, 0xfa, 0xe7, 0xfa, 0x59, 0x75,
		0x4e, 0xef, 0x91, 0x39, 0xd0, 0x6b, 0xa3, 0xc2, 0x6d, 0x86, 0xdb, 0x0c, 0xb7, 0x59, 0x2b, 0xb7,
		0x19, 0xad, 0x9b, 0xe1, 0xd9, 0xc2, 0xb3, 0x85, 0x67, 0x0b, 0xcf, 0x36, 0xbe, 0x67, 0x1b, 0x03,
		0x61, 0x2f, 0x2a, 0xd8, 0xd2, 0xc1, 0xae, 0xe5, 0x78, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00,
		0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0xab, 0x6d, 0xd9, 0xd6, 0x1f,
		0x95, 0xa7, 0x0b, 0x2b, 0x5a, 0xb0, 0x02, 0x9c, 0x01, 0x9c, 0xa1, 0x05, 0xeb, 0x1e, 0x63, 0x71,
		0xb5, 0x60, 0xcd, 0x66, 0xff, 0xd5, 0x57, 0x65, 0xb9, 0x32, 0x58, 0x83, 0xf8, 0x45, 0x27, 0xd6,
		0xcc, 0xbd, 0xfd, 0x7a, 0x5d, 0xc5, 0xcc, 0x2e, 0xc3, 0xab, 0x36, 0x4a, 0x99, 0x7b, 0xff, 0x8d,
		0x95, 0x7a, 0x32, 0xb7, 0x0a, 0x41, 0x23, 0xc5, 0x56, 0xaf, 0xf6, 0x67, 0xb3, 0x9e, 0xb1, 0xac,
		0x9f, 0x79, 0x45, 0x05, 0xc4, 0xf6, 0xeb, 0xec, 0xa2, 0x79, 0x93, 0x5b, 0x1e, 0x2f, 0x6d, 0x35,
		0x11, 0x1c, 0x35, 0x38, 0x6a, 0x70, 0xd4, 0xe0, 0xa8, 0xe9, 0xe5, 0xa8, 0xd1, 0x56, 0xfd, 0x49,
		0x90, 0xaf, 0x76, 0x7d, 0xd5, 0x6e, 0xd6, 0xce, 0xea, 0x9f, 0xeb, 0x67, 0x99, 0xf5, 0xd0, 0x50,
		0xf1, 0x29, 0x24, 0x13, 0x72, 0x5b, 0x81, 0x4b, 0x90, 0x13, 0xb6, 0x95, 0x91, 0xdf, 0x22, 0x3c,
		0x1d, 0xab, 0x23, 0xa3, 0x75, 0x78, 0x3a, 0x56, 0x46, 0x66, 0x4b, 0xf1, 0xe4, 0xae, 0x90, 0xcc,
		0x56, 0xe3, 0xc9, 0x5e, 0x15, 0xf2, 0x16, 0xe4, 0xb4, 0xee, 0x34, 0x9d, 0x5b, 0x9d, 0x1c, 0xf8,
		0x20, 0xdb, 0x40, 0x26, 0x61, 0x05, 0xe4, 0x1b, 0xc2, 0x64, 0xad, 0x82, 0x0c, 0x83, 0x97, 0xac,
		0x15, 0x90, 0x69, 0xd8, 0x92, 0x51, 0x97, 0x5f, 0x96, 0x01, 0x4b, 0xc6, 0xdb, 0x93, 0x1b, 0xaa,
		0xc4, 0x5d, 0xf2, 0xc0, 0x93, 0x7c, 0xb5, 0x3e, 0x12, 0x7b, 0xf1, 0x26, 0x17, 0xd4, 0x49, 0xee,
		0xd1, 0x9b, 0xdc, 0x85, 0x91, 0xdf, 0xbb, 0x37, 0xb9, 0x6b, 0x23, 0xb9, 0xa7, 0x6f, 0x92, 0x5d,
		0x6b, 0xb6, 0x5e, 0xbf, 0xc9, 0x5d, 0x24, 0x9e, 0x1e, 0xc0, 0x69, 0x50, 0xc9, 0x72, 0x7a, 0x03,
		0x27, 0x58, 0x72, 0xa4, 0xf7, 0x0c, 0x4e, 0xbe, 0x4e, 0x96, 0xd7, 0x4b, 0x38, 0x0d, 0xf6, 0x4a,
		0x5e, 0x8f, 0x61, 0x10, 0x59, 0x1a, 0xe3, 0xf3, 0x24, 0x35, 0x84, 0x97, 0x82, 0xc3, 0x93, 0x70,
		0x0b, 0x2a, 0x1b, 0x6f, 0x27, 0xa9, 0x17, 0xba, 0x14, 0x5c, 0x9d, 0x04, 0x06, 0x8f, 0x0d, 0x3f,
		0x27, 0x40, 0x1f, 0xb2, 0xe0, 0xe4, 0x24, 0xa9, 0x46, 0x39, 0x78, 0x38, 0x51, 0x96, 0x51, 0x12,
		0xee, 0x4d, 0x8e, 0x6e, 0x94, 0x87, 0x6f, 0x93, 0x64, 0x1f, 0xe4, 0xe1, 0xd8, 0xa4, 0xe5, 0x74,
		0x80, 0xe6, 0xde, 0x22, 0x24, 0x68, 0x9c, 0xae, 0xfb, 0x31, 0xce, 0x6e, 0xe7, 0xec, 0x57, 0x49,
		0x79, 0x38, 0xc3, 0xaf, 0xd6, 0x47, 0x5e, 0x6b, 0xfd, 0xe4, 0x92, 0x38, 0x2c, 0x2d, 0xf7, 0x93,
		0xbb, 0x3c, 0x32, 0x5b, 0xf1, 0x43, 0xe5, 0xeb, 0x7b, 0xa0, 0x13, 0xd5, 0x65, 0x48, 0xde, 0xc1,
		0x4d, 0x96, 0x08, 0x64, 0xcf, 0xe2, 0x6f, 0xcc, 0xc0, 0x85, 0xdd, 0x7f, 0xed, 0xda, 0x30, 0x37,
		0xca, 0x4f, 0xae, 0xb9, 0xe3, 0x6e, 0xa0, 0x9f, 0xca, 0x95, 0xa2, 0x6f, 0xac, 0x0f, 0xa4, 0x90,
		0x34, 0x15, 0x90, 0xe8, 0x15, 0x91, 0x72, 0xd4, 0x13, 0x2f, 0x23, 0xb4, 0x47, 0x3a, 0x21, 0x95,
		0x1d, 0x00, 0x26, 0x5e, 0x2f, 0x8b, 0xd4, 0xfe, 0xce, 0xc9, 0xb5, 0x87, 0xf2, 0xfa, 0x3e, 0x27,
		0x77, 0x4d, 0x64, 0xf6, 0x83, 0x4e, 0xee, 0xaa, 0xc8, 0xef, 0x13, 0x9d, 0x6c, 0x36, 0x4e, 0x72,
		0xff, 0xe8, 0xe4, 0x2e, 0x8e, 0xdc, 0xbe, 0xd2, 0xc9, 0x16, 0x1a, 0x69, 0xfd, 0xa6, 0x53, 0x23,
		0x2e, 0xf4, 0x7d, 0xa8, 0xe1, 0x95, 0x69, 0x8d, 0xa5, 0x12, 0xf0, 0xfa, 0xd2, 0x30, 0x93, 0xfe,
		0xef, 0x2e, 0x13, 0x1b, 0x25, 0x21, 0xf4, 0x48, 0x36, 0x06, 0x4a, 0xc6, 0x05, 0x86, 0x64, 0xac,
		0x93, 0x80, 0x28, 0x3c, 0xa9, 0x98, 0x26, 0x51, 0xb7, 0x58, 0xf4, 0xd8, 0x25, 0x71, 0xdb, 0x4f,
		0x8f, 0x51, 0x50, 0x4f, 0x93, 0xb2, 0x9e, 0xa6, 0x6f, 0x8d, 0xa4, 0x96, 0xd1, 0x9c, 0x8f, 0x8f,
		0xea, 0x99, 0xbf, 0x5d, 0x39, 0x54, 0xcf, 0x44, 0xf5, 0xcc, 0xed, 0x6f, 0x44, 0x5f, 0x3d, 0x73,
		0x76, 0x2e, 0x7d, 0xab, 0xff, 0xb7, 0xa7, 0x5d, 0x23, 0xaa, 0x6b, 0x7b, 0xd1, 0x24, 0x27, 0x67,
		0x9b, 0xb6, 0xe3, 0x89, 0xbe, 0x63, 0x0f, 0xbc, 0x1c, 0x1a, 0x5c, 0x29, 0xd1, 0x99, 0xa1, 0x61,
		0xd1, 0xe0, 0x0a, 0x0d, 0xae, 0x78, 0x77, 0x2f, 0xeb, 0x0d, 0xae, 0x58, 0x3b, 0xc8, 0x57, 0x6d,
		0xdb, 0xf1, 0xe7, 0xc0, 0x2d, 0x5e, 0x23, 0x79, 0xaf, 0xff, 0x5d, 0x8c, 0xcc, 0xb1, 0xe9, 0x7f,
		0x9f, 0x29, 0xf2, 0x23, 0x67, 0x2c, 0xec, 0xfe, 0x1c, 0x7d, 0xcd, 0x8c, 0xf1, 0xd1, 0xec, 0xb7,
		0x2d, 0xac, 0xfb, 0xef, 0xb7, 0x8e, 0xeb, 0x05, 0x9f, 0x8e, 0x3c, 0xdf, 0xf4, 0xc5, 0xd1, 0x48,
		0x78, 0x9e, 0x79, 0x2f, 0xbc, 0x23, 0x6f, 0x66, 0xc1, 0x63, 0x60, 0x5d, 0xcf, 0x77, 0x27, 0x7d,
		0xdf, 0x5e, 0x11, 0x53, 0xc1, 0x23, 0x7c, 0xba, 0x1f, 0xf7, 0x66, 0xbf, 0xaf, 0x56, 0x4f, 0x10,
		0x7c, 0xea, 0xb5, 0x67, 0x4f, 0xd0, 0xbb, 0x5c, 0x3e, 0x41, 0xaf, 0x3d, 0x7b, 0x82, 0x37, 0x3c,
		0xbb, 0xb6, 0xdf, 0x37, 0xf6, 0xdc, 0xdf, 0xb8, 0xfb, 0x4a, 0xb1, 0x9f, 0x11, 0xb6, 0x32, 0xfe,
		0x16, 0xee, 0xb7, 0x7b, 0xbb, 0xef, 0xc1, 0x1e, 0xeb, 0x9f, 0x5b, 0xad, 0x87, 0x61, 0x0e, 0x06,
		0xae, 0xf0, 0xbc, 0xbd, 0x77, 0x20, 0xc0, 0x6c, 0xa1, 0x91, 0xf6, 0x94, 0x82, 0x68, 0x86, 0x26,
		0xb2, 0xdf, 0x14, 0xc7, 0x4f, 0x8a, 0xef, 0x17, 0xc5, 0xf5, 0x83, 0xc8, 0xfc, 0x1e, 0x32, 0x3f,
		0x87, 0xc4, 0xaf, 0x91, 0xab, 0x67, 0x22, 0xfb, 0x29, 0xcf, 0x55, 0xfd, 0xc7, 0x11, 0xa5, 0xfb,
		0xa5, 0x84, 0xe7, 0x4f, 0x23, 0x7c, 0x77, 0xf9, 0xec, 0xd1, 0xdc, 0x83, 0x18, 0xb6, 0xf2, 0xf9,
		0xcd, 0x1f, 0x8a, 0x31, 0xde, 0x3d, 0xb4, 0x06, 0x31, 0x7c, 0xb1, 0x5c, 0xd3, 0xf4, 0x7d, 0xe1,
		0xda, 0xb1, 0xbd, 0xa5, 0xdc, 0xdb, 0xb7, 0x37, 0xc7, 0xc6, 0x69, 0xf7, 0xe9, 0x26, 0x6f, 0x9c,
		0x76, 0x17, 0x1f, 0xf3, 0xf3, 0x3f, 0x16, 0x9f, 0x0b, 0x37, 0xc7, 0x46, 0x71, 0xf5, 0xb9, 0x74,
		0x73, 0x6c, 0x94, 0xba, 0x87, 0xdf, 0xbe, 0xbd, 0x3f, 0xfc, 0x79, 0x32, 0xdd, 0xff, 0x8b, 0xd1,
		0x9d, 0xfc, 0x6e, 0x9c, 0xa5, 0x6a, 0xb4, 0xeb, 0x7f, 0x92, 0xad, 0xd7, 0x5f, 0x9c, 0x0b, 0xf6,
		0xaf, 0x18, 0x2b, 0xc6, 0x09, 0x4b, 0x69, 0x0e, 0x57, 0x39, 0xa5, 0x87, 0xcb, 0x34, 0xee, 0xaa,
		0xc6, 0xe7, 0xee, 0xcf, 0xfc, 0xbb, 0xe2, 0xf4, 0xe3, 0xe1, 0xcf, 0xca, 0xf4, 0xf5, 0x5f, 0x3e,
		0x6d, 0xfa, 0xb1, 0xfc, 0xbb, 0xca, 0xf4, 0xe3, 0x96, 0x7f, 0x29, 0x4f, 0x3f, 0xee, 0x38, 0x46,
		0x69, 0xfa, 0x36, 0xf4, 0xa3, 0xb3, 0xbf, 0x2f, 0x6c, 0xfb, 0x42, 0x71, 0xcb, 0x17, 0x4e, 0xb6,
		0x7d, 0xe1, 0x64, 0xcb, 0x17, 0xb6, 0x3e, 0x52, 0x61, 0xcb, 0x17, 0x4a, 0xd3, 0xa7, 0xd0, 0xcf,
		0xbf, 0xdd, 0xfc, 0xa3, 0xe5, 0xe9, 0xe1, 0xd3, 0xb6, 0x7f, 0xab, 0x4c, 0x9f, 0x3e, 0x1e, 0xa6,
		0x49, 0xd5, 0x40, 0x7c, 0xf8, 0xc5, 0x87, 0x5f, 0xf1, 0xbe, 0x91, 0x3b, 0x8f, 0x1c, 0xcf, 0x69,
		0x2c, 0x84, 0x6b, 0x98, 0x31, 0x1c, 0xa6, 0xd5, 0x00, 0xf0, 0x93, 0xe0, 0x27, 0xa5, 0xcc, 0x4f,
		0x32, 0x3d, 0xc3, 0x9e, 0x8c, 0x6e, 0x85, 0x1b, 0xc3, 0x4d, 0xaa, 0x44, 0xf8, 0x6a, 0xbc, 0x5b,
		0x94, 0x18, 0x48, 0x8e, 0xe2, 0x96, 0x84, 0xea, 0x26, 0x99, 0xe8, 0x16, 0x84, 0x92, 0x37, 0x8f,
		0x13, 0x15, 0x40, 0x71, 0xab, 0x41, 0xbd, 0xb4, 0xc5, 0xc2, 0x69, 0xf1, 0xb4, 0x5c, 0x29, 0x9c,
		0x96, 0x34, 0x5a, 0xe3, 0xac, 0xd9, 0xde, 0x7b, 0xd7, 0x99, 0x8c, 0x63, 0x9a, 0xdf, 0xc5, 0x18,
		0xb0, 0xc0, 0xb0, 0xc0, 0x29, 0xb3, 0xc0, 0x43, 0x61, 0xde, 0x45, 0xeb, 0x3d, 0x1a, 0xb0, 0x08,
		0x51, 0x0c, 0x70, 0x73, 0x79, 0x09, 0xf3, 0xfe, 0xfd, 0x51, 0xf0, 0xdf, 0xf3, 0x41, 0xf3, 0x5e,
		0x7c, 0x7e, 0xf1, 0xd1, 0x98, 0xdf, 0xa1, 0xe8, 0xa2, 0x56, 0xfc, 0x28, 0x6b, 0xbf, 0xae, 0x55,
		0xe6, 0x43, 0x40, 0xa9, 0x40, 0xa9, 0xa4, 0x4c, 0xa9, 0x44, 0x15, 0xee, 0x35, 0xb5, 0x52, 0x8c,
		0xf0, 0xdd, 0x9a, 0x3d, 0x19, 0xcd, 0x1e, 0x7d, 0xaa, 0x81, 0x92, 0xf8, 0xff, 0x26, 0x62, 0x91,
		0x49, 0x1d, 0x51, 0x43, 0x2c, 0xbf, 0x1f, 0x4d, 0x3d, 0xe4, 0xa1, 0x1e, 0xa0, 0x1e, 0xe4, 0xa8,
		0x87, 0x73, 0xcb, 0x8d, 0xb6, 0xdd, 0x96, 0x3d, 0x9e, 0xf8, 0xd1, 0xf7, 0x2a, 0xb8, 0x04, 0x99,
		0x0f, 0x13, 0x71, 0x79, 0xe3, 0xf9, 0x77, 0xb1, 0x83, 0xaf, 0x29, 0x82, 0xae, 0xe9, 0x82, 0xad,
		0xa9, 0x82, 0xac, 0xc9, 0x83, 0xab, 0xc9, 0x83, 0xaa, 0x49, 0x83, 0xa9, 0x79, 0x83, 0xd9, 0x62,
		0x07, 0x4d, 0x07, 0xf2, 0x32, 0xb1, 0x6c, 0xff, 0xa4, 0x40, 0x70, 0x6f, 0x58, 0x89, 0x31, 0x04,
		0x4d, 0xfc, 0x32, 0x41, 0x08, 0x39, 0x65, 0xbc, 0x32, 0x71, 0xf0, 0x2b, 0x75, 0x7c, 0xb2, 0x8c,
		0xc8, 0x56, 0x82, 0x78, 0x64, 0xd2, 0x38, 0x64, 0x59, 0x5b, 0x40, 0xc5, 0xe0, 0x49, 0xdd, 0x0b,
		0x45, 0x51, 0xbd, 0x5c, 0xb7, 0x78, 0x11, 0x64, 0x2d, 0xe7, 0x4c, 0x7c, 0x12, 0xb4, 0xb1, 0x1c,
		0x07, 0x70, 0x03, 0x70, 0x03, 0x70, 0x03, 0x70, 0x03, 0x70, 0x03, 0x70, 0x03, 0x70, 0x23, 0xe5,
		0x70, 0x23, 0xad, 0x49, 0x2c, 0x91, 0x18, 0xc5, 0x83, 0x58, 0x29, 0x2c, 0xff, 0xcf, 0x62, 0x4a,
		0x0d, 0xe8, 0x58, 0x57, 0x8c, 0x9c, 0x07, 0x61, 0x8c, 0x5d, 0xeb, 0xc1, 0xf4, 0x45, 0xac, 0x80,
		0xac, 0xf0, 0x50, 0xb8, 0xc3, 0x91, 0x07, 0xfb, 0x40, 0xd2, 0x2a, 0xb9, 0xc3, 0x09, 0x09, 0xb9,
		0xe1, 0x8c, 0xe7, 0x5a, 0x2b, 0xc6, 0x95, 0x4e, 0x04, 0xa3, 0x96, 0xab, 0x0f, 0x84, 0xed, 0x5b,
		0xfe, 0xe3, 0x27, 0xd3, 0x13, 0xf1, 0xdd, 0xb9, 0x56, 0xed, 0xb2, 0xf1, 0xb5, 0xd6, 0x6b, 0xb6,
		0xea, 0x5f, 0xab, 0x9d, 0x5a, 0xaf, 0xda, 0xee, 0x2d, 0x1a, 0x71, 0x46, 0x15, 0x29, 0x82, 0x72,
		0xb9, 0x44, 0x45, 0x4b, 0x5e, 0xbc, 0xd2, 0xf2, 0x25, 0xab, 0x17, 0x17, 0x39, 0x15, 0x91, 0x58,
		0x32, 0x5e, 0xa8, 0x79, 0x51, 0x3d, 0x8b, 0xfb, 0x46, 0x6f, 0x78, 0x40, 0x87, 0x0e, 0x77, 0x8f,
		0xae, 0x33, 0xf1, 0x85, 0x71, 0x37, 0x34, 0xc7, 0xc6, 0xc0, 0x1c, 0x8d, 0x2d, 0xfb, 0x3e, 0x86,
		0xb5, 0x0b, 0x8f, 0xb5, 0xef, 0x8d, 0x91, 0xb8, 0x33, 0x27, 0xc3, 0xb9, 0xb6, 0xbc, 0x33, 0x87,
		0x1e, 0x42, 0x1e, 0x60, 0x2e, 0x53, 0x67, 0x2e, 0x6f, 0x1d, 0x67, 0x28, 0xcc, 0x58, 0xd6, 0x31,
		0xaf, 0x81, 0xe2, 0xf0, 0x84, 0x3d, 0x30, 0xfa, 0xce, 0x68, 0x34, 0xb1, 0x2d, 0xff, 0x31, 0xba,
		0xd2, 0x78, 0x35, 0x4e, 0x74, 0x85, 0x71, 0xd5, 0xb8, 0xaa, 0x41, 0x5f, 0x40, 0x5f, 0xa4, 0x4d,
		0x5f, 0x04, 0x67, 0x23, 0xf3, 0x71, 0x52, 0x9e, 0xf0, 0x3c, 0xcb, 0xb1, 0x8d, 0x39, 0x47, 0x11,
		0x47, 0xe3, 0xbc, 0x1c, 0x06, 0x1a, 0x03, 0x1a, 0x23, 0x65, 0x1a, 0x43, 0xd8, 0x93, 0x91, 0x70,
		0xcd, 0xb8, 0x3e, 0x78, 0xe2, 0xd5, 0xc5, 0x64, 0x3c, 0x76, 0x5c, 0x5f, 0x0c, 0x8c, 0xbe, 0x39,
		0x36, 0x6f, 0xad, 0xa1, 0xe5, 0x5b, 0x71, 0xc2, 0x2c, 0xb7, 0x8c, 0x07, 0x05, 0x02, 0x05, 0x92,
		0x32, 0x05, 0x62, 0x2d, 0x99, 0xb4, 0x98, 0xe9, 0x1e, 0xea, 0x49, 0xbc, 0x4f, 0x5f, 0x9a, 0xbd,
		0xb3, 0x6a, 0xb3, 0xfa, 0xa9, 0x7e, 0x51, 0xef, 0xfc, 0x37, 0xf9, 0xd4, 0x5d, 0xf5, 0xfc, 0xbc,
		0xd7, 0xac, 0x76, 0xfe, 0x68, 0x27, 0x99, 0xae, 0xfb, 0xd2, 0xaa, 0x9e, 0xd5, 0x3e, 0x5f, 0x5f,
		0xf4, 0x5a, 0xb5, 0x76, 0xa7, 0xda, 0xea, 0x24, 0xf9, 0x5d, 0xaa, 0xed, 0xab, 0x93, 0x42, 0x92,
		0x5f, 0xe0, 0xb2, 0xf9, 0xe9, 0x4b, 0x33, 0xc9, 0x2f, 0x50, 0xfb, 0xb3, 0x53, 0xbb, 0x3a, 0xaf,
		0x9d, 0xf7, 0xae, 0x6a, 0x7f, 0x76, 0xfe, 0x68, 0x34, 0x7b, 0xb5, 0xab, 0xb3, 0xc6, 0x79, 0xfd,
		0xea, 0x4b, 0x92, 0x5f, 0xaa, 0xd5, 0xb8, 0xee, 0xd4, 0x7a, 0xad, 0xda, 0xe7, 0x56, 0xad, 0xfd,
		0x47, 0xea, 0x88, 0xec, 0x3d, 0xed, 0xd9, 0x85, 0xe5, 0xf9, 0x55, 0xdf, 0x8f, 0x98, 0x4b, 0x70,
		0x69, 0xd9, 0xb5, 0xa1, 0x98, 0x59, 0x6c, 0x2f, 0x5a, 0x14, 0x46, 0xee, 0xd2, 0xfc, 0xf1, 0x62,
		0x04, 0x9a, 0xf2, 0xb2, 0xb9, 0x86, 0x3b, 0x10, 0xae, 0x18, 0x7c, 0x7a, 0xcc, 0x7d, 0x3c, 0xb0,
		0x27, 0xc3, 0xa1, 0x2c, 0xbc, 0xfc, 0x86, 0x70, 0x47, 0xa2, 0x46, 0x24, 0xc4, 0x88, 0x44, 0xc8,
		0xed, 0x83, 0xf7, 0x23, 0x86, 0x1e, 0xec, 0x76, 0xbe, 0x7e, 0xbf, 0x92, 0x3b, 0xac, 0xe2, 0xbc,
		0x0c, 0xb9, 0xbb, 0xbb, 0x0f, 0xb2, 0x56, 0xbe, 0xdc, 0xdd, 0xd5, 0xd7, 0xd8, 0x33, 0xb5, 0x6b,
		0x6f, 0xdf, 0x22, 0x8a, 0x4f, 0x11, 0xdd, 0x97, 0x88, 0xea, 0x43, 0xc4, 0xf6, 0x1d, 0x62, 0xfb,
		0x0c, 0xb1, 0x7c, 0x05, 0xda, 0x93, 0xbb, 0x6f, 0x2a, 0x56, 0xae, 0xbf, 0x92, 0x89, 0x88, 0xce,
		0xf2, 0xf2, 0xfb, 0xc8, 0x49, 0x84, 0x73, 0xac, 0x15, 0x98, 0x88, 0x9c, 0x93, 0xd8, 0x77, 0x6c,
		0x5b, 0xf4, 0x7d, 0xc3, 0x15, 0xbe, 0xfb, 0x18, 0xdf, 0x33, 0x5d, 0x1f, 0x2e, 0xe2, 0x72, 0xbf,
		0xb8, 0xfd, 0x3a, 0x39, 0x46, 0xe6, 0x01, 0x32, 0x0f, 0xb8, 0xcf, 0x6a, 0x3c, 0x47, 0x43, 0x7d,
		0xe6, 0xc1, 0x40, 0xf4, 0xad, 0x91, 0x39, 0x8c, 0xd5, 0x13, 0x26, 0x30, 0x5a, 0x85, 0x18, 0x63,
		0x84, 0x82, 0xaf, 0x0b, 0x48, 0x65, 0xd8, 0xbc, 0xcc, 0x05, 0xa4, 0x32, 0xec, 0xe9, 0xbc, 0x92,
		0x6f, 0xc1, 0x49, 0x86, 0xb6, 0x00, 0x09, 0x93, 0xa1, 0x65, 0xfe, 0xee, 0x0c, 0x07, 0xf1, 0xfa,
		0xe8, 0x05, 0xfa, 0xf7, 0x79, 0xa8, 0xf8, 0x08, 0xe8, 0x14, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08,
		0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x48, 0x1e, 0x02, 0xfa, 0x5b, 0x88, 0xb1,
		0x39, 0xb4, 0x1e, 0x84, 0x61, 0xd9, 0xbe, 0x70, 0x1f, 0xcc, 0x61, 0x7c, 0x28, 0xb4, 0x61, 0x4c,
		0xb0, 0x42, 0xc0, 0x44, 0xc0, 0x44, 0xc0, 0x44, 0xc0, 0x44, 0xc0, 0x44, 0xc0, 0x44, 0xc0, 0x44,
		0x5a, 0x63, 0xa2, 0x91, 0x65, 0x5b, 0xa3, 0xc9, 0xc8, 0x30, 0x07, 0x0f, 0xc2, 0xf5, 0x2d, 0x6f,
		0x1e, 0x30, 0x43, 0x88, 0x8f, 0x7e, 0x33, 0x3e, 0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x12,
		0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x12, 0x6a, 0x80, 0x1d, 0x44, 0x8e, 0xbc, 0x5d, 0x04,
		0x9b, 0x1e, 0x45, 0x0a, 0xe1, 0x3b, 0x88, 0x18, 0x89, 0xdb, 0x99, 0xcf, 0xd9, 0x5b, 0x62, 0x21,
		0x1d, 0xb2, 0x07, 0x63, 0x26, 0x19, 0xc7, 0x48, 0x2e, 0x8e, 0x1c, 0xfe, 0x58, 0x40, 0xf8, 0xa3,
		0x4a, 0x60, 0x88, 0xf0, 0xc7, 0x9d, 0xa5, 0x06, 0xe1, 0x8f, 0x70, 0xde, 0xe0, 0xbc, 0xc1, 0x79,
		0x83, 0xf3, 0x06, 0xe7, 0x0d, 0xce, 0x1b, 0x9c, 0x37, 0x55, 0xce, 0x1b, 0xc2, 0x1f, 0x81, 0x80,
		0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x76, 0x58,
		0x66, 0x84, 0x3f, 0x02, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01, 0x13, 0x01,
		0x13, 0x01, 0x13, 0x21, 0xfc, 0x11, 0x58, 0x09, 0x58, 0x09, 0x58, 0x09, 0x58, 0x09, 0x58, 0x09,
		0x58, 0x09, 0x58, 0x09, 0x58, 0xe9, 0x57, 0xcb, 0x6c, 0x8b, 0x7b, 0xc7, 0xb7, 0x4c, 0x5f, 0x0c,
		0x0c, 0xc2, 0xcb, 0xb4, 0x8d, 0xa3, 0x02, 0xd2, 0x00, 0xd2, 0x00, 0xd2, 0x00, 0xd2, 0x00, 0xd2,
		0x00, 0xd2, 0x00, 0xd2, 0x00, 0xd2, 0xd0, 0x7f, 0x23, 0x49, 0x19, 0x1d, 0x51, 0x92, 0x12, 0x0e,
		0xe2, 0x25, 0x74, 0xec, 0x51, 0x61, 0x7d, 0xff, 0xf5, 0x4f, 0x70, 0x75, 0xfb, 0xbd, 0x0a, 0xba,
		0xc7, 0xdb, 0x03, 0xd6, 0xfa, 0xf6, 0xae, 0x69, 0x7b, 0x63, 0xc7, 0xf5, 0x23, 0x94, 0xb8, 0x0f,
		0xbe, 0x8a, 0x2a, 0xf7, 0x8c, 0xa0, 0x1a, 0x55, 0xee, 0x51, 0xe5, 0x5e, 0xa6, 0x17, 0x89, 0x34,
		0x2f, 0x05, 0x20, 0x23, 0x72, 0x9a, 0xd7, 0xd0, 0xe9, 0x9b, 0x43, 0xc3, 0x1c, 0x0c, 0x5c, 0xe1,
		0x79, 0xf1, 0x39, 0x99, 0xf5, 0xe1, 0x40, 0xc6, 0x80, 0x8c, 0x01, 0x19, 0xb3, 0x97, 0xbc, 0x4c,
		0xec, 0x68, 0x4d, 0x5c, 0x43, 0xb6, 0xe6, 0x34, 0xc6, 0x18, 0xcb, 0xd7, 0x51, 0x4e, 0x9d, 0x04,
		0xed, 0x29, 0xc7, 0x31, 0x55, 0x0a, 0xf5, 0x0a, 0xd1, 0xae, 0x14, 0xdd, 0x8a, 0x6d, 0x58, 0xb9,
		0x87, 0x22, 0xe1, 0xda, 0x85, 0xd6, 0xf0, 0x03, 0xe1, 0x98, 0x4d, 0xd3, 0xf7, 0x85, 0x6b, 0x93,
		0x2d, 0x67, 0x30, 0xf0, 0xdb, 0xb7, 0x37, 0xc7, 0xc6, 0x69, 0xf7, 0xe9, 0x26, 0x6f, 0x9c, 0x76,
		0x17, 0x1f, 0xf3, 0xf3, 0x3f, 0x16, 0x9f, 0x0b, 0x37, 0xc7, 0x46, 0x71, 0xf5, 0xb9, 0x74, 0x73,
		0x6c, 0x94, 0xba, 0x87, 0xdf, 0xbe, 0xbd, 0x3f, 0xfc, 0x79, 0x32, 0xdd, 0xff, 0x8b, 0x39, 0xb2,
		0x47, 0xef, 0x52, 0x2e, 0x6d, 0xa3, 0x5d, 0xff, 0x53, 0xda, 0xfa, 0xfe, 0xc5, 0xb9, 0xc0, 0xff,
		0x22, 0x5c, 0x61, 0x92, 0x91, 0xa6, 0xef, 0x34, 0x3e, 0xfc, 0x65, 0x1c, 0xfe, 0xb9, 0x88, 0x99,
		0xc6, 0x5d, 0xd5, 0xf8, 0xdc, 0xfd, 0x99, 0x7f, 0x57, 0x9c, 0x7e, 0x3c, 0xfc, 0x59, 0x99, 0xbe,
		0xfe, 0xcb, 0xa7, 0x4d, 0x3f, 0x96, 0x7f, 0x57, 0x99, 0x7e, 0xdc, 0xf2, 0x2f, 0xe5, 0xe9, 0xc7,
		0x1d, 0xc7, 0x28, 0x4d, 0xdf, 0x86, 0x7e, 0x74, 0xf6, 0xf7, 0x85, 0x6d, 0x5f, 0x28, 0x6e, 0xf9,
		0xc2, 0xc9, 0xb6, 0x2f, 0x9c, 0x6c, 0xf9, 0xc2, 0xd6, 0x47, 0x2a, 0x6c, 0xf9, 0x42, 0x69, 0xfa,
		0x14, 0xfa, 0xf9, 0xb7, 0x9b, 0x7f, 0xb4, 0x3c, 0x3d, 0x7c, 0xda, 0xf6, 0x6f, 0x95, 0xe9, 0xd3,
		0xc7, 0xc3, 0x2c, 0xab, 0x42, 0x88, 0x1b, 0xbf, 0xb8, 0xe9, 0x67, 0x18, 0xde, 0xa8, 0x7d, 0x8e,
		0x98, 0x86, 0x89, 0x10, 0xbf, 0x7b, 0xbe, 0x6b, 0xd9, 0xf7, 0x94, 0xd8, 0xfd, 0x03, 0xa2, 0x6c,
		0x42, 0x6b, 0x33, 0xf2, 0x27, 0xc6, 0xc0, 0xf2, 0xfa, 0xce, 0x83, 0xa0, 0xa8, 0xd8, 0xb3, 0x3e,
		0x5c, 0xfc, 0x78, 0xe3, 0x3b, 0x73, 0xe8, 0x21, 0x3e, 0x07, 0x94, 0x10, 0x28, 0xa1, 0x3d, 0xe5,
		0xe5, 0xd6, 0x71, 0x86, 0xc2, 0x24, 0x21, 0x85, 0xf2, 0x1a, 0xab, 0xaf, 0xb1, 0xe9, 0x79, 0xd6,
		0x83, 0x30, 0x46, 0xce, 0x80, 0x20, 0x38, 0x70, 0x6d, 0x34, 0x28, 0x2f, 0x28, 0x2f, 0x28, 0x2f,
		0x28, 0x2f, 0x79, 0xca, 0xcb, 0xef, 0x8f, 0x8d, 0x11, 0xc5, 0x05, 0xda, 0x6a, 0x20, 0xa8, 0x1a,
		0xa8, 0x1a, 0xa8, 0x9a, 0xbd, 0xe4, 0x65, 0x62, 0xd9, 0x7e, 0xbe, 0x4c, 0xa0, 0x69, 0xca, 0x08,
		0x3b, 0x26, 0x55, 0x2b, 0xa1, 0xe1, 0x10, 0x76, 0xac, 0xcd, 0x16, 0x94, 0x4b, 0xa5, 0x93, 0x12,
		0x42, 0x8f, 0x95, 0xf1, 0x3c, 0x29, 0x0c, 0x3d, 0x5e, 0x85, 0x75, 0x32, 0xd7, 0x93, 0x5f, 0x4d,
		0x8b, 0x92, 0xf2, 0x28, 0x29, 0xcf, 0x8e, 0xec, 0x10, 0x6b, 0xb8, 0xc3, 0x17, 0x11, 0x6b, 0x08,
		0x87, 0x09, 0x0e, 0x93, 0x46, 0x0e, 0x13, 0x62, 0x0d, 0xc3, 0x8b, 0x82, 0x58, 0xc3, 0xe8, 0x2b,
		0x87, 0x58, 0x43, 0xc4, 0x1a, 0x22, 0xd6, 0x90, 0xd0, 0xa1, 0x94, 0xc0, 0x4a, 0x1c, 0x20, 0xd6,
		0x10, 0xb1, 0x86, 0x88, 0x35, 0x4c, 0x8f, 0x2a, 0x84, 0xb8, 0x21, 0xd6, 0x10, 0xb1, 0x86, 0x88,
		0x35, 0x8c, 0xce, 0x41, 0xbf, 0x8b, 0x4a, 0xe5, 0xec, 0x95, 0xf7, 0xff, 0x1b, 0x1e, 0x67, 0x8f,
		0x42, 0x00, 0x20, 0x71, 0x40, 0xe2, 0x80, 0xc4, 0x59, 0x05, 0xba, 0x39, 0xae, 0x6f, 0xd8, 0x93,
		0xd1, 0xad, 0x70, 0x71, 0xf5, 0xbd, 0x78, 0x10, 0x5c, 0x7d, 0xab, 0x76, 0x32, 0x71, 0xf5, 0x8d,
		0xab, 0x6f, 0x19, 0xb0, 0x03, 0x29, 0x0e, 0x00, 0x31, 0x00, 0x31, 0xe9, 0x03, 0x31, 0x48, 0x71,
		0x88, 0x82, 0xfc, 0x90, 0xe2, 0x00, 0xe5, 0x05, 0xe5, 0x05, 0xe5, 0xc5, 0xa3, 0xbc, 0x5c, 0x31,
		0x72, 0x7c, 0x41, 0x17, 0xbe, 0xf3, 0x6a, 0x3c, 0x28, 0x1e, 0x28, 0x1e, 0x28, 0x9e, 0xbd, 0xe4,
		0x85, 0x24, 0x54, 0x25, 0xa5, 0x41, 0x3c, 0xa4, 0xa1, 0x28, 0x94, 0xb7, 0xd0, 0xe4, 0xb7, 0xcf,
		0x09, 0x0b, 0x39, 0xe9, 0x52, 0x2c, 0xa1, 0x8c, 0x7b, 0xd5, 0xc4, 0x85, 0x96, 0xa4, 0xe5, 0xc6,
		0x8e, 0x38, 0x74, 0x24, 0x09, 0x87, 0x15, 0x77, 0xf6, 0x49, 0x0c, 0x11, 0xd1, 0x5e, 0x75, 0x41,
		0xac, 0x12, 0x19, 0x0a, 0xd2, 0x05, 0xd3, 0xbf, 0xcd, 0xdb, 0xa4, 0x89, 0x30, 0x78, 0x39, 0x18,
		0xfc, 0x4c, 0xf8, 0x99, 0xf0, 0x33, 0xf7, 0x23, 0x9a, 0x11, 0x62, 0xf0, 0xfa, 0x41, 0x10, 0x62,
		0x70, 0xa0, 0xd0, 0xf9, 0x38, 0x40, 0x88, 0x01, 0x42, 0x0c, 0x24, 0x01, 0x0f, 0x54, 0xf2, 0x01,
		0xe0, 0x00, 0xe0, 0x50, 0x0b, 0x38, 0x50, 0xc9, 0x07, 0x58, 0x03, 0x58, 0x03, 0x58, 0x23, 0x51,
		0x58, 0x23, 0xcd, 0x95, 0x7c, 0x58, 0xfb, 0x88, 0x06, 0x85, 0x7c, 0xd0, 0x4a, 0xf4, 0x37, 0xfb,
		0x22, 0xbb, 0x9b, 0x68, 0x30, 0x0f, 0x63, 0x43, 0xd1, 0x89, 0x27, 0x8c, 0xd1, 0x64, 0xe8, 0x5b,
		0xe3, 0xa1, 0x30, 0x66, 0x0b, 0xe3, 0xed, 0xdf, 0x59, 0x74, 0xc3, 0x18, 0x68, 0x31, 0xca, 0x88,
		0x92, 0xd1, 0x62, 0x14, 0x2d, 0x46, 0x65, 0xba, 0x85, 0x28, 0xfb, 0xa5, 0x00, 0x82, 0x44, 0x2e,
		0xfb, 0x25, 0x6c, 0xf3, 0x76, 0x28, 0x06, 0xf1, 0x19, 0x95, 0xd5, 0x40, 0x88, 0x75, 0x06, 0x33,
		0x03, 0x66, 0x46, 0x09, 0x33, 0x93, 0xc4, 0x58, 0xe7, 0xf4, 0x39, 0x66, 0x61, 0x7c, 0xcb, 0x5b,
		0x6b, 0xf5, 0xda, 0x13, 0x97, 0xcb, 0xe9, 0x9b, 0xb3, 0xd9, 0x35, 0x2a, 0xb9, 0x2a, 0x66, 0xc7,
		0x32, 0x32, 0xf6, 0x12, 0xfb, 0x2b, 0x43, 0x20, 0x2f, 0x20, 0x2f, 0x5d, 0x91, 0x57, 0x44, 0x57,
		0x84, 0xc6, 0x25, 0x89, 0x79, 0x40, 0x80, 0x97, 0x80, 0x97, 0x54, 0xe1, 0xa5, 0xa8, 0x07, 0x2e,
		0x18, 0xc0, 0x1c, 0x0e, 0x9d, 0x7f, 0x9e, 0x4d, 0xb4, 0xe9, 0xc5, 0xdf, 0xef, 0x95, 0x04, 0x86,
		0x87, 0x8e, 0xb9, 0x4d, 0x44, 0x6e, 0x11, 0x91, 0x7b, 0x44, 0x76, 0xec, 0x29, 0x8f, 0x3f, 0xbd,
		0x1a, 0xa0, 0x56, 0x07, 0xd2, 0xd4, 0x82, 0x34, 0xf5, 0x20, 0x45, 0x4d, 0xc4, 0x53, 0x17, 0x31,
		0xd5, 0x06, 0x9d, 0xbb, 0x25, 0xc1, 0xed, 0x22, 0x72, 0xbf, 0xe2, 0x2f, 0x30, 0xaf, 0x26, 0x8f,
		0xe9, 0x9e, 0x91, 0xbb, 0x69, 0x33, 0x07, 0xe3, 0x28, 0x16, 0x9c, 0x22, 0xf3, 0xd9, 0x6a, 0xb7,
		0xf7, 0xe3, 0x48, 0x8e, 0x5b, 0x0c, 0x57, 0x3c, 0x92, 0x7b, 0x1a, 0xa5, 0x87, 0x46, 0xe8, 0x04,
		0x45, 0xbd, 0xc1, 0x24, 0x45, 0xb0, 0x05, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20,
		0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0xd8, 0xa4, 0x22, 0xd8, 0x38, 0x68, 0x8a, 0x16, 0xc0, 0x46,
		0x88, 0x11, 0x8b, 0x81, 0x5f, 0x33, 0x71, 0x95, 0x24, 0x22, 0x5e, 0x0d, 0x50, 0xed, 0x29, 0x3a,
		0xf7, 0xb1, 0x78, 0x17, 0xb8, 0x48, 0xa2, 0x85, 0x05, 0x08, 0xe1, 0xd9, 0x41, 0x5e, 0x10, 0xc2,
		0x03, 0x87, 0x1e, 0x0e, 0xbd, 0x0a, 0x44, 0x8e, 0x10, 0x1e, 0xdd, 0x71, 0x17, 0x67, 0x92, 0x45,
		0x08, 0x78, 0x21, 0xd7, 0x62, 0xd7, 0x7d, 0x92, 0x9c, 0x74, 0xf1, 0x7a, 0x67, 0xc8, 0x72, 0x2f,
		0xde, 0xc4, 0x58, 0xfb, 0x99, 0x6a, 0x9f, 0xbd, 0xc1, 0x6a, 0x59, 0x76, 0x2c, 0xd7, 0x95, 0xbb,
		0xb0, 0x3c, 0xbf, 0xea, 0xfb, 0xbb, 0xa1, 0x8e, 0xdc, 0xa5, 0x65, 0xd7, 0x86, 0x62, 0xa6, 0x9f,
		0xbd, 0xdd, 0x6c, 0x6b, 0xee, 0xd2, 0xfc, 0xf1, 0xe2, 0x1b, 0xf9, 0x0f, 0xc5, 0x62, 0xb9, 0x52,
		0x2c, 0x1e, 0x57, 0x4e, 0x2a, 0xc7, 0xa7, 0xa5, 0x52, 0xbe, 0x9c, 0xdf, 0x21, 0x21, 0x2e, 0xd7,
		0x70, 0x07, 0xc2, 0x15, 0x83, 0x4f, 0xb3, 0x37, 0xb4, 0x27, 0xc3, 0x61, 0xac, 0x85, 0xda, 0x53,
		0x38, 0x23, 0x09, 0xe5, 0x0e, 0x12, 0x18, 0x41, 0xf2, 0x7e, 0x2d, 0x68, 0xdb, 0xc5, 0x67, 0xf3,
		0xbf, 0x6c, 0x59, 0xa7, 0x5d, 0xd7, 0x67, 0x9f, 0x75, 0xf9, 0xc5, 0x72, 0xec, 0xbe, 0x0c, 0x9b,
		0xdf, 0x3e, 0xfc, 0x6e, 0x1b, 0xde, 0x2b, 0x37, 0x16, 0xc2, 0x35, 0xee, 0x5d, 0x67, 0x32, 0xde,
		0xce, 0x92, 0x3f, 0x17, 0x53, 0x79, 0xf1, 0xc3, 0x5b, 0xd6, 0xe8, 0xd7, 0x8e, 0xe0, 0x6f, 0xd1,
		0xe7, 0x2e, 0xe8, 0x72, 0x77, 0xf4, 0xb8, 0x2b, 0x3a, 0xdc, 0x1b, 0xfd, 0xed, 0x8d, 0xee, 0xf6,
		0x42, 0x6f, 0xfb, 0x49, 0xe5, 0xef, 0x1c, 0xa3, 0x17, 0xbb, 0xf6, 0xfb, 0x85, 0x08, 0xef, 0xf4,
		0xef, 0x56, 0x62, 0x37, 0xcf, 0x7f, 0x67, 0xb7, 0x63, 0x1f, 0xf7, 0x62, 0x7f, 0x37, 0x62, 0x5f,
		0x77, 0x21, 0xb2, 0x5b, 0x10, 0x19, 0xfe, 0x47, 0x82, 0xf9, 0xf1, 0xec, 0xe3, 0xae, 0x9e, 0x75,
		0xce, 0xbc, 0xb3, 0x0c, 0xcf, 0xbc, 0xb3, 0x22, 0x64, 0x35, 0x3e, 0x7f, 0x15, 0xc9, 0x8c, 0x8c,
		0x5e, 0x69, 0xa6, 0x93, 0x19, 0x57, 0x32, 0x17, 0x9d, 0x0a, 0x0d, 0x46, 0x40, 0x58, 0x3d, 0xd8,
		0xd0, 0x74, 0xb0, 0xa1, 0xe6, 0x60, 0xb0, 0x67, 0x66, 0xfa, 0xf6, 0xd3, 0x11, 0x0c, 0x85, 0xe0,
		0x7a, 0x30, 0x99, 0x99, 0x60, 0x32, 0x63, 0x87, 0x26, 0xc5, 0xcc, 0x6a, 0x09, 0x89, 0x5d, 0xec,
		0x70, 0x4c, 0x82, 0x83, 0x48, 0x76, 0x20, 0x29, 0x0f, 0x26, 0xfd, 0x01, 0xa5, 0x3e, 0xa8, 0xd2,
		0x0e, 0xac, 0xb4, 0x83, 0x2b, 0xe5, 0x00, 0xc7, 0x3b, 0xc8, 0x31, 0x0f, 0x34, 0xd9, 0xc1, 0x0e,
		0x06, 0x12, 0x43, 0xeb, 0xde, 0xba, 0x1d, 0x0a, 0x63, 0xb1, 0x95, 0xc6, 0xd8, 0x19, 0x5a, 0xfd,
		0x47, 0x3a, 0x61, 0x09, 0x2e, 0x23, 0x37, 0xcf, 0xf3, 0x4e, 0xcb, 0x32, 0x5f, 0x54, 0x8a, 0x41,
		0x86, 0x82, 0x90, 0xa7, 0x28, 0x64, 0x29, 0x0c, 0xe9, 0x8a, 0x43, 0xba, 0x02, 0x91, 0xaa, 0x48,
		0x68, 0x14, 0x0a, 0x91, 0x62, 0x09, 0xde, 0x94, 0x2c, 0x2a, 0x31, 0x24, 0xaf, 0x43, 0x61, 0xde,
		0xb9, 0xe2, 0x8e, 0x52, 0x60, 0x57, 0x78, 0xa0, 0x42, 0x38, 0x66, 0x33, 0xa0, 0xc3, 0xfb, 0x86,
		0x3b, 0x76, 0x86, 0x1f, 0x5d, 0x67, 0xe2, 0x5b, 0xf6, 0xfd, 0x52, 0x73, 0x05, 0x7f, 0xbd, 0xf8,
		0xbf, 0xc6, 0x40, 0xdc, 0x59, 0xb6, 0xe5, 0x5b, 0x8e, 0xed, 0x6d, 0xff, 0xa7, 0xe0, 0x5f, 0xe6,
		0x24, 0xf9, 0x1b, 0x3d, 0xa4, 0x86, 0xa2, 0x66, 0xa3, 0x2b, 0xfa, 0xc2, 0x7a, 0x10, 0xf4, 0x66,
		0x63, 0x35, 0x30, 0x91, 0x54, 0x13, 0x47, 0xaf, 0xc3, 0xfe, 0xc0, 0xfe, 0xc0, 0xfe, 0x24, 0xcc,
		0xfe, 0xd0, 0x45, 0xc7, 0x87, 0xec, 0x4f, 0x3e, 0x45, 0x2a, 0xdd, 0x13, 0xf6, 0x80, 0x5e, 0x9f,
		0xcf, 0x47, 0x85, 0x32, 0x87, 0x32, 0x87, 0x32, 0x87, 0x32, 0x87, 0x32, 0xe7, 0x54, 0xe6, 0xc6,
		0x88, 0xb2, 0xb0, 0xfa, 0x4b, 0x85, 0x3e, 0x1f, 0x19, 0xca, 0x17, 0xca, 0x17, 0xca, 0x37, 0x53,
		0xca, 0x77, 0x62, 0xd9, 0xfe, 0x07, 0x09, 0xaa, 0xb7, 0x44, 0x38, 0x24, 0x4d, 0x67, 0x91, 0xd7,
		0xbf, 0x68, 0x8f, 0xd3, 0x01, 0x75, 0xe7, 0x11, 0xc9, 0x5a, 0x35, 0x34, 0x3c, 0x71, 0x67, 0x92,
		0xd0, 0xf8, 0x12, 0x5a, 0x64, 0x48, 0x3a, 0x6d, 0xeb, 0x5b, 0x6a, 0xfe, 0x48, 0xfc, 0x96, 0x16,
		0x4a, 0xa5, 0x04, 0x6f, 0xea, 0x1b, 0x3d, 0x47, 0xeb, 0xea, 0x02, 0x2d, 0x95, 0xde, 0x61, 0x12,
		0x65, 0xdb, 0x3f, 0x83, 0xdc, 0xdf, 0x86, 0xb1, 0xbf, 0x88, 0x07, 0x7f, 0xf1, 0xf9, 0x28, 0x08,
		0xf6, 0x0c, 0x3e, 0x1d, 0x05, 0xb1, 0x42, 0x47, 0x24, 0x11, 0x0b, 0x07, 0xbb, 0xc4, 0xc7, 0x37,
		0x85, 0x70, 0xbf, 0xcc, 0x1f, 0xee, 0xf9, 0x63, 0xaf, 0x7a, 0x67, 0xb5, 0x67, 0x8f, 0xb6, 0xfa,
		0xd0, 0xab, 0x0e, 0x06, 0xd1, 0xeb, 0x00, 0xd3, 0x09, 0xc0, 0x34, 0x56, 0x41, 0x82, 0x38, 0x65,
		0xa6, 0xc2, 0x2e, 0x48, 0xcc, 0x02, 0x09, 0x07, 0x32, 0x42, 0x4a, 0x0a, 0x08, 0x29, 0xd1, 0xc0,
		0x9f, 0x40, 0x48, 0xc9, 0xee, 0x6f, 0x84, 0x90, 0x12, 0x10, 0x11, 0x20, 0x22, 0x40, 0x44, 0x24,
		0x90, 0x88, 0x40, 0x48, 0x09, 0x42, 0x4a, 0x76, 0x16, 0x16, 0x84, 0x94, 0xc0, 0xfe, 0xc0, 0xfe,
		0xc0, 0xfe, 0x10, 0xca, 0x2b, 0x6e, 0x21, 0x77, 0xf3, 0xfb, 0x11, 0x52, 0x02, 0x65, 0x0e, 0x65,
		0x0e, 0x65, 0x0e, 0x65, 0x9e, 0x0e, 0x65, 0x8e, 0x90, 0x12, 0x28, 0x5f, 0x28, 0x5f, 0x28, 0x5f,
		0x3a, 0x79, 0x45, 0x48, 0x09, 0xa1, 0x40, 0x22, 0xa4, 0x64, 0xfb, 0xf8, 0x08, 0x29, 0x51, 0xb6,
		0xa5, 0x08, 0x29, 0x91, 0x30, 0x1a, 0x42, 0x4a, 0x92, 0x13, 0x52, 0x42, 0x11, 0xb0, 0x70, 0x20,
		0x21, 0xa2, 0x24, 0x46, 0x7f, 0x87, 0xf8, 0xdb, 0x9f, 0xd6, 0x4e, 0x1f, 0x11, 0x04, 0x44, 0x66,
		0xb3, 0x8f, 0xfd, 0x44, 0x42, 0xe7, 0x66, 0x75, 0xab, 0x75, 0x33, 0x96, 0x2f, 0x1b, 0xb7, 0x3a,
		0xd4, 0xda, 0x70, 0xa8, 0x75, 0x8f, 0x0a, 0x51, 0x8a, 0x5c, 0xbf, 0xa4, 0xd6, 0xba, 0x8f, 0x7f,
		0x09, 0x4f, 0x71, 0xe9, 0x1e, 0x5c, 0xb2, 0xbf, 0x7f, 0xbf, 0x0c, 0xdd, 0x3c, 0x5a, 0x3f, 0xd9,
		0x3a, 0x6b, 0xb4, 0xf1, 0x78, 0xf8, 0x18, 0x37, 0x5c, 0xea, 0x59, 0xa1, 0xbd, 0x1c, 0x0d, 0x15,
		0xef, 0x72, 0xcb, 0x40, 0x09, 0x28, 0xb4, 0x08, 0x0a, 0x6d, 0xbe, 0x70, 0xa8, 0x79, 0x17, 0x4d,
		0xf0, 0x50, 0xf3, 0x8e, 0xef, 0x88, 0x52, 0x1f, 0x55, 0x69, 0x47, 0x56, 0xda, 0xd1, 0x95, 0x73,
		0x84, 0xf5, 0x70, 0xef, 0xc9, 0x42, 0x94, 0x07, 0x8b, 0x7b, 0x7e, 0x43, 0xfc, 0x18, 0x3b, 0xae,
		0x2f, 0x2d, 0x42, 0x79, 0xf3, 0x34, 0xf4, 0xb1, 0x0a, 0xad, 0xda, 0xff, 0xd5, 0xce, 0x3a, 0xbd,
		0x56, 0xe3, 0xba, 0x53, 0xc3, 0xad, 0x99, 0x4e, 0x7a, 0x48, 0x96, 0x3e, 0x92, 0xae, 0x97, 0xa4,
		0xeb, 0x27, 0xb9, 0x7a, 0x8a, 0x96, 0x60, 0xd5, 0xff, 0xde, 0x6c, 0xa5, 0x69, 0x96, 0xf1, 0xc1,
		0xfe, 0x6c, 0x22, 0x09, 0x01, 0x0c, 0x45, 0xc2, 0x31, 0x6b, 0xf6, 0x64, 0x34, 0x5b, 0x8c, 0x69,
		0x8a, 0x82, 0x22, 0x56, 0xdb, 0x60, 0x8d, 0x58, 0xec, 0xca, 0xfa, 0x34, 0xb0, 0x2b, 0xb0, 0x2b,
		0xb0, 0x2b, 0xb0, 0x2b, 0xb0, 0x2b, 0xa9, 0xb3, 0x2b, 0x92, 0xfd, 0x14, 0x29, 0xfe, 0x09, 0x14,
		0x3d, 0x14, 0x3d, 0x14, 0x7d, 0x52, 0x14, 0x3d, 0x52, 0x28, 0x49, 0x53, 0x28, 0x89, 0xf6, 0x7b,
		0xaf, 0x9e, 0xae, 0x3b, 0x8f, 0xba, 0x77, 0xef, 0xd7, 0xdd, 0x47, 0x26, 0xe8, 0x11, 0xbb, 0xf3,
		0x64, 0x2f, 0x7b, 0xc9, 0x12, 0x2b, 0xc5, 0x20, 0x1c, 0xd5, 0x13, 0x2e, 0xb5, 0x3e, 0x94, 0xa4,
		0xc8, 0x5f, 0x2b, 0x73, 0x67, 0xb1, 0x3a, 0xc6, 0xed, 0x63, 0x4e, 0x42, 0x1c, 0xa2, 0x6c, 0xa5,
		0x1e, 0x52, 0xec, 0xf3, 0x9d, 0xd0, 0x34, 0xf6, 0x2e, 0x4d, 0x48, 0x53, 0x32, 0x73, 0x21, 0x85,
		0xb1, 0x00, 0xd2, 0x04, 0xd2, 0x04, 0xd2, 0x04, 0xd2, 0x04, 0xd2, 0x04, 0xd2, 0x04, 0xd2, 0x04,
		0xd2, 0x04, 0xd2, 0x94, 0x8e, 0x34, 0x91, 0xe5, 0xb1, 0x2d, 0x88, 0xff, 0x45, 0xd4, 0xa5, 0x7e,
		0xb5, 0x43, 0x67, 0x0f, 0xd7, 0x9c, 0x3f, 0x1b, 0xca, 0x87, 0xa2, 0x7c, 0xa8, 0x32, 0x57, 0x03,
		0xd1, 0x79, 0x88, 0xce, 0xfb, 0xc5, 0x40, 0x88, 0xce, 0x03, 0xe5, 0x01, 0xca, 0x03, 0x94, 0x47,
		0x6a, 0x28, 0x0f, 0x44, 0x51, 0x20, 0x3a, 0x0f, 0x76, 0x05, 0x76, 0x05, 0x76, 0x05, 0x76, 0x05,
		0x76, 0x05, 0xd1, 0x79, 0xfb, 0xed, 0x32, 0xa2, 0xf3, 0xa0, 0xe8, 0xa1, 0xe8, 0x33, 0xad, 0xe8,
		0x71, 0x67, 0x8a, 0x3b, 0x53, 0x82, 0x91, 0x71, 0x67, 0xaa, 0x4a, 0x91, 0x1f, 0xe0, 0xce, 0x54,
		0x85, 0x66, 0x3f, 0x40, 0x74, 0xde, 0x3e, 0x07, 0x0a, 0xd1, 0x79, 0x40, 0x9a, 0x40, 0x9a, 0x40,
		0x9a, 0x40, 0x9a, 0x40, 0x9a, 0x40, 0x9a, 0x40, 0x9a, 0x40, 0x9a, 0xc9, 0x44, 0x9a, 0x88, 0xce,
		0xdb, 0x25, 0x3a, 0x4f, 0xb7, 0x32, 0xcc, 0x2f, 0x82, 0xf3, 0x50, 0x89, 0x59, 0x1b, 0x31, 0xd1,
		0xa0, 0x18, 0xf3, 0xb3, 0x60, 0xe8, 0x5c, 0xbd, 0x34, 0x66, 0xd9, 0x44, 0x9a, 0x72, 0x89, 0x69,
		0xab, 0x58, 0x8a, 0x0a, 0xcc, 0xd1, 0x9c, 0xbf, 0x04, 0x55, 0x60, 0x8e, 0x5d, 0xaf, 0x94, 0xa6,
		0x10, 0x7a, 0x48, 0xfa, 0x28, 0x0a, 0xa2, 0x13, 0x93, 0x40, 0xda, 0x57, 0x2f, 0xa5, 0xe9, 0xb5,
		0x85, 0xf0, 0x68, 0x29, 0xbd, 0xb4, 0xd4, 0xc2, 0x62, 0x32, 0xca, 0xe6, 0x99, 0xad, 0x1d, 0x08,
		0xdb, 0xb7, 0xfc, 0x47, 0x1a, 0xba, 0x26, 0xb0, 0x9c, 0x04, 0xae, 0x79, 0xae, 0xbe, 0x7c, 0xb4,
		0x4f, 0xa6, 0x27, 0xa1, 0x83, 0x77, 0xf5, 0x73, 0xbd, 0xd7, 0x9e, 0xfd, 0x4f, 0xe7, 0xbf, 0x4d,
		0xb2, 0xc8, 0xb7, 0x79, 0x77, 0x22, 0x8f, 0xb4, 0xad, 0x97, 0x24, 0x32, 0xa2, 0xdd, 0xea, 0xd4,
		0x7a, 0xcd, 0xc6, 0x45, 0xfd, 0xec, 0xbf, 0xbd, 0x7a, 0xf3, 0x6b, 0x99, 0x90, 0xe4, 0x7c, 0xa7,
		0xfb, 0xbb, 0x5f, 0x9c, 0x7c, 0x6d, 0x5e, 0xcd, 0xde, 0xba, 0xd8, 0xbb, 0xbe, 0xaa, 0x9f, 0x55,
		0xdb, 0x9d, 0x4c, 0xbd, 0x7d, 0xfd, 0xea, 0xdf, 0xed, 0x4e, 0xb5, 0x53, 0xeb, 0xb5, 0x9b, 0x9f,
		0x33, 0xba, 0xed, 0x97, 0xd7, 0x17, 0x9d, 0xcc, 0x6d, 0xfc, 0xd7, 0xe6, 0xd5, 0xd7, 0x62, 0xef,
		0xf3, 0x45, 0xe3, 0x3f, 0xed, 0x66, 0xed, 0x2c, 0x4b, 0x6f, 0xfe, 0x4a, 0xd9, 0x15, 0x33, 0x25,
		0xf5, 0x85, 0x99, 0xd4, 0x7f, 0x6d, 0x5e, 0xb4, 0xb3, 0xf7, 0xd6, 0xb5, 0xaf, 0xcd, 0xab, 0x4c,
		0xaa, 0xf6, 0x2c, 0xbd, 0xf4, 0x5c, 0xa1, 0x5f, 0x54, 0x3f, 0xd5, 0x2e, 0x6a, 0xe7, 0xd9, 0xb6,
		0xe7, 0x59, 0x93, 0xf6, 0x95, 0x3d, 0x2f, 0x67, 0xd3, 0x9e, 0xcf, 0x05, 0x3f, 0x8b, 0xe6, 0x7c,
		0xbe, 0xe5, 0x59, 0x3e, 0xf1, 0xcf, 0x82, 0x9f, 0xc1, 0xb7, 0xcf, 0xaa, 0xdf, 0x26, 0x69, 0xbf,
		0x49, 0x46, 0xea, 0xaa, 0xe6, 0xd5, 0x94, 0xd4, 0x10, 0x11, 0xb6, 0x79, 0x3b, 0x14, 0x03, 0x3a,
		0xb6, 0x7c, 0x35, 0x60, 0xdc, 0x1a, 0x0a, 0xcf, 0xe9, 0x9d, 0x77, 0xe6, 0xd0, 0x03, 0xef, 0xbe,
		0xc3, 0xd2, 0x83, 0x77, 0x07, 0xef, 0xbe, 0xfd, 0x8d, 0xe8, 0x79, 0xf7, 0x5b, 0xc7, 0x19, 0x0a,
		0xd3, 0xa6, 0xe4, 0xdc, 0xf3, 0x08, 0xf5, 0xd8, 0x63, 0x1c, 0xca, 0x50, 0x8f, 0xd8, 0x25, 0xba,
		0x88, 0x82, 0x3c, 0xe2, 0x94, 0xe3, 0xe2, 0x89, 0xef, 0xb8, 0x77, 0xcd, 0xbe, 0xb8, 0x9b, 0x0c,
		0x0d, 0x57, 0x78, 0xbe, 0xe9, 0xfa, 0xf1, 0x23, 0x3d, 0x42, 0x23, 0x22, 0xe6, 0x03, 0x31, 0x1f,
		0x8a, 0x8c, 0x15, 0x7a, 0xd4, 0xa2, 0x47, 0x2d, 0xd0, 0x26, 0xd0, 0xa6, 0x2e, 0x35, 0xf0, 0xa8,
		0x1c, 0x54, 0x49, 0x8e, 0xaa, 0x2c, 0x87, 0x95, 0xd8, 0x71, 0x25, 0x57, 0x29, 0x32, 0x54, 0x8b,
		0x3c, 0x15, 0x23, 0x4b, 0xd5, 0x48, 0x57, 0x39, 0xd2, 0x55, 0x8f, 0x54, 0x15, 0x44, 0x4b, 0xd0,
		0xe9, 0x9f, 0x33, 0x48, 0xe7, 0x10, 0x13, 0x3b, 0xc6, 0x74, 0x1b, 0x81, 0x94, 0x9a, 0x6d, 0x0e,
		0xf4, 0x6b, 0x27, 0x4e, 0xbb, 0xa2, 0xd7, 0x5f, 0x96, 0x0f, 0xd8, 0x5a, 0x3c, 0x1f, 0x0a, 0x5f,
		0xa3, 0xf0, 0x35, 0x20, 0x3f, 0x20, 0x3f, 0x20, 0x3f, 0x20, 0x3f, 0x20, 0x3f, 0x20, 0x3f, 0x20,
		0x3f, 0x20, 0x3f, 0x20, 0x7f, 0x3c, 0xc8, 0xaf, 0x59, 0x26, 0xfd, 0x6b, 0xc4, 0x8f, 0x6c, 0x7a,
		0xad, 0xc4, 0x45, 0xfd, 0x65, 0xeb, 0x2b, 0x01, 0xd1, 0xf9, 0xd6, 0xd5, 0x1a, 0x3f, 0x14, 0x8d,
		0xa1, 0x79, 0x2b, 0x86, 0x62, 0x60, 0x4c, 0x6c, 0xab, 0x6f, 0x7a, 0x04, 0x37, 0xaf, 0x1b, 0x47,
		0xc5, 0xed, 0x2b, 0x6e, 0x5f, 0x15, 0xc1, 0xa8, 0x84, 0xdd, 0xbe, 0x2e, 0x76, 0xc4, 0x18, 0x5a,
		0x23, 0xcb, 0xa7, 0xe3, 0x63, 0xd6, 0x46, 0xc5, 0x4d, 0x2c, 0x68, 0x19, 0xd0, 0x32, 0x3a, 0xd0,
		0x32, 0x44, 0xa1, 0x16, 0x21, 0xf1, 0x25, 0xe3, 0xc9, 0x09, 0x0f, 0x3c, 0xc8, 0x13, 0x90, 0x27,
		0x20, 0x4f, 0x68, 0x15, 0x48, 0x30, 0xe0, 0xc8, 0xfc, 0x61, 0x2c, 0x76, 0x7d, 0x5e, 0x67, 0x42,
		0x52, 0xae, 0xc9, 0xda, 0x2c, 0xc4, 0x9b, 0x4f, 0xcb, 0xd0, 0x4a, 0x53, 0x36, 0x32, 0x95, 0x8e,
		0x7c, 0xe5, 0x23, 0x5b, 0x09, 0xb1, 0x29, 0x23, 0x36, 0xa5, 0xc4, 0xa2, 0x9c, 0x68, 0x95, 0x14,
		0xb1, 0xb2, 0x0a, 0x56, 0x80, 0x9c, 0xf1, 0x0d, 0xc9, 0xfb, 0xc4, 0xb2, 0xfd, 0x93, 0x82, 0x0c,
		0x79, 0x5f, 0x6a, 0x97, 0x8a, 0x84, 0xa1, 0x5b, 0xa6, 0x7d, 0x2f, 0x48, 0x6b, 0xfb, 0xbc, 0xfc,
		0x25, 0xe7, 0x7c, 0x1e, 0x2c, 0x4b, 0x34, 0x4b, 0x53, 0x00, 0x92, 0xd5, 0x7a, 0x68, 0x9a, 0x79,
		0x85, 0x25, 0x86, 0x79, 0x3e, 0xbb, 0x66, 0xdf, 0xb7, 0x1c, 0xfb, 0xdc, 0xba, 0xb7, 0x16, 0x95,
		0xad, 0xa5, 0xcd, 0x37, 0x7d, 0x27, 0x71, 0xeb, 0xcd, 0x1f, 0xa9, 0xdb, 0xfa, 0x62, 0xe1, 0xb4,
		0x78, 0x5a, 0xae, 0x14, 0x4e, 0x4b, 0x29, 0x92, 0x81, 0x37, 0xc9, 0x18, 0xb5, 0xab, 0x6b, 0xd5,
		0x6c, 0x42, 0xbf, 0x6d, 0xec, 0x8a, 0x07, 0x61, 0xfb, 0x86, 0x2f, 0x4c, 0x77, 0xe0, 0xfc, 0x63,
		0xcb, 0x83, 0xd9, 0xa1, 0x99, 0x88, 0x0d, 0xb9, 0xa4, 0x20, 0x0b, 0x40, 0x79, 0x40, 0x79, 0x40,
		0x79, 0x40, 0x79, 0x49, 0x41, 0x1c, 0xaf, 0xd5, 0x0b, 0x51, 0x30, 0x87, 0xde, 0x46, 0x67, 0x79,
		0xad, 0x6d, 0xf8, 0xd6, 0x48, 0xb8, 0xf2, 0x2c, 0xce, 0xfa, 0x34, 0x30, 0x07, 0x30, 0x07, 0x30,
		0x07, 0x30, 0x07, 0x84, 0xf2, 0x3e, 0x10, 0x7d, 0x6b, 0x64, 0x0e, 0xcb, 0x45, 0x99, 0x06, 0xa1,
		0x20, 0x61, 0xec, 0x90, 0xb3, 0x57, 0x00, 0x85, 0xa4, 0x86, 0x42, 0x2a, 0x80, 0x42, 0xca, 0x2a,
		0x85, 0x74, 0x82, 0xad, 0x07, 0x73, 0x94, 0x5c, 0x10, 0xff, 0x8f, 0xe9, 0xda, 0x96, 0x7d, 0x6f,
		0xf8, 0xdf, 0x5d, 0xe1, 0x7d, 0x77, 0x86, 0x03, 0x63, 0xdc, 0xf7, 0xe5, 0x81, 0xf9, 0xcd, 0xd3,
		0x01, 0xd4, 0x03, 0xd4, 0x03, 0xd4, 0x03, 0xd4, 0x13, 0xca, 0xfb, 0x58, 0xb8, 0x7d, 0x61, 0xfb,
		0xe6, 0xbd, 0x90, 0x88, 0xea, 0x4b, 0xc0, 0xdb, 0x6a, 0xf0, 0x36, 0xae, 0x6c, 0x33, 0x8b, 0xb7,
		0xb9, 0xb6, 0x3e, 0x7f, 0x0c, 0xc4, 0x0d, 0xc4, 0x4d, 0x3a, 0x12, 0x55, 0x84, 0x26, 0x71, 0x8e,
		0x64, 0x30, 0x2e, 0x65, 0xf2, 0xdb, 0xa6, 0x4c, 0xab, 0xa3, 0x97, 0x99, 0x1e, 0x47, 0xa4, 0x71,
		0xe0, 0x07, 0x74, 0x49, 0x72, 0xf5, 0xf1, 0x43, 0xf1, 0x62, 0xf1, 0xe0, 0xd7, 0x8b, 0xe7, 0xee,
		0x2d, 0x00, 0xfa, 0xc5, 0xec, 0xb1, 0x49, 0xca, 0xa8, 0xd0, 0x89, 0xd5, 0x94, 0x24, 0xf9, 0x94,
		0xa2, 0xbc, 0x4a, 0x08, 0x81, 0x51, 0x25, 0xc7, 0x1e, 0xc8, 0x0c, 0xf3, 0x2f, 0x20, 0xcc, 0x3f,
		0x41, 0xae, 0x1a, 0xc2, 0xfc, 0x11, 0xe6, 0x8f, 0x30, 0x7f, 0xf0, 0x46, 0xe0, 0x8d, 0xc0, 0x1b,
		0x49, 0x92, 0x77, 0x84, 0xf9, 0x83, 0x33, 0x02, 0x67, 0x04, 0xce, 0x28, 0xd2, 0xd6, 0x23, 0xcc,
		0x1f, 0xd4, 0x91, 0xc4, 0x33, 0x84, 0x30, 0x7f, 0x40, 0x79, 0x40, 0x79, 0x40, 0x79, 0x40, 0xf9,
		0x9d, 0xe4, 0x1d, 0x61, 0xfe, 0x24, 0xef, 0x8a, 0x30, 0x7f, 0x98, 0x03, 0x98, 0x03, 0x98, 0x83,
		0xa4, 0x9b, 0x03, 0x84, 0xf9, 0x83, 0x42, 0x8a, 0xb9, 0xbd, 0x08, 0xf3, 0xcf, 0x2c, 0x85, 0x84,
		0x30, 0x7f, 0x30, 0x47, 0x09, 0x06, 0xf1, 0x08, 0xf3, 0x07, 0xa8, 0x07, 0xa8, 0x07, 0xa8, 0x4f,
		0x1b, 0xa8, 0x47, 0x98, 0x7f, 0x9a, 0xf1, 0x36, 0xae, 0x6c, 0x33, 0x8b, 0xb7, 0x11, 0xe6, 0x0f,
		0xc4, 0xcd, 0x8f, 0xb8, 0x11, 0xe6, 0x4f, 0x1e, 0xe6, 0x4f, 0x19, 0x06, 0x7e, 0xc0, 0x16, 0xe5,
		0x4f, 0xd0, 0x3a, 0x89, 0x4e, 0xa8, 0xd0, 0x91, 0x2b, 0xb2, 0xf8, 0xe9, 0xd3, 0x9c, 0xeb, 0xd7,
		0x02, 0x87, 0x2e, 0x5d, 0x3a, 0x89, 0x90, 0xfa, 0x4e, 0x5d, 0x61, 0x69, 0xd1, 0xbe, 0x59, 0x17,
		0x6d, 0x93, 0x2e, 0x34, 0xe7, 0x42, 0x73, 0x2e, 0xc5, 0x9c, 0x4b, 0xc2, 0x9a, 0x73, 0x11, 0xf5,
		0xeb, 0xa1, 0xed, 0xd3, 0x83, 0x86, 0x5c, 0x2a, 0x49, 0x56, 0x34, 0xe4, 0xd2, 0x00, 0x3f, 0x93,
		0x35, 0xe4, 0xf2, 0x84, 0x3d, 0x30, 0x06, 0x8b, 0xc0, 0x59, 0xc3, 0x75, 0x26, 0x52, 0x92, 0x76,
		0xc3, 0x73, 0xa0, 0x7b, 0xba, 0x2e, 0x0a, 0x47, 0x9e, 0xe2, 0x91, 0xa5, 0x80, 0xa4, 0x2b, 0x22,
		0xe9, 0x0a, 0x49, 0xaa, 0x62, 0xd2, 0x93, 0x77, 0x42, 0xf7, 0x74, 0x70, 0x35, 0xb2, 0x1c, 0xed,
		0x15, 0x47, 0x43, 0x56, 0xfc, 0x83, 0xd0, 0xdf, 0x5e, 0xd1, 0x32, 0x14, 0x15, 0x3e, 0x62, 0x30,
		0x32, 0xef, 0xd0, 0x9f, 0x17, 0xee, 0x00, 0xdc, 0x01, 0xb8, 0x03, 0x3c, 0xfe, 0xbe, 0x1c, 0xbf,
		0x9f, 0xf8, 0xc0, 0x03, 0x9e, 0x03, 0x9e, 0x03, 0x9e, 0xd3, 0x2a, 0x90, 0x60, 0x40, 0x14, 0xee,
		0x61, 0x52, 0x36, 0x32, 0x95, 0x8e, 0x7c, 0xe5, 0x23, 0x5b, 0x09, 0xb1, 0x29, 0x23, 0x36, 0xa5,
		0xc4, 0xa2, 0x9c, 0x68, 0x95, 0x14, 0xb1, 0xb2, 0x92, 0xc7, 0x29, 0x84, 0xe4, 0x1d, 0x85, 0x7b,
		0x42, 0xbf, 0x10, 0x05, 0xba, 0xd3, 0x34, 0x88, 0x02, 0xdd, 0x6f, 0xeb, 0x51, 0xb8, 0x27, 0x19,
		0x32, 0x80, 0x60, 0x50, 0x5d, 0xce, 0x10, 0x0a, 0xf7, 0x00, 0xca, 0x03, 0xca, 0x03, 0xca, 0x03,
		0xca, 0xef, 0x24, 0xef, 0x28, 0xdc, 0x43, 0xf2, 0xae, 0x28, 0xdc, 0x03, 0x73, 0x00, 0x73, 0x00,
		0x73, 0x90, 0x74, 0x73, 0x80, 0xc2, 0x3d, 0xa0, 0x90, 0x62, 0x6e, 0x2f, 0x0a, 0xf7, 0x64, 0x96,
		0x42, 0x42, 0xe1, 0x1e, 0x30, 0x47, 0x09, 0x06, 0xf1, 0x28, 0xdc, 0x03, 0x50, 0x0f, 0x50, 0x0f,
		0x50, 0x9f, 0x36, 0x50, 0x8f, 0xc2, 0x3d, 0x69, 0xc6, 0xdb, 0xb8, 0xb2, 0xcd, 0x2c, 0xde, 0x46,
		0xe1, 0x1e, 0x20, 0x6e, 0x7e, 0xc4, 0x8d, 0xc2, 0x3d, 0x71, 0xb2, 0x71, 0x12, 0xd3, 0x97, 0x17,
		0x0d, 0x79, 0x63, 0x40, 0x2e, 0x34, 0xe4, 0xd5, 0xd5, 0x57, 0x43, 0x5c, 0xbf, 0x12, 0x5f, 0x0c,
		0x71, 0xfd, 0x04, 0x87, 0x01, 0x71, 0xfd, 0x20, 0x8a, 0x40, 0x14, 0x81, 0x28, 0x92, 0x25, 0xef,
		0x88, 0xeb, 0x07, 0x49, 0x04, 0x92, 0x08, 0x24, 0x51, 0xa4, 0xad, 0x47, 0x5c, 0x3f, 0xb8, 0x22,
		0x89, 0x67, 0x08, 0x71, 0xfd, 0x80, 0xf2, 0x80, 0xf2, 0x80, 0xf2, 0x80, 0xf2, 0x3b, 0xc9, 0x3b,
		0xe2, 0xfa, 0x49, 0xde, 0x15, 0x71, 0xfd, 0x30, 0x07, 0x30, 0x07, 0x30, 0x07, 0x49, 0x37, 0x07,
		0x88, 0xeb, 0x07, 0x85, 0x14, 0x73, 0x7b, 0x11, 0xd7, 0x9f, 0x59, 0x0a, 0x09, 0x71, 0xfd, 0x60,
		0x8e, 0x12, 0x0c, 0xe2, 0x11, 0xd7, 0x0f, 0x50, 0x0f, 0x50, 0x0f, 0x50, 0x9f, 0x36, 0x50, 0x8f,
		0xb8, 0xfe, 0x34, 0xe3, 0x6d, 0x5c, 0xd9, 0x66, 0x16, 0x6f, 0x23, 0xae, 0x1f, 0x88, 0x9b, 0x1f,
		0x71, 0x23, 0xae, 0x9f, 0x2c, 0xae, 0x5f, 0xe3, 0x46, 0xbc, 0xe8, 0xc0, 0xcb, 0x29, 0x77, 0x3c,
		0xf2, 0xa6, 0x67, 0x6f, 0x17, 0x1d, 0x5a, 0xee, 0xc6, 0x6a, 0x2e, 0x4b, 0x91, 0x19, 0x42, 0x9a,
		0x11, 0x42, 0xde, 0xd2, 0xa5, 0x80, 0x96, 0x2e, 0x1a, 0x78, 0xe9, 0x68, 0xe9, 0xb2, 0xfb, 0x1b,
		0xa1, 0xc3, 0xe3, 0x01, 0x3a, 0x3c, 0x22, 0xd5, 0x0c, 0xa9, 0x66, 0x49, 0x71, 0x64, 0xd0, 0xe1,
		0x11, 0xbe, 0x80, 0x6c, 0x5f, 0x80, 0xca, 0xdd, 0x94, 0xe0, 0x04, 0x10, 0xb8, 0x96, 0xd3, 0x84,
		0x74, 0x95, 0x27, 0x12, 0x17, 0x69, 0x62, 0x92, 0x8b, 0xe5, 0x0c, 0x11, 0x0b, 0x46, 0x34, 0x91,
		0xd8, 0x7f, 0x43, 0x23, 0x6c, 0x66, 0xce, 0x1a, 0x3f, 0x94, 0x8d, 0xa1, 0x79, 0x2b, 0x86, 0x62,
		0x10, 0x2c, 0x5e, 0xd4, 0x2d, 0x0d, 0xd4, 0xf5, 0xc6, 0x51, 0x23, 0x8a, 0x5a, 0x3c, 0x3f, 0x30,
		0x36, 0x2c, 0xa3, 0x80, 0x61, 0x74, 0xb0, 0x8b, 0x0a, 0x66, 0x91, 0xc3, 0x2a, 0x72, 0x18, 0x45,
		0x0a, 0x9b, 0x78, 0x95, 0x63, 0x5c, 0xbf, 0x0d, 0xfd, 0x76, 0x41, 0xce, 0x80, 0x9c, 0xc9, 0x0a,
		0x39, 0x83, 0x7e, 0xbb, 0x20, 0x4b, 0x40, 0x96, 0x64, 0x8f, 0x2c, 0x41, 0x5d, 0x9e, 0x6d, 0x4a,
		0x06, 0x81, 0x9e, 0x08, 0xf4, 0xd4, 0x49, 0x29, 0xb1, 0x28, 0x27, 0x5a, 0x25, 0x45, 0xac, 0xac,
		0x82, 0x15, 0x40, 0x5d, 0x9e, 0x8d, 0x43, 0x23, 0xc8, 0x93, 0x5f, 0xad, 0x87, 0xa6, 0x41, 0x90,
		0xe7, 0x7e, 0x5b, 0x8f, 0xba, 0x3c, 0xc9, 0x90, 0x01, 0xc4, 0x7a, 0xea, 0x72, 0x86, 0x50, 0x97,
		0x07, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79, 0x47, 0x5d, 0x1e, 0x92, 0x77,
		0x45, 0x5d, 0x1e, 0x98, 0x03, 0x98, 0x03, 0x98, 0x83, 0xa4, 0x9b, 0x03, 0xd4, 0xe5, 0x01, 0x85,
		0x14, 0x73, 0x7b, 0x51, 0x97, 0x27, 0xb3, 0x14, 0x12, 0xea, 0xf2, 0x80, 0x39, 0x4a, 0x30, 0x88,
		0x47, 0x5d, 0x1e, 0x80, 0x7a, 0x80, 0x7a, 0x80, 0xfa, 0xb4, 0x81, 0x7a, 0xd4, 0xe5, 0x49, 0x33,
		0xde, 0xc6, 0x95, 0x6d, 0x66, 0xf1, 0x36, 0xea, 0xf2, 0x00, 0x71, 0xf3, 0x23, 0x6e, 0xd4, 0xe5,
		0xd9, 0x3f, 0xe9, 0x2d, 0x94, 0x69, 0x95, 0x98, 0xbe, 0xbb, 0xe5, 0x8b, 0xc5, 0x83, 0xa3, 0xfd,
		0x6e, 0x0c, 0x04, 0x86, 0xf6, 0xbb, 0xba, 0xba, 0x6e, 0x08, 0xf3, 0x57, 0xe2, 0x9a, 0x21, 0xcc,
		0x9f, 0xe0, 0x30, 0x20, 0xcc, 0x1f, 0xbc, 0x11, 0x78, 0x23, 0xf0, 0x46, 0xb2, 0xe4, 0x1d, 0x61,
		0xfe, 0xe0, 0x8c, 0xc0, 0x19, 0x81, 0x33, 0x8a, 0xb4, 0xf5, 0x08, 0xf3, 0x07, 0x75, 0x24, 0xf1,
		0x0c, 0x21, 0xcc, 0x1f, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79, 0x47, 0x98,
		0x3f, 0xc9, 0xbb, 0x22, 0xcc, 0x1f, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xe9, 0xe6, 0x00, 0x61,
		0xfe, 0xa0, 0x90, 0x62, 0x6e, 0x2f, 0xc2, 0xfc, 0x33, 0x4b, 0x21, 0x21, 0xcc, 0x1f, 0xcc, 0x51,
		0x82, 0x41, 0x3c, 0xc2, 0xfc, 0x01, 0xea, 0x01, 0xea, 0x01, 0xea, 0xd3, 0x06, 0xea, 0x11, 0xe6,
		0x9f, 0x66, 0xbc, 0x8d, 0x2b, 0xdb, 0xcc, 0xe2, 0x6d, 0x84, 0xf9, 0x03, 0x71, 0xf3, 0x23, 0x6e,
		0x84, 0xf9, 0x93, 0x87, 0xf9, 0xeb, 0xdb, 0x86, 0xf7, 0x57, 0x51, 0xfe, 0xe8, 0xc6, 0x2b, 0x4b,
		0x0c, 0x79, 0xc5, 0x4f, 0xab, 0x86, 0x5c, 0xbf, 0x10, 0x38, 0x74, 0xe7, 0xd2, 0x49, 0x84, 0xb4,
		0xe8, 0xd2, 0xf5, 0x4a, 0x5a, 0xb4, 0x6f, 0xd6, 0x45, 0xdb, 0xa4, 0x0b, 0xcd, 0xb9, 0xd0, 0x9c,
		0x4b, 0x31, 0xe7, 0x92, 0xb0, 0xe6, 0x5c, 0x44, 0xfd, 0x7a, 0x68, 0xfb, 0xf4, 0xa0, 0x21, 0x97,
		0x4a, 0x92, 0x15, 0x0d, 0xb9, 0x34, 0xc0, 0xcf, 0xe8, 0x96, 0x7e, 0x80, 0x6e, 0xe9, 0xc8, 0x0c,
		0x46, 0x66, 0x70, 0x52, 0x78, 0x27, 0x74, 0x4b, 0x07, 0x57, 0x23, 0xcb, 0xd1, 0x5e, 0x71, 0x34,
		0x64, 0xc5, 0x3f, 0x08, 0xfd, 0xed, 0x15, 0x2d, 0x43, 0x51, 0xe1, 0x23, 0x06, 0x23, 0xf3, 0x0e,
		0xfd, 0x79, 0xe1, 0x0e, 0xc0, 0x1d, 0x80, 0x3b, 0xc0, 0xe3, 0xef, 0xcb, 0xf1, 0xfb, 0x89, 0x0f,
		0x3c, 0xe0, 0x39, 0xe0, 0x39, 0xe0, 0x39, 0xad, 0x02, 0x09, 0x06, 0x44, 0xe1, 0x1e, 0x26, 0x65,
		0x23, 0x53, 0xe9, 0xc8, 0x57, 0x3e, 0xb2, 0x95, 0x10, 0x9b, 0x32, 0x62, 0x53, 0x4a, 0x2c, 0xca,
		0x89, 0x56, 0x49, 0x11, 0x2b, 0x2b, 0x79, 0x9c, 0x42, 0x48, 0xde, 0x51, 0xb8, 0x27, 0xf4, 0x0b,
		0x51, 0xa0, 0x3b, 0x4d, 0x83, 0x28, 0xd0, 0xfd, 0xb6, 0x1e, 0x85, 0x7b, 0x92, 0x21, 0x03, 0x08,
		0x06, 0xd5, 0xe5, 0x0c, 0xa1, 0x70, 0x0f, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0xfc, 0x4e,
		0xf2, 0x8e, 0xc2, 0x3d, 0x24, 0xef, 0x8a, 0xc2, 0x3d, 0x30, 0x07, 0x30, 0x07, 0x30, 0x07, 0x49,
		0x37, 0x07, 0x28, 0xdc, 0x03, 0x0a, 0x29, 0xe6, 0xf6, 0xa2, 0x70, 0x4f, 0x66, 0x29, 0x24, 0x14,
		0xee, 0x01, 0x73, 0x94, 0x60, 0x10, 0x8f, 0xc2, 0x3d, 0x00, 0xf5, 0x00, 0xf5, 0x00, 0xf5, 0x69,
		0x03, 0xf5, 0x28, 0xdc, 0x93, 0x66, 0xbc, 0x8d, 0x2b, 0xdb, 0xcc, 0xe2, 0x6d, 0x14, 0xee, 0x01,
		0xe2, 0xe6, 0x47, 0xdc, 0x28, 0xdc, 0x13, 0x27, 0x1b, 0x27, 0x31, 0x7d, 0x79, 0xd1, 0x90, 0x37,
		0x06, 0xe4, 0x42, 0x43, 0x5e, 0x5d, 0x7d, 0x35, 0xc4, 0xf5, 0x2b, 0xf1, 0xc5, 0x10, 0xd7, 0x4f,
		0x70, 0x18, 0x10, 0xd7, 0x0f, 0xa2, 0x08, 0x44, 0x11, 0x88, 0x22, 0x59, 0xf2, 0x8e, 0xb8, 0x7e,
		0x90, 0x44, 0x20, 0x89, 0x40, 0x12, 0x45, 0xda, 0x7a, 0xc4, 0xf5, 0x83, 0x2b, 0x92, 0x78, 0x86,
		0x10, 0xd7, 0x0f, 0x28, 0x0f, 0x28, 0x0f, 0x28, 0x0f, 0x28, 0xbf, 0x93, 0xbc, 0x23, 0xae, 0x9f,
		0xe4, 0x5d, 0x11, 0xd7, 0x0f, 0x73, 0x00, 0x73, 0x00, 0x73, 0x90, 0x74, 0x73, 0x80, 0xb8, 0x7e,
		0x50, 0x48, 0x31, 0xb7, 0x17, 0x71, 0xfd, 0x99, 0xa5, 0x90, 0x10, 0xd7, 0x0f, 0xe6, 0x28, 0xc1,
		0x20, 0x1e, 0x71, 0xfd, 0x00, 0xf5, 0x00, 0xf5, 0x00, 0xf5, 0x69, 0x03, 0xf5, 0x88, 0xeb, 0x4f,
		0x33, 0xde, 0xc6, 0x95, 0x6d, 0x66, 0xf1, 0x36, 0xe2, 0xfa, 0x81, 0xb8, 0xf9, 0x11, 0x37, 0xe2,
		0xfa, 0xc9, 0xe2, 0xfa, 0x35, 0x6e, 0xc4, 0x8b, 0x0e, 0xbc, 0x9c, 0x72, 0xc7, 0x23, 0x6f, 0x7a,
		0xf6, 0x76, 0xd1, 0xa1, 0xe5, 0x6e, 0xac, 0xe6, 0xb2, 0x14, 0x99, 0x21, 0xa4, 0x19, 0x21, 0xe4,
		0x2d, 0x5d, 0x0a, 0x68, 0xe9, 0xa2, 0x81, 0x97, 0x8e, 0x96, 0x2e, 0xbb, 0xbf, 0x11, 0x3a, 0x3c,
		0x1e, 0xa0, 0xc3, 0x23, 0x52, 0xcd, 0x90, 0x6a, 0x96, 0x14, 0x47, 0x06, 0x1d, 0x1e, 0xe1, 0x0b,
		0xc8, 0xf6, 0x05, 0xa8, 0xdc, 0x4d, 0x09, 0x4e, 0x00, 0x81, 0x6b, 0x39, 0x4d, 0x48, 0x57, 0x79,
		0x22, 0x71, 0x91, 0x26, 0x26, 0xb9, 0x58, 0xce, 0x10, 0xb1, 0x60, 0x44, 0x13, 0x89, 0xfd, 0x37,
		0x34, 0xc2, 0x66, 0xe6, 0x86, 0x85, 0x87, 0xb1, 0x6d, 0x88, 0x87, 0x71, 0xf4, 0x8d, 0x0c, 0x94,
		0xf4, 0x8b, 0xb1, 0x22, 0x8a, 0x55, 0x3c, 0x9f, 0x2f, 0x36, 0x04, 0xa3, 0x80, 0x5c, 0x74, 0x10,
		0x8b, 0x0a, 0x52, 0x91, 0x43, 0x28, 0x72, 0xc8, 0x44, 0x0a, 0x91, 0x78, 0x15, 0x61, 0x5c, 0x1f,
		0x0d, 0xbd, 0x75, 0x41, 0xc4, 0x80, 0x88, 0xc9, 0x0a, 0x11, 0x83, 0xde, 0xba, 0x20, 0x46, 0x40,
		0x8c, 0x64, 0x8f, 0x18, 0x41, 0x0d, 0x9e, 0x6d, 0x4a, 0x06, 0x41, 0x9d, 0x08, 0xea, 0xd4, 0x49,
		0x29, 0xb1, 0x28, 0x27, 0x5a, 0x25, 0x45, 0xac, 0xac, 0x82, 0x15, 0x40, 0x0d, 0x9e, 0x8d, 0x43,
		0x23, 0xa0, 0x93, 0x5f, 0xad, 0x87, 0xa6, 0x41, 0x40, 0xe7, 0x7e, 0x5b, 0x8f, 0x1a, 0x3c, 0xc9,
		0x90, 0x01, 0xc4, 0x75, 0xea, 0x72, 0x86, 0x50, 0x83, 0x07, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e,
		0x50, 0x7e, 0x27, 0x79, 0x47, 0x0d, 0x1e, 0x92, 0x77, 0x45, 0x0d, 0x1e, 0x98, 0x03, 0x98, 0x03,
		0x98, 0x83, 0xa4, 0x9b, 0x03, 0xd4, 0xe0, 0x01, 0x85, 0x14, 0x73, 0x7b, 0x51, 0x83, 0x27, 0xb3,
		0x14, 0x12, 0x6a, 0xf0, 0x80, 0x39, 0x4a, 0x30, 0x88, 0x47, 0x0d, 0x1e, 0x80, 0x7a, 0x80, 0x7a,
		0x80, 0xfa, 0xb4, 0x81, 0x7a, 0xd4, 0xe0, 0x49, 0x33, 0xde, 0xc6, 0x95, 0x6d, 0x66, 0xf1, 0x36,
		0x6a, 0xf0, 0x00, 0x71, 0xf3, 0x23, 0x6e, 0xd4, 0xe0, 0xd9, 0x33, 0xc1, 0xed, 0x39, 0xbf, 0x2a,
		0x19, 0x9d, 0x75, 0x2f, 0x0a, 0x5f, 0xc7, 0x76, 0xed, 0x61, 0x6c, 0xa3, 0xaf, 0x6e, 0x14, 0xb8,
		0x85, 0xbe, 0xba, 0xba, 0xfa, 0x69, 0x88, 0xe9, 0x57, 0xe2, 0x87, 0x21, 0xa6, 0x9f, 0xe0, 0x30,
		0x20, 0xa6, 0x1f, 0x24, 0x11, 0x48, 0x22, 0x90, 0x44, 0xb2, 0xe4, 0x1d, 0x31, 0xfd, 0x20, 0x88,
		0x40, 0x10, 0x81, 0x20, 0x8a, 0xb4, 0xf5, 0x88, 0xe9, 0x07, 0x4f, 0x24, 0xf1, 0x0c, 0x21, 0xa6,
		0x1f, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79, 0x47, 0x4c, 0x3f, 0xc9, 0xbb,
		0x22, 0xa6, 0x1f, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xe9, 0xe6, 0x00, 0x31, 0xfd, 0xa0, 0x90,
		0x62, 0x6e, 0x2f, 0x62, 0xfa, 0x33, 0x4b, 0x21, 0x21, 0xa6, 0x1f, 0xcc, 0x51, 0x82, 0x41, 0x3c,
		0x62, 0xfa, 0x01, 0xea, 0x01, 0xea, 0x01, 0xea, 0xd3, 0x06, 0xea, 0x11, 0xd3, 0x9f, 0x66, 0xbc,
		0x8d, 0x2b, 0xdb, 0xcc, 0xe2, 0x6d, 0xc4, 0xf4, 0x03, 0x71, 0xf3, 0x23, 0x6e, 0xc4, 0xf4, 0x13,
		0xc5, 0xf4, 0x6b, 0xda, 0x55, 0x77, 0x73, 0x48, 0x3f, 0x7a, 0xea, 0xca, 0x92, 0x39, 0x0e, 0x59,
		0xd3, 0xa7, 0x99, 0xd6, 0x46, 0xe9, 0x42, 0x43, 0x2d, 0xf5, 0xf2, 0xa2, 0xbe, 0x9d, 0x56, 0x20,
		0x1a, 0xfa, 0x37, 0xd3, 0x7a, 0x18, 0x0f, 0x3d, 0xaa, 0x66, 0x5a, 0xf3, 0xb1, 0xd0, 0x4c, 0x0b,
		0xcd, 0xb4, 0x14, 0xd1, 0x26, 0x68, 0xa6, 0x85, 0x66, 0x5a, 0xea, 0x38, 0x54, 0x34, 0xd3, 0x42,
		0x33, 0xad, 0xed, 0x03, 0xa1, 0x99, 0x16, 0xc5, 0x80, 0x48, 0xbc, 0x45, 0xe2, 0x6d, 0xb2, 0x68,
		0x1d, 0x24, 0xde, 0x6e, 0x53, 0x32, 0xb8, 0xc9, 0xc5, 0x4d, 0xae, 0x4e, 0x4a, 0x89, 0x45, 0x39,
		0xd1, 0x2a, 0x29, 0x62, 0x65, 0x15, 0xac, 0x00, 0x12, 0x6f, 0x37, 0x0e, 0x8d, 0x5b, 0x5c, 0x7e,
		0xb5, 0x1e, 0x9a, 0x06, 0xb7, 0xb8, 0xfb, 0x6d, 0x3d, 0x12, 0x6f, 0x93, 0x21, 0x03, 0xb8, 0xcc,
		0xd5, 0xe5, 0x0c, 0x21, 0xf1, 0x16, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79,
		0x47, 0xe2, 0x2d, 0xc9, 0xbb, 0x22, 0xf1, 0x16, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xe9, 0xe6,
		0x00, 0x89, 0xb7, 0xa0, 0x90, 0x62, 0x6e, 0x2f, 0x12, 0x6f, 0x33, 0x4b, 0x21, 0x21, 0xf1, 0x16,
		0xcc, 0x51, 0x82, 0x41, 0x3c, 0x12, 0x6f, 0x01, 0xea, 0x01, 0xea, 0x01, 0xea, 0xd3, 0x06, 0xea,
		0x91, 0x78, 0x9b, 0x66, 0xbc, 0x8d, 0x2b, 0xdb, 0xcc, 0xe2, 0x6d, 0x24, 0xde, 0x02, 0x71, 0xf3,
		0x23, 0x6e, 0x24, 0xde, 0x46, 0x4a, 0x6e, 0x7b, 0x18, 0x0f, 0xbd, 0x04, 0x35, 0xd3, 0xfa, 0x3a,
		0x1e, 0x7a, 0x68, 0xa6, 0x15, 0x05, 0x6e, 0xa1, 0x99, 0x96, 0xae, 0x7e, 0x1a, 0x62, 0xfa, 0x95,
		0xf8, 0x61, 0x88, 0xe9, 0x27, 0x38, 0x0c, 0x88, 0xe9, 0x07, 0x49, 0x04, 0x92, 0x08, 0x24, 0x91,
		0x2c, 0x79, 0x47, 0x4c, 0x3f, 0x08, 0x22, 0x10, 0x44, 0x20, 0x88, 0x22, 0x6d, 0x3d, 0x62, 0xfa,
		0xc1, 0x13, 0x49, 0x3c, 0x43, 0x88, 0xe9, 0x07, 0x94, 0x07, 0x94, 0x07, 0x94, 0x07, 0x94, 0xdf,
		0x49, 0xde, 0x11, 0xd3, 0x4f, 0xf2, 0xae, 0x88, 0xe9, 0x87, 0x39, 0x80, 0x39, 0x80, 0x39, 0x48,
		0xba, 0x39, 0x40, 0x4c, 0x3f, 0x28, 0xa4, 0x98, 0xdb, 0x8b, 0x98, 0xfe, 0xcc, 0x52, 0x48, 0x88,
		0xe9, 0x07, 0x73, 0x94, 0x60, 0x10, 0x8f, 0x98, 0x7e, 0x80, 0x7a, 0x80, 0x7a, 0x80, 0xfa, 0xb4,
		0x81, 0x7a, 0xc4, 0xf4, 0xa7, 0x19, 0x6f, 0xe3, 0xca, 0x36, 0xb3, 0x78, 0x1b, 0x31, 0xfd, 0x40,
		0xdc, 0xfc, 0x88, 0x1b, 0x31, 0xfd, 0x44, 0x31, 0xfd, 0x3a, 0x37, 0xd3, 0x0a, 0x85, 0xf4, 0xa3,
		0x99, 0x96, 0x2c, 0x99, 0xe3, 0x90, 0x35, 0xcd, 0x9a, 0x69, 0xbd, 0x96, 0x2e, 0x34, 0xd3, 0x52,
		0x2f, 0x2f, 0x9a, 0x34, 0xd3, 0x9a, 0x89, 0x86, 0xd6, 0xcd, 0xb4, 0x4e, 0x66, 0x0b, 0x66, 0x8d,
		0x1f, 0x8a, 0xc6, 0x68, 0x32, 0xf4, 0xad, 0xbe, 0xe9, 0xf9, 0x04, 0x6d, 0xb5, 0x36, 0x8d, 0x8a,
		0x06, 0x5b, 0x68, 0xb0, 0xa5, 0x88, 0x4a, 0x41, 0x83, 0x2d, 0x34, 0xd8, 0x52, 0xc7, 0xab, 0xa2,
		0xc1, 0x16, 0x1a, 0x6c, 0x6d, 0x1f, 0x08, 0x0d, 0xb6, 0x28, 0x06, 0x44, 0x32, 0x2e, 0x92, 0x71,
		0x93, 0x45, 0xf5, 0x20, 0x19, 0x77, 0x9b, 0x92, 0xc1, 0xed, 0x2e, 0x6e, 0x77, 0x75, 0x52, 0x4a,
		0x2c, 0xca, 0x89, 0x56, 0x49, 0x11, 0x2b, 0xab, 0x60, 0x05, 0x90, 0x8c, 0xbb, 0x71, 0x68, 0xdc,
		0xec, 0xf2, 0xab, 0xf5, 0xd0, 0x34, 0xb8, 0xd9, 0xdd, 0x6f, 0xeb, 0x91, 0x8c, 0x9b, 0x0c, 0x19,
		0xc0, 0x05, 0xaf, 0x2e, 0x67, 0x08, 0xc9, 0xb8, 0x80, 0xf2, 0x80, 0xf2, 0x80, 0xf2, 0x80, 0xf2,
		0x3b, 0xc9, 0x3b, 0x92, 0x71, 0x49, 0xde, 0x15, 0xc9, 0xb8, 0x30, 0x07, 0x30, 0x07, 0x30, 0x07,
		0x49, 0x37, 0x07, 0x48, 0xc6, 0x05, 0x85, 0x14, 0x73, 0x7b, 0x91, 0x8c, 0x9b, 0x59, 0x0a, 0x09,
		0xc9, 0xb8, 0x60, 0x8e, 0x12, 0x0c, 0xe2, 0x91, 0x8c, 0x0b, 0x50, 0x0f, 0x50, 0x0f, 0x50, 0x9f,
		0x36, 0x50, 0x8f, 0x64, 0xdc, 0x34, 0xe3, 0x6d, 0x5c, 0xd9, 0x66, 0x16, 0x6f, 0x23, 0x19, 0x17,
		0x88, 0x9b, 0x1f, 0x71, 0x23, 0x19, 0x77, 0xdf, 0x84, 0xb7, 0x0d, 0x99, 0x56, 0x09, 0x69, 0xb5,
		0x75, 0xf2, 0x75, 0x6c, 0xd7, 0xc7, 0x0f, 0xc5, 0xcb, 0xd5, 0x73, 0xa3, 0xe7, 0x56, 0x14, 0x04,
		0x86, 0x9e, 0x5b, 0xba, 0xba, 0x6e, 0x08, 0xf3, 0x57, 0xe2, 0x9a, 0x21, 0xcc, 0x9f, 0xe0, 0x30,
		0x20, 0xcc, 0x1f, 0xbc, 0x11, 0x78, 0x23, 0xf0, 0x46, 0xb2, 0xe4, 0x1d, 0x61, 0xfe, 0xe0, 0x8c,
		0xc0, 0x19, 0x81, 0x33, 0x8a, 0xb4, 0xf5, 0x08, 0xf3, 0x07, 0x75, 0x24, 0xf1, 0x0c, 0x21, 0xcc,
		0x1f, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79, 0x47, 0x98, 0x3f, 0xc9, 0xbb,
		0x22, 0xcc, 0x1f, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xe9, 0xe6, 0x00, 0x61, 0xfe, 0xa0, 0x90,
		0x62, 0x6e, 0x2f, 0xc2, 0xfc, 0x33, 0x4b, 0x21, 0x21, 0xcc, 0x1f, 0xcc, 0x51, 0x82, 0x41, 0x3c,
		0xc2, 0xfc, 0x01, 0xea, 0x01, 0xea, 0x01, 0xea, 0xd3, 0x06, 0xea, 0x11, 0xe6, 0x9f, 0x66, 0xbc,
		0x8d, 0x2b, 0xdb, 0xcc, 0xe2, 0x6d, 0x84, 0xf9, 0x03, 0x71, 0xf3, 0x23, 0x6e, 0x84, 0xf9, 0x93,
		0x87, 0xf9, 0xeb, 0xda, 0x7d, 0xeb, 0xd7, 0x51, 0xfe, 0x68, 0xc3, 0x25, 0x4b, 0x0c, 0x79, 0xc5,
		0x4f, 0xa3, 0x86, 0x5c, 0xbf, 0x14, 0x38, 0x74, 0xe6, 0xd2, 0x49, 0x84, 0x34, 0xe8, 0xd1, 0x15,
		0x92, 0x96, 0x84, 0x34, 0xeb, 0x9a, 0xd8, 0xf4, 0xad, 0xba, 0x56, 0x63, 0xa2, 0x51, 0x17, 0x1a,
		0x75, 0x29, 0xe2, 0x5f, 0xd0, 0xa8, 0x0b, 0x8d, 0xba, 0xd4, 0x91, 0xb1, 0x68, 0xd4, 0x85, 0x46,
		0x5d, 0xdb, 0x07, 0x42, 0xa3, 0x2e, 0x8a, 0x01, 0x91, 0xc1, 0x8b, 0x0c, 0xde, 0x64, 0xf1, 0x43,
		0xc8, 0xe0, 0xdd, 0xa6, 0x64, 0x70, 0x25, 0x8c, 0x2b, 0x61, 0x9d, 0x94, 0x12, 0x8b, 0x72, 0xa2,
		0x55, 0x52, 0xc4, 0xca, 0x2a, 0x58, 0x01, 0x64, 0xf0, 0x6e, 0x1c, 0x1a, 0xd7, 0xc1, 0xfc, 0x6a,
		0x3d, 0x34, 0x0d, 0xae, 0x83, 0xf7, 0xdb, 0x7a, 0x64, 0xf0, 0x26, 0x43, 0x06, 0x70, 0x2b, 0xac,
		0xcb, 0x19, 0x42, 0x06, 0x2f, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0x3c, 0xa0, 0xfc, 0x4e, 0xf2, 0x8e,
		0x0c, 0x5e, 0x92, 0x77, 0x45, 0x06, 0x2f, 0xcc, 0x01, 0xcc, 0x01, 0xcc, 0x41, 0xd2, 0xcd, 0x01,
		0x32, 0x78, 0x41, 0x21, 0xc5, 0xdc, 0x5e, 0x64, 0xf0, 0x66, 0x96, 0x42, 0x42, 0x06, 0x2f, 0x98,
		0xa3, 0x04, 0x83, 0x78, 0x64, 0xf0, 0x02, 0xd4, 0x03, 0xd4, 0x03, 0xd4, 0xa7, 0x0d, 0xd4, 0x23,
		0x83, 0x37, 0xcd, 0x78, 0x1b, 0x57, 0xb6, 0x99, 0xc5, 0xdb, 0xc8, 0xe0, 0x05, 0xe2, 0xe6, 0x47,
		0xdc, 0xc8, 0xe0, 0x8d, 0x9e, 0xff, 0xb6, 0xcc, 0xb3, 0x4a, 0x58, 0x9b, 0xae, 0x6b, 0x1b, 0x4d,
		0xba, 0x22, 0xa3, 0x2f, 0x34, 0xe9, 0xd2, 0xd5, 0x6d, 0x43, 0x88, 0xbf, 0x12, 0xb7, 0x0c, 0x21,
		0xfe, 0x04, 0x87, 0x01, 0x21, 0xfe, 0xe0, 0x8c, 0xc0, 0x19, 0x81, 0x33, 0x92, 0x25, 0xef, 0x08,
		0xf1, 0x07, 0x5f, 0x04, 0xbe, 0x08, 0x7c, 0x51, 0xa4, 0xad, 0x47, 0x88, 0x3f, 0x68, 0x23, 0x89,
		0x67, 0x08, 0x21, 0xfe, 0x80, 0xf2, 0x80, 0xf2, 0x80, 0xf2, 0x80, 0xf2, 0x3b, 0xc9, 0x3b, 0x42,
		0xfc, 0x49, 0xde, 0x15, 0x21, 0xfe, 0x30, 0x07, 0x30, 0x07, 0x30, 0x07, 0x49, 0x37, 0x07, 0x08,
		0xf1, 0x07, 0x85, 0x14, 0x73, 0x7b, 0x11, 0xe2, 0x9f, 0x59, 0x0a, 0x09, 0x21, 0xfe, 0x60, 0x8e,
		0x12, 0x0c, 0xe2, 0x11, 0xe2, 0x0f, 0x50, 0x0f, 0x50, 0x0f, 0x50, 0x9f, 0x36, 0x50, 0x8f, 0x10,
		0xff, 0x34, 0xe3, 0x6d, 0x5c, 0xd9, 0x66, 0x16, 0x6f, 0x23, 0xc4, 0x1f, 0x88, 0x9b, 0x1f, 0x71,
		0x23, 0xc4, 0x9f, 0x38, 0xc4, 0x5f, 0xf7, 0x16, 0x5d, 0x9b, 0x22, 0xfc, 0xd1, 0xa0, 0x4b, 0x96,
		0x08, 0x72, 0x8a, 0x9e, 0x86, 0xed, 0xb9, 0x36, 0x08, 0x1b, 0x9a, 0x73, 0xe9, 0x23, 0x3e, 0x1a,
		0xb5, 0xe6, 0x5a, 0x4a, 0x4a, 0x22, 0x1a, 0x73, 0x95, 0x5f, 0x34, 0x37, 0xa3, 0x6b, 0xcd, 0x55,
		0x8e, 0xdd, 0x32, 0x0d, 0xcd, 0xb9, 0x64, 0xf0, 0x37, 0x68, 0xce, 0x25, 0x51, 0x4f, 0xa2, 0x39,
		0x17, 0xd7, 0xe1, 0x94, 0x41, 0xca, 0xa2, 0x39, 0x17, 0x9a, 0x73, 0x31, 0x1c, 0xf2, 0x60, 0x20,
		0x34, 0xe7, 0xa2, 0x18, 0x10, 0x99, 0xbb, 0xc8, 0xdc, 0x4d, 0x16, 0x2f, 0x84, 0xcc, 0xdd, 0x6d,
		0x4a, 0x06, 0x57, 0xc1, 0xb8, 0x0a, 0xd6, 0x49, 0x29, 0xb1, 0x28, 0x27, 0x5a, 0x25, 0x45, 0xac,
		0xac, 0x82, 0x15, 0x40, 0xe6, 0xee, 0xc6, 0xa1, 0x71, 0x0d, 0xcc, 0xaf, 0xd6, 0x43, 0xd3, 0xe0,
		0x1a, 0x78, 0xbf, 0xad, 0x47, 0xe6, 0x6e, 0x32, 0x64, 0x00, 0xb7, 0xc1, 0xba, 0x9c, 0x21, 0x64,
		0xee, 0x02, 0xca, 0x03, 0xca, 0x03, 0xca, 0x03, 0xca, 0xef, 0x24, 0xef, 0xc8, 0xdc, 0x25, 0x79,
		0x57, 0x64, 0xee, 0xc2, 0x1c, 0xc0, 0x1c, 0xc0, 0x1c, 0x24, 0xdd, 0x1c, 0x20, 0x73, 0x17, 0x14,
		0x52, 0xcc, 0xed, 0x45, 0xe6, 0x6e, 0x66, 0x29, 0x24, 0x64, 0xee, 0x82, 0x39, 0x4a, 0x30, 0x88,
		0x47, 0xe6, 0x2e, 0x40, 0x3d, 0x40, 0x3d, 0x40, 0x7d, 0xda, 0x40, 0x3d, 0x32, 0x77, 0xd3, 0x8c,
		0xb7, 0x71, 0x65, 0x9b, 0x59, 0xbc, 0x8d, 0xcc, 0x5d, 0x20, 0x6e, 0x7e, 0xc4, 0x8d, 0xcc, 0xdd,
		0xa8, 0xf9, 0x6f, 0x2f, 0x32, 0xad, 0x92, 0xd5, 0x9e, 0xab, 0x7c, 0xb9, 0x7a, 0x6e, 0x34, 0xe8,
		0x8a, 0x82, 0xc0, 0xd0, 0xa0, 0x4b, 0x57, 0xd7, 0x0d, 0x61, 0xfe, 0x4a, 0x5c, 0x33, 0x84, 0xf9,
		0x13, 0x1c, 0x06, 0x84, 0xf9, 0x83, 0x37, 0x02, 0x6f, 0x04, 0xde, 0x48, 0x96, 0xbc, 0x23, 0xcc,
		0x1f, 0x9c, 0x11, 0x38, 0x23, 0x70, 0x46, 0x91, 0xb6, 0x1e, 0x61, 0xfe, 0xa0, 0x8e, 0x24, 0x9e,
		0x21, 0x84, 0xf9, 0x03, 0xca, 0x03, 0xca, 0x03, 0xca, 0x03, 0xca, 0xef, 0x24, 0xef, 0x08, 0xf3,
		0x27, 0x79, 0x57, 0x84, 0xf9, 0xc3, 0x1c, 0xc0, 0x1c, 0xc0, 0x1c, 0x24, 0xdd, 0x1c, 0x20, 0xcc,
		0x1f, 0x14, 0x52, 0xcc, 0xed, 0x45, 0x98, 0x7f, 0x66, 0x29, 0x24, 0x84, 0xf9, 0x83, 0x39, 0x4a,
		0x30, 0x88, 0x47, 0x98, 0x3f, 0x40, 0x3d, 0x40, 0x3d, 0x40, 0x7d, 0xda, 0x40, 0x3d, 0xc2, 0xfc,
		0xd3, 0x8c, 0xb7, 0x71, 0x65, 0x9b, 0x59, 0xbc, 0x8d, 0x30, 0x7f, 0x20, 0x6e, 0x7e, 0xc4, 0x8d,
		0x30, 0x7f, 0xf2, 0x30, 0x7f, 0xcd, 0x5b, 0x74, 0x6d, 0x89, 0xf2, 0x47, 0x93, 0x2e, 0x59, 0x62,
		0xc8, 0x2b, 0x7e, 0xfa, 0xb5, 0xe9, 0xda, 0x2c, 0x70, 0x68, 0xd4, 0xa5, 0x93, 0x08, 0xe9, 0xd3,
		0xaa, 0xeb, 0x59, 0x5a, 0x12, 0xd2, 0xac, 0x6b, 0xd5, 0xec, 0x8c, 0xb2, 0x55, 0x57, 0xbc, 0x06,
		0x6a, 0x68, 0xd4, 0x25, 0x83, 0xc7, 0x41, 0xa3, 0x2e, 0x89, 0x7a, 0x12, 0x8d, 0xba, 0xb8, 0x0e,
		0xa7, 0x0c, 0x72, 0x16, 0x8d, 0xba, 0xd0, 0xa8, 0x8b, 0xe1, 0x90, 0x07, 0x03, 0xa1, 0x51, 0x17,
		0xc5, 0x80, 0xc8, 0xe0, 0x45, 0x06, 0x6f, 0xb2, 0xf8, 0x21, 0x64, 0xf0, 0x6e, 0x53, 0x32, 0xb8,
		0x12, 0xc6, 0x95, 0xb0, 0x4e, 0x4a, 0x89, 0x45, 0x39, 0xd1, 0x2a, 0x29, 0x62, 0x65, 0x15, 0xac,
		0x00, 0x32, 0x78, 0x37, 0x0e, 0x8d, 0xeb, 0x60, 0x7e, 0xb5, 0x1e, 0x9a, 0x06, 0xd7, 0xc1, 0xfb,
		0x6d, 0x3d, 0x32, 0x78, 0x93, 0x21, 0x03, 0xb8, 0x15, 0xd6, 0xe5, 0x0c, 0x21, 0x83, 0x17, 0x50,
		0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79, 0x47, 0x06, 0x2f, 0xc9, 0xbb, 0x22, 0x83,
		0x17, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xe9, 0xe6, 0x00, 0x19, 0xbc, 0xa0, 0x90, 0x62, 0x6e,
		0x2f, 0x32, 0x78, 0x33, 0x4b, 0x21, 0x21, 0x83, 0x17, 0xcc, 0x51, 0x82, 0x41, 0x3c, 0x32, 0x78,
		0x01, 0xea, 0x01, 0xea, 0x01, 0xea, 0xd3, 0x06, 0xea, 0x91, 0xc1, 0x9b, 0x66, 0xbc, 0x8d, 0x2b,
		0xdb, 0xcc, 0xe2, 0x6d, 0x64, 0xf0, 0x02, 0x71, 0xf3, 0x23, 0x6e, 0x64, 0xf0, 0x46, 0xcf, 0x7f,
		0x5b, 0xe6, 0x59, 0x25, 0xac, 0x4d, 0xd7, 0xb5, 0x8d, 0x26, 0x5d, 0x91, 0xd1, 0x17, 0x9a, 0x74,
		0xe9, 0xea, 0xb6, 0x21, 0xc4, 0x5f, 0x89, 0x5b, 0x86, 0x10, 0x7f, 0x82, 0xc3, 0x80, 0x10, 0x7f,
		0x70, 0x46, 0xe0, 0x8c, 0xc0, 0x19, 0xc9, 0x92, 0x77, 0x84, 0xf8, 0x83, 0x2f, 0x02, 0x5f, 0x04,
		0xbe, 0x28, 0xd2, 0xd6, 0x23, 0xc4, 0x1f, 0xb4, 0x91, 0xc4, 0x33, 0x84, 0x10, 0x7f, 0x40, 0x79,
		0x40, 0x79, 0x40, 0x79, 0x40, 0xf9, 0x9d, 0xe4, 0x1d, 0x21, 0xfe, 0x24, 0xef, 0x8a, 0x10, 0x7f,
		0x98, 0x03, 0x98, 0x03, 0x98, 0x83, 0xa4, 0x9b, 0x03, 0x84, 0xf8, 0x83, 0x42, 0x8a, 0xb9, 0xbd,
		0x08, 0xf1, 0xcf, 0x2c, 0x85, 0x84, 0x10, 0x7f, 0x30, 0x47, 0x09, 0x06, 0xf1, 0x08, 0xf1, 0x07,
		0xa8, 0x07, 0xa8, 0x07, 0xa8, 0x4f, 0x1b, 0xa8, 0x47, 0x88, 0x7f, 0x9a, 0xf1, 0x36, 0xae, 0x6c,
		0x33, 0x8b, 0xb7, 0x11, 0xe2, 0x0f, 0xc4, 0xcd, 0x8f, 0xb8, 0x11, 0xe2, 0x4f, 0x1c, 0xe2, 0xaf,
		0x7b, 0x8b, 0xae, 0x4d, 0x11, 0xfe, 0x68, 0xd0, 0x25, 0x4b, 0x04, 0x39, 0x45, 0x4f, 0xc3, 0xf6,
		0x5c, 0x1b, 0x84, 0x0d, 0xcd, 0xb9, 0xf4, 0x11, 0x1f, 0x8d, 0x5a, 0x73, 0x2d, 0x25, 0x45, 0xe7,
		0xc6, 0x5c, 0x9e, 0xeb, 0x0b, 0x63, 0xec, 0x0c, 0xad, 0xfe, 0xe3, 0x6c, 0x15, 0x8b, 0xf1, 0xdb,
		0x72, 0x85, 0x46, 0x44, 0x53, 0x2e, 0x34, 0xe5, 0x52, 0xc4, 0xb7, 0xa0, 0x29, 0x17, 0x9a, 0x72,
		0xa9, 0x23, 0x5f, 0xd1, 0x94, 0x0b, 0x4d, 0xb9, 0xb6, 0x0f, 0x84, 0xa6, 0x5c, 0x14, 0x03, 0x22,
		0x63, 0x17, 0x19, 0xbb, 0xc9, 0xe2, 0x83, 0x90, 0xb1, 0xbb, 0x4d, 0xc9, 0xe0, 0x0a, 0x18, 0x57,
		0xc0, 0x3a, 0x29, 0x25, 0x16, 0xe5, 0x44, 0xab, 0xa4, 0x88, 0x95, 0x55, 0xb0, 0x02, 0xc8, 0xd8,
		0xdd, 0x38, 0x34, 0xae, 0x7f, 0xf9, 0xd5, 0x7a, 0x68, 0x1a, 0x5c, 0xff, 0xee, 0xb7, 0xf5, 0xc8,
		0xd8, 0x4d, 0x86, 0x0c, 0xe0, 0x16, 0x58, 0x97, 0x33, 0x84, 0x8c, 0x5d, 0x40, 0x79, 0x40, 0x79,
		0x40, 0x79, 0x40, 0xf9, 0x9d, 0xe4, 0x1d, 0x19, 0xbb, 0x24, 0xef, 0x8a, 0x8c, 0x5d, 0x98, 0x03,
		0x98, 0x03, 0x98, 0x83, 0xa4, 0x9b, 0x03, 0x64, 0xec, 0x82, 0x42, 0x8a, 0xb9, 0xbd, 0xc8, 0xd8,
		0xcd, 0x2c, 0x85, 0x84, 0x8c, 0x5d, 0x30, 0x47, 0x09, 0x06, 0xf1, 0xc8, 0xd8, 0x05, 0xa8, 0x07,
		0xa8, 0x07, 0xa8, 0x4f, 0x1b, 0xa8, 0x47, 0xc6, 0x6e, 0x9a, 0xf1, 0x36, 0xae, 0x6c, 0x33, 0x8b,
		0xb7, 0x91, 0xb1, 0x0b, 0xc4, 0xcd, 0x8f, 0xb8, 0x91, 0xb1, 0xbb, 0x67, 0xde, 0xdb, 0xeb, 0x2c,
		0xab, 0x64, 0xb4, 0xe4, 0x6a, 0xbb, 0xbe, 0x68, 0xce, 0x1f, 0xba, 0x3e, 0x7e, 0x28, 0xa2, 0x21,
		0x57, 0x14, 0xe4, 0x85, 0x86, 0x5c, 0xba, 0xba, 0x6c, 0x08, 0xef, 0x57, 0xe2, 0x92, 0x21, 0xbc,
		0x9f, 0xe0, 0x30, 0x20, 0xbc, 0x1f, 0x7c, 0x11, 0xf8, 0x22, 0xf0, 0x45, 0xb2, 0xe4, 0x1d, 0xe1,
		0xfd, 0xe0, 0x8a, 0xc0, 0x15, 0x81, 0x2b, 0x8a, 0xb4, 0xf5, 0x08, 0xef, 0x07, 0x65, 0x24, 0xf1,
		0x0c, 0x21, 0xbc, 0x1f, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x1e, 0x50, 0x7e, 0x27, 0x79, 0x47, 0x78,
		0x3f, 0xc9, 0xbb, 0x22, 0xbc, 0x1f, 0xe6, 0x00, 0xe6, 0x00, 0xe6, 0x20, 0xe9, 0xe6, 0x00, 0xe1,
		0xfd, 0xa0, 0x90, 0x62, 0x6e, 0x2f, 0xc2, 0xfb, 0x33, 0x4b, 0x21, 0x21, 0xbc, 0x1f, 0xcc, 0x51,
		0x82, 0x41, 0x3c, 0xc2, 0xfb, 0x01, 0xea, 0x01, 0xea, 0x01, 0xea, 0xd3, 0x06, 0xea, 0x11, 0xde,
		0x9f, 0x66, 0xbc, 0x8d, 0x2b, 0xdb, 0xcc, 0xe2, 0x6d, 0x84, 0xf7, 0x03, 0x71, 0xf3, 0x23, 0x6e,
		0x84, 0xf7, 0x93, 0x86, 0xf7, 0x6b, 0xda, 0x8e, 0xeb, 0x17, 0xd1, 0xfd, 0x68, 0xc6, 0x25, 0x4b,
		0xfc, 0xf8, 0xc4, 0x4e, 0x9f, 0x56, 0x5c, 0xdb, 0x05, 0x0d, 0x8d, 0xb8, 0x74, 0x11, 0x1d, 0xf5,
		0x6d, 0xb8, 0xd6, 0xa5, 0x24, 0x41, 0x4d, 0xb8, 0xca, 0xe4, 0x4d, 0xb8, 0xca, 0x68, 0xc2, 0x85,
		0x26, 0x5c, 0xaa, 0x38, 0x16, 0x34, 0xe1, 0x42, 0x13, 0x2e, 0x75, 0x84, 0x2b, 0x9a, 0x70, 0xa1,
		0x09, 0xd7, 0xf6, 0x81, 0xd0, 0x84, 0x8b, 0x62, 0x40, 0x64, 0xe9, 0x22, 0x4b, 0x37, 0x59, 0x1c,
		0x10, 0xb2, 0x74, 0xb7, 0x29, 0x19, 0x5c, 0xfb, 0xe2, 0xda, 0x57, 0x27, 0xa5, 0xc4, 0xa2, 0x9c,
		0x68, 0x95, 0x14, 0xb1, 0xb2, 0x0a, 0x56, 0x00, 0x59, 0xba, 0x1b, 0x87, 0xc6, 0x95, 0x2f, 0xbf,
		0x5a, 0x0f, 0x4d, 0x83, 0x2b, 0xdf, 0xfd, 0xb6, 0x1e, 0x59, 0xba, 0xc9, 0x90, 0x01, 0xdc, 0xfc,
		0xea, 0x72, 0x86, 0x90, 0xa5, 0x0b, 0x28, 0x0f, 0x28, 0x0f, 0x28, 0x0f, 0x28, 0xbf, 0x93, 0xbc,
		0x23, 0x4b, 0x97, 0xe4, 0x5d, 0x91, 0xa5, 0x0b, 0x73, 0x00, 0x73, 0x00, 0x73, 0x90, 0x74, 0x73,
		0x80, 0x2c, 0x5d, 0x50, 0x48, 0x31, 0xb7, 0x17, 0x59, 0xba, 0x99, 0xa5, 0x90, 0x90, 0xa5, 0x0b,
		0xe6, 0x28, 0xc1, 0x20, 0x1e, 0x59, 0xba, 0x00, 0xf5, 0x00, 0xf5, 0x00, 0xf5, 0x69, 0x03, 0xf5,
		0xc8, 0xd2, 0x4d, 0x33, 0xde, 0xc6, 0x95, 0x6d, 0x66, 0xf1, 0x36, 0xb2, 0x74, 0x81, 0xb8, 0xf9,
		0x11, 0x37, 0xb2, 0x74, 0xe3, 0xe5, 0xbc, 0x95, 0x13, 0xd8, 0x84, 0xab, 0x8c, 0x26, 0x5c, 0x51,
		0x90, 0x17, 0x9a, 0x70, 0xe9, 0xea, 0xb2, 0x21, 0xbc, 0x5f, 0x89, 0x4b, 0x86, 0xf0, 0x7e, 0x82,
		0xc3, 0x80, 0xf0, 0x7e, 0xf0, 0x45, 0xe0, 0x8b, 0xc0, 0x17, 0xc9, 0x92, 0x77, 0x84, 0xf7, 0x83,
		0x2b, 0x02, 0x57, 0x04, 0xae, 0x28, 0xd2, 0xd6, 0x23, 0xbc, 0x1f, 0x94, 0x91, 0xc4, 0x33, 0x84,
		0xf0, 0x7e, 0x40, 0x79, 0x40, 0x79, 0x40, 0x79, 0x40, 0xf9, 0x9d, 0xe4, 0x1d, 0xe1, 0xfd, 0x24,
		0xef, 0x8a, 0xf0, 0x7e, 0x98, 0x03, 0x98, 0x03, 0x98, 0x83, 0xa4, 0x9b, 0x03, 0x84, 0xf7, 0x83,
		0x42, 0x8a, 0xb9, 0xbd, 0x08, 0xef, 0xcf, 0x2c, 0x85, 0x84, 0xf0, 0x7e, 0x30, 0x47, 0x09, 0x06,
		0xf1, 0x08, 0xef, 0x07, 0xa8, 0x07, 0xa8, 0x07, 0xa8, 0x4f, 0x1b, 0xa8, 0x47, 0x78, 0x7f, 0x9a,
		0xf1, 0x36, 0xae, 0x6c, 0x33, 0x8b, 0xb7, 0x11, 0xde, 0x0f, 0xc4, 0xcd, 0x8f, 0xb8, 0x11, 0xde,
		0x4f, 0x1a, 0xde, 0x9f, 0x84, 0x26, 0x5c, 0x65, 0x34, 0xe1, 0x62, 0x11, 0x3f, 0x3e, 0xb1, 0xd3,
		0xb4, 0x09, 0x57, 0x19, 0x4d, 0xb8, 0x74, 0x14, 0x1d, 0xcd, 0x9a, 0x70, 0x95, 0xb5, 0x6e, 0xc2,
		0x15, 0x2b, 0x53, 0x88, 0x24, 0x33, 0x88, 0xac, 0xdd, 0x56, 0x01, 0xed, 0xb6, 0x24, 0xb2, 0x2f,
		0x68, 0xb7, 0xf5, 0xfc, 0xe4, 0xb1, 0xdb, 0x6d, 0xad, 0x74, 0x97, 0xb1, 0xd4, 0x34, 0x44, 0xfd,
		0xb6, 0xd6, 0x87, 0xa5, 0x69, 0xb8, 0x75, 0x8c, 0x86, 0x5b, 0x0a, 0xc8, 0x54, 0x34, 0xdc, 0xd2,
		0x00, 0x2f, 0x93, 0x91, 0x9d, 0x81, 0xbc, 0x59, 0x03, 0x61, 0xfb, 0x96, 0xff, 0xe8, 0x8a, 0x3b,
		0x0a, 0xa1, 0x5b, 0x59, 0x4e, 0x02, 0x3a, 0x33, 0x57, 0x5f, 0x3e, 0xda, 0x27, 0xd3, 0x93, 0x90,
		0x3a, 0x5c, 0xfd, 0x5c, 0xef, 0xb5, 0x67, 0xff, 0xd3, 0xf9, 0x6f, 0xb3, 0x46, 0x25, 0xca, 0x73,
		0xc6, 0xc7, 0x23, 0xa5, 0x5c, 0x25, 0xdd, 0x9e, 0xb5, 0x5b, 0x9d, 0x5a, 0xaf, 0xd9, 0xb8, 0xa8,
		0x9f, 0xfd, 0xb7, 0x57, 0x6f, 0x7e, 0x2d, 0xe7, 0x74, 0xbc, 0x52, 0x94, 0xf4, 0xee, 0x17, 0x27,
		0x5f, 0x9b, 0x57, 0xb3, 0xb7, 0x2e, 0xf6, 0xae, 0xaf, 0xea, 0x67, 0xd5, 0x76, 0x27, 0x53, 0x6f,
		0x5f, 0xbf, 0xfa, 0x77, 0xbb, 0x53, 0xed, 0xd4, 0x7a, 0xed, 0xe6, 0xe7, 0x8c, 0x6e, 0xfb, 0xe5,
		0xf5, 0x45, 0x27, 0x73, 0x1b, 0xff, 0xb5, 0x79, 0xf5, 0xb5, 0xd8, 0xfb, 0x7c, 0xd1, 0xf8, 0x4f,
		0xbb, 0x59, 0x3b, 0xcb, 0xd2, 0x9b, 0xbf, 0x52, 0x76, 0xc5, 0x4c, 0x49, 0x7d, 0x61, 0x26, 0xf5,
		0x5f, 0x9b, 0x17, 0xed, 0xec, 0xbd, 0x75, 0xed, 0x6b, 0xf3, 0x2a, 0x93, 0xaa, 0x3d, 0x4b, 0x2f,
		0x3d, 0x57, 0xe8, 0x17, 0xd5, 0x4f, 0xb5, 0x8b, 0xda, 0x79, 0xb6, 0xed, 0x79, 0xd6, 0xa4, 0x7d,
		0x65, 0xcf, 0xcb, 0xd9, 0xb4, 0xe7, 0x73, 0xc1, 0xcf, 0xa2, 0x39, 0x9f, 0x6f, 0x79, 0x96, 0x4f,
		0xfc, 0xb3, 0xe0, 0x67, 0xf0, 0xed, 0xb3, 0xea, 0xb7, 0x49, 0xda, 0x6f, 0x92, 0x91, 0xba, 0xaa,
		0x79, 0xb5, 0x37, 0x0a, 0xf6, 0x3d, 0x27, 0x6c, 0xf3, 0x76, 0x28, 0x06, 0x74, 0x6c, 0xf9, 0x6a,
		0xc0, 0xb8, 0x6d, 0xf9, 0x69, 0x13, 0xdf, 0xc1, 0xbb, 0xef, 0x35, 0x22, 0x78, 0x77, 0xf0, 0xee,
		0xbf, 0x97, 0x37, 0xba, 0xc4, 0x71, 0xa2, 0x44, 0x71, 0xc4, 0x7b, 0xc4, 0x88, 0xf7, 0x88, 0x19,
		0x83, 0x46, 0x15, 0xe4, 0x11, 0x3d, 0xb0, 0x8c, 0x27, 0xb6, 0x63, 0xe2, 0x09, 0x63, 0x34, 0x19,
		0xfa, 0xd6, 0x78, 0x28, 0x8c, 0xd9, 0xd2, 0x7b, 0xf1, 0x03, 0x3d, 0x36, 0x8c, 0xa9, 0x38, 0xea,
		0xe3, 0x18, 0x51, 0x1f, 0x12, 0xcd, 0x17, 0xa2, 0x3e, 0x5e, 0x00, 0xbd, 0xb8, 0x51, 0x1f, 0xfd,
		0x95, 0xcc, 0x12, 0x01, 0x58, 0x92, 0x5a, 0xdb, 0x44, 0x85, 0x98, 0x81, 0x37, 0x81, 0x37, 0x93,
		0x8a, 0x37, 0xa9, 0x0a, 0x27, 0x93, 0xb9, 0xa8, 0x92, 0x5c, 0x55, 0x59, 0x2e, 0x2b, 0xb1, 0xeb,
		0x4a, 0xae, 0x52, 0x64, 0xa8, 0x16, 0x79, 0x2a, 0x46, 0x96, 0xaa, 0x91, 0xae, 0x72, 0xa4, 0xab,
		0x1e, 0xa9, 0x2a, 0x88, 0x96, 0xa2, 0xa3, 0xca, 0x18, 0x22, 0xcf, 0xb7, 0x95, 0x58, 0x4b, 0x8d,
		0xb8, 0x86, 0x1a, 0xb2, 0x6d, 0xe4, 0xb9, 0xd0, 0x61, 0x37, 0x8e, 0xae, 0x71, 0x0b, 0x91, 0x7b,
		0x7d, 0xed, 0x89, 0xcb, 0xe5, 0x13, 0x36, 0x67, 0x0f, 0x48, 0xd2, 0xa6, 0x45, 0x11, 0x73, 0x3d,
		0x53, 0x50, 0x74, 0xb4, 0x75, 0x7c, 0x33, 0x03, 0xcc, 0x0f, 0xcc, 0x0f, 0xcc, 0x4f, 0x23, 0x6e,
		0x44, 0x4e, 0xbd, 0x1c, 0xe7, 0x9e, 0xf8, 0xc0, 0x03, 0x99, 0x03, 0x99, 0x03, 0x99, 0xd3, 0x2a,
		0x90, 0x60, 0x40, 0x73, 0x38, 0x74, 0xfe, 0x79, 0x46, 0x65, 0xa6, 0xc4, 0x96, 0x4b, 0xe1, 0xa9,
		0x50, 0x0c, 0x1e, 0x85, 0xc2, 0xb8, 0xd5, 0x1d, 0x9b, 0xda, 0x63, 0x53, 0x7f, 0x2c, 0x6a, 0x90,
		0x56, 0x1d, 0x12, 0xab, 0x45, 0x79, 0xc4, 0x05, 0x03, 0x81, 0x21, 0x89, 0xc8, 0xa0, 0xdf, 0x30,
		0xca, 0x3a, 0x92, 0x23, 0xf3, 0x87, 0x35, 0x9a, 0x8c, 0x62, 0x5e, 0x10, 0xff, 0x76, 0xb7, 0xd6,
		0xa7, 0x91, 0x67, 0x6e, 0xf2, 0x30, 0x35, 0x30, 0x35, 0x30, 0x35, 0x30, 0x35, 0x94, 0xf2, 0x8e,
		0x16, 0x82, 0xa1, 0x5f, 0xa8, 0x47, 0xb9, 0xd3, 0x34, 0xa8, 0x47, 0xb9, 0xdf, 0xd6, 0xa3, 0x85,
		0x60, 0x32, 0x64, 0x00, 0x65, 0x29, 0x53, 0x44, 0x65, 0x25, 0xa1, 0x2c, 0xe5, 0x86, 0x1b, 0x4b,
		0x31, 0x1b, 0x81, 0x94, 0x26, 0x3f, 0x90, 0x78, 0x7d, 0x59, 0xbb, 0xbd, 0x1f, 0x93, 0xdc, 0x61,
		0xd2, 0xc9, 0xd0, 0x94, 0xe4, 0xb2, 0x37, 0x4e, 0x01, 0xb9, 0xad, 0x88, 0x8b, 0xb2, 0xce, 0xa8,
		0xb4, 0xcb, 0x8f, 0x02, 0x2e, 0x3f, 0x12, 0xe4, 0x9a, 0xe1, 0xf2, 0x03, 0x97, 0x1f, 0xb8, 0xfc,
		0x00, 0x23, 0x05, 0x46, 0x0a, 0x8c, 0x54, 0xe2, 0x19, 0x29, 0x5c, 0x7e, 0x90, 0xbc, 0x2b, 0x2e,
		0x3f, 0x60, 0x6a, 0x60, 0x6a, 0x60, 0x6a, 0x60, 0x6a, 0xb6, 0xcb, 0x3b, 0x2e, 0x3f, 0x42, 0xbf,
		0x70, 0xf9, 0xb1, 0xd3, 0x34, 0xb8, 0xfc, 0xd8, 0x6f, 0xeb, 0x71, 0xf9, 0x91, 0x0c, 0x19, 0xc0,
		0xe5, 0x47, 0x8a, 0xa8, 0xac, 0x24, 0x5f, 0x7e, 0x68, 0xda, 0x8d, 0x6b, 0xf3, 0xdd, 0x07, 0x1a,
		0x71, 0xc9, 0x92, 0x39, 0x0e, 0x59, 0xd3, 0x38, 0x31, 0xb0, 0x16, 0x1b, 0xf6, 0xab, 0x49, 0x0b,
		0xb4, 0x48, 0xd3, 0x02, 0x2d, 0xa4, 0x05, 0xf2, 0xba, 0xef, 0x48, 0x0b, 0x44, 0x5a, 0xe0, 0xf6,
		0x81, 0x90, 0x16, 0xa8, 0x29, 0x9f, 0x87, 0x9b, 0x71, 0x7e, 0xbe, 0x0e, 0x37, 0xe3, 0xd1, 0x07,
		0xc4, 0x15, 0x85, 0x0a, 0x42, 0x03, 0x57, 0x14, 0xac, 0x2a, 0x8e, 0x4d, 0xd5, 0xb1, 0xa9, 0x3c,
		0x16, 0xd5, 0x27, 0x87, 0x3b, 0xc2, 0x15, 0x45, 0x48, 0xbb, 0xe0, 0x8a, 0xe2, 0xc5, 0x83, 0xe3,
		0x8a, 0x62, 0xff, 0x79, 0x70, 0x45, 0xa1, 0xed, 0xd6, 0xe3, 0x8a, 0x42, 0xdd, 0xa8, 0xb8, 0xa2,
		0xd8, 0x09, 0x42, 0x24, 0xf3, 0x8a, 0xc2, 0x4a, 0x54, 0x7e, 0x46, 0x1d, 0xf9, 0x19, 0x7b, 0x20,
		0x2e, 0xe4, 0x67, 0x80, 0x85, 0x02, 0x0b, 0x05, 0x16, 0x0a, 0x2c, 0x14, 0x58, 0x28, 0xb0, 0x50,
		0x60, 0xa1, 0xc0, 0x42, 0x81, 0x85, 0x02, 0x0b, 0x05, 0x16, 0x0a, 0x2c, 0x14, 0x58, 0x28, 0xb0,
		0x50, 0x60, 0xa1, 0x34, 0x63, 0xa1, 0x92, 0x12, 0x28, 0x5b, 0x47, 0xa0, 0xac, 0x4c, 0x99, 0xe3,
		0x90, 0x35, 0x8d, 0x03, 0x65, 0xeb, 0x09, 0x0d, 0x94, 0xa5, 0xe1, 0x30, 0x49, 0xb9, 0x4b, 0xf2,
		0x50, 0xd9, 0x02, 0x42, 0x65, 0x35, 0x70, 0xd0, 0x11, 0x2a, 0xcb, 0xcf, 0x31, 0xa2, 0x6b, 0x1e,
		0xba, 0xe6, 0xe1, 0xfa, 0x03, 0xd7, 0x1f, 0xe8, 0x9a, 0x07, 0xc4, 0x9f, 0x38, 0xc4, 0x4f, 0xe5,
		0x58, 0xca, 0x82, 0xfc, 0x04, 0xbe, 0xe4, 0x34, 0x21, 0xed, 0xb9, 0x89, 0x24, 0x47, 0xb2, 0xc4,
		0xe4, 0x62, 0xf9, 0x41, 0x32, 0x64, 0x24, 0x9a, 0x74, 0xec, 0xbf, 0xb7, 0xfb, 0x7d, 0x63, 0x4f,
		0x29, 0x98, 0x99, 0xe7, 0x79, 0x71, 0xbf, 0xe5, 0xca, 0x1b, 0xf3, 0x55, 0xda, 0x73, 0x8c, 0x0b,
		0xcb, 0xf3, 0xab, 0xbe, 0x1f, 0x0d, 0xd6, 0xe6, 0x2e, 0x2d, 0xbb, 0x36, 0x14, 0x33, 0x03, 0xeb,
		0x45, 0x03, 0x5f, 0xb9, 0x4b, 0xf3, 0xc7, 0x8b, 0x11, 0xf2, 0x1f, 0x8a, 0xc5, 0x72, 0xa5, 0x58,
		0x3c, 0xae, 0x9c, 0x54, 0x8e, 0x4f, 0x4b, 0xa5, 0x7c, 0x39, 0x1f, 0x81, 0x1b, 0xce, 0x35, 0xdc,
		0x81, 0x70, 0xc5, 0xe0, 0xd3, 0x6c, 0x79, 0xec, 0xc9, 0x70, 0x28, 0x75, 0x17, 0x62, 0x9e, 0x41,
		0xca, 0xb3, 0x17, 0xe1, 0xa0, 0xd1, 0x1c, 0xb0, 0xfd, 0xce, 0xd3, 0xee, 0xa7, 0x62, 0xb7, 0x9f,
		0xdc, 0x71, 0xc7, 0xa2, 0xee, 0x14, 0xc1, 0x0e, 0xed, 0xb1, 0x31, 0xf1, 0x36, 0x64, 0xb7, 0x8d,
		0xf8, 0xfd, 0xb2, 0xee, 0xb0, 0xa4, 0x39, 0x73, 0x3c, 0x1e, 0x3e, 0x1a, 0x63, 0x67, 0x68, 0xf5,
		0x1f, 0x77, 0x5e, 0xd0, 0xe7, 0x92, 0xa4, 0x2f, 0xbf, 0xbd, 0xe3, 0x06, 0xee, 0x47, 0x40, 0xed,
		0xed, 0x15, 0x46, 0xf1, 0xfa, 0x5e, 0x7a, 0x75, 0xee, 0xd8, 0x19, 0xee, 0xb3, 0xd3, 0x11, 0xdd,
		0xb6, 0xd8, 0x6e, 0x59, 0x6c, 0xb7, 0xeb, 0xb5, 0x5b, 0x35, 0x7f, 0x71, 0x45, 0x87, 0x7a, 0x5f,
		0x4a, 0x26, 0x6a, 0x96, 0x72, 0xbc, 0x6c, 0xe4, 0x88, 0xdc, 0x69, 0x64, 0x62, 0x23, 0x0e, 0x81,
		0x11, 0x43, 0xa4, 0xa9, 0x18, 0x09, 0x32, 0xe6, 0x81, 0x8c, 0x61, 0x88, 0x27, 0xf2, 0x3c, 0x78,
		0x30, 0x2a, 0x3b, 0x99, 0x1b, 0x2c, 0x58, 0x3e, 0x43, 0xfc, 0x18, 0x3b, 0xae, 0xbf, 0xaf, 0x4a,
		0xdf, 0x2a, 0x3f, 0x9b, 0x87, 0x8d, 0xb8, 0xfe, 0x2f, 0x98, 0xc8, 0x56, 0xed, 0xff, 0x6a, 0x67,
		0x9d, 0x5e, 0xab, 0x71, 0xdd, 0xa9, 0x45, 0x1d, 0x2e, 0x1e, 0x01, 0x19, 0x9b, 0x70, 0xa4, 0x20,
		0x18, 0x09, 0xce, 0x29, 0x35, 0x83, 0x48, 0xce, 0x18, 0x92, 0x33, 0x84, 0x34, 0xe7, 0x58, 0x8d,
		0xb7, 0x1f, 0x9b, 0xe2, 0x0b, 0x9d, 0xcc, 0xc5, 0x91, 0x34, 0xfc, 0xd9, 0xc0, 0x31, 0xa4, 0x67,
		0x65, 0xdc, 0x8a, 0x31, 0xc6, 0xa8, 0xd9, 0x93, 0xd1, 0xec, 0xe5, 0xa6, 0x5c, 0xae, 0xf9, 0xbb,
		0xe8, 0x7a, 0xd2, 0x1a, 0x49, 0xd1, 0x93, 0xeb, 0xc3, 0x42, 0x4f, 0x42, 0x4f, 0x42, 0x4f, 0x42,
		0x4f, 0x26, 0x50, 0x4f, 0x12, 0xe3, 0x48, 0x12, 0xfc, 0x08, 0x45, 0x06, 0x45, 0x96, 0x5d, 0x45,
		0x36, 0x14, 0xe6, 0x9d, 0x2b, 0xee, 0x28, 0x94, 0x57, 0x8c, 0x8c, 0x8c, 0x5c, 0x33, 0xe0, 0x50,
		0x17, 0x1b, 0xf1, 0xd1, 0x75, 0x26, 0xbe, 0x65, 0xdf, 0x2f, 0xcf, 0x76, 0xf0, 0xd7, 0x4b, 0x7d,
		0x3b, 0x10, 0x77, 0x96, 0x6d, 0xf9, 0x96, 0x63, 0x7b, 0xdb, 0xff, 0x29, 0xf8, 0x97, 0x39, 0x65,
		0xca, 0xba, 0x3f, 0xb1, 0x2e, 0x4f, 0x82, 0x51, 0x62, 0x5f, 0xa2, 0x3c, 0x8f, 0x24, 0xe1, 0x32,
		0x25, 0x18, 0xfc, 0xe5, 0xa5, 0x0a, 0x51, 0x54, 0xe2, 0xc4, 0x13, 0x6e, 0x5c, 0x7d, 0x41, 0x18,
		0xfb, 0xf2, 0x52, 0x99, 0x39, 0x8b, 0xb7, 0x35, 0x6e, 0x1f, 0x29, 0x6e, 0xba, 0x65, 0xc4, 0xb9,
		0xac, 0x29, 0xb6, 0xf9, 0x4a, 0x26, 0xeb, 0xca, 0x9b, 0x05, 0x89, 0x10, 0x7b, 0x6a, 0x24, 0x1e,
		0x1a, 0x90, 0x08, 0x90, 0x08, 0x90, 0x08, 0x90, 0x08, 0x90, 0x08, 0x90, 0x08, 0x90, 0x48, 0x22,
		0x91, 0x48, 0x4a, 0x03, 0x8a, 0x5e, 0x84, 0x64, 0x44, 0x2f, 0x62, 0x15, 0x31, 0x80, 0x65, 0x36,
		0x77, 0x73, 0x3e, 0x75, 0xa4, 0x8a, 0x54, 0x7b, 0xc4, 0x14, 0xed, 0x15, 0x8b, 0x13, 0x25, 0x0b,
		0x2b, 0x56, 0xd6, 0x55, 0xec, 0x48, 0x81, 0x02, 0x22, 0x05, 0x94, 0x6a, 0x46, 0x44, 0x0a, 0xec,
		0x2f, 0x3f, 0x88, 0x14, 0x80, 0xbb, 0x06, 0x77, 0x4d, 0x47, 0x77, 0x0d, 0x37, 0x60, 0x88, 0x14,
		0x80, 0x9e, 0x84, 0x9e, 0x84, 0x9e, 0x84, 0x9e, 0x94, 0xa0, 0x27, 0x11, 0x29, 0x00, 0x45, 0x06,
		0x45, 0xa6, 0x93, 0x22, 0x03, 0x3f, 0x2f, 0x63, 0x7f, 0xc0, 0xcf, 0xc7, 0x93, 0x4a, 0xf0, 0xf3,
		0x54, 0x8a, 0x0d, 0x91, 0x02, 0x9b, 0xd7, 0x08, 0x91, 0x02, 0x40, 0x22, 0x40, 0x22, 0x40, 0x22,
		0x40, 0x22, 0x40, 0x22, 0x40, 0x22, 0x40, 0x22, 0x44, 0x48, 0x24, 0x03, 0x91, 0x02, 0x51, 0xeb,
		0x41, 0xc5, 0x0f, 0x14, 0x88, 0x50, 0xe9, 0x29, 0x3b, 0xb5, 0x47, 0xf6, 0xaf, 0xaf, 0x41, 0xb2,
		0x29, 0xac, 0x15, 0x48, 0xbc, 0x79, 0x81, 0x29, 0xc3, 0x19, 0xcf, 0xed, 0x6d, 0x84, 0x22, 0x24,
		0xaf, 0x06, 0x48, 0x47, 0x1d, 0x92, 0xfd, 0xaa, 0x4b, 0xa6, 0xa7, 0x0c, 0xc9, 0x5e, 0xd5, 0x1d,
		0x51, 0x85, 0x44, 0xbe, 0x23, 0x49, 0x15, 0x5b, 0x14, 0xad, 0x5c, 0x6a, 0xfa, 0x43, 0x8b, 0x22,
		0x95, 0x33, 0xd5, 0x34, 0xb2, 0xc8, 0x1c, 0x0e, 0x9d, 0x7f, 0x0c, 0xe7, 0x1f, 0xdb, 0x30, 0xbd,
		0xf8, 0xf4, 0xcb, 0xda, 0x68, 0xf1, 0xef, 0xc7, 0x8f, 0xc1, 0xe0, 0x10, 0xd4, 0x2d, 0xce, 0x2e,
		0x81, 0x13, 0xab, 0xee, 0x70, 0x52, 0xf9, 0x9b, 0x89, 0x65, 0xfb, 0x1f, 0x08, 0xd8, 0x9b, 0x38,
		0x04, 0x00, 0x4d, 0xab, 0x2f, 0x02, 0x37, 0x9d, 0xb2, 0x75, 0x17, 0x75, 0xf5, 0x74, 0xe2, 0x56,
		0x5c, 0x32, 0xda, 0x2d, 0x51, 0xb4, 0x05, 0xa6, 0x6c, 0xa1, 0x25, 0x6b, 0x0b, 0x0a, 0xa5, 0x92,
		0xc6, 0x9b, 0xa0, 0x88, 0xac, 0xe9, 0xea, 0x1c, 0xe8, 0x67, 0x79, 0xe6, 0xed, 0x50, 0x18, 0x73,
		0xcf, 0xdb, 0xf4, 0x8c, 0x3b, 0x6b, 0xe8, 0x0b, 0x97, 0x20, 0xd2, 0x6f, 0xf3, 0xb8, 0xf1, 0xa1,
		0x4c, 0x9c, 0x36, 0x0e, 0x80, 0x33, 0x80, 0x33, 0x99, 0x85, 0x33, 0xf1, 0xdb, 0x20, 0xc4, 0x6c,
		0x7b, 0xc0, 0xa3, 0xd0, 0x5c, 0x31, 0x1e, 0x9a, 0xfd, 0x40, 0xf1, 0xc4, 0xd7, 0x64, 0xaf, 0x07,
		0x84, 0x0a, 0x83, 0x0a, 0x83, 0x0a, 0x83, 0x0a, 0xd3, 0x81, 0xad, 0x52, 0x77, 0x81, 0xb6, 0x7e,
		0xf1, 0xc0, 0x9e, 0x6d, 0xeb, 0x35, 0x4d, 0xff, 0x7b, 0x63, 0x31, 0x39, 0xf2, 0x6d, 0x93, 0x98,
		0x6f, 0x0b, 0x4e, 0x9c, 0x50, 0xb1, 0x83, 0x13, 0xdf, 0x1f, 0x85, 0x81, 0x13, 0x07, 0x02, 0x03,
		0x02, 0xdb, 0x53, 0x5e, 0xc0, 0x89, 0xbf, 0x78, 0x10, 0x70, 0xe2, 0xb1, 0x7e, 0x81, 0x13, 0xd7,
		0x61, 0x13, 0xc0, 0x89, 0x87, 0x96, 0x19, 0x9c, 0x38, 0xe0, 0x0c, 0xe0, 0x0c, 0x08, 0x25, 0x3d,
		0x09, 0x25, 0x70, 0xe2, 0x50, 0x61, 0x50, 0x61, 0x50, 0x61, 0xe0, 0xc4, 0xb7, 0x08, 0x85, 0x2e,
		0x9c, 0x38, 0x73, 0x5e, 0xc9, 0x1a, 0x25, 0x8e, 0xcc, 0x92, 0x9d, 0xf7, 0x49, 0x7e, 0x72, 0xc9,
		0xcb, 0x9d, 0xe1, 0x4c, 0x2f, 0xd9, 0x33, 0x46, 0x3f, 0x5a, 0x6c, 0x3e, 0x92, 0x49, 0x0e, 0x90,
		0x4c, 0xf2, 0x0a, 0xd6, 0xed, 0x9b, 0x4c, 0x62, 0x4e, 0xfc, 0xef, 0xc6, 0xd8, 0xf4, 0xbc, 0xe5,
		0x12, 0x46, 0xbc, 0x3e, 0x5b, 0x1f, 0x26, 0xda, 0x35, 0xda, 0x31, 0x52, 0x4b, 0x38, 0xb1, 0x61,
		0x96, 0xae, 0xd1, 0x22, 0x63, 0xbe, 0x67, 0xb7, 0x6b, 0x95, 0xb9, 0x1f, 0x4d, 0xc6, 0xd7, 0xd4,
		0xf5, 0x07, 0x0d, 0xae, 0xcb, 0x07, 0xc2, 0xeb, 0xbb, 0xd6, 0x38, 0x12, 0x56, 0x7b, 0x51, 0xb9,
		0xee, 0x79, 0x10, 0x9c, 0x79, 0x9c, 0xf9, 0x94, 0x9d, 0x79, 0xcf, 0x77, 0x2d, 0xfb, 0x3e, 0xe9,
		0x27, 0x7d, 0xe8, 0xf4, 0xcd, 0x61, 0x14, 0xea, 0xe9, 0xb9, 0x9a, 0xca, 0x6a, 0x04, 0x9c, 0x71,
		0x9c, 0xf1, 0x94, 0x9d, 0x71, 0xd3, 0x33, 0xec, 0xc9, 0xe8, 0x36, 0xd2, 0x5d, 0xd0, 0x4a, 0xc0,
		0x23, 0x94, 0x08, 0x8a, 0x79, 0x93, 0x1e, 0xaf, 0xfc, 0x0e, 0x01, 0x3f, 0x49, 0x72, 0x5d, 0x4b,
		0x75, 0x53, 0x4e, 0x79, 0x39, 0x3b, 0x8d, 0x57, 0x8f, 0x48, 0xbb, 0xa5, 0x2d, 0x16, 0x4e, 0x8b,
		0xa7, 0xe5, 0x4a, 0xe1, 0xb4, 0xa4, 0xd1, 0x1a, 0x33, 0x91, 0x9d, 0x5d, 0x0d, 0xac, 0x6f, 0xd4,
		0x7b, 0x9f, 0x40, 0x41, 0x45, 0xbb, 0xe7, 0x81, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85, 0xed, 0x85,
		0xed, 0x85, 0xed, 0xcd, 0xb6, 0xed, 0x9d, 0x5f, 0x3c, 0x19, 0xcb, 0x7b, 0xa3, 0x38, 0x36, 0xf8,
		0xc5, 0x40, 0xb0, 0xc5, 0xb0, 0xc5, 0xe0, 0xba, 0x34, 0xe4, 0xba, 0xe6, 0x07, 0xd5, 0x8f, 0xb2,
		0x18, 0xeb, 0x67, 0x3d, 0x42, 0x0f, 0x16, 0x9c, 0x72, 0x9c, 0x72, 0xed, 0x4f, 0x79, 0x54, 0xe1,
		0x3e, 0x88, 0xd9, 0x58, 0x28, 0x62, 0x43, 0x21, 0x39, 0x4a, 0xc2, 0x15, 0x23, 0xe7, 0x41, 0x18,
		0x63, 0xd7, 0x7a, 0x30, 0x7d, 0x11, 0xcb, 0x39, 0x0f, 0x0f, 0x05, 0xa5, 0x01, 0xa5, 0x91, 0x32,
		0xa5, 0x11, 0x12, 0xf2, 0x65, 0xf8, 0x56, 0x1c, 0x1d, 0x12, 0xc1, 0x23, 0xca, 0xd5, 0x07, 0xc2,
		0xf6, 0x2d, 0xff, 0xf1, 0x93, 0xe9, 0x89, 0xf8, 0x71, 0xd4, 0xad, 0xda, 0x65, 0xe3, 0x6b, 0xad,
		0xd7, 0x6c, 0xd5, 0xbf, 0x56, 0x3b, 0xb5, 0x5e, 0xb5, 0xdd, 0x6b, 0x34, 0x3b, 0xf5, 0xc6, 0x55,
		0x54, 0x91, 0x9a, 0x3b, 0x7d, 0x5e, 0xac, 0xdc, 0x38, 0xa2, 0x32, 0xf3, 0x2f, 0x5e, 0x69, 0xf9,
		0x92, 0xd5, 0x8b, 0x8b, 0x9c, 0x0a, 0xaf, 0x5c, 0xc6, 0x0b, 0x35, 0x2f, 0xaa, 0x67, 0x71, 0xdf,
		0x28, 0xd2, 0x37, 0xbb, 0xb2, 0x0f, 0xb6, 0x1c, 0x63, 0xe7, 0x4c, 0x7c, 0x61, 0xdc, 0x0d, 0xcd,
		0xb1, 0x31, 0x30, 0x47, 0xe3, 0x19, 0xc6, 0x8f, 0x6e, 0xed, 0xc2, 0x63, 0xed, 0x9b, 0xce, 0x1e,
		0x2f, 0xeb, 0x00, 0xe6, 0x12, 0xe6, 0x52, 0x7b, 0x73, 0x19, 0x3d, 0x2b, 0x20, 0x62, 0x36, 0x80,
		0xa4, 0x7a, 0x2a, 0xc2, 0x1e, 0x18, 0x7d, 0x67, 0x34, 0x9a, 0xd8, 0x96, 0xff, 0x18, 0xa3, 0xb0,
		0xca, 0xfa, 0x38, 0xd1, 0x15, 0xc6, 0x55, 0xe3, 0xaa, 0x06, 0x7d, 0x01, 0x7d, 0x91, 0x36, 0x7d,
		0x11, 0x9c, 0x8d, 0x74, 0x3a, 0xe6, 0xc9, 0x4e, 0x58, 0xd9, 0xbb, 0xb8, 0x56, 0xb4, 0x3c, 0x95,
		0x7d, 0xca, 0x68, 0xd1, 0x24, 0xa8, 0x88, 0xdb, 0xfb, 0xb1, 0x31, 0x9a, 0x0c, 0x7d, 0xeb, 0xbb,
		0x33, 0xde, 0x3f, 0x4f, 0x65, 0xfd, 0xeb, 0x48, 0x57, 0x61, 0xd4, 0xb2, 0xe8, 0x7d, 0x82, 0xde,
		0x27, 0x80, 0x11, 0x29, 0x83, 0x11, 0x91, 0xeb, 0xbc, 0x09, 0xdb, 0xbc, 0x1d, 0x8a, 0x01, 0x41,
		0xff, 0xfb, 0xe5, 0x40, 0xa8, 0x27, 0x80, 0x7a, 0x02, 0x7c, 0x47, 0x93, 0xf4, 0x88, 0xc6, 0xe3,
		0xf7, 0x50, 0x4f, 0x80, 0xa9, 0x24, 0xca, 0x0a, 0x36, 0x1a, 0xbe, 0x3f, 0x8c, 0xaf, 0xb7, 0xd6,
		0x46, 0x83, 0xd2, 0x81, 0xd2, 0x81, 0xd2, 0xd9, 0x4b, 0x5e, 0x50, 0x56, 0xf2, 0xc5, 0x83, 0xa0,
		0xac, 0x64, 0xac, 0x5f, 0x28, 0x2b, 0xa9, 0xc3, 0x26, 0xa4, 0xbd, 0xac, 0x64, 0x3a, 0x4b, 0x18,
		0xad, 0x31, 0x6a, 0xdc, 0x45, 0xfd, 0x6b, 0xb7, 0xf7, 0xe3, 0xcb, 0xe5, 0xdc, 0xa8, 0xe9, 0x8f,
		0x9a, 0xfe, 0xe0, 0x7a, 0xc0, 0xf5, 0x80, 0xeb, 0x81, 0xdb, 0x05, 0xb7, 0x0b, 0x5c, 0x0f, 0xb8,
		0x1e, 0x28, 0x1d, 0x28, 0x1d, 0x70, 0x3d, 0xe0, 0x7a, 0xc0, 0xf5, 0x80, 0xeb, 0x01, 0xd7, 0x03,
		0xae, 0x87, 0x98, 0xeb, 0xe1, 0x2d, 0x56, 0xbd, 0x46, 0xf5, 0xa0, 0x56, 0xf5, 0x8e, 0x9b, 0x24,
		0x3d, 0x02, 0xf0, 0xe5, 0xb6, 0xb0, 0xc6, 0x01, 0xce, 0xa9, 0x00, 0xe3, 0xf6, 0x6e, 0x10, 0x21,
		0x08, 0xf0, 0xf9, 0xbb, 0x29, 0x89, 0x00, 0xbc, 0x1b, 0x64, 0x33, 0x02, 0xf0, 0x6e, 0x80, 0x08,
		0x40, 0x42, 0xc1, 0x8d, 0xed, 0x2d, 0x92, 0xb1, 0xc2, 0x77, 0x03, 0xb0, 0xc2, 0x71, 0x05, 0x9e,
		0x07, 0x8c, 0x24, 0x9e, 0x15, 0x4e, 0x1b, 0xb1, 0x72, 0x37, 0x00, 0xb1, 0xc2, 0x75, 0xb4, 0xc0,
		0xe6, 0xa2, 0x13, 0x10, 0x11, 0x6a, 0x0f, 0x30, 0x29, 0xfb, 0x1d, 0xfa, 0x7c, 0xe6, 0x4f, 0x77,
		0x03, 0x5c, 0xa0, 0x27, 0xf2, 0x02, 0x1d, 0x50, 0x09, 0x50, 0x09, 0x50, 0x09, 0x50, 0x09, 0x50,
		0x09, 0x50, 0x29, 0x6b, 0x50, 0x89, 0x99, 0x82, 0x0e, 0x90, 0x12, 0xf8, 0xe7, 0x5d, 0xb6, 0x47,
		0x3e, 0xf9, 0xbc, 0xda, 0x10, 0x56, 0xe6, 0xd9, 0x75, 0x1d, 0xd7, 0xf8, 0x6e, 0xda, 0x83, 0xe1,
		0x3e, 0x55, 0x89, 0x9e, 0x6d, 0xf0, 0xfa, 0xf7, 0x91, 0x83, 0x9e, 0x68, 0x06, 0x1a, 0x39, 0xe8,
		0x29, 0x65, 0xa0, 0x11, 0x97, 0x1c, 0x5f, 0xe0, 0x35, 0x77, 0xab, 0x7c, 0x57, 0x98, 0xbe, 0x61,
		0x7a, 0xc6, 0x3f, 0x96, 0xff, 0x7d, 0xe0, 0x9a, 0xff, 0xc4, 0x77, 0xb0, 0xc2, 0x43, 0x22, 0x56,
		0x19, 0x61, 0x83, 0x1a, 0xb8, 0x6c, 0x88, 0x55, 0x86, 0xcb, 0xa6, 0xd0, 0x65, 0x5b, 0xc3, 0xbc,
		0xec, 0x0c, 0xf7, 0x6c, 0xf6, 0x3f, 0x96, 0x93, 0x83, 0xe5, 0x46, 0x9a, 0x18, 0xe0, 0x18, 0xe0,
		0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0xe0, 0x18, 0x37, 0x8b, 0xbe, 0x86, 0xc6,
		0xc0, 0xa4, 0xef, 0xba, 0x4d, 0xf2, 0xd9, 0xf4, 0x97, 0x1b, 0xc3, 0xc9, 0xa8, 0xdf, 0xbb, 0x66,
		0x5f, 0xdc, 0x4d, 0x86, 0x86, 0x2b, 0x3c, 0xdf, 0x74, 0xfd, 0xfd, 0x39, 0xf5, 0xd0, 0x08, 0x60,
		0xd5, 0x19, 0xcd, 0x27, 0x58, 0x75, 0xb0, 0xea, 0x70, 0xe3, 0xe0, 0xc6, 0x2d, 0xbe, 0x88, 0x60,
		0x25, 0xb8, 0x5a, 0x70, 0xb5, 0xe0, 0x6a, 0xc9, 0x5f, 0xb4, 0xdc, 0x77, 0x31, 0x1c, 0x0b, 0xd7,
		0x70, 0xec, 0xe1, 0x63, 0x7c, 0x75, 0xf3, 0x72, 0x30, 0xa8, 0x1c, 0xa8, 0x1c, 0xa8, 0x1c, 0xa8,
		0x9c, 0xf0, 0x33, 0x2e, 0x1d, 0x4c, 0xc3, 0xb7, 0x46, 0x04, 0xcd, 0x1c, 0xd7, 0x46, 0x83, 0xd2,
		0x81, 0xd2, 0x81, 0xd2, 0xd9, 0x4b, 0x5e, 0x26, 0x96, 0xed, 0xe7, 0xcb, 0x04, 0x3a, 0xa7, 0x8c,
		0xca, 0x40, 0xa4, 0x6a, 0x25, 0x34, 0x1c, 0x2a, 0x03, 0x69, 0xb3, 0x05, 0xc5, 0xe3, 0xd3, 0x32,
		0x4a, 0x03, 0xbd, 0xfe, 0xd5, 0xd5, 0x18, 0x74, 0x78, 0xbe, 0x39, 0x14, 0xc6, 0xbc, 0x8d, 0xad,
		0x47, 0x84, 0x3c, 0xc2, 0x43, 0x02, 0x7e, 0x00, 0x7e, 0x00, 0x7e, 0xec, 0x25, 0x2f, 0x03, 0xd1,
		0xb7, 0x46, 0xe6, 0xb0, 0x5c, 0xa4, 0xf0, 0x7a, 0x0a, 0x31, 0xc6, 0x08, 0xe9, 0xe1, 0x02, 0xf0,
		0xcc, 0xe6, 0x65, 0x2e, 0x00, 0xcf, 0xa8, 0xc6, 0x33, 0x27, 0x19, 0xda, 0x02, 0xd4, 0x39, 0x8c,
		0x2e, 0x90, 0xea, 0xe2, 0x63, 0x5e, 0x87, 0x13, 0x70, 0x07, 0x2c, 0x7f, 0x59, 0xce, 0xdf, 0x5a,
		0x4c, 0x8f, 0x90, 0x65, 0x84, 0x2c, 0xb3, 0x23, 0x47, 0xdc, 0x75, 0xef, 0xf0, 0x45, 0xdc, 0x75,
		0xc3, 0x09, 0x83, 0x13, 0xa6, 0xd6, 0x09, 0xc3, 0x5d, 0xf7, 0xfe, 0x6b, 0x86, 0xbb, 0x6e, 0xa8,
		0x1c, 0xa8, 0x1c, 0xa8, 0x9c, 0x5f, 0x3f, 0x23, 0xee, 0xba, 0xa1, 0x74, 0xa0, 0x74, 0x74, 0x51,
		0x3a, 0xb8, 0xeb, 0x5e, 0x23, 0x26, 0x71, 0xd7, 0x1d, 0x8b, 0x5a, 0xc4, 0x5d, 0xb7, 0x0e, 0xbb,
		0x80, 0xbb, 0xee, 0x4d, 0x0c, 0x23, 0xee, 0xba, 0x01, 0x3f, 0x00, 0x3f, 0x34, 0x83, 0x1f, 0xb8,
		0xeb, 0x4e, 0x1c, 0x9e, 0xc1, 0x5d, 0xb7, 0x72, 0x3c, 0x83, 0xbb, 0xee, 0xf4, 0x80, 0x99, 0x8c,
		0xdc, 0x75, 0xf3, 0x56, 0x83, 0x78, 0x7d, 0xd5, 0x8d, 0x7a, 0x10, 0xbb, 0x6f, 0x95, 0xf4, 0x8a,
		0x10, 0xaf, 0x36, 0x87, 0xb3, 0x26, 0xc4, 0xd0, 0xb9, 0xbf, 0xb7, 0xec, 0x7b, 0xc3, 0x19, 0xcf,
		0x16, 0xd8, 0xdb, 0xbf, 0x24, 0xc4, 0xeb, 0x01, 0x50, 0x11, 0x82, 0x11, 0x92, 0xa3, 0x22, 0x04,
		0x2a, 0x42, 0xc8, 0xf4, 0x41, 0x11, 0x25, 0xa3, 0x00, 0xa2, 0x44, 0x8e, 0x92, 0x19, 0x3a, 0xf7,
		0x86, 0x2d, 0xac, 0xfb, 0xef, 0xb7, 0x8e, 0x6b, 0xcc, 0xe1, 0x85, 0xd1, 0xff, 0x3e, 0x73, 0xbc,
		0xbc, 0xf8, 0xdc, 0xce, 0x2f, 0xc6, 0x8e, 0x5f, 0xea, 0x6f, 0xb6, 0x9d, 0xe0, 0x8a, 0xc0, 0x15,
		0x81, 0x2b, 0xda, 0x4f, 0x5e, 0x50, 0xe9, 0x4f, 0x17, 0xef, 0xee, 0x15, 0x0a, 0xe6, 0x0e, 0x64,
		0xbe, 0x58, 0x4c, 0xdf, 0x58, 0xcc, 0x8e, 0x38, 0x66, 0xc4, 0x31, 0x03, 0xa1, 0x01, 0xa1, 0x01,
		0xa1, 0x01, 0xa1, 0x01, 0xa1, 0x01, 0xa1, 0x01, 0xa1, 0x6d, 0x40, 0x68, 0xbc, 0xf4, 0xfb, 0x2b,
		0x80, 0x06, 0xf6, 0x7d, 0xe7, 0x8d, 0x92, 0x4e, 0xbe, 0xaf, 0x6f, 0x0d, 0x27, 0xf7, 0xfe, 0xfc,
		0xd2, 0xc6, 0xf2, 0x99, 0xf7, 0xe4, 0xde, 0x5f, 0x0f, 0xb0, 0x1f, 0xf7, 0x7e, 0x0c, 0xee, 0x1d,
		0xdc, 0x7b, 0x44, 0x83, 0xf7, 0x8c, 0x3a, 0x85, 0x79, 0xe7, 0x8a, 0xbb, 0x7d, 0x36, 0x6c, 0x65,
		0xd0, 0x2a, 0x7b, 0x7c, 0xa7, 0xb9, 0xd4, 0x23, 0xef, 0xdf, 0x2f, 0x5d, 0xeb, 0xa3, 0xd7, 0xb2,
		0xcf, 0x78, 0x6e, 0xe7, 0x11, 0x6e, 0x86, 0x2b, 0xee, 0x86, 0xa2, 0xef, 0x3b, 0xee, 0xfe, 0xe7,
		0xf6, 0xf5, 0x00, 0xb8, 0x33, 0xc3, 0xb9, 0x8d, 0x74, 0x6e, 0x71, 0x67, 0x06, 0x46, 0x06, 0x8c,
		0x4c, 0x1c, 0x46, 0xe6, 0x95, 0x2a, 0x36, 0xfa, 0x43, 0x6b, 0xf1, 0xa2, 0x71, 0xb3, 0xb0, 0x36,
		0x8f, 0x8b, 0xb6, 0x58, 0xa0, 0x62, 0x40, 0xc5, 0x80, 0x8a, 0x91, 0xb6, 0x68, 0x1b, 0x14, 0xcf,
		0xc4, 0xf3, 0x85, 0x6b, 0x58, 0x03, 0x19, 0x4a, 0x2d, 0x18, 0x1b, 0x0a, 0x09, 0x0a, 0x09, 0x0a,
		0x69, 0xbf, 0xd3, 0xf4, 0xf2, 0x00, 0x19, 0xfe, 0x6c, 0x5c, 0x02, 0xdd, 0x74, 0x1a, 0x63, 0x8c,
		0xe5, 0xbb, 0x29, 0x4f, 0xd2, 0x78, 0x99, 0x8a, 0x7b, 0x52, 0xc8, 0x11, 0xe4, 0x1c, 0x2c, 0x57,
		0xa7, 0x42, 0x30, 0x14, 0x4d, 0x2a, 0x0b, 0xdd, 0x6a, 0x05, 0x0f, 0x46, 0x99, 0xda, 0x42, 0xa4,
		0xa0, 0xb7, 0x0e, 0x4b, 0x9c, 0x67, 0x11, 0x8c, 0x2b, 0x21, 0xdf, 0x22, 0xa6, 0xc2, 0xd8, 0xbc,
		0x55, 0x84, 0x29, 0x30, 0x5c, 0x5b, 0x55, 0x2c, 0x9c, 0x16, 0x4f, 0xcb, 0x95, 0xc2, 0x69, 0x29,
		0x41, 0x7b, 0xf6, 0x46, 0x8f, 0x51, 0xba, 0x6f, 0x14, 0x4a, 0x1e, 0xa1, 0x42, 0xb6, 0xc6, 0x0f,
		0x45, 0xc3, 0x1c, 0x0c, 0x5c, 0xe1, 0x79, 0x84, 0x6a, 0x39, 0xff, 0x81, 0x60, 0xac, 0xa6, 0xe9,
		0xfb, 0xc2, 0xb5, 0xc9, 0x34, 0x73, 0xee, 0xed, 0xdb, 0x9b, 0x63, 0xe3, 0xb4, 0xfb, 0x74, 0x93,
		0x37, 0x4e, 0xbb, 0x8b, 0x8f, 0xf9, 0xf9, 0x1f, 0x8b, 0xcf, 0x85, 0x9b, 0x63, 0xa3, 0xb8, 0xfa,
		0x5c, 0xba, 0x39, 0x36, 0x4a, 0xdd, 0xc3, 0x6f, 0xdf, 0xde, 0x1f, 0xfe, 0x3c, 0x99, 0xee, 0xff,
		0xc5, 0x5c, 0x7c, 0x11, 0xa3, 0x58, 0xc2, 0x46, 0xbb, 0xfe, 0x27, 0xf9, 0x3a, 0xfe, 0xc5, 0xb9,
		0x90, 0xff, 0xca, 0xa9, 0x3e, 0xac, 0x48, 0xb0, 0x53, 0x73, 0xc1, 0xff, 0xca, 0x39, 0xe5, 0x0e,
		0xc1, 0x6c, 0xcd, 0xa6, 0x6f, 0xad, 0x66, 0x47, 0x08, 0x26, 0x42, 0x30, 0xd9, 0xdd, 0x75, 0x10,
		0xfe, 0x91, 0xf8, 0x31, 0x10, 0xfe, 0xe0, 0xd7, 0xc0, 0xaf, 0xa5, 0x8f, 0x5f, 0x03, 0xe1, 0x0f,
		0xc2, 0x1f, 0x0a, 0x09, 0x0a, 0x49, 0x1b, 0x85, 0x04, 0xc2, 0xff, 0x77, 0x2b, 0x04, 0xc2, 0x7f,
		0x9f, 0x07, 0x03, 0xe1, 0x0f, 0xc2, 0x1f, 0x84, 0x3f, 0x11, 0xfb, 0x46, 0x3b, 0x0a, 0x08, 0xff,
		0x5f, 0x1b, 0x2d, 0x10, 0xfe, 0x20, 0xfc, 0x41, 0xf8, 0x83, 0xf0, 0xa7, 0x24, 0xfc, 0x79, 0x33,
		0xfa, 0x5e, 0xf1, 0xfd, 0xc8, 0xe8, 0xdb, 0x79, 0xa3, 0xa4, 0x67, 0xf4, 0xad, 0x6f, 0x0d, 0x67,
		0x66, 0xd0, 0x7e, 0x77, 0x2d, 0x91, 0xee, 0x58, 0x22, 0x67, 0x01, 0x15, 0x90, 0x05, 0x44, 0xc9,
		0x70, 0x24, 0x39, 0x0b, 0xc8, 0x9c, 0xf8, 0xdf, 0x8d, 0xb1, 0xe9, 0x79, 0xcb, 0x25, 0x8c, 0x78,
		0x35, 0xb8, 0x3e, 0x4c, 0xb4, 0x2b, 0xc2, 0x63, 0xe4, 0x04, 0x71, 0x12, 0x7c, 0x59, 0xba, 0x22,
		0x8c, 0x4c, 0xdc, 0xad, 0xd1, 0xdf, 0x96, 0x7d, 0x1f, 0x55, 0xc6, 0xd7, 0x3d, 0x1e, 0x0d, 0x42,
		0x01, 0x06, 0xc2, 0xeb, 0xbb, 0xd6, 0x38, 0x12, 0x56, 0x7b, 0x51, 0xa0, 0xfe, 0x79, 0x10, 0x9c,
		0x79, 0x9c, 0xf9, 0x94, 0x9d, 0x79, 0xcf, 0x77, 0x2d, 0xfb, 0x3e, 0xe9, 0x27, 0x7d, 0xe8, 0xf4,
		0xcd, 0xa1, 0x61, 0x7a, 0xd1, 0x8f, 0x79, 0x30, 0x02, 0xce, 0x38, 0xce, 0x78, 0xca, 0xce, 0xb8,
		0xe9, 0x19, 0xf6, 0x64, 0x74, 0x2b, 0xdc, 0x18, 0xc7, 0x3c, 0xc2, 0xcd, 0x52, 0xcc, 0x9b, 0xa4,
		0x18, 0x37, 0x90, 0x14, 0x37, 0x45, 0x44, 0xd7, 0x0d, 0x54, 0x37, 0x41, 0x94, 0xb7, 0x08, 0x31,
		0xf8, 0x76, 0x92, 0x9b, 0x1d, 0xea, 0xa5, 0xa5, 0xba, 0xb9, 0x21, 0x5d, 0x63, 0x26, 0xb2, 0xb3,
		0xab, 0x81, 0xf5, 0x9d, 0x73, 0x5f, 0x71, 0x8c, 0xef, 0x6a, 0x00, 0xd8, 0x5e, 0xd8, 0x5e, 0xd8,
		0x5e, 0xd8, 0x5e, 0xd8, 0x5e, 0xd8, 0x5e, 0xd8, 0xde, 0xdd, 0x6d, 0x6f, 0x84, 0xa2, 0x8a, 0x9b,
		0x6d, 0xf0, 0xde, 0xc5, 0x15, 0x61, 0x8b, 0x61, 0x8b, 0xc1, 0x75, 0xf1, 0x9f, 0x78, 0x3f, 0xca,
		0x62, 0xac, 0x9f, 0xf5, 0x08, 0x01, 0xb9, 0x38, 0xe5, 0x38, 0xe5, 0xda, 0x9f, 0xf2, 0xa8, 0xc2,
		0xbd, 0x76, 0xd0, 0x8b, 0x11, 0xbe, 0x5b, 0xb3, 0x27, 0xa3, 0xd9, 0xa3, 0x4f, 0x35, 0x50, 0x12,
		0xae, 0x18, 0x39, 0x0f, 0xc2, 0x18, 0xbb, 0xd6, 0x83, 0xe9, 0x8b, 0x58, 0xce, 0x79, 0x78, 0x28,
		0x28, 0x0d, 0x28, 0x8d, 0x94, 0x29, 0x8d, 0x90, 0x90, 0x2f, 0xeb, 0xb1, 0xc7, 0xd1, 0x21, 0x11,
		0x3c, 0xa2, 0x5c, 0x7d, 0x20, 0x6c, 0xdf, 0xf2, 0x1f, 0x3f, 0x99, 0x9e, 0x88, 0x9f, 0xcf, 0xd6,
		0xaa, 0x5d, 0x36, 0xbe, 0xd6, 0x7a, 0xcd, 0x56, 0xfd, 0x6b, 0xb5, 0x53, 0xeb, 0x55, 0xdb, 0xbd,
		0x46, 0xb3, 0x53, 0x6f, 0x5c, 0x45, 0x15, 0xa9, 0xb9, 0xd3, 0xe7, 0xc5, 0x8a, 0x9c, 0x8d, 0xe9,
		0xbd, 0xae, 0xde, 0xec, 0xc5, 0x2b, 0x2d, 0x5f, 0xb2, 0x7a, 0x71, 0x91, 0x53, 0xe1, 0x95, 0xcb,
		0x78, 0xa1, 0xe6, 0x45, 0xf5, 0x2c, 0xee, 0x1b, 0x45, 0xfa, 0x66, 0x57, 0xf6, 0xc1, 0x96, 0x63,
		0xec, 0xe6, 0x01, 0x97, 0x77, 0x43, 0x73, 0x6c, 0x0c, 0xcc, 0xd1, 0x78, 0x86, 0xf1, 0xa3, 0x5b,
		0xbb, 0xf0, 0x58, 0xfb, 0xa6, 0xea, 0xc7, 0xcb, 0x65, 0x87, 0xb9, 0x84, 0xb9, 0xd4, 0xde, 0x5c,
		0x46, 0xcf, 0x35, 0x8f, 0x98, 0x63, 0x2e, 0xa9, 0x56, 0x8c, 0xb0, 0x07, 0x46, 0xdf, 0x19, 0x8d,
		0x26, 0xb6, 0xe5, 0x3f, 0xc6, 0x28, 0x1a, 0xb3, 0x3e, 0x4e, 0x74, 0x85, 0x71, 0xd5, 0xb8, 0xaa,
		0x41, 0x5f, 0x40, 0x5f, 0xa4, 0x4d, 0x5f, 0x04, 0x67, 0x23, 0xf3, 0x8e, 0xb9, 0xef, 0xf8, 0xe6,
		0xd0, 0x18, 0x9b, 0xfe, 0xf7, 0x18, 0x2e, 0xf9, 0xcb, 0x41, 0xa0, 0x2d, 0xa0, 0x2d, 0x52, 0xa6,
		0x2d, 0x22, 0x97, 0x45, 0xc0, 0x85, 0x39, 0x2e, 0xcc, 0xd7, 0x96, 0x16, 0x17, 0xe6, 0x12, 0xc9,
		0x82, 0x64, 0x5e, 0x98, 0x2f, 0x6d, 0xe7, 0x5c, 0x9b, 0x8b, 0xf8, 0x36, 0x78, 0x35, 0x0e, 0xcc,
		0x30, 0xcc, 0x30, 0xcc, 0x30, 0xcc, 0x30, 0xcc, 0x30, 0xcc, 0x70, 0x66, 0xcd, 0x70, 0xb2, 0xeb,
		0x36, 0xec, 0x5b, 0x50, 0x23, 0x5a, 0xb5, 0x86, 0x3d, 0x2a, 0x67, 0xd0, 0x14, 0x69, 0xf0, 0xad,
		0x91, 0x70, 0xbd, 0xfd, 0xab, 0x34, 0x2c, 0xbf, 0x87, 0x66, 0xad, 0x8c, 0x40, 0x05, 0xcd, 0x5a,
		0xd1, 0xac, 0x15, 0x48, 0x3c, 0x65, 0x48, 0x3c, 0x72, 0xed, 0xf6, 0xbe, 0x63, 0xdb, 0xa2, 0xef,
		0x1b, 0xae, 0xf0, 0xdd, 0xc7, 0xf8, 0xd1, 0x20, 0xeb, 0xc3, 0xc5, 0xaf, 0xd4, 0x7e, 0x72, 0x8c,
		0xaa, 0xc8, 0xa8, 0x8a, 0xcc, 0x7d, 0x56, 0x63, 0x82, 0x65, 0xe5, 0x55, 0x91, 0x07, 0xa2, 0x6f,
		0x8d, 0xcc, 0x61, 0xb9, 0x48, 0x51, 0x0c, 0xb9, 0x10, 0x63, 0x8c, 0x90, 0xe3, 0x12, 0x67, 0x30,
		0x9a, 0xa2, 0xc1, 0x04, 0x95, 0x3c, 0x29, 0x8b, 0x04, 0xaf, 0x96, 0xb9, 0x40, 0x53, 0x10, 0x96,
		0xba, 0x28, 0xb0, 0x8c, 0xc2, 0xb2, 0x04, 0x45, 0x80, 0x49, 0x8b, 0xff, 0xae, 0xb6, 0xe0, 0x24,
		0x43, 0x5b, 0x90, 0xf6, 0xf2, 0x9c, 0x11, 0x60, 0xeb, 0x77, 0x67, 0x38, 0x30, 0x66, 0x0e, 0x69,
		0x7c, 0x14, 0xf4, 0x3c, 0x54, 0x7c, 0x04, 0x74, 0x0a, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04,
		0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x24, 0x0f, 0x01, 0xfd, 0x2d, 0xc4, 0xd8, 0x1c,
		0x5a, 0x0f, 0xc2, 0xb0, 0x6c, 0x5f, 0xb8, 0x0f, 0xe6, 0x30, 0x3e, 0x14, 0xda, 0x30, 0x26, 0x58,
		0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0xad,
		0x31, 0xd1, 0xc8, 0xb2, 0xad, 0xd1, 0x64, 0x64, 0x98, 0x83, 0x07, 0xe1, 0xfa, 0x96, 0x27, 0x66,
		0x56, 0x84, 0x10, 0x1f, 0xfd, 0x66, 0x7c, 0x60, 0x25, 0x60, 0x25, 0x60, 0x25, 0x60, 0x25, 0x60,
		0x25, 0x60, 0x25, 0x60, 0x25, 0x60, 0x25, 0x34, 0xb8, 0x3b, 0x88, 0x15, 0x7f, 0xbb, 0x08, 0x38,
		0x3d, 0x8a, 0x14, 0xc6, 0x77, 0x10, 0x39, 0x1e, 0xb7, 0x33, 0x9f, 0xb5, 0xb7, 0x44, 0x44, 0x3a,
		0x14, 0x25, 0xd8, 0xab, 0xa9, 0x5a, 0xc8, 0x3a, 0x46, 0x69, 0x0b, 0x18, 0x3b, 0x08, 0xb2, 0x80,
		0x20, 0x48, 0x95, 0xf0, 0x10, 0x41, 0x90, 0x3b, 0x4b, 0x0d, 0x82, 0x20, 0xe1, 0xc2, 0xc1, 0x85,
		0x83, 0x0b, 0x07, 0x17, 0x0e, 0x2e, 0x1c, 0x5c, 0x38, 0xb8, 0x70, 0xaa, 0x5c, 0x38, 0x04, 0x41,
		0x02, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01,
		0xed, 0xb0, 0xcc, 0x08, 0x82, 0x04, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02,
		0x26, 0x02, 0x26, 0x02, 0x26, 0x42, 0x10, 0x24, 0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x12,
		0xb0, 0x12, 0xb0, 0x12, 0xb0, 0x52, 0x86, 0xb0, 0x52, 0xaa, 0x83, 0x20, 0xa3, 0x44, 0xf1, 0x1d,
		0xc4, 0x8d, 0x81, 0xdc, 0xa3, 0x34, 0xe9, 0xfe, 0xbb, 0x90, 0xf0, 0xe2, 0xb0, 0x7b, 0x55, 0x43,
		0x8d, 0xbb, 0x13, 0xac, 0xe5, 0x61, 0x5d, 0xd3, 0xf6, 0xc6, 0x8e, 0xeb, 0x47, 0xa8, 0x10, 0x1b,
		0x7c, 0x15, 0x45, 0x62, 0x19, 0x01, 0x36, 0x8a, 0xc4, 0xa2, 0x48, 0xac, 0x4c, 0x8f, 0x12, 0xf1,
		0xd1, 0x0a, 0x00, 0x47, 0xe4, 0xf8, 0xe8, 0xa1, 0xd3, 0x37, 0x87, 0x86, 0x39, 0x18, 0xb8, 0xc2,
		0xf3, 0xe2, 0xd3, 0x3d, 0xeb, 0xc3, 0x81, 0x98, 0x01, 0x31, 0x03, 0x62, 0x66, 0x2f, 0x79, 0x99,
		0xd8, 0xd1, 0xda, 0x86, 0x87, 0x6c, 0xcd, 0x69, 0x8c, 0x31, 0x96, 0xaf, 0xa3, 0x9c, 0x46, 0x59,
		0x2d, 0x8a, 0x35, 0x8e, 0xa9, 0x52, 0xa8, 0x57, 0x88, 0x76, 0xa5, 0xe8, 0x56, 0x6c, 0xc3, 0xca,
		0x3d, 0x14, 0x09, 0xd7, 0x2e, 0xb4, 0x86, 0x1f, 0x08, 0xc7, 0x6c, 0x9a, 0xbe, 0x2f, 0x5c, 0x9b,
		0x6c, 0x39, 0x83, 0x81, 0xdf, 0xbe, 0xbd, 0x39, 0x36, 0x4e, 0xbb, 0x4f, 0x37, 0x79, 0xe3, 0xb4,
		0xbb, 0xf8, 0x98, 0x9f, 0xff, 0xb1, 0xf8, 0x5c, 0xb8, 0x39, 0x36, 0x8a, 0xab, 0xcf, 0xa5, 0x9b,
		0x63, 0xa3, 0xd4, 0x3d, 0xfc, 0xf6, 0xed, 0xfd, 0xe1, 0xcf, 0x93, 0xe9, 0xfe, 0x5f, 0xcc, 0x91,
		0x3d, 0x7a, 0x97, 0x72, 0x69, 0x1b, 0xed, 0xfa, 0x9f, 0xd2, 0xd6, 0xf7, 0x2f, 0xce, 0x05, 0xfe,
		0x17, 0xe1, 0x0a, 0x93, 0x8c, 0x34, 0x7d, 0xa7, 0xf1, 0xe1, 0x2f, 0xe3, 0xf0, 0xcf, 0x45, 0xcc,
		0x34, 0xee, 0xaa, 0xc6, 0xe7, 0xee, 0xcf, 0xfc, 0xbb, 0xe2, 0xf4, 0xe3, 0xe1, 0xcf, 0xca, 0xf4,
		0xf5, 0x5f, 0x3e, 0x6d, 0xfa, 0xb1, 0xfc, 0xbb, 0xca, 0xf4, 0xe3, 0x96, 0x7f, 0x29, 0x4f, 0x3f,
		0xee, 0x38, 0x46, 0x69, 0xfa, 0x36, 0xf4, 0xa3, 0xb3, 0xbf, 0x2f, 0x6c, 0xfb, 0x42, 0x71, 0xcb,
		0x17, 0x4e, 0xb6, 0x7d, 0xe1, 0x64, 0xcb, 0x17, 0xb6, 0x3e, 0x52, 0x61, 0xcb, 0x17, 0x4a, 0xd3,
		0xa7, 0xd0, 0xcf, 0xbf, 0xdd, 0xfc, 0xa3, 0xe5, 0xe9, 0xe1, 0xd3, 0xb6, 0x7f, 0xab, 0x4c, 0x9f,
		0x3e, 0x1e, 0x66, 0x59, 0x15, 0x42, 0xdc, 0xf8, 0xc5, 0x4d, 0x3f, 0xc3, 0xf0, 0x46, 0xed, 0x73,
		0xc4, 0x34, 0x4c, 0x84, 0xf8, 0xdd, 0xf3, 0x5d, 0xcb, 0xbe, 0xa7, 0xc4, 0xee, 0x1f, 0x10, 0xca,
		0x13, 0x5a, 0x9b, 0x91, 0x3f, 0x31, 0x06, 0x96, 0xd7, 0x77, 0x1e, 0x04, 0x45, 0xaa, 0xfb, 0xfa,
		0x70, 0xf1, 0x03, 0x75, 0xee, 0xcc, 0xa1, 0x27, 0x40, 0x09, 0x81, 0x12, 0x02, 0x25, 0xb4, 0x9f,
		0xbc, 0xdc, 0x3a, 0xce, 0x50, 0x98, 0x24, 0xa4, 0x50, 0x5e, 0x63, 0xf5, 0x35, 0x36, 0x3d, 0xcf,
		0x7a, 0x10, 0xc6, 0xc8, 0x19, 0x10, 0xa4, 0xa8, 0xae, 0x8d, 0x06, 0xe5, 0x05, 0xe5, 0x05, 0xe5,
		0x05, 0xe5, 0x25, 0x4f, 0x79, 0xf9, 0xfd, 0xb1, 0x31, 0xa2, 0xb8, 0x40, 0x5b, 0x0d, 0x04, 0x55,
		0x03, 0x55, 0x03, 0x55, 0xb3, 0x97, 0xbc, 0x4c, 0x2c, 0xdb, 0xcf, 0x97, 0x09, 0x34, 0x4d, 0x19,
		0x21, 0xc8, 0xa4, 0x6a, 0x25, 0x34, 0x1c, 0x42, 0x90, 0xb5, 0xd9, 0x82, 0x72, 0xa9, 0x74, 0x52,
		0x42, 0x18, 0xb2, 0x32, 0x9e, 0x27, 0xa5, 0x61, 0xc8, 0xab, 0xd0, 0x4e, 0xf6, 0x72, 0xac, 0xab,
		0x89, 0x51, 0x91, 0x15, 0x15, 0x59, 0xd9, 0xf1, 0x1d, 0x22, 0x0e, 0x77, 0xf8, 0x22, 0x22, 0x0e,
		0xe1, 0x36, 0xc1, 0x6d, 0xd2, 0xc8, 0x6d, 0x42, 0xc4, 0x61, 0x78, 0x51, 0x10, 0x71, 0x18, 0x7d,
		0xe5, 0x10, 0x71, 0x88, 0x88, 0x43, 0x44, 0x1c, 0x12, 0xba, 0x95, 0x12, 0xb8, 0x89, 0x03, 0x44,
		0x1c, 0x22, 0xe2, 0x10, 0x11, 0x87, 0xe9, 0x51, 0x85, 0x10, 0x37, 0x44, 0x1c, 0x22, 0xe2, 0x10,
		0x11, 0x87, 0xd1, 0x99, 0x68, 0x44, 0x1c, 0x82, 0x12, 0x02, 0x25, 0x04, 0x4a, 0x08, 0x11, 0x87,
		0xd1, 0x16, 0x0d, 0x11, 0x87, 0x50, 0x5e, 0x50, 0x5e, 0x50, 0x5e, 0x88, 0x38, 0x84, 0xaa, 0x81,
		0xaa, 0xc9, 0x84, 0xaa, 0x41, 0xc4, 0xe1, 0xcb, 0x07, 0x41, 0xc4, 0xe1, 0x81, 0x42, 0xf2, 0xe4,
		0x00, 0x11, 0x87, 0x88, 0x38, 0x24, 0xff, 0x46, 0x02, 0x23, 0x0e, 0x99, 0x6b, 0x9f, 0x06, 0x01,
		0x87, 0x28, 0x7f, 0xba, 0xc3, 0xee, 0xc8, 0xaf, 0x80, 0x1a, 0xcc, 0xc4, 0x58, 0x04, 0x75, 0xe2,
		0x09, 0x63, 0x34, 0x19, 0xfa, 0xd6, 0x78, 0x28, 0x8c, 0xd9, 0xf2, 0x78, 0xfb, 0x57, 0x43, 0xdd,
		0x30, 0x06, 0xca, 0xa2, 0x32, 0x22, 0x66, 0x94, 0x45, 0x45, 0x59, 0x54, 0x99, 0x2e, 0x22, 0x82,
		0x94, 0x15, 0xc0, 0x91, 0xc8, 0x41, 0xca, 0xc2, 0x36, 0x6f, 0x87, 0x62, 0x10, 0x9f, 0x5d, 0x59,
		0x0d, 0x04, 0x42, 0x18, 0x2c, 0x0d, 0x58, 0x1a, 0x25, 0x2c, 0x4d, 0x12, 0x09, 0xe1, 0x74, 0x3a,
		0x69, 0x61, 0x8c, 0xcb, 0x9d, 0x1f, 0x76, 0xed, 0x89, 0xcb, 0xe5, 0x03, 0x34, 0x67, 0xf3, 0x6b,
		0x94, 0x26, 0x26, 0x66, 0x87, 0x33, 0x32, 0x02, 0x13, 0xfb, 0xab, 0x44, 0xe0, 0x2f, 0xe0, 0x2f,
		0x5d, 0xf1, 0x57, 0x44, 0x87, 0x84, 0xc6, 0x31, 0x89, 0x79, 0x40, 0x80, 0x9a, 0x80, 0x9a, 0x54,
		0xa1, 0xa6, 0xa8, 0x07, 0x2e, 0x18, 0xc0, 0x1c, 0x0e, 0x9d, 0x7f, 0x9e, 0x8d, 0xb4, 0xe9, 0xc5,
		0xdf, 0xef, 0x95, 0x04, 0x86, 0x87, 0x8e, 0xb9, 0x4d, 0x44, 0xce, 0x11, 0x91, 0x93, 0x44, 0x76,
		0xec, 0x29, 0x8f, 0x3f, 0xbd, 0x1a, 0xa0, 0x56, 0x07, 0xd2, 0xd4, 0x82, 0x34, 0xf5, 0x20, 0x45,
		0x4d, 0xc4, 0x53, 0x17, 0x31, 0xd5, 0x06, 0x9d, 0xd3, 0x25, 0xc1, 0xf9, 0x22, 0x72, 0xc2, 0xe2,
		0x2f, 0x70, 0x8c, 0xc5, 0xcd, 0x8d, 0xcc, 0x1f, 0xf3, 0x36, 0xc8, 0xfb, 0x5d, 0x0e, 0xfc, 0x76,
		0x75, 0xd7, 0x87, 0xa5, 0x53, 0xa7, 0x79, 0xa8, 0x52, 0xa8, 0x52, 0xa8, 0x52, 0xbd, 0x54, 0xe9,
		0xc4, 0xb2, 0xfd, 0x93, 0x02, 0xa1, 0x26, 0xad, 0x10, 0x0c, 0x45, 0x13, 0x7d, 0xb4, 0xfa, 0x45,
		0x98, 0x92, 0x4a, 0x19, 0x8d, 0x44, 0xac, 0xd6, 0x42, 0xc3, 0x12, 0x47, 0x27, 0x05, 0xe3, 0x4a,
		0x08, 0x8f, 0x21, 0x3a, 0x1e, 0xeb, 0x5b, 0x45, 0x18, 0xb5, 0xc4, 0xb5, 0x55, 0xc5, 0xc2, 0x69,
		0xf1, 0xb4, 0x5c, 0x29, 0x9c, 0x96, 0x12, 0xb4, 0x67, 0xe9, 0x48, 0x32, 0x4c, 0x88, 0x2b, 0x1e,
		0x93, 0x65, 0x0f, 0xc6, 0xa1, 0x64, 0xdb, 0xc5, 0xec, 0xc7, 0x63, 0x71, 0x62, 0x07, 0x74, 0xd4,
		0x7b, 0xed, 0xf6, 0x7e, 0x1c, 0x89, 0x7f, 0x8f, 0xbe, 0x9f, 0xd3, 0x48, 0xf7, 0x0c, 0x51, 0xca,
		0xb7, 0x85, 0xac, 0x77, 0xd4, 0xb0, 0x34, 0x52, 0x22, 0xb2, 0x00, 0x22, 0x12, 0x44, 0x24, 0x88,
		0x48, 0x10, 0x91, 0xf0, 0x9e, 0xe1, 0x3d, 0x83, 0x88, 0x04, 0x11, 0x09, 0x22, 0x12, 0xaa, 0x14,
		0xaa, 0x14, 0xaa, 0x14, 0x44, 0x24, 0x88, 0x48, 0x10, 0x91, 0x20, 0x22, 0x41, 0x44, 0x82, 0x88,
		0x64, 0x23, 0x22, 0xe3, 0x50, 0x62, 0xd4, 0x3c, 0x64, 0x84, 0xec, 0xcd, 0x18, 0x34, 0x64, 0x66,
		0xc2, 0xbb, 0x45, 0xc4, 0x60, 0x5d, 0xba, 0x9d, 0xd5, 0x21, 0xb4, 0xdb, 0x8a, 0x15, 0xda, 0x6d,
		0x21, 0xb4, 0x5b, 0xae, 0xdb, 0x82, 0xd0, 0x6e, 0x84, 0x76, 0x33, 0xf3, 0x01, 0xb8, 0x51, 0x51,
		0xe3, 0xe7, 0x67, 0xf9, 0x46, 0x05, 0xd4, 0x1f, 0xa8, 0x3f, 0x50, 0x7f, 0xa0, 0xfe, 0x40, 0xfd,
		0x81, 0xfa, 0x03, 0xf5, 0x07, 0xea, 0x0f, 0xd4, 0x1f, 0xa8, 0x3f, 0x05, 0x94, 0x90, 0xa5, 0x53,
		0x0c, 0x62, 0x1d, 0x31, 0x88, 0xdc, 0x1e, 0x33, 0x62, 0x10, 0xe1, 0x31, 0xc3, 0x63, 0x86, 0xc7,
		0x0c, 0x8f, 0x19, 0x1e, 0x33, 0x3c, 0x66, 0x78, 0xcc, 0xf0, 0x98, 0xe1, 0x31, 0xc3, 0x63, 0x86,
		0xc7, 0x0c, 0x8f, 0xf9, 0x97, 0x1e, 0xb3, 0x26, 0xc1, 0x32, 0x75, 0x04, 0xcb, 0x48, 0xdd, 0x67,
		0x75, 0xc1, 0x32, 0x75, 0x4d, 0x82, 0x65, 0xa2, 0x71, 0x1d, 0xb1, 0x38, 0x8e, 0xd8, 0xe1, 0x32,
		0x05, 0x84, 0xcb, 0xa8, 0x74, 0x4c, 0x50, 0x89, 0x7a, 0x07, 0x79, 0x41, 0x25, 0x6a, 0xd0, 0x88,
		0xa0, 0x11, 0x55, 0x70, 0x02, 0xa8, 0x44, 0x9d, 0x04, 0xf4, 0xc5, 0xdb, 0x37, 0x28, 0x04, 0xbf,
		0xd0, 0x3e, 0x68, 0x9f, 0xdd, 0x92, 0xde, 0x47, 0xe8, 0xf5, 0xfe, 0x90, 0xb5, 0x13, 0x7a, 0x13,
		0x63, 0x07, 0x66, 0x6a, 0x7e, 0xae, 0xe2, 0x83, 0xa5, 0x31, 0xe6, 0xaf, 0xf5, 0x9b, 0x6f, 0x5d,
		0x58, 0x9e, 0x5f, 0xf5, 0xfd, 0xdd, 0x00, 0x48, 0xee, 0xd2, 0xb2, 0x6b, 0x43, 0x31, 0x53, 0xd5,
		0xde, 0x6e, 0x66, 0x36, 0x77, 0x69, 0xfe, 0x78, 0xf1, 0x8d, 0xfc, 0x87, 0x62, 0xb1, 0x5c, 0x29,
		0x16, 0x8f, 0x2b, 0x27, 0x95, 0xe3, 0xd3, 0x52, 0x29, 0x5f, 0xce, 0xef, 0xc0, 0xb6, 0xe4, 0x1a,
		0xee, 0x40, 0xb8, 0x62, 0xf0, 0x69, 0xf6, 0x82, 0xf6, 0x64, 0x38, 0x8c, 0xb5, 0x4e, 0x7b, 0x4a,
		0x68, 0x64, 0xc9, 0xdc, 0x41, 0x0c, 0x23, 0x89, 0xdf, 0xaf, 0xa5, 0x6d, 0xbb, 0x0c, 0x6d, 0xfe,
		0x97, 0x2d, 0xab, 0xb5, 0xeb, 0x2a, 0xed, 0xb7, 0x3a, 0xbf, 0x58, 0x92, 0x3d, 0x96, 0x62, 0xf3,
		0x02, 0x84, 0x5f, 0x6f, 0xc3, 0xab, 0xe5, 0x5c, 0xeb, 0x76, 0xeb, 0xfb, 0x04, 0xa6, 0x78, 0xf6,
		0x43, 0x5b, 0x96, 0xe5, 0xd7, 0xce, 0xe0, 0x6f, 0x9d, 0xbe, 0x5d, 0x10, 0xe6, 0x4b, 0x04, 0xe9,
		0x5a, 0xb7, 0xbf, 0x41, 0x91, 0xbb, 0xa2, 0xc4, 0xbd, 0x51, 0xe0, 0xde, 0x28, 0xef, 0x35, 0x8a,
		0x5b, 0x3d, 0x3b, 0x91, 0x40, 0xfe, 0xce, 0x49, 0xca, 0x99, 0x77, 0x96, 0xe1, 0x99, 0x77, 0xd6,
		0xef, 0x2f, 0x63, 0x9f, 0x8b, 0xbd, 0x04, 0x5f, 0xf9, 0x9d, 0x6e, 0xdd, 0x89, 0x03, 0xd8, 0xd9,
		0xe7, 0xdf, 0xc7, 0xd1, 0xd8, 0x4f, 0x1c, 0xa2, 0x3a, 0x0f, 0x91, 0x9d, 0x84, 0xc8, 0xce, 0xc0,
		0xde, 0xe2, 0x42, 0x63, 0x25, 0x77, 0xf5, 0xb5, 0x03, 0xd9, 0xd8, 0xbf, 0x5b, 0x5f, 0xf0, 0xcd,
		0x74, 0xf4, 0xe8, 0xdb, 0x5d, 0xe8, 0xe2, 0x7a, 0xae, 0xfa, 0xf5, 0xe9, 0xdb, 0x59, 0x28, 0xe5,
		0x80, 0xe9, 0xbd, 0x7b, 0xf5, 0xad, 0x44, 0xcf, 0x58, 0xda, 0xd1, 0x88, 0x3c, 0xe9, 0xfa, 0x30,
		0xd1, 0xf8, 0xd2, 0xe3, 0x84, 0xa5, 0x17, 0xee, 0x2f, 0xe6, 0xd9, 0xe1, 0x4c, 0xf7, 0x3e, 0x06,
		0x3c, 0x0c, 0x41, 0x64, 0xf2, 0x25, 0xd8, 0xf7, 0xa1, 0x30, 0xef, 0x5c, 0x71, 0x17, 0x65, 0xd3,
		0x57, 0x5a, 0x3b, 0x42, 0xc8, 0x45, 0xae, 0xb9, 0x84, 0xcb, 0xef, 0xdf, 0x2f, 0x98, 0x85, 0xa3,
		0xf5, 0x03, 0xa7, 0x43, 0x56, 0xf2, 0xf8, 0xa1, 0x68, 0x78, 0xae, 0x2f, 0x8c, 0xb1, 0x33, 0xb4,
		0xfa, 0x8f, 0x31, 0x32, 0x94, 0x5f, 0x8f, 0x94, 0x8d, 0x6c, 0x65, 0xa8, 0x93, 0xc4, 0xa9, 0x93,
		0xc8, 0xd7, 0x30, 0xc3, 0xc5, 0x3b, 0xc5, 0xbf, 0x86, 0x59, 0x0d, 0x84, 0xbc, 0xe5, 0x78, 0x47,
		0x88, 0xea, 0x28, 0x91, 0x1f, 0x29, 0xf2, 0xa3, 0x45, 0x7e, 0xc4, 0xa2, 0xdf, 0x06, 0x1c, 0xa8,
		0x8c, 0xc6, 0x76, 0x9d, 0x89, 0x2f, 0x08, 0xc3, 0xb0, 0x97, 0xe3, 0xd1, 0xc4, 0x4c, 0xe7, 0x53,
		0x1e, 0x33, 0x1d, 0xff, 0xa0, 0x52, 0x1f, 0x58, 0x69, 0x07, 0x57, 0xda, 0x01, 0x96, 0x76, 0x90,
		0xe3, 0x1d, 0xe8, 0x98, 0x07, 0x9b, 0xec, 0x80, 0xaf, 0x1f, 0x74, 0x3a, 0xf9, 0x58, 0x3b, 0xef,
		0x54, 0xb2, 0x41, 0x73, 0xec, 0xc9, 0x8f, 0xbf, 0x0c, 0x35, 0x20, 0x57, 0x1d, 0xc8, 0x52, 0x0b,
		0xd2, 0xd5, 0x83, 0x74, 0x35, 0x21, 0x5d, 0x5d, 0xd0, 0xa8, 0x0d, 0x22, 0xf5, 0x41, 0xae, 0x46,
		0x82, 0x01, 0xfb, 0xce, 0xd0, 0x71, 0xe9, 0xe5, 0xea, 0xb9, 0x0e, 0xd1, 0x6c, 0xf8, 0x77, 0x89,
		0x88, 0x83, 0xa7, 0x56, 0x33, 0x32, 0xd5, 0x0d, 0x8f, 0xda, 0x91, 0xad, 0x7e, 0xd8, 0xd4, 0x10,
		0x9b, 0x3a, 0x62, 0x53, 0x4b, 0xb4, 0xea, 0x89, 0x58, 0x4d, 0xc5, 0x27, 0x28, 0x77, 0x67, 0x0c,
		0x22, 0x13, 0x98, 0x3b, 0xa3, 0x98, 0x8a, 0x84, 0xb1, 0x43, 0x04, 0xe8, 0x42, 0x51, 0xbe, 0xd1,
		0x53, 0x34, 0x28, 0x33, 0xa3, 0x84, 0x3d, 0x18, 0x3b, 0xd6, 0xfc, 0x60, 0x48, 0xb2, 0x39, 0xc1,
		0x0c, 0x30, 0x3b, 0x30, 0x3b, 0x30, 0x3b, 0x30, 0x3b, 0x30, 0x3b, 0x5b, 0xcd, 0x4e, 0xa0, 0x2b,
		0x33, 0x60, 0x79, 0xc6, 0xa6, 0xff, 0xdd, 0xb0, 0x06, 0xf2, 0x0c, 0xcf, 0x6a, 0x02, 0xd8, 0x1d,
		0xd8, 0x1d, 0xd8, 0x1d, 0xd8, 0x1d, 0xd8, 0x9d, 0xad, 0x76, 0x67, 0xa5, 0x2a, 0x33, 0x60, 0x76,
		0xe2, 0x95, 0x27, 0xfb, 0xad, 0x44, 0xc4, 0x4d, 0x7d, 0xff, 0xa5, 0x2c, 0xc0, 0xe4, 0xc0, 0xe4,
		0xc0, 0xe4, 0xe8, 0x6c, 0x72, 0xa8, 0x2f, 0x04, 0x82, 0x81, 0x4d, 0xdf, 0x77, 0x0d, 0xcb, 0x1e,
		0x88, 0x1f, 0xf2, 0x84, 0x32, 0x08, 0xb7, 0x7d, 0x9e, 0x4b, 0x92, 0xb0, 0xc8, 0xc1, 0xd0, 0xd2,
		0x15, 0x1b, 0x87, 0x82, 0xe3, 0x55, 0x74, 0x5c, 0x0a, 0x8f, 0x5d, 0xf1, 0xb1, 0x2b, 0x40, 0x76,
		0x45, 0x28, 0x47, 0x21, 0x4a, 0x52, 0x8c, 0xf2, 0x31, 0x39, 0x23, 0x36, 0xe7, 0xc0, 0xe8, 0x9b,
		0xb0, 0xfa, 0xc6, 0xff, 0xe6, 0xca, 0xda, 0x13, 0xbe, 0x17, 0x7c, 0x5a, 0x62, 0xfa, 0x85, 0x02,
		0x7f, 0x93, 0x0c, 0x91, 0x93, 0x20, 0x6e, 0x92, 0xee, 0xd2, 0x43, 0x72, 0x26, 0xe3, 0x4e, 0x1d,
		0x86, 0x12, 0x86, 0x12, 0x86, 0x12, 0x86, 0x92, 0xe5, 0xdc, 0x90, 0x55, 0x7d, 0xfd, 0x9d, 0x16,
		0x93, 0x69, 0x26, 0x69, 0xab, 0xc4, 0x6e, 0xfb, 0x25, 0xf7, 0xcc, 0x1f, 0xc8, 0xaa, 0x2a, 0xab,
		0xc8, 0xbc, 0x84, 0xa6, 0x93, 0x54, 0x85, 0x76, 0xeb, 0x7c, 0x12, 0x2b, 0x9d, 0x32, 0xab, 0x83,
		0x75, 0x11, 0x31, 0x7f, 0xa4, 0x5e, 0x44, 0x64, 0x55, 0xbf, 0xd5, 0x4a, 0x56, 0xde, 0x24, 0x73,
		0xf4, 0x6e, 0xa6, 0x9d, 0x8a, 0xd1, 0x68, 0x62, 0x5b, 0xfe, 0x23, 0x17, 0x19, 0xf7, 0x7a, 0x42,
		0x38, 0x1a, 0x70, 0x34, 0xe0, 0x68, 0xc0, 0xd1, 0x48, 0xa0, 0xa3, 0x91, 0x11, 0x46, 0x6e, 0xa5,
		0xb1, 0x2d, 0xe1, 0x05, 0x9f, 0x1f, 0x41, 0xca, 0x2d, 0x16, 0x4f, 0x5a, 0xbc, 0x71, 0x48, 0xda,
		0x24, 0xc5, 0x1d, 0xc3, 0x62, 0xc2, 0x62, 0xc2, 0x62, 0xc2, 0x62, 0xb2, 0x9c, 0x1b, 0x6b, 0x6c,
		0x98, 0x83, 0x81, 0x2b, 0x3c, 0x8f, 0xc3, 0x68, 0x9e, 0x4a, 0x9c, 0x63, 0xb9, 0x66, 0x89, 0xa7,
		0xe7, 0xd6, 0xca, 0x08, 0xc9, 0xdf, 0x9b, 0xd0, 0x1e, 0x7d, 0x60, 0x98, 0xab, 0x69, 0xfa, 0xbe,
		0x70, 0x6d, 0xe9, 0xdb, 0x15, 0x4c, 0xf8, 0xf6, 0xed, 0xcd, 0xb1, 0x71, 0xda, 0x7d, 0xba, 0xc9,
		0x1b, 0xa7, 0xdd, 0xc5, 0xc7, 0xfc, 0xfc, 0x8f, 0xc5, 0xe7, 0xc2, 0xcd, 0xb1, 0x51, 0x5c, 0x7d,
		0x2e, 0xdd, 0x1c, 0x1b, 0xa5, 0xee, 0xe1, 0xb7, 0x6f, 0xef, 0x0f, 0x7f, 0x9e, 0x4c, 0xf7, 0xff,
		0x62, 0x4e, 0xfa, 0x2b, 0x75, 0x39, 0xb6, 0xa8, 0xd1, 0xae, 0xff, 0xc9, 0xbe, 0x4f, 0x7f, 0x71,
		0x6e, 0xd4, 0xbf, 0x18, 0x76, 0x4a, 0x2e, 0x01, 0xf7, 0x2e, 0x45, 0xca, 0xae, 0x0c, 0x65, 0x47,
		0xaa, 0xec, 0x4c, 0xe3, 0xae, 0x6a, 0x7c, 0xee, 0xfe, 0xcc, 0xbf, 0x2b, 0x4e, 0x3f, 0x1e, 0xfe,
		0xac, 0x4c, 0x5f, 0xff, 0xe5, 0xd3, 0xa6, 0x1f, 0xcb, 0xbf, 0xab, 0x4c, 0x3f, 0x6e, 0xf9, 0x97,
		0xf2, 0xf4, 0xe3, 0x8e, 0x63, 0x94, 0xa6, 0x6f, 0x43, 0x3f, 0x3a, 0xfb, 0xfb, 0xc2, 0xb6, 0x2f,
		0x14, 0xb7, 0x7c, 0xe1, 0x64, 0xdb, 0x17, 0x4e, 0xb6, 0x7c, 0x61, 0xeb, 0x23, 0x15, 0xb6, 0x7c,
		0xa1, 0x34, 0x7d, 0x0a, 0xfd, 0xfc, 0xdb, 0xcd, 0x3f, 0x5a, 0x9e, 0x1e, 0x3e, 0x6d, 0xfb, 0xb7,
		0xca, 0xf4, 0xe9, 0xe3, 0x21, 0x54, 0x7f, 0x7c, 0xd5, 0x0f, 0xb1, 0xe5, 0x17, 0xdb, 0xe4, 0x1b,
		0x42, 0xdc, 0x44, 0xc9, 0x60, 0xd2, 0x7e, 0xf8, 0x06, 0xfb, 0x6d, 0xd4, 0xa6, 0x49, 0xc1, 0xaf,
		0x81, 0x5f, 0x03, 0xbf, 0x06, 0x7e, 0x2d, 0x81, 0xfc, 0x5a, 0x46, 0x6e, 0xa4, 0x5e, 0x6a, 0x6d,
		0x4b, 0x78, 0x6b, 0xff, 0x1f, 0x37, 0x53, 0xcb, 0x45, 0xb4, 0xec, 0x07, 0x73, 0x68, 0x0d, 0x0c,
		0x57, 0x98, 0x9e, 0x63, 0xcb, 0x37, 0xa5, 0xaf, 0xe6, 0x83, 0x15, 0x85, 0x15, 0x85, 0x15, 0x85,
		0x15, 0x4d, 0xa0, 0x15, 0xb5, 0x06, 0xc2, 0xf6, 0x2d, 0xff, 0x91, 0xc9, 0x92, 0x4a, 0x8c, 0x08,
		0xcd, 0xd5, 0x97, 0xaf, 0xf2, 0xc9, 0xf4, 0x18, 0x8e, 0xe8, 0x6a, 0x01, 0xeb, 0x57, 0x5f, 0xab,
		0x17, 0xf5, 0xf3, 0x5e, 0xab, 0x71, 0xdd, 0xa9, 0xf5, 0x5a, 0xb5, 0x6a, 0xbb, 0x71, 0x25, 0xfb,
		0xb4, 0xce, 0x03, 0x6d, 0x3d, 0x16, 0x02, 0x89, 0x29, 0x52, 0xf9, 0xf5, 0x6a, 0x9e, 0x5d, 0x5c,
		0xb7, 0x3b, 0xb5, 0x56, 0xef, 0xa2, 0xd1, 0x68, 0xe6, 0xd2, 0x10, 0xf8, 0xad, 0x68, 0x1d, 0x1b,
		0xad, 0xfa, 0x97, 0xfa, 0x55, 0xb5, 0xd3, 0x68, 0x61, 0x15, 0xa3, 0xaf, 0x62, 0xb5, 0x0d, 0x41,
		0x8c, 0x7b, 0xa0, 0x1b, 0x57, 0x9f, 0x6b, 0xe7, 0xb9, 0x84, 0xc7, 0xe5, 0x77, 0x93, 0x86, 0x4f,
		0x12, 0xe1, 0xbd, 0x0d, 0x4d, 0xcf, 0x37, 0x46, 0xce, 0xc0, 0xba, 0xb3, 0xc4, 0x40, 0xbe, 0xf3,
		0xb6, 0x3e, 0x1d, 0x7c, 0x37, 0xf8, 0x6e, 0xf0, 0xdd, 0xe0, 0xbb, 0x25, 0xd0, 0x77, 0xf3, 0xad,
		0x91, 0xf0, 0xad, 0xfe, 0xdf, 0x5e, 0xb9, 0xc8, 0xe0, 0xbb, 0x49, 0x0c, 0xe8, 0xc8, 0x5d, 0xdb,
		0x8b, 0xbc, 0xbd, 0x9c, 0x6d, 0xda, 0x8e, 0x27, 0xfa, 0x8e, 0x3d, 0x90, 0x1a, 0x35, 0x89, 0x8c,
		0x63, 0xfd, 0x6c, 0xda, 0x66, 0x2f, 0x17, 0x19, 0xc7, 0xb1, 0x45, 0x24, 0x03, 0x19, 0xc7, 0xf9,
		0x0f, 0xc5, 0x62, 0xb9, 0x52, 0x2c, 0x1e, 0x57, 0x4e, 0x2a, 0xc7, 0xa7, 0xa5, 0x52, 0xbe, 0x9c,
		0x47, 0xee, 0xb1, 0x76, 0xa3, 0x67, 0x39, 0xe2, 0x43, 0x56, 0xc5, 0xec, 0x10, 0x28, 0x90, 0x53,
		0x39, 0x3b, 0x98, 0xe6, 0x5c, 0xdc, 0x99, 0x93, 0xe1, 0x1c, 0xfa, 0x1d, 0xc3, 0x77, 0x82, 0xef,
		0x04, 0xdf, 0x09, 0xbe, 0x53, 0x12, 0x7d, 0x27, 0x14, 0x4e, 0x82, 0x1b, 0x03, 0x37, 0x06, 0x6e,
		0x8c, 0x56, 0x22, 0x82, 0xc2, 0x49, 0x70, 0x5e, 0x74, 0x74, 0x5e, 0x96, 0xc1, 0x6e, 0xa4, 0xed,
		0x92, 0xb7, 0x5a, 0xe6, 0x97, 0x93, 0xc1, 0xc1, 0x80, 0x83, 0x01, 0x07, 0x03, 0x0e, 0x46, 0x02,
		0x1d, 0x8c, 0x5b, 0xc7, 0x19, 0x0a, 0xd3, 0xe6, 0x08, 0xaa, 0xcb, 0x27, 0xc5, 0x34, 0x69, 0xdd,
		0xfe, 0xa3, 0x6a, 0xdb, 0x8e, 0x6f, 0xce, 0xd0, 0x90, 0x9c, 0x2e, 0x20, 0x5e, 0xff, 0xbb, 0x18,
		0x99, 0xe3, 0x65, 0xb8, 0xff, 0x91, 0x33, 0x16, 0x76, 0x7f, 0x6e, 0x28, 0x66, 0xe7, 0xf3, 0x68,
		0xf6, 0xdb, 0xb5, 0x6e, 0x8f, 0xcc, 0x3b, 0xcb, 0xf0, 0xcc, 0x3b, 0xcb, 0x0b, 0x3e, 0x1d, 0xcd,
		0xcb, 0x55, 0x78, 0xae, 0x2f, 0x8c, 0xb1, 0x33, 0xb4, 0xfa, 0x8f, 0x47, 0xc3, 0xc5, 0xb9, 0x3e,
		0x9a, 0xdb, 0x48, 0x6f, 0xf1, 0xc7, 0x91, 0x8c, 0xe6, 0x45, 0x8b, 0xe7, 0xf6, 0xdd, 0x49, 0xdf,
		0xb7, 0x97, 0x62, 0xdd, 0x08, 0x1e, 0xfb, 0xd3, 0xfd, 0xb8, 0x37, 0xfb, 0xdd, 0xb2, 0x6e, 0x7b,
		0xd5, 0x3b, 0xab, 0x3d, 0x7b, 0xe8, 0xd5, 0x87, 0x5e, 0x7d, 0xfc, 0x50, 0x6c, 0xbb, 0xbe, 0x68,
		0xce, 0x9f, 0xb8, 0x77, 0xe1, 0xf4, 0x67, 0x3f, 0xd6, 0x9a, 0x3f, 0xf0, 0xe2, 0x8f, 0x5e, 0x7b,
		0xfe, 0xc0, 0x19, 0xe8, 0x5a, 0x35, 0xb1, 0xff, 0xb6, 0x9d, 0x7f, 0x6c, 0xc3, 0xf4, 0x7d, 0xd7,
		0xba, 0x9d, 0xad, 0x80, 0xbc, 0x16, 0x56, 0x1b, 0xe6, 0x42, 0x3f, 0x2b, 0xf4, 0xb3, 0xd2, 0x02,
		0x13, 0xa1, 0x9f, 0x15, 0xaf, 0x41, 0x93, 0xd6, 0xcf, 0x2a, 0xa4, 0x64, 0xe4, 0x3b, 0x85, 0xe1,
		0x29, 0xe5, 0xba, 0x86, 0x79, 0xb8, 0x86, 0x70, 0x0d, 0xe1, 0x1a, 0x66, 0xc9, 0x35, 0x94, 0xa5,
		0x2e, 0x83, 0x09, 0xe6, 0x3d, 0x9e, 0x7c, 0xd9, 0x0e, 0xe8, 0x41, 0xa8, 0x1b, 0xe0, 0x7c, 0x4a,
		0xc9, 0xa2, 0xc5, 0x43, 0x98, 0x4b, 0x57, 0x9f, 0x9c, 0x6a, 0x54, 0x8d, 0x3a, 0xe5, 0x56, 0xab,
		0xca, 0xd4, 0xab, 0x32, 0x35, 0xab, 0x4c, 0xdd, 0xca, 0x55, 0xbb, 0x92, 0xd5, 0x2f, 0x1f, 0x43,
		0x17, 0x3a, 0x77, 0xf2, 0x0b, 0x49, 0x84, 0xd0, 0x65, 0x85, 0xa7, 0x38, 0xde, 0x7a, 0xa3, 0xf0,
		0x67, 0x63, 0x90, 0xd0, 0x2b, 0x38, 0x89, 0xa2, 0x27, 0xa9, 0xb5, 0xf8, 0x56, 0x99, 0x93, 0xc5,
		0xd6, 0x31, 0xfa, 0x32, 0x30, 0xca, 0x30, 0xca, 0x30, 0xca, 0xd9, 0x30, 0xca, 0xb2, 0x7d, 0xa3,
		0x75, 0x1f, 0x69, 0x28, 0x18, 0xa3, 0xc1, 0xd6, 0x5c, 0xa5, 0xd9, 0xcc, 0xef, 0x52, 0x19, 0x62,
		0xc4, 0xa5, 0xa4, 0x55, 0x28, 0x6b, 0xb5, 0x4a, 0x5b, 0x95, 0xf2, 0x56, 0xae, 0xc4, 0x95, 0x2b,
		0x73, 0xe5, 0x4a, 0x9d, 0x47, 0xb9, 0x33, 0x29, 0x79, 0x7e, 0x0f, 0x2c, 0x74, 0x6e, 0x27, 0x96,
		0xed, 0xe7, 0xcb, 0x9c, 0x67, 0x76, 0xa9, 0x85, 0xcb, 0x8c, 0x53, 0xf2, 0x04, 0x6d, 0xbf, 0xfe,
		0xc5, 0xab, 0x93, 0x0e, 0xb8, 0x83, 0xba, 0x15, 0x9b, 0xd7, 0xd0, 0xf4, 0xcc, 0x41, 0xdf, 0xa1,
		0xf9, 0x15, 0x04, 0xf6, 0x2a, 0x52, 0x57, 0xeb, 0x22, 0x67, 0xfe, 0xc8, 0xbc, 0xc8, 0x95, 0x4b,
		0xa5, 0x93, 0x52, 0x86, 0xc5, 0xee, 0x4d, 0x3a, 0x67, 0xeb, 0xbe, 0x49, 0xc7, 0xfb, 0x70, 0xe4,
		0x8a, 0xf0, 0xdd, 0xb4, 0x6d, 0x76, 0x23, 0x19, 0x6e, 0xdc, 0xe0, 0x47, 0xc2, 0x8f, 0x84, 0x1f,
		0x09, 0x3f, 0x12, 0x7e, 0xe4, 0x16, 0x3f, 0xf2, 0x83, 0x02, 0x37, 0xb2, 0x04, 0x37, 0x12, 0x6e,
		0x24, 0xdc, 0x48, 0xb8, 0x91, 0x29, 0x10, 0xb9, 0x42, 0x09, 0x4e, 0x24, 0x9c, 0xc8, 0xac, 0x3b,
		0x91, 0x0f, 0xcb, 0xd3, 0xa0, 0xc2, 0x8b, 0x5c, 0xcc, 0x0d, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48,
		0xb8, 0x91, 0x70, 0x23, 0xd9, 0xcf, 0xed, 0xad, 0x65, 0x9b, 0xee, 0xa3, 0x02, 0x3f, 0xf2, 0x94,
		0x71, 0xca, 0x0b, 0x61, 0xdf, 0xcf, 0x03, 0x45, 0xe1, 0x48, 0x66, 0x00, 0xd5, 0xe7, 0xe1, 0x48,
		0xc2, 0x91, 0xe4, 0x15, 0x39, 0xdc, 0x47, 0xc2, 0x95, 0xcc, 0xb8, 0x2b, 0x29, 0x7e, 0xf8, 0xc2,
		0x1e, 0x48, 0xec, 0x6d, 0xb2, 0x15, 0xc2, 0x04, 0x33, 0xc3, 0x8d, 0x84, 0x1b, 0x09, 0x37, 0x12,
		0x6e, 0x24, 0xdc, 0x48, 0x7e, 0x37, 0x52, 0x7a, 0x25, 0xb0, 0x6d, 0x6a, 0x58, 0x52, 0x65, 0xb0,
		0x74, 0x1a, 0x69, 0x67, 0x3c, 0x43, 0x8a, 0xe6, 0x90, 0xdf, 0x48, 0x07, 0x33, 0xc3, 0x48, 0xc3,
		0x48, 0xc3, 0x48, 0xc3, 0x48, 0xc3, 0x48, 0xc3, 0x48, 0xc3, 0x48, 0x6f, 0x5a, 0xb3, 0xb1, 0xe9,
		0xfa, 0x96, 0x0a, 0x1b, 0xbd, 0x9a, 0x18, 0x26, 0x1a, 0x26, 0x1a, 0x26, 0x1a, 0x26, 0x1a, 0x26,
		0x1a, 0x26, 0x1a, 0x26, 0x7a, 0xd3, 0x9a, 0xf9, 0xae, 0x69, 0x7b, 0x96, 0x6f, 0x3d, 0x28, 0x88,
		0x9b, 0x7a, 0x31, 0x37, 0x0c, 0x35, 0x0c, 0x35, 0x0c, 0x35, 0x0c, 0x35, 0x0c, 0x35, 0x0c, 0x75,
		0x02, 0x0d, 0x75, 0xa2, 0xcb, 0x45, 0x49, 0x6e, 0xa5, 0x11, 0x9a, 0x4f, 0x72, 0x6b, 0x8d, 0x70,
		0x53, 0x85, 0xf0, 0x5f, 0x1d, 0x71, 0x54, 0xf4, 0x3b, 0x90, 0xd9, 0x8f, 0xe3, 0x7a, 0xf1, 0x4a,
		0xd5, 0xe0, 0x25, 0x43, 0x7f, 0x23, 0xa3, 0x65, 0x07, 0x9f, 0xe0, 0x27, 0xab, 0x1a, 0xf5, 0xbf,
		0xc5, 0x23, 0x47, 0x3a, 0x79, 0xee, 0xc2, 0xf2, 0xfc, 0xd9, 0x06, 0xcb, 0x2d, 0x7d, 0x7d, 0x69,
		0xd9, 0xb5, 0xa1, 0x98, 0xd9, 0x76, 0x4f, 0x2e, 0x76, 0xcd, 0x5d, 0x9a, 0x3f, 0x5e, 0xcc, 0xc4,
		0xdb, 0x17, 0x3e, 0xd7, 0x70, 0x07, 0xc2, 0x15, 0x83, 0x4f, 0xb3, 0xad, 0xb3, 0x27, 0xc3, 0x61,
		0xa2, 0x24, 0x8e, 0x49, 0x69, 0xeb, 0xa0, 0xac, 0x73, 0x52, 0x0b, 0xc9, 0xaa, 0x52, 0xcf, 0x39,
		0xb4, 0x01, 0xd3, 0xff, 0x18, 0xf0, 0x8b, 0x7f, 0x92, 0x7a, 0x82, 0x85, 0x84, 0x5c, 0xdb, 0xfe,
		0x60, 0x6f, 0x34, 0x92, 0xdd, 0x15, 0x58, 0x98, 0x09, 0x95, 0x61, 0x0d, 0x0e, 0x84, 0x3d, 0x18,
		0x3b, 0x96, 0xed, 0x1f, 0xf4, 0x9d, 0xa1, 0xe3, 0x12, 0xed, 0xbf, 0x1c, 0xa4, 0x20, 0x0f, 0x19,
		0xb0, 0x22, 0x01, 0x39, 0x96, 0x9f, 0x4a, 0x3c, 0x24, 0xa9, 0x34, 0xc9, 0xaa, 0x8c, 0x50, 0x6f,
		0xc9, 0xd2, 0x57, 0x34, 0xda, 0x29, 0xbe, 0x2e, 0x89, 0x37, 0x42, 0x4c, 0x31, 0xa3, 0x16, 0x2f,
		0x69, 0x62, 0x45, 0x20, 0x50, 0xf4, 0x82, 0x14, 0x4f, 0x84, 0xa2, 0x6f, 0x7c, 0xb4, 0x6f, 0x46,
		0x14, 0x15, 0x2a, 0x11, 0xa1, 0x17, 0x8d, 0x18, 0x32, 0x41, 0x28, 0x0b, 0xd1, 0x84, 0x60, 0xff,
		0x2d, 0x8c, 0xb0, 0x7d, 0x39, 0x5b, 0x58, 0xf7, 0xdf, 0x6f, 0x1d, 0x37, 0x7a, 0xd3, 0xd2, 0x80,
		0x17, 0x7e, 0x1e, 0x2a, 0xa2, 0x18, 0xc5, 0x6b, 0x68, 0x11, 0xfb, 0xf2, 0x8c, 0xe2, 0x32, 0x8c,
		0xf6, 0x72, 0x8b, 0xea, 0xb2, 0x8a, 0xfc, 0xf2, 0x89, 0xfc, 0x32, 0x89, 0xfc, 0x72, 0x88, 0x57,
		0x01, 0xc6, 0x6d, 0xa0, 0x10, 0x9c, 0x9d, 0xf8, 0x5b, 0xfd, 0xfa, 0x34, 0xc6, 0xdd, 0x69, 0x9a,
		0x2e, 0x33, 0x64, 0x37, 0xdb, 0x94, 0x37, 0xd6, 0x72, 0x6e, 0xa2, 0xa9, 0x6f, 0x98, 0xa5, 0xdd,
		0x1c, 0x4b, 0xbb, 0x11, 0x96, 0x76, 0xd3, 0xab, 0x16, 0x08, 0x53, 0x75, 0x49, 0xc9, 0x99, 0x83,
		0xff, 0xcd, 0xd7, 0xc4, 0xb2, 0x8d, 0xb1, 0xe3, 0xf9, 0x74, 0x92, 0x12, 0xd4, 0x17, 0x7a, 0x35,
		0x01, 0x15, 0x0f, 0x41, 0xda, 0x70, 0x8a, 0x3c, 0xd8, 0x45, 0x46, 0x30, 0x8b, 0xdc, 0x60, 0x15,
		0x59, 0xc1, 0x28, 0xd2, 0x83, 0x4d, 0xa4, 0x07, 0x93, 0x48, 0x0f, 0x16, 0xd1, 0x8b, 0xe1, 0xa3,
		0x6e, 0xc0, 0x94, 0x5b, 0xba, 0xc4, 0xe4, 0x82, 0xb5, 0x3a, 0x0e, 0x64, 0x2e, 0xb7, 0x44, 0x05,
		0x23, 0x4d, 0xd1, 0xc8, 0x54, 0x38, 0x3c, 0x8a, 0x47, 0xb6, 0x02, 0x62, 0x53, 0x44, 0x6c, 0x0a,
		0x89, 0x4d, 0x31, 0xd1, 0x2a, 0x28, 0x62, 0x45, 0x25, 0x4d, 0x61, 0xad, 0x2b, 0x2e, 0x79, 0xf2,
		0xb8, 0xa6, 0xbf, 0x64, 0xc9, 0xa2, 0xdc, 0xc6, 0x9c, 0xd2, 0x83, 0x84, 0x39, 0x82, 0x82, 0x79,
		0x83, 0x80, 0xb9, 0x82, 0x7e, 0xd9, 0x83, 0x7c, 0xd9, 0x83, 0x7a, 0xd9, 0x83, 0x78, 0x93, 0x15,
		0xd6, 0x25, 0xbb, 0x91, 0x66, 0x6e, 0x71, 0xe5, 0xcb, 0xd6, 0xc7, 0x98, 0xf2, 0x86, 0xf9, 0x77,
		0xea, 0xf2, 0x18, 0x7d, 0x8c, 0x35, 0x57, 0xa3, 0xdc, 0xea, 0x54, 0x99, 0x5a, 0x55, 0xa6, 0x5e,
		0x95, 0xa9, 0x59, 0xb9, 0xea, 0x56, 0xb2, 0xda, 0x0d, 0x56, 0x8d, 0x2d, 0x27, 0x22, 0x38, 0x77,
		0x43, 0x61, 0xde, 0xb9, 0xe2, 0x8e, 0xe3, 0xd0, 0xad, 0x50, 0x65, 0x85, 0x61, 0xae, 0xe6, 0xf2,
		0x0a, 0xf6, 0xfd, 0xfb, 0x45, 0xe0, 0xfb, 0xd1, 0xc2, 0x10, 0x24, 0x35, 0x34, 0x5c, 0x22, 0xb2,
		0x5c, 0x05, 0x63, 0xf1, 0xd9, 0xe4, 0x60, 0x46, 0x98, 0x65, 0x98, 0x65, 0x98, 0x65, 0x98, 0x65,
		0x98, 0xe5, 0xcc, 0x9a, 0xe5, 0xc0, 0x16, 0xc0, 0x32, 0x87, 0x16, 0x6b, 0x19, 0x2e, 0xcd, 0x67,
		0x98, 0x57, 0x13, 0xc2, 0x2e, 0xc3, 0x2e, 0xc3, 0x2e, 0xc3, 0x2e, 0xc3, 0x2e, 0x67, 0xd6, 0x2e,
		0xaf, 0x4c, 0x01, 0xcc, 0x72, 0x68, 0xad, 0x16, 0x89, 0xf4, 0x6c, 0x46, 0x99, 0x23, 0x6f, 0x5f,
		0xf2, 0x85, 0x1f, 0x4c, 0x32, 0x4c, 0x32, 0x4c, 0x72, 0x36, 0x4c, 0xb2, 0xec, 0x0b, 0xc4, 0x60,
		0xa2, 0x79, 0xe5, 0x09, 0xcb, 0x1e, 0x88, 0x1f, 0x8a, 0xda, 0x5f, 0x2e, 0xe6, 0x46, 0x19, 0xb7,
		0xa4, 0x29, 0x6c, 0xb5, 0x8a, 0x5b, 0x95, 0x02, 0x57, 0xae, 0xc8, 0x95, 0x2b, 0x74, 0xe5, 0x8a,
		0x9d, 0x47, 0xc1, 0x33, 0x29, 0x7a, 0x7e, 0x1f, 0x4c, 0xa1, 0x2f, 0xa6, 0xc2, 0x27, 0xdb, 0xe4,
		0x9b, 0xfd, 0xe2, 0xbf, 0xb9, 0x49, 0xf2, 0x84, 0xef, 0x05, 0x9f, 0x96, 0x9e, 0xdc, 0xc2, 0x4c,
		0xa1, 0x3e, 0xec, 0xce, 0xeb, 0x7d, 0x2b, 0x3c, 0xdf, 0x58, 0xa6, 0xf0, 0x32, 0xe3, 0x8a, 0xe7,
		0xa9, 0x01, 0x2b, 0x00, 0x2b, 0x00, 0x2b, 0x00, 0x2b, 0x00, 0x2b, 0xd8, 0xcf, 0x2d, 0xaa, 0xc3,
		0x26, 0xc2, 0x4c, 0xf3, 0x04, 0x12, 0x87, 0xa4, 0x83, 0x23, 0xa0, 0x18, 0xe6, 0x19, 0xe6, 0x19,
		0xe6, 0x19, 0xe6, 0x19, 0xe6, 0x79, 0xc3, 0xb9, 0x9d, 0x58, 0xb6, 0x7f, 0x52, 0x50, 0x60, 0x9d,
		0x39, 0x7d, 0xfe, 0x96, 0x69, 0xdf, 0xcf, 0xde, 0xf6, 0x86, 0xf5, 0x8c, 0xfc, 0x64, 0x6f, 0x3e,
		0x9f, 0xbb, 0xb4, 0x6c, 0x76, 0x65, 0xa8, 0xc8, 0xbc, 0x86, 0xa6, 0xff, 0x6a, 0x0e, 0x27, 0x42,
		0xe1, 0xfc, 0x9f, 0x5d, 0xb3, 0xef, 0x5b, 0x8e, 0x7d, 0x6e, 0xdd, 0x5b, 0x8b, 0xea, 0x96, 0xec,
		0xcf, 0x31, 0x7d, 0xa7, 0x40, 0xe4, 0xcc, 0x1f, 0x99, 0x17, 0xb9, 0x62, 0xe1, 0xb4, 0x78, 0x5a,
		0xae, 0x14, 0x4e, 0x4b, 0x19, 0x96, 0xbd, 0x37, 0xe9, 0x9c, 0xad, 0x0b, 0x27, 0x72, 0x0f, 0x27,
		0x72, 0x34, 0x9a, 0xd8, 0x96, 0xff, 0xa8, 0xea, 0x26, 0xf9, 0xf5, 0x03, 0xc0, 0xb1, 0x84, 0x63,
		0x09, 0xc7, 0x12, 0x8e, 0x25, 0x1c, 0x4b, 0xf6, 0x73, 0x8b, 0xeb, 0xe4, 0x17, 0xff, 0xad, 0xec,
		0x92, 0x25, 0xbc, 0xe0, 0xf3, 0x23, 0x6e, 0x94, 0xa3, 0x2d, 0x39, 0x5b, 0x8a, 0x6d, 0x48, 0xa6,
		0x99, 0x52, 0x6d, 0x81, 0x2b, 0x80, 0x2b, 0x80, 0x2b, 0x80, 0x2b, 0x80, 0x2b, 0x36, 0x9c, 0x5b,
		0x6b, 0x6c, 0x98, 0x83, 0x81, 0x2b, 0x3c, 0x4f, 0x05, 0xb4, 0x38, 0x65, 0x9c, 0x73, 0xb9, 0xc6,
		0xa9, 0x27, 0xad, 0x9f, 0x77, 0xf6, 0xa1, 0xa8, 0x60, 0x6f, 0x43, 0x7b, 0xfc, 0x41, 0xc1, 0xdc,
		0x4d, 0xd3, 0xf7, 0x85, 0x6b, 0xb3, 0x6f, 0x77, 0xf0, 0x00, 0x6f, 0xdf, 0xde, 0x1c, 0x1b, 0xa7,
		0xdd, 0xa7, 0x9b, 0xbc, 0x71, 0xda, 0x5d, 0x7c, 0xcc, 0xcf, 0xff, 0x58, 0x7c, 0x2e, 0xdc, 0x1c,
		0x1b, 0xc5, 0xd5, 0xe7, 0xd2, 0xcd, 0xb1, 0x51, 0xea, 0x1e, 0x7e, 0xfb, 0xf6, 0xfe, 0xf0, 0xe7,
		0xc9, 0x74, 0xff, 0x2f, 0xe6, 0xd8, 0x5f, 0xb1, 0xab, 0x62, 0x4b, 0x1b, 0xed, 0xfa, 0x9f, 0xca,
		0xf7, 0xf5, 0x2f, 0xce, 0x8d, 0xfd, 0x97, 0x82, 0x9d, 0xe5, 0xa5, 0x9d, 0xdf, 0x65, 0x48, 0x19,
		0x97, 0xa1, 0x8c, 0x95, 0x2a, 0x63, 0xd3, 0xb8, 0xab, 0x1a, 0x9f, 0xbb, 0x3f, 0xf3, 0xef, 0x8a,
		0xd3, 0x8f, 0x87, 0x3f, 0x2b, 0xd3, 0xd7, 0x7f, 0xf9, 0xb4, 0xe9, 0xc7, 0xf2, 0xef, 0x2a, 0xd3,
		0x8f, 0x5b, 0xfe, 0xa5, 0x3c, 0xfd, 0xb8, 0xe3, 0x18, 0xa5, 0xe9, 0xdb, 0xd0, 0x8f, 0xce, 0xfe,
		0xbe, 0xb0, 0xed, 0x0b, 0xc5, 0x2d, 0x5f, 0x38, 0xd9, 0xf6, 0x85, 0x93, 0x2d, 0x5f, 0xd8, 0xfa,
		0x48, 0x85, 0x2d, 0x5f, 0x28, 0x4d, 0x9f, 0x42, 0x3f, 0xff, 0x76, 0xf3, 0x8f, 0x96, 0xa7, 0x87,
		0x4f, 0xdb, 0xfe, 0xad, 0x32, 0x7d, 0xfa, 0x78, 0x08, 0xd3, 0xc4, 0x6f, 0x9a, 0x20, 0xe6, 0xfc,
		0x62, 0x9e, 0x7e, 0x43, 0x8d, 0xfb, 0x61, 0x1d, 0x99, 0xdb, 0x1f, 0xbe, 0xa1, 0xfc, 0x8e, 0x78,
		0xd3, 0x43, 0x80, 0xcf, 0x05, 0x9f, 0x0b, 0x3e, 0x17, 0x7c, 0x2e, 0xf8, 0x5c, 0xf6, 0x73, 0x8b,
		0x7b, 0xe2, 0x17, 0xff, 0xbd, 0xb4, 0x4d, 0x96, 0xf0, 0xd6, 0xfe, 0x3f, 0xee, 0x8b, 0x23, 0x2e,
		0xbd, 0x65, 0x3f, 0x98, 0x43, 0x6b, 0x60, 0xb8, 0xc2, 0xf4, 0x1c, 0x9b, 0x1f, 0x70, 0xbc, 0x9a,
		0x1f, 0x58, 0x03, 0x58, 0x03, 0x58, 0x03, 0x58, 0x03, 0x58, 0x83, 0xfd, 0xdc, 0x5a, 0x03, 0x61,
		0xfb, 0x96, 0xff, 0xa8, 0x08, 0x6f, 0x30, 0x66, 0x07, 0xe4, 0xea, 0xcb, 0x57, 0xfd, 0x64, 0x7a,
		0x0a, 0x54, 0xc6, 0x6a, 0xc1, 0xeb, 0x57, 0x5f, 0xab, 0x17, 0xf5, 0xf3, 0x5e, 0xab, 0x71, 0xdd,
		0xa9, 0xf5, 0x5a, 0xb5, 0x6a, 0xbb, 0x71, 0xc5, 0xad, 0x3d, 0xe6, 0x49, 0x1a, 0x9e, 0x12, 0x9a,
		0x53, 0x51, 0x56, 0xcc, 0xeb, 0xd5, 0x3f, 0xbb, 0xb8, 0x6e, 0x77, 0x6a, 0xad, 0xde, 0x45, 0xa3,
		0xd1, 0xcc, 0x65, 0x21, 0x29, 0x49, 0x93, 0x75, 0x6f, 0xb4, 0xea, 0x5f, 0xea, 0x57, 0xd5, 0x4e,
		0xa3, 0x85, 0x55, 0xe7, 0x5b, 0xf5, 0x6a, 0x1b, 0x82, 0xce, 0xad, 0x60, 0x1a, 0x57, 0x9f, 0x6b,
		0xe7, 0xb9, 0x94, 0xe7, 0x9c, 0x75, 0xd3, 0x86, 0xf7, 0x52, 0xe1, 0xdd, 0x0f, 0x4d, 0xcf, 0x37,
		0x46, 0xce, 0xc0, 0xba, 0xb3, 0xc4, 0x80, 0xdf, 0xb9, 0x5f, 0x9f, 0x1e, 0xbe, 0x3d, 0x7c, 0x7b,
		0xf8, 0xf6, 0xf0, 0xed, 0xe1, 0xdb, 0xb3, 0x9f, 0x5b, 0xdf, 0x1a, 0x09, 0xdf, 0xea, 0xff, 0xed,
		0x95, 0x8b, 0x0a, 0x7c, 0x7b, 0xc6, 0x30, 0xb5, 0xdc, 0xb5, 0xbd, 0xc8, 0xf1, 0xcf, 0xd9, 0xa6,
		0xed, 0x78, 0xa2, 0xef, 0xd8, 0x03, 0xd6, 0x58, 0x78, 0x54, 0x53, 0x49, 0x9f, 0x8d, 0xdf, 0xcc,
		0x9a, 0xa0, 0x9a, 0x0a, 0xbb, 0xc8, 0xa1, 0x9a, 0xca, 0x41, 0xfe, 0x43, 0xb1, 0x58, 0xae, 0x14,
		0x8b, 0xc7, 0x95, 0x93, 0xca, 0xf1, 0x69, 0xa9, 0x94, 0x2f, 0xe7, 0x51, 0x57, 0x25, 0x75, 0xb3,
		0x21, 0x6e, 0x6e, 0x77, 0x31, 0xe4, 0x6a, 0x5d, 0x18, 0x02, 0x55, 0x3c, 0x2d, 0x0c, 0x83, 0x69,
		0xcf, 0xc5, 0x9d, 0x39, 0x19, 0xce, 0xa1, 0xf8, 0x31, 0x7c, 0x69, 0xf8, 0xd2, 0xf0, 0xa5, 0xe1,
		0x4b, 0xc3, 0x97, 0x46, 0x51, 0x50, 0xb8, 0xb1, 0x70, 0x63, 0xe1, 0xc6, 0xc2, 0x8d, 0x4d, 0x94,
		0xc8, 0xa1, 0x28, 0x28, 0x9c, 0x57, 0x38, 0xaf, 0x07, 0xb9, 0x65, 0xf0, 0xb3, 0x33, 0xf1, 0x05,
		0xbf, 0x03, 0xfb, 0x72, 0x72, 0x38, 0x94, 0x70, 0x28, 0xe1, 0x50, 0xc2, 0xa1, 0x84, 0x43, 0xc9,
		0x7e, 0x6e, 0xd1, 0x04, 0x4a, 0xf3, 0x19, 0x64, 0xf7, 0xb1, 0xae, 0xda, 0xb6, 0xe3, 0x9b, 0x33,
		0x34, 0xca, 0xd3, 0xce, 0xda, 0xeb, 0x7f, 0x17, 0x23, 0x73, 0xd9, 0x76, 0x32, 0x77, 0xe4, 0x8c,
		0x85, 0xdd, 0x9f, 0x1b, 0xca, 0x99, 0xfe, 0x38, 0x9a, 0xfd, 0x76, 0xad, 0xdb, 0x23, 0xf3, 0xce,
		0x32, 0x3c, 0xf3, 0xce, 0xf2, 0x82, 0x4f, 0x47, 0xf3, 0x22, 0x64, 0x9e, 0xeb, 0x0b, 0x63, 0xec,
		0x0c, 0xad, 0xfe, 0xe3, 0x91, 0x2d, 0xac, 0xfb, 0xef, 0xb7, 0x8e, 0xeb, 0x05, 0x9f, 0x8e, 0xcc,
		0xc1, 0xff, 0xe6, 0xaa, 0xc8, 0xb2, 0x8d, 0xb1, 0xe3, 0xf9, 0x47, 0x73, 0x78, 0xe1, 0x2d, 0xfe,
		0x58, 0x24, 0xe9, 0x71, 0xb4, 0xac, 0xf7, 0x7c, 0x77, 0xd2, 0xf7, 0xed, 0xe5, 0x09, 0x6b, 0x04,
		0x6f, 0xf8, 0xe9, 0x7e, 0xdc, 0x9b, 0xfd, 0x6e, 0x59, 0xb7, 0xbd, 0xea, 0x9d, 0xd5, 0x9e, 0xbd,
		0xdf, 0xea, 0x43, 0xaf, 0x3e, 0x7e, 0x28, 0xb6, 0x5d, 0x5f, 0x34, 0xe7, 0x2f, 0xd7, 0xbb, 0x5a,
		0xbd, 0x5c, 0xf0, 0xa9, 0x57, 0x1d, 0xfc, 0xaf, 0x65, 0xdd, 0xd6, 0xed, 0xa6, 0xe3, 0xf9, 0xbd,
		0xd6, 0xfc, 0xcd, 0x16, 0x7f, 0xf4, 0xda, 0xf3, 0x37, 0x7b, 0x93, 0x4c, 0x21, 0x97, 0x28, 0xe0,
		0xb9, 0x89, 0xfd, 0xb7, 0xed, 0xfc, 0x63, 0x1b, 0xa6, 0xef, 0xbb, 0xd6, 0xed, 0x6c, 0xc5, 0xa4,
		0x0b, 0xf9, 0x33, 0x55, 0x17, 0x9e, 0x5b, 0xf2, 0x51, 0x5e, 0x29, 0x56, 0xc9, 0xd3, 0x70, 0xe1,
		0x5a, 0x4e, 0x3c, 0xab, 0x06, 0xc7, 0x72, 0xe3, 0x57, 0x65, 0xb8, 0x55, 0x19, 0x5e, 0x55, 0x86,
		0x53, 0x93, 0x0d, 0x0a, 0xce, 0x2d, 0x9e, 0x8e, 0x93, 0x61, 0x25, 0xc9, 0x4f, 0x44, 0x84, 0x1f,
		0x81, 0x97, 0x8e, 0xc8, 0x83, 0x8e, 0x00, 0x1d, 0x01, 0x3a, 0x02, 0x74, 0x84, 0x3e, 0x74, 0x04,
		0x97, 0xfa, 0x0f, 0x26, 0x9c, 0xe9, 0x5e, 0xc3, 0xe7, 0x26, 0x41, 0xd6, 0x34, 0xc6, 0xf3, 0x23,
		0x30, 0x8b, 0xae, 0x9a, 0x4b, 0x31, 0x76, 0x73, 0xa0, 0xd2, 0x2c, 0xe8, 0x61, 0x1e, 0x54, 0x9b,
		0x09, 0x6d, 0xcc, 0x85, 0x36, 0x66, 0x43, 0x1b, 0xf3, 0xc1, 0x6b, 0x46, 0x98, 0xcd, 0x49, 0xb0,
		0xca, 0x1d, 0x15, 0x0a, 0xfe, 0x40, 0x6d, 0x49, 0xb3, 0x10, 0xda, 0xaf, 0xa8, 0x29, 0x9b, 0xbd,
		0x2a, 0x71, 0xb6, 0xa8, 0x54, 0xf6, 0x6c, 0xec, 0x52, 0x1a, 0x06, 0xc0, 0x28, 0xda, 0xb9, 0x05,
		0xaf, 0xac, 0x0c, 0xb8, 0x70, 0xd1, 0xda, 0x0a, 0x7d, 0x57, 0x80, 0x16, 0x80, 0x16, 0x80, 0x16,
		0x80, 0x16, 0x15, 0xa0, 0x85, 0xdb, 0x17, 0x5e, 0xf7, 0x89, 0x87, 0x42, 0x61, 0x84, 0xf0, 0x9a,
		0x6b, 0x3c, 0x7b, 0x92, 0x77, 0x99, 0x0c, 0x1b, 0x55, 0x65, 0x74, 0x74, 0x30, 0x3e, 0x7a, 0x19,
		0x21, 0x5d, 0x8c, 0x91, 0x76, 0x46, 0x49, 0x3b, 0xe3, 0xa4, 0x9d, 0x91, 0x52, 0x63, 0xac, 0x14,
		0x19, 0x2d, 0xf5, 0x1e, 0x77, 0x48, 0x6f, 0x4c, 0x2c, 0xdb, 0xcf, 0x97, 0x55, 0xea, 0x8c, 0xa5,
		0x15, 0x29, 0x2b, 0x7c, 0x04, 0x35, 0x89, 0x4d, 0xaf, 0x7f, 0xa9, 0xd5, 0x99, 0x07, 0xaa, 0x13,
		0x9f, 0x34, 0x83, 0x17, 0xa1, 0xc7, 0x51, 0x9c, 0x18, 0x15, 0x7a, 0x1e, 0x0d, 0x92, 0x55, 0x34,
		0x51, 0xa7, 0xeb, 0x22, 0x6c, 0xfe, 0x80, 0x08, 0xff, 0x46, 0x84, 0xcb, 0xa5, 0xd2, 0x49, 0x09,
		0x62, 0xac, 0x17, 0x16, 0x51, 0x3f, 0x7b, 0xf7, 0x4d, 0x36, 0xde, 0x57, 0x45, 0x7e, 0xa7, 0xba,
		0x9b, 0xf4, 0xcd, 0xb4, 0x81, 0x82, 0x1b, 0x75, 0xf0, 0x06, 0xe0, 0x0d, 0xc0, 0x1b, 0x80, 0x37,
		0x00, 0x6f, 0x90, 0x12, 0xde, 0xe0, 0x83, 0x06, 0xb4, 0x41, 0x09, 0xb4, 0x01, 0x68, 0x03, 0xd0,
		0x06, 0xa0, 0x0d, 0x40, 0x1b, 0x48, 0x17, 0xe1, 0x42, 0x09, 0xa4, 0x01, 0x48, 0x03, 0x90, 0x06,
		0xbc, 0xa4, 0xc1, 0xc3, 0xf2, 0xf4, 0xe9, 0xc0, 0x1a, 0x2c, 0x9e, 0x05, 0xb4, 0x01, 0x68, 0x03,
		0xd0, 0x06, 0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0xd8, 0x53, 0x6f, 0xdc, 0x5a, 0xb6, 0xe9, 0x3e,
		0x6a, 0xc0, 0x1b, 0x9c, 0x2a, 0x7c, 0x84, 0x0b, 0x61, 0xdf, 0xcf, 0x03, 0xff, 0x41, 0x1c, 0x80,
		0x38, 0xf8, 0xad, 0xd7, 0x95, 0x87, 0xcf, 0x05, 0xe2, 0x20, 0xd9, 0x22, 0x8c, 0x78, 0x03, 0x50,
		0x07, 0xa0, 0x0e, 0x58, 0xc5, 0x5c, 0xfc, 0xf0, 0x85, 0x3d, 0x60, 0xec, 0xef, 0xb9, 0x15, 0xf2,
		0x05, 0x4f, 0x02, 0xda, 0x00, 0xb4, 0x01, 0x68, 0x03, 0xd0, 0x06, 0xa0, 0x0d, 0x40, 0x1b, 0xec,
		0x4b, 0x1b, 0xb0, 0x57, 0xc3, 0xdd, 0x66, 0x46, 0x98, 0xaa, 0xe3, 0x66, 0x13, 0xb4, 0x38, 0xe3,
		0x19, 0x32, 0x37, 0x87, 0xea, 0x41, 0x4b, 0xf0, 0x24, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d, 0x00,
		0x2d, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d, 0xe1, 0x35, 0x1e, 0x9b, 0xae, 0x6f, 0xe9,
		0x80, 0x59, 0x56, 0x0f, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8,
		0x02, 0xc8, 0x02, 0xc8, 0x12, 0x5e, 0x63, 0xdf, 0x35, 0x6d, 0xcf, 0xf2, 0xad, 0x07, 0x0d, 0xe2,
		0x4a, 0x5f, 0x3c, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b,
		0x80, 0x8b, 0xf6, 0xc0, 0x25, 0xd5, 0xe5, 0x45, 0x99, 0xdb, 0x2f, 0x86, 0xe6, 0x57, 0xd7, 0x8e,
		0x31, 0xdc, 0x1f, 0x2f, 0xfc, 0x57, 0x47, 0x2a, 0x8a, 0x5b, 0x1f, 0x28, 0xe9, 0xe1, 0x78, 0xbd,
		0x78, 0xf7, 0x6a, 0xb0, 0x1a, 0xa1, 0xbf, 0xe1, 0x68, 0xf3, 0xa8, 0xee, 0xf0, 0xa5, 0xab, 0x83,
		0xce, 0xbf, 0xc5, 0xa3, 0x8a, 0x12, 0x38, 0xb9, 0x0b, 0xcb, 0xf3, 0x67, 0x02, 0xc3, 0xdb, 0xbe,
		0xe7, 0xd2, 0xb2, 0x6b, 0x43, 0x31, 0xc3, 0x47, 0x1e, 0xaf, 0x7f, 0x91, 0xbb, 0x34, 0x7f, 0xbc,
		0x98, 0x39, 0xff, 0xa1, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xe3, 0xca, 0x49, 0xe5, 0xf8, 0xb4, 0x54,
		0xca, 0x97, 0xf3, 0x8c, 0xe1, 0xc0, 0xb9, 0x86, 0x3b, 0x10, 0xae, 0x18, 0x7c, 0x9a, 0x6d, 0xbd,
		0x3d, 0x19, 0x0e, 0x53, 0x25, 0xd1, 0x8a, 0x0c, 0x95, 0xe6, 0x06, 0x2a, 0xc7, 0xda, 0x67, 0x42,
		0x3b, 0x93, 0x94, 0x43, 0x0b, 0x6f, 0xf5, 0x47, 0x34, 0x43, 0x2d, 0xbc, 0xd9, 0x7b, 0x2a, 0x6b,
		0x72, 0xf0, 0x12, 0xdb, 0xdb, 0xfb, 0x4d, 0x82, 0xce, 0xd3, 0x0a, 0xb4, 0xcd, 0x04, 0xdb, 0xb0,
		0x06, 0x07, 0xc2, 0x1e, 0x8c, 0x1d, 0xcb, 0xf6, 0x0f, 0xfa, 0xce, 0xd0, 0x71, 0x25, 0x09, 0x1a,
		0x0f, 0x62, 0xe3, 0x43, 0x68, 0x4a, 0x11, 0x19, 0x0f, 0x02, 0x93, 0x25, 0x7e, 0x4c, 0x6a, 0x5c,
		0x9d, 0xfa, 0x96, 0xa8, 0xab, 0xd9, 0x75, 0xb4, 0x1c, 0x8d, 0x4c, 0xaf, 0x2f, 0x69, 0x47, 0x24,
		0x16, 0x7d, 0xd9, 0x22, 0xaf, 0x42, 0xd4, 0x25, 0x08, 0x39, 0xa3, 0x70, 0xd3, 0x8a, 0x35, 0x9d,
		0xf0, 0xd1, 0x8c, 0x44, 0x24, 0xbe, 0xb2, 0xc4, 0x96, 0x55, 0x5c, 0x09, 0xe5, 0x94, 0x43, 0x3e,
		0x69, 0x04, 0x33, 0xbe, 0x18, 0x11, 0x88, 0x50, 0xee, 0xe5, 0x4e, 0xb8, 0x74, 0x17, 0x5b, 0xcf,
		0x25, 0xb4, 0xd6, 0xc7, 0x27, 0x12, 0x7a, 0xda, 0x96, 0x8f, 0xe4, 0xe1, 0x08, 0x32, 0xc2, 0x0b,
		0xe4, 0x86, 0x0b, 0xc8, 0xba, 0xfe, 0x97, 0x7e, 0x9d, 0x2f, 0xfd, 0x7a, 0x5e, 0xfa, 0x75, 0xbb,
		0x5e, 0xe6, 0x84, 0xba, 0xc5, 0x60, 0x6e, 0x89, 0x44, 0xc8, 0x05, 0x6b, 0x75, 0x1c, 0xa4, 0x20,
		0x1d, 0x49, 0x3d, 0x65, 0xa5, 0xc5, 0x3d, 0xc9, 0x8c, 0x67, 0xe2, 0x89, 0x53, 0x92, 0x1d, 0x7f,
		0xc4, 0x16, 0x57, 0xc4, 0x16, 0x2f, 0xc4, 0x16, 0x07, 0xa4, 0xb7, 0xdb, 0x26, 0xab, 0x27, 0xea,
		0x42, 0xb1, 0xc8, 0x93, 0xc7, 0x35, 0xfd, 0x25, 0x4b, 0x16, 0xe5, 0xb6, 0xc6, 0x96, 0x1e, 0xc6,
		0xc9, 0x11, 0xa6, 0xc9, 0x1b, 0x86, 0xc9, 0x15, 0x66, 0xc9, 0x1e, 0x46, 0xc9, 0x1e, 0x26, 0xc9,
		0x1e, 0x06, 0x99, 0xac, 0xfb, 0x03, 0xd9, 0xad, 0xa2, 0x73, 0x8b, 0x8b, 0x08, 0xe9, 0x72, 0xbc,
		0x3a, 0x9d, 0x32, 0xef, 0x3d, 0x5e, 0xab, 0x4b, 0xc9, 0x41, 0x23, 0x6c, 0xd1, 0xef, 0x9c, 0x51,
		0xee, 0x6a, 0xa2, 0xd9, 0xb9, 0xa3, 0xd6, 0x95, 0x45, 0xa7, 0x2b, 0x8b, 0x42, 0x57, 0x16, 0x6d,
		0x9e, 0xec, 0x30, 0x08, 0xb6, 0x28, 0xf1, 0xe0, 0xdc, 0x0d, 0x85, 0x79, 0xe7, 0x8a, 0x3b, 0x8e,
		0x43, 0xb7, 0x42, 0x95, 0x15, 0x86, 0xb9, 0x9a, 0x4b, 0x02, 0xfa, 0xfd, 0xfb, 0x45, 0xfc, 0xed,
		0xd1, 0xc2, 0x10, 0x24, 0x35, 0x06, 0x41, 0x22, 0xb2, 0x5c, 0x85, 0x08, 0xf0, 0xd9, 0xe4, 0x60,
		0x46, 0x98, 0x65, 0x98, 0x65, 0x98, 0x65, 0x98, 0x65, 0x98, 0xe5, 0xcc, 0x9a, 0xe5, 0xc0, 0x16,
		0xc0, 0x32, 0x87, 0x16, 0x6b, 0x19, 0xc4, 0xc7, 0x67, 0x98, 0x57, 0x13, 0xc2, 0x2e, 0xc3, 0x2e,
		0xc3, 0x2e, 0xc3, 0x2e, 0xc3, 0x2e, 0x67, 0xd6, 0x2e, 0xaf, 0x4c, 0x01, 0xcc, 0x72, 0x68, 0xad,
		0x16, 0xf9, 0xbc, 0x6c, 0x46, 0x99, 0x23, 0x7d, 0x58, 0xf2, 0x85, 0x1f, 0x4c, 0x32, 0x4c, 0x32,
		0x4c, 0x72, 0x36, 0x4c, 0xb2, 0xec, 0x0b, 0xc4, 0x60, 0xa2, 0x79, 0x5e, 0xba, 0x65, 0x0f, 0x04,
		0x5f, 0x39, 0xa6, 0xf5, 0x06, 0xaf, 0x8b, 0xb9, 0xb9, 0x92, 0xf1, 0x59, 0x0b, 0x6f, 0xb1, 0x17,
		0xda, 0x52, 0x51, 0x58, 0x4b, 0x6d, 0x21, 0x2d, 0x55, 0x85, 0xb3, 0x94, 0x17, 0xca, 0x52, 0x5e,
		0x18, 0x4b, 0x79, 0x21, 0xac, 0x74, 0x95, 0x09, 0x61, 0x2f, 0x6c, 0xa5, 0xc0, 0x17, 0x53, 0xe1,
		0x93, 0x6d, 0xf2, 0xcd, 0x7e, 0xf1, 0xdf, 0xdc, 0x24, 0x79, 0xc2, 0xf7, 0x82, 0x4f, 0x4b, 0x4f,
		0x6e, 0x61, 0xa6, 0xd2, 0x52, 0xe4, 0x80, 0x01, 0x59, 0xf3, 0x44, 0x28, 0x85, 0xa4, 0x99, 0x23,
		0x52, 0x09, 0x70, 0x02, 0x70, 0x02, 0x70, 0x02, 0x70, 0x02, 0x70, 0x62, 0xc3, 0xb9, 0x9d, 0x58,
		0xb6, 0x7f, 0x52, 0x50, 0x80, 0x26, 0x38, 0xc1, 0x44, 0xcb, 0xb4, 0xef, 0x05, 0x7b, 0x3b, 0x75,
		0x05, 0x45, 0x21, 0x55, 0xb6, 0x4b, 0x57, 0x5d, 0x26, 0x7b, 0xd5, 0x4b, 0x5a, 0xd5, 0xfc, 0x1a,
		0xf4, 0x8d, 0x56, 0x51, 0x2a, 0x5e, 0x65, 0x7b, 0x73, 0x5d, 0x44, 0xae, 0x58, 0x38, 0x2d, 0x9e,
		0x96, 0x2b, 0x85, 0xd3, 0x52, 0x86, 0x65, 0x2f, 0xa5, 0xe5, 0x4d, 0xbb, 0x70, 0x22, 0xf7, 0x70,
		0x22, 0x47, 0xa3, 0x89, 0x6d, 0xf9, 0x8f, 0xaa, 0x28, 0xea, 0xd7, 0x0f, 0x00, 0xc7, 0x12, 0x8e,
		0x25, 0x1c, 0x4b, 0x38, 0x96, 0x70, 0x2c, 0xd9, 0xcf, 0x2d, 0x78, 0xea, 0x17, 0xff, 0xad, 0xec,
		0x92, 0x25, 0xbc, 0xe0, 0xf3, 0x23, 0xa8, 0xea, 0x68, 0x4b, 0xce, 0x96, 0xbb, 0x13, 0x92, 0x69,
		0xa6, 0x1c, 0x1e, 0xe0, 0x0a, 0xe0, 0x0a, 0xe0, 0x0a, 0xe0, 0x0a, 0xe0, 0x8a, 0x0d, 0xe7, 0xd6,
		0x1a, 0x1b, 0xe6, 0x60, 0xe0, 0x0a, 0xcf, 0x53, 0x01, 0x2d, 0x4e, 0x19, 0xe7, 0x5c, 0xae, 0x71,
		0xea, 0x49, 0xeb, 0xe7, 0x9d, 0x7d, 0x28, 0x2a, 0xd8, 0xdb, 0xd0, 0x1e, 0x7f, 0x50, 0x30, 0x77,
		0xd3, 0xf4, 0x7d, 0xe1, 0xda, 0xec, 0xdb, 0x1d, 0x3c, 0xc0, 0xdb, 0xb7, 0x37, 0xc7, 0xc6, 0x69,
		0xf7, 0xe9, 0x26, 0x6f, 0x9c, 0x76, 0x17, 0x1f, 0xf3, 0xf3, 0x3f, 0x16, 0x9f, 0x0b, 0x37, 0xc7,
		0x46, 0x71, 0xf5, 0xb9, 0x74, 0x73, 0x6c, 0x94, 0xba, 0x87, 0xdf, 0xbe, 0xbd, 0x3f, 0xfc, 0x79,
		0x32, 0xdd, 0xff, 0x8b, 0xfc, 0xdd, 0xf7, 0xba, 0x2a, 0xb6, 0xb4, 0xd1, 0xae, 0xff, 0xa9, 0x7c,
		0x5f, 0xff, 0xe2, 0xdc, 0xd8, 0x7f, 0x29, 0xd8, 0xd9, 0x34, 0x37, 0x99, 0x53, 0xab, 0x8c, 0xcb,
		0x50, 0xc6, 0x4a, 0x95, 0xb1, 0x69, 0xdc, 0x55, 0x8d, 0xcf, 0xdd, 0x9f, 0xf9, 0x77, 0xc5, 0xe9,
		0xc7, 0xc3, 0x9f, 0x95, 0xe9, 0xeb, 0xbf, 0x7c, 0xda, 0xf4, 0x63, 0xf9, 0x77, 0x95, 0xe9, 0xc7,
		0x2d, 0xff, 0x52, 0x9e, 0x7e, 0xdc, 0x71, 0x8c, 0xd2, 0xf4, 0x6d, 0xe8, 0x47, 0x67, 0x7f, 0x5f,
		0xd8, 0xf6, 0x85, 0xe2, 0x96, 0x2f, 0x9c, 0x6c, 0xfb, 0xc2, 0xc9, 0x96, 0x2f, 0x6c, 0x7d, 0xa4,
		0xc2, 0x96, 0x2f, 0x94, 0xa6, 0x4f, 0xa1, 0x9f, 0x7f, 0xbb, 0xf9, 0x47, 0xcb, 0xd3, 0xc3, 0xa7,
		0x6d, 0xff, 0x56, 0x99, 0x3e, 0x7d, 0x3c, 0x84, 0x69, 0xe2, 0x37, 0x4d, 0x10, 0x73, 0x7e, 0x31,
		0x4f, 0xbf, 0xa1, 0xc6, 0xfd, 0xb0, 0x8e, 0xcc, 0xed, 0x0f, 0xdf, 0x50, 0x7e, 0x47, 0xbc, 0xe9,
		0x21, 0xc0, 0xe7, 0x82, 0xcf, 0x05, 0x9f, 0x0b, 0x3e, 0x17, 0x7c, 0x2e, 0xfb, 0xb9, 0xc5, 0x3d,
		0xf1, 0x8b, 0xff, 0x5e, 0xda, 0x26, 0x4b, 0x78, 0x6b, 0xff, 0x1f, 0xf7, 0xc5, 0x11, 0x97, 0xde,
		0xb2, 0x1f, 0xcc, 0xa1, 0x35, 0x30, 0x5c, 0x61, 0x7a, 0x8c, 0x4d, 0x90, 0x9f, 0xa9, 0x94, 0xf5,
		0xf9, 0x81, 0x35, 0x80, 0x35, 0x80, 0x35, 0x80, 0x35, 0x80, 0x35, 0xd8, 0xcf, 0xad, 0x35, 0x10,
		0xb6, 0x6f, 0xf9, 0x8f, 0x8a, 0xf0, 0x06, 0x63, 0x76, 0x40, 0xae, 0xbe, 0x7c, 0xd5, 0x4f, 0xa6,
		0xa7, 0x40, 0x65, 0xac, 0x16, 0xbc, 0x7e, 0xf5, 0xb5, 0x7a, 0x51, 0x3f, 0xef, 0xb5, 0x1a, 0xd7,
		0x9d, 0x5a, 0xaf, 0x55, 0xab, 0xb6, 0x1b, 0x57, 0xdc, 0xda, 0x63, 0x9e, 0xa4, 0xe1, 0x29, 0xa1,
		0x39, 0x15, 0x65, 0xc5, 0xbc, 0x5e, 0xfd, 0xb3, 0x8b, 0xeb, 0x76, 0xa7, 0xd6, 0xea, 0x5d, 0x34,
		0x1a, 0xcd, 0x5c, 0x16, 0x92, 0x92, 0x34, 0x59, 0xf7, 0x46, 0xab, 0xfe, 0xa5, 0x7e, 0x55, 0xed,
		0x34, 0x5a, 0x58, 0x75, 0xbe, 0x55, 0xaf, 0xb6, 0x21, 0xe8, 0xdc, 0x0a, 0xa6, 0x71, 0xf5, 0xb9,
		0x76, 0x9e, 0x4b, 0x79, 0xce, 0x59, 0x37, 0x6d, 0x78, 0x2f, 0x15, 0xde, 0xfd, 0xd0, 0xf4, 0x7c,
		0x63, 0xe4, 0x0c, 0xac, 0x3b, 0x4b, 0x0c, 0xf8, 0x9d, 0xfb, 0xf5, 0xe9, 0xe1, 0xdb, 0xc3, 0xb7,
		0x87, 0x6f, 0x0f, 0xdf, 0x1e, 0xbe, 0x3d, 0xfb, 0xb9, 0xf5, 0xad, 0x91, 0xf0, 0xad, 0xfe, 0xdf,
		0x5e, 0xb9, 0xa8, 0xc0, 0xb7, 0x67, 0x0c, 0x53, 0xcb, 0x5d, 0xdb, 0x8b, 0x1c, 0xff, 0x9c, 0x6d,
		0xda, 0x8e, 0x27, 0xfa, 0x8e, 0x3d, 0x60, 0x8d, 0x85, 0x47, 0x35, 0x95, 0xf4, 0xd9, 0xf8, 0xcd,
		0xac, 0x09, 0xaa, 0xa9, 0xb0, 0x8b, 0x1c, 0xaa, 0xa9, 0x1c, 0xe4, 0x3f, 0x14, 0x8b, 0xe5, 0x4a,
		0xb1, 0x78, 0x5c, 0x39, 0xa9, 0x1c, 0x9f, 0x96, 0x4a, 0xf9, 0x72, 0x1e, 0x75, 0x55, 0x52, 0x37,
		0x1b, 0xe2, 0xe6, 0x76, 0x17, 0x43, 0xae, 0x9e, 0x48, 0x21, 0x50, 0xc5, 0xd3, 0x1b, 0x29, 0x98,
		0xf6, 0x5c, 0xdc, 0x99, 0x93, 0xe1, 0x1c, 0x8a, 0x1f, 0xc3, 0x97, 0x86, 0x2f, 0x0d, 0x5f, 0x1a,
		0xbe, 0x34, 0x7c, 0x69, 0x14, 0x05, 0x85, 0x1b, 0x0b, 0x37, 0x16, 0x6e, 0x2c, 0xdc, 0xd8, 0x44,
		0x89, 0x1c, 0x8a, 0x82, 0xc2, 0x79, 0x85, 0xf3, 0x7a, 0x90, 0x5b, 0x06, 0x3f, 0x3b, 0x13, 0x5f,
		0xf0, 0x3b, 0xb0, 0x2f, 0x27, 0x87, 0x43, 0x09, 0x87, 0x12, 0x0e, 0x25, 0x1c, 0x4a, 0x38, 0x94,
		0xec, 0xe7, 0xf6, 0xd6, 0x71, 0x86, 0xc2, 0xb4, 0x55, 0x04, 0x5d, 0xe7, 0xd3, 0x62, 0xaa, 0x13,
		0xdd, 0x20, 0xb3, 0x6a, 0xdb, 0x8e, 0x6f, 0xce, 0xd0, 0x28, 0x4f, 0x9f, 0x4c, 0xaf, 0xff, 0x5d,
		0x8c, 0xcc, 0xf1, 0x32, 0xe9, 0xee, 0xc8, 0x19, 0x0b, 0xbb, 0x3f, 0x37, 0x94, 0x33, 0xfd, 0x71,
		0x34, 0xfb, 0xed, 0x5a, 0xb7, 0x47, 0xe6, 0x9d, 0x65, 0x78, 0xe6, 0x9d, 0xe5, 0x05, 0x9f, 0x8e,
		0xe6, 0x45, 0xc8, 0x3c, 0xd7, 0x17, 0xc6, 0xd8, 0x19, 0x5a, 0xfd, 0xc7, 0x23, 0x5b, 0x58, 0xf7,
		0xdf, 0x6f, 0x1d, 0xd7, 0x0b, 0x3e, 0x1d, 0x99, 0x83, 0xff, 0xcd, 0x55, 0x91, 0x65, 0x1b, 0x63,
		0x57, 0x1c, 0xcd, 0xd1, 0x85, 0xb7, 0xf8, 0xe3, 0x88, 0xa3, 0x71, 0xf1, 0xe2, 0x0d, 0x7d, 0x77,
		0xd2, 0xf7, 0xed, 0xe5, 0x01, 0x6b, 0x04, 0x2f, 0xf8, 0xe9, 0x7e, 0xdc, 0x9b, 0xfd, 0x6e, 0x59,
		0xb7, 0xbd, 0xea, 0x9d, 0xd5, 0x9e, 0xbd, 0xde, 0xea, 0x43, 0xaf, 0x3e, 0x7e, 0x28, 0xb6, 0x5d,
		0x5f, 0x34, 0xe7, 0xef, 0xd6, 0xbb, 0x5a, 0xbd, 0x5b, 0xf0, 0xa9, 0x57, 0x1d, 0xfc, 0xaf, 0x65,
		0xdd, 0xd6, 0xed, 0xa6, 0x2b, 0x7a, 0xad, 0xf9, 0x8b, 0x2d, 0xfe, 0xe8, 0xb5, 0xe7, 0x2f, 0x86,
		0xce, 0xd8, 0xa1, 0x8d, 0x98, 0xd8, 0x7f, 0xdb, 0xce, 0x3f, 0xb6, 0x61, 0xfa, 0xbe, 0x6b, 0xdd,
		0xce, 0x56, 0x8c, 0xaf, 0x4d, 0xf6, 0x86, 0xb9, 0xd1, 0x33, 0x5b, 0x57, 0x34, 0x8b, 0x9e, 0xd9,
		0xe9, 0x44, 0xab, 0xe8, 0x99, 0x1d, 0x69, 0xd5, 0xd8, 0x7a, 0x66, 0x87, 0x94, 0x24, 0x3f, 0x0d,
		0x11, 0x7e, 0x04, 0x5e, 0x32, 0x22, 0x0f, 0x32, 0x02, 0x64, 0x04, 0xc8, 0x08, 0x90, 0x11, 0xfa,
		0x90, 0x11, 0x5c, 0xea, 0x3f, 0x98, 0x70, 0xde, 0x21, 0xda, 0xe7, 0xa6, 0x40, 0xd6, 0x34, 0xc6,
		0xf3, 0x23, 0x30, 0x8b, 0xae, 0x9a, 0x2b, 0x31, 0x76, 0x73, 0xa0, 0xd2, 0x2c, 0xe8, 0x61, 0x1e,
		0x54, 0x9b, 0x09, 0x6d, 0xcc, 0x85, 0x36, 0x66, 0x43, 0x1b, 0xf3, 0xc1, 0x6b, 0x46, 0x98, 0xcd,
		0x49, 0xb0, 0xca, 0x1d, 0x15, 0x0a, 0xfe, 0x40, 0x6d, 0x41, 0xb3, 0x10, 0xda, 0xaf, 0xa8, 0x29,
		0x9a, 0xbd, 0x2a, 0x70, 0xb6, 0xa8, 0x53, 0xf6, 0x6c, 0xec, 0x52, 0x1a, 0x04, 0xc0, 0x28, 0xda,
		0xb9, 0x05, 0xad, 0xac, 0x0c, 0xb8, 0x70, 0xb1, 0xda, 0x0a, 0x7d, 0x57, 0x80, 0x16, 0x80, 0x16,
		0x80, 0x16, 0x80, 0x16, 0x15, 0xa0, 0x85, 0xdb, 0x17, 0x5e, 0xf7, 0x89, 0x87, 0x42, 0x61, 0x7c,
		0xf0, 0x9a, 0x6b, 0x3c, 0x7b, 0x92, 0x77, 0x99, 0x0c, 0x1a, 0x55, 0x65, 0x74, 0x74, 0x30, 0x3e,
		0x7a, 0x19, 0x21, 0x5d, 0x8c, 0x91, 0x76, 0x46, 0x49, 0x3b, 0xe3, 0xa4, 0x9d, 0x91, 0x52, 0x63,
		0xac, 0x14, 0x19, 0x2d, 0xf5, 0x1e, 0x77, 0x48, 0x6f, 0x4c, 0x2c, 0xdb, 0xcf, 0x97, 0x55, 0xea,
		0x8c, 0xa5, 0x15, 0x29, 0x2b, 0x7c, 0x04, 0x35, 0x69, 0x4d, 0xaf, 0x7f, 0xa9, 0xd5, 0x99, 0x07,
		0xaa, 0xd3, 0x9e, 0x34, 0x83, 0x17, 0xa1, 0xc7, 0x51, 0x9c, 0x16, 0x15, 0x7a, 0x1e, 0x0d, 0x52,
		0x55, 0x34, 0x51, 0xa7, 0xeb, 0x22, 0x6c, 0xfe, 0x80, 0x08, 0xff, 0x46, 0x84, 0xcb, 0xa5, 0xd2,
		0x49, 0x09, 0x62, 0xac, 0x17, 0x16, 0x51, 0x3f, 0x7b, 0xf7, 0x4d, 0x36, 0xde, 0x57, 0x45, 0x76,
		0xa7, 0xba, 0x9b, 0xf4, 0xcd, 0xb4, 0x81, 0x82, 0x1b, 0x75, 0xf0, 0x06, 0xe0, 0x0d, 0xc0, 0x1b,
		0x80, 0x37, 0x00, 0x6f, 0x90, 0x12, 0xde, 0xe0, 0x83, 0x06, 0xb4, 0x41, 0x09, 0xb4, 0x01, 0x68,
		0x03, 0xd0, 0x06, 0xa0, 0x0d, 0x40, 0x1b, 0x48, 0x17, 0xe1, 0x42, 0x09, 0xa4, 0x01, 0x48, 0x03,
		0x90, 0x06, 0xbc, 0xa4, 0xc1, 0xc3, 0xf2, 0xf4, 0xe9, 0xc0, 0x1a, 0x2c, 0x9e, 0x05, 0xb4, 0x01,
		0x68, 0x03, 0xd0, 0x06, 0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0xd8, 0x53, 0x6f, 0xdc, 0x5a, 0xb6,
		0xe9, 0x3e, 0x6a, 0xc0, 0x1b, 0x9c, 0x2a, 0x7c, 0x84, 0x0b, 0x61, 0xdf, 0xcf, 0x03, 0xff, 0x41,
		0x1c, 0x80, 0x38, 0xf8, 0xad, 0xd7, 0x95, 0x87, 0xcf, 0x05, 0xe2, 0x20, 0xd9, 0x22, 0x8c, 0x78,
		0x03, 0x50, 0x07, 0xa0, 0x0e, 0x58, 0xc5, 0x5c, 0xfc, 0xf0, 0x85, 0x3d, 0x60, 0xec, 0xee, 0xb9,
		0x15, 0xf2, 0x05, 0x4f, 0x02, 0xda, 0x00, 0xb4, 0x01, 0x68, 0x03, 0xd0, 0x06, 0xa0, 0x0d, 0x40,
		0x1b, 0xec, 0x4b, 0x1b, 0xb0, 0xd7, 0xc2, 0xdd, 0x66, 0x46, 0x98, 0x6a, 0xe3, 0x66, 0x13, 0xb4,
		0x38, 0xe3, 0x19, 0x32, 0x37, 0x87, 0xea, 0x41, 0x4b, 0xf0, 0x24, 0x00, 0x2d, 0x00, 0x2d, 0x00,
		0x2d, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d, 0xe1, 0x35, 0x1e, 0x9b, 0xae,
		0x6f, 0xe9, 0x80, 0x59, 0x56, 0x0f, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8,
		0x02, 0xc8, 0x02, 0xc8, 0x02, 0xc8, 0x12, 0x5e, 0x63, 0xdf, 0x35, 0x6d, 0xcf, 0xf2, 0xad, 0x07,
		0x0d, 0xe2, 0x4a, 0x5f, 0x3c, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b, 0x80, 0x0b,
		0x80, 0x0b, 0x80, 0x8b, 0xf6, 0xc0, 0x25, 0xd5, 0xe5, 0x45, 0x99, 0x9b, 0x2f, 0x86, 0xe6, 0x57,
		0xd6, 0x8c, 0x31, 0xdc, 0x1e, 0x2f, 0xfc, 0x57, 0x47, 0x2a, 0x6a, 0x5b, 0x1f, 0xa8, 0xe8, 0xe0,
		0x78, 0xbd, 0x78, 0xf5, 0x6a, 0xb0, 0x18, 0xa1, 0xbf, 0xe1, 0x68, 0xf2, 0xa8, 0xee, 0xe8, 0xa5,
		0xab, 0x7f, 0xce, 0xbf, 0xc5, 0xa3, 0x8a, 0x02, 0x38, 0xb9, 0x0b, 0xcb, 0xf3, 0x67, 0x02, 0xc3,
		0xdb, 0xbc, 0xe7, 0xd2, 0xb2, 0x6b, 0x43, 0x31, 0x43, 0x47, 0x1e, 0xaf, 0x77, 0x91, 0xbb, 0x34,
		0x7f, 0xbc, 0x98, 0x39, 0xff, 0xa1, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xe3, 0xca, 0x49, 0xe5, 0xf8,
		0xb4, 0x54, 0xca, 0x97, 0xf3, 0x8c, 0xc1, 0xc0, 0xb9, 0x86, 0x3b, 0x10, 0xae, 0x18, 0x7c, 0x9a,
		0x6d, 0xbd, 0x3d, 0x19, 0x0e, 0x53, 0x25, 0xd1, 0x8a, 0xcc, 0x94, 0xde, 0xe6, 0x29, 0xc7, 0xda,
		0x64, 0x42, 0x37, 0x83, 0x94, 0x43, 0xf3, 0x6e, 0xf5, 0x07, 0x34, 0x3b, 0xcd, 0xbb, 0xd9, 0xdb,
		0x29, 0xeb, 0x71, 0xec, 0x12, 0xdb, 0xd5, 0xfb, 0x4d, 0x82, 0x4e, 0xd3, 0x0a, 0xb0, 0xcd, 0xc4,
		0xda, 0xb0, 0x06, 0x07, 0xc2, 0x1e, 0x8c, 0x1d, 0xcb, 0xf6, 0x0f, 0xfa, 0xce, 0xd0, 0x71, 0x25,
		0xc9, 0x19, 0x0f, 0x5a, 0xe3, 0x43, 0x67, 0x4a, 0xd1, 0x18, 0x0f, 0xfa, 0x92, 0x25, 0x7e, 0x4c,
		0x4a, 0x5c, 0x99, 0xf2, 0x96, 0xa8, 0xa9, 0xb9, 0x35, 0xb4, 0x1c, 0x7d, 0x4c, 0xaf, 0x2d, 0x69,
		0x47, 0x24, 0x16, 0x7c, 0xd9, 0x02, 0xaf, 0x40, 0xd0, 0x25, 0x88, 0x38, 0x9f, 0x68, 0xd3, 0x0a,
		0x35, 0x9d, 0xe8, 0xd1, 0x8c, 0x44, 0x24, 0xbc, 0xb2, 0x84, 0x96, 0x53, 0x58, 0x09, 0xa5, 0x94,
		0x41, 0x3a, 0x69, 0xc4, 0x32, 0xbe, 0x10, 0x11, 0x08, 0x50, 0x6e, 0xb5, 0x0f, 0xce, 0xc4, 0x37,
		0xc6, 0x8e, 0xe7, 0x93, 0x89, 0xd0, 0x73, 0xe1, 0xac, 0xd7, 0x33, 0x10, 0x89, 0x3d, 0x6d, 0xab,
		0x47, 0xf2, 0x30, 0x04, 0x19, 0x61, 0x05, 0x72, 0xc3, 0x04, 0x64, 0x5d, 0xfb, 0x4b, 0xbf, 0xc6,
		0x97, 0x7e, 0x2d, 0x2f, 0xfd, 0x9a, 0x5d, 0x2f, 0x83, 0x42, 0xdd, 0x5a, 0x30, 0xb7, 0x84, 0x22,
		0xe4, 0x82, 0xb5, 0x3a, 0x0e, 0x52, 0xa0, 0x8e, 0xa4, 0x5e, 0xb2, 0xd2, 0xe2, 0x9d, 0x64, 0xc6,
		0x31, 0xf1, 0xc4, 0x27, 0xc9, 0x8e, 0x3b, 0x62, 0x8b, 0x27, 0x62, 0x8b, 0x13, 0x62, 0x8b, 0xff,
		0xd1, 0xdb, 0x6d, 0x93, 0xd5, 0x0b, 0x75, 0xa1, 0x58, 0xe4, 0xc9, 0xe3, 0x9a, 0xfe, 0x92, 0x25,
		0x8b, 0x72, 0x5b, 0x62, 0x4b, 0x0f, 0xdf, 0xe4, 0x08, 0xcf, 0xe4, 0x0d, 0xbf, 0xe4, 0x0a, 0xaf,
		0x64, 0x0f, 0x9f, 0x64, 0x0f, 0x8f, 0x64, 0x0f, 0x7f, 0x4c, 0xd6, 0xed, 0x81, 0xec, 0x16, 0xd1,
		0xb9, 0xc5, 0x35, 0x84, 0x74, 0x39, 0x5e, 0x9d, 0x4e, 0x99, 0xb7, 0x1e, 0xaf, 0xd5, 0xa5, 0xe4,
		0x70, 0x11, 0xb6, 0xa8, 0x77, 0xce, 0xe8, 0x76, 0x35, 0x51, 0xec, 0xdc, 0xd1, 0xea, 0xca, 0xa2,
		0xd2, 0x95, 0x45, 0x9f, 0x2b, 0x8b, 0x32, 0x4f, 0x76, 0x08, 0x04, 0x5b, 0x74, 0x78, 0x70, 0xee,
		0x86, 0xc2, 0xbc, 0x73, 0xc5, 0x1d, 0xc7, 0xa1, 0x5b, 0xa1, 0xca, 0x0a, 0xc3, 0x5c, 0xcd, 0x25,
		0x05, 0xfd, 0xfe, 0xfd, 0x22, 0xf0, 0xf6, 0x68, 0x61, 0x08, 0x92, 0x1a, 0x81, 0x20, 0x11, 0x59,
		0xae, 0x02, 0x04, 0xf8, 0x6c, 0x72, 0x30, 0x23, 0xcc, 0x32, 0xcc, 0x32, 0xcc, 0x32, 0xcc, 0x32,
		0xcc, 0x72, 0x66, 0xcd, 0x72, 0x60, 0x0b, 0x60, 0x99, 0x43, 0x8b, 0xb5, 0x0c, 0xe1, 0xe3, 0x33,
		0xcc, 0xab, 0x09, 0x61, 0x97, 0x61, 0x97, 0x61, 0x97, 0x61, 0x97, 0x61, 0x97, 0x33, 0x6b, 0x97,
		0x57, 0xa6, 0x00, 0x66, 0x39, 0xb4, 0x56, 0x8b, 0x44, 0x5e, 0x36, 0xa3, 0xcc, 0x91, 0x37, 0x2c,
		0xf9, 0xc2, 0x0f, 0x26, 0x19, 0x26, 0x19, 0x26, 0x39, 0x1b, 0x26, 0x59, 0xf6, 0x05, 0x62, 0x30,
		0xd1, 0x3c, 0x23, 0xdd, 0xb2, 0x07, 0x82, 0xaf, 0x0c, 0xd3, 0x7a, 0x63, 0xd7, 0xc5, 0xdc, 0x5c,
		0x69, 0xf8, 0xac, 0x05, 0xb7, 0xd8, 0x0b, 0x6c, 0xa9, 0x28, 0xa8, 0xa5, 0xb6, 0x80, 0x96, 0xaa,
		0x82, 0x59, 0xca, 0x0b, 0x64, 0x29, 0x2f, 0x88, 0xa5, 0xbc, 0x00, 0x56, 0xba, 0x0a, 0x84, 0xb0,
		0x17, 0xb4, 0x52, 0xe0, 0x8b, 0xa9, 0xf0, 0xc9, 0x36, 0xf9, 0x66, 0xbf, 0xf8, 0x6f, 0x6e, 0x92,
		0x3c, 0xe1, 0x7b, 0xc1, 0xa7, 0xa5, 0x27, 0xb7, 0x30, 0x53, 0x69, 0x29, 0x70, 0xc0, 0x80, 0xac,
		0x79, 0x22, 0x94, 0x42, 0xd2, 0xcc, 0x11, 0xa9, 0x04, 0x38, 0x01, 0x38, 0x01, 0x38, 0x01, 0x38,
		0x01, 0x38, 0xb1, 0xe1, 0xdc, 0x4e, 0x2c, 0xdb, 0x3f, 0x29, 0x28, 0x40, 0x13, 0x9c, 0x60, 0xa2,
		0x65, 0xda, 0xf7, 0x82, 0xbd, 0x8d, 0xba, 0x82, 0x62, 0x90, 0x2a, 0xdb, 0xa4, 0xab, 0x2e, 0x8f,
		0xbd, 0xea, 0x21, 0xad, 0x6a, 0x7e, 0x0d, 0xfa, 0x45, 0xab, 0x28, 0x11, 0xaf, 0xb2, 0xad, 0xb9,
		0x2e, 0x22, 0x57, 0x2c, 0x9c, 0x16, 0x4f, 0xcb, 0x95, 0xc2, 0x69, 0x29, 0xc3, 0xb2, 0x97, 0xd2,
		0xc2, 0xa6, 0x5d, 0x38, 0x91, 0x7b, 0x38, 0x91, 0xa3, 0xd1, 0xc4, 0xb6, 0xfc, 0x47, 0x55, 0x14,
		0xf5, 0xeb, 0x07, 0x80, 0x63, 0x09, 0xc7, 0x12, 0x8e, 0x25, 0x1c, 0x4b, 0x38, 0x96, 0xec, 0xe7,
		0x16, 0x3c, 0xf5, 0x8b, 0xff, 0x56, 0x76, 0xc9, 0x12, 0x5e, 0xf0, 0xf9, 0x11, 0x54, 0x75, 0xb4,
		0x25, 0x67, 0xcb, 0xdd, 0x09, 0xc9, 0x34, 0x53, 0x0e, 0x0f, 0x70, 0x05, 0x70, 0x05, 0x70, 0x05,
		0x70, 0x05, 0x70, 0xc5, 0x86, 0x73, 0x6b, 0x8d, 0x0d, 0x73, 0x30, 0x70, 0x85, 0xe7, 0xa9, 0x80,
		0x16, 0xa7, 0x8c, 0x73, 0x2e, 0xd7, 0x38, 0xf5, 0xa4, 0xf5, 0xf3, 0xce, 0x3e, 0x14, 0x15, 0xec,
		0x6d, 0x68, 0x8f, 0x3f, 0x28, 0x98, 0xbb, 0x69, 0xfa, 0xbe, 0x70, 0x6d, 0xf6, 0xed, 0x0e, 0x1e,
		0xe0, 0xed, 0xdb, 0x9b, 0x63, 0xe3, 0xb4, 0xfb, 0x74, 0x93, 0x37, 0x4e, 0xbb, 0x8b, 0x8f, 0xf9,
		0xf9, 0x1f, 0x8b, 0xcf, 0x85, 0x9b, 0x63, 0xa3, 0xb8, 0xfa, 0x5c, 0xba, 0x39, 0x36, 0x4a, 0xdd,
		0xc3, 0x6f, 0xdf, 0xde, 0x1f, 0xfe, 0x3c, 0x99, 0xee, 0xff, 0x45, 0xfe, 0xae, 0x7b, 0x5d, 0x15,
		0x5b, 0xda, 0x68, 0xd7, 0xff, 0x54, 0xbe, 0xaf, 0x7f, 0x71, 0x6e, 0xec, 0xbf, 0x14, 0xec, 0x6c,
		0x9a, 0x9b, 0xcb, 0xa9, 0x55, 0xc6, 0x65, 0x28, 0x63, 0xa5, 0xca, 0xd8, 0x34, 0xee, 0xaa, 0xc6,
		0xe7, 0xee, 0xcf, 0xfc, 0xbb, 0xe2, 0xf4, 0xe3, 0xe1, 0xcf, 0xca, 0xf4, 0xf5, 0x5f, 0x3e, 0x6d,
		0xfa, 0xb1, 0xfc, 0xbb, 0xca, 0xf4, 0xe3, 0x96, 0x7f, 0x29, 0x4f, 0x3f, 0xee, 0x38, 0x46, 0x69,
		0xfa, 0x36, 0xf4, 0xa3, 0xb3, 0xbf, 0x2f, 0x6c, 0xfb, 0x42, 0x71, 0xcb, 0x17, 0x4e, 0xb6, 0x7d,
		0xe1, 0x64, 0xcb, 0x17, 0xb6, 0x3e, 0x52, 0x61, 0xcb, 0x17, 0x4a, 0xd3, 0xa7, 0xd0, 0xcf, 0xbf,
		0xdd, 0xfc, 0xa3, 0xe5, 0xe9, 0xe1, 0xd3, 0xb6, 0x7f, 0xab, 0x4c, 0x9f, 0x3e, 0x1e, 0xc2, 0x34,
		0xf1, 0x9b, 0x26, 0x88, 0x39, 0xbf, 0x98, 0xa7, 0xdf, 0x50, 0xe3, 0x7e, 0x58, 0x47, 0xe6, 0xf6,
		0x87, 0x6f, 0x28, 0xbf, 0x23, 0xde, 0xf4, 0x10, 0xe0, 0x73, 0xc1, 0xe7, 0x82, 0xcf, 0x05, 0x9f,
		0x0b, 0x3e, 0x97, 0xfd, 0xdc, 0xe2, 0x9e, 0xf8, 0xc5, 0x7f, 0x2f, 0x6d, 0x93, 0x25, 0xbc, 0xb5,
		0xff, 0x8f, 0xfb, 0xe2, 0x88, 0x4b, 0x6f, 0xd9, 0x0f, 0xe6, 0xd0, 0x1a, 0x18, 0xae, 0x30, 0x3d,
		0xc6, 0xf6, 0xc7, 0xcf, 0x54, 0xca, 0xfa, 0xfc, 0xc0, 0x1a, 0xc0, 0x1a, 0xc0, 0x1a, 0xc0, 0x1a,
		0xc0, 0x1a, 0xec, 0xe7, 0xd6, 0x1a, 0x08, 0xdb, 0xb7, 0xfc, 0x47, 0x45, 0x78, 0x83, 0x31, 0x3b,
		0x20, 0x57, 0x5f, 0xbe, 0xea, 0x27, 0xd3, 0x53, 0xa0, 0x32, 0x56, 0x0b, 0x5e, 0xbf, 0xfa, 0x5a,
		0xbd, 0xa8, 0x9f, 0xf7, 0x5a, 0x8d, 0xeb, 0x4e, 0xad, 0xd7, 0xaa, 0x55, 0xdb, 0x8d, 0x2b, 0x6e,
		0xed, 0x31, 0x4f, 0xd2, 0xf0, 0x94, 0xd0, 0x9c, 0x8a, 0xb2, 0x62, 0x5e, 0xaf, 0xfe, 0xd9, 0xc5,
		0x75, 0xbb, 0x53, 0x6b, 0xf5, 0x2e, 0x1a, 0x8d, 0x66, 0x2e, 0x0b, 0x49, 0x49, 0x9a, 0xac, 0x7b,
		0xa3, 0x55, 0xff, 0x52, 0xbf, 0xaa, 0x76, 0x1a, 0x2d, 0xac, 0x3a, 0xdf, 0xaa, 0x57, 0xdb, 0x10,
		0x74, 0x6e, 0x05, 0xd3, 0xb8, 0xfa, 0x5c, 0x3b, 0xcf, 0xa5, 0x3c, 0xe7, 0xac, 0x9b, 0x36, 0xbc,
		0x97, 0x0a, 0xef, 0x7e, 0x68, 0x7a, 0xbe, 0x31, 0x72, 0x06, 0xd6, 0x9d, 0x25, 0x06, 0xfc, 0xce,
		0xfd, 0xfa, 0xf4, 0xf0, 0xed, 0xe1, 0xdb, 0xc3, 0xb7, 0x87, 0x6f, 0x0f, 0xdf, 0x9e, 0xfd, 0xdc,
		0xfa, 0xd6, 0x48, 0xf8, 0x56, 0xff, 0x6f, 0xaf, 0x5c, 0x54, 0xe0, 0xdb, 0x33, 0x86, 0xa9, 0xe5,
		0xae, 0xed, 0x45, 0x8e, 0x7f, 0xce, 0x36, 0x6d, 0xc7, 0x13, 0x7d, 0xc7, 0x1e, 0xb0, 0xc6, 0xc2,
		0xa3, 0x9a, 0x4a, 0xfa, 0x6c, 0xfc, 0x66, 0xd6, 0x04, 0xd5, 0x54, 0xd8, 0x45, 0x0e, 0xd5, 0x54,
		0x0e, 0xf2, 0x1f, 0x8a, 0xc5, 0x72, 0xa5, 0x58, 0x3c, 0xae, 0x9c, 0x54, 0x8e, 0x4f, 0x4b, 0xa5,
		0x7c, 0x39, 0x8f, 0xba, 0x2a, 0xa9, 0x9b, 0x0d, 0x71, 0x73, 0xbb, 0x8b, 0x21, 0x57, 0x4f, 0xa4,
		0x10, 0xa8, 0xe2, 0xe9, 0x8d, 0x14, 0x4c, 0x7b, 0x2e, 0xee, 0xcc, 0xc9, 0x70, 0x0e, 0xc5, 0x8f,
		0xe1, 0x4b, 0xc3, 0x97, 0x86, 0x2f, 0x0d, 0x5f, 0x1a, 0xbe, 0x34, 0x8a, 0x82, 0xc2, 0x8d, 0x85,
		0x1b, 0x0b, 0x37, 0x16, 0x6e, 0x6c, 0xa2, 0x44, 0x0e, 0x45, 0x41, 0xe1, 0xbc, 0xc2, 0x79, 0x3d,
		0xc8, 0x2d, 0x83, 0x9f, 0x9d, 0x89, 0x2f, 0xf8, 0x1d, 0xd8, 0x97, 0x93, 0xc3, 0xa1, 0x84, 0x43,
		0x09, 0x87, 0x12, 0x0e, 0x25, 0x1c, 0x4a, 0xf6, 0x73, 0x7b, 0xeb, 0x38, 0x43, 0x61, 0xda, 0x2a,
		0x82, 0xae, 0xf3, 0x69, 0x31, 0xd5, 0x89, 0x6e, 0x90, 0x59, 0xb5, 0x6d, 0xc7, 0x37, 0x67, 0x68,
		0x94, 0xa7, 0x4f, 0xa6, 0xd7, 0xff, 0x2e, 0x46, 0xe6, 0x78, 0x99, 0x74, 0x77, 0xe4, 0x8c, 0x85,
		0xdd, 0x9f, 0x1b, 0xca, 0x99, 0xfe, 0x38, 0x9a, 0xfd, 0x76, 0xad, 0xdb, 0x23, 0xf3, 0xce, 0x32,
		0x3c, 0xf3, 0xce, 0xf2, 0x82, 0x4f, 0x47, 0xf3, 0x22, 0x64, 0x9e, 0xeb, 0x0b, 0x63, 0xec, 0x0c,
		0xad, 0xfe, 0xe3, 0x91, 0x2d, 0xac, 0xfb, 0xef, 0xb7, 0x8e, 0xeb, 0x05, 0x9f, 0x8e, 0xcc, 0xc1,
		0xff, 0xe6, 0xaa, 0xc8, 0x99, 0xf8, 0xc6, 0xd8, 0xf1, 0xfc, 0xa3, 0x39, 0xbe, 0xf0, 0x16, 0x7f,
		0x1c, 0x71, 0xb4, 0x2e, 0x5e, 0xbc, 0xa3, 0xef, 0x4e, 0xfa, 0xbe, 0xbd, 0x3c, 0x62, 0x8d, 0xe0,
		0x15, 0x3f, 0xdd, 0x8f, 0x7b, 0xb3, 0xdf, 0x2d, 0xeb, 0xb6, 0x57, 0xbd, 0xb3, 0xda, 0xb3, 0x17,
		0x5c, 0x7d, 0xe8, 0xd5, 0xc7, 0x0f, 0xc5, 0xb6, 0xeb, 0x8b, 0xe6, 0xfc, 0xed, 0x7a, 0x57, 0xab,
		0xb7, 0x0b, 0x3e, 0xf5, 0xaa, 0x83, 0xff, 0xb5, 0xac, 0xdb, 0xc6, 0xc4, 0x6f, 0x3a, 0x9e, 0xdf,
		0x6b, 0xcd, 0x5f, 0x6d, 0xf1, 0x47, 0xaf, 0x3d, 0x7f, 0x35, 0x74, 0xc7, 0x0e, 0x6d, 0xc5, 0xc4,
		0xfe, 0xdb, 0x76, 0xfe, 0xb1, 0x0d, 0xd3, 0xf7, 0x5d, 0xeb, 0x76, 0xb6, 0x62, 0x7c, 0xad, 0xb2,
		0x37, 0xcc, 0x8d, 0xbe, 0xd9, 0xba, 0x22, 0x5a, 0xf4, 0xcd, 0x4e, 0x27, 0x62, 0x45, 0xdf, 0xec,
		0x48, 0xab, 0xc6, 0xd6, 0x37, 0x3b, 0xa4, 0x24, 0xf9, 0xa9, 0x88, 0xf0, 0x23, 0xf0, 0x12, 0x12,
		0x79, 0x10, 0x12, 0x20, 0x24, 0x40, 0x48, 0x80, 0x90, 0xd0, 0x87, 0x90, 0xe0, 0x52, 0xff, 0xc1,
		0x84, 0xf3, 0x2e, 0xd1, 0x3e, 0x37, 0x0d, 0xb2, 0xa6, 0x31, 0x9e, 0x1f, 0x81, 0x59, 0x74, 0xd5,
		0x5c, 0x8b, 0xb1, 0x9b, 0x03, 0x95, 0x66, 0x41, 0x0f, 0xf3, 0xa0, 0xda, 0x4c, 0x68, 0x63, 0x2e,
		0xb4, 0x31, 0x1b, 0xda, 0x98, 0x0f, 0x5e, 0x33, 0xc2, 0x6c, 0x4e, 0x82, 0x55, 0xee, 0xa8, 0x50,
		0xf0, 0x07, 0x6a, 0x8b, 0x9a, 0x85, 0xd0, 0x7e, 0x45, 0x4d, 0xe1, 0xec, 0x55, 0x91, 0xb3, 0x45,
		0xad, 0xb2, 0x67, 0x63, 0x97, 0xd2, 0x40, 0x00, 0x46, 0xd1, 0xce, 0x2d, 0x88, 0x65, 0x65, 0xc0,
		0x85, 0x8b, 0xd7, 0x56, 0xe8, 0xbb, 0x02, 0xb4, 0x00, 0xb4, 0x00, 0xb4, 0x00, 0xb4, 0xa8, 0x00,
		0x2d, 0xdc, 0xbe, 0xf0, 0xba, 0x4f, 0x3c, 0x14, 0x0a, 0x63, 0x84, 0xd7, 0x5c, 0xe3, 0xd9, 0x93,
		0xbc, 0xcb, 0x64, 0xe0, 0xa8, 0x2a, 0xa3, 0xa3, 0x83, 0xf1, 0xd1, 0xcb, 0x08, 0xe9, 0x62, 0x8c,
		0xb4, 0x33, 0x4a, 0xda, 0x19, 0x27, 0xed, 0x8c, 0x94, 0x1a, 0x63, 0xa5, 0xc8, 0x68, 0xa9, 0xf7,
		0xb8, 0x43, 0x7a, 0x63, 0x62, 0xd9, 0x7e, 0xbe, 0xac, 0x52, 0x67, 0x2c, 0xad, 0x48, 0x59, 0xe1,
		0x23, 0xa8, 0x49, 0x6d, 0x7a, 0xfd, 0x4b, 0xad, 0xce, 0x3c, 0x50, 0x9d, 0xfa, 0xa4, 0x19, 0xbc,
		0x08, 0x3d, 0x8e, 0xe2, 0xd4, 0xa8, 0xd0, 0xf3, 0x68, 0x90, 0xae, 0xa2, 0x89, 0x3a, 0x5d, 0x17,
		0x61, 0xf3, 0x07, 0x44, 0xf8, 0x37, 0x22, 0x5c, 0x2e, 0x95, 0x4e, 0x4a, 0x10, 0x63, 0xbd, 0xb0,
		0x88, 0xfa, 0xd9, 0xbb, 0x6f, 0xb2, 0xf1, 0xbe, 0x2a, 0x32, 0x3c, 0xd5, 0xdd, 0xa4, 0x6f, 0xa6,
		0x0d, 0x14, 0xdc, 0xa8, 0x83, 0x37, 0x00, 0x6f, 0x00, 0xde, 0x00, 0xbc, 0x01, 0x78, 0x83, 0x94,
		0xf0, 0x06, 0x1f, 0x34, 0xa0, 0x0d, 0x4a, 0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0x00, 0x6d, 0x00,
		0xda, 0x40, 0xba, 0x08, 0x17, 0x4a, 0x20, 0x0d, 0x40, 0x1a, 0x80, 0x34, 0xe0, 0x25, 0x0d, 0x1e,
		0x96, 0xa7, 0x4f, 0x07, 0xd6, 0x60, 0xf1, 0x2c, 0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0x00, 0x6d,
		0x00, 0xda, 0x00, 0xb4, 0xc1, 0x9e, 0x7a, 0xe3, 0xd6, 0xb2, 0x4d, 0xf7, 0x51, 0x03, 0xde, 0xe0,
		0x54, 0xe1, 0x23, 0x5c, 0x08, 0xfb, 0x7e, 0x1e, 0xf8, 0x0f, 0xe2, 0x00, 0xc4, 0xc1, 0x6f, 0xbd,
		0xae, 0x3c, 0x7c, 0x2e, 0x10, 0x07, 0xc9, 0x16, 0x61, 0xc4, 0x1b, 0x80, 0x3a, 0x00, 0x75, 0xc0,
		0x2a, 0xe6, 0xe2, 0x87, 0x2f, 0xec, 0x01, 0x63, 0x87, 0xcf, 0xad, 0x90, 0x2f, 0x78, 0x12, 0xd0,
		0x06, 0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0x00, 0x6d, 0x00, 0xda, 0x60, 0x5f, 0xda, 0x80, 0xbd,
		0x1e, 0xee, 0x36, 0x33, 0xc2, 0x54, 0x1f, 0x37, 0x9b, 0xa0, 0xc5, 0x19, 0xcf, 0x90, 0xb9, 0x39,
		0x54, 0x0f, 0x5a, 0x82, 0x27, 0x01, 0x68, 0x01, 0x68, 0x01, 0x68, 0x01, 0x68, 0x01, 0x68, 0x01,
		0x68, 0x01, 0x68, 0x01, 0x68, 0x09, 0xaf, 0xf1, 0xd8, 0x74, 0x7d, 0x4b, 0x07, 0xcc, 0xb2, 0x7a,
		0x10, 0x40, 0x16, 0x40, 0x16, 0x40, 0x16, 0x40, 0x16, 0x40, 0x16, 0x40, 0x16, 0x40, 0x16, 0x40,
		0x96, 0xf0, 0x1a, 0xfb, 0xae, 0x69, 0x7b, 0x96, 0x6f, 0x3d, 0x68, 0x10, 0x57, 0xfa, 0xe2, 0x59,
		0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0x00, 0x5c, 0xb4, 0x07,
		0x2e, 0xa9, 0x2e, 0x2f, 0xca, 0xdc, 0x80, 0x31, 0x34, 0xbf, 0xc2, 0x86, 0x8c, 0xe1, 0x06, 0x79,
		0xe1, 0xbf, 0x3a, 0x52, 0x51, 0xdd, 0xfa, 0x40, 0x4d, 0x17, 0xc7, 0xeb, 0xc5, 0xcb, 0x57, 0x83,
		0xe5, 0x08, 0xfd, 0x0d, 0x47, 0xa3, 0x47, 0x75, 0xc7, 0x2f, 0x5d, 0x3d, 0x74, 0xfe, 0x2d, 0x1e,
		0x55, 0x14, 0xc1, 0xc9, 0x5d, 0x58, 0x9e, 0x3f, 0x13, 0x18, 0xde, 0x06, 0x3e, 0x97, 0x96, 0x5d,
		0x1b, 0x8a, 0x19, 0x42, 0xf2, 0x78, 0x3d, 0x8c, 0xdc, 0xa5, 0xf9, 0xe3, 0xc5, 0xcc, 0xf9, 0x0f,
		0xc5, 0x62, 0xb9, 0x52, 0x2c, 0x1e, 0x57, 0x4e, 0x2a, 0xc7, 0xa7, 0xa5, 0x52, 0xbe, 0x9c, 0x67,
		0x0c, 0x08, 0xce, 0x35, 0xdc, 0x81, 0x70, 0xc5, 0xe0, 0xd3, 0x6c, 0xeb, 0xed, 0xc9, 0x70, 0x98,
		0x2a, 0x89, 0x56, 0x64, 0xaa, 0x74, 0x37, 0x51, 0x39, 0xd6, 0x56, 0x13, 0xfa, 0x19, 0xa5, 0x1c,
		0x1a, 0x79, 0xab, 0x3f, 0xa4, 0x59, 0x6a, 0xe4, 0xcd, 0xde, 0x58, 0x59, 0x97, 0xa3, 0x97, 0xd8,
		0x0e, 0xdf, 0x6f, 0x12, 0x74, 0xa2, 0x56, 0xc0, 0x6d, 0x26, 0xda, 0x86, 0x35, 0x38, 0x10, 0xf6,
		0x60, 0xec, 0x58, 0xb6, 0x7f, 0xd0, 0x77, 0x86, 0x8e, 0x2b, 0x49, 0xd2, 0x78, 0x50, 0x1b, 0x1f,
		0x4a, 0x53, 0x8a, 0xca, 0x78, 0x50, 0x98, 0x2c, 0xf1, 0x63, 0x52, 0xe4, 0x0a, 0x15, 0xb8, 0x44,
		0x6d, 0xcd, 0xaf, 0xa5, 0xe5, 0xe8, 0x64, 0x7a, 0x8d, 0x49, 0x3b, 0x22, 0xb1, 0xf0, 0xcb, 0x16,
		0x7a, 0x25, 0xc2, 0x2e, 0x41, 0xcc, 0x39, 0xc5, 0x9b, 0x56, 0xb0, 0xe9, 0xc4, 0x8f, 0x66, 0x24,
		0x22, 0x01, 0x96, 0x25, 0xb8, 0xbc, 0x02, 0x4b, 0x28, 0xa9, 0x2c, 0x12, 0x4a, 0x23, 0x9a, 0xf1,
		0x05, 0x89, 0x40, 0x88, 0x72, 0x6b, 0x7b, 0xe1, 0xd2, 0xdd, 0x72, 0x3d, 0xd7, 0xd3, 0x7a, 0x35,
		0x01, 0x91, 0xe0, 0xd3, 0x36, 0x80, 0x24, 0x0f, 0x4e, 0x90, 0x11, 0x6c, 0x20, 0x37, 0x78, 0x40,
		0x56, 0x30, 0x80, 0xf4, 0xcb, 0x7d, 0xe9, 0x97, 0xf5, 0xd2, 0x2f, 0xdf, 0xf5, 0x32, 0x29, 0xd4,
		0x0d, 0x07, 0x73, 0x4b, 0x38, 0x42, 0x2e, 0x58, 0xab, 0xe3, 0x20, 0x05, 0xee, 0x48, 0xea, 0x30,
		0x2b, 0x2d, 0x0a, 0x4a, 0x66, 0x74, 0x13, 0x4f, 0xd4, 0x92, 0xec, 0x68, 0x24, 0xb6, 0x28, 0x23,
		0xb6, 0xe8, 0x21, 0xb6, 0xa8, 0x20, 0xbd, 0x9d, 0x37, 0x59, 0x1d, 0x52, 0x17, 0x8a, 0x45, 0x9e,
		0x3c, 0xae, 0xe9, 0x2f, 0x59, 0xb2, 0x28, 0xb7, 0x51, 0xb6, 0xf4, 0xa0, 0x4e, 0x8e, 0xa0, 0x4d,
		0xde, 0xa0, 0x4c, 0xae, 0xa0, 0x4b, 0xf6, 0xa0, 0x4a, 0xf6, 0xa0, 0x49, 0xf6, 0xa0, 0xc8, 0x64,
		0xdd, 0x23, 0xc8, 0x6e, 0x1c, 0x9d, 0x5b, 0x5c, 0x48, 0x48, 0x97, 0xe3, 0xd5, 0xe9, 0x94, 0x79,
		0xff, 0xf1, 0x5a, 0x5d, 0x4a, 0x0e, 0x20, 0x61, 0x8b, 0x85, 0xe7, 0x8c, 0x79, 0x57, 0x13, 0xdb,
		0xce, 0x1d, 0xc3, 0xae, 0x2c, 0x56, 0x5d, 0x59, 0x4c, 0xba, 0xb2, 0xd8, 0xf3, 0x64, 0x07, 0x44,
		0xb0, 0xc5, 0x8c, 0x07, 0xe7, 0x6e, 0x28, 0xcc, 0x3b, 0x57, 0xdc, 0x71, 0x1c, 0xba, 0x15, 0xaa,
		0xac, 0x30, 0xcc, 0xd5, 0x5c, 0x92, 0xd0, 0xef, 0xdf, 0x2f, 0x82, 0x71, 0x8f, 0x16, 0x86, 0x20,
		0xa9, 0xb1, 0x08, 0x12, 0x91, 0xe5, 0x2a, 0x54, 0x80, 0xcf, 0x26, 0x07, 0x33, 0xc2, 0x2c, 0xc3,
		0x2c, 0xc3, 0x2c, 0xc3, 0x2c, 0xc3, 0x2c, 0x67, 0xd6, 0x2c, 0x07, 0xb6, 0x00, 0x96, 0x39, 0xb4,
		0x58, 0xcb, 0x60, 0x3e, 0x3e, 0xc3, 0xbc, 0x9a, 0x10, 0x76, 0x19, 0x76, 0x19, 0x76, 0x19, 0x76,
		0x19, 0x76, 0x39, 0xb3, 0x76, 0x79, 0x65, 0x0a, 0x60, 0x96, 0x43, 0x6b, 0xb5, 0x48, 0xee, 0x65,
		0x33, 0xca, 0x1c, 0xb9, 0xc4, 0x92, 0x2f, 0xfc, 0x60, 0x92, 0x61, 0x92, 0x61, 0x92, 0xb3, 0x61,
		0x92, 0x65, 0x5f, 0x20, 0x06, 0x13, 0xcd, 0x73, 0xd4, 0x2d, 0x7b, 0x20, 0xf8, 0x8a, 0x33, 0xad,
		0xb7, 0x7b, 0x5d, 0xcc, 0xcd, 0x95, 0x98, 0xcf, 0x5a, 0x86, 0x8b, 0xbd, 0xec, 0x96, 0x8a, 0x32,
		0x5b, 0x6a, 0xcb, 0x6a, 0xa9, 0x2a, 0xa3, 0xa5, 0xbc, 0x6c, 0x96, 0xf2, 0x32, 0x59, 0xca, 0xcb,
		0x62, 0xa5, 0xab, 0x64, 0x08, 0x7b, 0x99, 0x2b, 0x05, 0xbe, 0x98, 0x0a, 0x9f, 0x6c, 0x93, 0x6f,
		0xf6, 0x8b, 0xff, 0xe6, 0x26, 0xc9, 0x13, 0xbe, 0x17, 0x7c, 0x5a, 0x7a, 0x72, 0x0b, 0x33, 0x95,
		0x96, 0x72, 0x07, 0x0c, 0xc8, 0x9a, 0x27, 0x42, 0x29, 0x24, 0xcd, 0x1c, 0x91, 0x4a, 0x80, 0x13,
		0x80, 0x13, 0x80, 0x13, 0x80, 0x13, 0x80, 0x13, 0x1b, 0xce, 0xed, 0xc4, 0xb2, 0xfd, 0x93, 0x82,
		0x02, 0x34, 0xc1, 0x09, 0x26, 0x5a, 0xa6, 0x7d, 0x2f, 0xd8, 0x9b, 0xab, 0x2b, 0x28, 0x11, 0xa9,
		0xb2, 0x79, 0xba, 0xea, 0xa2, 0xd9, 0xab, 0xce, 0xd2, 0xaa, 0xe6, 0xd7, 0xa0, 0x8b, 0xb4, 0x8a,
		0xc2, 0xf1, 0x2a, 0x9b, 0x9d, 0xeb, 0x22, 0x72, 0xc5, 0xc2, 0x69, 0xf1, 0xb4, 0x5c, 0x29, 0x9c,
		0x96, 0x32, 0x2c, 0x7b, 0x29, 0x2d, 0x75, 0xda, 0x85, 0x13, 0xb9, 0x87, 0x13, 0x39, 0x1a, 0x4d,
		0x6c, 0xcb, 0x7f, 0x54, 0x45, 0x51, 0xbf, 0x7e, 0x00, 0x38, 0x96, 0x70, 0x2c, 0xe1, 0x58, 0xc2,
		0xb1, 0x84, 0x63, 0xc9, 0x7e, 0x6e, 0xc1, 0x53, 0xbf, 0xf8, 0x6f, 0x65, 0x97, 0x2c, 0xe1, 0x05,
		0x9f, 0x1f, 0x41, 0x55, 0x47, 0x5b, 0x72, 0xb6, 0xdc, 0x9d, 0x90, 0x4c, 0x33, 0xe5, 0xf0, 0x00,
		0x57, 0x00, 0x57, 0x00, 0x57, 0x00, 0x57, 0x00, 0x57, 0x6c, 0x38, 0xb7, 0xd6, 0xd8, 0x30, 0x07,
		0x03, 0x57, 0x78, 0x9e, 0x0a, 0x68, 0x71, 0xca, 0x38, 0xe7, 0x72, 0x8d, 0x53, 0x4f, 0x5a, 0x3f,
		0xef, 0xec, 0x43, 0x51, 0xc1, 0xde, 0x86, 0xf6, 0xf8, 0x83, 0x82, 0xb9, 0x9b, 0xa6, 0xef, 0x0b,
		0xd7, 0x66, 0xdf, 0xee, 0xe0, 0x01, 0xde, 0xbe, 0xbd, 0x39, 0x36, 0x4e, 0xbb, 0x4f, 0x37, 0x79,
		0xe3, 0xb4, 0xbb, 0xf8, 0x98, 0x9f, 0xff, 0xb1, 0xf8, 0x5c, 0xb8, 0x39, 0x36, 0x8a, 0xab, 0xcf,
		0xa5, 0x9b, 0x63, 0xa3, 0xd4, 0x3d, 0xfc, 0xf6, 0xed, 0xfd, 0xe1, 0xcf, 0x93, 0xe9, 0xfe, 0x5f,
		0xe4, 0xef, 0xc5, 0xd7, 0x55, 0xb1, 0xa5, 0x8d, 0x76, 0xfd, 0x4f, 0xe5, 0xfb, 0xfa, 0x17, 0xe7,
		0xc6, 0xfe, 0x4b, 0xc1, 0xce, 0xa6, 0xb9, 0xe5, 0x9c, 0x5a, 0x65, 0x5c, 0x86, 0x32, 0x56, 0xaa,
		0x8c, 0x4d, 0xe3, 0xae, 0x6a, 0x7c, 0xee, 0xfe, 0xcc, 0xbf, 0x2b, 0x4e, 0x3f, 0x1e, 0xfe, 0xac,
		0x4c, 0x5f, 0xff, 0xe5, 0xd3, 0xa6, 0x1f, 0xcb, 0xbf, 0xab, 0x4c, 0x3f, 0x6e, 0xf9, 0x97, 0xf2,
		0xf4, 0xe3, 0x8e, 0x63, 0x94, 0xa6, 0x6f, 0x43, 0x3f, 0x3a, 0xfb, 0xfb, 0xc2, 0xb6, 0x2f, 0x14,
		0xb7, 0x7c, 0xe1, 0x64, 0xdb, 0x17, 0x4e, 0xb6, 0x7c, 0x61, 0xeb, 0x23, 0x15, 0xb6, 0x7c, 0xa1,
		0x34, 0x7d, 0x0a, 0xfd, 0xfc, 0xdb, 0xcd, 0x3f, 0x5a, 0x9e, 0x1e, 0x3e, 0x6d, 0xfb, 0xb7, 0xca,
		0xf4, 0xe9, 0xe3, 0x21, 0x4c, 0x13, 0xbf, 0x69, 0x82, 0x98, 0xf3, 0x8b, 0x79, 0xfa, 0x0d, 0x35,
		0xee, 0x87, 0x75, 0x64, 0x6e, 0x7f, 0xf8, 0x86, 0xf2, 0x3b, 0xe2, 0x4d, 0x0f, 0x01, 0x3e, 0x17,
		0x7c, 0x2e, 0xf8, 0x5c, 0xf0, 0xb9, 0xe0, 0x73, 0xd9, 0xcf, 0x2d, 0xee, 0x89, 0x5f, 0xfc, 0xf7,
		0xd2, 0x36, 0x59, 0xc2, 0x5b, 0xfb, 0xff, 0xb8, 0x2f, 0x8e, 0xb8, 0xf4, 0x96, 0xfd, 0x60, 0x0e,
		0xad, 0x81, 0xe1, 0x0a, 0xd3, 0x63, 0x6c, 0x88, 0xfc, 0x4c, 0xa5, 0xac, 0xcf, 0x0f, 0xac, 0x01,
		0xac, 0x01, 0xac, 0x01, 0xac, 0x01, 0xac, 0xc1, 0x7e, 0x6e, 0xad, 0x81, 0xb0, 0x7d, 0xcb, 0x7f,
		0x54, 0x84, 0x37, 0x18, 0xb3, 0x03, 0x72, 0xf5, 0xe5, 0xab, 0x7e, 0x32, 0x3d, 0x05, 0x2a, 0x63,
		0xb5, 0xe0, 0xf5, 0xab, 0xaf, 0xd5, 0x8b, 0xfa, 0x79, 0xaf, 0xd5, 0xb8, 0xee, 0xd4, 0x7a, 0xad,
		0x5a, 0xb5, 0xdd, 0xb8, 0xe2, 0xd6, 0x1e, 0xf3, 0x24, 0x0d, 0x4f, 0x09, 0xcd, 0xa9, 0x28, 0x2b,
		0xe6, 0xf5, 0xea, 0x9f, 0x5d, 0x5c, 0xb7, 0x3b, 0xb5, 0x56, 0xef, 0xa2, 0xd1, 0x68, 0xe6, 0xb2,
		0x90, 0x94, 0xa4, 0xc9, 0xba, 0x37, 0x5a, 0xf5, 0x2f, 0xf5, 0xab, 0x6a, 0xa7, 0xd1, 0xc2, 0xaa,
		0xf3, 0xad, 0x7a, 0xb5, 0x0d, 0x41, 0xe7, 0x56, 0x30, 0x8d, 0xab, 0xcf, 0xb5, 0xf3, 0x5c, 0xca,
		0x73, 0xce, 0xba, 0x69, 0xc3, 0x7b, 0xa9, 0xf0, 0xee, 0x87, 0xa6, 0xe7, 0x1b, 0x23, 0x67, 0x60,
		0xdd, 0x59, 0x62, 0xc0, 0xef, 0xdc, 0xaf, 0x4f, 0x0f, 0xdf, 0x1e, 0xbe, 0x3d, 0x7c, 0x7b, 0xf8,
		0xf6, 0xf0, 0xed, 0xd9, 0xcf, 0xad, 0x6f, 0x8d, 0x84, 0x6f, 0xf5, 0xff, 0xf6, 0xca, 0x45, 0x05,
		0xbe, 0x3d, 0x63, 0x98, 0x5a, 0xee, 0xda, 0x5e, 0xe4, 0xf8, 0xe7, 0x6c, 0xd3, 0x76, 0x3c, 0xd1,
		0x77, 0xec, 0x01, 0x6b, 0x2c, 0x3c, 0xaa, 0xa9, 0xa4, 0xcf, 0xc6, 0x6f, 0x66, 0x4d, 0x50, 0x4d,
		0x85, 0x5d, 0xe4, 0x50, 0x4d, 0xe5, 0x20, 0xff, 0xa1, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xe3, 0xca,
		0x49, 0xe5, 0xf8, 0xb4, 0x54, 0xca, 0x97, 0xf3, 0xa8, 0xab, 0x92, 0xba, 0xd9, 0x10, 0x37, 0xb7,
		0xbb, 0x18, 0x72, 0xf5, 0x44, 0x0a, 0x81, 0x2a, 0x9e, 0xde, 0x48, 0xc1, 0xb4, 0xe7, 0xe2, 0xce,
		0x9c, 0x0c, 0xe7, 0x50, 0xfc, 0x18, 0xbe, 0x34, 0x7c, 0x69, 0xf8, 0xd2, 0xf0, 0xa5, 0xe1, 0x4b,
		0xa3, 0x28, 0x28, 0xdc, 0x58, 0xb8, 0xb1, 0x70, 0x63, 0xe1, 0xc6, 0x26, 0x4a, 0xe4, 0x50, 0x14,
		0x14, 0xce, 0x2b, 0x9c, 0xd7, 0x83, 0xdc, 0x32, 0xf8, 0xd9, 0x99, 0xf8, 0x82, 0xdf, 0x81, 0x7d,
		0x39, 0x39, 0x1c, 0x4a, 0x38, 0x94, 0x70, 0x28, 0xe1, 0x50, 0xc2, 0xa1, 0x64, 0x3f, 0xb7, 0xb7,
		0x8e, 0x33, 0x14, 0xa6, 0xad, 0x22, 0xe8, 0x3a, 0x9f, 0x16, 0x53, 0x9d, 0xe8, 0x06, 0x99, 0x55,
		0xdb, 0x76, 0x7c, 0x73, 0x86, 0x46, 0x79, 0xfa, 0x64, 0x7a, 0xfd, 0xef, 0x62, 0x64, 0x8e, 0x97,
		0x49, 0x77, 0x47, 0xce, 0x58, 0xd8, 0xfd, 0xb9, 0xa1, 0x9c, 0xe9, 0x8f, 0xa3, 0xd9, 0x6f, 0xd7,
		0xba, 0x3d, 0x32, 0xef, 0x2c, 0xc3, 0x33, 0xef, 0x2c, 0x2f, 0xf8, 0x74, 0x34, 0x2f, 0x42, 0xe6,
		0xb9, 0xbe, 0x30, 0xc6, 0xce, 0xd0, 0xea, 0x3f, 0x1e, 0xd9, 0xc2, 0xba, 0xff, 0x7e, 0xeb, 0xb8,
		0x5e, 0xf0, 0xe9, 0xc8, 0x1c, 0xfc, 0x6f, 0xae, 0x8a, 0x9c, 0x89, 0x6f, 0x8c, 0x5d, 0x71, 0x34,
		0x87, 0x17, 0xde, 0xe2, 0x8f, 0x23, 0x8e, 0xce, 0xc5, 0x8b, 0x57, 0xf4, 0xdd, 0x49, 0xdf, 0xb7,
		0x97, 0x27, 0xac, 0x11, 0xbc, 0xe1, 0xa7, 0xfb, 0x71, 0x6f, 0xf6, 0xbb, 0x65, 0xdd, 0xf6, 0xaa,
		0x77, 0x56, 0x7b, 0xf6, 0x7e, 0xab, 0x0f, 0xbd, 0xfa, 0xf8, 0xa1, 0xd8, 0x76, 0x7d, 0xd1, 0x9c,
		0xbf, 0x5c, 0xef, 0x6a, 0xf5, 0x72, 0xc1, 0xa7, 0x5e, 0x75, 0xf0, 0xbf, 0x96, 0x75, 0xdb, 0x98,
		0xf8, 0x4d, 0x57, 0xf4, 0x5a, 0xf3, 0x37, 0x5b, 0xfc, 0xd1, 0x6b, 0xcf, 0xdf, 0x0c, 0xbd, 0xb1,
		0x43, 0x3b, 0x31, 0xb1, 0xff, 0xb6, 0x9d, 0x7f, 0x6c, 0xc3, 0xf4, 0x7d, 0xd7, 0xba, 0x9d, 0xad,
		0x18, 0x5f, 0xa3, 0xec, 0x0d, 0x73, 0xa3, 0x6b, 0xb6, 0xae, 0x78, 0x16, 0x5d, 0xb3, 0xd3, 0x89,
		0x57, 0xd1, 0x35, 0x3b, 0xd2, 0xaa, 0xb1, 0x75, 0xcd, 0x0e, 0x29, 0x49, 0x7e, 0x22, 0x22, 0xfc,
		0x08, 0xbc, 0x74, 0x44, 0x1e, 0x74, 0x04, 0xe8, 0x08, 0xd0, 0x11, 0xa0, 0x23, 0xf4, 0xa1, 0x23,
		0xb8, 0xd4, 0x7f, 0x30, 0xe1, 0xbc, 0x47, 0xb4, 0xcf, 0x4d, 0x82, 0xac, 0x69, 0x8c, 0xe7, 0x47,
		0x60, 0x16, 0x5d, 0x35, 0x97, 0x62, 0xec, 0xe6, 0x40, 0xa5, 0x59, 0xd0, 0xc3, 0x3c, 0xa8, 0x36,
		0x13, 0xda, 0x98, 0x0b, 0x6d, 0xcc, 0x86, 0x36, 0xe6, 0x83, 0xd7, 0x8c, 0x30, 0x9b, 0x93, 0x60,
		0x95, 0x3b, 0x2a, 0x14, 0xfc, 0x81, 0xda, 0x92, 0x66, 0x21, 0xb4, 0x5f, 0x51, 0x53, 0x36, 0x7b,
		0x55, 0xe2, 0x6c, 0x51, 0xa9, 0xec, 0xd9, 0xd8, 0xa5, 0x34, 0x0c, 0x80, 0x51, 0xb4, 0x73, 0x0b,
		0x5e, 0x59, 0x19, 0x70, 0xe1, 0xa2, 0xb5, 0x15, 0xfa, 0xae, 0x00, 0x2d, 0x00, 0x2d, 0x00, 0x2d,
		0x00, 0x2d, 0x2a, 0x40, 0x0b, 0xb7, 0x2f, 0xbc, 0xee, 0x13, 0x0f, 0x85, 0xc2, 0x08, 0xe1, 0x35,
		0xd7, 0x78, 0xf6, 0x24, 0xef, 0x32, 0x19, 0x36, 0xaa, 0xca, 0xe8, 0xe8, 0x60, 0x7c, 0xf4, 0x32,
		0x42, 0xba, 0x18, 0x23, 0xed, 0x8c, 0x92, 0x76, 0xc6, 0x49, 0x3b, 0x23, 0xa5, 0xc6, 0x58, 0x29,
		0x32, 0x5a, 0xea, 0x3d, 0xee, 0x90, 0xde, 0x98, 0x58, 0xb6, 0x9f, 0x2f, 0xab, 0xd4, 0x19, 0x4b,
		0x2b, 0x52, 0x56, 0xf8, 0x08, 0x6a, 0x12, 0x9b, 0x5e, 0xff, 0x52, 0xab, 0x33, 0x0f, 0x54, 0x27,
		0x3e, 0x69, 0x06, 0x2f, 0x42, 0x8f, 0xa3, 0x38, 0x31, 0x2a, 0xf4, 0x3c, 0x1a, 0x24, 0xab, 0x68,
		0xa2, 0x4e, 0xd7, 0x45, 0xd8, 0xfc, 0x01, 0x11, 0xfe, 0x8d, 0x08, 0x97, 0x4b, 0xa5, 0x93, 0x12,
		0xc4, 0x58, 0x2f, 0x2c, 0xa2, 0x7e, 0xf6, 0xee, 0x9b, 0x6c, 0xbc, 0xaf, 0x8a, 0xfc, 0x4e, 0x75,
		0x37, 0xe9, 0x9b, 0x69, 0x03, 0x05, 0x37, 0xea, 0xe0, 0x0d, 0xc0, 0x1b, 0x80, 0x37, 0x00, 0x6f,
		0x00, 0xde, 0x20, 0x25, 0xbc, 0xc1, 0x07, 0x0d, 0x68, 0x83, 0x12, 0x68, 0x03, 0xd0, 0x06, 0xa0,
		0x0d, 0x40, 0x1b, 0x80, 0x36, 0x90, 0x2e, 0xc2, 0x85, 0x12, 0x48, 0x03, 0x90, 0x06, 0x20, 0x0d,
		0x78, 0x49, 0x83, 0x87, 0xe5, 0xe9, 0xd3, 0x81, 0x35, 0x58, 0x3c, 0x0b, 0x68, 0x03, 0xd0, 0x06,
		0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0x00, 0x6d, 0xb0, 0xa7, 0xde, 0xb8, 0xb5, 0x6c, 0xd3, 0x7d,
		0xd4, 0x80, 0x37, 0x38, 0x55, 0xf8, 0x08, 0x17, 0xc2, 0xbe, 0x9f, 0x07, 0xfe, 0x83, 0x38, 0x00,
		0x71, 0xf0, 0x5b, 0xaf, 0x2b, 0x0f, 0x9f, 0x0b, 0xc4, 0x41, 0xb2, 0x45, 0x18, 0xf1, 0x06, 0xa0,
		0x0e, 0x40, 0x1d, 0xb0, 0x8a, 0xb9, 0xf8, 0xe1, 0x0b, 0x7b, 0xc0, 0xd8, 0xdf, 0x73, 0x2b, 0xe4,
		0x0b, 0x9e, 0x04, 0xb4, 0x01, 0x68, 0x03, 0xd0, 0x06, 0xa0, 0x0d, 0x40, 0x1b, 0x80, 0x36, 0xd8,
		0x97, 0x36, 0x60, 0xaf, 0x86, 0xbb, 0xcd, 0x8c, 0x30, 0x55, 0xc7, 0xcd, 0x26, 0x68, 0x71, 0xc6,
		0x33, 0x64, 0x6e, 0x0e, 0xd5, 0x83, 0x96, 0xe0, 0x49, 0x00, 0x5a, 0x00, 0x5a, 0x00, 0x5a, 0x00,
		0x5a, 0x00, 0x5a, 0x00, 0x5a, 0x00, 0x5a, 0x00, 0x5a, 0xc2, 0x6b, 0x3c, 0x36, 0x5d, 0xdf, 0xd2,
		0x01, 0xb3, 0xac, 0x1e, 0x04, 0x90, 0x05, 0x90, 0x05, 0x90, 0x05, 0x90, 0x05, 0x90, 0x05, 0x90,
		0x05, 0x90, 0x05, 0x90, 0x25, 0xbc, 0xc6, 0xbe, 0x6b, 0xda, 0x9e, 0xe5, 0x5b, 0x0f, 0x1a, 0xc4,
		0x95, 0xbe, 0x78, 0x16, 0x00, 0x17, 0x00, 0x17, 0x00, 0x17, 0x00, 0x17, 0x00, 0x17, 0x00, 0x17,
		0x00, 0x17, 0xed, 0x81, 0x4b, 0xaa, 0xcb, 0x8b, 0x32, 0xb7, 0x5f, 0x0c, 0xcd, 0xaf, 0xae, 0x1d,
		0x63, 0xb8, 0x3f, 0x5e, 0xf8, 0xaf, 0x8e, 0x54, 0x14, 0xb7, 0x3e, 0x50, 0xd2, 0xc3, 0xf1, 0x7a,
		0xf1, 0xee, 0xd5, 0x60, 0x35, 0x42, 0x7f, 0xc3, 0xd1, 0xe6, 0x51, 0xdd, 0xe1, 0x4b, 0x57, 0x07,
		0x9d, 0x7f, 0x8b, 0x47, 0x15, 0x25, 0x70, 0x72, 0x17, 0x96, 0xe7, 0xcf, 0x04, 0x86, 0xb7, 0x7d,
		0xcf, 0xa5, 0x65, 0xd7, 0x86, 0x62, 0x86, 0x8f, 0x3c, 0x5e, 0xff, 0x22, 0x77, 0x69, 0xfe, 0x78,
		0x31, 0x73, 0xfe, 0x43, 0xb1, 0x58, 0xae, 0x14, 0x8b, 0xc7, 0x95, 0x93, 0xca, 0xf1, 0x69, 0xa9,
		0x94, 0x2f, 0xe7, 0x19, 0xc3, 0x81, 0x73, 0x0d, 0x77, 0x20, 0x5c, 0x31, 0xf8, 0x34, 0xdb, 0x7a,
		0x7b, 0x32, 0x1c, 0xa6, 0x4a, 0xa2, 0x15, 0x19, 0x2a, 0xcd, 0x0d, 0x54, 0x8e, 0xb5, 0xcf, 0x84,
		0x76, 0x26, 0x29, 0x87, 0x16, 0xde, 0xea, 0x8f, 0x68, 0x86, 0x5a, 0x78, 0xb3, 0xf7, 0x54, 0xd6,
		0xe4, 0xe0, 0x25, 0xb6, 0xb7, 0xf7, 0x9b, 0x04, 0x9d, 0xa7, 0x15, 0x68, 0x9b, 0x09, 0xb6, 0x61,
		0x0d, 0x0e, 0x84, 0x3d, 0x18, 0x3b, 0x96, 0xed, 0x1f, 0xf4, 0x9d, 0xa1, 0xe3, 0x4a, 0x12, 0x34,
		0x1e, 0xc4, 0xc6, 0x87, 0xd0, 0x94, 0x22, 0x32, 0x1e, 0x04, 0x26, 0x4b, 0xfc, 0x98, 0xd4, 0xb8,
		0x3a, 0xf5, 0x2d, 0x51, 0x57, 0xb3, 0xeb, 0x68, 0x39, 0x1a, 0x99, 0x5e, 0x5f, 0xd2, 0x8e, 0x48,
		0x2c, 0xfa, 0xb2, 0x45, 0x5e, 0x85, 0xa8, 0x4b, 0x10, 0x72, 0x46, 0xe1, 0xa6, 0x15, 0x6b, 0x3a,
		0xe1, 0xa3, 0x19, 0x89, 0x48, 0x7c, 0x65, 0x89, 0x2d, 0xab, 0xb8, 0x12, 0xca, 0x29, 0x87, 0x7c,
		0xd2, 0x08, 0x66, 0x7c, 0x31, 0x22, 0x10, 0xa1, 0xdc, 0x6a, 0x4b, 0x0c, 0x73, 0x30, 0x70, 0x85,
		0xe7, 0x91, 0x09, 0x51, 0x70, 0x4d, 0x15, 0x9a, 0x81, 0x48, 0xf0, 0x69, 0x43, 0x18, 0xc8, 0x43,
		0x12, 0x64, 0x84, 0x18, 0xc8, 0x0d, 0x19, 0x90, 0x15, 0x02, 0x20, 0xfd, 0x4a, 0x5f, 0xfa, 0x15,
		0xbd, 0xf4, 0x2b, 0x77, 0xbd, 0x4c, 0x0a, 0xf9, 0x15, 0xb7, 0xc4, 0x9e, 0xc7, 0x32, 0x7a, 0x19,
		0x87, 0x7b, 0x14, 0x87, 0x74, 0x58, 0x8a, 0x2c, 0x00, 0x6d, 0xcb, 0x60, 0x29, 0xad, 0x80, 0x89,
		0x5b, 0xfc, 0x42, 0xd7, 0x43, 0xd7, 0x43, 0xd7, 0x2f, 0xde, 0x96, 0xba, 0xa5, 0xac, 0x3c, 0x40,
		0xc9, 0x05, 0x2c, 0x25, 0x01, 0x4c, 0x69, 0xca, 0x47, 0xa6, 0x12, 0xe2, 0x51, 0x46, 0xb2, 0x95,
		0x12, 0x9b, 0x72, 0x62, 0x53, 0x52, 0x6c, 0xca, 0x2a, 0x19, 0xd4, 0x9d, 0xb4, 0x98, 0xcc, 0x40,
		0xee, 0xad, 0xb1, 0x24, 0x2d, 0xb3, 0x06, 0x6f, 0x24, 0x14, 0xe8, 0x5c, 0xad, 0x8d, 0x9c, 0xb2,
		0x9b, 0x12, 0x6f, 0x06, 0x9e, 0x57, 0xfe, 0xa1, 0x28, 0x71, 0xed, 0x43, 0x7b, 0xf0, 0x41, 0xe2,
		0x1c, 0x4d, 0xd3, 0xf7, 0x85, 0x6b, 0x4b, 0xaf, 0x82, 0x9a, 0x7b, 0xfb, 0xf6, 0xe6, 0xd8, 0x38,
		0xed, 0x3e, 0xdd, 0xe4, 0x8d, 0xd3, 0xee, 0xe2, 0x63, 0x7e, 0xfe, 0xc7, 0xe2, 0x73, 0xe1, 0xe6,
		0xd8, 0x28, 0xae, 0x3e, 0x97, 0x6e, 0x8e, 0x8d, 0x52, 0xf7, 0xf0, 0xdb, 0xb7, 0xf7, 0x87, 0x3f,
		0x4f, 0xa6, 0xfb, 0x7f, 0x51, 0xde, 0x7d, 0x70, 0x57, 0xe6, 0x56, 0x34, 0xda, 0xf5, 0x3f, 0xd9,
		0xf6, 0xe3, 0x2f, 0xce, 0x0d, 0xf9, 0x97, 0xc4, 0x1d, 0x49, 0xd2, 0x25, 0x26, 0x8f, 0x72, 0x2a,
		0x43, 0x39, 0x45, 0x52, 0x4e, 0xa6, 0x71, 0x57, 0x35, 0x3e, 0x77, 0x7f, 0xe6, 0xdf, 0x15, 0xa7,
		0x1f, 0x0f, 0x7f, 0x56, 0xa6, 0xaf, 0xff, 0xf2, 0x69, 0xd3, 0x8f, 0xe5, 0xdf, 0x55, 0xa6, 0x1f,
		0xb7, 0xfc, 0x4b, 0x79, 0xfa, 0x71, 0xc7, 0x31, 0x4a, 0xd3, 0xb7, 0xa1, 0x1f, 0x9d, 0xfd, 0x7d,
		0x61, 0xdb, 0x17, 0x8a, 0x5b, 0xbe, 0x70, 0xb2, 0xed, 0x0b, 0x27, 0x5b, 0xbe, 0xb0, 0xf5, 0x91,
		0x0a, 0x5b, 0xbe, 0x50, 0x9a, 0x3e, 0x85, 0x7e, 0xfe, 0xed, 0xe6, 0x1f, 0x2d, 0x4f, 0x0f, 0x9f,
		0xb6, 0xfd, 0x5b, 0x65, 0xfa, 0xf4, 0xf1, 0x10, 0xaa, 0x7a, 0x77, 0x55, 0x0d, 0xf1, 0xe4, 0x17,
		0xcf, 0xe4, 0x19, 0xae, 0x37, 0x7a, 0x3f, 0x27, 0xee, 0xbc, 0xf7, 0x1b, 0x57, 0xea, 0x9d, 0x37,
		0x75, 0xfa, 0x90, 0xac, 0x9b, 0x6e, 0xc2, 0xcc, 0x1e, 0x82, 0x0b, 0x8e, 0x37, 0x0a, 0xe5, 0x6d,
		0x15, 0x84, 0x49, 0x4c, 0x34, 0xd2, 0x86, 0x59, 0xd2, 0x87, 0x53, 0xb2, 0x84, 0x4d, 0xd2, 0x86,
		0x47, 0xc6, 0xdd, 0x68, 0x62, 0x85, 0x22, 0x55, 0x91, 0xe4, 0x48, 0xee, 0xfc, 0x64, 0xa8, 0x8e,
		0x78, 0x4a, 0x23, 0xfa, 0x51, 0x8f, 0xf6, 0xcd, 0x88, 0x32, 0x43, 0x25, 0x2b, 0x32, 0x64, 0x24,
		0x86, 0x68, 0xd0, 0x8a, 0x44, 0x34, 0x49, 0xd8, 0x7f, 0x1f, 0xf7, 0xfb, 0xc6, 0x9e, 0x3b, 0x1e,
		0x77, 0xa7, 0xe9, 0x76, 0x38, 0xc2, 0xbe, 0x52, 0xec, 0xe7, 0x7e, 0xbb, 0xb8, 0xfb, 0x5e, 0xec,
		0xb1, 0x0f, 0x0b, 0xfa, 0x77, 0x62, 0x5b, 0x7d, 0xd3, 0xf3, 0xf7, 0xde, 0x85, 0x75, 0x12, 0x79,
		0x35, 0xca, 0x9e, 0x52, 0x10, 0x2d, 0xf6, 0x20, 0xf2, 0x35, 0x5f, 0x9c, 0x6b, 0x3c, 0x9a, 0x6b,
		0xba, 0xb8, 0xd7, 0x70, 0x64, 0xd7, 0x6c, 0x64, 0xd7, 0x68, 0x64, 0xd7, 0x64, 0x72, 0xf5, 0x4d,
		0xd4, 0xbb, 0xf8, 0xdc, 0x70, 0xf1, 0x4e, 0xd1, 0x77, 0x2c, 0x88, 0xcf, 0x5a, 0x0e, 0x14, 0x71,
		0x99, 0xe3, 0x85, 0xe9, 0x3c, 0x1f, 0x99, 0x42, 0xc4, 0x01, 0x08, 0x6e, 0xc0, 0x69, 0x6f, 0xba,
		0xa9, 0x6e, 0xb4, 0xc9, 0x6f, 0xae, 0xc9, 0x6f, 0xa8, 0xc9, 0x6f, 0xa2, 0x79, 0x41, 0x5d, 0xdc,
		0x30, 0x98, 0xdc, 0x32, 0xe1, 0x22, 0xf6, 0x46, 0xaf, 0xc4, 0x8f, 0x24, 0x81, 0x83, 0x28, 0x6e,
		0x8e, 0x2c, 0x64, 0x85, 0x32, 0x44, 0x45, 0x4e, 0x48, 0x0a, 0x75, 0x08, 0x8a, 0xb4, 0x90, 0x13,
		0x69, 0x21, 0x26, 0xd2, 0x42, 0x4a, 0xd4, 0x52, 0x39, 0x54, 0x71, 0x6e, 0x8b, 0x83, 0x49, 0x1f,
		0x2e, 0x4b, 0x99, 0x94, 0x88, 0x70, 0x59, 0x84, 0xcb, 0xca, 0x56, 0x13, 0xd2, 0xd5, 0x05, 0x1d,
		0x87, 0x7c, 0xa0, 0x73, 0xb8, 0xac, 0xe3, 0x5a, 0xf7, 0x12, 0x1a, 0x02, 0x3f, 0x1f, 0x87, 0xc5,
		0xf8, 0x08, 0x8d, 0x45, 0x68, 0xac, 0x52, 0x45, 0xc4, 0xa6, 0x90, 0xd8, 0x14, 0x13, 0xad, 0x82,
		0x22, 0x56, 0x54, 0xc1, 0x2a, 0xc8, 0x0f, 0x8d, 0xa5, 0xcf, 0xe9, 0x0a, 0xe1, 0x98, 0x8a, 0x84,
		0xb1, 0x43, 0x39, 0x5e, 0x4b, 0x4d, 0xa9, 0xeb, 0x05, 0x3c, 0x21, 0x98, 0x59, 0x16, 0x95, 0x91,
		0x67, 0x74, 0x56, 0x13, 0xc0, 0xea, 0xc0, 0xea, 0xc0, 0xea, 0xc0, 0xea, 0xc0, 0xea, 0x6c, 0xb5,
		0x3a, 0x2b, 0x55, 0x99, 0x05, 0xb3, 0x23, 0x47, 0x1d, 0x3e, 0x5b, 0x1d, 0x29, 0x0e, 0x34, 0x8c,
		0x0e, 0x8c, 0x0e, 0x8c, 0x0e, 0x8c, 0x4e, 0xaa, 0x8c, 0xce, 0x42, 0xec, 0x33, 0x60, 0x73, 0x68,
		0x8b, 0x5b, 0x84, 0x04, 0x42, 0x46, 0x4b, 0x00, 0x62, 0xf6, 0x1e, 0x16, 0x07, 0x16, 0x07, 0x16,
		0x47, 0x8e, 0xc5, 0xa1, 0xbe, 0x0d, 0x08, 0x06, 0x9e, 0xf7, 0x6a, 0xb0, 0xec, 0x81, 0x90, 0xd7,
		0xa2, 0x2c, 0x38, 0x5a, 0x2f, 0xe6, 0x92, 0x55, 0xcb, 0x58, 0x6a, 0xb3, 0x39, 0xe9, 0xcd, 0xe4,
		0x38, 0x9a, 0xc5, 0xf1, 0x36, 0x83, 0xe3, 0x6a, 0xf6, 0xc6, 0xde, 0xcc, 0x8d, 0xbd, 0x59, 0x1b,
		0x7b, 0x33, 0xb6, 0x64, 0x55, 0x31, 0x97, 0xde, 0x2c, 0x8d, 0x01, 0x9a, 0x73, 0x40, 0xf4, 0x4d,
		0x50, 0x7d, 0xe3, 0x7f, 0x73, 0x65, 0xed, 0x09, 0xdf, 0x0b, 0x3e, 0x2d, 0x21, 0xfd, 0x42, 0x81,
		0x27, 0xa5, 0x10, 0xb4, 0x04, 0x0c, 0xd7, 0x77, 0x46, 0xa3, 0x89, 0x6d, 0xf9, 0x8f, 0x5c, 0x76,
		0xf3, 0xf5, 0x84, 0x30, 0x9e, 0x30, 0x9e, 0x30, 0x9e, 0x30, 0x9e, 0x30, 0x9e, 0xba, 0x1a, 0xcf,
		0x95, 0xc6, 0xb6, 0x84, 0x17, 0x7c, 0x7e, 0x84, 0xfd, 0x5c, 0x2c, 0x9e, 0xf8, 0xe1, 0x1b, 0xec,
		0x36, 0x74, 0xd3, 0xa4, 0xb0, 0xa3, 0xb0, 0xa3, 0xb0, 0xa3, 0xb0, 0xa3, 0xb0, 0xa3, 0xba, 0xda,
		0xd1, 0x97, 0x5a, 0x7b, 0x66, 0x4b, 0xd7, 0xb4, 0x38, 0xec, 0xe9, 0x62, 0x11, 0x2d, 0xfb, 0xc1,
		0x1c, 0x5a, 0x03, 0xc3, 0x15, 0xa6, 0x27, 0xb1, 0x8b, 0xd6, 0x73, 0x8a, 0xf3, 0xfa, 0x7c, 0xb0,
		0xa2, 0xb0, 0xa2, 0xb0, 0xa2, 0xb0, 0xa2, 0x09, 0xb4, 0xa2, 0xd6, 0x40, 0xd8, 0xbe, 0xe5, 0x3f,
		0x32, 0x59, 0x52, 0x99, 0x3d, 0x20, 0xeb, 0xcb, 0x57, 0xf9, 0x64, 0x7a, 0x0c, 0x47, 0x74, 0xb5,
		0x80, 0xf5, 0xab, 0xaf, 0xd5, 0x8b, 0xfa, 0x79, 0xaf, 0xd5, 0xb8, 0xee, 0xd4, 0x7a, 0xad, 0x5a,
		0xb5, 0xdd, 0xb8, 0x92, 0x7d, 0x5a, 0xbf, 0x9a, 0xc3, 0xc9, 0x3c, 0xff, 0xf9, 0x46, 0x7a, 0x0f,
		0x5c, 0x9e, 0x86, 0xdf, 0xa1, 0xd5, 0x3c, 0xbb, 0xb8, 0x6e, 0x77, 0x6a, 0xad, 0xde, 0x45, 0xa3,
		0xd1, 0x94, 0xdf, 0x6b, 0x9a, 0xa1, 0x95, 0xba, 0xa2, 0x75, 0x6c, 0xb4, 0xea, 0x5f, 0xea, 0x57,
		0xd5, 0x4e, 0xa3, 0x85, 0x55, 0x8c, 0xbe, 0x8a, 0xd5, 0x36, 0x04, 0x31, 0xee, 0x81, 0x6e, 0x5c,
		0x7d, 0xae, 0x9d, 0xe7, 0x12, 0xde, 0xd0, 0xbd, 0x9b, 0x34, 0x7c, 0x92, 0x08, 0xef, 0x6d, 0x68,
		0x7a, 0xbe, 0x31, 0x72, 0x06, 0xd6, 0x9d, 0x25, 0x06, 0xf2, 0x9d, 0xb7, 0xf5, 0xe9, 0xe0, 0xbb,
		0xc1, 0x77, 0x83, 0xef, 0x06, 0xdf, 0x2d, 0x81, 0xbe, 0x9b, 0x6f, 0x8d, 0x84, 0x6f, 0xf5, 0xff,
		0xf6, 0xca, 0x45, 0x06, 0xdf, 0x4d, 0x66, 0x3b, 0x84, 0x6b, 0xdb, 0x9a, 0x97, 0xbf, 0xcd, 0xd9,
		0xa6, 0xed, 0x78, 0xa2, 0xef, 0xd8, 0x03, 0xa9, 0x2d, 0x1e, 0x5a, 0xa6, 0x7d, 0x2f, 0xa4, 0xfb,
		0x4f, 0xf2, 0xa1, 0x56, 0xee, 0xd2, 0xb2, 0xa5, 0x6b, 0x34, 0x26, 0x9b, 0xb6, 0xd9, 0xcb, 0x65,
		0x9c, 0xef, 0xb3, 0x6b, 0xf6, 0x7d, 0xcb, 0xb1, 0xcf, 0xad, 0xfb, 0x85, 0x34, 0x1e, 0xa7, 0x01,
		0xef, 0xe7, 0x2e, 0xcd, 0x1f, 0xa9, 0x17, 0x11, 0x39, 0x65, 0xb3, 0xb5, 0x95, 0x9a, 0x37, 0xc9,
		0x1c, 0xbd, 0x9b, 0x61, 0x1f, 0x47, 0x52, 0xe9, 0xa1, 0x30, 0x96, 0x96, 0x51, 0x82, 0x08, 0x5e,
		0x0d, 0xbc, 0x1a, 0x78, 0x35, 0xf0, 0x6a, 0x58, 0xce, 0xcd, 0xc4, 0xb6, 0xa4, 0x5d, 0xa9, 0x1f,
		0x48, 0x6e, 0x00, 0xfa, 0x7a, 0xb9, 0x12, 0xef, 0x5f, 0xb0, 0xb4, 0x64, 0x55, 0xb1, 0x43, 0xbc,
		0x3b, 0xc5, 0xb7, 0x63, 0x1b, 0x76, 0x8e, 0xa5, 0xa5, 0xeb, 0xd6, 0x3d, 0xfc, 0xc0, 0x38, 0x27,
		0x57, 0xdf, 0xba, 0xd0, 0xc4, 0xe9, 0x68, 0x01, 0x1b, 0xc2, 0xeb, 0x9c, 0x5b, 0xc7, 0xd9, 0x77,
		0x30, 0x34, 0x7b, 0x5a, 0x5a, 0xc6, 0xf2, 0x78, 0x5c, 0x0a, 0x58, 0x0c, 0x75, 0xca, 0xb3, 0x0c,
		0xe5, 0xc9, 0xa2, 0x3c, 0xd1, 0x03, 0x34, 0x4d, 0x2d, 0x6a, 0x33, 0x6f, 0x4a, 0x20, 0xce, 0xa9,
		0x6a, 0x69, 0xab, 0xc8, 0xb0, 0xbe, 0x49, 0xf6, 0x7b, 0x48, 0x06, 0x06, 0x9c, 0xfe, 0x2f, 0x4b,
		0x98, 0x6c, 0xc8, 0xfe, 0x33, 0x5c, 0x62, 0xf0, 0x86, 0xcd, 0x86, 0x16, 0xb6, 0x7e, 0xd5, 0xee,
		0x54, 0x2f, 0x2e, 0x7a, 0xcd, 0x56, 0xa3, 0xd3, 0x38, 0x6b, 0x5c, 0xf4, 0x3a, 0xff, 0x6d, 0xd6,
		0x72, 0x9c, 0xd7, 0x47, 0x1e, 0xab, 0x8d, 0xf8, 0xc9, 0x6b, 0x8d, 0x56, 0xcb, 0x7c, 0x5e, 0x6f,
		0xd5, 0xce, 0x3a, 0x17, 0xff, 0xed, 0x9d, 0x35, 0xae, 0xae, 0x6a, 0x67, 0x1d, 0x8e, 0x50, 0x3c,
		0x66, 0xf7, 0x40, 0xe1, 0xea, 0x7e, 0xfa, 0xd2, 0xc4, 0x72, 0x12, 0xea, 0x84, 0x2f, 0x97, 0x58,
		0x4f, 0xc2, 0xf5, 0x6c, 0xd6, 0x2f, 0xb1, 0x9c, 0x74, 0xcb, 0xd9, 0xee, 0x54, 0x3b, 0xf5, 0x33,
		0xac, 0x28, 0xdd, 0x8a, 0x36, 0xda, 0xcd, 0xcf, 0x58, 0x4f, 0xda, 0xf5, 0x3c, 0xc1, 0x82, 0x12,
		0x5a, 0xa4, 0x76, 0xbd, 0x8d, 0xf5, 0xa4, 0x5b, 0xcf, 0x8b, 0xc6, 0x59, 0xf5, 0xa2, 0x57, 0xfd,
		0xf2, 0xa5, 0x55, 0xfb, 0x52, 0xed, 0xd4, 0x18, 0x97, 0xf6, 0x4d, 0x3a, 0xd8, 0x01, 0x84, 0x80,
		0xc9, 0x7d, 0x5e, 0x19, 0x21, 0x60, 0xb2, 0x3a, 0x01, 0x85, 0x4e, 0x97, 0x9c, 0x8e, 0x40, 0xc1,
		0x34, 0xe7, 0xe2, 0xce, 0x9c, 0x0c, 0xe7, 0x71, 0x32, 0xc7, 0x08, 0x34, 0xdb, 0x3c, 0x01, 0x02,
		0xcd, 0x22, 0xef, 0x3c, 0x02, 0xcd, 0x12, 0xa1, 0xcd, 0x53, 0x10, 0x68, 0x66, 0xd9, 0xfe, 0x49,
		0x81, 0x21, 0xd2, 0xac, 0x82, 0x4c, 0x96, 0xdf, 0xbf, 0x08, 0x32, 0x59, 0xe8, 0xe6, 0x43, 0x26,
		0x4b, 0x62, 0x45, 0xa4, 0x58, 0x38, 0x2d, 0x9e, 0x96, 0x2b, 0x85, 0x53, 0xe4, 0xaf, 0xc0, 0x79,
		0xd1, 0xc9, 0x79, 0x91, 0x0b, 0x68, 0xe5, 0xf6, 0x95, 0x83, 0x5b, 0x01, 0xb7, 0x02, 0x6e, 0x05,
		0xdc, 0x0a, 0x9e, 0x8a, 0x6a, 0xe3, 0x87, 0xa2, 0x21, 0x5d, 0xc6, 0x38, 0x42, 0x44, 0xd9, 0x42,
		0x42, 0x59, 0xe3, 0xe7, 0x8f, 0x96, 0x93, 0x1d, 0x3e, 0xbd, 0xbd, 0xc9, 0x1b, 0x85, 0xee, 0xea,
		0xff, 0x9c, 0xdc, 0x1c, 0x1b, 0x85, 0xae, 0xcc, 0xa0, 0xc8, 0xae, 0xcc, 0xad, 0xe2, 0x0c, 0x7a,
		0xe4, 0x8d, 0x97, 0xff, 0xdd, 0x86, 0x49, 0x0c, 0xfb, 0xcb, 0x32, 0xe2, 0x5b, 0x56, 0xb8, 0x75,
		0x26, 0xbe, 0x90, 0x0f, 0xfb, 0x5e, 0x4e, 0x06, 0xec, 0x07, 0xec, 0x07, 0xec, 0x07, 0xec, 0x97,
		0x40, 0xec, 0x77, 0xeb, 0x38, 0x43, 0x61, 0xb2, 0x64, 0x2f, 0xe7, 0x93, 0x62, 0x9a, 0xb4, 0x6e,
		0x2a, 0x5a, 0xb5, 0x6d, 0xc7, 0x37, 0x7d, 0x4b, 0x52, 0xd1, 0xf8, 0x9c, 0xd7, 0xff, 0x2e, 0x46,
		0xe6, 0x78, 0x59, 0xe3, 0xff, 0xc8, 0x19, 0x0b, 0xbb, 0x3f, 0x37, 0x14, 0xb3, 0xf3, 0x79, 0x34,
		0xfb, 0xed, 0x5a, 0xb7, 0x47, 0xe6, 0x9d, 0x65, 0x78, 0xe6, 0x9d, 0xe5, 0x05, 0x9f, 0x8e, 0xe6,
		0x5e, 0xc4, 0xc4, 0xb6, 0xfa, 0xa6, 0xe7, 0x1f, 0x0d, 0x17, 0x67, 0xfa, 0x68, 0x6e, 0x1f, 0xbd,
		0xc5, 0x1f, 0x47, 0x32, 0xda, 0x21, 0x2f, 0x9e, 0xd9, 0x77, 0x27, 0x7d, 0xdf, 0x5e, 0xc5, 0x12,
		0x05, 0x8f, 0xfc, 0xe9, 0x7e, 0xdc, 0x9b, 0xfd, 0x6e, 0x59, 0xb7, 0xbd, 0xea, 0x9d, 0xd5, 0x9e,
		0x3d, 0xf0, 0xea, 0x43, 0xaf, 0x3e, 0x7e, 0x28, 0x5e, 0x2f, 0x1e, 0xb7, 0x77, 0xe1, 0xf4, 0x67,
		0x3f, 0xd3, 0x9a, 0x3f, 0xed, 0xe2, 0x8f, 0x5e, 0x7b, 0xfe, 0xb4, 0x19, 0x68, 0x82, 0x3d, 0xb1,
		0xff, 0xb6, 0x9d, 0x7f, 0x6c, 0xc3, 0xf4, 0x7d, 0xd7, 0xba, 0x9d, 0xad, 0x80, 0xbc, 0x8e, 0xd8,
		0x1b, 0xe6, 0x42, 0x7b, 0x6c, 0xb4, 0xc7, 0xd6, 0x02, 0x0c, 0xa1, 0x3d, 0x36, 0xaf, 0x25, 0x93,
		0xd6, 0x1e, 0x3b, 0xa4, 0x64, 0xe4, 0x7b, 0x83, 0xe1, 0x29, 0xe5, 0xfa, 0x84, 0x79, 0xf8, 0x84,
		0xf0, 0x09, 0xe1, 0x13, 0x66, 0xc9, 0x27, 0x94, 0xa5, 0x2e, 0x83, 0x09, 0xe6, 0x2d, 0xa3, 0x7d,
		0xd9, 0x9e, 0xe7, 0xda, 0x09, 0x7d, 0x9e, 0x52, 0xb2, 0x68, 0xf1, 0xc4, 0x46, 0x48, 0x57, 0x9f,
		0x9c, 0x6a, 0x54, 0x8d, 0x3a, 0xe5, 0x56, 0xab, 0xca, 0xd4, 0xab, 0x32, 0x35, 0xab, 0x4c, 0xdd,
		0xca, 0x55, 0xbb, 0x92, 0xd5, 0x2f, 0x1f, 0x35, 0x17, 0x3a, 0x77, 0xf2, 0xdb, 0x46, 0x86, 0xd0,
		0x65, 0x85, 0x61, 0xae, 0x17, 0x6d, 0x24, 0x17, 0x3d, 0x21, 0x9f, 0x8d, 0x41, 0x42, 0xa3, 0xad,
		0x24, 0x8a, 0x5e, 0x6e, 0xc1, 0x9d, 0xb1, 0x19, 0x66, 0x59, 0x54, 0x1d, 0xa3, 0x2f, 0x03, 0xa3,
		0xfc, 0xff, 0xb3, 0x77, 0x75, 0x3d, 0x8d, 0x1c, 0x4d, 0xf7, 0x9e, 0x5f, 0x81, 0x46, 0xb9, 0x00,
		0x69, 0x67, 0xfd, 0x81, 0x3f, 0xf0, 0xde, 0x79, 0xb3, 0x6c, 0x64, 0x05, 0x30, 0x32, 0x10, 0xe5,
		0x15, 0x71, 0xac, 0xc1, 0x6e, 0x48, 0x67, 0x4d, 0x8f, 0x35, 0xd3, 0x26, 0xa0, 0x85, 0xff, 0xfe,
		0xca, 0x1e, 0x7b, 0xc0, 0x8c, 0xfd, 0xec, 0x02, 0xdd, 0x55, 0xed, 0xf1, 0x59, 0x2d, 0xc1, 0x61,
		0xb1, 0x7b, 0xa6, 0xa7, 0xba, 0xce, 0x39, 0xd5, 0xd5, 0x55, 0x00, 0x65, 0x80, 0xf2, 0x66, 0x80,
		0xb2, 0x6d, 0x6d, 0xb4, 0xa8, 0x91, 0x86, 0x42, 0xd1, 0x97, 0x9d, 0x49, 0x47, 0xfe, 0x90, 0xcb,
		0x6c, 0x72, 0x2a, 0x27, 0xcd, 0xe1, 0xac, 0x79, 0x9d, 0x36, 0x97, 0xf3, 0x66, 0x77, 0xe2, 0xec,
		0xce, 0x9c, 0xdd, 0xa9, 0xd3, 0x38, 0x77, 0x22, 0x27, 0x4f, 0xaf, 0xc0, 0x32, 0xeb, 0x76, 0x2c,
		0x95, 0x2e, 0xd5, 0x18, 0xca, 0xaa, 0xd6, 0x08, 0x87, 0xa4, 0x39, 0x9f, 0xf7, 0xf2, 0x0f, 0xad,
		0x4f, 0xda, 0xa6, 0x3e, 0xbf, 0xc7, 0x0c, 0xaf, 0x99, 0xe1, 0x89, 0xcf, 0xf7, 0x65, 0xc6, 0x67,
		0x38, 0xc3, 0xc5, 0xe4, 0xae, 0x16, 0x4d, 0x2e, 0xb8, 0xdb, 0x78, 0x93, 0xab, 0x55, 0xab, 0x7b,
		0xd5, 0x0d, 0x36, 0xbb, 0xad, 0x7c, 0x8e, 0x96, 0x97, 0xfa, 0xb2, 0x14, 0xc7, 0x82, 0xe9, 0x76,
		0xda, 0x96, 0xcb, 0x48, 0x82, 0x1d, 0x37, 0xe8, 0x48, 0xe8, 0x48, 0xe8, 0x48, 0xe8, 0x48, 0xe8,
		0xc8, 0x15, 0x3a, 0x72, 0x9f, 0x41, 0x46, 0x56, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23,
		0x73, 0x60, 0x72, 0xe5, 0x2a, 0x44, 0x24, 0x44, 0xe4, 0xa6, 0x8b, 0xc8, 0xdb, 0xd9, 0x6a, 0xe0,
		0x50, 0x91, 0xc9, 0xd8, 0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0xe4, 0xeb,
		0xf6, 0x52, 0xaa, 0x20, 0xba, 0x67, 0xd0, 0x91, 0x0d, 0xc2, 0x21, 0x0f, 0x85, 0xba, 0x9e, 0x26,
		0x8a, 0x42, 0x48, 0x6e, 0x00, 0xab, 0x2f, 0x41, 0x48, 0x42, 0x48, 0xd2, 0x9a, 0x1c, 0xf6, 0x23,
		0x21, 0x25, 0x37, 0x5c, 0x4a, 0x8a, 0x3b, 0x2d, 0xd4, 0x40, 0x0c, 0xe8, 0x85, 0x64, 0x3a, 0x32,
		0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0xbd, 0x8c, 0xb4, 0x5e, 0x02, 0x6c,
		0x95, 0x1b, 0xb6, 0x54, 0x12, 0x2c, 0x9f, 0x20, 0x1d, 0x8e, 0x26, 0x4c, 0x31, 0x18, 0xd2, 0x83,
		0x74, 0x3a, 0x32, 0x40, 0x1a, 0x20, 0x0d, 0x90, 0x06, 0x48, 0x03, 0xa4, 0x01, 0xd2, 0x00, 0xe9,
		0x65, 0x73, 0x36, 0x0a, 0x22, 0x2d, 0x39, 0x30, 0x7a, 0x3e, 0x30, 0x20, 0x1a, 0x10, 0x0d, 0x88,
		0x06, 0x44, 0x03, 0xa2, 0x01, 0xd1, 0x80, 0xe8, 0x65, 0x73, 0xa6, 0xa3, 0x40, 0xc5, 0x52, 0xcb,
		0x5b, 0x86, 0xbc, 0xa9, 0x67, 0x63, 0x03, 0xa8, 0x01, 0xd4, 0x00, 0x6a, 0x00, 0x35, 0x80, 0x1a,
		0x40, 0xbd, 0x86, 0x40, 0xbd, 0xd6, 0xe5, 0xa2, 0x2c, 0xf7, 0xd0, 0xc8, 0x8c, 0x67, 0xb1, 0xa7,
		0x46, 0xb6, 0xa1, 0x42, 0xf6, 0x47, 0x05, 0x8a, 0x6a, 0x7e, 0xdb, 0xd6, 0x1a, 0x71, 0x9c, 0x27,
		0xf7, 0xd3, 0x4c, 0xef, 0x30, 0xf3, 0x13, 0x1b, 0xbd, 0x3a, 0xe8, 0x2c, 0x7e, 0xbd, 0xca, 0x50,
		0xff, 0x2e, 0xee, 0x29, 0xce, 0x91, 0x7b, 0x87, 0x32, 0xd6, 0x93, 0x07, 0x6c, 0xb7, 0xe6, 0xf5,
		0x91, 0x54, 0x07, 0x43, 0x31, 0x01, 0xf5, 0xd8, 0x2e, 0x69, 0xf5, 0x8e, 0x82, 0xbb, 0x67, 0x23,
		0x95, 0xf6, 0x2b, 0x95, 0x5a, 0xbd, 0x52, 0x29, 0xd6, 0xf7, 0xea, 0xc5, 0x46, 0xb5, 0x5a, 0xaa,
		0x95, 0x2c, 0xe6, 0xa0, 0x79, 0xed, 0x68, 0x20, 0x22, 0x31, 0xf8, 0x3c, 0x79, 0x74, 0x6a, 0x3c,
		0x1c, 0xae, 0x95, 0xc5, 0x11, 0x79, 0x6b, 0x6e, 0x2f, 0xed, 0x59, 0xad, 0x1e, 0xcb, 0xe2, 0x97,
		0x3d, 0x74, 0xfc, 0x72, 0xdf, 0xfe, 0x69, 0xed, 0x7e, 0x6d, 0xda, 0x7f, 0x65, 0xac, 0xdb, 0xd9,
		0x56, 0x60, 0x5b, 0x0e, 0x19, 0xed, 0x9c, 0x1e, 0x24, 0x11, 0x82, 0xed, 0x30, 0x92, 0xd7, 0x52,
		0x6d, 0x4f, 0x6c, 0xcb, 0x97, 0xa6, 0x92, 0x3c, 0xed, 0x50, 0x03, 0x7b, 0x54, 0x80, 0x14, 0xfa,
		0xed, 0x40, 0xbd, 0x29, 0xeb, 0xb0, 0xe4, 0xca, 0x2c, 0xba, 0x30, 0x83, 0xfe, 0xca, 0x8a, 0x9f,
		0x32, 0xe3, 0x95, 0xde, 0xef, 0x43, 0xde, 0xf7, 0x09, 0xef, 0xb4, 0x2f, 0xd3, 0x76, 0x65, 0xc5,
		0x9e, 0x0c, 0x58, 0x92, 0x61, 0x0b, 0x7a, 0x9f, 0xed, 0xbc, 0xfd, 0x89, 0xbf, 0xe3, 0x69, 0x1b,
		0xea, 0x83, 0x60, 0xb4, 0xcf, 0x81, 0xa1, 0x3e, 0x06, 0x4f, 0x7b, 0x27, 0xe5, 0x77, 0x7e, 0x90,
		0xc1, 0x3d, 0x11, 0x3b, 0x7b, 0x1d, 0xa6, 0xf7, 0x30, 0xac, 0xed, 0x4d, 0x58, 0xdb, 0x73, 0xb0,
		0xb6, 0x97, 0x00, 0x3f, 0xbc, 0xda, 0x0f, 0x9b, 0x0a, 0x83, 0x1a, 0x73, 0xc3, 0x06, 0xc2, 0x96,
		0xef, 0xf0, 0xc2, 0x5b, 0x84, 0x16, 0x62, 0xca, 0x32, 0xcc, 0x5a, 0x84, 0xf7, 0x2e, 0x20, 0x32,
		0x62, 0x03, 0x6f, 0x7b, 0xfa, 0xaf, 0x7f, 0x76, 0x6f, 0x78, 0x6e, 0x9e, 0x12, 0xf2, 0xfa, 0x9f,
		0xcb, 0x30, 0x7a, 0x7b, 0x3f, 0xe8, 0x14, 0x3e, 0x9e, 0x3e, 0xea, 0x8d, 0xf6, 0xf3, 0x3e, 0x8c,
		0x7d, 0x37, 0xb6, 0x9a, 0xc0, 0x54, 0xb3, 0x58, 0x6a, 0x0a, 0x43, 0x8d, 0x63, 0xa7, 0x71, 0xcc,
		0x34, 0x8e, 0x95, 0xb4, 0x9e, 0xef, 0xbd, 0xbd, 0x69, 0xd2, 0xb5, 0x63, 0x8e, 0xf5, 0xa6, 0x9f,
		0xe8, 0x18, 0xf1, 0x2d, 0x82, 0xf8, 0x82, 0xf8, 0xae, 0x25, 0xf1, 0x35, 0xd5, 0x80, 0xca, 0x0b,
		0x06, 0xff, 0x4e, 0xe7, 0x44, 0x2a, 0x7f, 0x14, 0xc6, 0xda, 0x9c, 0xa5, 0xa4, 0xa5, 0xdb, 0x5e,
		0x0c, 0x60, 0x2a, 0xee, 0x6b, 0xb4, 0x97, 0x9f, 0xf1, 0x3c, 0x42, 0x1b, 0x79, 0x82, 0x76, 0xf3,
		0x00, 0x6d, 0xe5, 0xf9, 0x59, 0xcf, 0xe3, 0xb3, 0x9e, 0xa7, 0x67, 0x3d, 0x0f, 0xcf, 0xad, 0x1d,
		0x15, 0xd3, 0xbd, 0xed, 0xbc, 0x59, 0x38, 0xd2, 0xb8, 0x61, 0xcd, 0x97, 0x83, 0xb1, 0x70, 0xa7,
		0x45, 0x07, 0x63, 0x3c, 0xe8, 0x46, 0xe1, 0x70, 0x68, 0x1c, 0x8f, 0x6d, 0x07, 0x44, 0xe6, 0x88,
		0xc8, 0x1c, 0x12, 0x99, 0x63, 0x32, 0xeb, 0xa0, 0x0c, 0x3b, 0x2a, 0x6b, 0x0e, 0x6b, 0xd1, 0x71,
		0xd9, 0xb3, 0xc7, 0x05, 0xff, 0x65, 0xcb, 0x16, 0xed, 0xf6, 0x3c, 0xb6, 0x7e, 0xfe, 0x82, 0xe2,
		0xbc, 0x05, 0xed, 0xf9, 0x0a, 0xaa, 0xf3, 0x14, 0xe4, 0xe7, 0x27, 0xc8, 0xcf, 0x4b, 0x90, 0x9f,
		0x8f, 0x58, 0xaf, 0xc4, 0x59, 0xdb, 0x3d, 0x8a, 0xbd, 0x79, 0x96, 0x0d, 0x59, 0x93, 0x78, 0xb3,
		0x69, 0x3d, 0x3f, 0x72, 0x99, 0x45, 0xb4, 0x89, 0x77, 0xdc, 0x95, 0x52, 0xbb, 0x54, 0x36, 0xd7,
		0xca, 0xe6, 0x62, 0xd9, 0x5c, 0xad, 0x5d, 0x97, 0x6b, 0xd9, 0xf5, 0xa6, 0xb3, 0x46, 0x76, 0xe4,
		0x2c, 0x5d, 0x77, 0x43, 0x11, 0x5c, 0x45, 0xe2, 0x8a, 0x62, 0xd1, 0xcd, 0x99, 0x65, 0x9d, 0x60,
		0xac, 0x93, 0xd9, 0xfe, 0xeb, 0xc7, 0x8f, 0xc9, 0xa6, 0x7a, 0x61, 0x0e, 0x05, 0xeb, 0x7a, 0x04,
		0xc7, 0x22, 0xbf, 0x1c, 0xd1, 0xb8, 0xfb, 0x27, 0x54, 0x26, 0x21, 0x97, 0x00, 0x65, 0x80, 0x32,
		0x40, 0x19, 0xa0, 0x0c, 0x50, 0x76, 0x18, 0x94, 0x93, 0x65, 0x07, 0x4c, 0xce, 0x4c, 0x95, 0x99,
		0x2c, 0xe2, 0x9f, 0x36, 0x38, 0x8a, 0xf3, 0xd7, 0x96, 0x23, 0x8b, 0x40, 0x64, 0x20, 0x32, 0x10,
		0x79, 0x33, 0x10, 0xd9, 0x76, 0xa4, 0x32, 0x1d, 0x68, 0x5a, 0x44, 0x40, 0xaa, 0x81, 0xb8, 0x63,
		0x6a, 0x61, 0x98, 0x8c, 0x8d, 0x52, 0x5c, 0xeb, 0xe6, 0xb0, 0x79, 0x1d, 0x37, 0x97, 0x03, 0x67,
		0x77, 0xe4, 0xec, 0x0e, 0x9d, 0xdd, 0xb1, 0xd3, 0x38, 0x78, 0x22, 0x47, 0x4f, 0x2f, 0xc1, 0x18,
		0xa5, 0x18, 0x87, 0x24, 0x5b, 0x26, 0xcd, 0xfe, 0xc7, 0xdf, 0x29, 0x24, 0xc5, 0x42, 0xc7, 0xe9,
		0xab, 0x99, 0x90, 0x4b, 0x60, 0x0a, 0x35, 0x3e, 0x7f, 0x7a, 0xbe, 0x2f, 0x45, 0xac, 0xfd, 0xd9,
		0x21, 0x21, 0x62, 0x5e, 0xf1, 0x34, 0x34, 0x68, 0x05, 0x68, 0x05, 0x68, 0x05, 0x68, 0x05, 0x68,
		0x05, 0xf9, 0xba, 0x45, 0x85, 0xcf, 0xb5, 0x80, 0xe9, 0x7e, 0x78, 0x73, 0x33, 0x56, 0x52, 0xdf,
		0x73, 0x05, 0x01, 0x5e, 0x5e, 0x00, 0x20, 0x1b, 0x90, 0x0d, 0xc8, 0x06, 0x64, 0x03, 0xb2, 0x11,
		0x09, 0xe0, 0x8c, 0x04, 0xcc, 0x71, 0x49, 0x8a, 0x38, 0x7d, 0x7d, 0x8f, 0x60, 0xc0, 0xdb, 0xa6,
		0x5c, 0xdc, 0x69, 0x9f, 0x9d, 0x69, 0x2c, 0xbb, 0x08, 0xb0, 0x0d, 0xb0, 0x0d, 0xb0, 0x0d, 0xb0,
		0x0d, 0xb0, 0x0d, 0xb0, 0x0d, 0x4e, 0xb6, 0xf1, 0x1c, 0x9b, 0x26, 0x8c, 0x63, 0x01, 0xab, 0xc0,
		0x3a, 0xde, 0x36, 0xf5, 0x52, 0xdd, 0x06, 0x43, 0x39, 0xf0, 0x23, 0x11, 0xc4, 0x44, 0x7d, 0x46,
		0x16, 0x2c, 0xfc, 0xc5, 0xf8, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe4,
		0xeb, 0x56, 0x0e, 0x84, 0xd2, 0x52, 0xdf, 0x33, 0xf1, 0x8d, 0x2a, 0xe1, 0x98, 0xad, 0xd9, 0xad,
		0x7e, 0x0e, 0x62, 0x06, 0x97, 0x31, 0x9f, 0xf0, 0xd6, 0xf1, 0x1f, 0xcd, 0xc3, 0xd6, 0x97, 0x5e,
		0xa7, 0x7d, 0x7e, 0x76, 0xd0, 0xeb, 0x1c, 0x34, 0x4f, 0xdb, 0xc7, 0xd4, 0xde, 0xe3, 0x8f, 0x60,
		0x38, 0x9e, 0x16, 0xd9, 0xb9, 0x20, 0x1d, 0x77, 0xf2, 0xe7, 0x3b, 0xf9, 0x88, 0x4b, 0x67, 0xff,
		0xd7, 0xc3, 0xf3, 0xd3, 0xb3, 0x83, 0x4e, 0xef, 0xb0, 0xdd, 0x3e, 0xf1, 0xc8, 0x2f, 0xe9, 0xf1,
		0xc3, 0xa6, 0xce, 0x7b, 0xbb, 0xd3, 0xfa, 0xad, 0x75, 0xdc, 0x3c, 0x6b, 0x77, 0x30, 0xeb, 0x74,
		0xb3, 0xde, 0x3c, 0x85, 0xa1, 0x53, 0x3b, 0x98, 0xf6, 0xf1, 0xd7, 0x83, 0x2f, 0x0c, 0x33, 0x4e,
		0x3a, 0x62, 0x37, 0x6f, 0x7c, 0x2f, 0x17, 0xea, 0x7e, 0x18, 0xc4, 0xda, 0xbf, 0x09, 0x07, 0xf2,
		0x4a, 0x8a, 0x01, 0xbd, 0xb8, 0x5f, 0x1c, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x1e,
		0xda, 0x9e, 0x7c, 0xdd, 0x6a, 0x79, 0x23, 0xb4, 0xec, 0x7f, 0x8b, 0x6b, 0x15, 0x06, 0x6d, 0xbf,
		0x4f, 0x38, 0xe4, 0xb9, 0x92, 0xd3, 0xf6, 0x75, 0x9e, 0x0a, 0x54, 0x18, 0x8b, 0x7e, 0xa8, 0x06,
		0x31, 0xe5, 0x2d, 0x77, 0x02, 0x75, 0x2d, 0xc8, 0xf5, 0x34, 0x3d, 0xd5, 0xf5, 0x8e, 0xa4, 0x22,
		0xf7, 0xc8, 0x4c, 0x18, 0xbf, 0x3c, 0x6a, 0xc2, 0x38, 0xfe, 0xd7, 0x28, 0xe8, 0x6b, 0x19, 0xaa,
		0x2f, 0xf2, 0x3a, 0xb1, 0xf6, 0xe2, 0x26, 0xe8, 0x39, 0xef, 0x28, 0xb8, 0xdb, 0x78, 0x93, 0xa3,
		0xed, 0xc8, 0xed, 0xbc, 0x15, 0x6e, 0xe5, 0x73, 0xb4, 0x2e, 0x34, 0xee, 0x4f, 0x9b, 0x21, 0x55,
		0x3d, 0xd1, 0x0c, 0xa9, 0xa2, 0xa9, 0x2b, 0x0a, 0x5d, 0x0b, 0x5d, 0x0b, 0x5d, 0x0b, 0x5d, 0x0b,
		0x5d, 0xbb, 0x64, 0xdd, 0x8e, 0xa5, 0xd2, 0x7b, 0x65, 0x06, 0x49, 0x5b, 0x87, 0xa4, 0x84, 0xa4,
		0x84, 0xa4, 0x84, 0xa4, 0xcc, 0x81, 0xc9, 0x55, 0xca, 0x8d, 0x4a, 0xa3, 0x56, 0x2f, 0x37, 0x20,
		0x24, 0x21, 0x24, 0x37, 0x59, 0x48, 0xd2, 0x0a, 0x10, 0xda, 0x4a, 0xd8, 0x90, 0x91, 0x90, 0x91,
		0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0x4b, 0xd6, 0xed, 0xb4, 0xe9, 0x3e, 0xb9, 0x0d, 0xa7, 0xa9,
		0xcf, 0xfb, 0xb4, 0x47, 0xad, 0xb4, 0x88, 0x14, 0xb9, 0x9c, 0xf4, 0x76, 0x76, 0x2e, 0x8a, 0x7e,
		0xa3, 0xfb, 0x70, 0x51, 0xf2, 0x1b, 0xdd, 0xe4, 0x65, 0x69, 0xfa, 0x2d, 0x79, 0x5d, 0xbe, 0x28,
		0xfa, 0x95, 0xf9, 0xeb, 0xea, 0x45, 0xd1, 0xaf, 0x76, 0x77, 0xff, 0xfa, 0xeb, 0xe3, 0xee, 0xf7,
		0xbd, 0xc7, 0xd7, 0xbf, 0xb1, 0x30, 0x1b, 0x6c, 0xf7, 0x61, 0xe7, 0xa2, 0xe4, 0x97, 0xbb, 0xf3,
		0xff, 0xd9, 0xbb, 0x28, 0xfa, 0xe5, 0xee, 0xee, 0x2e, 0xdd, 0x0a, 0xed, 0x52, 0x3e, 0xda, 0xf6,
		0x69, 0xeb, 0x4f, 0xb6, 0xe7, 0xfb, 0xb7, 0x4b, 0x0f, 0xf8, 0x17, 0x0f, 0x0c, 0xdb, 0x41, 0x86,
		0x3d, 0x3b, 0xea, 0x67, 0xb5, 0x3f, 0xe6, 0x4a, 0x27, 0xff, 0x7c, 0x70, 0x70, 0x6d, 0x70, 0x6d,
		0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0xf2, 0x75, 0x8b, 0x9a, 0x87, 0x8e, 0x8f, 0x60, 0xbb, 0x6d,
		0x43, 0x53, 0xa9, 0x50, 0x07, 0x5a, 0x12, 0x55, 0x1b, 0xf0, 0xe2, 0xfe, 0x3f, 0xe2, 0x26, 0x98,
		0x55, 0x59, 0xf6, 0x0a, 0xe1, 0x48, 0xa8, 0xfe, 0x14, 0x28, 0x27, 0xfe, 0xa3, 0x30, 0xf9, 0x8a,
		0xe4, 0x65, 0x21, 0xb8, 0x92, 0x7e, 0x1c, 0x5c, 0xc9, 0x38, 0x7d, 0x55, 0x98, 0xaa, 0xc2, 0xb1,
		0x92, 0xfd, 0x20, 0xd6, 0x05, 0x25, 0xe4, 0xf5, 0x3f, 0x97, 0x61, 0x14, 0xa7, 0xaf, 0x0a, 0xc1,
		0xe0, 0xdf, 0xa9, 0x1b, 0x92, 0xca, 0x1f, 0x85, 0xb1, 0x2e, 0x4c, 0xa9, 0x45, 0x9c, 0x7c, 0x2b,
		0x50, 0xf4, 0xd2, 0x49, 0x6e, 0x4f, 0x47, 0xe3, 0xbe, 0x56, 0xb3, 0xd5, 0xd5, 0x4e, 0xef, 0xee,
		0xf3, 0xf5, 0xa8, 0x37, 0xf9, 0xea, 0xc8, 0xcb, 0x5e, 0xf3, 0x4a, 0x9e, 0x4e, 0xee, 0x6d, 0xfe,
		0xa2, 0xd7, 0x1a, 0xdd, 0x56, 0xce, 0x93, 0x3b, 0xeb, 0x1d, 0xcf, 0xef, 0x2c, 0x7d, 0xd5, 0x6b,
		0x0e, 0xfe, 0xed, 0xc8, 0xcb, 0x96, 0x3a, 0x09, 0x63, 0xdd, 0xeb, 0x4c, 0x6f, 0x2b, 0xf9, 0xd6,
		0x3b, 0x9d, 0xde, 0x16, 0x5a, 0x35, 0x65, 0x1e, 0xc3, 0x58, 0x7d, 0x53, 0xe1, 0x7f, 0xca, 0x0f,
		0xb4, 0x8e, 0xe4, 0xe5, 0x64, 0xc6, 0xe8, 0xfa, 0x36, 0x2d, 0x19, 0x1b, 0x4d, 0x9c, 0x5c, 0x25,
		0xb2, 0x68, 0xe2, 0x94, 0x4f, 0xa2, 0x8a, 0x26, 0x4e, 0x6f, 0x9a, 0x35, 0xb2, 0x26, 0x4e, 0x19,
		0x27, 0x49, 0x1f, 0x81, 0xc8, 0x5e, 0x02, 0x6d, 0x1c, 0xa2, 0x84, 0x38, 0x04, 0xe2, 0x10, 0x88,
		0x43, 0x20, 0x0e, 0xe1, 0x4e, 0x1c, 0x82, 0xca, 0xfd, 0xa7, 0x03, 0x4e, 0x5b, 0x16, 0x69, 0xea,
		0xe8, 0xc7, 0x76, 0xa6, 0xa5, 0xdf, 0xf4, 0x12, 0x88, 0x4d, 0x97, 0x27, 0xdf, 0x8c, 0x1c, 0x0e,
		0x38, 0x61, 0xc1, 0x0d, 0x78, 0xe0, 0x86, 0x09, 0x67, 0xe0, 0xc2, 0x19, 0xd8, 0x70, 0x06, 0x3e,
		0x68, 0x61, 0x84, 0x18, 0x4e, 0xd2, 0x59, 0x3e, 0xe3, 0x70, 0xf0, 0xdb, 0xbc, 0x95, 0x7b, 0x33,
		0x6c, 0xbf, 0xce, 0x30, 0x76, 0xa6, 0xb9, 0xfb, 0x13, 0xd8, 0xe5, 0x34, 0xc3, 0x96, 0xd0, 0xb4,
		0x89, 0xfa, 0xc1, 0xaf, 0xb4, 0x69, 0xaa, 0x98, 0x36, 0xa3, 0x76, 0x05, 0x69, 0x01, 0x69, 0x01,
		0x69, 0x01, 0x69, 0xe1, 0x20, 0x2d, 0xd4, 0x5a, 0x78, 0x51, 0x13, 0x0f, 0x05, 0xe3, 0xe1, 0xbb,
		0x05, 0x69, 0x3c, 0xb9, 0x92, 0x0f, 0x1b, 0x79, 0x22, 0x8b, 0x0b, 0x74, 0x5c, 0x00, 0x1f, 0xb7,
		0x40, 0xc8, 0x15, 0x30, 0x72, 0x0e, 0x94, 0x9c, 0x03, 0x27, 0xe7, 0x40, 0x8a, 0x07, 0xac, 0x98,
		0x40, 0x8b, 0x5f, 0x71, 0x67, 0xfc, 0xc6, 0x58, 0x2a, 0x5d, 0xaa, 0x71, 0xfa, 0x8c, 0x19, 0x8a,
		0xd4, 0x18, 0x2f, 0x81, 0xa7, 0x66, 0xc0, 0xcb, 0x3f, 0xbc, 0x3e, 0x73, 0x9b, 0xbb, 0xa6, 0x80,
		0x63, 0xf4, 0x22, 0x73, 0x39, 0xcc, 0x35, 0x07, 0x32, 0xd7, 0xe3, 0xc0, 0x39, 0x70, 0x47, 0xdc,
		0xe9, 0xa2, 0x09, 0x07, 0x77, 0x30, 0xe1, 0x1f, 0x98, 0x70, 0xad, 0x5a, 0xdd, 0xab, 0xc2, 0x8c,
		0xdd, 0xe2, 0x22, 0xfc, 0xa3, 0x77, 0xb7, 0x36, 0xe3, 0x7e, 0x39, 0x4a, 0xa7, 0xf0, 0xed, 0xa4,
		0x2f, 0x0f, 0x1b, 0x30, 0xec, 0xa8, 0x23, 0x6e, 0x80, 0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20,
		0x6e, 0x90, 0x93, 0xb8, 0xc1, 0xbe, 0x03, 0x61, 0x83, 0x2a, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c,
		0x80, 0xb0, 0x01, 0xc2, 0x06, 0xd6, 0x4d, 0xb8, 0x5c, 0x45, 0xd0, 0x00, 0x41, 0x03, 0x04, 0x0d,
		0x68, 0x83, 0x06, 0xb7, 0xb3, 0xd5, 0xe7, 0x42, 0xd4, 0x20, 0xb9, 0x16, 0x84, 0x0d, 0x10, 0x36,
		0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x78, 0xa5, 0xdf, 0xb8, 0x94, 0x2a, 0x88,
		0xee, 0x1d, 0x88, 0x1b, 0x34, 0x18, 0x2f, 0xe1, 0x50, 0xa8, 0xeb, 0x69, 0xe2, 0x3f, 0x02, 0x07,
		0x08, 0x1c, 0xfc, 0x50, 0x75, 0x95, 0xa0, 0xb9, 0x10, 0x38, 0x58, 0x6f, 0x13, 0x46, 0xbe, 0x01,
		0x42, 0x07, 0x08, 0x1d, 0x90, 0x9a, 0xb9, 0xb8, 0xd3, 0x42, 0x0d, 0x08, 0xdb, 0xd8, 0xaf, 0xa4,
		0x7c, 0xe9, 0x95, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0,
		0xc1, 0x6b, 0xc3, 0x06, 0xe4, 0x65, 0x70, 0x57, 0xc1, 0x08, 0x51, 0x59, 0xdc, 0xcd, 0x24, 0x2d,
		0xe1, 0x68, 0xc2, 0xcc, 0x83, 0x21, 0x3f, 0x69, 0x49, 0xaf, 0x04, 0xa4, 0x05, 0xa4, 0x05, 0xa4,
		0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x25, 0x3b, 0xc7, 0xa3, 0x20, 0xd2,
		0xd2, 0x05, 0xce, 0x32, 0xbf, 0x10, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16,
		0x50, 0x16, 0x50, 0x16, 0x50, 0x96, 0xec, 0x1c, 0xeb, 0x28, 0x50, 0xb1, 0xd4, 0xf2, 0xd6, 0x81,
		0xbc, 0xd2, 0x67, 0xd7, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2,
		0x02, 0xe2, 0xe2, 0x3c, 0x71, 0xc9, 0x75, 0x79, 0x51, 0xe2, 0xbe, 0x8b, 0x99, 0xf1, 0x79, 0xfa,
		0x30, 0x66, 0x7b, 0xe3, 0x65, 0x7f, 0x54, 0xe0, 0x28, 0x6c, 0xbd, 0x4d, 0xdf, 0xbc, 0xf1, 0x3c,
		0xb9, 0xf1, 0x66, 0x3a, 0x15, 0x99, 0x9f, 0x50, 0xf4, 0x77, 0xe4, 0x5b, 0x75, 0xf9, 0x6a, 0x9d,
		0xf3, 0xbb, 0xb8, 0xe7, 0xa8, 0x7d, 0xe3, 0x1d, 0xca, 0x58, 0x4f, 0x0c, 0x86, 0xb6, 0x6f, 0xcf,
		0x91, 0x54, 0x07, 0x43, 0x31, 0x21, 0x46, 0x31, 0xad, 0xb0, 0xf0, 0x8e, 0x82, 0xbb, 0x67, 0x23,
		0x97, 0xf6, 0x2b, 0x95, 0x5a, 0xbd, 0x52, 0x29, 0xd6, 0xf7, 0xea, 0xc5, 0x46, 0xb5, 0x5a, 0xaa,
		0x95, 0x08, 0xf3, 0x80, 0xbd, 0x76, 0x34, 0x10, 0x91, 0x18, 0x7c, 0x9e, 0x3c, 0x7a, 0x35, 0x1e,
		0x0e, 0x73, 0x65, 0xd1, 0x4c, 0x08, 0xe5, 0x30, 0x32, 0x79, 0xa4, 0xcd, 0x25, 0xdc, 0xc2, 0x22,
		0x0f, 0xdd, 0xba, 0xf9, 0xd7, 0xe6, 0x86, 0x74, 0xeb, 0x26, 0xef, 0xa0, 0xec, 0xc2, 0x8a, 0x5b,
		0xdb, 0x36, 0xde, 0x5b, 0x6b, 0xb4, 0x90, 0xe6, 0x34, 0x2d, 0x89, 0x76, 0x6d, 0x4f, 0x0c, 0xdb,
		0x97, 0xb6, 0x4e, 0x0e, 0xd0, 0x70, 0x33, 0x3a, 0x2e, 0xc6, 0xca, 0xbd, 0x68, 0xb8, 0x96, 0x2d,
		0xb3, 0x23, 0xf2, 0xdb, 0x3c, 0xfe, 0xda, 0xa2, 0x73, 0xa6, 0x75, 0xca, 0x76, 0x5c, 0xb0, 0x79,
		0x07, 0x69, 0xf6, 0x13, 0x0d, 0xdb, 0xbc, 0x6d, 0x5b, 0xa7, 0xb6, 0x71, 0x0b, 0xd6, 0x4d, 0x65,
		0xd5, 0x66, 0xed, 0xd9, 0x9c, 0xd5, 0x19, 0xb4, 0x38, 0x4b, 0x4d, 0xf8, 0xac, 0x36, 0xd9, 0xb3,
		0xd4, 0x44, 0xef, 0x69, 0xa3, 0xb7, 0x6c, 0xf8, 0x83, 0x2d, 0x6e, 0xe0, 0xd2, 0x6c, 0xcc, 0xda,
		0xde, 0x70, 0x25, 0xdb, 0x48, 0x25, 0xdb, 0x20, 0x25, 0xdb, 0xf8, 0x04, 0x96, 0x91, 0x60, 0x99,
		0xad, 0x3d, 0x15, 0xfb, 0x50, 0x66, 0x61, 0x0f, 0xc4, 0x20, 0x92, 0x6d, 0x39, 0x64, 0xb5, 0xb6,
		0xac, 0x95, 0xcc, 0x4a, 0x3d, 0xa3, 0xbc, 0xc0, 0xae, 0x5d, 0x9a, 0xb1, 0xc8, 0xf7, 0xdb, 0x8f,
		0x01, 0xdb, 0xf1, 0x9e, 0x3f, 0x86, 0xc8, 0x1c, 0x4a, 0x3e, 0x95, 0x76, 0x5c, 0xfc, 0x7c, 0x43,
		0xd6, 0x6e, 0x96, 0x45, 0x19, 0x4f, 0x93, 0xb3, 0xc1, 0x9a, 0xec, 0xb2, 0x25, 0x5b, 0x2c, 0xc9,
		0x3a, 0x3b, 0xb2, 0xce, 0x8a, 0xac, 0xb3, 0x21, 0xb7, 0x70, 0xc4, 0x74, 0xeb, 0x5b, 0x6f, 0xa6,
		0xa4, 0xad, 0xa9, 0x34, 0x2b, 0x4a, 0x1d, 0x32, 0x0d, 0x32, 0x0d, 0x32, 0x6d, 0x2d, 0x64, 0x9a,
		0xad, 0x5e, 0xdd, 0x89, 0x63, 0xb1, 0x67, 0x8f, 0x0b, 0xfe, 0xcb, 0x96, 0x2d, 0xda, 0x71, 0x63,
		0xd6, 0x78, 0x13, 0xa5, 0x5b, 0xa3, 0x75, 0x6f, 0x54, 0x6e, 0x8e, 0xdc, 0xdd, 0x91, 0xbb, 0x3d,
		0x72, 0xf7, 0x67, 0xc7, 0x0d, 0x5a, 0x72, 0x87, 0xd6, 0xdd, 0x62, 0x3a, 0xc0, 0x7c, 0xff, 0xdc,
		0xba, 0x25, 0x3f, 0x1d, 0x41, 0xb7, 0xb9, 0x61, 0xff, 0xd2, 0x65, 0x5a, 0xce, 0x6b, 0x24, 0x3b,
		0x99, 0x45, 0x79, 0x02, 0x8b, 0xe7, 0xa4, 0x15, 0xf5, 0x89, 0x2a, 0xb6, 0x93, 0x53, 0x6c, 0x27,
		0xa4, 0xd8, 0x4e, 0x42, 0xad, 0x77, 0xc2, 0x1e, 0xd9, 0x09, 0xa6, 0x74, 0xdd, 0x0d, 0x45, 0x70,
		0x15, 0x89, 0x2b, 0x8a, 0x45, 0x37, 0x67, 0x96, 0x75, 0x82, 0xb1, 0x4e, 0x66, 0xd1, 0xe7, 0x8f,
		0x1f, 0x93, 0xbd, 0x8c, 0xc2, 0x1c, 0x0a, 0xd6, 0x35, 0x6d, 0xce, 0x22, 0xbf, 0x1c, 0xd1, 0xb8,
		0xfb, 0x27, 0x54, 0x26, 0x21, 0x97, 0x00, 0x65, 0x80, 0x32, 0x40, 0x19, 0xa0, 0x0c, 0x50, 0x76,
		0x18, 0x94, 0x93, 0x65, 0x07, 0x4c, 0xce, 0x4c, 0x95, 0x9d, 0x3c, 0xb5, 0x95, 0x06, 0x47, 0x71,
		0x86, 0xd6, 0x72, 0x64, 0x11, 0x88, 0x0c, 0x44, 0x06, 0x22, 0x6f, 0x06, 0x22, 0xdb, 0x8e, 0x54,
		0xa6, 0x03, 0x4d, 0xcf, 0x67, 0x4b, 0x35, 0x10, 0x74, 0xf5, 0x88, 0x16, 0x3b, 0x9c, 0x26, 0x63,
		0x53, 0x1d, 0x4a, 0x27, 0xad, 0x3c, 0x45, 0x5e, 0x69, 0x8a, 0xa3, 0xb2, 0x14, 0x6f, 0x25, 0x29,
		0xae, 0xca, 0x51, 0xec, 0x95, 0xa2, 0xd8, 0x2b, 0x43, 0xb1, 0x57, 0x82, 0xca, 0x57, 0xb9, 0x0c,
		0xf2, 0xca, 0x4e, 0x0c, 0x52, 0x8c, 0x43, 0x92, 0x2d, 0x93, 0x66, 0xff, 0xe3, 0xef, 0x14, 0x92,
		0x62, 0xa1, 0xe3, 0xf4, 0xd5, 0x4c, 0xc8, 0x25, 0x30, 0x95, 0x97, 0x33, 0xff, 0x04, 0xcc, 0xba,
		0x1f, 0xde, 0xdc, 0x8c, 0x95, 0xd4, 0xf7, 0x5c, 0xec, 0xe2, 0xe5, 0x05, 0x80, 0x62, 0x80, 0x62,
		0x80, 0x62, 0x80, 0x62, 0x80, 0x62, 0x80, 0x62, 0x70, 0x52, 0x8c, 0x39, 0x2e, 0x49, 0x11, 0xa7,
		0xaf, 0xef, 0xc1, 0x32, 0xde, 0x36, 0xe5, 0xe2, 0x4e, 0xfb, 0xec, 0x4c, 0x63, 0xd9, 0x45, 0x80,
		0x6d, 0x80, 0x6d, 0x80, 0x6d, 0x80, 0x6d, 0x80, 0x6d, 0x80, 0x6d, 0x70, 0xb2, 0x8d, 0xe7, 0xd8,
		0x34, 0x61, 0x1c, 0x0b, 0x58, 0x05, 0xd6, 0xf1, 0xb6, 0xa9, 0x97, 0xea, 0x36, 0x18, 0xca, 0x81,
		0x1f, 0x89, 0x20, 0x26, 0xac, 0x06, 0x9a, 0x5a, 0xf8, 0x8b, 0xf1, 0xc1, 0x35, 0xc0, 0x35, 0xc0,
		0x35, 0xc0, 0x35, 0xc0, 0x35, 0xc8, 0xd7, 0xad, 0x1c, 0x08, 0xa5, 0xa5, 0xbe, 0x67, 0xe2, 0x1b,
		0x94, 0xb5, 0xbd, 0x5b, 0xb3, 0x5b, 0xfd, 0x1c, 0xc4, 0x0c, 0x2e, 0x63, 0x3e, 0xe1, 0xad, 0xe3,
		0x3f, 0x9a, 0x87, 0xad, 0x2f, 0xbd, 0x4e, 0xfb, 0xfc, 0xec, 0xa0, 0xd7, 0x39, 0x68, 0x9e, 0xb6,
		0x8f, 0xa9, 0xbd, 0xc7, 0x1f, 0xc1, 0x70, 0x3c, 0x3d, 0xbd, 0x7f, 0x41, 0xde, 0x92, 0x81, 0xb9,
		0x77, 0xd8, 0x7c, 0xf6, 0x7f, 0x3d, 0x3c, 0x3f, 0x3d, 0x3b, 0xe8, 0xf4, 0x0e, 0xdb, 0xed, 0x13,
		0x6f, 0x13, 0x3a, 0xb8, 0x39, 0x32, 0xef, 0xed, 0x4e, 0xeb, 0xb7, 0xd6, 0x71, 0xf3, 0xac, 0xdd,
		0xc1, 0xac, 0xd3, 0xcd, 0x7a, 0xf3, 0x14, 0x86, 0x4e, 0xed, 0x60, 0xda, 0xc7, 0x5f, 0x0f, 0xbe,
		0x78, 0x39, 0xef, 0xb1, 0xd4, 0xcd, 0x1b, 0xdf, 0xcb, 0x85, 0xba, 0x1f, 0x06, 0xb1, 0xf6, 0x6f,
		0xc2, 0x81, 0xbc, 0x92, 0x62, 0x40, 0x2f, 0xee, 0x17, 0x87, 0x87, 0xb6, 0x87, 0xb6, 0x87, 0xb6,
		0x87, 0xb6, 0x87, 0xb6, 0x27, 0x5f, 0xb7, 0x5a, 0xde, 0x08, 0x2d, 0xfb, 0xdf, 0xe2, 0x5a, 0x85,
		0x41, 0xdb, 0xef, 0x13, 0x0e, 0x79, 0xae, 0xe4, 0xb4, 0x83, 0x85, 0xa7, 0x02, 0x15, 0xc6, 0xa2,
		0x1f, 0xaa, 0x41, 0x4c, 0x79, 0xcb, 0x9d, 0x40, 0x5d, 0x0b, 0x72, 0x3d, 0xcd, 0xd0, 0x64, 0xf2,
		0x48, 0x2a, 0xbe, 0x06, 0xe0, 0xcc, 0x6d, 0xb7, 0xa7, 0x51, 0x13, 0xc6, 0xf1, 0xbf, 0x46, 0x41,
		0x5f, 0xcb, 0x50, 0x7d, 0x91, 0xd7, 0x89, 0xb5, 0x17, 0x37, 0xa2, 0xf5, 0xfc, 0x51, 0x70, 0xb7,
		0xf1, 0x26, 0xc7, 0xdb, 0x15, 0xd1, 0x39, 0x2b, 0xcc, 0x69, 0xff, 0xd4, 0x2e, 0x34, 0xee, 0x4f,
		0x9b, 0x21, 0x55, 0xa1, 0xb2, 0x0c, 0xa9, 0xa2, 0x29, 0x58, 0x06, 0x5d, 0x0b, 0x5d, 0x0b, 0x5d,
		0x0b, 0x5d, 0x0b, 0x5d, 0xbb, 0x64, 0xdd, 0x8e, 0xa5, 0xd2, 0x7b, 0x65, 0x06, 0x49, 0x5b, 0x87,
		0xa4, 0x84, 0xa4, 0x84, 0xa4, 0x84, 0xa4, 0xcc, 0x81, 0xc9, 0x55, 0xca, 0x8d, 0x4a, 0xa3, 0x56,
		0x2f, 0x37, 0x20, 0x24, 0x21, 0x24, 0x37, 0x59, 0x48, 0xd2, 0x0a, 0x10, 0xda, 0x12, 0x9b, 0x90,
		0x91, 0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0x4b, 0xd6, 0xed, 0xb4, 0x97, 0x21, 0xb9,
		0x0d, 0xa7, 0xa9, 0xcf, 0xfb, 0xb4, 0x47, 0xad, 0xb4, 0x88, 0x14, 0xb9, 0x9c, 0xf4, 0x76, 0x76,
		0x2e, 0x8a, 0x7e, 0xa3, 0xfb, 0x70, 0x51, 0xf2, 0x1b, 0xdd, 0xe4, 0x65, 0x69, 0xfa, 0x2d, 0x79,
		0x5d, 0xbe, 0x28, 0xfa, 0x95, 0xf9, 0xeb, 0xea, 0x45, 0xd1, 0xaf, 0x76, 0x77, 0xff, 0xfa, 0xeb,
		0xe3, 0xee, 0xf7, 0xbd, 0xc7, 0xd7, 0xbf, 0xb1, 0x30, 0x1b, 0x6c, 0xf7, 0x61, 0xe7, 0xa2, 0xe4,
		0x97, 0xbb, 0xf3, 0xff, 0xd9, 0xbb, 0x28, 0xfa, 0xe5, 0xee, 0xee, 0x2e, 0xdd, 0x0a, 0xed, 0x52,
		0x3e, 0xda, 0xf6, 0x69, 0xeb, 0x4f, 0xb6, 0xe7, 0xfb, 0xb7, 0x4b, 0x0f, 0xf8, 0x17, 0x0f, 0x0c,
		0xdb, 0x41, 0x86, 0x3d, 0x3b, 0xea, 0x67, 0xb5, 0xf1, 0xd6, 0x4a, 0x27, 0xff, 0x7c, 0x70, 0x70,
		0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0x70, 0x6d, 0xf2, 0x75, 0x7b, 0x19, 0x86, 0x43, 0x11,
		0x28, 0x0e, 0x9e, 0x5d, 0xca, 0x0b, 0x54, 0xaf, 0x75, 0x3d, 0x68, 0x4b, 0x9d, 0xec, 0x57, 0x8e,
		0x47, 0xd2, 0xe1, 0x3e, 0x12, 0x85, 0xa4, 0x51, 0x71, 0xf2, 0xad, 0x40, 0x51, 0xa3, 0x7f, 0xdb,
		0x7a, 0x2f, 0xfc, 0x48, 0xf4, 0x3a, 0xd3, 0xbb, 0x4a, 0xbe, 0xf5, 0x4e, 0xa7, 0x77, 0x85, 0x0e,
		0x10, 0x99, 0xa7, 0x30, 0x56, 0xdf, 0x54, 0xf8, 0x9f, 0xf2, 0x03, 0xad, 0x23, 0x79, 0x69, 0xa5,
		0x21, 0xf6, 0x4a, 0x87, 0xba, 0x64, 0x6c, 0xf4, 0x86, 0x70, 0x95, 0xc6, 0xa2, 0x37, 0x44, 0x3e,
		0x69, 0x2a, 0x7a, 0x43, 0xbc, 0x69, 0xd6, 0xc8, 0x7a, 0x43, 0x64, 0x9c, 0x24, 0x7d, 0xfc, 0x21,
		0x7b, 0x09, 0xb4, 0x51, 0x88, 0x12, 0xa2, 0x10, 0x88, 0x42, 0x20, 0x0a, 0x81, 0x28, 0x84, 0x3b,
		0x51, 0x08, 0x2a, 0xf7, 0x9f, 0x0e, 0x38, 0xed, 0x84, 0xa0, 0xa9, 0x63, 0x1f, 0xdb, 0x99, 0x4e,
		0x41, 0xd3, 0x4b, 0x20, 0x36, 0x5d, 0x9e, 0x6c, 0x33, 0x72, 0x38, 0xe0, 0x84, 0x05, 0x37, 0xe0,
		0x81, 0x1b, 0x26, 0x9c, 0x81, 0x0b, 0x67, 0x60, 0xc3, 0x19, 0xf8, 0xa0, 0x85, 0x11, 0x62, 0x38,
		0x49, 0x67, 0xf9, 0x8c, 0xc3, 0xc1, 0x6f, 0xf3, 0xd6, 0xed, 0xcd, 0xb0, 0xfd, 0x3a, 0xc3, 0xd8,
		0x99, 0x9e, 0xb1, 0x4f, 0x60, 0x97, 0xd3, 0xfc, 0x5a, 0x42, 0xd3, 0x26, 0x6a, 0x33, 0xbb, 0xd2,
		0xa6, 0xa9, 0x42, 0xda, 0x8c, 0xda, 0x15, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x85, 0x83,
		0xb4, 0x50, 0x6b, 0xe1, 0x45, 0x4d, 0x3c, 0x14, 0x8c, 0x47, 0xef, 0x16, 0xa4, 0xf1, 0xe4, 0x4a,
		0x3e, 0x6c, 0xe4, 0x79, 0x2c, 0x2e, 0xd0, 0x71, 0x01, 0x7c, 0xdc, 0x02, 0x21, 0x57, 0xc0, 0xc8,
		0x39, 0x50, 0x72, 0x0e, 0x9c, 0x9c, 0x03, 0x29, 0x1e, 0xb0, 0x62, 0x02, 0x2d, 0x7e, 0xc5, 0x9d,
		0xf1, 0x1b, 0x63, 0xa9, 0x74, 0xa9, 0xc6, 0xe9, 0x33, 0x66, 0x28, 0x52, 0x63, 0xbc, 0x04, 0x9e,
		0x8a, 0x01, 0x2f, 0xff, 0xf0, 0xfa, 0xcc, 0x6d, 0xee, 0x8a, 0x02, 0x8e, 0xd1, 0x8b, 0xcc, 0xe5,
		0x30, 0x57, 0x1c, 0xc8, 0x5c, 0x8f, 0x03, 0xa7, 0xc0, 0x1d, 0x71, 0xa7, 0x8b, 0x26, 0x1c, 0xdc,
		0xc1, 0x84, 0x7f, 0x60, 0xc2, 0xb5, 0x6a, 0x75, 0xaf, 0x0a, 0x33, 0x76, 0x8b, 0x8b, 0xf0, 0x8f,
		0xde, 0xdd, 0xda, 0x8c, 0xfb, 0xe5, 0x28, 0x9c, 0xc2, 0xb7, 0x93, 0xbe, 0x3c, 0x6c, 0xc0, 0xb0,
		0xa3, 0x8e, 0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e, 0x80, 0xb8, 0x41, 0x4e, 0xe2, 0x06,
		0xfb, 0x0e, 0x84, 0x0d, 0xaa, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b,
		0x58, 0x37, 0xe1, 0x72, 0x15, 0x41, 0x03, 0x04, 0x0d, 0x10, 0x34, 0xa0, 0x0d, 0x1a, 0xdc, 0xce,
		0x56, 0x9f, 0x0b, 0x51, 0x83, 0xe4, 0x5a, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d,
		0x10, 0x36, 0x40, 0xd8, 0xe0, 0x95, 0x7e, 0xe3, 0x52, 0xaa, 0x20, 0xba, 0x77, 0x20, 0x6e, 0xd0,
		0x60, 0xbc, 0x84, 0x43, 0xa1, 0xae, 0xa7, 0x89, 0xff, 0x08, 0x1c, 0x20, 0x70, 0xf0, 0x43, 0xd5,
		0x55, 0x82, 0xe6, 0x42, 0xe0, 0x60, 0xbd, 0x4d, 0x18, 0xf9, 0x06, 0x08, 0x1d, 0x20, 0x74, 0x40,
		0x6a, 0xe6, 0xe2, 0x4e, 0x0b, 0x35, 0x20, 0x6c, 0x62, 0xbf, 0x92, 0xf2, 0xa5, 0x57, 0x82, 0xb0,
		0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0xaf, 0x0d, 0x1b, 0x90,
		0x17, 0xc1, 0x5d, 0x05, 0x23, 0x44, 0x45, 0x71, 0x37, 0x93, 0xb4, 0x84, 0xa3, 0x09, 0x33, 0x0f,
		0x86, 0xfc, 0xa4, 0x25, 0xbd, 0x12, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16,
		0x90, 0x16, 0x90, 0x16, 0x90, 0x96, 0xec, 0x1c, 0x8f, 0x82, 0x48, 0x4b, 0x17, 0x38, 0xcb, 0xfc,
		0x42, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40,
		0x59, 0xb2, 0x73, 0xac, 0xa3, 0x40, 0xc5, 0x52, 0xcb, 0x5b, 0x07, 0xf2, 0x4a, 0x9f, 0x5d, 0x0b,
		0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x8b, 0xf3, 0xc4,
		0x25, 0xd7, 0xe5, 0x45, 0x89, 0xbb, 0x2e, 0x66, 0xc6, 0x67, 0xe9, 0xc2, 0x98, 0x6d, 0x8d, 0x97,
		0xfd, 0x51, 0x81, 0xa3, 0xae, 0xf5, 0x36, 0x79, 0xeb, 0xc6, 0xf3, 0xe4, 0xbe, 0x9b, 0xe9, 0x4c,
		0x64, 0x7e, 0x42, 0xd1, 0xdd, 0x91, 0x6f, 0xcd, 0xe5, 0xab, 0x71, 0xce, 0xef, 0xe2, 0x9e, 0xa3,
		0xf2, 0x8d, 0x77, 0x28, 0x63, 0x3d, 0x31, 0x18, 0xda, 0xae, 0x3d, 0x47, 0x52, 0x1d, 0x0c, 0xc5,
		0x84, 0x16, 0xc5, 0xb4, 0xb2, 0xc2, 0x3b, 0x0a, 0xee, 0x9e, 0x8d, 0x5c, 0xda, 0xaf, 0x54, 0x6a,
		0xf5, 0x4a, 0xa5, 0x58, 0xdf, 0xab, 0x17, 0x1b, 0xd5, 0x6a, 0xa9, 0x56, 0x22, 0xcc, 0x02, 0xf6,
		0xda, 0xd1, 0x40, 0x44, 0x62, 0xf0, 0x79, 0xf2, 0xe8, 0xd5, 0x78, 0x38, 0xcc, 0x95, 0x45, 0x33,
		0xe1, 0x93, 0xbb, 0xb8, 0xe4, 0x91, 0x76, 0x96, 0x70, 0x0a, 0x89, 0x3c, 0xf4, 0xe9, 0xe6, 0x5f,
		0x99, 0x9b, 0xd1, 0xa7, 0x9b, 0xbc, 0x79, 0xb2, 0x03, 0xeb, 0x6d, 0x6d, 0x1b, 0x78, 0x6f, 0xad,
		0xd1, 0x32, 0x9a, 0x53, 0xb4, 0x24, 0xce, 0xb5, 0x3d, 0x31, 0x6b, 0x5f, 0xda, 0x3a, 0x33, 0x40,
		0xc3, 0xcb, 0xe8, 0x78, 0x18, 0x2b, 0xef, 0xa2, 0xe1, 0x59, 0xb6, 0xcc, 0x8e, 0xc8, 0x6b, 0xb3,
		0x78, 0x6b, 0x8b, 0xae, 0x99, 0xd4, 0x25, 0xdb, 0x71, 0xc0, 0xe6, 0xdd, 0xa3, 0xd9, 0x4f, 0x34,
		0x6c, 0xf1, 0xb6, 0x2d, 0x9d, 0xd8, 0xc2, 0x2d, 0xd8, 0x36, 0x91, 0x4d, 0x9b, 0xb5, 0x66, 0x73,
		0x36, 0x67, 0xd0, 0xde, 0x2c, 0xb5, 0xde, 0xb3, 0xda, 0x5a, 0xcf, 0x52, 0xeb, 0xbc, 0xa7, 0xed,
		0xdd, 0xb2, 0xe1, 0x0f, 0xb6, 0xb8, 0x6d, 0x4b, 0xb3, 0x1d, 0x6b, 0x7b, 0x9b, 0x95, 0x6c, 0xfb,
		0x94, 0x6c, 0x5b, 0x94, 0x6c, 0xbb, 0x13, 0x48, 0x46, 0x81, 0x64, 0xb6, 0x76, 0x52, 0xac, 0x03,
		0x99, 0x85, 0x9d, 0x0f, 0x83, 0x38, 0xb6, 0xe5, 0x90, 0xcd, 0xda, 0xb2, 0x55, 0x2a, 0x1b, 0xf5,
		0x8c, 0x92, 0x02, 0xab, 0x56, 0x69, 0xc6, 0x1e, 0xdf, 0x6f, 0x3d, 0x06, 0x2c, 0xc7, 0x9b, 0x3f,
		0x84, 0x70, 0xac, 0xfd, 0x51, 0x18, 0x6b, 0x63, 0xb6, 0xf3, 0x54, 0xce, 0xf1, 0xe5, 0x08, 0x86,
		0xec, 0xdd, 0x2c, 0x8b, 0x32, 0x9e, 0x1c, 0x67, 0x83, 0x35, 0xd9, 0x65, 0x4b, 0xb6, 0x58, 0x92,
		0x75, 0x76, 0x64, 0x9d, 0x15, 0x59, 0x67, 0x43, 0x6e, 0x21, 0x89, 0xe9, 0x86, 0xb7, 0xde, 0x4c,
		0x48, 0x5b, 0x53, 0x69, 0x56, 0x84, 0x3a, 0x64, 0x1a, 0x64, 0x1a, 0x64, 0xda, 0x5a, 0xc8, 0x34,
		0x5b, 0x1d, 0xba, 0x13, 0xc7, 0x62, 0xcf, 0x1e, 0x17, 0xfc, 0x97, 0x2d, 0x5b, 0xb4, 0xe3, 0xc6,
		0xac, 0xf1, 0x26, 0x4a, 0xb7, 0x46, 0xeb, 0xde, 0xa8, 0xdc, 0x1c, 0xb9, 0xbb, 0x23, 0x77, 0x7b,
		0xe4, 0xee, 0xcf, 0x8e, 0x1b, 0xb4, 0xe4, 0x0e, 0xad, 0xbb, 0xc5, 0x74, 0x80, 0xf9, 0xde, 0xb9,
		0x75, 0x4b, 0x7e, 0x3a, 0x78, 0x6e, 0x73, 0xb3, 0xfe, 0xa5, 0xcb, 0xb4, 0x9c, 0xcf, 0x48, 0x76,
		0x1e, 0x8b, 0xf2, 0xdc, 0x15, 0xcf, 0xf9, 0x2a, 0xea, 0x73, 0x54, 0x6c, 0xe7, 0xa5, 0xd8, 0xce,
		0x45, 0xb1, 0x9d, 0x7f, 0x5a, 0xef, 0x54, 0x3d, 0xb2, 0x73, 0x4b, 0xe9, 0xba, 0x1b, 0x8a, 0xe0,
		0x2a, 0x12, 0x57, 0x14, 0x8b, 0x6e, 0xce, 0x2c, 0xeb, 0x04, 0x63, 0x9d, 0xcc, 0xe2, 0xcf, 0x1f,
		0x3f, 0x26, 0x9b, 0x19, 0x85, 0x39, 0x14, 0xac, 0x6b, 0xca, 0x9c, 0x45, 0x7e, 0x39, 0xa2, 0x71,
		0xf7, 0x4f, 0xa8, 0x4c, 0x42, 0x2e, 0x01, 0xca, 0x00, 0x65, 0x80, 0x32, 0x40, 0x19, 0xa0, 0xec,
		0x30, 0x28, 0x27, 0xcb, 0x0e, 0x98, 0x9c, 0x99, 0x2a, 0x3b, 0x79, 0x6a, 0x2b, 0x0d, 0x8e, 0xe2,
		0xe8, 0xac, 0xe5, 0xc8, 0x22, 0x10, 0x19, 0x88, 0x0c, 0x44, 0xde, 0x0c, 0x44, 0xb6, 0x1d, 0xa9,
		0x4c, 0x07, 0x9a, 0x9e, 0xcb, 0x96, 0x6a, 0x20, 0xe8, 0xaa, 0x10, 0x2d, 0xf6, 0x35, 0x4d, 0xc6,
		0xa6, 0x3a, 0x8c, 0x4e, 0x5a, 0x6f, 0x8a, 0xbc, 0xbe, 0x14, 0x47, 0x3d, 0x29, 0xde, 0xfa, 0x51,
		0x5c, 0xf5, 0xa2, 0xd8, 0xeb, 0x43, 0xb1, 0xd7, 0x83, 0x62, 0xaf, 0xff, 0x94, 0xaf, 0x32, 0x19,
		0xe4, 0xf5, 0x9c, 0x18, 0xa4, 0x18, 0x87, 0x24, 0x5b, 0x26, 0xcd, 0xfe, 0xc7, 0xdf, 0x29, 0x24,
		0xc5, 0x42, 0xc7, 0xe9, 0xab, 0x99, 0x90, 0x4b, 0x60, 0x2a, 0x2f, 0xa7, 0xfd, 0x09, 0x98, 0x75,
		0x3f, 0xbc, 0xb9, 0x19, 0x2b, 0xa9, 0xef, 0xb9, 0xd8, 0xc5, 0xcb, 0x0b, 0x00, 0xc5, 0x00, 0xc5,
		0x00, 0xc5, 0x00, 0xc5, 0x00, 0xc5, 0x00, 0xc5, 0xe0, 0xa4, 0x18, 0x73, 0x5c, 0x92, 0x22, 0x4e,
		0x5f, 0xdf, 0x83, 0x65, 0xbc, 0x6d, 0xca, 0xc5, 0x9d, 0xf6, 0xd9, 0x99, 0xc6, 0xb2, 0x8b, 0x00,
		0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0xe0, 0x64, 0x1b, 0xcf, 0xb1,
		0x69, 0xc2, 0x38, 0x16, 0xb0, 0x0a, 0xac, 0xe3, 0x6d, 0x53, 0x2f, 0xd5, 0x6d, 0x30, 0x94, 0x03,
		0x3f, 0x12, 0x41, 0x4c, 0x58, 0x05, 0x34, 0xb5, 0xf0, 0x17, 0xe3, 0x83, 0x6b, 0x80, 0x6b, 0x80,
		0x6b, 0x80, 0x6b, 0x80, 0x6b, 0x90, 0xaf, 0x5b, 0x39, 0x10, 0x4a, 0x4b, 0x7d, 0xcf, 0xc4, 0x37,
		0x28, 0x6b, 0x7a, 0xb7, 0x66, 0xb7, 0xfa, 0x39, 0x88, 0x19, 0x5c, 0xc6, 0x7c, 0xc2, 0x5b, 0xc7,
		0x7f, 0x34, 0x0f, 0x5b, 0x5f, 0x7a, 0x9d, 0xf6, 0xf9, 0xd9, 0x41, 0xaf, 0x73, 0xd0, 0x3c, 0x6d,
		0x1f, 0x53, 0x7b, 0x8f, 0x3f, 0x82, 0xe1, 0x78, 0x7a, 0x7a, 0xff, 0x82, 0xbc, 0x13, 0x03, 0x73,
		0xc7, 0xb0, 0xf9, 0xec, 0xff, 0x7a, 0x78, 0x7e, 0x7a, 0x76, 0xd0, 0xe9, 0x1d, 0xb6, 0xdb, 0x27,
		0xde, 0x26, 0xf4, 0x6d, 0x73, 0x64, 0xde, 0xdb, 0x9d, 0xd6, 0x6f, 0xad, 0xe3, 0xe6, 0x59, 0xbb,
		0x83, 0x59, 0xa7, 0x9b, 0xf5, 0xe6, 0x29, 0x0c, 0x9d, 0xda, 0xc1, 0xb4, 0x8f, 0xbf, 0x1e, 0x7c,
		0xf1, 0x72, 0xde, 0x59, 0xa9, 0x9b, 0x37, 0xbe, 0x97, 0x0b, 0x75, 0x3f, 0x0c, 0x62, 0xed, 0xdf,
		0x84, 0x03, 0x79, 0x25, 0xc5, 0x80, 0x5e, 0xdc, 0x2f, 0x0e, 0x0f, 0x6d, 0x0f, 0x6d, 0x0f, 0x6d,
		0x0f, 0x6d, 0x0f, 0x6d, 0x4f, 0xbe, 0x6e, 0xb5, 0xbc, 0x11, 0x5a, 0xf6, 0xbf, 0xc5, 0xb5, 0x0a,
		0x83, 0xb6, 0xdf, 0x27, 0x1c, 0xf2, 0x5c, 0xc9, 0x69, 0xf7, 0x0a, 0x4f, 0x05, 0x2a, 0x8c, 0x45,
		0x3f, 0x54, 0x83, 0x98, 0xf2, 0x96, 0x3b, 0x81, 0xba, 0x16, 0xe4, 0x7a, 0x9a, 0xa1, 0xb5, 0xe4,
		0x91, 0x54, 0x7c, 0x6d, 0xbf, 0x99, 0x9b, 0x6d, 0x4f, 0xa3, 0x26, 0x8c, 0xe3, 0x7f, 0x8d, 0x82,
		0xbe, 0x96, 0xa1, 0xfa, 0x22, 0xaf, 0x13, 0x6b, 0x2f, 0x6e, 0x44, 0xc3, 0xf9, 0xa3, 0xe0, 0x6e,
		0xe3, 0x4d, 0x8e, 0xb7, 0x1b, 0xa2, 0x73, 0x56, 0x98, 0xd3, 0xbe, 0xa9, 0x5d, 0x68, 0xdc, 0x9f,
		0x36, 0x43, 0xaa, 0x42, 0x65, 0x19, 0x52, 0x45, 0x53, 0xb0, 0x0c, 0xba, 0x16, 0xba, 0x16, 0xba,
		0x16, 0xba, 0x16, 0xba, 0x76, 0xc9, 0xba, 0x1d, 0x4b, 0xa5, 0xf7, 0xca, 0x0c, 0x92, 0xb6, 0x0e,
		0x49, 0x09, 0x49, 0x09, 0x49, 0x09, 0x49, 0x99, 0x03, 0x93, 0xab, 0x94, 0x1b, 0x95, 0x46, 0xad,
		0x5e, 0x6e, 0x40, 0x48, 0x42, 0x48, 0x6e, 0xb2, 0x90, 0xa4, 0x15, 0x20, 0xb4, 0x25, 0x36, 0x21,
		0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x97, 0xac, 0xdb, 0x69, 0x37, 0x43, 0x72,
		0x1b, 0x4e, 0x53, 0x9f, 0xf7, 0x69, 0x8f, 0x5a, 0x69, 0x11, 0x29, 0x72, 0x39, 0xe9, 0xed, 0xec,
		0x5c, 0x14, 0xfd, 0x46, 0xf7, 0xe1, 0xa2, 0xe4, 0x37, 0xba, 0xc9, 0xcb, 0xd2, 0xf4, 0x5b, 0xf2,
		0xba, 0x7c, 0x51, 0xf4, 0x2b, 0xf3, 0xd7, 0xd5, 0x8b, 0xa2, 0x5f, 0xed, 0xee, 0xfe, 0xf5, 0xd7,
		0xc7, 0xdd, 0xef, 0x7b, 0x8f, 0xaf, 0x7f, 0x63, 0x61, 0x36, 0xd8, 0xee, 0xc3, 0xce, 0x45, 0xc9,
		0x2f, 0x77, 0xe7, 0xff, 0xb3, 0x77, 0x51, 0xf4, 0xcb, 0xdd, 0xdd, 0x5d, 0xba, 0x15, 0xda, 0xa5,
		0x7c, 0xb4, 0xed, 0xd3, 0xd6, 0x9f, 0x6c, 0xcf, 0xf7, 0x6f, 0x97, 0x1e, 0xf0, 0x2f, 0x1e, 0x18,
		0xb6, 0x83, 0x0c, 0x7b, 0x76, 0xd4, 0xcf, 0x6a, 0xe3, 0xad, 0x95, 0x4e, 0xfe, 0xf9, 0xe0, 0xe0,
		0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe0, 0xda, 0xe4, 0xeb, 0xf6, 0x32, 0x0c, 0x87, 0x22,
		0x50, 0x1c, 0x3c, 0xbb, 0x94, 0x17, 0xa8, 0x5e, 0xeb, 0x7a, 0xd0, 0x96, 0x7a, 0xd9, 0xaf, 0x1c,
		0xcf, 0x7a, 0x8f, 0xfb, 0x79, 0xf3, 0xf3, 0x42, 0xd2, 0xaa, 0x38, 0xf9, 0x56, 0xa0, 0xa8, 0xd2,
		0xbf, 0x6d, 0xb7, 0x21, 0x7e, 0x7b, 0xac, 0x4f, 0xc2, 0x58, 0xf7, 0x3a, 0xd3, 0xfb, 0x4a, 0xbe,
		0xf5, 0x4e, 0xa7, 0xf7, 0x85, 0x2e, 0x10, 0x99, 0xe7, 0x30, 0x56, 0xdf, 0x54, 0xf8, 0x9f, 0xf2,
		0x03, 0xad, 0x23, 0x79, 0x69, 0xa5, 0x29, 0xf6, 0x4a, 0xa7, 0xba, 0x64, 0x6c, 0xf4, 0x87, 0x70,
		0x95, 0xca, 0xa2, 0x3f, 0x44, 0x3e, 0xa9, 0x2a, 0xfa, 0x43, 0xbc, 0x69, 0xd6, 0xc8, 0xfa, 0x43,
		0x64, 0x9c, 0x24, 0x7d, 0x0c, 0x22, 0x7b, 0x09, 0xb4, 0x91, 0x88, 0x12, 0x22, 0x11, 0x88, 0x44,
		0x20, 0x12, 0x81, 0x48, 0x84, 0x3b, 0x91, 0x08, 0x2a, 0xf7, 0x9f, 0x0e, 0x38, 0xed, 0x86, 0xa0,
		0xa9, 0xe3, 0x1f, 0xdb, 0x99, 0x6e, 0x41, 0xd3, 0x4b, 0x20, 0x36, 0x5d, 0x9e, 0x8c, 0x33, 0x72,
		0x38, 0xe0, 0x84, 0x05, 0x37, 0xe0, 0x81, 0x1b, 0x26, 0x9c, 0x81, 0x0b, 0x67, 0x60, 0xc3, 0x19,
		0xf8, 0xa0, 0x85, 0x11, 0x62, 0x38, 0x49, 0x67, 0xf9, 0x8c, 0xc3, 0xc1, 0x6f, 0xf3, 0xd6, 0xee,
		0xcd, 0xb0, 0xfd, 0x3a, 0xc3, 0xd8, 0x99, 0xbe, 0xb1, 0x4f, 0x60, 0x97, 0xd3, 0x1c, 0x5b, 0x42,
		0xd3, 0x26, 0x6a, 0x35, 0xbb, 0xd2, 0xa6, 0xa9, 0x82, 0xda, 0x8c, 0xda, 0x15, 0xa4, 0x05, 0xa4,
		0x05, 0xa4, 0x05, 0xa4, 0x85, 0x83, 0xb4, 0x50, 0x6b, 0xe1, 0x45, 0x4d, 0x3c, 0x14, 0x8c, 0xc7,
		0xef, 0x16, 0xa4, 0xf1, 0xe4, 0x4a, 0x3e, 0x6c, 0xe4, 0x99, 0x2c, 0x2e, 0xd0, 0x71, 0x01, 0x7c,
		0xdc, 0x02, 0x21, 0x57, 0xc0, 0xc8, 0x39, 0x50, 0x72, 0x0e, 0x9c, 0x9c, 0x03, 0x29, 0x1e, 0xb0,
		0x62, 0x02, 0x2d, 0x7e, 0xc5, 0x9d, 0xf1, 0x1b, 0x63, 0xa9, 0x74, 0xa9, 0xc6, 0xe9, 0x33, 0x66,
		0x28, 0x52, 0x63, 0xbc, 0x04, 0x9e, 0xaa, 0x01, 0x2f, 0xff, 0xf0, 0xfa, 0xcc, 0x6d, 0xee, 0xaa,
		0x02, 0x8e, 0xd1, 0x8b, 0xcc, 0xe5, 0x30, 0x57, 0x1d, 0xc8, 0x5c, 0x8f, 0x03, 0x27, 0xc1, 0x1d,
		0x71, 0xa7, 0x8b, 0x26, 0x1c, 0xdc, 0xc1, 0x84, 0x7f, 0x60, 0xc2, 0xb5, 0x6a, 0x75, 0xaf, 0x0a,
		0x33, 0x76, 0x8b, 0x8b, 0xf0, 0x8f, 0xde, 0xdd, 0xda, 0x8c, 0xfb, 0xe5, 0x28, 0x9e, 0xc2, 0xb7,
		0x93, 0xbe, 0x3c, 0x6c, 0xc0, 0xb0, 0xa3, 0x8e, 0xb8, 0x01, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e,
		0x80, 0xb8, 0x41, 0x4e, 0xe2, 0x06, 0xfb, 0x0e, 0x84, 0x0d, 0xaa, 0x08, 0x1b, 0x20, 0x6c, 0x80,
		0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x58, 0x37, 0xe1, 0x72, 0x15, 0x41, 0x03, 0x04, 0x0d, 0x10,
		0x34, 0xa0, 0x0d, 0x1a, 0xdc, 0xce, 0x56, 0x9f, 0x0b, 0x51, 0x83, 0xe4, 0x5a, 0x10, 0x36, 0x40,
		0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0xe0, 0x95, 0x7e, 0xe3, 0x52, 0xaa,
		0x20, 0xba, 0x77, 0x20, 0x6e, 0xd0, 0x60, 0xbc, 0x84, 0x43, 0xa1, 0xae, 0xa7, 0x89, 0xff, 0x08,
		0x1c, 0x20, 0x70, 0xf0, 0x43, 0xd5, 0x55, 0x82, 0xe6, 0x42, 0xe0, 0x60, 0xbd, 0x4d, 0x18, 0xf9,
		0x06, 0x08, 0x1d, 0x20, 0x74, 0x40, 0x6a, 0xe6, 0xe2, 0x4e, 0x0b, 0x35, 0x20, 0x6c, 0x64, 0xbf,
		0x92, 0xf2, 0xa5, 0x57, 0x82, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01,
		0xc2, 0x06, 0xaf, 0x0d, 0x1b, 0x90, 0x17, 0xc2, 0x5d, 0x05, 0x23, 0x44, 0x85, 0x71, 0x37, 0x93,
		0xb4, 0x84, 0xa3, 0x09, 0x33, 0x0f, 0x86, 0xfc, 0xa4, 0x25, 0xbd, 0x12, 0x90, 0x16, 0x90, 0x16,
		0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x96, 0xec, 0x1c, 0x8f, 0x82,
		0x48, 0x4b, 0x17, 0x38, 0xcb, 0xfc, 0x42, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0x40,
		0x59, 0x40, 0x59, 0x40, 0x59, 0x40, 0x59, 0xb2, 0x73, 0xac, 0xa3, 0x40, 0xc5, 0x52, 0xcb, 0x5b,
		0x07, 0xf2, 0x4a, 0x9f, 0x5d, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b, 0x88, 0x0b,
		0x88, 0x0b, 0x88, 0x8b, 0xf3, 0xc4, 0x25, 0xd7, 0xe5, 0x45, 0x89, 0x3b, 0x2f, 0x66, 0xc6, 0x67,
		0xea, 0xc4, 0x98, 0x6d, 0x8e, 0x97, 0xfd, 0x51, 0x81, 0xa3, 0xb2, 0xf5, 0x36, 0x43, 0xfb, 0xc6,
		0xf3, 0xe4, 0xce, 0x9b, 0xe9, 0x5c, 0x64, 0x7e, 0x42, 0xd1, 0xe1, 0x91, 0x6f, 0xdd, 0xe5, 0xab,
		0x79, 0xce, 0xef, 0xe2, 0x9e, 0xa3, 0xfa, 0x8d, 0x77, 0x28, 0x63, 0x3d, 0x31, 0x18, 0xda, 0xce,
		0x3d, 0x47, 0x52, 0x1d, 0x0c, 0xc5, 0x84, 0x1a, 0xc5, 0xb4, 0xd2, 0xc2, 0x3b, 0x0a, 0xee, 0x9e,
		0x8d, 0x5c, 0xda, 0xaf, 0x54, 0x6a, 0xf5, 0x4a, 0xa5, 0x58, 0xdf, 0xab, 0x17, 0x1b, 0xd5, 0x6a,
		0xa9, 0x56, 0x22, 0xcc, 0x04, 0xf6, 0xda, 0xd1, 0x40, 0x44, 0x62, 0xf0, 0x79, 0xf2, 0xe8, 0xd5,
		0x78, 0x38, 0xcc, 0x95, 0x45, 0x33, 0x61, 0x94, 0xcb, 0xd8, 0xe4, 0x91, 0xf6, 0x97, 0x70, 0x0c,
		0x8d, 0x3c, 0xf4, 0xec, 0xe6, 0x5f, 0x9d, 0x9b, 0xd2, 0xb3, 0x9b, 0xbc, 0x8d, 0xb2, 0x13, 0x6b,
		0x6e, 0x6d, 0x9b, 0x79, 0x6f, 0xad, 0xd1, 0x52, 0x9a, 0x53, 0xb5, 0x24, 0xe6, 0xb5, 0x3d, 0x31,
		0x6d, 0x5f, 0xda, 0x3a, 0x3f, 0x40, 0xc3, 0xcf, 0xe8, 0xf8, 0x18, 0x2b, 0xff, 0xa2, 0xe1, 0x5b,
		0xb6, 0xcc, 0x8e, 0xc8, 0x73, 0x33, 0x79, 0x6c, 0x8b, 0xee, 0x99, 0xd8, 0x2d, 0xdb, 0x71, 0xc2,
		0xe6, 0x5d, 0xa4, 0xd9, 0x4f, 0x34, 0x6c, 0xf5, 0xb6, 0xad, 0x9d, 0xdc, 0xca, 0x2d, 0xd8, 0x37,
		0x99, 0x5d, 0x9b, 0xb5, 0x68, 0x73, 0x76, 0x67, 0xd0, 0xe6, 0x2c, 0xb5, 0xe3, 0xb3, 0xda, 0x6e,
		0xcf, 0x52, 0x3b, 0xbd, 0xa7, 0x2d, 0xdf, 0xb2, 0xe1, 0x0f, 0xb6, 0xb8, 0x95, 0x4b, 0xb3, 0x45,
		0x6b, 0x7b, 0xeb, 0x95, 0x6c, 0x4b, 0x95, 0x6c, 0xab, 0x94, 0x6c, 0x0b, 0x14, 0x68, 0x46, 0x83,
		0x66, 0xb6, 0x76, 0x57, 0x08, 0xc0, 0xcc, 0xc2, 0x6e, 0x88, 0x41, 0x2c, 0xdb, 0x72, 0xc8, 0x6e,
		0x6d, 0xd9, 0x2b, 0x9d, 0x9d, 0x7a, 0x46, 0xa9, 0x81, 0x65, 0xcb, 0x34, 0x63, 0x93, 0xef, 0xb7,
		0x20, 0x03, 0xd6, 0xe3, 0x2d, 0x3c, 0x88, 0xc8, 0x1c, 0x54, 0x3e, 0x55, 0x7a, 0x7c, 0x31, 0x80,
		0x21, 0x8b, 0x37, 0xcb, 0xa5, 0x8c, 0xa7, 0xcd, 0xd9, 0xe0, 0x4e, 0x76, 0x39, 0x93, 0x2d, 0xae,
		0x64, 0x9d, 0x23, 0x59, 0xe7, 0x46, 0xd6, 0x39, 0x91, 0x5b, 0x58, 0x62, 0xba, 0x15, 0xae, 0x37,
		0x13, 0xd4, 0xd6, 0xb4, 0x9a, 0x15, 0xc1, 0x0e, 0xb1, 0x06, 0xb1, 0x06, 0xb1, 0xb6, 0x16, 0x62,
		0xcd, 0x56, 0xef, 0xee, 0xc4, 0xb1, 0xd8, 0xb3, 0xc7, 0x05, 0xff, 0x65, 0xcb, 0x16, 0xed, 0xb8,
		0x31, 0x6b, 0xbc, 0x89, 0xd2, 0xad, 0xd1, 0xba, 0x37, 0x2a, 0x37, 0x47, 0xee, 0xee, 0xc8, 0xdd,
		0x1e, 0xb9, 0xfb, 0xb3, 0xe3, 0x06, 0x2d, 0xb9, 0x43, 0xeb, 0x6e, 0x31, 0x1d, 0x60, 0xbe, 0x93,
		0x6e, 0xdd, 0x92, 0x9f, 0x8e, 0xa4, 0xdb, 0xdc, 0xba, 0x7f, 0xe9, 0x32, 0x2d, 0x67, 0x39, 0x92,
		0x9d, 0xd4, 0xa2, 0x3c, 0x91, 0xc5, 0x73, 0xf2, 0x8a, 0xfa, 0x84, 0x15, 0xdb, 0x49, 0x2a, 0xb6,
		0x13, 0x53, 0x6c, 0x27, 0xa3, 0xd6, 0x3b, 0x79, 0x8f, 0xec, 0x44, 0x53, 0xba, 0xee, 0x86, 0x22,
		0xb8, 0x8a, 0xc4, 0x15, 0xc5, 0xa2, 0x9b, 0x33, 0xcb, 0x3a, 0xc1, 0x58, 0x27, 0xb3, 0x08, 0xf4,
		0xc7, 0x8f, 0xc9, 0x86, 0x46, 0x61, 0x0e, 0x05, 0xeb, 0x9a, 0x40, 0x67, 0x91, 0x5f, 0x8e, 0x68,
		0xdc, 0xfd, 0x13, 0x2a, 0x93, 0x90, 0x4b, 0x80, 0x32, 0x40, 0x19, 0xa0, 0x0c, 0x50, 0x06, 0x28,
		0x3b, 0x0c, 0xca, 0xc9, 0xb2, 0x03, 0x26, 0x67, 0xa6, 0xca, 0x4e, 0xb6, 0xda, 0x4a, 0x83, 0xa3,
		0x38, 0x52, 0x6b, 0x39, 0xb2, 0x08, 0x44, 0x06, 0x22, 0x03, 0x91, 0x37, 0x03, 0x91, 0x6d, 0x47,
		0x2a, 0xd3, 0x81, 0xa6, 0xa7, 0xb5, 0xa5, 0x1a, 0x08, 0xba, 0xfa, 0x44, 0x8b, 0x1d, 0x4f, 0x93,
		0xb1, 0xa9, 0x8e, 0xa8, 0x93, 0x56, 0xa2, 0x22, 0xaf, 0x3c, 0xc5, 0x51, 0x69, 0x8a, 0xb7, 0xb2,
		0x14, 0x57, 0x25, 0x29, 0xf6, 0xca, 0x51, 0xec, 0x95, 0xa2, 0xd8, 0x2b, 0x43, 0xe5, 0xab, 0x78,
		0x06, 0x79, 0xa5, 0x27, 0x06, 0x29, 0xc6, 0x21, 0xc9, 0x96, 0x49, 0xb3, 0xff, 0xf1, 0x77, 0x0a,
		0x49, 0xb1, 0xd0, 0x71, 0xfa, 0x6a, 0x26, 0xe4, 0x12, 0x98, 0xca, 0xcb, 0xf9, 0x7f, 0x02, 0x66,
		0xdd, 0x0f, 0x6f, 0x6e, 0xc6, 0x4a, 0xea, 0x7b, 0x2e, 0x76, 0xf1, 0xf2, 0x02, 0x40, 0x31, 0x40,
		0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x40, 0x31, 0x38, 0x29, 0xc6, 0x1c, 0x97, 0xa4, 0x88,
		0xd3, 0xd7, 0xf7, 0x60, 0x19, 0x6f, 0x9b, 0x72, 0x71, 0xa7, 0x7d, 0x76, 0xa6, 0xb1, 0xec, 0x22,
		0xc0, 0x36, 0xc0, 0x36, 0xc0, 0x36, 0xc0, 0x36, 0xc0, 0x36, 0xc0, 0x36, 0x38, 0xd9, 0xc6, 0x73,
		0x6c, 0x9a, 0x30, 0x8e, 0x05, 0xac, 0x02, 0xeb, 0x78, 0xdb, 0xd4, 0x4b, 0x75, 0x1b, 0x0c, 0xe5,
		0xc0, 0x8f, 0x44, 0x10, 0x13, 0xd6, 0x06, 0x4d, 0x2d, 0xfc, 0xc5, 0xf8, 0xe0, 0x1a, 0xe0, 0x1a,
		0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe4, 0xeb, 0x56, 0x0e, 0x84, 0xd2, 0x52, 0xdf, 0x33, 0xf1,
		0x0d, 0xca, 0x4a, 0xdf, 0xad, 0xd9, 0xad, 0x7e, 0x0e, 0x62, 0x06, 0x97, 0x31, 0x9f, 0xf0, 0xd6,
		0xf1, 0x1f, 0xcd, 0xc3, 0xd6, 0x97, 0x5e, 0xa7, 0x7d, 0x7e, 0x76, 0xd0, 0xeb, 0x1c, 0x34, 0x4f,
		0xdb, 0xc7, 0xd4, 0xde, 0xe3, 0x8f, 0x60, 0x38, 0x9e, 0x9e, 0xde, 0xbf, 0x20, 0xef, 0xd0, 0xc0,
		0xdc, 0x4b, 0x6c, 0x3e, 0xfb, 0xbf, 0x1e, 0x9e, 0x9f, 0x9e, 0x1d, 0x74, 0x7a, 0x87, 0xed, 0xf6,
		0x89, 0xb7, 0x09, 0x1d, 0xdd, 0x1c, 0x99, 0xf7, 0x76, 0xa7, 0xf5, 0x5b, 0xeb, 0xb8, 0x79, 0xd6,
		0xee, 0x60, 0xd6, 0xe9, 0x66, 0xbd, 0x79, 0x0a, 0x43, 0xa7, 0x76, 0x30, 0xed, 0xe3, 0xaf, 0x07,
		0x5f, 0xbc, 0x9c, 0xf7, 0x5c, 0xea, 0xe6, 0x8d, 0xef, 0xe5, 0x42, 0xdd, 0x0f, 0x83, 0x58, 0xfb,
		0x37, 0xe1, 0x40, 0x5e, 0x49, 0x31, 0xa0, 0x17, 0xf7, 0x8b, 0xc3, 0x43, 0xdb, 0x43, 0xdb, 0x43,
		0xdb, 0x43, 0xdb, 0x43, 0xdb, 0x93, 0xaf, 0x5b, 0x2d, 0x6f, 0x84, 0x96, 0xfd, 0x6f, 0x71, 0xad,
		0xc2, 0xa0, 0xed, 0xf7, 0x09, 0x87, 0x3c, 0x57, 0x72, 0xda, 0xcb, 0xc2, 0x53, 0x81, 0x0a, 0x63,
		0xd1, 0x0f, 0xd5, 0x20, 0xa6, 0xbc, 0xe5, 0x4e, 0xa0, 0xae, 0x05, 0xb9, 0x9e, 0x66, 0x68, 0x3a,
		0x79, 0x24, 0x15, 0x5f, 0x43, 0x70, 0xe6, 0x36, 0xdc, 0xd3, 0xa8, 0x09, 0xe3, 0xf8, 0x5f, 0xa3,
		0xa0, 0xaf, 0x65, 0xa8, 0xbe, 0xc8, 0xeb, 0xc4, 0xda, 0x8b, 0x1b, 0xd1, 0x8a, 0xfe, 0x28, 0xb8,
		0xdb, 0x78, 0x93, 0xe3, 0xed, 0x91, 0xe8, 0x9c, 0x15, 0xe6, 0xb4, 0x9b, 0x6a, 0x17, 0x1a, 0xf7,
		0xa7, 0xcd, 0x90, 0xaa, 0x50, 0x59, 0x86, 0x54, 0xd1, 0x14, 0x2c, 0x83, 0xae, 0x85, 0xae, 0x85,
		0xae, 0x85, 0xae, 0x85, 0xae, 0x5d, 0xb2, 0x6e, 0xc7, 0x52, 0xe9, 0xbd, 0x32, 0x83, 0xa4, 0xad,
		0x43, 0x52, 0x42, 0x52, 0x42, 0x52, 0x42, 0x52, 0xe6, 0xc0, 0xe4, 0x2a, 0xe5, 0x46, 0xa5, 0x51,
		0xab, 0x97, 0x1b, 0x10, 0x92, 0x10, 0x92, 0x9b, 0x2c, 0x24, 0x69, 0x05, 0x08, 0x6d, 0x89, 0x4d,
		0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0x48, 0xc8, 0xc8, 0x25, 0xeb, 0x76, 0xda, 0xcf, 0x90,
		0xdc, 0x86, 0xd3, 0xd4, 0xe7, 0x7d, 0xda, 0xa3, 0x56, 0x5a, 0x44, 0x8a, 0x5c, 0x4e, 0x7a, 0x3b,
		0x3b, 0x17, 0x45, 0xbf, 0xd1, 0x7d, 0xb8, 0x28, 0xf9, 0x8d, 0x6e, 0xf2, 0xb2, 0x34, 0xfd, 0x96,
		0xbc, 0x2e, 0x5f, 0x14, 0xfd, 0xca, 0xfc, 0x75, 0xf5, 0xa2, 0xe8, 0x57, 0xbb, 0xbb, 0x7f, 0xfd,
		0xf5, 0x71, 0xf7, 0xfb, 0xde, 0xe3, 0xeb, 0xdf, 0x58, 0x98, 0x0d, 0xb6, 0xfb, 0xb0, 0x73, 0x51,
		0xf2, 0xcb, 0xdd, 0xf9, 0xff, 0xec, 0x5d, 0x14, 0xfd, 0x72, 0x77, 0x77, 0x97, 0x6e, 0x85, 0x76,
		0x29, 0x1f, 0x6d, 0xfb, 0xb4, 0xf5, 0x27, 0xdb, 0xf3, 0xfd, 0xdb, 0xa5, 0x07, 0xfc, 0x8b, 0x07,
		0x86, 0xed, 0x20, 0xc3, 0x9e, 0x1d, 0xf5, 0xb3, 0xda, 0x78, 0x6b, 0xa5, 0x93, 0x7f, 0x3e, 0x38,
		0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xb8, 0x36, 0xf9, 0xba, 0xbd, 0x0c, 0xc3, 0xa1,
		0x08, 0x14, 0x07, 0xcf, 0x2e, 0xe5, 0x05, 0xaa, 0xd7, 0xba, 0x1e, 0xb4, 0xa5, 0x6e, 0xf6, 0x2b,
		0xc7, 0xa3, 0xe9, 0x72, 0x1f, 0x89, 0x42, 0xd2, 0xa9, 0x38, 0xf9, 0x56, 0xa0, 0x28, 0xd2, 0xbf,
		0x6d, 0xbf, 0x1f, 0x7e, 0x24, 0x7a, 0x9d, 0xe9, 0x6d, 0x25, 0xdf, 0x7a, 0xa7, 0xd3, 0xdb, 0x42,
		0x0f, 0x88, 0xcc, 0x63, 0x18, 0xab, 0x6f, 0x2a, 0xfc, 0x4f, 0xf9, 0x81, 0xd6, 0x91, 0xbc, 0xb4,
		0xd2, 0x12, 0x7b, 0xa5, 0x4b, 0x5d, 0x32, 0x36, 0xba, 0x43, 0xb8, 0x4a, 0x64, 0xd1, 0x1d, 0x22,
		0x9f, 0x44, 0x15, 0xdd, 0x21, 0xde, 0x34, 0x6b, 0x64, 0xdd, 0x21, 0x32, 0x4e, 0x92, 0x3e, 0x02,
		0x91, 0xbd, 0x04, 0xda, 0x38, 0x44, 0x09, 0x71, 0x08, 0xc4, 0x21, 0x10, 0x87, 0x40, 0x1c, 0xc2,
		0x9d, 0x38, 0x04, 0x95, 0xfb, 0x4f, 0x07, 0x9c, 0xf6, 0x42, 0xd0, 0xd4, 0xd1, 0x8f, 0xed, 0x4c,
		0xaf, 0xa0, 0xe9, 0x25, 0x10, 0x9b, 0x2e, 0x4f, 0xbe, 0x19, 0x39, 0x1c, 0x70, 0xc2, 0x82, 0x1b,
		0xf0, 0xc0, 0x0d, 0x13, 0xce, 0xc0, 0x85, 0x33, 0xb0, 0xe1, 0x0c, 0x7c, 0xd0, 0xc2, 0x08, 0x31,
		0x9c, 0xa4, 0xb3, 0x7c, 0xc6, 0xe1, 0xe0, 0xb7, 0x79, 0x2b, 0xf7, 0x66, 0xd8, 0x7e, 0x9d, 0x61,
		0xec, 0x4c, 0xd7, 0xd8, 0x27, 0xb0, 0xcb, 0x69, 0x86, 0x2d, 0xa1, 0x69, 0x13, 0x35, 0x9a, 0x5d,
		0x69, 0xd3, 0x54, 0x31, 0x6d, 0x46, 0xed, 0x0a, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0xc2,
		0x41, 0x5a, 0xa8, 0xb5, 0xf0, 0xa2, 0x26, 0x1e, 0x0a, 0xc6, 0xc3, 0x77, 0x0b, 0xd2, 0x78, 0x72,
		0x25, 0x1f, 0x36, 0xf2, 0x44, 0x16, 0x17, 0xe8, 0xb8, 0x00, 0x3e, 0x6e, 0x81, 0x90, 0x2b, 0x60,
		0xe4, 0x1c, 0x28, 0x39, 0x07, 0x4e, 0xce, 0x81, 0x14, 0x0f, 0x58, 0x31, 0x81, 0x16, 0xbf, 0xe2,
		0xce, 0xf8, 0x8d, 0xb1, 0x54, 0xba, 0x54, 0xe3, 0xf4, 0x19, 0x33, 0x14, 0xa9, 0x31, 0x5e, 0x02,
		0x4f, 0xcd, 0x80, 0x97, 0x7f, 0x78, 0x7d, 0xe6, 0x36, 0x77, 0x4d, 0x01, 0xc7, 0xe8, 0x45, 0xe6,
		0x72, 0x98, 0x6b, 0x0e, 0x64, 0xae, 0xc7, 0x81, 0x73, 0xe0, 0x8e, 0xb8, 0xd3, 0x45, 0x13, 0x0e,
		0xee, 0x60, 0xc2, 0x3f, 0x30, 0xe1, 0x5a, 0xb5, 0xba, 0x57, 0x85, 0x19, 0xbb, 0xc5, 0x45, 0xf8,
		0x47, 0xef, 0x6e, 0x6d, 0xc6, 0xfd, 0x72, 0x94, 0x4e, 0xe1, 0xdb, 0x49, 0x5f, 0x1e, 0x36, 0x60,
		0xd8, 0x51, 0x47, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc, 0x20, 0x27, 0x71,
		0x83, 0x7d, 0x07, 0xc2, 0x06, 0x55, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84,
		0x0d, 0xac, 0x9b, 0x70, 0xb9, 0x8a, 0xa0, 0x01, 0x82, 0x06, 0x08, 0x1a, 0xd0, 0x06, 0x0d, 0x6e,
		0x67, 0xab, 0xcf, 0x85, 0xa8, 0x41, 0x72, 0x2d, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2,
		0x06, 0x08, 0x1b, 0x20, 0x6c, 0xf0, 0x4a, 0xbf, 0x71, 0x29, 0x55, 0x10, 0xdd, 0x3b, 0x10, 0x37,
		0x68, 0x30, 0x5e, 0xc2, 0xa1, 0x50, 0xd7, 0xd3, 0xc4, 0x7f, 0x04, 0x0e, 0x10, 0x38, 0xf8, 0xa1,
		0xea, 0x2a, 0x41, 0x73, 0x21, 0x70, 0xb0, 0xde, 0x26, 0x8c, 0x7c, 0x03, 0x84, 0x0e, 0x10, 0x3a,
		0x20, 0x35, 0x73, 0x71, 0xa7, 0x85, 0x1a, 0x10, 0xb6, 0xb1, 0x5f, 0x49, 0xf9, 0xd2, 0x2b, 0x41,
		0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x83, 0xd7, 0x86, 0x0d,
		0xc8, 0xcb, 0xe0, 0xae, 0x82, 0x11, 0xa2, 0xb2, 0xb8, 0x9b, 0x49, 0x5a, 0xc2, 0xd1, 0x84, 0x99,
		0x07, 0x43, 0x7e, 0xd2, 0x92, 0x5e, 0x09, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48,
		0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x4b, 0x76, 0x8e, 0x47, 0x41, 0xa4, 0xa5, 0x0b, 0x9c, 0x65,
		0x7e, 0x21, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c,
		0xa0, 0x2c, 0xd9, 0x39, 0xd6, 0x51, 0xa0, 0x62, 0xa9, 0xe5, 0xad, 0x03, 0x79, 0xa5, 0xcf, 0xae,
		0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0xc5, 0x79,
		0xe2, 0x92, 0xeb, 0xf2, 0xa2, 0xc4, 0x7d, 0x17, 0x33, 0xe3, 0xf3, 0xf4, 0x61, 0xcc, 0xf6, 0xc6,
		0xcb, 0xfe, 0xa8, 0xc0, 0x51, 0xd8, 0x7a, 0x9b, 0xbe, 0x79, 0xe3, 0x79, 0x72, 0xe3, 0xcd, 0x74,
		0x2a, 0x32, 0x3f, 0xa1, 0xe8, 0xef, 0xc8, 0xb7, 0xea, 0xf2, 0xd5, 0x3a, 0xe7, 0x77, 0x71, 0xcf,
		0x51, 0xfb, 0xc6, 0x3b, 0x94, 0xb1, 0x9e, 0x18, 0x0c, 0x6d, 0xdf, 0x9e, 0x23, 0xa9, 0x0e, 0x86,
		0x62, 0x42, 0x8c, 0x62, 0x5a, 0x61, 0xe1, 0x1d, 0x05, 0x77, 0xcf, 0x46, 0x2e, 0xed, 0x57, 0x2a,
		0xb5, 0x7a, 0xa5, 0x52, 0xac, 0xef, 0xd5, 0x8b, 0x8d, 0x6a, 0xb5, 0x54, 0x2b, 0x11, 0xe6, 0x01,
		0x7b, 0xed, 0x68, 0x20, 0x22, 0x31, 0xf8, 0x3c, 0x79, 0xf4, 0x6a, 0x3c, 0x1c, 0xe6, 0xca, 0xa2,
		0x99, 0x10, 0xca, 0x61, 0x64, 0xf2, 0x48, 0x9b, 0x4b, 0xb8, 0x85, 0x45, 0x1e, 0xba, 0x75, 0xf3,
		0xaf, 0xcd, 0x0d, 0xe9, 0xd6, 0x4d, 0xde, 0x41, 0xd9, 0x85, 0x15, 0xb7, 0xb6, 0x6d, 0xbc, 0xb7,
		0xd6, 0x68, 0x21, 0xcd, 0x69, 0x5a, 0x12, 0xed, 0xda, 0x9e, 0x18, 0xb6, 0x2f, 0x6d, 0x9d, 0x1c,
		0xa0, 0xe1, 0x66, 0x74, 0x5c, 0x8c, 0x95, 0x7b, 0xd1, 0x70, 0x2d, 0x5b, 0x66, 0x47, 0xe4, 0xb7,
		0x79, 0xfc, 0xb5, 0x45, 0xe7, 0x4c, 0xeb, 0x94, 0xed, 0xb8, 0x60, 0xf3, 0x0e, 0xd2, 0xec, 0x27,
		0x1a, 0xb6, 0x79, 0xdb, 0xb6, 0x4e, 0x6d, 0xe3, 0x16, 0xac, 0x9b, 0xca, 0xaa, 0xcd, 0xda, 0xb3,
		0x39, 0xab, 0x33, 0x68, 0x71, 0x96, 0x9a, 0xf0, 0x59, 0x6d, 0xb2, 0x67, 0xa9, 0x89, 0xde, 0xd3,
		0x46, 0x6f, 0xd9, 0xf0, 0x07, 0x5b, 0xdc, 0xc0, 0xa5, 0xd9, 0x98, 0xb5, 0xbd, 0xe1, 0x4a, 0xb6,
		0x91, 0x4a, 0xb6, 0x41, 0x4a, 0xb6, 0xf1, 0x09, 0x2c, 0x23, 0xc1, 0x32, 0x5b, 0x7b, 0x2a, 0xf6,
		0xa1, 0xcc, 0xc2, 0x1e, 0x88, 0x41, 0x24, 0xdb, 0x72, 0xc8, 0x6a, 0x6d, 0x59, 0x2b, 0x99, 0x95,
		0x7a, 0x46, 0x79, 0x81, 0x5d, 0xbb, 0x34, 0x63, 0x91, 0xef, 0xb7, 0x1f, 0x03, 0xb6, 0xe3, 0xcd,
		0x9f, 0x87, 0x1f, 0x0c, 0x06, 0x91, 0x88, 0x63, 0x63, 0xd6, 0x93, 0xa2, 0x7b, 0x66, 0x04, 0x43,
		0x16, 0x6f, 0x36, 0xb5, 0xce, 0x78, 0xaa, 0x9c, 0x0d, 0xe6, 0x64, 0x97, 0x31, 0xd9, 0x62, 0x4a,
		0xd6, 0x19, 0x92, 0x75, 0x66, 0x64, 0x9d, 0x11, 0xb9, 0x85, 0x25, 0xc6, 0x53, 0xaf, 0x2c, 0xf6,
		0xe2, 0xb7, 0xd1, 0x63, 0x3f, 0xdb, 0x3b, 0x3f, 0xe3, 0xc3, 0x72, 0x84, 0x00, 0x66, 0x55, 0xb4,
		0x15, 0xf5, 0x6c, 0x58, 0x35, 0xc3, 0xd7, 0xc3, 0xd7, 0xc3, 0xd7, 0x27, 0x77, 0x6b, 0xba, 0xd5,
		0xb9, 0x3d, 0x42, 0x49, 0x45, 0x2c, 0x2d, 0x11, 0x4c, 0x6b, 0xce, 0x07, 0xa1, 0x3a, 0x84, 0xea,
		0x36, 0x3c, 0x54, 0x67, 0xed, 0xac, 0x40, 0x6a, 0xf7, 0x72, 0x64, 0xc9, 0xcb, 0x2c, 0xd0, 0x1b,
		0x0b, 0x85, 0xa3, 0xe7, 0x73, 0x63, 0xa7, 0x1c, 0xb4, 0xc5, 0xed, 0xec, 0xa7, 0x99, 0xbf, 0xad,
		0x58, 0x9c, 0xfb, 0xcc, 0x33, 0xd8, 0xb7, 0x38, 0xc6, 0x49, 0xa0, 0xb5, 0x88, 0x94, 0xf5, 0xea,
		0xdc, 0xde, 0xce, 0xce, 0x45, 0xd1, 0x6f, 0x74, 0x1f, 0x2e, 0x4a, 0x7e, 0xa3, 0x9b, 0xbc, 0x2c,
		0x4d, 0xbf, 0x25, 0xaf, 0xcb, 0x17, 0x45, 0xbf, 0x32, 0x7f, 0x5d, 0xbd, 0x28, 0xfa, 0xd5, 0xee,
		0xee, 0x5f, 0x7f, 0x7d, 0xdc, 0xfd, 0xbe, 0xf7, 0xf8, 0xfa, 0x37, 0xda, 0x4b, 0x5e, 0xea, 0xda,
		0x7c, 0x14, 0xed, 0xd3, 0xd6, 0x9f, 0x64, 0xcf, 0xe3, 0x6f, 0xca, 0x07, 0xf2, 0x8b, 0xc5, 0x27,
		0xb2, 0x4e, 0x99, 0x37, 0x34, 0xce, 0xa9, 0x06, 0xe7, 0xf4, 0x26, 0xe7, 0x14, 0xf8, 0x57, 0x4d,
		0xff, 0x6b, 0xf7, 0x7b, 0xe9, 0x43, 0xe5, 0xf1, 0xd3, 0xee, 0xf7, 0xfa, 0xe3, 0xcb, 0x1f, 0x3e,
		0x2c, 0xfb, 0xb5, 0xd2, 0x87, 0xfa, 0xe3, 0xa7, 0x15, 0xff, 0x52, 0x7b, 0xfc, 0xf4, 0x93, 0x9f,
		0x51, 0x7d, 0xdc, 0xc9, 0xfc, 0xea, 0xe4, 0xe7, 0xe5, 0x55, 0x6f, 0xa8, 0xac, 0x78, 0xc3, 0xde,
		0xaa, 0x37, 0xec, 0xad, 0x78, 0xc3, 0xca, 0x4b, 0x2a, 0xaf, 0x78, 0x43, 0xf5, 0xf1, 0x21, 0xf3,
		0xfb, 0x3b, 0xcb, 0x7f, 0xb5, 0xf6, 0xb8, 0xfb, 0xb0, 0xea, 0xdf, 0xea, 0x8f, 0x0f, 0x9f, 0x76,
		0xe1, 0xaa, 0x7f, 0xde, 0x55, 0xc3, 0x3c, 0xe9, 0xcd, 0x73, 0xfd, 0x80, 0x6b, 0xcb, 0xed, 0xeb,
		0xc4, 0x66, 0xf7, 0xeb, 0x3e, 0xd7, 0xda, 0x66, 0xb7, 0xe9, 0x14, 0x0c, 0x2b, 0x5b, 0xdc, 0x06,
		0xb3, 0x2d, 0x0c, 0xec, 0x6c, 0x6c, 0x31, 0x1a, 0xda, 0xfc, 0xa8, 0x80, 0xe1, 0x08, 0xa3, 0xd9,
		0x43, 0x01, 0xe6, 0x93, 0xff, 0x49, 0x92, 0xfc, 0xcd, 0x26, 0xf3, 0xbf, 0xf7, 0x41, 0x1b, 0xf6,
		0x24, 0xd6, 0x3c, 0x88, 0x67, 0x64, 0xa3, 0xcf, 0xb8, 0xcf, 0x78, 0x9f, 0xb7, 0x78, 0xfb, 0x1a,
		0x7f, 0xdb, 0x3b, 0xdf, 0x68, 0x2c, 0xa6, 0x8c, 0xc4, 0xb4, 0x71, 0xbc, 0xc3, 0x26, 0x0c, 0xda,
		0xc2, 0xdb, 0x4c, 0xe0, 0xf5, 0x0f, 0xf0, 0x75, 0xef, 0x78, 0xe5, 0xa3, 0x7e, 0xef, 0x23, 0x36,
		0xf3, 0x68, 0xdf, 0xf0, 0x40, 0xdf, 0xfd, 0x20, 0x5f, 0xf7, 0xf8, 0x7e, 0xfe, 0x21, 0xbc, 0xe2,
		0x01, 0x24, 0x51, 0x94, 0x38, 0xd2, 0xc2, 0x1f, 0x85, 0x43, 0xd9, 0xbf, 0x7f, 0xf5, 0x23, 0x58,
		0x8c, 0xc7, 0x3c, 0xff, 0xa4, 0x57, 0x9a, 0xc1, 0xdb, 0xf2, 0x0c, 0xde, 0xbc, 0xa5, 0xf7, 0x9e,
		0x2d, 0x3b, 0x33, 0x5b, 0x72, 0xef, 0xdd, 0x72, 0x33, 0xb6, 0xa5, 0x66, 0x6c, 0xcb, 0xcc, 0xd8,
		0x96, 0x98, 0x5d, 0x87, 0xf3, 0xd6, 0x7d, 0x77, 0x6f, 0x98, 0xdc, 0xd3, 0xdb, 0x9f, 0x58, 0x9a,
		0x8b, 0x35, 0xfb, 0xa0, 0x37, 0x4e, 0xf3, 0xfb, 0x52, 0x72, 0xde, 0xbd, 0x0b, 0x6e, 0x62, 0xb7,
		0xdb, 0xec, 0xae, 0xb6, 0xa9, 0xdd, 0x6b, 0xe3, 0xbb, 0xd4, 0xc6, 0x77, 0xa3, 0x8d, 0xef, 0x3a,
		0xd3, 0xd2, 0xb9, 0xf7, 0xa6, 0xbc, 0x78, 0xb3, 0xc3, 0x81, 0xef, 0x7e, 0xd0, 0x73, 0xf3, 0x33,
		0x72, 0xd8, 0xd0, 0x50, 0x8e, 0x9c, 0xb1, 0xf4, 0x14, 0x93, 0xe9, 0x28, 0x76, 0xd2, 0x4f, 0x4c,
		0xa7, 0x9b, 0x58, 0x4b, 0x2f, 0xb1, 0x96, 0x4e, 0x62, 0x2d, 0x7d, 0x84, 0x37, 0x7a, 0x63, 0x2a,
		0xa7, 0x2d, 0x59, 0x98, 0xe6, 0x53, 0x63, 0x4d, 0x9e, 0x9c, 0x47, 0x6a, 0x2c, 0x52, 0x63, 0x6d,
		0xbb, 0x09, 0xeb, 0xee, 0xc2, 0x5c, 0xd8, 0x78, 0xdb, 0xe5, 0xd4, 0xd8, 0x7e, 0x38, 0x0c, 0x23,
		0x7b, 0xf9, 0xb0, 0xc9, 0xc7, 0x23, 0x09, 0x16, 0x49, 0xb0, 0xac, 0x6e, 0x88, 0xcc, 0x1d, 0x91,
		0xb9, 0x25, 0xb3, 0xee, 0xc9, 0xb0, 0x9b, 0x4a, 0x67, 0xc1, 0x7e, 0x12, 0xac, 0xf9, 0xd3, 0x5b,
		0x19, 0x16, 0x53, 0xb7, 0xf0, 0xd9, 0x99, 0xd3, 0x5c, 0x89, 0xa3, 0xdc, 0x80, 0x02, 0x29, 0x42,
		0x0d, 0x46, 0xa1, 0x9c, 0x2e, 0x0c, 0x4b, 0x98, 0x93, 0x8e, 0x00, 0xd8, 0x01, 0xec, 0x00, 0x76,
		0x00, 0x3b, 0x80, 0x9d, 0x95, 0xb0, 0x93, 0xfa, 0xca, 0x0d, 0x40, 0x9e, 0x79, 0x75, 0x4d, 0x6b,
		0xc0, 0x63, 0xa7, 0x7c, 0x27, 0x70, 0x07, 0xb8, 0x03, 0xdc, 0x01, 0xee, 0xe4, 0x0a, 0x77, 0xe6,
		0xae, 0x12, 0x15, 0x21, 0xdf, 0x6b, 0x11, 0x6b, 0x59, 0x11, 0x12, 0x90, 0x03, 0xc8, 0x01, 0xe4,
		0x98, 0x98, 0x05, 0xd3, 0x1b, 0x02, 0xe9, 0x07, 0x4f, 0x3b, 0x07, 0x49, 0x35, 0x10, 0xf6, 0x3a,
		0x65, 0xa6, 0x4b, 0xeb, 0xd9, 0x58, 0xb6, 0xea, 0xec, 0x5b, 0xed, 0x79, 0x6a, 0xbd, 0xa7, 0x29,
		0x45, 0xcf, 0x52, 0xda, 0x9e, 0xa4, 0x54, 0x3d, 0x47, 0xc9, 0x7b, 0x8a, 0x92, 0xf7, 0x0c, 0x25,
		0xef, 0x09, 0xba, 0x5e, 0x1d, 0x36, 0xac, 0xf7, 0xec, 0x24, 0xe0, 0xe6, 0x14, 0x1c, 0x7d, 0x19,
		0x57, 0x5f, 0xfa, 0x77, 0xea, 0xac, 0x63, 0xa1, 0xe3, 0xf4, 0xd5, 0x8c, 0xd3, 0x27, 0x0e, 0x7c,
		0x5d, 0x7a, 0x16, 0x58, 0xe0, 0x70, 0x76, 0xf6, 0xd2, 0x33, 0x76, 0x66, 0x63, 0x4f, 0x1d, 0x40,
		0x09, 0xa0, 0x04, 0x50, 0x02, 0x28, 0x49, 0xd6, 0xcd, 0x58, 0x2a, 0xbd, 0x57, 0x26, 0xc0, 0x49,
		0x9b, 0x30, 0xd9, 0x09, 0xd4, 0xb5, 0xb0, 0x5e, 0xfa, 0x81, 0xa0, 0xa7, 0xde, 0x91, 0xa4, 0x6b,
		0xa8, 0x69, 0x19, 0x5e, 0x32, 0xc3, 0xfd, 0x11, 0x0c, 0xc7, 0x82, 0x70, 0xbc, 0xaf, 0x51, 0xd0,
		0xd7, 0x32, 0x54, 0x5f, 0xe4, 0xb5, 0x4c, 0x4e, 0x40, 0xdb, 0x6f, 0x20, 0x49, 0xd0, 0x8a, 0xf0,
		0x28, 0xb8, 0xcb, 0xbd, 0x89, 0x54, 0xca, 0x8d, 0x4a, 0xa3, 0x56, 0x2f, 0x37, 0xaa, 0x39, 0xb6,
		0x95, 0x35, 0xed, 0xe9, 0xd8, 0xdd, 0x68, 0x51, 0x71, 0x73, 0x33, 0x56, 0x52, 0xdf, 0x53, 0x05,
		0xe3, 0x5e, 0x0e, 0x08, 0xa1, 0x01, 0xa1, 0x01, 0xa1, 0x01, 0xa1, 0xb1, 0x86, 0x42, 0x63, 0x43,
		0x22, 0x72, 0x73, 0x8f, 0x2d, 0x45, 0x9c, 0xbe, 0xbe, 0x47, 0x50, 0x2e, 0x99, 0x3c, 0x6b, 0xf9,
		0xc6, 0x19, 0x6b, 0xb3, 0x94, 0x77, 0x0c, 0xc4, 0x04, 0x62, 0x02, 0x31, 0x81, 0x98, 0x9f, 0x68,
		0x8a, 0x07, 0x53, 0x96, 0x0e, 0x6e, 0x58, 0x1c, 0xc3, 0x6a, 0x8d, 0xf9, 0xf9, 0x1f, 0x82, 0xf0,
		0x1c, 0x71, 0xcd, 0xf9, 0xcc, 0x33, 0xda, 0x27, 0x18, 0x8b, 0xaa, 0x90, 0x6e, 0x3a, 0x60, 0x3e,
		0x6a, 0xd1, 0xa7, 0xe1, 0x11, 0x8a, 0x47, 0x44, 0x59, 0xf0, 0x38, 0x1d, 0x35, 0x2f, 0x35, 0xea,
		0xed, 0x06, 0xb2, 0x2c, 0xc3, 0x0f, 0x8f, 0xb3, 0xab, 0xc1, 0xd9, 0x19, 0x75, 0x76, 0x28, 0x1e,
		0x9e, 0xa7, 0xda, 0xf6, 0x1b, 0xe3, 0xfa, 0x61, 0xb6, 0xb9, 0xaa, 0x79, 0x4f, 0x04, 0x84, 0xd8,
		0x89, 0xb2, 0x11, 0x49, 0xbb, 0xd3, 0x3e, 0xf9, 0x6e, 0xd4, 0xb2, 0x41, 0x11, 0x5f, 0x43, 0x7c,
		0x0d, 0xf1, 0x35, 0xc4, 0xd7, 0xd6, 0x30, 0xbe, 0xb6, 0x21, 0x3b, 0x52, 0xcf, 0xbd, 0xb6, 0x14,
		0xf1, 0xc2, 0xff, 0x63, 0x67, 0x6a, 0x36, 0x89, 0x52, 0xdd, 0x06, 0x43, 0x39, 0xf0, 0x23, 0x11,
		0xc4, 0xa1, 0xb2, 0x0f, 0xa5, 0x2f, 0xc6, 0x03, 0x8a, 0x02, 0x45, 0x81, 0xa2, 0x40, 0xd1, 0x35,
		0x44, 0x51, 0x39, 0x10, 0x4a, 0x4b, 0x7d, 0x4f, 0x84, 0xa4, 0x16, 0x33, 0x42, 0xbd, 0xd6, 0xec,
		0x56, 0x3e, 0x07, 0x31, 0xc1, 0x12, 0x9d, 0x4f, 0x60, 0xeb, 0xf8, 0x8f, 0xe6, 0x61, 0xeb, 0x4b,
		0xaf, 0xd3, 0x3e, 0x3f, 0x3b, 0xe8, 0x75, 0x0e, 0x9a, 0xa7, 0xed, 0x63, 0xdb, 0xab, 0x75, 0x9a,
		0x68, 0x1b, 0x93, 0x04, 0x90, 0x88, 0x32, 0x95, 0x5f, 0xce, 0xe6, 0xaf, 0x87, 0xe7, 0xa7, 0x67,
		0x07, 0x9d, 0xde, 0x61, 0xbb, 0x7d, 0xe2, 0xe5, 0x21, 0xf1, 0x9b, 0x69, 0x1e, 0xdb, 0x9d, 0xd6,
		0x6f, 0xad, 0xe3, 0xe6, 0x59, 0xbb, 0x83, 0x59, 0x7c, 0xfb, 0x2c, 0x36, 0x4f, 0x61, 0x88, 0xef,
		0x5d, 0xd0, 0xed, 0xe3, 0xaf, 0x07, 0x5f, 0xbc, 0x35, 0xcf, 0xcb, 0xef, 0xae, 0x1b, 0x3f, 0x59,
		0x0b, 0xf5, 0x36, 0x0c, 0x62, 0xed, 0xdf, 0x84, 0x03, 0x79, 0x25, 0xc5, 0xc0, 0xbe, 0x78, 0x5b,
		0x1c, 0x0e, 0xda, 0x0d, 0xda, 0x0d, 0xda, 0x0d, 0xda, 0x6d, 0x0d, 0xb5, 0x9b, 0x96, 0x37, 0x42,
		0xcb, 0xfe, 0xb7, 0xb8, 0x56, 0x21, 0xd0, 0x6e, 0x16, 0x13, 0x3a, 0xbc, 0x73, 0x95, 0x9c, 0xdb,
		0xf3, 0x54, 0xa0, 0xc2, 0x58, 0xf4, 0x43, 0x35, 0xb0, 0x9a, 0x35, 0x89, 0x13, 0xc7, 0xee, 0x61,
		0xda, 0x72, 0x95, 0x8b, 0x13, 0xc7, 0xef, 0x36, 0x91, 0x0d, 0x38, 0x71, 0x6c, 0xa7, 0x97, 0xb5,
		0xb3, 0x56, 0x83, 0x8c, 0x8f, 0xb5, 0xd3, 0x38, 0xb6, 0x2a, 0x66, 0x67, 0x48, 0x81, 0x9d, 0xca,
		0xd9, 0xe9, 0x30, 0x5f, 0xc4, 0x55, 0x30, 0x1e, 0x4e, 0xa9, 0x5f, 0x11, 0xda, 0x09, 0xda, 0x09,
		0xda, 0x09, 0xda, 0x69, 0x1d, 0xb5, 0x13, 0x0a, 0x27, 0x41, 0xc6, 0x40, 0xc6, 0x40, 0xc6, 0x38,
		0x65, 0x22, 0x28, 0x9c, 0x04, 0xf1, 0xe2, 0xa2, 0x78, 0x99, 0x25, 0xbb, 0x19, 0x6d, 0x97, 0xbc,
		0x12, 0x99, 0x9f, 0x0f, 0x06, 0x81, 0x01, 0x81, 0x01, 0x81, 0x01, 0x81, 0xb1, 0x86, 0x02, 0xe3,
		0x32, 0x0c, 0x87, 0x22, 0x50, 0x14, 0x49, 0x75, 0xa5, 0x75, 0x81, 0x26, 0xa7, 0xdb, 0x7f, 0x34,
		0x95, 0x0a, 0x75, 0x30, 0x61, 0x43, 0x76, 0xba, 0x80, 0xc4, 0xfd, 0x7f, 0xc4, 0x4d, 0x30, 0x9a,
		0xa5, 0xfb, 0x17, 0xc2, 0x91, 0x50, 0xfd, 0x29, 0x50, 0x4c, 0xd6, 0x67, 0x61, 0xf2, 0x15, 0xc9,
		0xcb, 0x42, 0x70, 0x25, 0xfd, 0x38, 0xb8, 0x92, 0x71, 0xfa, 0xaa, 0x30, 0x3d, 0xc1, 0x1d, 0x47,
		0x5a, 0xf8, 0xa3, 0x70, 0x28, 0xfb, 0xf7, 0x85, 0x61, 0xb2, 0xae, 0x0b, 0x53, 0x8c, 0x8c, 0x93,
		0x6f, 0x05, 0x1b, 0xcd, 0x8b, 0x92, 0xeb, 0xd6, 0xd1, 0xb8, 0xaf, 0xd5, 0xcc, 0xac, 0xdb, 0xe9,
		0x65, 0x7f, 0xbe, 0x1e, 0xf5, 0x26, 0x5f, 0x1d, 0x79, 0xd9, 0x6b, 0x5e, 0xc9, 0xd3, 0xc9, 0x45,
		0xcf, 0x5f, 0xf4, 0x5a, 0xa3, 0xdb, 0xda, 0x69, 0xa4, 0xc5, 0xc9, 0xf4, 0x8a, 0x7b, 0x87, 0x61,
		0x7f, 0xf2, 0x6b, 0x9d, 0xe9, 0x05, 0x27, 0xdf, 0x7a, 0xa7, 0xd3, 0x0b, 0xde, 0x80, 0xae, 0x55,
		0x63, 0xf5, 0x4d, 0x85, 0xff, 0x29, 0x3f, 0xd0, 0x3a, 0x92, 0x97, 0x93, 0x19, 0xb0, 0xd7, 0xc2,
		0x6a, 0xc9, 0x58, 0xe8, 0x67, 0x85, 0x7e, 0x56, 0x4e, 0x70, 0x22, 0xf4, 0xb3, 0xa2, 0x05, 0x34,
		0x6b, 0xfd, 0xac, 0x32, 0x4e, 0xc6, 0xbe, 0x28, 0xcc, 0x0e, 0x69, 0x57, 0x1a, 0x96, 0x20, 0x0d,
		0x21, 0x0d, 0x21, 0x0d, 0x37, 0x49, 0x1a, 0xda, 0x72, 0x97, 0xe9, 0x00, 0xd3, 0x1e, 0x4f, 0xda,
		0xb6, 0x00, 0xdd, 0xce, 0x74, 0x03, 0x9c, 0x0e, 0x69, 0xd9, 0xb4, 0x68, 0x02, 0xe6, 0xd6, 0xdd,
		0x27, 0xa5, 0x1b, 0xe5, 0x71, 0xa7, 0xd4, 0x6e, 0x95, 0xcd, 0xbd, 0xb2, 0xb9, 0x59, 0x36, 0x77,
		0x6b, 0xd7, 0xed, 0x5a, 0x76, 0xbf, 0x74, 0x11, 0xba, 0xcc, 0xba, 0xb3, 0x5f, 0x48, 0x22, 0xc3,
		0x2e, 0xeb, 0x34, 0xc5, 0xf1, 0x16, 0x1b, 0x85, 0x3f, 0x81, 0xc1, 0x9a, 0x6e, 0xc1, 0x59, 0x34,
		0x3d, 0x4b, 0xad, 0xc5, 0x57, 0xda, 0x9c, 0xad, 0x68, 0x1d, 0xa1, 0x96, 0x01, 0x28, 0x03, 0x94,
		0x01, 0xca, 0x9b, 0x01, 0xca, 0xb6, 0xb5, 0xd1, 0xa2, 0x46, 0x1a, 0x0a, 0xc2, 0x6c, 0xb0, 0x05,
		0xa9, 0x34, 0x19, 0xf9, 0x43, 0x2e, 0x53, 0x8c, 0xa8, 0x9c, 0x34, 0x87, 0xb3, 0xe6, 0x75, 0xda,
		0x5c, 0xce, 0x9b, 0xdd, 0x89, 0xb3, 0x3b, 0x73, 0x76, 0xa7, 0x4e, 0xe3, 0xdc, 0x89, 0x9c, 0x3c,
		0xbd, 0x02, 0xcb, 0xac, 0xdb, 0xb1, 0x54, 0xba, 0x54, 0xa3, 0x5c, 0xb3, 0x33, 0x2f, 0x5c, 0x23,
		0x1c, 0x92, 0x26, 0x69, 0xfb, 0xe5, 0x1f, 0x5a, 0x9f, 0xb4, 0x4d, 0x9d, 0xd4, 0xcd, 0x0c, 0xaf,
		0x99, 0xe1, 0x89, 0x93, 0xbe, 0x33, 0xe3, 0x33, 0x24, 0xf6, 0x32, 0xb9, 0xab, 0x45, 0x93, 0x0b,
		0xee, 0x36, 0xde, 0xe4, 0x6a, 0xd5, 0xea, 0x5e, 0x75, 0x83, 0xcd, 0x6e, 0x2b, 0x9f, 0xa3, 0x75,
		0xb7, 0xf2, 0x71, 0x3f, 0x14, 0x67, 0x45, 0xe8, 0x76, 0xda, 0x96, 0xcb, 0x48, 0x82, 0x1d, 0x37,
		0xe8, 0x48, 0xe8, 0x48, 0xe8, 0x48, 0xe8, 0x48, 0xe8, 0xc8, 0x15, 0x3a, 0x72, 0x9f, 0x41, 0x46,
		0x56, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x21, 0x23, 0x73, 0x60, 0x72, 0xe5, 0x2a, 0x44, 0x24,
		0x44, 0xe4, 0xa6, 0x8b, 0xc8, 0xdb, 0xd9, 0x6a, 0xe0, 0x50, 0x91, 0xc9, 0xd8, 0x90, 0x91, 0x90,
		0x91, 0x90, 0x91, 0x90, 0x91, 0x90, 0x91, 0xe4, 0xeb, 0xf6, 0x52, 0xaa, 0x20, 0xba, 0x67, 0xd0,
		0x91, 0x0d, 0xc2, 0x21, 0x0f, 0x85, 0xba, 0x9e, 0x26, 0x8a, 0x42, 0x48, 0x6e, 0x00, 0xab, 0x2f,
		0x41, 0x48, 0x42, 0x48, 0xd2, 0x9a, 0x1c, 0xf6, 0x23, 0x21, 0x25, 0x37, 0x5c, 0x4a, 0x8a, 0x3b,
		0x2d, 0xd4, 0xc0, 0x62, 0x6f, 0x93, 0x95, 0x14, 0x26, 0x1d, 0x19, 0x32, 0x12, 0x32, 0x12, 0x32,
		0x12, 0x32, 0x12, 0x32, 0x92, 0x5e, 0x46, 0x5a, 0xaf, 0x04, 0xb6, 0xca, 0x0d, 0x5b, 0xaa, 0x0c,
		0x96, 0x4f, 0x90, 0x0e, 0x47, 0x13, 0xa6, 0x18, 0x0c, 0xe9, 0x41, 0x3a, 0x1d, 0x19, 0x20, 0x0d,
		0x90, 0x06, 0x48, 0x03, 0xa4, 0x01, 0xd2, 0x00, 0x69, 0x80, 0xf4, 0xb2, 0x39, 0x1b, 0x05, 0x91,
		0x96, 0x1c, 0x18, 0x3d, 0x1f, 0x18, 0x10, 0x0d, 0x88, 0x06, 0x44, 0x03, 0xa2, 0x01, 0xd1, 0x80,
		0x68, 0x40, 0xf4, 0xb2, 0x39, 0xd3, 0x51, 0xa0, 0x62, 0xa9, 0xe5, 0x2d, 0x43, 0xde, 0xd4, 0xb3,
		0xb1, 0x01, 0xd4, 0x00, 0x6a, 0x00, 0x35, 0x80, 0x1a, 0x40, 0x0d, 0xa0, 0x5e, 0x43, 0xa0, 0x5e,
		0xeb, 0x72, 0x51, 0x96, 0x5b, 0x69, 0x64, 0xc6, 0xb3, 0xdc, 0x5a, 0x23, 0xdb, 0x54, 0x21, 0xfb,
		0xa3, 0x02, 0x45, 0x45, 0xbf, 0x6d, 0x9b, 0xfd, 0x38, 0xce, 0x93, 0x5b, 0x6a, 0xa6, 0x37, 0x99,
		0xf9, 0x89, 0x8d, 0x96, 0x1d, 0x74, 0x86, 0xbf, 0x5e, 0xd5, 0xa8, 0x7f, 0x17, 0xf7, 0x14, 0xc7,
		0xc9, 0xbd, 0x43, 0x19, 0xeb, 0xc9, 0x03, 0xb6, 0x5b, 0xfa, 0xfa, 0x48, 0xaa, 0x83, 0xa1, 0x98,
		0x60, 0x7b, 0x6c, 0x97, 0xbb, 0x7a, 0x47, 0xc1, 0xdd, 0xb3, 0x91, 0x68, 0xfb, 0xc2, 0x7b, 0xed,
		0x68, 0x20, 0x22, 0x31, 0xf8, 0x3c, 0x79, 0x74, 0x6a, 0x3c, 0x1c, 0xae, 0x95, 0xc5, 0x11, 0x39,
		0x6d, 0x17, 0x9c, 0xb5, 0x67, 0xb5, 0x90, 0x2c, 0x97, 0x7b, 0xf6, 0xd0, 0x06, 0xcc, 0xfd, 0x65,
		0x40, 0x6f, 0xfe, 0xeb, 0xd4, 0x13, 0x2c, 0x63, 0xe4, 0xce, 0xf6, 0x07, 0xdb, 0x72, 0xc8, 0x76,
		0xe7, 0x64, 0x61, 0x62, 0x54, 0xbe, 0x1c, 0x6c, 0x0b, 0x35, 0x18, 0x85, 0x52, 0xe9, 0xed, 0x7e,
		0x38, 0x0c, 0x23, 0x43, 0xcf, 0xdf, 0x0e, 0x53, 0xb0, 0xc7, 0x0c, 0x48, 0x99, 0x80, 0x1d, 0xe4,
		0x37, 0x65, 0x1e, 0x96, 0x5c, 0x9a, 0x65, 0x57, 0x66, 0xd0, 0x6f, 0xd9, 0xf2, 0x57, 0x66, 0xbc,
		0xd3, 0xfb, 0x7d, 0xc9, 0xfb, 0x3e, 0xe1, 0x9d, 0x66, 0x66, 0xda, 0xbc, 0xac, 0x99, 0x95, 0x01,
		0x83, 0x32, 0x6f, 0x48, 0xef, 0x33, 0xa1, 0xb7, 0x3f, 0xf8, 0xb7, 0xbd, 0xf3, 0x8d, 0xa6, 0x62,
		0xca, 0x44, 0xcc, 0x9b, 0xc6, 0x3b, 0x6c, 0xc2, 0xa0, 0x2d, 0xbc, 0xcd, 0x08, 0x5e, 0xff, 0x08,
		0xdf, 0xf0, 0xf8, 0x3c, 0x25, 0xe4, 0xf5, 0x3f, 0x97, 0x61, 0xf4, 0xf6, 0xa6, 0xa5, 0x69, 0x5c,
		0xf8, 0xe9, 0xa3, 0xde, 0x68, 0x46, 0xef, 0x6b, 0x68, 0xf1, 0xee, 0xcd, 0x33, 0x13, 0x9b, 0x61,
		0x66, 0x37, 0xb7, 0x4c, 0x6d, 0x56, 0x19, 0xdf, 0x7c, 0x32, 0xbe, 0x99, 0x64, 0x7c, 0x73, 0x88,
		0xd6, 0x01, 0xbe, 0xb7, 0x81, 0x42, 0xba, 0x76, 0xde, 0xff, 0xa8, 0x5f, 0xae, 0xc6, 0xf7, 0x3e,
		0x69, 0x33, 0x5d, 0x66, 0x8c, 0xed, 0x6c, 0x9b, 0xdc, 0xb1, 0xb6, 0xb3, 0x13, 0x6d, 0x7a, 0x87,
		0xd9, 0xda, 0xce, 0xb1, 0xb5, 0x1d, 0x61, 0x6b, 0x3b, 0xbd, 0xbc, 0x44, 0xd8, 0x54, 0x97, 0x14,
		0x2f, 0x18, 0xfc, 0x3b, 0x9d, 0x13, 0xa9, 0xfc, 0x51, 0x18, 0x6b, 0x73, 0x96, 0x92, 0xd6, 0x17,
		0x7a, 0x31, 0x80, 0xa9, 0x38, 0x84, 0xd1, 0x86, 0x53, 0xc6, 0x93, 0x5d, 0x6c, 0x24, 0xb3, 0xd8,
		0x4d, 0x56, 0xb1, 0x95, 0x8c, 0x62, 0x3d, 0xd9, 0xc4, 0x7a, 0x32, 0x89, 0xf5, 0x64, 0x11, 0xb7,
		0x22, 0x7c, 0xa6, 0x1b, 0x30, 0x79, 0x33, 0x49, 0x6c, 0xdc, 0xb0, 0xe6, 0xcb, 0xc1, 0x98, 0xe4,
		0xb6, 0xe8, 0x60, 0xac, 0x39, 0x1a, 0x9b, 0x0e, 0x87, 0xc6, 0xf1, 0xd8, 0x76, 0x40, 0x64, 0x8e,
		0x88, 0xcc, 0x21, 0x91, 0x39, 0x26, 0xb3, 0x0e, 0xca, 0xb0, 0xa3, 0xb2, 0xe6, 0xb0, 0x16, 0x1d,
		0x97, 0x3d, 0x7b, 0x5c, 0xf0, 0x5f, 0xb6, 0x6c, 0xd1, 0x6e, 0x63, 0x4e, 0xeb, 0x49, 0xc2, 0x14,
		0x49, 0xc1, 0xb4, 0x49, 0xc0, 0x54, 0x49, 0xbf, 0xe4, 0x49, 0xbe, 0xe4, 0x49, 0xbd, 0xe4, 0x49,
		0xbc, 0xeb, 0x95, 0xd6, 0x65, 0xbb, 0x91, 0xa6, 0x97, 0x6c, 0xf9, 0x92, 0xf5, 0x31, 0x36, 0xb9,
		0xc3, 0xfc, 0x23, 0x77, 0x59, 0x44, 0x1f, 0x63, 0xc7, 0xdd, 0x28, 0xb5, 0x3b, 0x65, 0x73, 0xab,
		0x6c, 0xee, 0x95, 0xcd, 0xcd, 0xda, 0x75, 0xb7, 0x96, 0xdd, 0x6e, 0x3a, 0x6b, 0x64, 0x67, 0x22,
		0xd2, 0x75, 0x37, 0x14, 0xc1, 0x55, 0x24, 0xae, 0x28, 0x16, 0xdd, 0x9c, 0x55, 0xd6, 0x09, 0xc6,
		0x3a, 0x99, 0x6d, 0xc1, 0x7e, 0xfc, 0x98, 0x24, 0xbe, 0x17, 0x12, 0x20, 0x58, 0xd7, 0xd4, 0x70,
		0x8b, 0xcc, 0x72, 0x9e, 0x8c, 0x45, 0x87, 0xc9, 0xe9, 0x88, 0x80, 0x65, 0xc0, 0x32, 0x60, 0x19,
		0xb0, 0x0c, 0x58, 0xde, 0x58, 0x58, 0x4e, 0xb1, 0x00, 0xc8, 0x9c, 0x99, 0xac, 0x59, 0xba, 0x34,
		0x1d, 0x30, 0xcf, 0x07, 0x04, 0x2e, 0x03, 0x97, 0x81, 0xcb, 0xc0, 0x65, 0xe0, 0xf2, 0xc6, 0xe2,
		0xf2, 0x1c, 0x0a, 0x00, 0xcb, 0x99, 0xb9, 0x4a, 0x0e, 0xd2, 0x93, 0x81, 0x32, 0xc5, 0xb9, 0x7d,
		0xcb, 0x1b, 0x7e, 0x80, 0x64, 0x40, 0x32, 0x20, 0x79, 0x33, 0x20, 0xd9, 0xf6, 0x06, 0x62, 0x3a,
		0xd0, 0xb4, 0xf2, 0x84, 0x54, 0x03, 0x71, 0xc7, 0xd4, 0xfe, 0x32, 0x19, 0x1b, 0x65, 0xdc, 0xd6,
		0xcd, 0x61, 0xf3, 0x3a, 0x6e, 0x2e, 0x07, 0xce, 0xee, 0xc8, 0xd9, 0x1d, 0x3a, 0xbb, 0x63, 0xa7,
		0x71, 0xf0, 0x44, 0x8e, 0x9e, 0x5e, 0x83, 0x31, 0x6a, 0x31, 0x0e, 0x4d, 0xb6, 0x4c, 0x9b, 0xfd,
		0x8f, 0xbf, 0x53, 0x48, 0x8a, 0x85, 0x8e, 0xd3, 0x57, 0x33, 0x25, 0x97, 0xc0, 0x14, 0xea, 0xc3,
		0xfe, 0xf4, 0x7c, 0x5f, 0x8a, 0x58, 0xfb, 0xb3, 0x23, 0xbc, 0xc4, 0xbc, 0xe2, 0x69, 0x68, 0xd0,
		0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0xd0, 0x0a, 0xf2, 0x75, 0x8b, 0xea, 0xb0, 0x6b, 0x01,
		0xd3, 0x34, 0x89, 0xc4, 0x19, 0xeb, 0xa0, 0x48, 0x28, 0x06, 0x3c, 0x03, 0x9e, 0x01, 0xcf, 0x80,
		0x67, 0xc0, 0xf3, 0x92, 0x75, 0x3b, 0x96, 0x4a, 0xef, 0x95, 0x19, 0xd0, 0x99, 0x52, 0xf3, 0x77,
		0x02, 0x75, 0x3d, 0xb9, 0xdb, 0x0b, 0xd2, 0x35, 0xf2, 0x9d, 0xbc, 0xf9, 0xbc, 0x77, 0x24, 0x15,
		0xb9, 0x33, 0x64, 0x82, 0xd7, 0xcc, 0xf0, 0x7f, 0x04, 0xc3, 0xb1, 0x60, 0x1c, 0xff, 0x6b, 0x14,
		0xf4, 0xb5, 0x0c, 0xd5, 0x17, 0x79, 0x2d, 0x93, 0xea, 0x96, 0xe4, 0xd7, 0xf1, 0xf8, 0x81, 0xc1,
		0xe4, 0x82, 0xbb, 0x8d, 0x37, 0xb9, 0x4a, 0xb9, 0x51, 0x69, 0xd4, 0xea, 0xe5, 0x46, 0x75, 0x83,
		0x6d, 0x6f, 0x2b, 0x9f, 0xa3, 0x75, 0x21, 0x22, 0x5f, 0x21, 0x22, 0x6f, 0x6e, 0xc6, 0x4a, 0xea,
		0x7b, 0xae, 0x9d, 0xe4, 0x97, 0x17, 0x00, 0x61, 0x09, 0x61, 0x09, 0x61, 0x09, 0x61, 0x09, 0x61,
		0x49, 0xbe, 0x6e, 0xb1, 0x9d, 0xfc, 0xec, 0xef, 0x1c, 0x97, 0xa4, 0x88, 0xd3, 0xd7, 0xf7, 0xd8,
		0x51, 0x7e, 0xdb, 0x94, 0x93, 0x1d, 0xb1, 0xcd, 0xd8, 0x34, 0xd1, 0x51, 0x5b, 0xf0, 0x0a, 0xf0,
		0x0a, 0xf0, 0x0a, 0xf0, 0x0a, 0xf0, 0x8a, 0x25, 0xeb, 0x56, 0x8e, 0xfc, 0x60, 0x30, 0x88, 0x44,
		0x1c, 0x73, 0x50, 0x8b, 0x06, 0xe1, 0x98, 0xb3, 0x39, 0xce, 0x7d, 0xd0, 0xfa, 0xe9, 0xc9, 0xde,
		0x56, 0x18, 0x9e, 0x6d, 0xe6, 0x19, 0xef, 0x33, 0x8c, 0x7d, 0x12, 0x68, 0x2d, 0x22, 0x45, 0xfe,
		0xb8, 0xd3, 0x0b, 0xd8, 0xd9, 0xb9, 0x28, 0xfa, 0x8d, 0xee, 0xc3, 0x45, 0xc9, 0x6f, 0x74, 0x93,
		0x97, 0xa5, 0xe9, 0xb7, 0xe4, 0x75, 0xf9, 0xa2, 0xe8, 0x57, 0xe6, 0xaf, 0xab, 0x17, 0x45, 0xbf,
		0xda, 0xdd, 0xfd, 0xeb, 0xaf, 0x8f, 0xbb, 0xdf, 0xf7, 0x1e, 0x5f, 0xff, 0x46, 0x8f, 0xfc, 0x16,
		0xbb, 0x1c, 0x8f, 0xb4, 0x7d, 0xda, 0xfa, 0x93, 0xfd, 0xb9, 0xfe, 0x4d, 0xf9, 0x60, 0x7f, 0x61,
		0x78, 0xb2, 0xb4, 0x61, 0xe7, 0x0f, 0x1b, 0xe4, 0x8c, 0x6b, 0x70, 0xc6, 0xac, 0xce, 0x38, 0xf0,
		0xaf, 0x9a, 0xfe, 0xd7, 0xee, 0xf7, 0xd2, 0x87, 0xca, 0xe3, 0xa7, 0xdd, 0xef, 0xf5, 0xc7, 0x97,
		0x3f, 0x7c, 0x58, 0xf6, 0x6b, 0xa5, 0x0f, 0xf5, 0xc7, 0x4f, 0x2b, 0xfe, 0xa5, 0xf6, 0xf8, 0xe9,
		0x27, 0x3f, 0xa3, 0xfa, 0xb8, 0x93, 0xf9, 0xd5, 0xc9, 0xcf, 0xcb, 0xab, 0xde, 0x50, 0x59, 0xf1,
		0x86, 0xbd, 0x55, 0x6f, 0xd8, 0x5b, 0xf1, 0x86, 0x95, 0x97, 0x54, 0x5e, 0xf1, 0x86, 0xea, 0xe3,
		0x43, 0xe6, 0xf7, 0x77, 0x96, 0xff, 0x6a, 0xed, 0x71, 0xf7, 0x61, 0xd5, 0xbf, 0xd5, 0x1f, 0x1f,
		0x3e, 0xed, 0x02, 0x9a, 0xe8, 0xa1, 0x09, 0x66, 0x4e, 0x6f, 0xe6, 0xf9, 0x07, 0x6a, 0xec, 0x0f,
		0xbb, 0x18, 0xb9, 0xbd, 0xd3, 0x3e, 0xfb, 0x1e, 0xf1, 0xb2, 0x8b, 0x40, 0x3c, 0x17, 0xf1, 0x5c,
		0xc4, 0x73, 0x11, 0xcf, 0x45, 0x3c, 0x97, 0x7c, 0xdd, 0x62, 0x9f, 0xf8, 0xd9, 0xdf, 0xe7, 0xd8,
		0x24, 0x45, 0xbc, 0xf0, 0xff, 0xd8, 0x2f, 0x7e, 0xe3, 0xd4, 0x4b, 0x75, 0x1b, 0x0c, 0xe5, 0xc0,
		0x8f, 0x44, 0x10, 0x87, 0x8a, 0x9e, 0x70, 0xbc, 0x18, 0x1f, 0x5c, 0x03, 0x5c, 0x03, 0x5c, 0x03,
		0x5c, 0x03, 0x5c, 0x83, 0x7c, 0xdd, 0xca, 0x81, 0x50, 0x5a, 0xea, 0x7b, 0x26, 0xbe, 0x41, 0x78,
		0x3a, 0xc0, 0x6b, 0xcd, 0x6e, 0xf5, 0x73, 0x10, 0x33, 0xb8, 0x8c, 0xf9, 0x84, 0xb7, 0x8e, 0xff,
		0x68, 0x1e, 0xb6, 0xbe, 0xf4, 0x3a, 0xed, 0xf3, 0xb3, 0x83, 0x5e, 0xe7, 0xa0, 0x79, 0xda, 0x3e,
		0xa6, 0xf6, 0x1e, 0xd3, 0x43, 0x1a, 0x31, 0x4b, 0x98, 0x93, 0xe9, 0x54, 0xcc, 0xcb, 0xd9, 0xff,
		0xf5, 0xf0, 0xfc, 0xf4, 0xec, 0xa0, 0xd3, 0x3b, 0x6c, 0xb7, 0x4f, 0xbc, 0x4d, 0x38, 0x94, 0xe4,
		0xc8, 0xbc, 0xb7, 0x3b, 0xad, 0xdf, 0x5a, 0xc7, 0xcd, 0xb3, 0x76, 0x07, 0xb3, 0x4e, 0x37, 0xeb,
		0xcd, 0x53, 0x18, 0x3a, 0xb5, 0x83, 0x69, 0x1f, 0x7f, 0x3d, 0xf8, 0xe2, 0xe5, 0xfc, 0xcc, 0x59,
		0x37, 0x6f, 0x7c, 0x2f, 0x17, 0xea, 0x7e, 0x18, 0xc4, 0xda, 0xbf, 0x09, 0x07, 0xf2, 0x4a, 0x8a,
		0x01, 0xbd, 0xb8, 0x5f, 0x1c, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x9e,
		0x7c, 0xdd, 0x6a, 0x79, 0x23, 0xb4, 0xec, 0x7f, 0x8b, 0x6b, 0x15, 0x06, 0x6d, 0x4f, 0x98, 0xa6,
		0xe6, 0x9d, 0xab, 0xe4, 0x8c, 0xbf, 0xa7, 0x02, 0x15, 0xc6, 0xa2, 0x1f, 0xaa, 0x01, 0x69, 0x2e,
		0x3c, 0xaa, 0xa9, 0xe4, 0x0f, 0xe3, 0x97, 0x47, 0x4d, 0x50, 0x4d, 0x85, 0xdc, 0xe4, 0x50, 0x4d,
		0x65, 0xbb, 0xb4, 0x5f, 0xa9, 0xd4, 0xea, 0x95, 0x4a, 0xb1, 0xbe, 0x57, 0x2f, 0x36, 0xaa, 0xd5,
		0x52, 0xad, 0x84, 0xba, 0x2a, 0xb9, 0x1b, 0x0d, 0x79, 0x73, 0x3f, 0x6f, 0x86, 0x54, 0xad, 0x0b,
		0x33, 0xa4, 0x8a, 0xa6, 0x85, 0x61, 0x3a, 0xec, 0x17, 0x71, 0x15, 0x8c, 0x87, 0x53, 0x2a, 0x5e,
		0x84, 0x96, 0x86, 0x96, 0x86, 0x96, 0x86, 0x96, 0x86, 0x96, 0x46, 0x51, 0x50, 0xc8, 0x58, 0xc8,
		0x58, 0xc8, 0x58, 0xc8, 0xd8, 0xb5, 0x32, 0x39, 0x14, 0x05, 0x85, 0x78, 0x85, 0x78, 0xdd, 0xf6,
		0x66, 0xc9, 0xcf, 0xe1, 0x58, 0x0b, 0x7a, 0x01, 0xfb, 0x7c, 0x70, 0x08, 0x4a, 0x08, 0x4a, 0x08,
		0x4a, 0x08, 0x4a, 0x08, 0x4a, 0xf2, 0x75, 0x8b, 0x26, 0x50, 0x8e, 0x8f, 0x60, 0xbb, 0x8f, 0x75,
		0x53, 0xa9, 0x50, 0x07, 0x13, 0x36, 0x4a, 0xd3, 0xce, 0x3a, 0xee, 0xff, 0x23, 0x6e, 0x82, 0x59,
		0xdb, 0x49, 0xaf, 0x10, 0x8e, 0x84, 0xea, 0x4f, 0x81, 0x72, 0xe2, 0x3f, 0x0a, 0x93, 0xaf, 0x48,
		0x5e, 0x16, 0x82, 0x2b, 0xe9, 0xc7, 0xc1, 0x95, 0x8c, 0xd3, 0x57, 0x85, 0x69, 0xdd, 0x9b, 0x38,
		0xd2, 0xc2, 0x1f, 0x85, 0x43, 0xd9, 0xbf, 0x2f, 0x28, 0x21, 0xaf, 0xff, 0xb9, 0x0c, 0xa3, 0x38,
		0x7d, 0x55, 0x08, 0x06, 0xff, 0x4e, 0x5d, 0x91, 0x54, 0xfe, 0x28, 0x8c, 0x75, 0x61, 0x4a, 0x2f,
		0xe2, 0xe4, 0x5b, 0x72, 0x48, 0x8f, 0xa2, 0x65, 0x7d, 0xac, 0xa3, 0x71, 0x5f, 0xab, 0xd9, 0x0a,
		0x6b, 0xa7, 0x77, 0xf8, 0xf9, 0x7a, 0xd4, 0x9b, 0x7c, 0x75, 0xe4, 0x65, 0xaf, 0x79, 0x25, 0x4f,
		0x27, 0xf7, 0x37, 0x7f, 0xd1, 0x6b, 0x8d, 0x6e, 0x6b, 0xa7, 0x91, 0x16, 0x27, 0xd3, 0x9b, 0xeb,
		0x1d, 0xcf, 0x6f, 0x2e, 0x7d, 0xd5, 0x6b, 0x0e, 0xfe, 0xed, 0xc8, 0xcb, 0x96, 0x3a, 0x09, 0x63,
		0xdd, 0xeb, 0x4c, 0xef, 0x2c, 0xf9, 0xd6, 0x3b, 0x9d, 0xde, 0xd9, 0xd6, 0x7a, 0x1a, 0xb9, 0x45,
		0x03, 0xf7, 0xc6, 0xea, 0x9b, 0x0a, 0xff, 0x53, 0x7e, 0xa0, 0x75, 0x24, 0x2f, 0x27, 0x33, 0x66,
		0xdd, 0xc8, 0x9f, 0x42, 0x75, 0xd9, 0xb1, 0x2d, 0x2f, 0xe5, 0xb9, 0x63, 0xb5, 0x3c, 0x0c, 0x15,
		0xaf, 0xa5, 0xe4, 0xb3, 0x3c, 0x3c, 0x96, 0x9a, 0xbf, 0xb2, 0xf1, 0x56, 0x36, 0xbe, 0xca, 0xc6,
		0x53, 0xd7, 0x9b, 0x14, 0x7c, 0x91, 0x34, 0x1d, 0x27, 0xb3, 0x4e, 0x92, 0x3e, 0x10, 0x91, 0xbd,
		0x04, 0xda, 0x70, 0x44, 0x09, 0xe1, 0x08, 0x84, 0x23, 0x10, 0x8e, 0x40, 0x38, 0xc2, 0x9d, 0x70,
		0x04, 0x95, 0xfb, 0x4f, 0x07, 0x9c, 0xf8, 0x5e, 0x5f, 0x53, 0x07, 0x41, 0x16, 0x3c, 0xc6, 0xd3,
		0x25, 0x10, 0x9b, 0x2e, 0xcf, 0xa6, 0x18, 0x39, 0x1c, 0x70, 0xc2, 0x82, 0x1b, 0xf0, 0xc0, 0x0d,
		0x13, 0xce, 0xc0, 0x85, 0x33, 0xb0, 0xe1, 0x0c, 0x7c, 0xd0, 0xc2, 0x08, 0x31, 0x9c, 0xa4, 0xb3,
		0x7c, 0xc6, 0xe1, 0xe0, 0xb7, 0x79, 0x4b, 0x9a, 0x65, 0xd8, 0x7e, 0x9d, 0xa7, 0x6c, 0xf6, 0xbc,
		0xc4, 0x59, 0x52, 0xa9, 0xec, 0x09, 0xec, 0x72, 0x9a, 0x06, 0x40, 0x68, 0xda, 0x5e, 0x12, 0x57,
		0x66, 0x23, 0x2e, 0x54, 0x61, 0x6d, 0x46, 0xed, 0x0a, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2,
		0xc2, 0x41, 0x5a, 0xa8, 0xb5, 0xf0, 0xa2, 0x26, 0x1e, 0x0a, 0xc6, 0x0c, 0xe1, 0x05, 0x69, 0x3c,
		0xb9, 0x92, 0x0f, 0x1b, 0x99, 0x36, 0xca, 0x05, 0x3a, 0x2e, 0x80, 0x8f, 0x5b, 0x20, 0xe4, 0x0a,
		0x18, 0x39, 0x07, 0x4a, 0xce, 0x81, 0x93, 0x73, 0x20, 0xc5, 0x03, 0x56, 0x4c, 0xa0, 0xc5, 0xaf,
		0xb8, 0x33, 0x7e, 0x63, 0x2c, 0x95, 0x2e, 0xd5, 0x38, 0x7d, 0xc6, 0x0c, 0x45, 0x6a, 0x8c, 0x97,
		0xc0, 0x73, 0xb0, 0xe9, 0xe5, 0x1f, 0x5e, 0x9f, 0xb9, 0xcd, 0x7d, 0xf0, 0xc9, 0x31, 0x7a, 0x91,
		0xb9, 0x1c, 0xe6, 0x83, 0x51, 0x99, 0xeb, 0x71, 0xe0, 0xb0, 0x8a, 0x23, 0xee, 0x74, 0xd1, 0x84,
		0x83, 0x3b, 0x98, 0xf0, 0x0f, 0x4c, 0xb8, 0x56, 0xad, 0xee, 0x55, 0x61, 0xc6, 0x6e, 0x71, 0x11,
		0xfe, 0xd1, 0xbb, 0x5b, 0x9b, 0x71, 0xbf, 0x1c, 0xe7, 0x3b, 0xf9, 0x76, 0xd2, 0x97, 0x87, 0x0d,
		0x18, 0x76, 0xd4, 0x11, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0xc8, 0x49,
		0xdc, 0x60, 0xdf, 0x81, 0xb0, 0x41, 0x15, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00,
		0x61, 0x03, 0xeb, 0x26, 0x5c, 0xae, 0x22, 0x68, 0x80, 0xa0, 0x01, 0x82, 0x06, 0xb4, 0x41, 0x83,
		0xdb, 0xd9, 0xea, 0x73, 0x21, 0x6a, 0x90, 0x5c, 0x0b, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80,
		0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0xbc, 0xd2, 0x6f, 0x5c, 0x4a, 0x15, 0x44, 0xf7, 0x0e, 0xc4,
		0x0d, 0x1a, 0x8c, 0x97, 0x70, 0x28, 0xd4, 0xf5, 0x34, 0xf1, 0x1f, 0x81, 0x03, 0x04, 0x0e, 0x7e,
		0xa8, 0xba, 0x4a, 0xd0, 0x5c, 0x08, 0x1c, 0xac, 0xb7, 0x09, 0x23, 0xdf, 0x00, 0xa1, 0x03, 0x84,
		0x0e, 0x48, 0xcd, 0x5c, 0xdc, 0x69, 0xa1, 0x06, 0x84, 0xfd, 0x3d, 0x57, 0x52, 0xbe, 0xf4, 0x4a,
		0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0xe0, 0xb5, 0x61,
		0x03, 0xf2, 0x6a, 0xb8, 0xab, 0x60, 0x84, 0xa8, 0x3a, 0xee, 0x66, 0x92, 0x96, 0x70, 0x34, 0x61,
		0xe6, 0xc1, 0x90, 0x9f, 0xb4, 0xa4, 0x57, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02,
		0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x92, 0x9d, 0xe3, 0x51, 0x10, 0x69, 0xe9, 0x02, 0x67,
		0x99, 0x5f, 0x08, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28,
		0x0b, 0x28, 0x4b, 0x76, 0x8e, 0x75, 0x14, 0xa8, 0x58, 0x6a, 0x79, 0xeb, 0x40, 0x5e, 0xe9, 0xb3,
		0x6b, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x71,
		0x9e, 0xb8, 0xe4, 0xba, 0xbc, 0x28, 0x71, 0xfb, 0xc5, 0xcc, 0xf8, 0x7c, 0xed, 0x18, 0xb3, 0xfd,
		0xf1, 0xb2, 0x3f, 0x2a, 0x70, 0x14, 0xb7, 0xde, 0x66, 0xe9, 0xe1, 0x78, 0x9e, 0xdc, 0x7b, 0x33,
		0x9d, 0x8d, 0xcc, 0x4f, 0x28, 0xda, 0x3c, 0xf2, 0x2d, 0xbe, 0x7c, 0x75, 0xd0, 0xf9, 0x5d, 0xdc,
		0x73, 0x94, 0xc0, 0xf1, 0x0e, 0x65, 0xac, 0x27, 0x06, 0x43, 0xdb, 0xbe, 0xe7, 0x48, 0xaa, 0x83,
		0xa1, 0x98, 0xf0, 0xa3, 0x98, 0x56, 0x5f, 0x78, 0x47, 0xc1, 0xdd, 0xb3, 0x91, 0x4b, 0xfb, 0x95,
		0x4a, 0xad, 0x5e, 0xa9, 0x14, 0xeb, 0x7b, 0xf5, 0x62, 0xa3, 0x5a, 0x2d, 0xd5, 0x4a, 0x84, 0xe9,
		0xc0, 0x5e, 0x3b, 0x1a, 0x88, 0x48, 0x0c, 0x3e, 0x4f, 0x1e, 0xbd, 0x1a, 0x0f, 0x87, 0xb9, 0xb2,
		0x68, 0x26, 0xa0, 0x72, 0x1c, 0xa0, 0x3c, 0xd2, 0x3e, 0x13, 0xce, 0x41, 0x92, 0x87, 0x16, 0xde,
		0xfc, 0x4b, 0x74, 0x83, 0x5a, 0x78, 0x93, 0xf7, 0x54, 0x76, 0x64, 0xe1, 0xad, 0x6d, 0x6f, 0xef,
		0xad, 0x35, 0x5a, 0x4f, 0x73, 0xd2, 0x36, 0x31, 0x6c, 0x5f, 0x0e, 0xb6, 0x85, 0x1a, 0x8c, 0x42,
		0xa9, 0xf4, 0x76, 0x3f, 0x1c, 0x86, 0x91, 0x25, 0x43, 0xa3, 0x61, 0x6c, 0x74, 0x0c, 0x8d, 0x95,
		0x91, 0xd1, 0x30, 0x30, 0x5b, 0xe6, 0x47, 0xe4, 0xc6, 0xf9, 0xdc, 0xb7, 0x45, 0x5f, 0x4d, 0xee,
		0xa3, 0xed, 0x78, 0x64, 0xf3, 0xfe, 0xd2, 0xec, 0x27, 0x1a, 0x36, 0x7d, 0xdb, 0x26, 0xcf, 0x61,
		0xea, 0x16, 0x8c, 0x9c, 0xd0, 0xb8, 0xcd, 0x9a, 0xb5, 0x39, 0xe3, 0x33, 0xf3, 0x49, 0x86, 0xcc,
		0xd7, 0x96, 0xd9, 0x92, 0x9a, 0xab, 0x41, 0x3b, 0xa5, 0xb0, 0x4f, 0x33, 0x86, 0xf9, 0x7e, 0x33,
		0x32, 0x60, 0x42, 0xde, 0xf3, 0x27, 0x11, 0x99, 0xdb, 0xd8, 0x7a, 0x2a, 0xa1, 0xb5, 0xf8, 0xf9,
		0x86, 0x8c, 0xde, 0x6c, 0xcb, 0x47, 0xe3, 0xe9, 0x08, 0x36, 0xd2, 0x0b, 0xec, 0xa6, 0x0b, 0xd8,
		0xda, 0xfe, 0xb7, 0xbe, 0x9d, 0x6f, 0x7d, 0x7b, 0xde, 0xfa, 0x76, 0xbb, 0x5b, 0x70, 0x62, 0xba,
		0xc5, 0xa0, 0x37, 0x63, 0x22, 0xc6, 0x0d, 0x6b, 0xbe, 0x1c, 0xac, 0x30, 0x1d, 0x4b, 0x3d, 0x65,
		0xad, 0xe5, 0x3d, 0xd9, 0xcc, 0x67, 0xa2, 0xc9, 0x53, 0xb2, 0x9d, 0x7f, 0x44, 0x96, 0x57, 0x44,
		0x96, 0x2f, 0x44, 0x96, 0x07, 0xe4, 0xb6, 0x6c, 0xb3, 0xd5, 0x13, 0x35, 0x71, 0x2c, 0xf6, 0xec,
		0x71, 0xc1, 0x7f, 0xd9, 0xb2, 0x45, 0xbb, 0xad, 0xb1, 0xad, 0xa7, 0x71, 0x52, 0xa4, 0x69, 0xd2,
		0xa6, 0x61, 0x52, 0xa5, 0x59, 0x92, 0xa7, 0x51, 0x92, 0xa7, 0x49, 0x92, 0xa7, 0x41, 0xae, 0xd7,
		0xfe, 0x81, 0xed, 0x56, 0xd1, 0x5e, 0xb2, 0x11, 0x61, 0xdd, 0x8e, 0xe7, 0xab, 0xd3, 0xe6, 0xbe,
		0xc7, 0x4b, 0x77, 0x69, 0x39, 0x69, 0x84, 0x2c, 0xfb, 0x9d, 0x32, 0xcb, 0x9d, 0x27, 0x9b, 0x9d,
		0x3a, 0x6b, 0x9d, 0x2d, 0x3b, 0x9d, 0x2d, 0x0b, 0x9d, 0x2d, 0xdb, 0x7c, 0xbd, 0xd3, 0x20, 0xc8,
		0xb2, 0xc4, 0xd3, 0x75, 0x37, 0x14, 0xc1, 0x55, 0x24, 0xae, 0x28, 0x16, 0xdd, 0x9c, 0x55, 0xd6,
		0x09, 0xc6, 0x3a, 0x99, 0x05, 0xa0, 0x3f, 0x7e, 0x4c, 0xf2, 0x6f, 0x0b, 0x09, 0x10, 0xac, 0x6b,
		0x0e, 0x82, 0x45, 0x66, 0x39, 0x4f, 0x11, 0xa0, 0xc3, 0xe4, 0x74, 0x44, 0xc0, 0x32, 0x60, 0x19,
		0xb0, 0x0c, 0x58, 0x06, 0x2c, 0x6f, 0x2c, 0x2c, 0xa7, 0x58, 0x00, 0x64, 0xce, 0x4c, 0xd6, 0x2c,
		0x89, 0x8f, 0x0e, 0x98, 0xe7, 0x03, 0x02, 0x97, 0x81, 0xcb, 0xc0, 0x65, 0xe0, 0x32, 0x70, 0x79,
		0x63, 0x71, 0x79, 0x0e, 0x05, 0x80, 0xe5, 0xcc, 0x5c, 0x25, 0xe7, 0x79, 0xc9, 0x40, 0x99, 0xe2,
		0xf8, 0xb0, 0xe5, 0x0d, 0x3f, 0x40, 0x32, 0x20, 0x19, 0x90, 0xbc, 0x19, 0x90, 0x6c, 0x7b, 0x03,
		0x31, 0x1d, 0x68, 0x7a, 0x2e, 0x5d, 0xaa, 0x81, 0xa0, 0x2b, 0xc7, 0xb4, 0xd8, 0xe0, 0x35, 0x19,
		0x9b, 0xea, 0x30, 0x3e, 0x69, 0xe1, 0x2d, 0xf2, 0x42, 0x5b, 0x1c, 0x85, 0xb5, 0x78, 0x0b, 0x69,
		0x71, 0x15, 0xce, 0x62, 0x2f, 0x94, 0xc5, 0x5e, 0x18, 0x8b, 0xbd, 0x10, 0x56, 0xbe, 0xca, 0x84,
		0x90, 0x17, 0xb6, 0x62, 0xd0, 0x62, 0x1c, 0x9a, 0x6c, 0x99, 0x36, 0xfb, 0x1f, 0x7f, 0xa7, 0x90,
		0x14, 0x0b, 0x1d, 0xa7, 0xaf, 0x66, 0x4a, 0x2e, 0x81, 0xa9, 0xbc, 0x14, 0x39, 0x20, 0x60, 0xd6,
		0x34, 0x19, 0x4a, 0x19, 0x6b, 0xa6, 0xc8, 0x54, 0x02, 0x9d, 0x00, 0x9d, 0x00, 0x9d, 0x00, 0x9d,
		0x00, 0x9d, 0x58, 0xb2, 0x6e, 0xc7, 0x52, 0xe9, 0xbd, 0x32, 0x03, 0x9b, 0xa0, 0x24, 0x13, 0x9d,
		0x40, 0x5d, 0x0b, 0xf2, 0x76, 0xea, 0x0c, 0x45, 0x21, 0x39, 0xdb, 0xa5, 0x73, 0x97, 0xc9, 0x9e,
		0xf7, 0x92, 0xe6, 0x1a, 0xdf, 0x81, 0xbe, 0xd1, 0x1c, 0xa5, 0xe2, 0x39, 0xdb, 0x9b, 0xbb, 0x62,
		0x72, 0x95, 0x72, 0xa3, 0xd2, 0xa8, 0xd5, 0xcb, 0x8d, 0xea, 0x06, 0xdb, 0x5e, 0x4e, 0xcb, 0x9b,
		0x76, 0x21, 0x22, 0x5f, 0x21, 0x22, 0x6f, 0x6e, 0xc6, 0x4a, 0xea, 0x7b, 0xae, 0x10, 0xf5, 0xcb,
		0x0b, 0x80, 0xb0, 0x84, 0xb0, 0x84, 0xb0, 0x84, 0xb0, 0x84, 0xb0, 0x24, 0x5f, 0xb7, 0x88, 0x53,
		0x3f, 0xfb, 0x3b, 0xc7, 0x25, 0x29, 0xe2, 0xf4, 0xf5, 0x3d, 0x42, 0xd5, 0x6f, 0x9b, 0x72, 0xb2,
		0xb3, 0x3b, 0x19, 0x9b, 0x26, 0x3a, 0xc3, 0x03, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0x01,
		0x5e, 0xb1, 0x64, 0xdd, 0xca, 0x91, 0x1f, 0x0c, 0x06, 0x91, 0x88, 0x63, 0x0e, 0x6a, 0xd1, 0x20,
		0x1c, 0x73, 0x36, 0xc7, 0xb9, 0x0f, 0x5a, 0x3f, 0x3d, 0xd9, 0xdb, 0x0a, 0xc3, 0xb3, 0xcd, 0x3c,
		0xe3, 0x7d, 0x86, 0xb1, 0x4f, 0x02, 0xad, 0x45, 0xa4, 0xc8, 0x1f, 0x77, 0x7a, 0x01, 0x3b, 0x3b,
		0x17, 0x45, 0xbf, 0xd1, 0x7d, 0xb8, 0x28, 0xf9, 0x8d, 0x6e, 0xf2, 0xb2, 0x34, 0xfd, 0x96, 0xbc,
		0x2e, 0x5f, 0x14, 0xfd, 0xca, 0xfc, 0x75, 0xf5, 0xa2, 0xe8, 0x57, 0xbb, 0xbb, 0x7f, 0xfd, 0xf5,
		0x71, 0xf7, 0xfb, 0xde, 0xe3, 0xeb, 0xdf, 0x48, 0xdf, 0x7d, 0xaf, 0xcb, 0xf1, 0x48, 0xdb, 0xa7,
		0xad, 0x3f, 0xd9, 0x9f, 0xeb, 0xdf, 0x94, 0x0f, 0xf6, 0x17, 0x86, 0x27, 0x9b, 0xe7, 0x26, 0x73,
		0xbc, 0xce, 0xb8, 0x06, 0x67, 0xcc, 0xea, 0x8c, 0x03, 0xff, 0xaa, 0xe9, 0x7f, 0xed, 0x7e, 0x2f,
		0x7d, 0xa8, 0x3c, 0x7e, 0xda, 0xfd, 0x5e, 0x7f, 0x7c, 0xf9, 0xc3, 0x87, 0x65, 0xbf, 0x56, 0xfa,
		0x50, 0x7f, 0xfc, 0xb4, 0xe2, 0x5f, 0x6a, 0x8f, 0x9f, 0x7e, 0xf2, 0x33, 0xaa, 0x8f, 0x3b, 0x99,
		0x5f, 0x9d, 0xfc, 0xbc, 0xbc, 0xea, 0x0d, 0x95, 0x15, 0x6f, 0xd8, 0x5b, 0xf5, 0x86, 0xbd, 0x15,
		0x6f, 0x58, 0x79, 0x49, 0xe5, 0x15, 0x6f, 0xa8, 0x3e, 0x3e, 0x64, 0x7e, 0x7f, 0x67, 0xf9, 0xaf,
		0xd6, 0x1e, 0x77, 0x1f, 0x56, 0xfd, 0x5b, 0xfd, 0xf1, 0xe1, 0xd3, 0x2e, 0xa0, 0x89, 0x1e, 0x9a,
		0x60, 0xe6, 0xf4, 0x66, 0x9e, 0x7f, 0xa0, 0xc6, 0xfe, 0xb0, 0x8b, 0x91, 0xdb, 0x3b, 0xed, 0xb3,
		0xef, 0x11, 0x2f, 0xbb, 0x08, 0xc4, 0x73, 0x11, 0xcf, 0x45, 0x3c, 0x17, 0xf1, 0x5c, 0xc4, 0x73,
		0xc9, 0xd7, 0x2d, 0xf6, 0x89, 0x9f, 0xfd, 0x7d, 0x8e, 0x4d, 0x52, 0xc4, 0x0b, 0xff, 0x8f, 0xfd,
		0xe2, 0x37, 0x4e, 0xbd, 0x54, 0xb7, 0xc1, 0x50, 0x0e, 0xfc, 0x48, 0x04, 0x31, 0x61, 0x13, 0xe4,
		0xa7, 0x50, 0xca, 0xe2, 0xf8, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe4,
		0xeb, 0x56, 0x0e, 0x84, 0xd2, 0x52, 0xdf, 0x33, 0xf1, 0x0d, 0xc2, 0xd3, 0x01, 0x5e, 0x6b, 0x76,
		0xab, 0x9f, 0x83, 0x98, 0xc1, 0x65, 0xcc, 0x27, 0xbc, 0x75, 0xfc, 0x47, 0xf3, 0xb0, 0xf5, 0xa5,
		0xd7, 0x69, 0x9f, 0x9f, 0x1d, 0xf4, 0x3a, 0x07, 0xcd, 0xd3, 0xf6, 0x31, 0xb5, 0xf7, 0x98, 0x1e,
		0xd2, 0x88, 0x59, 0xc2, 0x9c, 0x4c, 0xa7, 0x62, 0x5e, 0xce, 0xfe, 0xaf, 0x87, 0xe7, 0xa7, 0x67,
		0x07, 0x9d, 0xde, 0x61, 0xbb, 0x7d, 0xe2, 0x6d, 0xc2, 0xa1, 0x24, 0x47, 0xe6, 0xbd, 0xdd, 0x69,
		0xfd, 0xd6, 0x3a, 0x6e, 0x9e, 0xb5, 0x3b, 0x98, 0x75, 0xba, 0x59, 0x6f, 0x9e, 0xc2, 0xd0, 0xa9,
		0x1d, 0x4c, 0xfb, 0xf8, 0xeb, 0xc1, 0x17, 0x2f, 0xe7, 0x67, 0xce, 0xba, 0x79, 0xe3, 0x7b, 0xb9,
		0x50, 0xf7, 0xc3, 0x20, 0xd6, 0xfe, 0x4d, 0x38, 0x90, 0x57, 0x52, 0x0c, 0xe8, 0xc5, 0xfd, 0xe2,
		0xf0, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xe4, 0xeb, 0x56, 0xcb, 0x1b,
		0xa1, 0x65, 0xff, 0x5b, 0x5c, 0xab, 0x30, 0x68, 0x7b, 0xc2, 0x34, 0x35, 0xef, 0x5c, 0x25, 0x67,
		0xfc, 0x3d, 0x15, 0xa8, 0x30, 0x16, 0xfd, 0x50, 0x0d, 0x48, 0x73, 0xe1, 0x51, 0x4d, 0x25, 0x7f,
		0x18, 0xbf, 0x3c, 0x6a, 0x82, 0x6a, 0x2a, 0xe4, 0x26, 0x87, 0x6a, 0x2a, 0xdb, 0xa5, 0xfd, 0x4a,
		0xa5, 0x56, 0xaf, 0x54, 0x8a, 0xf5, 0xbd, 0x7a, 0xb1, 0x51, 0xad, 0x96, 0x6a, 0x25, 0xd4, 0x55,
		0xc9, 0xdd, 0x68, 0xc8, 0x9b, 0xfb, 0x79, 0x33, 0xa4, 0xea, 0x89, 0x94, 0x21, 0x55, 0x34, 0xbd,
		0x91, 0xd2, 0x61, 0xbf, 0x88, 0xab, 0x60, 0x3c, 0x9c, 0x52, 0xf1, 0x22, 0xb4, 0x34, 0xb4, 0x34,
		0xb4, 0x34, 0xb4, 0x34, 0xb4, 0x34, 0x8a, 0x82, 0x42, 0xc6, 0x42, 0xc6, 0x42, 0xc6, 0x42, 0xc6,
		0xae, 0x95, 0xc9, 0xa1, 0x28, 0x28, 0xc4, 0x2b, 0xc4, 0xeb, 0xb6, 0x37, 0x4b, 0x7e, 0x0e, 0xc7,
		0x5a, 0xd0, 0x0b, 0xd8, 0xe7, 0x83, 0x43, 0x50, 0x42, 0x50, 0x42, 0x50, 0x42, 0x50, 0x42, 0x50,
		0x92, 0xaf, 0xdb, 0xcb, 0x30, 0x1c, 0x8a, 0x40, 0x71, 0x24, 0x5d, 0x97, 0xf2, 0x02, 0xd5, 0x6b,
		0xdd, 0x20, 0xb3, 0xa9, 0x54, 0xa8, 0x83, 0x09, 0x1b, 0xa5, 0xe9, 0x93, 0x19, 0xf7, 0xff, 0x11,
		0x37, 0xc1, 0x68, 0x76, 0xe8, 0xae, 0x10, 0x8e, 0x84, 0xea, 0x4f, 0x81, 0x72, 0xe2, 0x3f, 0x0a,
		0x93, 0xaf, 0x48, 0x5e, 0x16, 0x82, 0x2b, 0xe9, 0xc7, 0xc1, 0x95, 0x8c, 0xd3, 0x57, 0x85, 0x69,
		0xdd, 0x9b, 0x38, 0xd2, 0xc2, 0x1f, 0x85, 0x43, 0xd9, 0xbf, 0x2f, 0x28, 0x21, 0xaf, 0xff, 0xb9,
		0x0c, 0xa3, 0x38, 0x7d, 0x55, 0x08, 0x06, 0xff, 0x4e, 0x5d, 0x91, 0x54, 0xfe, 0x28, 0x12, 0x85,
		0x29, 0xbb, 0x88, 0x93, 0x6f, 0x05, 0x8a, 0xc6, 0xc5, 0xc9, 0x1d, 0xea, 0x68, 0xdc, 0xd7, 0x6a,
		0xb6, 0xc0, 0xda, 0xe9, 0x0d, 0x7e, 0xbe, 0x1e, 0xf5, 0x26, 0x5f, 0x1d, 0x79, 0xd9, 0x6b, 0x5e,
		0xc9, 0xd3, 0xc9, 0xed, 0xcd, 0x5f, 0xf4, 0x5a, 0xa3, 0xdb, 0xda, 0x69, 0xa4, 0xc5, 0xc9, 0xf4,
		0xde, 0x7a, 0xc7, 0xf3, 0x7b, 0x4b, 0x5f, 0xf5, 0x9a, 0x83, 0x7f, 0x3b, 0xf2, 0xb2, 0xa5, 0x4e,
		0x22, 0xd1, 0xeb, 0x4c, 0x6f, 0x2c, 0xf9, 0xd6, 0x3b, 0x9d, 0xde, 0x18, 0x3a, 0x63, 0x67, 0x1e,
		0xc4, 0x58, 0x7d, 0x53, 0xe1, 0x7f, 0xca, 0x0f, 0xb4, 0x8e, 0xe4, 0xe5, 0x64, 0xc6, 0xe8, 0xda,
		0x64, 0x2f, 0x19, 0x1b, 0x3d, 0xb3, 0x5d, 0x65, 0xb3, 0xe8, 0x99, 0x9d, 0x4f, 0xb6, 0x8a, 0x9e,
		0xd9, 0x6f, 0x9a, 0x35, 0xb2, 0x9e, 0xd9, 0x19, 0x27, 0x49, 0x1f, 0x86, 0xc8, 0x5e, 0x02, 0x6d,
		0x30, 0xa2, 0x84, 0x60, 0x04, 0x82, 0x11, 0x08, 0x46, 0x20, 0x18, 0xe1, 0x4e, 0x30, 0x82, 0xca,
		0xfd, 0xa7, 0x03, 0x4e, 0x3b, 0x44, 0x6b, 0xea, 0x10, 0xc8, 0x82, 0xc7, 0x78, 0xba, 0x04, 0x62,
		0xd3, 0xe5, 0xd9, 0x12, 0x23, 0x87, 0x03, 0x4e, 0x58, 0x70, 0x03, 0x1e, 0xb8, 0x61, 0xc2, 0x19,
		0xb8, 0x70, 0x06, 0x36, 0x9c, 0x81, 0x0f, 0x5a, 0x18, 0x21, 0x86, 0x93, 0x74, 0x96, 0xcf, 0x38,
		0x1c, 0xfc, 0x36, 0x6f, 0x41, 0xb3, 0x0c, 0xdb, 0xaf, 0xf3, 0x14, 0xcd, 0x9e, 0x17, 0x38, 0x4b,
		0xea, 0x94, 0x3d, 0x81, 0x5d, 0x4e, 0x93, 0x00, 0x08, 0x4d, 0xdb, 0x4b, 0xc2, 0xca, 0x6c, 0xc4,
		0x85, 0x2a, 0xaa, 0xcd, 0xa8, 0x5d, 0x41, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x38, 0x48,
		0x0b, 0xb5, 0x16, 0x5e, 0xd4, 0xc4, 0x43, 0xc1, 0x98, 0x1f, 0xbc, 0x20, 0x8d, 0x27, 0x57, 0xf2,
		0x61, 0x23, 0x93, 0x46, 0xb9, 0x40, 0xc7, 0x05, 0xf0, 0x71, 0x0b, 0x84, 0x5c, 0x01, 0x23, 0xe7,
		0x40, 0xc9, 0x39, 0x70, 0x72, 0x0e, 0xa4, 0x78, 0xc0, 0x8a, 0x09, 0xb4, 0xf8, 0x15, 0x77, 0xc6,
		0x6f, 0x8c, 0xa5, 0xd2, 0xa5, 0x1a, 0xa7, 0xcf, 0x98, 0xa1, 0x48, 0x8d, 0xf1, 0x12, 0x78, 0x8e,
		0x35, 0xbd, 0xfc, 0xc3, 0xeb, 0x33, 0xb7, 0xb9, 0x8f, 0x3d, 0x39, 0x46, 0x2f, 0x32, 0x97, 0xc3,
		0x7c, 0x2c, 0x2a, 0x73, 0x3d, 0x0e, 0x1c, 0x55, 0x71, 0xc4, 0x9d, 0x2e, 0x9a, 0x70, 0x70, 0x07,
		0x13, 0xfe, 0x81, 0x09, 0xd7, 0xaa, 0xd5, 0xbd, 0x2a, 0xcc, 0xd8, 0x2d, 0x2e, 0xc2, 0x3f, 0x7a,
		0x77, 0x6b, 0x33, 0xee, 0x97, 0xe3, 0x74, 0x27, 0xdf, 0x4e, 0xfa, 0xf2, 0xb0, 0x01, 0xc3, 0x8e,
		0x3a, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e, 0x80, 0xb8, 0x01, 0xe2, 0x06, 0x39, 0x89, 0x1b, 0xec,
		0x3b, 0x10, 0x36, 0xa8, 0x22, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x60,
		0xdd, 0x84, 0xcb, 0x55, 0x04, 0x0d, 0x10, 0x34, 0x40, 0xd0, 0x80, 0x36, 0x68, 0x70, 0x3b, 0x5b,
		0x7d, 0x2e, 0x44, 0x0d, 0x92, 0x6b, 0x41, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40,
		0xd8, 0x00, 0x61, 0x83, 0x57, 0xfa, 0x8d, 0x4b, 0xa9, 0x82, 0xe8, 0xde, 0x81, 0xb8, 0x41, 0x83,
		0xf1, 0x12, 0x0e, 0x85, 0xba, 0x9e, 0x26, 0xfe, 0x23, 0x70, 0x80, 0xc0, 0xc1, 0x0f, 0x55, 0x57,
		0x09, 0x9a, 0x0b, 0x81, 0x83, 0xf5, 0x36, 0x61, 0xe4, 0x1b, 0x20, 0x74, 0x80, 0xd0, 0x01, 0xa9,
		0x99, 0x8b, 0x3b, 0x2d, 0xd4, 0x80, 0xb0, 0xbb, 0xe7, 0x4a, 0xca, 0x97, 0x5e, 0x09, 0xc2, 0x06,
		0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0xbc, 0x36, 0x6c, 0x40, 0x5e,
		0x0b, 0x77, 0x15, 0x8c, 0x10, 0xd5, 0xc6, 0xdd, 0x4c, 0xd2, 0x12, 0x8e, 0x26, 0xcc, 0x3c, 0x18,
		0xf2, 0x93, 0x96, 0xf4, 0x4a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40, 0x5a, 0x40,
		0x5a, 0x40, 0x5a, 0x40, 0x5a, 0xb2, 0x73, 0x3c, 0x0a, 0x22, 0x2d, 0x5d, 0xe0, 0x2c, 0xf3, 0x0b,
		0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65, 0x01, 0x65,
		0xc9, 0xce, 0xb1, 0x8e, 0x02, 0x15, 0x4b, 0x2d, 0x6f, 0x1d, 0xc8, 0x2b, 0x7d, 0x76, 0x2d, 0x20,
		0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0x20, 0x2e, 0xce, 0x13, 0x97,
		0x5c, 0x97, 0x17, 0x25, 0x6e, 0xbe, 0x98, 0x19, 0x9f, 0xad, 0x19, 0x63, 0xb6, 0x3d, 0x5e, 0xf6,
		0x47, 0x05, 0x8e, 0xda, 0xd6, 0xdb, 0x1c, 0x1d, 0x1c, 0xcf, 0x93, 0x5b, 0x6f, 0xa6, 0x93, 0x91,
		0xf9, 0x09, 0x45, 0x93, 0x47, 0xbe, 0xa5, 0x97, 0xaf, 0xfe, 0x39, 0xbf, 0x8b, 0x7b, 0x8e, 0x02,
		0x38, 0xde, 0xa1, 0x8c, 0xf5, 0xc4, 0x60, 0x68, 0x9b, 0xf7, 0x1c, 0x49, 0x75, 0x30, 0x14, 0x13,
		0x76, 0x14, 0xd3, 0xaa, 0x0b, 0xef, 0x28, 0xb8, 0x7b, 0x36, 0x72, 0x69, 0xbf, 0x52, 0xa9, 0xd5,
		0x2b, 0x95, 0x62, 0x7d, 0xaf, 0x5e, 0x6c, 0x54, 0xab, 0xa5, 0x5a, 0x89, 0x30, 0x19, 0xd8, 0x6b,
		0x47, 0x03, 0x11, 0x89, 0xc1, 0xe7, 0xc9, 0xa3, 0x57, 0xe3, 0xe1, 0x30, 0x57, 0x16, 0xcd, 0x04,
		0x53, 0x6e, 0xc3, 0x93, 0x47, 0xda, 0x64, 0xc2, 0x35, 0x40, 0xf2, 0xd0, 0xbc, 0x9b, 0x7f, 0x81,
		0x6e, 0x4e, 0xf3, 0x6e, 0xf2, 0x76, 0xca, 0x6e, 0x2c, 0xbb, 0xb5, 0xed, 0xea, 0xbd, 0xb5, 0x46,
		0xab, 0x69, 0x4e, 0xd8, 0x26, 0x66, 0xed, 0xcb, 0xc1, 0xb6, 0x50, 0x83, 0x51, 0x28, 0x95, 0xde,
		0xee, 0x87, 0xc3, 0x30, 0xb2, 0x64, 0x67, 0x34, 0x6c, 0x8d, 0x8e, 0x9d, 0xb1, 0xb2, 0x31, 0x1a,
		0xf6, 0x65, 0xcb, 0xfc, 0x88, 0x9c, 0x38, 0x9b, 0xf3, 0xb6, 0xe8, 0xa9, 0xa9, 0x3d, 0xb4, 0x1d,
		0x7f, 0x6c, 0xde, 0x5b, 0x9a, 0xfd, 0x44, 0xc3, 0x86, 0x6f, 0xdb, 0xe0, 0x19, 0x0c, 0xdd, 0x82,
		0x89, 0xd3, 0x99, 0xb6, 0x59, 0xa3, 0x36, 0x67, 0x7a, 0x66, 0x3e, 0xc9, 0x90, 0xf1, 0xda, 0x32,
		0x5a, 0x4a, 0x63, 0x35, 0x68, 0xa5, 0x04, 0xd6, 0x69, 0xc6, 0x2c, 0xdf, 0x6f, 0x44, 0x06, 0x0c,
		0xc8, 0x9b, 0x3f, 0x87, 0x70, 0xac, 0xfd, 0x51, 0x18, 0x6b, 0x63, 0x26, 0xf4, 0x54, 0x38, 0xeb,
		0xe5, 0x08, 0x86, 0xcc, 0xde, 0x6c, 0xab, 0x47, 0xe3, 0x69, 0x08, 0x36, 0xd2, 0x0a, 0xec, 0xa6,
		0x09, 0xd8, 0xda, 0xf6, 0xb7, 0xbe, 0x8d, 0x6f, 0x7d, 0x5b, 0xde, 0xfa, 0x36, 0xbb, 0x5b, 0x80,
		0x62, 0xba, 0xb5, 0xa0, 0x37, 0xa3, 0x22, 0xc6, 0x0d, 0x6b, 0xbe, 0x1c, 0xac, 0x50, 0x1d, 0x4b,
		0xbd, 0x64, 0xad, 0xe5, 0x3b, 0xd9, 0xcc, 0x63, 0xa2, 0xc9, 0x4f, 0xb2, 0x9d, 0x77, 0x44, 0x96,
		0x4f, 0x44, 0x96, 0x27, 0x44, 0x96, 0xff, 0xe3, 0xb6, 0x6c, 0xb3, 0xd5, 0x0b, 0x35, 0x71, 0x2c,
		0xf6, 0xec, 0x71, 0xc1, 0x7f, 0xd9, 0xb2, 0x45, 0xbb, 0x2d, 0xb1, 0xad, 0xa7, 0x6f, 0x52, 0xa4,
		0x67, 0xd2, 0xa6, 0x5f, 0x52, 0xa5, 0x57, 0x92, 0xa7, 0x4f, 0x92, 0xa7, 0x47, 0x92, 0xa7, 0x3f,
		0xae, 0xd7, 0xee, 0x81, 0xed, 0x16, 0xd1, 0x5e, 0xb2, 0x0d, 0x61, 0xdd, 0x8e, 0xe7, 0xab, 0xd3,
		0xe6, 0xae, 0xc7, 0x4b, 0x77, 0x69, 0x39, 0x5d, 0x84, 0x2c, 0xeb, 0x9d, 0x32, 0xbb, 0x9d, 0x27,
		0x8b, 0x9d, 0x3a, 0x5b, 0x9d, 0x2d, 0x2b, 0x9d, 0x2d, 0xfb, 0x9c, 0x2d, 0xcb, 0x7c, 0xbd, 0x53,
		0x20, 0xc8, 0xb2, 0xc3, 0xd3, 0x75, 0x37, 0x14, 0xc1, 0x55, 0x24, 0xae, 0x28, 0x16, 0xdd, 0x9c,
		0x55, 0xd6, 0x09, 0xc6, 0x3a, 0x99, 0x85, 0xa0, 0x3f, 0x7e, 0x4c, 0x12, 0x6f, 0x0b, 0x09, 0x10,
		0xac, 0x6b, 0x06, 0x82, 0x45, 0x66, 0x39, 0x4f, 0x10, 0xa0, 0xc3, 0xe4, 0x74, 0x44, 0xc0, 0x32,
		0x60, 0x19, 0xb0, 0x0c, 0x58, 0x06, 0x2c, 0x6f, 0x2c, 0x2c, 0xa7, 0x58, 0x00, 0x64, 0xce, 0x4c,
		0xd6, 0x2c, 0x85, 0x8f, 0x0e, 0x98, 0xe7, 0x03, 0x02, 0x97, 0x81, 0xcb, 0xc0, 0x65, 0xe0, 0x32,
		0x70, 0x79, 0x63, 0x71, 0x79, 0x0e, 0x05, 0x80, 0xe5, 0xcc, 0x5c, 0x25, 0x07, 0x79, 0xc9, 0x40,
		0x99, 0xe2, 0xdc, 0xb0, 0xe5, 0x0d, 0x3f, 0x40, 0x32, 0x20, 0x19, 0x90, 0xbc, 0x19, 0x90, 0x6c,
		0x7b, 0x03, 0x31, 0x1d, 0x68, 0x7a, 0x22, 0x5d, 0xaa, 0x81, 0xa0, 0x2b, 0xc3, 0xb4, 0xd8, 0xd8,
		0x35, 0x19, 0x9b, 0xea, 0x18, 0x3e, 0x69, 0xc1, 0x2d, 0xf2, 0x02, 0x5b, 0x1c, 0x05, 0xb5, 0x78,
		0x0b, 0x68, 0x71, 0x15, 0xcc, 0x62, 0x2f, 0x90, 0xc5, 0x5e, 0x10, 0x8b, 0xbd, 0x00, 0x56, 0xbe,
		0x0a, 0x84, 0x90, 0x17, 0xb4, 0x62, 0xd0, 0x62, 0x1c, 0x9a, 0x6c, 0x99, 0x36, 0xfb, 0x1f, 0x7f,
		0xa7, 0x90, 0x14, 0x0b, 0x1d, 0xa7, 0xaf, 0x66, 0x4a, 0x2e, 0x81, 0xa9, 0xbc, 0x14, 0x38, 0x20,
		0x60, 0xd6, 0x34, 0x19, 0x4a, 0x19, 0x6b, 0xa6, 0xc8, 0x54, 0x02, 0x9d, 0x00, 0x9d, 0x00, 0x9d,
		0x00, 0x9d, 0x00, 0x9d, 0x58, 0xb2, 0x6e, 0xc7, 0x52, 0xe9, 0xbd, 0x32, 0x03, 0x9b, 0xa0, 0x24,
		0x13, 0x9d, 0x40, 0x5d, 0x0b, 0xf2, 0x36, 0xea, 0x0c, 0xc5, 0x20, 0x39, 0xdb, 0xa4, 0x73, 0x97,
		0xc7, 0x9e, 0xf7, 0x90, 0xe6, 0x1a, 0xdf, 0x81, 0x7e, 0xd1, 0x1c, 0x25, 0xe2, 0x39, 0xdb, 0x9a,
		0xbb, 0x62, 0x72, 0x95, 0x72, 0xa3, 0xd2, 0xa8, 0xd5, 0xcb, 0x8d, 0xea, 0x06, 0xdb, 0x5e, 0x4e,
		0x0b, 0x9b, 0x76, 0x21, 0x22, 0x5f, 0x21, 0x22, 0x6f, 0x6e, 0xc6, 0x4a, 0xea, 0x7b, 0xae, 0x10,
		0xf5, 0xcb, 0x0b, 0x80, 0xb0, 0x84, 0xb0, 0x84, 0xb0, 0x84, 0xb0, 0x84, 0xb0, 0x24, 0x5f, 0xb7,
		0x88, 0x53, 0x3f, 0xfb, 0x3b, 0xc7, 0x25, 0x29, 0xe2, 0xf4, 0xf5, 0x3d, 0x42, 0xd5, 0x6f, 0x9b,
		0x72, 0xb2, 0xb3, 0x3b, 0x19, 0x9b, 0x26, 0x3a, 0xc3, 0x03, 0x5e, 0x01, 0x5e, 0x01, 0x5e, 0x01,
		0x5e, 0x01, 0x5e, 0xb1, 0x64, 0xdd, 0xca, 0x91, 0x1f, 0x0c, 0x06, 0x91, 0x88, 0x63, 0x0e, 0x6a,
		0xd1, 0x20, 0x1c, 0x73, 0x36, 0xc7, 0xb9, 0x0f, 0x5a, 0x3f, 0x3d, 0xd9, 0xdb, 0x0a, 0xc3, 0xb3,
		0xcd, 0x3c, 0xe3, 0x7d, 0x86, 0xb1, 0x4f, 0x02, 0xad, 0x45, 0xa4, 0xc8, 0x1f, 0x77, 0x7a, 0x01,
		0x3b, 0x3b, 0x17, 0x45, 0xbf, 0xd1, 0x7d, 0xb8, 0x28, 0xf9, 0x8d, 0x6e, 0xf2, 0xb2, 0x34, 0xfd,
		0x96, 0xbc, 0x2e, 0x5f, 0x14, 0xfd, 0xca, 0xfc, 0x75, 0xf5, 0xa2, 0xe8, 0x57, 0xbb, 0xbb, 0x7f,
		0xfd, 0xf5, 0x71, 0xf7, 0xfb, 0xde, 0xe3, 0xeb, 0xdf, 0x48, 0xdf, 0x75, 0xaf, 0xcb, 0xf1, 0x48,
		0xdb, 0xa7, 0xad, 0x3f, 0xd9, 0x9f, 0xeb, 0xdf, 0x94, 0x0f, 0xf6, 0x17, 0x86, 0x27, 0x9b, 0xe7,
		0xe6, 0x72, 0xbc, 0xce, 0xb8, 0x06, 0x67, 0xcc, 0xea, 0x8c, 0x03, 0xff, 0xaa, 0xe9, 0x7f, 0xed,
		0x7e, 0x2f, 0x7d, 0xa8, 0x3c, 0x7e, 0xda, 0xfd, 0x5e, 0x7f, 0x7c, 0xf9, 0xc3, 0x87, 0x65, 0xbf,
		0x56, 0xfa, 0x50, 0x7f, 0xfc, 0xb4, 0xe2, 0x5f, 0x6a, 0x8f, 0x9f, 0x7e, 0xf2, 0x33, 0xaa, 0x8f,
		0x3b, 0x99, 0x5f, 0x9d, 0xfc, 0xbc, 0xbc, 0xea, 0x0d, 0x95, 0x15, 0x6f, 0xd8, 0x5b, 0xf5, 0x86,
		0xbd, 0x15, 0x6f, 0x58, 0x79, 0x49, 0xe5, 0x15, 0x6f, 0xa8, 0x3e, 0x3e, 0x64, 0x7e, 0x7f, 0x67,
		0xf9, 0xaf, 0xd6, 0x1e, 0x77, 0x1f, 0x56, 0xfd, 0x5b, 0xfd, 0xf1, 0xe1, 0xd3, 0x2e, 0xa0, 0x89,
		0x1e, 0x9a, 0x60, 0xe6, 0xf4, 0x66, 0x9e, 0x7f, 0xa0, 0xc6, 0xfe, 0xb0, 0x8b, 0x91, 0xdb, 0x3b,
		0xed, 0xb3, 0xef, 0x11, 0x2f, 0xbb, 0x08, 0xc4, 0x73, 0x11, 0xcf, 0x45, 0x3c, 0x17, 0xf1, 0x5c,
		0xc4, 0x73, 0xc9, 0xd7, 0x2d, 0xf6, 0x89, 0x9f, 0xfd, 0x7d, 0x8e, 0x4d, 0x52, 0xc4, 0x0b, 0xff,
		0x8f, 0xfd, 0xe2, 0x37, 0x4e, 0xbd, 0x54, 0xb7, 0xc1, 0x50, 0x0e, 0xfc, 0x48, 0x04, 0x31, 0x61,
		0xfb, 0xe3, 0xa7, 0x50, 0xca, 0xe2, 0xf8, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0, 0x1a, 0xe0,
		0x1a, 0xe4, 0xeb, 0x56, 0x0e, 0x84, 0xd2, 0x52, 0xdf, 0x33, 0xf1, 0x0d, 0xc2, 0xd3, 0x01, 0x5e,
		0x6b, 0x76, 0xab, 0x9f, 0x83, 0x98, 0xc1, 0x65, 0xcc, 0x27, 0xbc, 0x75, 0xfc, 0x47, 0xf3, 0xb0,
		0xf5, 0xa5, 0xd7, 0x69, 0x9f, 0x9f, 0x1d, 0xf4, 0x3a, 0x07, 0xcd, 0xd3, 0xf6, 0x31, 0xb5, 0xf7,
		0x98, 0x1e, 0xd2, 0x88, 0x59, 0xc2, 0x9c, 0x4c, 0xa7, 0x62, 0x5e, 0xce, 0xfe, 0xaf, 0x87, 0xe7,
		0xa7, 0x67, 0x07, 0x9d, 0xde, 0x61, 0xbb, 0x7d, 0xe2, 0x6d, 0xc2, 0xa1, 0x24, 0x47, 0xe6, 0xbd,
		0xdd, 0x69, 0xfd, 0xd6, 0x3a, 0x6e, 0x9e, 0xb5, 0x3b, 0x98, 0x75, 0xba, 0x59, 0x6f, 0x9e, 0xc2,
		0xd0, 0xa9, 0x1d, 0x4c, 0xfb, 0xf8, 0xeb, 0xc1, 0x17, 0x2f, 0xe7, 0x67, 0xce, 0xba, 0x79, 0xe3,
		0x7b, 0xb9, 0x50, 0xf7, 0xc3, 0x20, 0xd6, 0xfe, 0x4d, 0x38, 0x90, 0x57, 0x52, 0x0c, 0xe8, 0xc5,
		0xfd, 0xe2, 0xf0, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xd0, 0xf6, 0xe4, 0xeb, 0x56,
		0xcb, 0x1b, 0xa1, 0x65, 0xff, 0x5b, 0x5c, 0xab, 0x30, 0x68, 0x7b, 0xc2, 0x34, 0x35, 0xef, 0x5c,
		0x25, 0x67, 0xfc, 0x3d, 0x15, 0xa8, 0x30, 0x16, 0xfd, 0x50, 0x0d, 0x48, 0x73, 0xe1, 0x51, 0x4d,
		0x25, 0x7f, 0x18, 0xbf, 0x3c, 0x6a, 0x82, 0x6a, 0x2a, 0xe4, 0x26, 0x87, 0x6a, 0x2a, 0xdb, 0xa5,
		0xfd, 0x4a, 0xa5, 0x56, 0xaf, 0x54, 0x8a, 0xf5, 0xbd, 0x7a, 0xb1, 0x51, 0xad, 0x96, 0x6a, 0x25,
		0xd4, 0x55, 0xc9, 0xdd, 0x68, 0xc8, 0x9b, 0xfb, 0x79, 0x33, 0xa4, 0xea, 0x89, 0x94, 0x21, 0x55,
		0x34, 0xbd, 0x91, 0xd2, 0x61, 0xbf, 0x88, 0xab, 0x60, 0x3c, 0x9c, 0x52, 0xf1, 0x22, 0xb4, 0x34,
		0xb4, 0x34, 0xb4, 0x34, 0xb4, 0x34, 0xb4, 0x34, 0x8a, 0x82, 0x42, 0xc6, 0x42, 0xc6, 0x42, 0xc6,
		0x42, 0xc6, 0xae, 0x95, 0xc9, 0xa1, 0x28, 0x28, 0xc4, 0x2b, 0xc4, 0xeb, 0xb6, 0x37, 0x4b, 0x7e,
		0x0e, 0xc7, 0x5a, 0xd0, 0x0b, 0xd8, 0xe7, 0x83, 0x43, 0x50, 0x42, 0x50, 0x42, 0x50, 0x42, 0x50,
		0x42, 0x50, 0x92, 0xaf, 0xdb, 0xcb, 0x30, 0x1c, 0x8a, 0x40, 0x71, 0x24, 0x5d, 0x97, 0xf2, 0x02,
		0xd5, 0x6b, 0xdd, 0x20, 0xb3, 0xa9, 0x54, 0xa8, 0x83, 0x09, 0x1b, 0xa5, 0xe9, 0x93, 0x19, 0xf7,
		0xff, 0x11, 0x37, 0xc1, 0x68, 0x76, 0xe8, 0xae, 0x10, 0x8e, 0x84, 0xea, 0x4f, 0x81, 0x72, 0xe2,
		0x3f, 0x0a, 0x93, 0xaf, 0x48, 0x5e, 0x16, 0x82, 0x2b, 0xe9, 0xc7, 0xc1, 0x95, 0x8c, 0xd3, 0x57,
		0x85, 0x69, 0xdd, 0x9b, 0x38, 0xd2, 0xc2, 0x1f, 0x85, 0x43, 0xd9, 0xbf, 0x2f, 0x28, 0x21, 0xaf,
		0xff, 0xb9, 0x0c, 0xa3, 0x38, 0x7d, 0x55, 0x08, 0x06, 0xff, 0x4e, 0x5d, 0x51, 0x38, 0xd6, 0xfe,
		0x28, 0x8c, 0x75, 0x61, 0xca, 0x2f, 0xe2, 0xe4, 0x5b, 0x81, 0xa2, 0x75, 0x71, 0x72, 0x8f, 0x3a,
		0x1a, 0xf7, 0xb5, 0x9a, 0x2d, 0xb1, 0x76, 0x7a, 0x8b, 0x9f, 0xaf, 0x47, 0xbd, 0xc9, 0x57, 0x47,
		0x5e, 0xf6, 0x9a, 0x57, 0xf2, 0x74, 0x72, 0x83, 0xf3, 0x17, 0xbd, 0xd6, 0xe8, 0xb6, 0x76, 0x1a,
		0x69, 0x71, 0x32, 0xbd, 0xbb, 0xde, 0xf1, 0xfc, 0xee, 0xd2, 0x57, 0xbd, 0xe6, 0xe0, 0xdf, 0x8e,
		0xbc, 0x6c, 0x8f, 0xf5, 0x49, 0x18, 0xeb, 0x5e, 0x67, 0x7a, 0x6b, 0xc9, 0xb7, 0xde, 0xe9, 0xf4,
		0xd6, 0xd0, 0x1d, 0x3b, 0xf3, 0x28, 0xc6, 0xea, 0x9b, 0x0a, 0xff, 0x53, 0x7e, 0xa0, 0x75, 0x24,
		0x2f, 0x27, 0x33, 0x46, 0xd7, 0x2a, 0x7b, 0xc9, 0xd8, 0xe8, 0x9b, 0xed, 0x2a, 0xa3, 0x45, 0xdf,
		0xec, 0x7c, 0x32, 0x56, 0xf4, 0xcd, 0x7e, 0xd3, 0xac, 0x91, 0xf5, 0xcd, 0xce, 0x38, 0x49, 0xfa,
		0x50, 0x44, 0xf6, 0x12, 0x68, 0x03, 0x12, 0x25, 0x04, 0x24, 0x10, 0x90, 0x40, 0x40, 0x02, 0x01,
		0x09, 0x77, 0x02, 0x12, 0x54, 0xee, 0x3f, 0x1d, 0x70, 0xda, 0x25, 0x5a, 0x53, 0x87, 0x41, 0x16,
		0x3c, 0xc6, 0xd3, 0x25, 0x10, 0x9b, 0x2e, 0xcf, 0xb6, 0x18, 0x39, 0x1c, 0x70, 0xc2, 0x82, 0x1b,
		0xf0, 0xc0, 0x0d, 0x13, 0xce, 0xc0, 0x85, 0x33, 0xb0, 0xe1, 0x0c, 0x7c, 0xd0, 0xc2, 0x08, 0x31,
		0x9c, 0xa4, 0xb3, 0x7c, 0xc6, 0xe1, 0xe0, 0xb7, 0x79, 0x8b, 0x9a, 0x65, 0xd8, 0x7e, 0x9d, 0xa7,
		0x70, 0xf6, 0xbc, 0xc8, 0x59, 0x52, 0xab, 0xec, 0x09, 0xec, 0x72, 0x9a, 0x08, 0x40, 0x68, 0xda,
		0x5e, 0x12, 0x58, 0x66, 0x23, 0x2e, 0x54, 0x71, 0x6d, 0x46, 0xed, 0x0a, 0xd2, 0x02, 0xd2, 0x02,
		0xd2, 0x02, 0xd2, 0xc2, 0x41, 0x5a, 0xa8, 0xb5, 0xf0, 0xa2, 0x26, 0x1e, 0x0a, 0xc6, 0x1c, 0xe1,
		0x05, 0x69, 0x3c, 0xb9, 0x92, 0x0f, 0x1b, 0x99, 0x38, 0xca, 0x05, 0x3a, 0x2e, 0x80, 0x8f, 0x5b,
		0x20, 0xe4, 0x0a, 0x18, 0x39, 0x07, 0x4a, 0xce, 0x81, 0x93, 0x73, 0x20, 0xc5, 0x03, 0x56, 0x4c,
		0xa0, 0xc5, 0xaf, 0xb8, 0x33, 0x7e, 0x63, 0x2c, 0x95, 0x2e, 0xd5, 0x38, 0x7d, 0xc6, 0x0c, 0x45,
		0x6a, 0x8c, 0x97, 0xc0, 0x73, 0xb4, 0xe9, 0xe5, 0x1f, 0x5e, 0x9f, 0xb9, 0xcd, 0x7d, 0xf4, 0xc9,
		0x31, 0x7a, 0x91, 0xb9, 0x1c, 0xe6, 0xa3, 0x51, 0x99, 0xeb, 0x71, 0xe0, 0xb8, 0x8a, 0x23, 0xee,
		0x74, 0xd1, 0x84, 0x83, 0x3b, 0x98, 0xf0, 0x0f, 0x4c, 0xb8, 0x56, 0xad, 0xee, 0x55, 0x61, 0xc6,
		0x6e, 0x71, 0x11, 0xfe, 0xd1, 0xbb, 0x5b, 0x9b, 0x71, 0xbf, 0x1c, 0x27, 0x3c, 0xf9, 0x76, 0xd2,
		0x97, 0x87, 0x0d, 0x18, 0x76, 0xd4, 0x11, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x10,
		0x37, 0xc8, 0x49, 0xdc, 0x60, 0xdf, 0x81, 0xb0, 0x41, 0x15, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36,
		0x40, 0xd8, 0x00, 0x61, 0x03, 0xeb, 0x26, 0x5c, 0xae, 0x22, 0x68, 0x80, 0xa0, 0x01, 0x82, 0x06,
		0xb4, 0x41, 0x83, 0xdb, 0xd9, 0xea, 0x73, 0x21, 0x6a, 0x90, 0x5c, 0x0b, 0xc2, 0x06, 0x08, 0x1b,
		0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0xbc, 0xd2, 0x6f, 0x5c, 0x4a, 0x15, 0x44,
		0xf7, 0x0e, 0xc4, 0x0d, 0x1a, 0x8c, 0x97, 0x70, 0x28, 0xd4, 0xf5, 0x34, 0xf1, 0x1f, 0x81, 0x03,
		0x04, 0x0e, 0x7e, 0xa8, 0xba, 0x4a, 0xd0, 0x5c, 0x08, 0x1c, 0xac, 0xb7, 0x09, 0x23, 0xdf, 0x00,
		0xa1, 0x03, 0x84, 0x0e, 0x48, 0xcd, 0x5c, 0xdc, 0x69, 0xa1, 0x06, 0x84, 0x1d, 0x3e, 0x57, 0x52,
		0xbe, 0xf4, 0x4a, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8,
		0xe0, 0xb5, 0x61, 0x03, 0xf2, 0x7a, 0xb8, 0xab, 0x60, 0x84, 0xa8, 0x3e, 0xee, 0x66, 0x92, 0x96,
		0x70, 0x34, 0x61, 0xe6, 0xc1, 0x90, 0x9f, 0xb4, 0xa4, 0x57, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2,
		0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x92, 0x9d, 0xe3, 0x51, 0x10, 0x69,
		0xe9, 0x02, 0x67, 0x99, 0x5f, 0x08, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b,
		0x28, 0x0b, 0x28, 0x0b, 0x28, 0x4b, 0x76, 0x8e, 0x75, 0x14, 0xa8, 0x58, 0x6a, 0x79, 0xeb, 0x40,
		0x5e, 0xe9, 0xb3, 0x6b, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71,
		0x01, 0x71, 0x71, 0x9e, 0xb8, 0xe4, 0xba, 0xbc, 0x28, 0x71, 0x03, 0xc6, 0xcc, 0xf8, 0x8c, 0x0d,
		0x19, 0xb3, 0x0d, 0xf2, 0xb2, 0x3f, 0x2a, 0x70, 0x54, 0xb7, 0xde, 0xe6, 0xe9, 0xe2, 0x78, 0x9e,
		0xdc, 0x7c, 0x33, 0x9d, 0x8e, 0xcc, 0x4f, 0x28, 0x1a, 0x3d, 0xf2, 0x2d, 0xbf, 0x7c, 0xf5, 0xd0,
		0xf9, 0x5d, 0xdc, 0x73, 0x14, 0xc1, 0xf1, 0x0e, 0x65, 0xac, 0x27, 0x06, 0x43, 0xdb, 0xc0, 0xe7,
		0x48, 0xaa, 0x83, 0xa1, 0x98, 0x30, 0xa4, 0x98, 0x56, 0x61, 0x78, 0x47, 0xc1, 0xdd, 0xb3, 0x91,
		0x4b, 0xfb, 0x95, 0x4a, 0xad, 0x5e, 0xa9, 0x14, 0xeb, 0x7b, 0xf5, 0x62, 0xa3, 0x5a, 0x2d, 0xd5,
		0x4a, 0x84, 0x09, 0xc1, 0x5e, 0x3b, 0x1a, 0x88, 0x48, 0x0c, 0x3e, 0x4f, 0x1e, 0xbd, 0x1a, 0x0f,
		0x87, 0xb9, 0xb2, 0x68, 0x26, 0xa8, 0x72, 0x1d, 0xa2, 0x3c, 0xd2, 0x56, 0x13, 0xee, 0x81, 0x92,
		0x87, 0x46, 0xde, 0xfc, 0x8b, 0x74, 0x93, 0x1a, 0x79, 0x93, 0x37, 0x56, 0x76, 0x65, 0xe9, 0xad,
		0x6d, 0x87, 0xef, 0xad, 0x35, 0x5a, 0x51, 0x73, 0xe2, 0x36, 0x31, 0x6d, 0x5f, 0x0e, 0xb6, 0x85,
		0x1a, 0x8c, 0x42, 0xa9, 0xf4, 0x76, 0x3f, 0x1c, 0x86, 0x91, 0x25, 0x4b, 0xa3, 0x61, 0x6d, 0x74,
		0x2c, 0x8d, 0x95, 0x95, 0xd1, 0xb0, 0x30, 0x5b, 0xe6, 0x47, 0xe4, 0xc8, 0x19, 0x1d, 0xb8, 0x45,
		0x6f, 0x4d, 0xef, 0xa5, 0xed, 0xf8, 0x64, 0xf3, 0x1e, 0xd3, 0xec, 0x27, 0x1a, 0x36, 0x7e, 0xdb,
		0x46, 0xcf, 0x62, 0xec, 0x16, 0xcc, 0x9c, 0xd2, 0xbc, 0xcd, 0x1a, 0xb6, 0x39, 0xf3, 0x33, 0xf3,
		0x49, 0x86, 0x0c, 0xd8, 0x96, 0xe1, 0xd2, 0x1a, 0xac, 0x41, 0x4b, 0x25, 0xb1, 0x50, 0x33, 0xa6,
		0xf9, 0x7e, 0x43, 0x32, 0x60, 0x44, 0xde, 0xc2, 0xb3, 0x88, 0xcc, 0xed, 0x72, 0x3d, 0xd5, 0xd3,
		0x7a, 0x31, 0x80, 0x21, 0xc3, 0x37, 0xdb, 0x00, 0xd2, 0x78, 0x72, 0x82, 0x8d, 0x64, 0x03, 0xbb,
		0xc9, 0x03, 0xb6, 0x92, 0x01, 0xac, 0x6f, 0xee, 0x5b, 0xdf, 0xac, 0xb7, 0xbe, 0xf9, 0xee, 0x16,
		0xa4, 0x98, 0x6e, 0x38, 0xe8, 0xcd, 0xe8, 0x88, 0x71, 0xc3, 0x9a, 0x2f, 0x07, 0x2b, 0x74, 0xc7,
		0x52, 0x87, 0x59, 0x6b, 0x59, 0x50, 0x36, 0xb3, 0x9b, 0x68, 0xb2, 0x96, 0x6c, 0x67, 0x23, 0x91,
		0x65, 0x19, 0x91, 0x65, 0x0f, 0x91, 0x65, 0x05, 0xb9, 0x2d, 0xde, 0x6c, 0x75, 0x48, 0x4d, 0x1c,
		0x8b, 0x3d, 0x7b, 0x5c, 0xf0, 0x5f, 0xb6, 0x6c, 0xd1, 0x6e, 0xa3, 0x6c, 0xeb, 0x49, 0x9d, 0x14,
		0x49, 0x9b, 0xb4, 0x49, 0x99, 0x54, 0x49, 0x97, 0xe4, 0x49, 0x95, 0xe4, 0x49, 0x93, 0xe4, 0x49,
		0x91, 0xeb, 0xb5, 0x8f, 0x60, 0xbb, 0x71, 0xb4, 0x97, 0x6c, 0x48, 0x58, 0xb7, 0xe3, 0xf9, 0xea,
		0xb4, 0xb9, 0xff, 0xf1, 0xd2, 0x5d, 0x5a, 0x4e, 0x20, 0x21, 0xcb, 0x85, 0xa7, 0xcc, 0x79, 0xe7,
		0xc9, 0x6d, 0xa7, 0xce, 0x61, 0x67, 0xcb, 0x55, 0x67, 0xcb, 0x49, 0x67, 0xcb, 0x3d, 0x5f, 0xef,
		0x84, 0x08, 0xb2, 0x9c, 0xf1, 0x74, 0xdd, 0x0d, 0x45, 0x70, 0x15, 0x89, 0x2b, 0x8a, 0x45, 0x37,
		0x67, 0x95, 0x75, 0x82, 0xb1, 0x4e, 0x66, 0x41, 0xe8, 0x8f, 0x1f, 0x93, 0x64, 0xdc, 0x42, 0x02,
		0x04, 0xeb, 0x9a, 0x8b, 0x60, 0x91, 0x59, 0xce, 0x53, 0x05, 0xe8, 0x30, 0x39, 0x1d, 0x11, 0xb0,
		0x0c, 0x58, 0x06, 0x2c, 0x03, 0x96, 0x01, 0xcb, 0x1b, 0x0b, 0xcb, 0x29, 0x16, 0x00, 0x99, 0x33,
		0x93, 0x35, 0x4b, 0xe6, 0xa3, 0x03, 0xe6, 0xf9, 0x80, 0xc0, 0x65, 0xe0, 0x32, 0x70, 0x19, 0xb8,
		0x0c, 0x5c, 0xde, 0x58, 0x5c, 0x9e, 0x43, 0x01, 0x60, 0x39, 0x33, 0x57, 0xc9, 0xe1, 0x5e, 0x32,
		0x50, 0xa6, 0x38, 0x4b, 0x6c, 0x79, 0xc3, 0x0f, 0x90, 0x0c, 0x48, 0x06, 0x24, 0x6f, 0x06, 0x24,
		0xdb, 0xde, 0x40, 0x4c, 0x07, 0x9a, 0x9e, 0x51, 0x97, 0x6a, 0x20, 0xe8, 0x8a, 0x33, 0x2d, 0xb6,
		0x7b, 0x4d, 0xc6, 0xa6, 0x3a, 0x98, 0x4f, 0x5a, 0x86, 0x8b, 0xbc, 0xec, 0x16, 0x47, 0x99, 0x2d,
		0xde, 0xb2, 0x5a, 0x5c, 0x65, 0xb4, 0xd8, 0xcb, 0x66, 0xb1, 0x97, 0xc9, 0x62, 0x2f, 0x8b, 0x95,
		0xaf, 0x92, 0x21, 0xe4, 0x65, 0xae, 0x18, 0xb4, 0x18, 0x87, 0x26, 0x5b, 0xa6, 0xcd, 0xfe, 0xc7,
		0xdf, 0x29, 0x24, 0xc5, 0x42, 0xc7, 0xe9, 0xab, 0x99, 0x92, 0x4b, 0x60, 0x2a, 0x2f, 0xe5, 0x0e,
		0x08, 0x98, 0x35, 0x4d, 0x86, 0x52, 0xc6, 0x9a, 0x29, 0x32, 0x95, 0x40, 0x27, 0x40, 0x27, 0x40,
		0x27, 0x40, 0x27, 0x40, 0x27, 0x96, 0xac, 0xdb, 0xb1, 0x54, 0x7a, 0xaf, 0xcc, 0xc0, 0x26, 0x28,
		0xc9, 0x44, 0x27, 0x50, 0xd7, 0x82, 0xbc, 0xb9, 0x3a, 0x43, 0x89, 0x48, 0xce, 0xe6, 0xe9, 0xdc,
		0x45, 0xb3, 0xe7, 0x9d, 0xa5, 0xb9, 0xc6, 0x77, 0xa0, 0x8b, 0x34, 0x47, 0xe1, 0x78, 0xce, 0x66,
		0xe7, 0xae, 0x98, 0x5c, 0xa5, 0xdc, 0xa8, 0x34, 0x6a, 0xf5, 0x72, 0xa3, 0xba, 0xc1, 0xb6, 0x97,
		0xd3, 0x52, 0xa7, 0x5d, 0x88, 0xc8, 0x57, 0x88, 0xc8, 0x9b, 0x9b, 0xb1, 0x92, 0xfa, 0x9e, 0x2b,
		0x44, 0xfd, 0xf2, 0x02, 0x20, 0x2c, 0x21, 0x2c, 0x21, 0x2c, 0x21, 0x2c, 0x21, 0x2c, 0xc9, 0xd7,
		0x2d, 0xe2, 0xd4, 0xcf, 0xfe, 0xce, 0x71, 0x49, 0x8a, 0x38, 0x7d, 0x7d, 0x8f, 0x50, 0xf5, 0xdb,
		0xa6, 0x9c, 0xec, 0xec, 0x4e, 0xc6, 0xa6, 0x89, 0xce, 0xf0, 0x80, 0x57, 0x80, 0x57, 0x80, 0x57,
		0x80, 0x57, 0x80, 0x57, 0x2c, 0x59, 0xb7, 0x72, 0xe4, 0x07, 0x83, 0x41, 0x24, 0xe2, 0x98, 0x83,
		0x5a, 0x34, 0x08, 0xc7, 0x9c, 0xcd, 0x71, 0xee, 0x83, 0xd6, 0x4f, 0x4f, 0xf6, 0xb6, 0xc2, 0xf0,
		0x6c, 0x33, 0xcf, 0x78, 0x9f, 0x61, 0xec, 0x93, 0x40, 0x6b, 0x11, 0x29, 0xf2, 0xc7, 0x9d, 0x5e,
		0xc0, 0xce, 0xce, 0x45, 0xd1, 0x6f, 0x74, 0x1f, 0x2e, 0x4a, 0x7e, 0xa3, 0x9b, 0xbc, 0x2c, 0x4d,
		0xbf, 0x25, 0xaf, 0xcb, 0x17, 0x45, 0xbf, 0x32, 0x7f, 0x5d, 0xbd, 0x28, 0xfa, 0xd5, 0xee, 0xee,
		0x5f, 0x7f, 0x7d, 0xdc, 0xfd, 0xbe, 0xf7, 0xf8, 0xfa, 0x37, 0xd2, 0xf7, 0xe2, 0xeb, 0x72, 0x3c,
		0xd2, 0xf6, 0x69, 0xeb, 0x4f, 0xf6, 0xe7, 0xfa, 0x37, 0xe5, 0x83, 0xfd, 0x85, 0xe1, 0xc9, 0xe6,
		0xb9, 0xe5, 0x1c, 0xaf, 0x33, 0xae, 0xc1, 0x19, 0xb3, 0x3a, 0xe3, 0xc0, 0xbf, 0x6a, 0xfa, 0x5f,
		0xbb, 0xdf, 0x4b, 0x1f, 0x2a, 0x8f, 0x9f, 0x76, 0xbf, 0xd7, 0x1f, 0x5f, 0xfe, 0xf0, 0x61, 0xd9,
		0xaf, 0x95, 0x3e, 0xd4, 0x1f, 0x3f, 0xad, 0xf8, 0x97, 0xda, 0xe3, 0xa7, 0x9f, 0xfc, 0x8c, 0xea,
		0xe3, 0x4e, 0xe6, 0x57, 0x27, 0x3f, 0x2f, 0xaf, 0x7a, 0x43, 0x65, 0xc5, 0x1b, 0xf6, 0x56, 0xbd,
		0x61, 0x6f, 0xc5, 0x1b, 0x56, 0x5e, 0x52, 0x79, 0xc5, 0x1b, 0xaa, 0x8f, 0x0f, 0x99, 0xdf, 0xdf,
		0x59, 0xfe, 0xab, 0xb5, 0xc7, 0xdd, 0x87, 0x55, 0xff, 0x56, 0x7f, 0x7c, 0xf8, 0xb4, 0x0b, 0x68,
		0xa2, 0x87, 0x26, 0x98, 0x39, 0xbd, 0x99, 0xe7, 0x1f, 0xa8, 0xb1, 0x3f, 0xec, 0x62, 0xe4, 0xf6,
		0x4e, 0xfb, 0xec, 0x7b, 0xc4, 0xcb, 0x2e, 0x02, 0xf1, 0x5c, 0xc4, 0x73, 0x11, 0xcf, 0x45, 0x3c,
		0x17, 0xf1, 0x5c, 0xf2, 0x75, 0x8b, 0x7d, 0xe2, 0x67, 0x7f, 0x9f, 0x63, 0x93, 0x14, 0xf1, 0xc2,
		0xff, 0x63, 0xbf, 0xf8, 0x8d, 0x53, 0x2f, 0xd5, 0x6d, 0x30, 0x94, 0x03, 0x3f, 0x12, 0x41, 0x4c,
		0xd8, 0x10, 0xf9, 0x29, 0x94, 0xb2, 0x38, 0x3e, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06, 0xb8, 0x06,
		0xb8, 0x06, 0xf9, 0xba, 0x95, 0x03, 0xa1, 0xb4, 0xd4, 0xf7, 0x4c, 0x7c, 0x83, 0xf0, 0x74, 0x80,
		0xd7, 0x9a, 0xdd, 0xea, 0xe7, 0x20, 0x66, 0x70, 0x19, 0xf3, 0x09, 0x6f, 0x1d, 0xff, 0xd1, 0x3c,
		0x6c, 0x7d, 0xe9, 0x75, 0xda, 0xe7, 0x67, 0x07, 0xbd, 0xce, 0x41, 0xf3, 0xb4, 0x7d, 0x4c, 0xed,
		0x3d, 0xa6, 0x87, 0x34, 0x62, 0x96, 0x30, 0x27, 0xd3, 0xa9, 0x98, 0x97, 0xb3, 0xff, 0xeb, 0xe1,
		0xf9, 0xe9, 0xd9, 0x41, 0xa7, 0x77, 0xd8, 0x6e, 0x9f, 0x78, 0x9b, 0x70, 0x28, 0xc9, 0x91, 0x79,
		0x6f, 0x77, 0x5a, 0xbf, 0xb5, 0x8e, 0x9b, 0x67, 0xed, 0x0e, 0x66, 0x9d, 0x6e, 0xd6, 0x9b, 0xa7,
		0x30, 0x74, 0x6a, 0x07, 0xd3, 0x3e, 0xfe, 0x7a, 0xf0, 0xc5, 0xcb, 0xf9, 0x99, 0xb3, 0x6e, 0xde,
		0xf8, 0x5e, 0x2e, 0xd4, 0xfd, 0x30, 0x88, 0xb5, 0x7f, 0x13, 0x0e, 0xe4, 0x95, 0x14, 0x03, 0x7a,
		0x71, 0xbf, 0x38, 0x3c, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xf9, 0xba,
		0xd5, 0xf2, 0x46, 0x68, 0xd9, 0xff, 0x16, 0xd7, 0x2a, 0x0c, 0xda, 0x9e, 0x30, 0x4d, 0xcd, 0x3b,
		0x57, 0xc9, 0x19, 0x7f, 0x4f, 0x05, 0x2a, 0x8c, 0x45, 0x3f, 0x54, 0x03, 0xd2, 0x5c, 0x78, 0x54,
		0x53, 0xc9, 0x1f, 0xc6, 0x2f, 0x8f, 0x9a, 0xa0, 0x9a, 0x0a, 0xb9, 0xc9, 0xa1, 0x9a, 0xca, 0x76,
		0x69, 0xbf, 0x52, 0xa9, 0xd5, 0x2b, 0x95, 0x62, 0x7d, 0xaf, 0x5e, 0x6c, 0x54, 0xab, 0xa5, 0x5a,
		0x09, 0x75, 0x55, 0x72, 0x37, 0x1a, 0xf2, 0xe6, 0x7e, 0xde, 0x0c, 0xa9, 0x7a, 0x22, 0x65, 0x48,
		0x15, 0x4d, 0x6f, 0xa4, 0x74, 0xd8, 0x2f, 0xe2, 0x2a, 0x18, 0x0f, 0xa7, 0x54, 0xbc, 0x08, 0x2d,
		0x0d, 0x2d, 0x0d, 0x2d, 0x0d, 0x2d, 0x0d, 0x2d, 0x8d, 0xa2, 0xa0, 0x90, 0xb1, 0x90, 0xb1, 0x90,
		0xb1, 0x90, 0xb1, 0x6b, 0x65, 0x72, 0x28, 0x0a, 0x0a, 0xf1, 0x0a, 0xf1, 0xba, 0xed, 0xcd, 0x92,
		0x9f, 0xc3, 0xb1, 0x16, 0xf4, 0x02, 0xf6, 0xf9, 0xe0, 0x10, 0x94, 0x10, 0x94, 0x10, 0x94, 0x10,
		0x94, 0x10, 0x94, 0xe4, 0xeb, 0xf6, 0x32, 0x0c, 0x87, 0x22, 0x50, 0x1c, 0x49, 0xd7, 0xa5, 0xbc,
		0x40, 0xf5, 0x5a, 0x37, 0xc8, 0x6c, 0x2a, 0x15, 0xea, 0x60, 0xc2, 0x46, 0x69, 0xfa, 0x64, 0xc6,
		0xfd, 0x7f, 0xc4, 0x4d, 0x30, 0x9a, 0x1d, 0xba, 0x2b, 0x84, 0x23, 0xa1, 0xfa, 0x53, 0xa0, 0x9c,
		0xf8, 0x8f, 0xc2, 0xe4, 0x2b, 0x92, 0x97, 0x85, 0xe0, 0x4a, 0xfa, 0x71, 0x70, 0x25, 0xe3, 0xf4,
		0x55, 0x61, 0x5a, 0xf7, 0x26, 0x8e, 0xb4, 0xf0, 0x47, 0xe1, 0x50, 0xf6, 0xef, 0x0b, 0x4a, 0xc8,
		0xeb, 0x7f, 0x2e, 0xc3, 0x28, 0x4e, 0x5f, 0x15, 0x82, 0xc1, 0xbf, 0x53, 0x57, 0x14, 0x8e, 0xb5,
		0x3f, 0x8a, 0x44, 0x61, 0x4a, 0x2f, 0xe2, 0xe4, 0x5b, 0x81, 0xa2, 0x73, 0x71, 0x72, 0x8b, 0x3a,
		0x1a, 0xf7, 0xb5, 0x9a, 0xad, 0xb0, 0x76, 0x7a, 0x87, 0x9f, 0xaf, 0x47, 0xbd, 0xc9, 0x57, 0x47,
		0x5e, 0xf6, 0x9a, 0x57, 0xf2, 0x74, 0x72, 0x7f, 0xf3, 0x17, 0xbd, 0xd6, 0xe8, 0xb6, 0x76, 0x1a,
		0x69, 0x71, 0x32, 0xbd, 0xb9, 0xde, 0xf1, 0xfc, 0xe6, 0xd2, 0x57, 0xbd, 0xe6, 0xe0, 0xdf, 0x8e,
		0xbc, 0x6c, 0x8f, 0xf5, 0x49, 0x24, 0x7a, 0x9d, 0xe9, 0x9d, 0x25, 0xdf, 0x7a, 0xa7, 0xd3, 0x3b,
		0x43, 0x6f, 0xec, 0xcc, 0x93, 0x18, 0xab, 0x6f, 0x2a, 0xfc, 0x4f, 0xf9, 0x81, 0xd6, 0x91, 0xbc,
		0x9c, 0xcc, 0x18, 0x5d, 0xa3, 0xec, 0x25, 0x63, 0xa3, 0x6b, 0xb6, 0xab, 0x7c, 0x16, 0x5d, 0xb3,
		0xf3, 0xc9, 0x57, 0xd1, 0x35, 0xfb, 0x4d, 0xb3, 0x46, 0xd6, 0x35, 0x3b, 0xe3, 0x24, 0xe9, 0x03,
		0x11, 0xd9, 0x4b, 0xa0, 0x0d, 0x47, 0x94, 0x10, 0x8e, 0x40, 0x38, 0x02, 0xe1, 0x08, 0x84, 0x23,
		0xdc, 0x09, 0x47, 0x50, 0xb9, 0xff, 0x74, 0xc0, 0x69, 0x8f, 0x68, 0x4d, 0x1d, 0x04, 0x59, 0xf0,
		0x18, 0x4f, 0x97, 0x40, 0x6c, 0xba, 0x3c, 0x9b, 0x62, 0xe4, 0x70, 0xc0, 0x09, 0x0b, 0x6e, 0xc0,
		0x03, 0x37, 0x4c, 0x38, 0x03, 0x17, 0xce, 0xc0, 0x86, 0x33, 0xf0, 0x41, 0x0b, 0x23, 0xc4, 0x70,
		0x92, 0xce, 0xf2, 0x19, 0x87, 0x83, 0xdf, 0xe6, 0x2d, 0x69, 0x96, 0x61, 0xfb, 0x75, 0x9e, 0xb2,
		0xd9, 0xf3, 0x12, 0x67, 0x49, 0xa5, 0xb2, 0x27, 0xb0, 0xcb, 0x69, 0x1a, 0x00, 0xa1, 0x69, 0x7b,
		0x49, 0x5c, 0x99, 0x8d, 0xb8, 0x50, 0x85, 0xb5, 0x19, 0xb5, 0x2b, 0x48, 0x0b, 0x48, 0x0b, 0x48,
		0x0b, 0x48, 0x0b, 0x07, 0x69, 0xa1, 0xd6, 0xc2, 0x8b, 0x9a, 0x78, 0x28, 0x18, 0x33, 0x84, 0x17,
		0xa4, 0xf1, 0xe4, 0x4a, 0x3e, 0x6c, 0x64, 0xda, 0x28, 0x17, 0xe8, 0xb8, 0x00, 0x3e, 0x6e, 0x81,
		0x90, 0x2b, 0x60, 0xe4, 0x1c, 0x28, 0x39, 0x07, 0x4e, 0xce, 0x81, 0x14, 0x0f, 0x58, 0x31, 0x81,
		0x16, 0xbf, 0xe2, 0xce, 0xf8, 0x8d, 0xb1, 0x54, 0xba, 0x54, 0xe3, 0xf4, 0x19, 0x33, 0x14, 0xa9,
		0x31, 0x5e, 0x02, 0xcf, 0xc1, 0xa6, 0x97, 0x7f, 0x78, 0x7d, 0xe6, 0x36, 0xf7, 0xc1, 0x27, 0xc7,
		0xe8, 0x45, 0xe6, 0x72, 0x98, 0x0f, 0x46, 0x65, 0xae, 0xc7, 0x81, 0xc3, 0x2a, 0x8e, 0xb8, 0xd3,
		0x45, 0x13, 0x0e, 0xee, 0x60, 0xc2, 0x3f, 0x30, 0xe1, 0x5a, 0xb5, 0xba, 0x57, 0x85, 0x19, 0xbb,
		0xc5, 0x45, 0xf8, 0x47, 0xef, 0x6e, 0x6d, 0xc6, 0xfd, 0x72, 0x9c, 0xef, 0xe4, 0xdb, 0x49, 0x5f,
		0x1e, 0x36, 0x60, 0xd8, 0x51, 0x47, 0xdc, 0x00, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc,
		0x20, 0x27, 0x71, 0x83, 0x7d, 0x07, 0xc2, 0x06, 0x55, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00,
		0x61, 0x03, 0x84, 0x0d, 0xac, 0x9b, 0x70, 0xb9, 0x8a, 0xa0, 0x01, 0x82, 0x06, 0x08, 0x1a, 0xd0,
		0x06, 0x0d, 0x6e, 0x67, 0xab, 0xcf, 0x85, 0xa8, 0x41, 0x72, 0x2d, 0x08, 0x1b, 0x20, 0x6c, 0x80,
		0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0xf0, 0x4a, 0xbf, 0x71, 0x29, 0x55, 0x10, 0xdd,
		0x3b, 0x10, 0x37, 0x68, 0x30, 0x5e, 0xc2, 0xa1, 0x50, 0xd7, 0xd3, 0xc4, 0x7f, 0x04, 0x0e, 0x10,
		0x38, 0xf8, 0xa1, 0xea, 0x2a, 0x41, 0x73, 0x21, 0x70, 0xb0, 0xde, 0x26, 0x8c, 0x7c, 0x03, 0x84,
		0x0e, 0x10, 0x3a, 0x20, 0x35, 0x73, 0x71, 0xa7, 0x85, 0x1a, 0x10, 0xf6, 0xf7, 0x5c, 0x49, 0xf9,
		0xd2, 0x2b, 0x41, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x83,
		0xd7, 0x86, 0x0d, 0xc8, 0xab, 0xe1, 0xae, 0x82, 0x11, 0xa2, 0xea, 0xb8, 0x9b, 0x49, 0x5a, 0xc2,
		0xd1, 0x84, 0x99, 0x07, 0x43, 0x7e, 0xd2, 0x92, 0x5e, 0x09, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b,
		0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x4b, 0x76, 0x8e, 0x47, 0x41, 0xa4, 0xa5,
		0x0b, 0x9c, 0x65, 0x7e, 0x21, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xa0,
		0x2c, 0xa0, 0x2c, 0xa0, 0x2c, 0xd9, 0x39, 0xd6, 0x51, 0xa0, 0x62, 0xa9, 0xe5, 0xad, 0x03, 0x79,
		0xa5, 0xcf, 0xae, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05, 0xc4, 0x05,
		0xc4, 0xc5, 0x79, 0xe2, 0x92, 0xeb, 0xf2, 0xa2, 0xc4, 0xed, 0x17, 0x33, 0xe3, 0xf3, 0xb5, 0x63,
		0xcc, 0xf6, 0xc7, 0xcb, 0xfe, 0xa8, 0xc0, 0x51, 0xdc, 0x7a, 0x9b, 0xa5, 0x87, 0xe3, 0x79, 0x72,
		0xef, 0xcd, 0x74, 0x36, 0x32, 0x3f, 0xa1, 0x68, 0xf3, 0xc8, 0xb7, 0xf8, 0xf2, 0xd5, 0x41, 0xe7,
		0x77, 0x71, 0xcf, 0x51, 0x02, 0xc7, 0x3b, 0x94, 0xb1, 0x9e, 0x18, 0x0c, 0x6d, 0xfb, 0x9e, 0x23,
		0xa9, 0x0e, 0x86, 0x62, 0xc2, 0x8f, 0x62, 0x5a, 0x7d, 0xe1, 0x1d, 0x05, 0x77, 0xcf, 0x46, 0x2e,
		0xed, 0x57, 0x2a, 0xb5, 0x7a, 0xa5, 0x52, 0xac, 0xef, 0xd5, 0x8b, 0x8d, 0x6a, 0xb5, 0x54, 0x2b,
		0x11, 0xa6, 0x03, 0x7b, 0xed, 0x68, 0x20, 0x22, 0x31, 0xf8, 0x3c, 0x79, 0xf4, 0x6a, 0x3c, 0x1c,
		0xe6, 0xca, 0xa2, 0x99, 0x80, 0xca, 0x71, 0x80, 0xf2, 0x48, 0xfb, 0x4c, 0x38, 0x07, 0x49, 0x1e,
		0x5a, 0x78, 0xf3, 0x2f, 0xd1, 0x0d, 0x6a, 0xe1, 0x4d, 0xde, 0x53, 0xd9, 0x91, 0x85, 0xb7, 0xb6,
		0xbd, 0xbd, 0xb7, 0xd6, 0x68, 0x3d, 0xcd, 0x49, 0xdb, 0xc4, 0xb0, 0x7d, 0x39, 0xd8, 0x16, 0x6a,
		0x30, 0x0a, 0xa5, 0xd2, 0xdb, 0xfd, 0x70, 0x18, 0x46, 0x96, 0x0c, 0x8d, 0x86, 0xb1, 0xd1, 0x31,
		0x34, 0x56, 0x46, 0x46, 0xc3, 0xc0, 0x6c, 0x99, 0x1f, 0x91, 0x1b, 0xe7, 0x73, 0xdf, 0x16, 0x7d,
		0x35, 0xb9, 0x8f, 0xb6, 0xe3, 0x91, 0xcd, 0xfb, 0x4b, 0xb3, 0x9f, 0x68, 0xd8, 0xf4, 0x6d, 0x9b,
		0x3c, 0x87, 0xa9, 0x5b, 0x30, 0x72, 0x42, 0xe3, 0x36, 0x6b, 0xd6, 0xe6, 0x8c, 0xcf, 0xcc, 0x27,
		0x19, 0x32, 0x5f, 0x5b, 0x66, 0x4b, 0x6a, 0xae, 0x06, 0xed, 0x94, 0xc2, 0x3e, 0xcd, 0x18, 0xe6,
		0xfb, 0xcd, 0xc8, 0x80, 0x09, 0x79, 0xf3, 0x47, 0xe2, 0x07, 0x83, 0x41, 0x24, 0xe2, 0xd8, 0x98,
		0x11, 0xa5, 0xdb, 0x54, 0x99, 0x11, 0x0c, 0x19, 0xbe, 0xd9, 0x14, 0x06, 0xe3, 0x29, 0x09, 0x36,
		0x52, 0x0c, 0xec, 0xa6, 0x0c, 0xd8, 0x4a, 0x01, 0xb0, 0xbe, 0xa5, 0x6f, 0x7d, 0x8b, 0xde, 0xfa,
		0x96, 0xbb, 0x5b, 0x90, 0x62, 0x7c, 0x8b, 0xdb, 0x62, 0xcf, 0x63, 0x1b, 0xbd, 0x8c, 0xb3, 0x3d,
		0x8a, 0x33, 0x3e, 0x2c, 0x47, 0x08, 0x60, 0xb6, 0x65, 0xb0, 0x95, 0x56, 0xc0, 0x86, 0x5b, 0xfc,
		0xc2, 0xd7, 0xc3, 0xd7, 0xc3, 0xd7, 0x27, 0x77, 0x6b, 0xba, 0xa5, 0xac, 0x3d, 0x42, 0x49, 0x45,
		0x2c, 0x2d, 0x11, 0x4c, 0x6b, 0xce, 0xc7, 0xa6, 0x13, 0xa2, 0x71, 0x46, 0xb6, 0x9d, 0x12, 0x99,
		0x73, 0x22, 0x73, 0x52, 0x64, 0xce, 0x6a, 0x3d, 0x42, 0x77, 0xd6, 0x72, 0x32, 0x53, 0xbb, 0x97,
		0x23, 0x4b, 0x5e, 0x66, 0x81, 0xde, 0x58, 0x28, 0xd0, 0x39, 0x9f, 0x1b, 0x3b, 0x65, 0x37, 0x2d,
		0xee, 0x0c, 0x3c, 0xcd, 0xfc, 0x6d, 0xc5, 0xe2, 0xdc, 0x67, 0x9e, 0xc1, 0xbe, 0xc5, 0x31, 0x4e,
		0x02, 0xad, 0x45, 0xa4, 0xac, 0x57, 0x41, 0xf5, 0x76, 0x76, 0x2e, 0x8a, 0x7e, 0xa3, 0xfb, 0x70,
		0x51, 0xf2, 0x1b, 0xdd, 0xe4, 0x65, 0x69, 0xfa, 0x2d, 0x79, 0x5d, 0xbe, 0x28, 0xfa, 0x95, 0xf9,
		0xeb, 0xea, 0x45, 0xd1, 0xaf, 0x76, 0x77, 0xff, 0xfa, 0xeb, 0xe3, 0xee, 0xf7, 0xbd, 0xc7, 0xd7,
		0xbf, 0xd1, 0xde, 0x7e, 0x70, 0xd7, 0xe6, 0xa3, 0x68, 0x9f, 0xb6, 0xfe, 0x24, 0x7b, 0x1e, 0x7f,
		0x53, 0x3e, 0x90, 0x5f, 0x2c, 0x3e, 0x91, 0x75, 0xda, 0xc4, 0xa4, 0x71, 0x4e, 0x35, 0x38, 0xa7,
		0x37, 0x39, 0xa7, 0xc0, 0xbf, 0x6a, 0xfa, 0x5f, 0xbb, 0xdf, 0x4b, 0x1f, 0x2a, 0x8f, 0x9f, 0x76,
		0xbf, 0xd7, 0x1f, 0x5f, 0xfe, 0xf0, 0x61, 0xd9, 0xaf, 0x95, 0x3e, 0xd4, 0x1f, 0x3f, 0xad, 0xf8,
		0x97, 0xda, 0xe3, 0xa7, 0x9f, 0xfc, 0x8c, 0xea, 0xe3, 0x4e, 0xe6, 0x57, 0x27, 0x3f, 0x2f, 0xaf,
		0x7a, 0x43, 0x65, 0xc5, 0x1b, 0xf6, 0x56, 0xbd, 0x61, 0x6f, 0xc5, 0x1b, 0x56, 0x5e, 0x52, 0x79,
		0xc5, 0x1b, 0xaa, 0x8f, 0x0f, 0x99, 0xdf, 0xdf, 0x59, 0xfe, 0xab, 0xb5, 0xc7, 0xdd, 0x87, 0x55,
		0xff, 0x56, 0x7f, 0x7c, 0xf8, 0xb4, 0x0b, 0x57, 0xfd, 0xf3, 0xae, 0x1a, 0xe6, 0x49, 0x6f, 0x9e,
		0xeb, 0x07, 0x5c, 0x5b, 0x6e, 0x5f, 0x27, 0xf6, 0xbc, 0x5f, 0xf7, 0xb9, 0x56, 0xf7, 0xbc, 0x4d,
		0x1f, 0x1f, 0xb2, 0xb5, 0xd3, 0x6d, 0xf0, 0x64, 0x8f, 0x81, 0x0d, 0x8e, 0x2d, 0x46, 0x7b, 0x9b,
		0x27, 0x61, 0x1a, 0x0e, 0x34, 0x9a, 0x4d, 0xb3, 0x34, 0x9f, 0x4e, 0x49, 0x92, 0x36, 0x69, 0x36,
		0x3d, 0xf2, 0xbd, 0x0f, 0xda, 0xb0, 0x43, 0xb1, 0xea, 0x48, 0x3c, 0x23, 0x7b, 0x7e, 0x36, 0x5c,
		0xc7, 0xfb, 0x9c, 0xc6, 0xdb, 0x97, 0xfa, 0xdb, 0xde, 0xf9, 0x46, 0x9b, 0x31, 0x65, 0x2b, 0x36,
		0x6c, 0xe4, 0x1d, 0xa6, 0x61, 0xd6, 0x24, 0xde, 0x66, 0x09, 0xaf, 0x7f, 0x8e, 0xaf, 0x7b, 0xc7,
		0x2b, 0x9f, 0xf8, 0x7b, 0x9f, 0xb4, 0xb9, 0x27, 0xfc, 0x86, 0xe7, 0x6a, 0xe2, 0x79, 0xbe, 0xee,
		0x29, 0xfe, 0xfc, 0xb3, 0x78, 0xc5, 0x73, 0x48, 0x22, 0x2c, 0x63, 0x25, 0xfb, 0x41, 0xac, 0x5f,
		0xfd, 0x14, 0x16, 0xe3, 0x34, 0xf3, 0x4f, 0x79, 0xa5, 0x15, 0xbc, 0x2d, 0xf7, 0xe0, 0xcd, 0xdb,
		0x7c, 0xef, 0xd9, 0xc6, 0x33, 0xb3, 0x4d, 0xf7, 0xde, 0x6d, 0x38, 0x63, 0xdb, 0x6c, 0xc6, 0xb6,
		0xd1, 0x8c, 0x6d, 0x93, 0xd9, 0xf5, 0x37, 0x6f, 0xdd, 0x8b, 0xf7, 0x86, 0xc9, 0x3d, 0xbd, 0xfd,
		0x89, 0xa5, 0xf9, 0x59, 0xb3, 0x0f, 0x7a, 0xe3, 0x34, 0xbf, 0x2f, 0x4d, 0xe7, 0x69, 0xc9, 0x94,
		0xdf, 0xf8, 0x01, 0x06, 0x76, 0xc0, 0xcd, 0xee, 0x74, 0x9b, 0xda, 0xd1, 0x36, 0xbe, 0x73, 0x6d,
		0x7c, 0x87, 0xda, 0xf8, 0x4e, 0x34, 0x2d, 0xa9, 0x7b, 0x6f, 0x1a, 0x8c, 0x37, 0x3b, 0x70, 0xf1,
		0xee, 0x07, 0x3d, 0x37, 0x3f, 0x23, 0x07, 0x38, 0x0c, 0xe5, 0xcd, 0x19, 0x4b, 0x59, 0x31, 0x99,
		0xa2, 0x62, 0x27, 0x25, 0xc5, 0x74, 0x0a, 0x8a, 0xb5, 0x94, 0x13, 0x6b, 0x29, 0x26, 0xd6, 0x52,
		0x4a, 0x78, 0x43, 0x39, 0xa6, 0xf2, 0xdc, 0x92, 0x85, 0x69, 0x3e, 0x5d, 0xd6, 0xe4, 0xa1, 0x44,
		0xa4, 0xcb, 0x22, 0x5d, 0xd6, 0xb6, 0x9b, 0xb0, 0xee, 0x2e, 0xcc, 0xc5, 0x90, 0xb7, 0x5d, 0x4e,
		0x97, 0x0d, 0x23, 0x79, 0x6d, 0xa1, 0x21, 0xf0, 0xd3, 0x72, 0x48, 0x3e, 0x1f, 0xa9, 0xb1, 0x48,
		0x8d, 0x65, 0x75, 0x44, 0x64, 0x0e, 0x89, 0xcc, 0x31, 0x99, 0x75, 0x50, 0x86, 0x1d, 0x55, 0x3a,
		0x0b, 0xf6, 0x53, 0x63, 0xcd, 0x9f, 0xe9, 0xca, 0xf0, 0x98, 0xba, 0x85, 0xcf, 0xce, 0x9c, 0xf1,
		0x9a, 0x79, 0x4a, 0x57, 0x37, 0xe0, 0x0d, 0x92, 0x99, 0x59, 0x51, 0x19, 0x7b, 0xa0, 0x33, 0x1f,
		0x00, 0xa8, 0x03, 0xd4, 0x01, 0xea, 0x00, 0x75, 0x80, 0x3a, 0x2b, 0x51, 0x67, 0xee, 0x2a, 0x37,
		0x01, 0x76, 0xec, 0xb8, 0xc3, 0x27, 0xd4, 0xb1, 0x22, 0xa0, 0x01, 0x3a, 0x00, 0x1d, 0x80, 0x0e,
		0x40, 0x27, 0x57, 0xa0, 0x93, 0x98, 0xfd, 0x06, 0x60, 0x8e, 0xd9, 0xe2, 0x16, 0x19, 0x83, 0xb0,
		0xd1, 0x12, 0xc0, 0x70, 0xf4, 0x1e, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0xd8, 0x41, 0x1c, 0xd3, 0xbb,
		0x01, 0xe9, 0x07, 0x4f, 0x7b, 0x35, 0x48, 0x35, 0x10, 0xf6, 0x5a, 0x94, 0xa5, 0x4b, 0xeb, 0xd9,
		0x58, 0xb6, 0x6a, 0x19, 0x5b, 0x6d, 0x36, 0x67, 0xbd, 0x99, 0x1c, 0x45, 0xb3, 0x38, 0xda, 0x66,
		0x70, 0x54, 0xcd, 0xde, 0xc8, 0x9b, 0xb9, 0x91, 0x37, 0x6b, 0x23, 0x6f, 0xc6, 0xb6, 0x5e, 0x55,
		0xcc, 0xad, 0x37, 0x4b, 0x23, 0xa0, 0xe6, 0x14, 0x14, 0x7d, 0x19, 0x55, 0x5f, 0xfa, 0x77, 0xea,
		0xac, 0x63, 0xa1, 0xe3, 0xf4, 0xd5, 0x8c, 0xd2, 0x27, 0x0e, 0x7c, 0x5d, 0x0a, 0x41, 0x5b, 0xe0,
		0x70, 0xfd, 0xf0, 0xe6, 0x66, 0xac, 0xa4, 0xbe, 0xa7, 0xc2, 0xcd, 0x97, 0x03, 0x02, 0x3c, 0x01,
		0x9e, 0x00, 0x4f, 0x80, 0x27, 0xc0, 0xd3, 0x55, 0xf0, 0x9c, 0x7b, 0x6c, 0x29, 0xe2, 0xf4, 0xf5,
		0x3d, 0xf0, 0x33, 0x99, 0x3c, 0x71, 0xa7, 0x7d, 0x72, 0x0c, 0x5d, 0x36, 0x28, 0x70, 0x14, 0x38,
		0x0a, 0x1c, 0x05, 0x8e, 0x02, 0x47, 0x5d, 0xc5, 0xd1, 0xe7, 0x5e, 0x7b, 0x82, 0xa5, 0x0b, 0x5e,
		0x1c, 0x78, 0x9a, 0x4c, 0xa2, 0x54, 0xb7, 0xc1, 0x50, 0x0e, 0xfc, 0x48, 0x04, 0xb1, 0xc5, 0x2e,
		0x5a, 0x4f, 0x47, 0x9c, 0x17, 0xc7, 0x03, 0x8a, 0x02, 0x45, 0x81, 0xa2, 0x40, 0xd1, 0x35, 0x44,
		0x51, 0x39, 0x10, 0x4a, 0x4b, 0x7d, 0x4f, 0x84, 0xa4, 0x36, 0x7b, 0x40, 0xb6, 0x66, 0xb7, 0xf2,
		0x39, 0x88, 0x09, 0x96, 0xe8, 0x7c, 0x02, 0x5b, 0xc7, 0x7f, 0x34, 0x0f, 0x5b, 0x5f, 0x7a, 0x9d,
		0xf6, 0xf9, 0xd9, 0x41, 0xaf, 0x73, 0xd0, 0x3c, 0x6d, 0x1f, 0xdb, 0x5e, 0xad, 0x7f, 0x04, 0xc3,
		0xf1, 0xf4, 0xfc, 0xf3, 0x85, 0xf5, 0x1e, 0xb8, 0x34, 0x0d, 0xbf, 0x33, 0xb3, 0xf9, 0xeb, 0xe1,
		0xf9, 0xe9, 0xd9, 0x41, 0xa7, 0x77, 0xd8, 0x6e, 0x9f, 0xd8, 0xef, 0x35, 0x4d, 0xd0, 0x4a, 0x9d,
		0x69, 0x1e, 0xdb, 0x9d, 0xd6, 0x6f, 0xad, 0xe3, 0xe6, 0x59, 0xbb, 0x83, 0x59, 0x7c, 0xfb, 0x2c,
		0x36, 0x4f, 0x61, 0x88, 0xef, 0x5d, 0xd0, 0xed, 0xe3, 0xaf, 0x07, 0x5f, 0xbc, 0x35, 0x6f, 0xe8,
		0xde, 0x5d, 0x37, 0x7e, 0xb2, 0x16, 0xea, 0x6d, 0x18, 0xc4, 0xda, 0xbf, 0x09, 0x07, 0xf2, 0x4a,
		0x8a, 0x81, 0x7d, 0xf1, 0xb6, 0x38, 0x1c, 0xb4, 0x1b, 0xb4, 0x1b, 0xb4, 0x1b, 0xb4, 0xdb, 0x1a,
		0x6a, 0x37, 0x2d, 0x6f, 0x84, 0x96, 0xfd, 0x6f, 0x71, 0xad, 0x42, 0xa0, 0xdd, 0x6c, 0xb6, 0x43,
		0x38, 0x57, 0x72, 0x5a, 0xfe, 0xd6, 0x53, 0x81, 0x0a, 0x63, 0xd1, 0x0f, 0xd5, 0xc0, 0x6a, 0x8b,
		0x87, 0x4e, 0xa0, 0xae, 0x85, 0x75, 0xfd, 0x64, 0x9f, 0x6a, 0x79, 0x47, 0x52, 0x59, 0xf7, 0x68,
		0x44, 0x98, 0xb6, 0x5c, 0xe5, 0x12, 0x8e, 0xf7, 0x35, 0x0a, 0xfa, 0x5a, 0x86, 0xea, 0x8b, 0xbc,
		0x4e, 0xac, 0xb1, 0x98, 0x07, 0xbe, 0xef, 0x1d, 0x05, 0x77, 0xb9, 0x37, 0x11, 0x3b, 0x65, 0xb3,
		0x9d, 0xb5, 0x9a, 0xad, 0xf5, 0xfc, 0xf4, 0xee, 0x06, 0x6b, 0x1c, 0x4b, 0xa5, 0x87, 0xb2, 0x5c,
		0xda, 0x46, 0x09, 0x22, 0xa8, 0x1a, 0xa8, 0x1a, 0xa8, 0x1a, 0xa8, 0x1a, 0x92, 0x75, 0x33, 0x56,
		0xd2, 0xda, 0x96, 0xfa, 0xb6, 0xe5, 0x06, 0xa0, 0x2f, 0xa7, 0x6b, 0xed, 0xf5, 0x05, 0x49, 0x4b,
		0x56, 0x8e, 0x27, 0x44, 0xfb, 0xa4, 0xe8, 0x9e, 0xd8, 0x92, 0x27, 0x47, 0xd2, 0xd2, 0x75, 0xe5,
		0x33, 0xdc, 0x27, 0x1c, 0x93, 0xaa, 0x6f, 0x5d, 0x66, 0xe0, 0x7c, 0xb4, 0x80, 0xcd, 0xf0, 0x75,
		0xca, 0x47, 0x47, 0xd9, 0x77, 0x30, 0x33, 0x7a, 0x5e, 0x5a, 0xc6, 0xd2, 0x28, 0x2e, 0x86, 0x28,
		0x06, 0x9f, 0xf3, 0xac, 0xc1, 0x79, 0x92, 0x38, 0x4f, 0xf4, 0x00, 0xcd, 0x53, 0x8b, 0xda, 0x8d,
		0x87, 0x12, 0x98, 0x73, 0xae, 0x5a, 0xda, 0x32, 0x01, 0xeb, 0xd6, 0x7a, 0xdf, 0x87, 0x65, 0x62,
		0x40, 0xa9, 0x7f, 0x49, 0xd2, 0x64, 0x33, 0xf8, 0x4f, 0xb0, 0x89, 0x41, 0x9b, 0x36, 0x9b, 0x99,
		0xd8, 0xd6, 0xf1, 0xe9, 0x59, 0xf3, 0xf0, 0xb0, 0x77, 0xd2, 0x69, 0x9f, 0xb5, 0x7f, 0x6d, 0x1f,
		0xf6, 0xce, 0xfe, 0xef, 0xe4, 0xc0, 0xa3, 0xdc, 0x3e, 0x8a, 0x49, 0x31, 0xe2, 0x3b, 0x2d, 0x1a,
		0xcd, 0xa7, 0xf9, 0x4b, 0xab, 0x73, 0xf0, 0xeb, 0xd9, 0xe1, 0xff, 0xf5, 0x7e, 0x6d, 0x1f, 0x1f,
		0x1f, 0xfc, 0x7a, 0x46, 0x91, 0x8a, 0x47, 0x2c, 0x0f, 0x18, 0x67, 0xf7, 0xf3, 0x6f, 0x27, 0x98,
		0x4e, 0x83, 0x3e, 0xe1, 0xb7, 0x23, 0xcc, 0xa7, 0xc1, 0xf9, 0x3c, 0x69, 0x1d, 0x61, 0x3a, 0xcd,
		0x4d, 0xe7, 0xe9, 0x59, 0xf3, 0xac, 0xf5, 0x2b, 0x66, 0xd4, 0xdc, 0x8c, 0xb6, 0x4f, 0x4f, 0xbe,
		0x62, 0x3e, 0xcd, 0xce, 0xe7, 0x1e, 0x26, 0xd4, 0x20, 0x22, 0x9d, 0xb6, 0x4e, 0x31, 0x9f, 0xe6,
		0xe6, 0xf3, 0xb0, 0xfd, 0x6b, 0xf3, 0xb0, 0xd7, 0xfc, 0xed, 0xb7, 0xce, 0xc1, 0x6f, 0xcd, 0xb3,
		0x03, 0xc2, 0xa9, 0xdd, 0xca, 0x47, 0x74, 0x00, 0x29, 0x60, 0x76, 0xaf, 0xd7, 0x46, 0x0a, 0x98,
		0xad, 0x4e, 0x40, 0x99, 0xd5, 0x65, 0xa7, 0x23, 0x50, 0x3a, 0xcc, 0x17, 0x71, 0x15, 0x8c, 0x87,
		0xd3, 0x3c, 0x99, 0x22, 0x12, 0xcd, 0x96, 0x0f, 0x80, 0x44, 0xb3, 0x37, 0x3f, 0x79, 0x24, 0x9a,
		0xad, 0x85, 0x37, 0xcf, 0x41, 0xa2, 0x99, 0x54, 0x7a, 0xaf, 0x4c, 0x90, 0x69, 0x56, 0xc7, 0x49,
		0x96, 0x1f, 0xdf, 0x08, 0x4e, 0xb2, 0x98, 0x1b, 0x0f, 0x27, 0x59, 0xd6, 0xd6, 0x44, 0x2a, 0xe5,
		0x46, 0xa5, 0x51, 0xab, 0x97, 0x1b, 0x38, 0xbf, 0x02, 0xf1, 0xe2, 0x92, 0x78, 0xb1, 0x4b, 0x68,
		0xed, 0xf6, 0x95, 0x83, 0xac, 0x80, 0xac, 0x80, 0xac, 0x80, 0xac, 0xa0, 0xa9, 0xa8, 0x36, 0xba,
		0xad, 0xf9, 0xd6, 0x6d, 0x8c, 0x22, 0x45, 0x94, 0x2c, 0x25, 0x14, 0x29, 0xa0, 0x6c, 0x39, 0x73,
		0x85, 0x9d, 0x52, 0xf9, 0xa2, 0xe8, 0xef, 0x27, 0x69, 0xeb, 0xa5, 0x6e, 0x26, 0x9b, 0x7d, 0xfa,
		0x5f, 0x8b, 0x99, 0xa2, 0x5d, 0x9b, 0xf6, 0x4b, 0x99, 0x09, 0x8a, 0xcc, 0x4f, 0xe7, 0xad, 0xd8,
		0x62, 0x82, 0xe8, 0x26, 0x6b, 0x83, 0x59, 0x2d, 0xe4, 0x70, 0xac, 0x85, 0x7d, 0x81, 0xf0, 0x7c,
		0x30, 0xa8, 0x04, 0xa8, 0x04, 0xa8, 0x04, 0xa8, 0x84, 0x35, 0x54, 0x09, 0x97, 0x61, 0x38, 0x14,
		0x01, 0xc9, 0x39, 0xf7, 0xd2, 0xba, 0x40, 0x93, 0xd3, 0xed, 0x67, 0x9b, 0x4a, 0x85, 0x3a, 0xd0,
		0xd2, 0x52, 0x7b, 0x01, 0x2f, 0xee, 0xff, 0x23, 0x6e, 0x82, 0xd1, 0xac, 0x1b, 0x44, 0x21, 0x1c,
		0x09, 0xd5, 0x9f, 0x02, 0xc5, 0x64, 0x7d, 0x16, 0x26, 0x5f, 0x91, 0xbc, 0x2c, 0x04, 0x57, 0xd2,
		0x8f, 0x83, 0x2b, 0x19, 0xa7, 0xaf, 0x0a, 0x53, 0xbd, 0x39, 0x56, 0xb2, 0x1f, 0xc4, 0xba, 0x30,
		0x4c, 0xd6, 0x74, 0x61, 0x8a, 0x8f, 0x71, 0xf2, 0xad, 0x60, 0xa3, 0x71, 0x76, 0x72, 0xcd, 0x3a,
		0x1a, 0xf7, 0xb5, 0x9a, 0x67, 0x9d, 0xa5, 0x97, 0xfc, 0xf9, 0x7a, 0xd4, 0x9b, 0x7c, 0x75, 0xe4,
		0x65, 0xaf, 0x79, 0x25, 0x4f, 0x27, 0x17, 0x3c, 0x7f, 0xd1, 0x6b, 0x8d, 0x6e, 0x6b, 0xe7, 0xc9,
		0xe5, 0xf6, 0x0e, 0xc3, 0xfe, 0xe4, 0x77, 0x3a, 0xd3, 0xab, 0x4d, 0xbe, 0xf5, 0x4e, 0xa7, 0x57,
		0xbb, 0x01, 0xed, 0xd2, 0xc7, 0xea, 0x9b, 0x0a, 0xff, 0x53, 0x7e, 0xa0, 0x75, 0x24, 0x2f, 0x27,
		0x33, 0x60, 0xaf, 0x77, 0xfa, 0x92, 0xb1, 0xd0, 0x48, 0x1d, 0x8d, 0xd4, 0x9d, 0x20, 0x43, 0x68,
		0xa4, 0x4e, 0x8b, 0x64, 0xd6, 0x1a, 0xa9, 0x67, 0x9c, 0x8c, 0x7d, 0x35, 0x98, 0x1d, 0xd2, 0xae,
		0x26, 0x2c, 0x41, 0x13, 0x42, 0x13, 0x42, 0x13, 0x6e, 0x92, 0x26, 0xb4, 0xe5, 0x2e, 0xd3, 0x01,
		0xa6, 0xcd, 0xc5, 0xb5, 0x6d, 0xe5, 0xb9, 0xb0, 0x42, 0x9f, 0x86, 0xb4, 0x6c, 0x5a, 0x34, 0x59,
		0x34, 0xd6, 0xdd, 0x27, 0xa5, 0x1b, 0xe5, 0x71, 0xa7, 0xd4, 0x6e, 0x95, 0xcd, 0xbd, 0xb2, 0xb9,
		0x59, 0x36, 0x77, 0x6b, 0xd7, 0xed, 0x5a, 0x76, 0xbf, 0x74, 0xa1, 0xb9, 0xcc, 0xba, 0xb3, 0xdf,
		0x60, 0x34, 0xc3, 0x2e, 0xeb, 0x04, 0x63, 0x3d, 0x6b, 0x38, 0x9a, 0x74, 0x0f, 0x7d, 0x02, 0x83,
		0x35, 0xcd, 0xcb, 0xb3, 0x68, 0x7a, 0x5e, 0x12, 0x3b, 0x23, 0x03, 0x66, 0x5b, 0xa1, 0x3a, 0x42,
		0x2d, 0x03, 0x50, 0x06, 0x28, 0x03, 0x94, 0x37, 0x03, 0x94, 0x6d, 0x6b, 0xa3, 0x45, 0x8d, 0x34,
		0x14, 0x8a, 0xbe, 0x40, 0x51, 0x3a, 0xf2, 0x87, 0x5c, 0x9e, 0x3b, 0xa0, 0x72, 0xd2, 0x1c, 0xce,
		0x9a, 0xd7, 0x69, 0x73, 0x39, 0x6f, 0x76, 0x27, 0xce, 0xee, 0xcc, 0xd9, 0x9d, 0x3a, 0x8d, 0x73,
		0x27, 0x72, 0xf2, 0xf4, 0x0a, 0x2c, 0xb3, 0x6e, 0xc7, 0x52, 0xe9, 0x52, 0x8d, 0xa1, 0x00, 0x6f,
		0x8d, 0x70, 0x48, 0x9a, 0x93, 0x9c, 0x2f, 0xff, 0xd0, 0xfa, 0xa4, 0x6d, 0xea, 0x93, 0x9e, 0xcc,
		0xf0, 0x9a, 0x19, 0x9e, 0xf8, 0x24, 0x68, 0x66, 0x7c, 0x86, 0xd3, 0x7e, 0x4c, 0xee, 0x6a, 0xd1,
		0xe4, 0x82, 0xbb, 0x8d, 0x37, 0xb9, 0x5a, 0xb5, 0xba, 0x57, 0xdd, 0x60, 0xb3, 0xdb, 0xca, 0xe7,
		0x68, 0x79, 0xa9, 0x44, 0x4c, 0x71, 0x80, 0x9c, 0x6e, 0xa7, 0x6d, 0xb9, 0x8c, 0x24, 0xd8, 0x71,
		0x83, 0x8e, 0x84, 0x8e, 0x84, 0x8e, 0x84, 0x8e, 0x84, 0x8e, 0x5c, 0xa1, 0x23, 0xf7, 0x19, 0x64,
		0x64, 0x15, 0x32, 0x12, 0x32, 0x12, 0x32, 0x12, 0x32, 0x32, 0x07, 0x26, 0x57, 0xae, 0x42, 0x44,
		0x42, 0x44, 0x6e, 0xba, 0x88, 0xbc, 0x9d, 0xad, 0x06, 0x0e, 0x15, 0x99, 0x8c, 0x0d, 0x19, 0x09,
		0x19, 0x09, 0x19, 0x09, 0x19, 0x09, 0x19, 0x49, 0xbe, 0x6e, 0x2f, 0xa5, 0x0a, 0xa2, 0x7b, 0x06,
		0x1d, 0xd9, 0x20, 0x1c, 0xf2, 0x50, 0xa8, 0xeb, 0x69, 0xa2, 0x28, 0x84, 0xe4, 0x06, 0xb0, 0xfa,
		0x12, 0x84, 0x24, 0x84, 0x24, 0xad, 0xc9, 0x61, 0x3f, 0x12, 0x52, 0x72, 0xc3, 0xa5, 0xa4, 0xb8,
		0xd3, 0x42, 0x0d, 0xc4, 0x80, 0x5e, 0x48, 0xa6, 0x23, 0x43, 0x46, 0x42, 0x46, 0x42, 0x46, 0x42,
		0x46, 0x42, 0x46, 0xd2, 0xcb, 0x48, 0xeb, 0x25, 0xc0, 0x56, 0xb9, 0x61, 0x4b, 0x25, 0xc1, 0xf2,
		0x09, 0xd2, 0xe1, 0x68, 0xc2, 0x14, 0x83, 0x21, 0x3d, 0x48, 0xa7, 0x23, 0x03, 0xa4, 0x01, 0xd2,
		0x00, 0x69, 0x80, 0x34, 0x40, 0x1a, 0x20, 0x0d, 0x90, 0x5e, 0x36, 0x67, 0xa3, 0x20, 0xd2, 0x92,
		0x03, 0xa3, 0xe7, 0x03, 0x03, 0xa2, 0x01, 0xd1, 0x80, 0x68, 0x40, 0x34, 0x20, 0x1a, 0x10, 0x0d,
		0x88, 0x5e, 0x36, 0x67, 0x3a, 0x0a, 0x54, 0x2c, 0xb5, 0xbc, 0x65, 0xc8, 0x9b, 0x7a, 0x36, 0x36,
		0x80, 0x1a, 0x40, 0x0d, 0xa0, 0x06, 0x50, 0x03, 0xa8, 0x01, 0xd4, 0x6b, 0x08, 0xd4, 0x6b, 0x5d,
		0x2e, 0xca, 0x72, 0x0f, 0x8d, 0xcc, 0x78, 0x16, 0x7b, 0x6a, 0x64, 0x1b, 0x2a, 0x64, 0x7f, 0x54,
		0xa0, 0xa8, 0xe6, 0xb7, 0x6d, 0xad, 0x11, 0xc7, 0x79, 0x72, 0x3f, 0xcd, 0xf4, 0x0e, 0x33, 0x3f,
		0xb1, 0xd1, 0xab, 0x83, 0xce, 0xe2, 0xd7, 0xab, 0x0c, 0xf5, 0xef, 0xe2, 0x9e, 0xe2, 0x1c, 0xb9,
		0x77, 0x28, 0x63, 0x3d, 0x79, 0xc0, 0x76, 0x6b, 0x5e, 0x1f, 0x49, 0x75, 0x30, 0x14, 0x13, 0x50,
		0x8f, 0xed, 0x92, 0x56, 0xef, 0x28, 0xb8, 0x7b, 0x36, 0x52, 0x69, 0xbf, 0x52, 0xa9, 0xd5, 0x2b,
		0x95, 0x62, 0x7d, 0xaf, 0x5e, 0x6c, 0x54, 0xab, 0xa5, 0x5a, 0xc9, 0x62, 0x0e, 0x9a, 0xd7, 0x8e,
		0x06, 0x22, 0x12, 0x83, 0xcf, 0x93, 0x47, 0xa7, 0xc6, 0xc3, 0xe1, 0x5a, 0x59, 0x1c, 0x91, 0xb7,
		0xe6, 0xf6, 0xd2, 0x9e, 0xd5, 0xea, 0xb1, 0x2c, 0x7e, 0xd9, 0x43, 0xc7, 0x2f, 0xf7, 0xed, 0x9f,
		0xd6, 0xee, 0xd7, 0xa6, 0xfd, 0x57, 0xc6, 0xba, 0x9d, 0x6d, 0x05, 0xb6, 0xe5, 0x90, 0xd1, 0xce,
		0xe9, 0x41, 0x12, 0x21, 0xd8, 0x0e, 0x23, 0x79, 0x2d, 0xd5, 0xf6, 0xc4, 0xb6, 0x7c, 0x69, 0x2a,
		0xc9, 0xd3, 0x0e, 0x35, 0xb0, 0x47, 0x05, 0x48, 0xa1, 0xdf, 0x0e, 0xd4, 0x9b, 0xb2, 0x0e, 0x4b,
		0xae, 0xcc, 0xa2, 0x0b, 0x33, 0xe8, 0xaf, 0xac, 0xf8, 0x29, 0x33, 0x5e, 0xe9, 0xfd, 0x3e, 0xe4,
		0x7d, 0x9f, 0xf0, 0x4e, 0xfb, 0x32, 0x6d, 0x57, 0x56, 0xec, 0xc9, 0x80, 0x25, 0x19, 0xb6, 0xa0,
		0xf7, 0xd9, 0xce, 0xdb, 0x9f, 0xf8, 0x3b, 0x9e, 0xb6, 0xa1, 0x3e, 0x08, 0x46, 0xfb, 0x1c, 0x18,
		0xea, 0x63, 0xf0, 0xb4, 0x77, 0x52, 0x7e, 0xe7, 0x07, 0x19, 0xdc, 0x13, 0xb1, 0xb3, 0xd7, 0x61,
		0x7a, 0x0f, 0xc3, 0xda, 0xde, 0x84, 0xb5, 0x3d, 0x07, 0x6b, 0x7b, 0x09, 0xf0, 0xc3, 0xab, 0xfd,
		0xb0, 0xa9, 0x30, 0xa8, 0x31, 0x37, 0x6c, 0x20, 0x6c, 0xf9, 0x0e, 0x2f, 0xbc, 0x45, 0x68, 0x21,
		0xa6, 0x2c, 0xc3, 0xac, 0x45, 0x78, 0xef, 0x02, 0x22, 0x23, 0x36, 0xf0, 0xb6, 0xa7, 0xff, 0xfa,
		0x67, 0xf7, 0x86, 0xe7, 0xe6, 0x29, 0x21, 0xaf, 0xff, 0xb9, 0x0c, 0xa3, 0xb7, 0xf7, 0x83, 0x4e,
		0xe1, 0xe3, 0xe9, 0xa3, 0xde, 0x68, 0x3f, 0xef, 0xc3, 0xd8, 0x77, 0x63, 0xab, 0x09, 0x4c, 0x35,
		0x8b, 0xa5, 0xa6, 0x30, 0xd4, 0x38, 0x76, 0x1a, 0xc7, 0x4c, 0xe3, 0x58, 0x49, 0xeb, 0xf9, 0xde,
		0xdb, 0x9b, 0x26, 0x5d, 0x3b, 0xe6, 0x58, 0x6f, 0xfa, 0x89, 0x8e, 0x11, 0xdf, 0x22, 0x88, 0x2f,
		0x88, 0xef, 0x5a, 0x12, 0x5f, 0x53, 0x0d, 0xa8, 0xbc, 0x60, 0xf0, 0xef, 0x74, 0x4e, 0xa4, 0xf2,
		0x47, 0x61, 0xac, 0xcd, 0x59, 0x4a, 0x5a, 0xba, 0xed, 0xc5, 0x00, 0xa6, 0xe2, 0xbe, 0x46, 0x7b,
		0xf9, 0x19, 0xcf, 0x23, 0xb4, 0x91, 0x27, 0x68, 0x37, 0x0f, 0xd0, 0x56, 0x9e, 0x9f, 0xf5, 0x3c,
		0x3e, 0xeb, 0x79, 0x7a, 0xd6, 0xf3, 0xf0, 0xdc, 0xda, 0x51, 0x31, 0xdd, 0xdb, 0xce, 0x9b, 0x85,
		0x23, 0x8d, 0x1b, 0xd6, 0x7c, 0x39, 0x18, 0x0b, 0x77, 0x5a, 0x74, 0x30, 0xc6, 0x83, 0x6e, 0x14,
		0x0e, 0x87, 0xc6, 0xf1, 0xd8, 0x76, 0x40, 0x64, 0x8e, 0x88, 0xcc, 0x21, 0x91, 0x39, 0x26, 0xb3,
		0x0e, 0xca, 0xb0, 0xa3, 0xb2, 0xe6, 0xb0, 0x16, 0x1d, 0x97, 0x3d, 0x7b, 0x5c, 0xf0, 0x5f, 0xb6,
		0x6c, 0xd1, 0x6e, 0xcf, 0x63, 0xeb, 0xe7, 0x2f, 0x28, 0xce, 0x5b, 0xd0, 0x9e, 0xaf, 0xa0, 0x3a,
		0x4f, 0x41, 0x7e, 0x7e, 0x82, 0xfc, 0xbc, 0x04, 0xf9, 0xf9, 0x88, 0xf5, 0x4a, 0x9c, 0xb5, 0xdd,
		0xa3, 0xd8, 0x9b, 0x67, 0xd9, 0x90, 0x35, 0x89, 0x37, 0x9b, 0xd6, 0xf3, 0x23, 0x97, 0x59, 0x44,
		0x9b, 0x78, 0xc7, 0x5d, 0x29, 0xb5, 0x4b, 0x65, 0x73, 0xad, 0x6c, 0x2e, 0x96, 0xcd, 0xd5, 0xda,
		0x75, 0xb9, 0x96, 0x5d, 0x6f, 0x3a, 0x6b, 0x64, 0x47, 0xce, 0xd2, 0x75, 0x37, 0x14, 0xc1, 0x55,
		0x24, 0xae, 0x28, 0x16, 0xdd, 0x9c, 0x59, 0xd6, 0x09, 0xc6, 0x3a, 0x99, 0xed, 0xbf, 0x7e, 0xfc,
		0x98, 0x6c, 0xaa, 0x17, 0xe6, 0x50, 0xb0, 0xae, 0x47, 0x70, 0x2c, 0xf2, 0xcb, 0x11, 0x8d, 0xbb,
		0x7f, 0x42, 0x65, 0x12, 0x72, 0x09, 0x50, 0x06, 0x28, 0x03, 0x94, 0x01, 0xca, 0x00, 0x65, 0x87,
		0x41, 0x39, 0x59, 0x76, 0xc0, 0xe4, 0xcc, 0x54, 0x99, 0xc9, 0x22, 0xfe, 0x69, 0x83, 0xa3, 0x38,
		0x7f, 0x6d, 0x39, 0xb2, 0x08, 0x44, 0x06, 0x22, 0x03, 0x91, 0x37, 0x03, 0x91, 0x6d, 0x47, 0x2a,
		0xd3, 0x81, 0xa6, 0x45, 0x04, 0xa4, 0x1a, 0x88, 0x3b, 0xa6, 0x16, 0x86, 0xc9, 0xd8, 0x28, 0xc5,
		0xb5, 0x6e, 0x0e, 0x9b, 0xd7, 0x71, 0x73, 0x39, 0x70, 0x76, 0x47, 0xce, 0xee, 0xd0, 0xd9, 0x1d,
		0x3b, 0x8d, 0x83, 0x27, 0x72, 0xf4, 0xf4, 0x12, 0x8c, 0x51, 0x8a, 0x71, 0x48, 0xb2, 0x65, 0xd2,
		0xec, 0x7f, 0xfc, 0x9d, 0x42, 0x52, 0x2c, 0x74, 0x9c, 0xbe, 0x9a, 0x09, 0xb9, 0x04, 0xa6, 0x50,
		0xe3, 0xf3, 0xa7, 0xe7, 0xfb, 0x52, 0xc4, 0xda, 0x9f, 0x1d, 0x12, 0x22, 0xe6, 0x15, 0x4f, 0x43,
		0x83, 0x56, 0x80, 0x56, 0x80, 0x56, 0x80, 0x56, 0x80, 0x56, 0x90, 0xaf, 0x5b, 0x54, 0xf8, 0x5c,
		0x0b, 0x98, 0xee, 0x87, 0x37, 0x37, 0x63, 0x25, 0xf5, 0x3d, 0x57, 0x10, 0xe0, 0xe5, 0x05, 0x00,
		0xb2, 0x01, 0xd9, 0x80, 0x6c, 0x40, 0x36, 0x20, 0x1b, 0x91, 0x00, 0xce, 0x48, 0xc0, 0x1c, 0x97,
		0xa4, 0x88, 0xd3, 0xd7, 0xf7, 0x08, 0x06, 0xbc, 0x6d, 0xca, 0xc5, 0x9d, 0xf6, 0xd9, 0x99, 0xc6,
		0xb2, 0x8b, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0x00, 0xdb, 0xe0, 0x64,
		0x1b, 0xcf, 0xb1, 0x69, 0xc2, 0x38, 0x16, 0xb0, 0x0a, 0xac, 0xe3, 0x6d, 0x53, 0x2f, 0xd5, 0x6d,
		0x30, 0x94, 0x03, 0x3f, 0x12, 0x41, 0x4c, 0xd4, 0x67, 0x64, 0xc1, 0xc2, 0x5f, 0x8c, 0x0f, 0xae,
		0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x01, 0xae, 0x41, 0xbe, 0x6e, 0xe5, 0x40, 0x28, 0x2d, 0xf5,
		0x3d, 0x13, 0xdf, 0xa8, 0x12, 0x8e, 0xd9, 0x9a, 0xdd, 0xea, 0xe7, 0x20, 0x66, 0x70, 0x19, 0xf3,
		0x09, 0x6f, 0x1d, 0xff, 0xd1, 0x3c, 0x6c, 0x7d, 0xe9, 0x75, 0xda, 0xe7, 0x67, 0x07, 0xbd, 0xce,
		0x41, 0xf3, 0xb4, 0x7d, 0x4c, 0xed, 0x3d, 0xfe, 0x08, 0x86, 0xe3, 0x69, 0x91, 0x9d, 0x0b, 0xd2,
		0x71, 0x27, 0x7f, 0xbe, 0x93, 0x8f, 0xb8, 0x74, 0xf6, 0x7f, 0x3d, 0x3c, 0x3f, 0x3d, 0x3b, 0xe8,
		0xf4, 0x0e, 0xdb, 0xed, 0x13, 0x8f, 0xfc, 0x92, 0x1e, 0x3f, 0x6c, 0xea, 0xbc, 0xb7, 0x3b, 0xad,
		0xdf, 0x5a, 0xc7, 0xcd, 0xb3, 0x76, 0x07, 0xb3, 0x4e, 0x37, 0xeb, 0xcd, 0x53, 0x18, 0x3a, 0xb5,
		0x83, 0x69, 0x1f, 0x7f, 0x3d, 0xf8, 0xc2, 0x30, 0xe3, 0xa4, 0x23, 0x76, 0xf3, 0xc6, 0xf7, 0x72,
		0xa1, 0xee, 0x87, 0x41, 0xac, 0xfd, 0x9b, 0x70, 0x20, 0xaf, 0xa4, 0x18, 0xd0, 0x8b, 0xfb, 0xc5,
		0xe1, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xc9, 0xd7, 0xad, 0x96, 0x37,
		0x42, 0xcb, 0xfe, 0xb7, 0xb8, 0x56, 0x61, 0xd0, 0xf6, 0xfb, 0x84, 0x43, 0x9e, 0x2b, 0x39, 0x6d,
		0x5f, 0xe7, 0xa9, 0x40, 0x85, 0xb1, 0xe8, 0x87, 0x6a, 0x10, 0x53, 0xde, 0x72, 0x27, 0x50, 0xd7,
		0x82, 0x5c, 0x4f, 0xd3, 0x53, 0x5d, 0xef, 0x48, 0x2a, 0x72, 0x8f, 0xcc, 0x84, 0xf1, 0xcb, 0xa3,
		0x26, 0x8c, 0xe3, 0x7f, 0x8d, 0x82, 0xbe, 0x96, 0xa1, 0xfa, 0x22, 0xaf, 0x13, 0x6b, 0x2f, 0x6e,
		0x82, 0x9e, 0xf3, 0x8e, 0x82, 0xbb, 0x8d, 0x37, 0x39, 0xda, 0x8e, 0xdc, 0xce, 0x5b, 0xe1, 0x56,
		0x3e, 0x47, 0xeb, 0x42, 0xe3, 0xfe, 0xb4, 0x19, 0x52, 0xd5, 0x13, 0xcd, 0x90, 0x2a, 0x9a, 0xba,
		0xa2, 0xd0, 0xb5, 0xd0, 0xb5, 0xd0, 0xb5, 0xd0, 0xb5, 0xd0, 0xb5, 0x4b, 0xd6, 0xed, 0x58, 0x2a,
		0xbd, 0x57, 0x66, 0x90, 0xb4, 0x75, 0x48, 0x4a, 0x48, 0x4a, 0x48, 0x4a, 0x48, 0xca, 0x1c, 0x98,
		0x5c, 0xa5, 0xdc, 0xa8, 0x34, 0x6a, 0xf5, 0x72, 0x03, 0x42, 0x12, 0x42, 0x72, 0x93, 0x85, 0x24,
		0xad, 0x00, 0xa1, 0xad, 0x84, 0x0d, 0x19, 0x09, 0x19, 0x09, 0x19, 0x09, 0x19, 0x09, 0x19, 0xb9,
		0x64, 0xdd, 0x4e, 0x9b, 0xee, 0x93, 0xdb, 0x70, 0x9a, 0xfa, 0xbc, 0x4f, 0x7b, 0xd4, 0x4a, 0x8b,
		0x48, 0x91, 0xcb, 0x49, 0x6f, 0x67, 0xe7, 0xa2, 0xe8, 0x37, 0x02, 0xff, 0xaa, 0xe9, 0x7f, 0xed,
		0x7e, 0x2f, 0x7d, 0xa8, 0x3c, 0x7e, 0xda, 0xfd, 0x5e, 0x7f, 0x7c, 0xf9, 0xc3, 0x87, 0x65, 0xbf,
		0x56, 0xfa, 0x50, 0x7f, 0xfc, 0xb4, 0xe2, 0x5f, 0x6a, 0x8f, 0x9f, 0x7e, 0xf2, 0x33, 0xaa, 0x8f,
		0x3b, 0x99, 0x5f, 0x9d, 0xfc, 0xbc, 0xbc, 0xea, 0x0d, 0x95, 0x15, 0x6f, 0xd8, 0x5b, 0xf5, 0x86,
		0xbd, 0x15, 0x6f, 0x58, 0x79, 0x49, 0xe5, 0x15, 0x6f, 0xa8, 0x3e, 0x3e, 0x64, 0x7e, 0x7f, 0x67,
		0xf9, 0xaf, 0xd6, 0x1e, 0x77, 0x1f, 0x56, 0xfd, 0x5b, 0xfd, 0xf1, 0xe1, 0xd3, 0xee, 0x6e, 0x61,
		0xa7, 0x54, 0xbe, 0x28, 0xfa, 0xfb, 0xdd, 0x87, 0xd2, 0x45, 0xd1, 0x2f, 0x75, 0x27, 0xbf, 0xd9,
		0x7d, 0xb8, 0x28, 0xf9, 0x8d, 0xf9, 0xcb, 0xc9, 0x7f, 0x77, 0xe9, 0xdc, 0x56, 0x97, 0xd2, 0xde,
		0xdb, 0xa7, 0xad, 0x3f, 0xd9, 0x8c, 0xfe, 0x6f, 0x58, 0xbd, 0xe3, 0x56, 0xff, 0x8b, 0x07, 0x2d,
		0xe6, 0xa0, 0x16, 0x9b, 0x1d, 0x0a, 0xb5, 0xda, 0x49, 0x75, 0x25, 0x1d, 0x78, 0x3e, 0x38, 0x54,
		0x19, 0x54, 0x19, 0x54, 0x19, 0x54, 0x19, 0x54, 0x19, 0xf9, 0xba, 0x45, 0x75, 0x4c, 0xc7, 0x47,
		0xb0, 0xdd, 0xe0, 0xa3, 0xa9, 0x54, 0xa8, 0x03, 0x2d, 0x89, 0xea, 0x52, 0x78, 0x71, 0xff, 0x1f,
		0x71, 0x13, 0xcc, 0xea, 0x71, 0x7b, 0x85, 0x70, 0x24, 0x54, 0x7f, 0x0a, 0x94, 0x13, 0xff, 0x51,
		0x98, 0x7c, 0x45, 0xf2, 0xb2, 0x10, 0x5c, 0x49, 0x3f, 0x0e, 0xae, 0x64, 0x9c, 0xbe, 0x2a, 0x4c,
		0xe3, 0x07, 0x63, 0x25, 0xfb, 0x41, 0xac, 0x0b, 0x4a, 0xc8, 0xeb, 0x7f, 0x2e, 0xc3, 0x28, 0x4e,
		0x5f, 0x15, 0x82, 0xc1, 0xbf, 0x53, 0x37, 0x24, 0x95, 0x3f, 0x0a, 0x63, 0x5d, 0x98, 0x52, 0x8b,
		0x38, 0xf9, 0x56, 0xa0, 0xe8, 0xba, 0x94, 0xdc, 0x9e, 0x8e, 0xc6, 0x7d, 0xad, 0x66, 0xab, 0xab,
		0x9d, 0xde, 0xdd, 0xe7, 0xeb, 0x51, 0x6f, 0xf2, 0xd5, 0x91, 0x97, 0xbd, 0xe6, 0x95, 0x3c, 0x9d,
		0xdc, 0xdb, 0xfc, 0x45, 0xaf, 0x35, 0xba, 0xad, 0x9d, 0x27, 0x77, 0xd6, 0x3b, 0x9e, 0xdf, 0x59,
		0xfa, 0xaa, 0xd7, 0x1c, 0xfc, 0xdb, 0x91, 0x97, 0x2d, 0x75, 0x12, 0xc6, 0xba, 0xd7, 0x99, 0xde,
		0x56, 0xf2, 0xad, 0x77, 0x3a, 0xbd, 0x2d, 0x34, 0xf5, 0xca, 0x3c, 0x86, 0xb1, 0xfa, 0xa6, 0xc2,
		0xff, 0x94, 0x1f, 0x68, 0x1d, 0xc9, 0xcb, 0xc9, 0x8c, 0xd1, 0x75, 0xf8, 0x5a, 0x32, 0x36, 0xda,
		0x7d, 0xb9, 0x4a, 0x64, 0xd1, 0xee, 0x2b, 0x9f, 0x44, 0x15, 0xed, 0xbe, 0xde, 0x34, 0x6b, 0x64,
		0xed, 0xbe, 0x32, 0x4e, 0x92, 0x3e, 0x02, 0x91, 0xbd, 0x04, 0xda, 0x38, 0x44, 0x09, 0x71, 0x08,
		0xc4, 0x21, 0x10, 0x87, 0x40, 0x1c, 0xc2, 0x9d, 0x38, 0x04, 0x95, 0xfb, 0x4f, 0x07, 0x9c, 0x36,
		0xb7, 0xd2, 0xd4, 0xd1, 0x8f, 0xed, 0x4c, 0xf3, 0xc7, 0xe9, 0x25, 0x10, 0x9b, 0x2e, 0x4f, 0x66,
		0x22, 0x39, 0x1c, 0x70, 0xc2, 0x82, 0x1b, 0xf0, 0xc0, 0x0d, 0x13, 0xce, 0xc0, 0x85, 0x33, 0xb0,
		0xe1, 0x0c, 0x7c, 0xd0, 0xc2, 0x08, 0x31, 0x9c, 0xa4, 0xb3, 0x7c, 0xc6, 0xe1, 0xe0, 0xb7, 0x79,
		0x6b, 0x3c, 0x67, 0xd8, 0x7e, 0x9d, 0x61, 0xec, 0x67, 0x35, 0x9f, 0x93, 0xd2, 0xcd, 0x4f, 0x60,
		0x97, 0xd3, 0x5c, 0x6c, 0x42, 0xd3, 0x9e, 0xb5, 0xf2, 0x67, 0x23, 0x2e, 0x54, 0x31, 0x6d, 0x46,
		0xed, 0x0a, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0xc2, 0x41, 0x5a, 0xa8, 0xb5, 0xf0, 0xa2,
		0x26, 0x1e, 0x0a, 0xc6, 0x63, 0x9a, 0x0b, 0xd2, 0x78, 0x72, 0x25, 0x1f, 0x36, 0xf2, 0xec, 0x1e,
		0x17, 0xe8, 0xb8, 0x00, 0x3e, 0x6e, 0x81, 0x90, 0x2b, 0x60, 0xe4, 0x1c, 0x28, 0x39, 0x07, 0x4e,
		0xce, 0x81, 0x14, 0x0f, 0x58, 0x31, 0x81, 0x16, 0xbf, 0xe2, 0xce, 0xf8, 0x8d, 0xb1, 0x54, 0xba,
		0x54, 0xe3, 0xf4, 0x19, 0x33, 0x14, 0xa9, 0x31, 0x5e, 0x02, 0x4f, 0x75, 0x89, 0x97, 0x7f, 0x78,
		0x7d, 0xe6, 0x36, 0x77, 0xf5, 0x09, 0xc7, 0xe8, 0x45, 0xe6, 0x72, 0x98, 0xab, 0x53, 0x64, 0xae,
		0xc7, 0x81, 0x8a, 0x01, 0x8e, 0xb8, 0xd3, 0x45, 0x13, 0x0e, 0xee, 0x60, 0xc2, 0x3f, 0x30, 0xe1,
		0x5a, 0xb5, 0xba, 0x57, 0x85, 0x19, 0xbb, 0xc5, 0x45, 0xf8, 0x47, 0xef, 0x6e, 0x6d, 0xc6, 0xfd,
		0x72, 0x14, 0xd9, 0xe1, 0xdb, 0x49, 0x5f, 0x1e, 0x36, 0x60, 0xd8, 0x51, 0x47, 0xdc, 0x00, 0x71,
		0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc, 0x20, 0x27, 0x71, 0x83, 0x7d, 0x07, 0xc2, 0x06, 0x55,
		0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0xac, 0x9b, 0x70, 0xb9, 0x8a,
		0xa0, 0x01, 0x82, 0x06, 0x08, 0x1a, 0xd0, 0x06, 0x0d, 0x6e, 0x67, 0xab, 0xcf, 0x85, 0xa8, 0x41,
		0x72, 0x2d, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0xf0,
		0x4a, 0xbf, 0x71, 0x29, 0x55, 0x10, 0xdd, 0x3b, 0x10, 0x37, 0x68, 0x30, 0x5e, 0xc2, 0xa1, 0x50,
		0xd7, 0xd3, 0xc4, 0x7f, 0x04, 0x0e, 0x10, 0x38, 0xf8, 0xa1, 0xea, 0x2a, 0x41, 0x73, 0x21, 0x70,
		0xb0, 0xde, 0x26, 0x8c, 0x7c, 0x03, 0x84, 0x0e, 0x10, 0x3a, 0x20, 0x35, 0x73, 0x71, 0xa7, 0x85,
		0x1a, 0x88, 0x01, 0x7f, 0xe0, 0x20, 0xbd, 0x12, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61,
		0x03, 0x84, 0x0d, 0x10, 0x36, 0x78, 0x6d, 0xd8, 0x80, 0xbc, 0x0c, 0xee, 0x2a, 0x18, 0x21, 0x2a,
		0x8b, 0xbb, 0x99, 0xa4, 0x25, 0x1c, 0x4d, 0x98, 0x79, 0x30, 0xe4, 0x27, 0x2d, 0xe9, 0x95, 0x80,
		0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x80, 0xb4, 0x64,
		0xe7, 0x78, 0x14, 0x44, 0x5a, 0xba, 0xc0, 0x59, 0xe6, 0x17, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca,
		0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x02, 0xca, 0x92, 0x9d, 0x63, 0x1d, 0x05, 0x2a,
		0x96, 0x5a, 0xde, 0x3a, 0x90, 0x57, 0xfa, 0xec, 0x5a, 0x40, 0x5c, 0x40, 0x5c, 0x40, 0x5c, 0x40,
		0x5c, 0x40, 0x5c, 0x40, 0x5c, 0x40, 0x5c, 0x9c, 0x27, 0x2e, 0xb9, 0x2e, 0x2f, 0x4a, 0xdc, 0x77,
		0x31, 0x33, 0x3e, 0x4f, 0x1f, 0xc6, 0x6c, 0x6f, 0xbc, 0xec, 0x8f, 0x0a, 0x1c, 0x85, 0xad, 0xb7,
		0xe9, 0x9b, 0x37, 0x9e, 0x27, 0x37, 0xde, 0x4c, 0xa7, 0x22, 0xf3, 0x13, 0x8a, 0xfe, 0x8e, 0x7c,
		0xab, 0x2e, 0x5f, 0xad, 0x73, 0x7e, 0x17, 0xf7, 0x1c, 0xb5, 0x6f, 0xbc, 0x43, 0x19, 0xeb, 0x89,
		0xc1, 0xd0, 0xf6, 0xed, 0x39, 0x92, 0xea, 0x60, 0x28, 0x26, 0xc4, 0x28, 0xa6, 0x15, 0x16, 0xde,
		0x51, 0x70, 0xf7, 0x6c, 0xe4, 0xd2, 0x7e, 0xa5, 0x52, 0xab, 0x57, 0x2a, 0xc5, 0xfa, 0x5e, 0xbd,
		0xd8, 0xa8, 0x56, 0x4b, 0xb5, 0x12, 0x61, 0x1e, 0xb0, 0xd7, 0x8e, 0x06, 0x22, 0x12, 0x83, 0xcf,
		0x93, 0x47, 0xaf, 0xc6, 0xc3, 0x61, 0xae, 0x2c, 0x9a, 0x09, 0xa1, 0x1c, 0x46, 0x26, 0x8f, 0xb4,
		0xb9, 0x84, 0x5b, 0x58, 0xe4, 0xa1, 0x5b, 0x37, 0xff, 0xda, 0xdc, 0x90, 0x6e, 0xdd, 0xe4, 0x1d,
		0x94, 0x5d, 0x58, 0x71, 0x6b, 0xdb, 0xc6, 0x7b, 0x6b, 0x8d, 0x16, 0xd2, 0x9c, 0xa6, 0x25, 0xd1,
		0xae, 0xed, 0x89, 0x61, 0xfb, 0xd2, 0xd6, 0xc9, 0x01, 0x1a, 0x6e, 0x46, 0xc7, 0xc5, 0x58, 0xb9,
		0x17, 0x0d, 0xd7, 0xb2, 0x65, 0x76, 0x44, 0x7e, 0x9b, 0xc7, 0x5f, 0x5b, 0x74, 0xce, 0xb4, 0x4e,
		0xd9, 0x8e, 0x0b, 0x36, 0xef, 0x20, 0xcd, 0x7e, 0xa2, 0x61, 0x9b, 0xb7, 0x6d, 0xeb, 0xd4, 0x36,
		0x6e, 0xc1, 0xba, 0xa9, 0xac, 0xda, 0xac, 0x3d, 0x9b, 0xb3, 0x3a, 0x33, 0x9f, 0x64, 0xc8, 0x6e,
		0x6d, 0xd9, 0x2b, 0x99, 0x9d, 0x1a, 0x34, 0x50, 0xeb, 0x86, 0x69, 0xc6, 0x22, 0xdf, 0x6f, 0x3f,
		0x06, 0x6c, 0xc7, 0x7b, 0xfe, 0x18, 0x22, 0x73, 0xdb, 0x54, 0x4f, 0x05, 0xb1, 0x16, 0x3f, 0xdf,
		0x90, 0xb5, 0x9b, 0x6d, 0xe0, 0x68, 0x3c, 0xb9, 0xc0, 0x46, 0xb2, 0x80, 0xdd, 0xcd, 0x7f, 0x5b,
		0x9b, 0xf9, 0xd6, 0x37, 0xe7, 0xad, 0x6f, 0xb6, 0x5b, 0xdf, 0x3c, 0x77, 0x0b, 0x47, 0x4c, 0x37,
		0x0c, 0xf4, 0x66, 0xfc, 0xc3, 0xb8, 0x61, 0xcd, 0x97, 0x83, 0x15, 0x7e, 0x63, 0xa9, 0x43, 0xec,
		0x93, 0xa3, 0x29, 0x1b, 0xfe, 0x60, 0x8b, 0xd9, 0x49, 0x34, 0x59, 0x47, 0xb6, 0xb3, 0x89, 0xc8,
		0xb2, 0x84, 0xc8, 0xb2, 0x7f, 0xc8, 0xb2, 0x7a, 0xdc, 0x16, 0x6a, 0xb6, 0x3a, 0x9c, 0x26, 0x8e,
		0xc5, 0x9e, 0x3d, 0x2e, 0xf8, 0x2f, 0x5b, 0xb6, 0x68, 0xb7, 0xd1, 0xb5, 0xf5, 0xa4, 0x4c, 0x8a,
		0xa4, 0x4b, 0xda, 0xa4, 0x4a, 0xaa, 0xa4, 0x49, 0xf2, 0xa4, 0x48, 0xf2, 0xa4, 0x47, 0xf2, 0xa4,
		0xc6, 0xf5, 0xda, 0x22, 0xb0, 0xdd, 0xf8, 0xd9, 0x9b, 0xef, 0x3a, 0x58, 0xb7, 0xe4, 0xa7, 0x83,
		0x7b, 0x36, 0xb7, 0x39, 0x5e, 0xba, 0x4c, 0xcb, 0xd9, 0x20, 0x64, 0xf9, 0xec, 0x94, 0x79, 0xeb,
		0x3c, 0xf9, 0xe9, 0xd4, 0x79, 0xe8, 0x6c, 0xf9, 0xe6, 0x6c, 0x79, 0xe5, 0x6c, 0xf9, 0xe3, 0xeb,
		0x9d, 0xe6, 0x40, 0x96, 0xf7, 0x9d, 0xae, 0xbb, 0xa1, 0x08, 0xae, 0x22, 0x71, 0x45, 0xb1, 0xe8,
		0xe6, 0xcc, 0xb2, 0x4e, 0x30, 0xd6, 0xc9, 0x2c, 0xfa, 0xfc, 0xf1, 0x63, 0x92, 0x55, 0x5b, 0x98,
		0x43, 0xc1, 0xba, 0x26, 0x1b, 0x58, 0xe4, 0x97, 0x23, 0x1a, 0x77, 0xff, 0x84, 0xca, 0x24, 0xe4,
		0x12, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0x03, 0x94, 0x01, 0xca, 0x0e, 0x83, 0x72, 0xb2, 0xec, 0x80,
		0xc9, 0x99, 0xa9, 0x4a, 0x8e, 0x02, 0x91, 0x41, 0x32, 0xc5, 0xc9, 0x23, 0xcb, 0x91, 0x45, 0x20,
		0x32, 0x10, 0x19, 0x88, 0xbc, 0x19, 0x88, 0x6c, 0x3b, 0x52, 0x99, 0x0e, 0x34, 0x3d, 0xd5, 0x26,
		0xd5, 0x40, 0xd0, 0x55, 0x71, 0x58, 0xec, 0x0b, 0x97, 0x8c, 0x4d, 0x75, 0x94, 0x8f, 0xb4, 0x5e,
		0x07, 0x79, 0x7d, 0x0e, 0x8e, 0x7a, 0x1c, 0xbc, 0xf5, 0x37, 0xb8, 0xea, 0x6d, 0xb0, 0xd7, 0xd7,
		0x60, 0xaf, 0xa7, 0xc1, 0x5e, 0x3f, 0x23, 0x5f, 0x87, 0x8c, 0xc9, 0xeb, 0x61, 0x30, 0x48, 0x31,
		0x0e, 0x49, 0xb6, 0x4c, 0x9a, 0xfd, 0x8f, 0xbf, 0x53, 0x48, 0x8a, 0x85, 0x8e, 0xd3, 0x57, 0x33,
		0x21, 0x97, 0xc0, 0x54, 0x5e, 0x4e, 0x4a, 0x12, 0x30, 0xeb, 0x7e, 0x78, 0x73, 0x33, 0x56, 0x52,
		0xdf, 0x73, 0xb1, 0x8b, 0x97, 0x17, 0x00, 0x8a, 0x01, 0x8a, 0x01, 0x8a, 0x01, 0x8a, 0x01, 0x8a,
		0x01, 0x8a, 0xc1, 0x49, 0x31, 0xe6, 0xb8, 0x24, 0x45, 0x9c, 0xbe, 0xbe, 0x07, 0xcb, 0x78, 0xdb,
		0x94, 0x8b, 0x3b, 0xed, 0xb3, 0x33, 0x8d, 0x65, 0x17, 0x01, 0xb6, 0x01, 0xb6, 0x01, 0xb6, 0x01,
		0xb6, 0x01, 0xb6, 0x01, 0xb6, 0xc1, 0xc9, 0x36, 0x9e, 0x63, 0xd3, 0x84, 0x71, 0x2c, 0x60, 0x15,
		0x58, 0xc7, 0xdb, 0xa6, 0x5e, 0xaa, 0xdb, 0x60, 0x28, 0x07, 0x7e, 0x24, 0x82, 0x98, 0xb0, 0x86,
		0x5a, 0x6a, 0xe1, 0x2f, 0xc6, 0x07, 0xd7, 0x00, 0xd7, 0x00, 0xd7, 0x00, 0xd7, 0x00, 0xd7, 0x20,
		0x5f, 0xb7, 0x72, 0x20, 0x94, 0x96, 0xfa, 0x9e, 0x89, 0x6f, 0x50, 0x56, 0x44, 0x6d, 0xcd, 0x6e,
		0xf5, 0x73, 0x10, 0x33, 0xb8, 0x8c, 0xf9, 0x84, 0xb7, 0x8e, 0xff, 0x68, 0x1e, 0xb6, 0xbe, 0xf4,
		0x3a, 0xed, 0xf3, 0xb3, 0x83, 0x5e, 0xe7, 0xa0, 0x79, 0xda, 0x3e, 0xa6, 0xf6, 0x1e, 0x7f, 0x04,
		0xc3, 0xf1, 0xf4, 0xf4, 0xfe, 0x05, 0x79, 0x21, 0x6b, 0xe6, 0x8e, 0x2b, 0xf3, 0xd9, 0xff, 0xf5,
		0xf0, 0xfc, 0xf4, 0xec, 0xa0, 0xd3, 0x3b, 0x6c, 0xb7, 0x4f, 0xbc, 0x4d, 0xe8, 0x7b, 0xe3, 0xc8,
		0xbc, 0xb7, 0x3b, 0xad, 0xdf, 0x5a, 0xc7, 0xcd, 0xb3, 0x76, 0x07, 0xb3, 0x4e, 0x37, 0xeb, 0xcd,
		0x53, 0x18, 0x3a, 0xb5, 0x83, 0x69, 0x1f, 0x7f, 0x3d, 0xf8, 0xe2, 0xe5, 0xbc, 0x33, 0x45, 0x37,
		0x6f, 0x7c, 0x2f, 0x17, 0xea, 0x7e, 0x18, 0xc4, 0xda, 0xbf, 0x09, 0x07, 0xf2, 0x4a, 0x8a, 0x01,
		0xbd, 0xb8, 0x5f, 0x1c, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x1e, 0xda, 0x9e, 0x7c,
		0xdd, 0x6a, 0x79, 0x23, 0xb4, 0xec, 0x7f, 0x8b, 0x6b, 0x15, 0x06, 0x6d, 0xbf, 0x4f, 0x38, 0xe4,
		0xb9, 0x92, 0xd3, 0xba, 0xdf, 0x9e, 0x0a, 0x54, 0x18, 0x8b, 0x7e, 0xa8, 0x06, 0x31, 0xe5, 0x2d,
		0x77, 0x02, 0x75, 0x2d, 0xc8, 0xf5, 0x34, 0x43, 0x6b, 0xae, 0x23, 0xa9, 0xf8, 0xda, 0xa6, 0x32,
		0x37, 0x2b, 0x9d, 0x46, 0x4d, 0x18, 0xc7, 0xff, 0x1a, 0x05, 0x7d, 0x2d, 0x43, 0xf5, 0x45, 0x5e,
		0x27, 0xd6, 0x5e, 0xdc, 0x88, 0x86, 0xbd, 0x47, 0xc1, 0xdd, 0xc6, 0x9b, 0x1c, 0x6f, 0x2f, 0x29,
		0xe7, 0xac, 0x30, 0xa7, 0x5d, 0xe7, 0xba, 0xd0, 0xb8, 0x3f, 0x6d, 0x86, 0x54, 0x85, 0xca, 0x32,
		0xa4, 0x8a, 0xa6, 0x60, 0x19, 0x74, 0x2d, 0x74, 0x2d, 0x74, 0x2d, 0x74, 0x2d, 0x74, 0xed, 0x92,
		0x75, 0x3b, 0x96, 0x4a, 0xef, 0x95, 0x19, 0x24, 0x6d, 0x1d, 0x92, 0x12, 0x92, 0x12, 0x92, 0x12,
		0x92, 0x32, 0x07, 0x26, 0x57, 0x29, 0x37, 0x2a, 0x8d, 0x5a, 0xbd, 0xdc, 0x80, 0x90, 0x84, 0x90,
		0xdc, 0x64, 0x21, 0x49, 0x2b, 0x40, 0x68, 0x4b, 0x6c, 0x42, 0x46, 0x42, 0x46, 0x42, 0x46, 0x42,
		0x46, 0x42, 0x46, 0x2e, 0x59, 0xb7, 0xd3, 0x5e, 0x86, 0xe4, 0x36, 0x9c, 0xa6, 0x3e, 0xef, 0xd3,
		0x1e, 0xb5, 0xd2, 0x22, 0x52, 0xe4, 0x72, 0xd2, 0xdb, 0xd9, 0xb9, 0x28, 0xfa, 0x8d, 0xc0, 0xbf,
		0x6a, 0xfa, 0x5f, 0xbb, 0xdf, 0x4b, 0x1f, 0x2a, 0x8f, 0x9f, 0x76, 0xbf, 0xd7, 0x1f, 0x5f, 0xfe,
		0xf0, 0x61, 0xd9, 0xaf, 0x95, 0x3e, 0xd4, 0x1f, 0x3f, 0xad, 0xf8, 0x97, 0xda, 0xe3, 0xa7, 0x9f,
		0xfc, 0x8c, 0xea, 0xe3, 0x4e, 0xe6, 0x57, 0x27, 0x3f, 0x2f, 0xaf, 0x7a, 0x43, 0x65, 0xc5, 0x1b,
		0xf6, 0x56, 0xbd, 0x61, 0x6f, 0xc5, 0x1b, 0x56, 0x5e, 0x52, 0x79, 0xc5, 0x1b, 0xaa, 0x8f, 0x0f,
		0x99, 0xdf, 0xdf, 0x59, 0xfe, 0xab, 0xb5, 0xc7, 0xdd, 0x87, 0x55, 0xff, 0x56, 0x7f, 0x7c, 0xf8,
		0xb4, 0xbb, 0x5b, 0xd8, 0x29, 0x95, 0x2f, 0x8a, 0xfe, 0x7e, 0xf7, 0xa1, 0x74, 0x51, 0xf4, 0x4b,
		0xdd, 0xc9, 0x6f, 0x76, 0x1f, 0x2e, 0x4a, 0x7e, 0x63, 0xfe, 0x72, 0xf2, 0xdf, 0x5d, 0x3a, 0xb7,
		0xd5, 0xa5, 0xb4, 0xf7, 0xf6, 0x69, 0xeb, 0x4f, 0x36, 0xa3, 0xff, 0x1b, 0x56, 0xef, 0xb8, 0xd5,
		0xff, 0xe2, 0x41, 0x8b, 0x39, 0xa8, 0xc5, 0x66, 0x87, 0x42, 0xad, 0xb6, 0x68, 0x5b, 0x49, 0x07,
		0x9e, 0x0f, 0x0e, 0x55, 0x06, 0x55, 0x06, 0x55, 0x06, 0x55, 0x06, 0x55, 0x46, 0xbe, 0x6e, 0x2f,
		0xc3, 0x70, 0x28, 0x02, 0xc5, 0xa1, 0xc8, 0x4a, 0x79, 0x81, 0xea, 0xb5, 0xae, 0x1c, 0xde, 0x54,
		0x2a, 0xd4, 0x81, 0x96, 0x44, 0x75, 0x29, 0xbc, 0xb8, 0xff, 0x8f, 0xb8, 0x09, 0x46, 0xb3, 0x62,
		0x24, 0x85, 0x70, 0x24, 0x54, 0x7f, 0x0a, 0x94, 0x13, 0xff, 0x51, 0x98, 0x7c, 0x45, 0xf2, 0xb2,
		0x10, 0x5c, 0x49, 0x3f, 0x0e, 0xae, 0x64, 0x9c, 0xbe, 0x2a, 0x4c, 0xe3, 0x07, 0x63, 0x25, 0xfb,
		0x41, 0xac, 0x0b, 0x4a, 0xc8, 0xeb, 0x7f, 0x2e, 0xc3, 0x28, 0x4e, 0x5f, 0x15, 0x16, 0x9b, 0xe4,
		0x17, 0x92, 0x96, 0xd6, 0xc9, 0xb7, 0x02, 0x45, 0x37, 0x87, 0xe4, 0xee, 0x74, 0x34, 0xee, 0x6b,
		0x35, 0x5b, 0x5c, 0xed, 0xf4, 0xe6, 0x3e, 0x5f, 0x8f, 0x7a, 0x93, 0xaf, 0x8e, 0xbc, 0xec, 0x35,
		0xaf, 0xe4, 0xe9, 0xe4, 0xd6, 0xe6, 0x2f, 0x7a, 0xad, 0xd1, 0x6d, 0xed, 0x3c, 0xb9, 0xb1, 0xde,
		0xf1, 0xfc, 0xc6, 0xd2, 0x57, 0xbd, 0xe6, 0xe0, 0xdf, 0x8e, 0xbc, 0x6c, 0xa9, 0x93, 0x48, 0xf4,
		0x3a, 0xd3, 0xbb, 0x4a, 0xbe, 0xf5, 0x4e, 0xa7, 0x77, 0x85, 0x5e, 0x21, 0x99, 0xa7, 0x30, 0x56,
		0xdf, 0x54, 0xf8, 0x9f, 0xf2, 0x03, 0xad, 0x23, 0x79, 0x69, 0xa5, 0x75, 0xfa, 0x4a, 0x87, 0xba,
		0x64, 0x6c, 0x74, 0x11, 0x71, 0x95, 0xc6, 0xa2, 0x8b, 0x48, 0x3e, 0x69, 0x2a, 0xba, 0x88, 0xbc,
		0x69, 0xd6, 0xc8, 0xba, 0x88, 0x64, 0x9c, 0x24, 0x7d, 0xfc, 0x21, 0x7b, 0x09, 0xb4, 0x51, 0x88,
		0x12, 0xa2, 0x10, 0x88, 0x42, 0x20, 0x0a, 0x81, 0x28, 0x84, 0x3b, 0x51, 0x08, 0x2a, 0xf7, 0x9f,
		0x0e, 0x38, 0xed, 0x99, 0xa1, 0xa9, 0x63, 0x1f, 0xdb, 0x99, 0x9e, 0x52, 0xd3, 0x4b, 0x20, 0x36,
		0x5d, 0x9e, 0xbc, 0x44, 0x72, 0x38, 0xe0, 0x84, 0x05, 0x37, 0xe0, 0x81, 0x1b, 0x26, 0x9c, 0x81,
		0x0b, 0x67, 0x60, 0xc3, 0x19, 0xf8, 0xa0, 0x85, 0x11, 0x62, 0x38, 0x49, 0x67, 0xf9, 0x8c, 0xc3,
		0xc1, 0x6f, 0xf3, 0x56, 0x78, 0xce, 0xb0, 0xfd, 0x3a, 0xc3, 0xd8, 0x99, 0xee, 0xc2, 0x4f, 0x60,
		0x97, 0xd3, 0x4c, 0x6c, 0x42, 0xd3, 0x26, 0x6a, 0x48, 0xbc, 0xd2, 0xa6, 0xa9, 0x42, 0xda, 0x8c,
		0xda, 0x15, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x85, 0x83, 0xb4, 0x50, 0x6b, 0xe1, 0x45,
		0x4d, 0x3c, 0x14, 0x8c, 0x87, 0x34, 0x17, 0xa4, 0xf1, 0xe4, 0x4a, 0x3e, 0x6c, 0xe4, 0xc9, 0x3d,
		0x2e, 0xd0, 0x71, 0x01, 0x7c, 0xdc, 0x02, 0x21, 0x57, 0xc0, 0xc8, 0x39, 0x50, 0x72, 0x0e, 0x9c,
		0x9c, 0x03, 0x29, 0x1e, 0xb0, 0x62, 0x02, 0x2d, 0x7e, 0xc5, 0x9d, 0xf1, 0x1b, 0x63, 0xa9, 0x74,
		0xa9, 0xc6, 0xe9, 0x33, 0x66, 0x28, 0x52, 0x63, 0xbc, 0x04, 0x9e, 0xda, 0x12, 0x2f, 0xff, 0xf0,
		0xfa, 0xcc, 0x6d, 0xee, 0xda, 0x13, 0x8e, 0xd1, 0x8b, 0xcc, 0xe5, 0x30, 0xd7, 0xa6, 0xc8, 0x5c,
		0x8f, 0x03, 0xf5, 0x02, 0x1c, 0x71, 0xa7, 0x8b, 0x26, 0x1c, 0xdc, 0xc1, 0x84, 0x7f, 0x60, 0xc2,
		0xb5, 0x6a, 0x75, 0xaf, 0x0a, 0x33, 0x76, 0x8b, 0x8b, 0xf0, 0x8f, 0xde, 0xdd, 0xda, 0x8c, 0xfb,
		0xe5, 0x28, 0xb1, 0xc3, 0xb7, 0x93, 0xbe, 0x3c, 0x6c, 0xc0, 0xb0, 0xa3, 0x8e, 0xb8, 0x01, 0xe2,
		0x06, 0x88, 0x1b, 0x20, 0x6e, 0x80, 0xb8, 0x41, 0x4e, 0xe2, 0x06, 0xfb, 0x0e, 0x84, 0x0d, 0xaa,
		0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x58, 0x37, 0xe1, 0x72, 0x15,
		0x41, 0x03, 0x04, 0x0d, 0x10, 0x34, 0xa0, 0x0d, 0x1a, 0xdc, 0xce, 0x56, 0x9f, 0x0b, 0x51, 0x83,
		0xe4, 0x5a, 0x10, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0xe0,
		0x95, 0x7e, 0xe3, 0x52, 0xaa, 0x20, 0xba, 0x77, 0x20, 0x6e, 0xd0, 0x60, 0xbc, 0x84, 0x43, 0xa1,
		0xae, 0xa7, 0x89, 0xff, 0x08, 0x1c, 0x20, 0x70, 0xf0, 0x43, 0xd5, 0x55, 0x82, 0xe6, 0x42, 0xe0,
		0x60, 0xbd, 0x4d, 0x18, 0xf9, 0x06, 0x08, 0x1d, 0x20, 0x74, 0x40, 0x6a, 0xe6, 0xe2, 0x4e, 0x0b,
		0x35, 0x10, 0x03, 0xfe, 0xc0, 0x41, 0x7a, 0x25, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2,
		0x06, 0x08, 0x1b, 0x20, 0x6c, 0xf0, 0xda, 0xb0, 0x01, 0x79, 0x11, 0xdc, 0x55, 0x30, 0x42, 0x54,
		0x14, 0x77, 0x33, 0x49, 0x4b, 0x38, 0x9a, 0x30, 0xf3, 0x60, 0xc8, 0x4f, 0x5a, 0xd2, 0x2b, 0x01,
		0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0xc9,
		0xce, 0xf1, 0x28, 0x88, 0xb4, 0x74, 0x81, 0xb3, 0xcc, 0x2f, 0x04, 0x94, 0x05, 0x94, 0x05, 0x94,
		0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x05, 0x94, 0x25, 0x3b, 0xc7, 0x3a, 0x0a, 0x54,
		0x2c, 0xb5, 0xbc, 0x75, 0x20, 0xaf, 0xf4, 0xd9, 0xb5, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80,
		0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x80, 0xb8, 0x38, 0x4f, 0x5c, 0x72, 0x5d, 0x5e, 0x94, 0xb8, 0xeb,
		0x62, 0x66, 0x7c, 0x96, 0x2e, 0x8c, 0xd9, 0xd6, 0x78, 0xd9, 0x1f, 0x15, 0x38, 0xea, 0x5a, 0x6f,
		0x93, 0xb7, 0x6e, 0x3c, 0x4f, 0xee, 0xbb, 0x99, 0xce, 0x44, 0xe6, 0x27, 0x14, 0xdd, 0x1d, 0xf9,
		0xd6, 0x5c, 0xbe, 0x1a, 0xe7, 0xfc, 0x2e, 0xee, 0x39, 0x2a, 0xdf, 0x78, 0x87, 0x32, 0xd6, 0x13,
		0x83, 0xa1, 0xed, 0xda, 0x73, 0x24, 0xd5, 0xc1, 0x50, 0x4c, 0x68, 0x51, 0x4c, 0x2b, 0x2b, 0xbc,
		0xa3, 0xe0, 0xee, 0xd9, 0xc8, 0xa5, 0xfd, 0x4a, 0xa5, 0x56, 0xaf, 0x54, 0x8a, 0xf5, 0xbd, 0x7a,
		0xb1, 0x51, 0xad, 0x96, 0x6a, 0x25, 0xc2, 0x2c, 0x60, 0xaf, 0x1d, 0x0d, 0x44, 0x24, 0x06, 0x9f,
		0x27, 0x8f, 0x5e, 0x8d, 0x87, 0xc3, 0x5c, 0x59, 0x34, 0x13, 0x3e, 0xb9, 0x8b, 0x4b, 0x1e, 0x69,
		0x67, 0x09, 0xa7, 0x90, 0xc8, 0x43, 0x9f, 0x6e, 0xfe, 0x95, 0xb9, 0x19, 0x7d, 0xba, 0xc9, 0x9b,
		0x27, 0x3b, 0xb0, 0xde, 0xd6, 0xb6, 0x81, 0xf7, 0xd6, 0x1a, 0x2d, 0xa3, 0x39, 0x45, 0x4b, 0xe2,
		0x5c, 0xdb, 0x13, 0xb3, 0xf6, 0xa5, 0xad, 0x33, 0x03, 0x34, 0xbc, 0x8c, 0x8e, 0x87, 0xb1, 0xf2,
		0x2e, 0x1a, 0x9e, 0x65, 0xcb, 0xec, 0x88, 0xbc, 0x36, 0x8b, 0xb7, 0xb6, 0xe8, 0x9a, 0x49, 0x5d,
		0xb2, 0x1d, 0x07, 0x6c, 0xde, 0x3d, 0x9a, 0xfd, 0x44, 0xc3, 0x16, 0x6f, 0xdb, 0xd2, 0x89, 0x2d,
		0xdc, 0x82, 0x6d, 0x13, 0xd9, 0xb4, 0x59, 0x6b, 0x36, 0x67, 0x73, 0x66, 0x3e, 0xc9, 0x90, 0xd5,
		0xda, 0xb2, 0x56, 0x2a, 0x2b, 0x35, 0x68, 0x9e, 0xb6, 0xcd, 0xd2, 0x8c, 0x3d, 0xbe, 0xdf, 0x7a,
		0x0c, 0x58, 0x8e, 0x37, 0x7f, 0x08, 0xe1, 0x58, 0xfb, 0xa3, 0x30, 0xd6, 0xc6, 0x6c, 0xe7, 0xa9,
		0x0c, 0xd6, 0xcb, 0x11, 0x0c, 0xd9, 0xbb, 0xd9, 0xc6, 0x8d, 0xc6, 0x93, 0x0a, 0x6c, 0x24, 0x09,
		0xd8, 0xdd, 0xf4, 0xb7, 0xb5, 0x89, 0x6f, 0x7d, 0x53, 0xde, 0xfa, 0x26, 0xbb, 0xf5, 0x4d, 0x73,
		0xb7, 0x90, 0xc4, 0x74, 0xa3, 0x40, 0x6f, 0x46, 0x40, 0x8c, 0x1b, 0xd6, 0x7c, 0x39, 0x58, 0x21,
		0x38, 0x96, 0x3a, 0xc3, 0x3e, 0x39, 0x9a, 0xb2, 0xe1, 0x0f, 0xb6, 0x98, 0x95, 0x44, 0x93, 0x6d,
		0x64, 0x3b, 0x8b, 0x88, 0x2c, 0x3b, 0x88, 0x2c, 0xeb, 0x87, 0x2c, 0x9b, 0xc7, 0x6d, 0xa1, 0x66,
		0xab, 0xb3, 0x69, 0xe2, 0x58, 0xec, 0xd9, 0xe3, 0x82, 0xff, 0xb2, 0x65, 0x8b, 0x76, 0x1b, 0x5c,
		0x5b, 0x4f, 0xc6, 0xa4, 0x48, 0xb6, 0xa4, 0x4d, 0xa6, 0xa4, 0x4a, 0x96, 0x24, 0x4f, 0x86, 0x24,
		0x4f, 0x76, 0x24, 0x4f, 0x66, 0x5c, 0xaf, 0x0d, 0x02, 0xdb, 0x0d, 0x9f, 0xbd, 0xf9, 0x9e, 0x83,
		0x75, 0x4b, 0x7e, 0x3a, 0xb0, 0x67, 0x73, 0x93, 0xe3, 0xa5, 0xcb, 0xb4, 0x9c, 0x07, 0x42, 0x96,
		0xc7, 0x4e, 0x99, 0xaf, 0xce, 0x93, 0x97, 0x4e, 0x9d, 0x7f, 0xce, 0x96, 0x67, 0xce, 0x96, 0x4f,
		0xce, 0x96, 0x37, 0xbe, 0xde, 0x29, 0x0e, 0x64, 0xf9, 0xde, 0xe9, 0xba, 0x1b, 0x8a, 0xe0, 0x2a,
		0x12, 0x57, 0x14, 0x8b, 0x6e, 0xce, 0x2c, 0xeb, 0x04, 0x63, 0x9d, 0xcc, 0xe2, 0xcf, 0x1f, 0x3f,
		0x26, 0xe9, 0xb4, 0x85, 0x39, 0x14, 0xac, 0x6b, 0xaa, 0x81, 0x45, 0x7e, 0x39, 0xa2, 0x71, 0xf7,
		0x4f, 0xa8, 0x4c, 0x42, 0x2e, 0x01, 0xca, 0x00, 0x65, 0x80, 0x32, 0x40, 0x19, 0xa0, 0xec, 0x30,
		0x28, 0x27, 0xcb, 0x0e, 0x98, 0x9c, 0x99, 0xaa, 0xe4, 0x0c, 0x10, 0x19, 0x24, 0x53, 0x1c, 0x39,
		0xb2, 0x1c, 0x59, 0x04, 0x22, 0x03, 0x91, 0x81, 0xc8, 0x9b, 0x81, 0xc8, 0xb6, 0x23, 0x95, 0xe9,
		0x40, 0xd3, 0xf3, 0x6c, 0x52, 0x0d, 0x04, 0x5d, 0xf5, 0x86, 0xc5, 0x7e, 0x70, 0xc9, 0xd8, 0x54,
		0x87, 0xf8, 0x48, 0xeb, 0x74, 0x90, 0xd7, 0xe5, 0xe0, 0xa8, 0xc3, 0xc1, 0x5b, 0x77, 0x83, 0xab,
		0xce, 0x06, 0x7b, 0x5d, 0x0d, 0xf6, 0x3a, 0x1a, 0xec, 0x75, 0x33, 0xf2, 0x75, 0xbc, 0x98, 0xbc,
		0x0e, 0x06, 0x83, 0x14, 0xe3, 0x90, 0x64, 0xcb, 0xa4, 0xd9, 0xff, 0xf8, 0x3b, 0x85, 0xa4, 0x58,
		0xe8, 0x38, 0x7d, 0x35, 0x13, 0x72, 0x09, 0x4c, 0xe5, 0xe5, 0x94, 0x24, 0x01, 0xb3, 0xee, 0x87,
		0x37, 0x37, 0x63, 0x25, 0xf5, 0x3d, 0x17, 0xbb, 0x78, 0x79, 0x01, 0xa0, 0x18, 0xa0, 0x18, 0xa0,
		0x18, 0xa0, 0x18, 0xa0, 0x18, 0xa0, 0x18, 0x9c, 0x14, 0x63, 0x8e, 0x4b, 0x52, 0xc4, 0xe9, 0xeb,
		0x7b, 0xb0, 0x8c, 0xb7, 0x4d, 0xb9, 0xb8, 0xd3, 0x3e, 0x3b, 0xd3, 0x58, 0x76, 0x11, 0x60, 0x1b,
		0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x60, 0x1b, 0x9c, 0x6c, 0xe3, 0x39, 0x36, 0x4d,
		0x18, 0xc7, 0x02, 0x56, 0x81, 0x75, 0xbc, 0x6d, 0xea, 0xa5, 0xba, 0x0d, 0x86, 0x72, 0xe0, 0x47,
		0x22, 0x88, 0x09, 0xab, 0xa7, 0xa5, 0x16, 0xfe, 0x62, 0x7c, 0x70, 0x0d, 0x70, 0x0d, 0x70, 0x0d,
		0x70, 0x0d, 0x70, 0x0d, 0xf2, 0x75, 0x2b, 0x07, 0x42, 0x69, 0xa9, 0xef, 0x99, 0xf8, 0x06, 0x65,
		0x2d, 0xd4, 0xd6, 0xec, 0x56, 0x3f, 0x07, 0x31, 0x83, 0xcb, 0x98, 0x4f, 0x78, 0xeb, 0xf8, 0x8f,
		0xe6, 0x61, 0xeb, 0x4b, 0xaf, 0xd3, 0x3e, 0x3f, 0x3b, 0xe8, 0x75, 0x0e, 0x9a, 0xa7, 0xed, 0x63,
		0x6a, 0xef, 0xf1, 0x47, 0x30, 0x1c, 0x4f, 0x4f, 0xef, 0x5f, 0x90, 0x57, 0xb0, 0x66, 0xee, 0xb4,
		0x32, 0x9f, 0xfd, 0x5f, 0x0f, 0xcf, 0x4f, 0xcf, 0x0e, 0x3a, 0xbd, 0xc3, 0x76, 0xfb, 0xc4, 0xdb,
		0x84, 0x7e, 0x37, 0x8e, 0xcc, 0x7b, 0xbb, 0xd3, 0xfa, 0xad, 0x75, 0xdc, 0x3c, 0x6b, 0x77, 0x30,
		0xeb, 0x74, 0xb3, 0xde, 0x3c, 0x85, 0xa1, 0x53, 0x3b, 0x98, 0xf6, 0xf1, 0xd7, 0x83, 0x2f, 0x5e,
		0xce, 0x3b, 0x52, 0x74, 0xf3, 0xc6, 0xf7, 0x72, 0xa1, 0xee, 0x87, 0x41, 0xac, 0xfd, 0x9b, 0x70,
		0x20, 0xaf, 0xa4, 0x18, 0xd0, 0x8b, 0xfb, 0xc5, 0xe1, 0xa1, 0xed, 0xa1, 0xed, 0xa1, 0xed, 0xa1,
		0xed, 0xa1, 0xed, 0xc9, 0xd7, 0xad, 0x96, 0x37, 0x42, 0xcb, 0xfe, 0xb7, 0xb8, 0x56, 0x61, 0xd0,
		0xf6, 0xfb, 0x84, 0x43, 0x9e, 0x2b, 0x39, 0xad, 0xfa, 0xed, 0xa9, 0x40, 0x85, 0xb1, 0xe8, 0x87,
		0x6a, 0x10, 0x53, 0xde, 0x72, 0x27, 0x50, 0xd7, 0x82, 0x5c, 0x4f, 0x33, 0xb4, 0xe4, 0x3a, 0x92,
		0x8a, 0xaf, 0x5d, 0x2a, 0x73, 0x93, 0xd2, 0x69, 0xd4, 0x84, 0x71, 0xfc, 0xaf, 0x51, 0xd0, 0xd7,
		0x32, 0x54, 0x5f, 0xe4, 0x75, 0x62, 0xed, 0xc5, 0x8d, 0x68, 0xd4, 0x7b, 0x14, 0xdc, 0x6d, 0xbc,
		0xc9, 0xf1, 0x76, 0x91, 0x72, 0xce, 0x0a, 0x73, 0xda, 0x6f, 0xae, 0x0b, 0x8d, 0xfb, 0xd3, 0x66,
		0x48, 0x55, 0xa8, 0x2c, 0x43, 0xaa, 0x68, 0x0a, 0x96, 0x41, 0xd7, 0x42, 0xd7, 0x42, 0xd7, 0x42,
		0xd7, 0x42, 0xd7, 0x2e, 0x59, 0xb7, 0x63, 0xa9, 0xf4, 0x5e, 0x99, 0x41, 0xd2, 0xd6, 0x21, 0x29,
		0x21, 0x29, 0x21, 0x29, 0x21, 0x29, 0x73, 0x60, 0x72, 0x95, 0x72, 0xa3, 0xd2, 0xa8, 0xd5, 0xcb,
		0x0d, 0x08, 0x49, 0x08, 0xc9, 0x4d, 0x16, 0x92, 0xb4, 0x02, 0x84, 0xb6, 0xc4, 0x26, 0x64, 0x24,
		0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0xe4, 0x92, 0x75, 0x3b, 0xed, 0x66, 0x48, 0x6e, 0xc3,
		0x69, 0xea, 0xf3, 0x3e, 0xed, 0x51, 0x2b, 0x2d, 0x22, 0x45, 0x2e, 0x27, 0xbd, 0x9d, 0x9d, 0x8b,
		0xa2, 0xdf, 0x08, 0xfc, 0xab, 0xa6, 0xff, 0xb5, 0xfb, 0xbd, 0xf4, 0xa1, 0xf2, 0xf8, 0x69, 0xf7,
		0x7b, 0xfd, 0xf1, 0xe5, 0x0f, 0x1f, 0x96, 0xfd, 0x5a, 0xe9, 0x43, 0xfd, 0xf1, 0xd3, 0x8a, 0x7f,
		0xa9, 0x3d, 0x7e, 0xfa, 0xc9, 0xcf, 0xa8, 0x3e, 0xee, 0x64, 0x7e, 0x75, 0xf2, 0xf3, 0xf2, 0xaa,
		0x37, 0x54, 0x56, 0xbc, 0x61, 0x6f, 0xd5, 0x1b, 0xf6, 0x56, 0xbc, 0x61, 0xe5, 0x25, 0x95, 0x57,
		0xbc, 0xa1, 0xfa, 0xf8, 0x90, 0xf9, 0xfd, 0x9d, 0xe5, 0xbf, 0x5a, 0x7b, 0xdc, 0x7d, 0x58, 0xf5,
		0x6f, 0xf5, 0xc7, 0x87, 0x4f, 0xbb, 0xbb, 0x85, 0x9d, 0x52, 0xf9, 0xa2, 0xe8, 0xef, 0x77, 0x1f,
		0x4a, 0x17, 0x45, 0xbf, 0xd4, 0x9d, 0xfc, 0x66, 0xf7, 0xe1, 0xa2, 0xe4, 0x37, 0xe6, 0x2f, 0x27,
		0xff, 0xdd, 0xa5, 0x73, 0x5b, 0x5d, 0x4a, 0x7b, 0x6f, 0x9f, 0xb6, 0xfe, 0x64, 0x33, 0xfa, 0xbf,
		0x61, 0xf5, 0x8e, 0x5b, 0xfd, 0x2f, 0x1e, 0xb4, 0x98, 0x83, 0x5a, 0x6c, 0x76, 0x28, 0xd4, 0x6a,
		0x8b, 0xb6, 0x95, 0x74, 0xe0, 0xf9, 0xe0, 0x50, 0x65, 0x50, 0x65, 0x50, 0x65, 0x50, 0x65, 0x50,
		0x65, 0xe4, 0xeb, 0xf6, 0x32, 0x0c, 0x87, 0x22, 0x50, 0x1c, 0x8a, 0xac, 0x94, 0x17, 0xa8, 0x5e,
		0xeb, 0xca, 0xe1, 0x4d, 0xa5, 0x42, 0x1d, 0x68, 0x49, 0x54, 0x97, 0xc2, 0x8b, 0xfb, 0xff, 0x88,
		0x9b, 0x60, 0x34, 0x2b, 0x46, 0x52, 0x08, 0x47, 0x42, 0xf5, 0xa7, 0x40, 0x39, 0xf1, 0x1f, 0x85,
		0xc9, 0x57, 0x24, 0x2f, 0x0b, 0xc1, 0x95, 0xf4, 0xe3, 0xe0, 0x4a, 0xc6, 0xe9, 0xab, 0xc2, 0x34,
		0x7e, 0x30, 0x56, 0xb2, 0x1f, 0xc4, 0xba, 0xa0, 0x84, 0xbc, 0xfe, 0xe7, 0x32, 0x8c, 0xe2, 0xf4,
		0x55, 0xe1, 0x65, 0x9b, 0xfc, 0x42, 0xd2, 0xd4, 0x3a, 0xf9, 0x56, 0xa0, 0xe8, 0xe7, 0x90, 0xdc,
		0x9f, 0x8e, 0xc6, 0x7d, 0xad, 0x66, 0xcb, 0xab, 0x9d, 0xde, 0xde, 0xe7, 0xeb, 0x51, 0x6f, 0xf2,
		0xd5, 0x91, 0x97, 0xbd, 0xe6, 0x95, 0x3c, 0x9d, 0xdc, 0xdc, 0xfc, 0x45, 0xaf, 0x35, 0xba, 0xad,
		0x9d, 0x27, 0xb7, 0xd6, 0x3b, 0x9e, 0xdf, 0x5a, 0xfa, 0xaa, 0xd7, 0x1c, 0xfc, 0xdb, 0x91, 0x97,
		0xed, 0xb1, 0x3e, 0x09, 0x63, 0xdd, 0xeb, 0x4c, 0xef, 0x2b, 0xf9, 0xd6, 0x3b, 0x9d, 0xde, 0x17,
		0xfa, 0x85, 0x64, 0x9e, 0xc3, 0x58, 0x7d, 0x53, 0xe1, 0x7f, 0xca, 0x0f, 0xb4, 0x8e, 0xe4, 0xa5,
		0x95, 0xf6, 0xe9, 0x2b, 0x9d, 0xea, 0x92, 0xb1, 0xd1, 0x49, 0xc4, 0x55, 0x2a, 0x8b, 0x4e, 0x22,
		0xf9, 0xa4, 0xaa, 0xe8, 0x24, 0xf2, 0xa6, 0x59, 0x23, 0xeb, 0x24, 0x92, 0x71, 0x92, 0xf4, 0x31,
		0x88, 0xec, 0x25, 0xd0, 0x46, 0x22, 0x4a, 0x88, 0x44, 0x20, 0x12, 0x81, 0x48, 0x04, 0x22, 0x11,
		0xee, 0x44, 0x22, 0xa8, 0xdc, 0x7f, 0x3a, 0xe0, 0xb4, 0x6f, 0x86, 0xa6, 0x8e, 0x7f, 0x6c, 0x67,
		0xfa, 0x4a, 0x4d, 0x2f, 0x81, 0xd8, 0x74, 0x79, 0x72, 0x13, 0xc9, 0xe1, 0x80, 0x13, 0x16, 0xdc,
		0x80, 0x07, 0x6e, 0x98, 0x70, 0x06, 0x2e, 0x9c, 0x81, 0x0d, 0x67, 0xe0, 0x83, 0x16, 0x46, 0x88,
		0xe1, 0x24, 0x9d, 0xe5, 0x33, 0x0e, 0x07, 0xbf, 0xcd, 0x5b, 0xe5, 0x39, 0xc3, 0xf6, 0xeb, 0x0c,
		0x63, 0x67, 0x3a, 0x0c, 0x3f, 0x81, 0x5d, 0x4e, 0xb3, 0xb1, 0x09, 0x4d, 0x9b, 0xa8, 0x29, 0xf1,
		0x4a, 0x9b, 0xa6, 0x0a, 0x6a, 0x33, 0x6a, 0x57, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16, 0x90, 0x16,
		0x0e, 0xd2, 0x42, 0xad, 0x85, 0x17, 0x35, 0xf1, 0x50, 0x30, 0x1e, 0xd4, 0x5c, 0x90, 0xc6, 0x93,
		0x2b, 0xf9, 0xb0, 0x91, 0xa7, 0xf7, 0xb8, 0x40, 0xc7, 0x05, 0xf0, 0x71, 0x0b, 0x84, 0x5c, 0x01,
		0x23, 0xe7, 0x40, 0xc9, 0x39, 0x70, 0x72, 0x0e, 0xa4, 0x78, 0xc0, 0x8a, 0x09, 0xb4, 0xf8, 0x15,
		0x77, 0xc6, 0x6f, 0x8c, 0xa5, 0xd2, 0xa5, 0x1a, 0xa7, 0xcf, 0x98, 0xa1, 0x48, 0x8d, 0xf1, 0x12,
		0x78, 0xea, 0x4b, 0xbc, 0xfc, 0xc3, 0xeb, 0x33, 0xb7, 0xb9, 0xeb, 0x4f, 0x38, 0x46, 0x2f, 0x32,
		0x97, 0xc3, 0x5c, 0x9f, 0x22, 0x73, 0x3d, 0x0e, 0xd4, 0x0c, 0x70, 0xc4, 0x9d, 0x2e, 0x9a, 0x70,
		0x70, 0x07, 0x13, 0xfe, 0x81, 0x09, 0xd7, 0xaa, 0xd5, 0xbd, 0x2a, 0xcc, 0xd8, 0x2d, 0x2e, 0xc2,
		0x3f, 0x7a, 0x77, 0x6b, 0x33, 0xee, 0x97, 0xa3, 0xcc, 0x0e, 0xdf, 0x4e, 0xfa, 0xf2, 0xb0, 0x01,
		0xc3, 0x8e, 0x3a, 0xe2, 0x06, 0x88, 0x1b, 0x20, 0x6e, 0x80, 0xb8, 0x01, 0xe2, 0x06, 0x39, 0x89,
		0x1b, 0xec, 0x3b, 0x10, 0x36, 0xa8, 0x22, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20,
		0x6c, 0x60, 0xdd, 0x84, 0xcb, 0x55, 0x04, 0x0d, 0x10, 0x34, 0x40, 0xd0, 0x80, 0x36, 0x68, 0x70,
		0x3b, 0x5b, 0x7d, 0x2e, 0x44, 0x0d, 0x92, 0x6b, 0x41, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10,
		0x36, 0x40, 0xd8, 0x00, 0x61, 0x83, 0x57, 0xfa, 0x8d, 0x4b, 0xa9, 0x82, 0xe8, 0xde, 0x81, 0xb8,
		0x41, 0x83, 0xf1, 0x12, 0x0e, 0x85, 0xba, 0x9e, 0x26, 0xfe, 0x23, 0x70, 0x80, 0xc0, 0xc1, 0x0f,
		0x55, 0x57, 0x09, 0x9a, 0x0b, 0x81, 0x83, 0xf5, 0x36, 0x61, 0xe4, 0x1b, 0x20, 0x74, 0x80, 0xd0,
		0x01, 0xa9, 0x99, 0x8b, 0x3b, 0x2d, 0xd4, 0x40, 0x0c, 0xf8, 0x03, 0x07, 0xe9, 0x95, 0x20, 0x6c,
		0x80, 0xb0, 0x01, 0xc2, 0x06, 0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0xc1, 0x6b, 0xc3, 0x06, 0xe4,
		0x85, 0x70, 0x57, 0xc1, 0x08, 0x51, 0x61, 0xdc, 0xcd, 0x24, 0x2d, 0xe1, 0x68, 0xc2, 0xcc, 0x83,
		0x21, 0x3f, 0x69, 0x49, 0xaf, 0x04, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x05,
		0xa4, 0x05, 0xa4, 0x05, 0xa4, 0x25, 0x3b, 0xc7, 0xa3, 0x20, 0xd2, 0xd2, 0x05, 0xce, 0x32, 0xbf,
		0x10, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50, 0x16, 0x50,
		0x96, 0xec, 0x1c, 0xeb, 0x28, 0x50, 0xb1, 0xd4, 0xf2, 0xd6, 0x81, 0xbc, 0xd2, 0x67, 0xd7, 0x02,
		0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0x02, 0xe2, 0xe2, 0x3c, 0x71,
		0xc9, 0x75, 0x79, 0x51, 0xe2, 0xce, 0x8b, 0x99, 0xf1, 0x99, 0x3a, 0x31, 0x66, 0x9b, 0xe3, 0x65,
		0x7f, 0x54, 0xe0, 0xa8, 0x6c, 0xbd, 0xcd, 0xd0, 0xbe, 0xf1, 0x3c, 0xb9, 0xf3, 0x66, 0x3a, 0x17,
		0x99, 0x9f, 0x50, 0x74, 0x78, 0xe4, 0x5b, 0x77, 0xf9, 0x6a, 0x9e, 0xf3, 0xbb, 0xb8, 0xe7, 0xa8,
		0x7e, 0xe3, 0x1d, 0xca, 0x58, 0x4f, 0x0c, 0x86, 0xb6, 0x73, 0xcf, 0x91, 0x54, 0x07, 0x43, 0x31,
		0xa1, 0x46, 0x31, 0xad, 0xb4, 0xf0, 0x8e, 0x82, 0xbb, 0x67, 0x23, 0x97, 0xf6, 0x2b, 0x95, 0x5a,
		0xbd, 0x52, 0x29, 0xd6, 0xf7, 0xea, 0xc5, 0x46, 0xb5, 0x5a, 0xaa, 0x95, 0x08, 0x33, 0x81, 0xbd,
		0x76, 0x34, 0x10, 0x91, 0x18, 0x7c, 0x9e, 0x3c, 0x7a, 0x35, 0x1e, 0x0e, 0x73, 0x65, 0xd1, 0x4c,
		0x18, 0xe5, 0x32, 0x36, 0x79, 0xa4, 0xfd, 0x25, 0x1c, 0x43, 0x23, 0x0f, 0x3d, 0xbb, 0xf9, 0x57,
		0xe7, 0xa6, 0xf4, 0xec, 0x26, 0x6f, 0xa3, 0xec, 0xc4, 0x9a, 0x5b, 0xdb, 0x66, 0xde, 0x5b, 0x6b,
		0xb4, 0x94, 0xe6, 0x54, 0x2d, 0x89, 0x79, 0x6d, 0x4f, 0x4c, 0xdb, 0x97, 0xb6, 0xce, 0x0f, 0xd0,
		0xf0, 0x33, 0x3a, 0x3e, 0xc6, 0xca, 0xbf, 0x68, 0xf8, 0x96, 0x2d, 0xb3, 0x23, 0xf2, 0xdc, 0x4c,
		0x1e, 0xdb, 0xa2, 0x7b, 0x26, 0x76, 0xcb, 0x76, 0x9c, 0xb0, 0x79, 0x17, 0x69, 0xf6, 0x13, 0x0d,
		0x5b, 0xbd, 0x6d, 0x6b, 0x27, 0xb7, 0x72, 0x0b, 0xf6, 0x4d, 0x66, 0xd7, 0x66, 0x2d, 0xda, 0x9c,
		0xdd, 0x99, 0xf9, 0x24, 0x43, 0x96, 0x6b, 0xcb, 0x62, 0xe9, 0x2c, 0xd5, 0xa0, 0x89, 0xda, 0x37,
		0x4d, 0x33, 0x36, 0xf9, 0x7e, 0x0b, 0x32, 0x60, 0x3d, 0xde, 0xc2, 0x83, 0x88, 0xcc, 0xed, 0x59,
		0x3d, 0x55, 0xc7, 0x7a, 0x31, 0x80, 0x21, 0x8b, 0x37, 0xdb, 0xce, 0xd1, 0x78, 0xaa, 0x81, 0x8d,
		0xd4, 0x01, 0xbb, 0xa9, 0x00, 0xb6, 0xb6, 0xf6, 0xad, 0x6f, 0xd5, 0x5b, 0xdf, 0x7a, 0xb7, 0xbe,
		0x95, 0xee, 0x16, 0x96, 0x98, 0x6e, 0x1f, 0xe8, 0xcd, 0x48, 0x88, 0x71, 0xc3, 0x9a, 0x2f, 0x07,
		0x2b, 0x24, 0xc7, 0x52, 0xbf, 0xd8, 0x27, 0x47, 0x53, 0x36, 0xfc, 0xc1, 0x16, 0x73, 0x95, 0x68,
		0x72, 0x90, 0x6c, 0xe7, 0x16, 0x91, 0xe5, 0x0c, 0x91, 0xe5, 0x02, 0x91, 0xe5, 0xf8, 0xb8, 0x2d,
		0xd7, 0x6c, 0xf5, 0x3b, 0x4d, 0x1c, 0x8b, 0x3d, 0x7b, 0x5c, 0xf0, 0x5f, 0xb6, 0x6c, 0xd1, 0x6e,
		0xdb, 0x6b, 0xeb, 0x29, 0x9a, 0x14, 0x29, 0x98, 0xb4, 0x29, 0x96, 0x54, 0x29, 0x94, 0xe4, 0x29,
		0x92, 0xe4, 0x29, 0x90, 0xe4, 0x29, 0x8e, 0xeb, 0xb5, 0x55, 0x60, 0xbb, 0x0d, 0xb4, 0x37, 0xdf,
		0x7d, 0xb0, 0x6e, 0xc9, 0x4f, 0xc7, 0xf8, 0x6c, 0x6e, 0x77, 0xbc, 0x74, 0x99, 0x96, 0x33, 0x43,
		0xc8, 0xb2, 0xdb, 0x29, 0xb3, 0xd8, 0x79, 0xb2, 0xd5, 0xa9, 0xb3, 0xd2, 0xd9, 0xb2, 0xcf, 0xd9,
		0xb2, 0xcc, 0xd9, 0xb2, 0xc9, 0xd7, 0x3b, 0xe1, 0x81, 0x2c, 0x0b, 0x3c, 0x5d, 0x77, 0x43, 0x11,
		0x5c, 0x45, 0xe2, 0x8a, 0x62, 0xd1, 0xcd, 0x99, 0x65, 0x9d, 0x60, 0xac, 0x93, 0x59, 0x04, 0xfa,
		0xe3, 0xc7, 0x24, 0xc5, 0xb6, 0x30, 0x87, 0x82, 0x75, 0x4d, 0x3a, 0xb0, 0xc8, 0x2f, 0x47, 0x34,
		0xee, 0xfe, 0x09, 0x95, 0x49, 0xc8, 0x25, 0x40, 0x19, 0xa0, 0x0c, 0x50, 0x06, 0x28, 0x03, 0x94,
		0x1d, 0x06, 0xe5, 0x64, 0xd9, 0x01, 0x93, 0x33, 0x53, 0x95, 0x9c, 0x0b, 0x22, 0x83, 0x64, 0x8a,
		0x63, 0x48, 0x96, 0x23, 0x8b, 0x40, 0x64, 0x20, 0x32, 0x10, 0x79, 0x33, 0x10, 0xd9, 0x76, 0xa4,
		0x32, 0x1d, 0x68, 0x7a, 0xc2, 0x4d, 0xaa, 0x81, 0xa0, 0xab, 0xe9, 0xb0, 0xd8, 0x25, 0x2e, 0x19,
		0x9b, 0xea, 0x58, 0x1f, 0x69, 0xf5, 0x0e, 0xf2, 0x6a, 0x1d, 0x1c, 0xd5, 0x39, 0x78, 0xab, 0x71,
		0x70, 0x55, 0xdf, 0x60, 0xaf, 0xb6, 0xc1, 0x5e, 0x5d, 0x83, 0xbd, 0x9a, 0x46, 0xbe, 0x0e, 0x1c,
		0x93, 0x57, 0xc7, 0x60, 0x90, 0x62, 0x1c, 0x92, 0x6c, 0x99, 0x34, 0xfb, 0x1f, 0x7f, 0xa7, 0x90,
		0x14, 0x0b, 0x1d, 0xa7, 0xaf, 0x66, 0x42, 0x2e, 0x81, 0xa9, 0xbc, 0x9c, 0x99, 0x24, 0x60, 0xd6,
		0xfd, 0xf0, 0xe6, 0x66, 0xac, 0xa4, 0xbe, 0xe7, 0x62, 0x17, 0x2f, 0x2f, 0x00, 0x14, 0x03, 0x14,
		0x03, 0x14, 0x03, 0x14, 0x03, 0x14, 0x03, 0x14, 0x83, 0x93, 0x62, 0xcc, 0x71, 0x49, 0x8a, 0x38,
		0x7d, 0x7d, 0x0f, 0x96, 0xf1, 0xb6, 0x29, 0x17, 0x77, 0xda, 0x67, 0x67, 0x1a, 0xcb, 0x2e, 0x02,
		0x6c, 0x03, 0x6c, 0x03, 0x6c, 0x03, 0x6c, 0x03, 0x6c, 0x03, 0x6c, 0x83, 0x93, 0x6d, 0x3c, 0xc7,
		0xa6, 0x09, 0xe3, 0x58, 0xc0, 0x2a, 0xb0, 0x8e, 0xb7, 0x4d, 0xbd, 0x54, 0xb7, 0xc1, 0x50, 0x0e,
		0xfc, 0x48, 0x04, 0x31, 0x61, 0x3d, 0xb5, 0xd4, 0xc2, 0x5f, 0x8c, 0x0f, 0xae, 0x01, 0xae, 0x01,
		0xae, 0x01, 0xae, 0x01, 0xae, 0x41, 0xbe, 0x6e, 0xe5, 0x40, 0x28, 0x2d, 0xf5, 0x3d, 0x13, 0xdf,
		0xa0, 0xac, 0x8e, 0xda, 0x9a, 0xdd, 0xea, 0xe7, 0x20, 0x66, 0x70, 0x19, 0xf3, 0x09, 0x6f, 0x1d,
		0xff, 0xd1, 0x3c, 0x6c, 0x7d, 0xe9, 0x75, 0xda, 0xe7, 0x67, 0x07, 0xbd, 0xce, 0x41, 0xf3, 0xb4,
		0x7d, 0x4c, 0xed, 0x3d, 0xfe, 0x08, 0x86, 0xe3, 0xe9, 0xe9, 0xfd, 0x0b, 0xf2, 0xaa, 0xd6, 0xcc,
		0xfd, 0x57, 0xe6, 0xb3, 0xff, 0xeb, 0xe1, 0xf9, 0xe9, 0xd9, 0x41, 0xa7, 0x77, 0xd8, 0x6e, 0x9f,
		0x78, 0x9b, 0xd0, 0x05, 0xc7, 0x91, 0x79, 0x6f, 0x77, 0x5a, 0xbf, 0xb5, 0x8e, 0x9b, 0x67, 0xed,
		0x0e, 0x66, 0x9d, 0x6e, 0xd6, 0x9b, 0xa7, 0x30, 0x74, 0x6a, 0x07, 0xd3, 0x3e, 0xfe, 0x7a, 0xf0,
		0xc5, 0xcb, 0x79, 0x9f, 0x8a, 0x6e, 0xde, 0xf8, 0x5e, 0x2e, 0xd4, 0xfd, 0x30, 0x88, 0xb5, 0x7f,
		0x13, 0x0e, 0xe4, 0x95, 0x14, 0x03, 0x7a, 0x71, 0xbf, 0x38, 0x3c, 0xb4, 0x3d, 0xb4, 0x3d, 0xb4,
		0x3d, 0xb4, 0x3d, 0xb4, 0x3d, 0xf9, 0xba, 0xd5, 0xf2, 0x46, 0x68, 0xd9, 0xff, 0x16, 0xd7, 0x2a,
		0x0c, 0xda, 0x7e, 0x9f, 0x70, 0xc8, 0x73, 0x25, 0xa7, 0xf5, 0xbf, 0x3d, 0x15, 0xa8, 0x30, 0x16,
		0xfd, 0x50, 0x0d, 0x62, 0xca, 0x5b, 0xee, 0x04, 0xea, 0x5a, 0x90, 0xeb, 0x69, 0x86, 0x46, 0x5d,
		0x47, 0x52, 0xf1, 0x35, 0x51, 0x65, 0x6e, 0x5d, 0x3a, 0x8d, 0x9a, 0x30, 0x8e, 0xff, 0x35, 0x0a,
		0xfa, 0x5a, 0x86, 0xea, 0x8b, 0xbc, 0x4e, 0xac, 0xbd, 0xb8, 0x11, 0xed, 0x7b, 0x8f, 0x82, 0xbb,
		0x8d, 0x37, 0x39, 0xde, 0xbe, 0x52, 0xce, 0x59, 0x61, 0x4e, 0x3b, 0xd0, 0x75, 0xa1, 0x71, 0x7f,
		0xda, 0x0c, 0xa9, 0x0a, 0x95, 0x65, 0x48, 0x15, 0x4d, 0xc1, 0x32, 0xe8, 0x5a, 0xe8, 0x5a, 0xe8,
		0x5a, 0xe8, 0x5a, 0xe8, 0xda, 0x25, 0xeb, 0x76, 0x2c, 0x95, 0xde, 0x2b, 0x33, 0x48, 0xda, 0x3a,
		0x24, 0x25, 0x24, 0x25, 0x24, 0x25, 0x24, 0x65, 0x0e, 0x4c, 0xae, 0x52, 0x6e, 0x54, 0x1a, 0xb5,
		0x7a, 0xb9, 0x01, 0x21, 0x09, 0x21, 0xb9, 0xc9, 0x42, 0x92, 0x56, 0x80, 0xd0, 0x96, 0xd8, 0x84,
		0x8c, 0x84, 0x8c, 0x84, 0x8c, 0x84, 0x8c, 0x84, 0x8c, 0x5c, 0xb2, 0x6e, 0xa7, 0xfd, 0x0c, 0xc9,
		0x6d, 0x38, 0x4d, 0x7d, 0xde, 0xa7, 0x3d, 0x6a, 0xa5, 0x45, 0xa4, 0xc8, 0xe5, 0xa4, 0xb7, 0xb3,
		0x73, 0x51, 0xf4, 0x1b, 0x81, 0x7f, 0xd5, 0xf4, 0xbf, 0x76, 0xbf, 0x97, 0x3e, 0x54, 0x1e, 0x3f,
		0xed, 0x7e, 0xaf, 0x3f, 0xbe, 0xfc, 0xe1, 0xc3, 0xb2, 0x5f, 0x2b, 0x7d, 0xa8, 0x3f, 0x7e, 0x5a,
		0xf1, 0x2f, 0xb5, 0xc7, 0x4f, 0x3f, 0xf9, 0x19, 0xd5, 0xc7, 0x9d, 0xcc, 0xaf, 0x4e, 0x7e, 0x5e,
		0x5e, 0xf5, 0x86, 0xca, 0x8a, 0x37, 0xec, 0xad, 0x7a, 0xc3, 0xde, 0x8a, 0x37, 0xac, 0xbc, 0xa4,
		0xf2, 0x8a, 0x37, 0x54, 0x1f, 0x1f, 0x32, 0xbf, 0xbf, 0xb3, 0xfc, 0x57, 0x6b, 0x8f, 0xbb, 0x0f,
		0xab, 0xfe, 0xad, 0xfe, 0xf8, 0xf0, 0x69, 0x77, 0xb7, 0xb0, 0x53, 0x2a, 0x5f, 0x14, 0xfd, 0xfd,
		0xee, 0x43, 0xe9, 0xa2, 0xe8, 0x97, 0xba, 0x93, 0xdf, 0xec, 0x3e, 0x5c, 0x94, 0xfc, 0xc6, 0xfc,
		0xe5, 0xe4, 0xbf, 0xbb, 0x74, 0x6e, 0xab, 0x4b, 0x69, 0xef, 0xed, 0xd3, 0xd6, 0x9f, 0x6c, 0x46,
		0xff, 0x37, 0xac, 0xde, 0x71, 0xab, 0xff, 0xc5, 0x83, 0x16, 0x73, 0x50, 0x8b, 0xcd, 0x0e, 0x85,
		0x5a, 0x6d, 0xd1, 0xb6, 0x92, 0x0e, 0x3c, 0x1f, 0x1c, 0xaa, 0x0c, 0xaa, 0x0c, 0xaa, 0x0c, 0xaa,
		0x0c, 0xaa, 0x8c, 0x7c, 0xdd, 0x5e, 0x86, 0xe1, 0x50, 0x04, 0x8a, 0x43, 0x91, 0x95, 0xf2, 0x02,
		0xd5, 0x6b, 0x5d, 0x39, 0xbc, 0xa9, 0x54, 0xa8, 0x03, 0x2d, 0x89, 0xea, 0x52, 0x78, 0x71, 0xff,
		0x1f, 0x71, 0x13, 0x8c, 0x66, 0xc5, 0x48, 0x0a, 0xe1, 0x48, 0xa8, 0xfe, 0x14, 0x28, 0x27, 0xfe,
		0xa3, 0x30, 0xf9, 0x8a, 0xe4, 0x65, 0x21, 0xb8, 0x92, 0x7e, 0x1c, 0x5c, 0xc9, 0x38, 0x7d, 0x55,
		0x98, 0xc6, 0x0f, 0xc6, 0x4a, 0xf6, 0x83, 0x58, 0x17, 0x94, 0x90, 0xd7, 0xff, 0x5c, 0x86, 0x51,
		0x9c, 0xbe, 0x2a, 0xbc, 0xe8, 0x92, 0x5f, 0x48, 0x7a, 0x5a, 0x27, 0xdf, 0x0a, 0x14, 0xed, 0x1c,
		0x92, 0xdb, 0xd3, 0xd1, 0xb8, 0xaf, 0xd5, 0x6c, 0x75, 0xb5, 0xd3, 0xbb, 0xfb, 0x7c, 0x3d, 0xea,
		0x4d, 0xbe, 0x3a, 0xf2, 0xb2, 0xd7, 0xbc, 0x92, 0xa7, 0x93, 0x7b, 0x9b, 0xbf, 0xe8, 0xb5, 0x46,
		0xb7, 0xb5, 0xf3, 0xe4, 0xce, 0x7a, 0xc7, 0xf3, 0x3b, 0x4b, 0x5f, 0xf5, 0x9a, 0x83, 0x7f, 0x3b,
		0xf2, 0xb2, 0x3d, 0xd6, 0x27, 0x91, 0xe8, 0x75, 0xa6, 0xb7, 0x95, 0x7c, 0xeb, 0x9d, 0x4e, 0x6f,
		0x0b, 0xdd, 0x42, 0x32, 0x8f, 0x61, 0xac, 0xbe, 0xa9, 0xf0, 0x3f, 0xe5, 0x07, 0x5a, 0x47, 0xf2,
		0xd2, 0x4a, 0xf3, 0xf4, 0x95, 0x2e, 0x75, 0xc9, 0xd8, 0xe8, 0x23, 0xe2, 0x2a, 0x91, 0x45, 0x1f,
		0x91, 0x7c, 0x12, 0x55, 0xf4, 0x11, 0x79, 0xd3, 0xac, 0x91, 0xf5, 0x11, 0xc9, 0x38, 0x49, 0xfa,
		0x08, 0x44, 0xf6, 0x12, 0x68, 0xe3, 0x10, 0x25, 0xc4, 0x21, 0x10, 0x87, 0x40, 0x1c, 0x02, 0x71,
		0x08, 0x77, 0xe2, 0x10, 0x54, 0xee, 0x3f, 0x1d, 0x70, 0xda, 0x35, 0x43, 0x53, 0x47, 0x3f, 0xb6,
		0x33, 0x5d, 0xa5, 0xa6, 0x97, 0x40, 0x6c, 0xba, 0x3c, 0x99, 0x89, 0xe4, 0x70, 0xc0, 0x09, 0x0b,
		0x6e, 0xc0, 0x03, 0x37, 0x4c, 0x38, 0x03, 0x17, 0xce, 0xc0, 0x86, 0x33, 0xf0, 0x41, 0x0b, 0x23,
		0xc4, 0x70, 0x92, 0xce, 0xf2, 0x19, 0x87, 0x83, 0xdf, 0xe6, 0xad, 0xf1, 0x9c, 0x61, 0xfb, 0x75,
		0x86, 0xb1, 0x33, 0xfd, 0x85, 0x9f, 0xc0, 0x2e, 0xa7, 0xb9, 0xd8, 0x84, 0xa6, 0x4d, 0xd4, 0x92,
		0x78, 0xa5, 0x4d, 0x53, 0xc5, 0xb4, 0x19, 0xb5, 0x2b, 0x48, 0x0b, 0x48, 0x0b, 0x48, 0x0b, 0x48,
		0x0b, 0x07, 0x69, 0xa1, 0xd6, 0xc2, 0x8b, 0x9a, 0x78, 0x28, 0x18, 0x8f, 0x69, 0x2e, 0x48, 0xe3,
		0xc9, 0x95, 0x7c, 0xd8, 0xc8, 0xb3, 0x7b, 0x5c, 0xa0, 0xe3, 0x02, 0xf8, 0xb8, 0x05, 0x42, 0xae,
		0x80, 0x91, 0x73, 0xa0, 0xe4, 0x1c, 0x38, 0x39, 0x07, 0x52, 0x3c, 0x60, 0xc5, 0x04, 0x5a, 0xfc,
		0x8a, 0x3b, 0xe3, 0x37, 0xc6, 0x52, 0xe9, 0x52, 0x8d, 0xd3, 0x67, 0xcc, 0x50, 0xa4, 0xc6, 0x78,
		0x09, 0x3c, 0xd5, 0x25, 0x5e, 0xfe, 0xe1, 0xf5, 0x99, 0xdb, 0xdc, 0xd5, 0x27, 0x1c, 0xa3, 0x17,
		0x99, 0xcb, 0x61, 0xae, 0x4e, 0x91, 0xb9, 0x1e, 0x07, 0x2a, 0x06, 0x38, 0xe2, 0x4e, 0x17, 0x4d,
		0x38, 0xb8, 0x83, 0x09, 0xff, 0xc0, 0x84, 0x6b, 0xd5, 0xea, 0x5e, 0x15, 0x66, 0xec, 0x16, 0x17,
		0xe1, 0x1f, 0xbd, 0xbb, 0xb5, 0x19, 0xf7, 0xcb, 0x51, 0x64, 0x87, 0x6f, 0x27, 0x7d, 0x79, 0xd8,
		0x80, 0x61, 0x47, 0x1d, 0x71, 0x03, 0xc4, 0x0d, 0x10, 0x37, 0x40, 0xdc, 0x00, 0x71, 0x83, 0x9c,
		0xc4, 0x0d, 0xf6, 0x1d, 0x08, 0x1b, 0x54, 0x11, 0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d,
		0x10, 0x36, 0xb0, 0x6e, 0xc2, 0xe5, 0x2a, 0x82, 0x06, 0x08, 0x1a, 0x20, 0x68, 0x40, 0x1b, 0x34,
		0xb8, 0x9d, 0xad, 0x3e, 0x17, 0xa2, 0x06, 0xc9, 0xb5, 0x20, 0x6c, 0x80, 0xb0, 0x01, 0xc2, 0x06,
		0x08, 0x1b, 0x20, 0x6c, 0x80, 0xb0, 0xc1, 0x2b, 0xfd, 0xc6, 0xa5, 0x54, 0x41, 0x74, 0xef, 0x40,
		0xdc, 0xa0, 0xc1, 0x78, 0x09, 0x87, 0x42, 0x5d, 0x4f, 0x13, 0xff, 0x11, 0x38, 0x40, 0xe0, 0xe0,
		0x87, 0xaa, 0xab, 0x04, 0xcd, 0x85, 0xc0, 0xc1, 0x7a, 0x9b, 0x30, 0xf2, 0x0d, 0x10, 0x3a, 0x40,
		0xe8, 0x80, 0xd4, 0xcc, 0xc5, 0x9d, 0x16, 0x6a, 0x20, 0x06, 0xfc, 0x81, 0x83, 0xf4, 0x4a, 0x10,
		0x36, 0x40, 0xd8, 0x00, 0x61, 0x03, 0x84, 0x0d, 0x10, 0x36, 0x40, 0xd8, 0xe0, 0xb5, 0x61, 0x03,
		0xf2, 0x32, 0xb8, 0xab, 0x60, 0x84, 0xa8, 0x2c, 0xee, 0x66, 0x92, 0x96, 0x70, 0x34, 0x61, 0xe6,
		0xc1, 0x90, 0x9f, 0xb4, 0xa4, 0x57, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2,
		0x02, 0xd2, 0x02, 0xd2, 0x02, 0xd2, 0x92, 0x9d, 0xe3, 0x51, 0x10, 0x69, 0xe9, 0x02, 0x67, 0x99,
		0x5f, 0x08, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b, 0x28, 0x0b,
		0x28, 0x4b, 0x76, 0x8e, 0x75, 0x14, 0xa8, 0x58, 0x6a, 0x79, 0xeb, 0x40, 0x5e, 0xe9, 0xb3, 0x6b,
		0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x01, 0x71, 0x71, 0x9e,
		0xb8, 0xe4, 0xba, 0xbc, 0x28, 0x71, 0xdf, 0xc5, 0xcc, 0xf8, 0x3c, 0x7d, 0x18, 0xb3, 0xbd, 0xf1,
		0xb2, 0x3f, 0x2a, 0x70, 0x14, 0xb6, 0xde, 0xa6, 0x6f, 0xde, 0x78, 0x9e, 0xdc, 0x78, 0x33, 0x9d,
		0x8a, 0xcc, 0x4f, 0x28, 0xfa, 0x3b, 0xf2, 0xad, 0xba, 0x7c, 0xb5, 0xce, 0xf9, 0x5d, 0xdc, 0x73,
		0xd4, 0xbe, 0xf1, 0x0e, 0x65, 0xac, 0x27, 0x06, 0x43, 0xdb, 0xb7, 0xe7, 0x48, 0xaa, 0x83, 0xa1,
		0x98, 0x10, 0xa3, 0x98, 0x56, 0x58, 0x78, 0x47, 0xc1, 0xdd, 0xb3, 0x91, 0x4b, 0xfb, 0x95, 0x4a,
		0xad, 0x5e, 0xa9, 0x14, 0xeb, 0x7b, 0xf5, 0x62, 0xa3, 0x5a, 0x2d, 0xd5, 0x4a, 0x84, 0x79, 0xc0,
		0x5e, 0x3b, 0x1a, 0x88, 0x48, 0x0c, 0x3e, 0x4f, 0x1e, 0xbd, 0x1a, 0x0f, 0x87, 0xb9, 0xb2, 0x68,
		0x26, 0x84, 0x72, 0x18, 0x99, 0x3c, 0xd2, 0xe6, 0x12, 0x6e, 0x61, 0x91, 0x87, 0x6e, 0xdd, 0xfc,
		0x6b, 0x73, 0x43, 0xba, 0x75, 0x93, 0x77, 0x50, 0x76, 0x61, 0xc5, 0xad, 0x6d, 0x1b, 0xef, 0xad,
		0x35, 0x5a, 0x48, 0x73, 0x9a, 0x96, 0x44, 0xbb, 0xb6, 0x27, 0x86, 0xed, 0x4b, 0x5b, 0x27, 0x07,
		0x68, 0xb8, 0x19, 0x1d, 0x17, 0x63, 0xe5, 0x5e, 0x34, 0x5c, 0xcb, 0x96, 0xd9, 0x11, 0xf9, 0x6d,
		0x1e, 0x7f, 0x6d, 0xd1, 0x39, 0xd3, 0x3a, 0x65, 0x3b, 0x2e, 0xd8, 0xbc, 0x83, 0x34, 0xfb, 0x89,
		0x86, 0x6d, 0xde, 0xb6, 0xad, 0x53, 0xdb, 0xb8, 0x05, 0xeb, 0xa6, 0xb2, 0x6a, 0xb3, 0xf6, 0x6c,
		0xce, 0xea, 0xcc, 0x7c, 0x92, 0x21, 0xbb, 0xb5, 0x65, 0xaf, 0x64, 0x76, 0x6a, 0xd0, 0x40, 0xad,
		0x1b, 0xa6, 0x19, 0x8b, 0x7c, 0xbf, 0xfd, 0x18, 0xb0, 0x1d, 0x6f, 0xfe, 0x3c, 0xfc, 0x60, 0x30,
		0x88, 0x44, 0x1c, 0x1b, 0xb3, 0x9e, 0x74, 0xd3, 0x29, 0x33, 0x82, 0x21, 0x8b, 0x37, 0x9b, 0x90,
		0x60, 0x3c, 0xc1, 0xc0, 0x46, 0xc2, 0x80, 0xdd, 0x04, 0x00, 0x5b, 0x1b, 0xfa, 0xd6, 0x37, 0xe8,
		0xad, 0x6f, 0xb8, 0x5b, 0xdf, 0x40, 0x77, 0x0b, 0x4b, 0x8c, 0x6f, 0x58, 0x5b, 0xec, 0x60, 0x6c,
		0xa3, 0x33, 0x71, 0xb6, 0xe3, 0x70, 0xc6, 0x87, 0xe5, 0x08, 0x01, 0xcc, 0x36, 0x00, 0xb6, 0xd2,
		0xd8, 0xd7, 0x70, 0xc3, 0x5e, 0xf8, 0x7a, 0xf8, 0x7a, 0xf8, 0xfa, 0xe4, 0x6e, 0x4d, 0x37, 0x88,
		0xb5, 0x47, 0x28, 0xa9, 0x88, 0xa5, 0x25, 0x82, 0x69, 0xcd, 0xf9, 0xd8, 0x74, 0x42, 0x34, 0xce,
		0xc8, 0xb6, 0x53, 0x22, 0x73, 0x4e, 0x64, 0x4e, 0x8a, 0xcc, 0x59, 0xad, 0x47, 0xb0, 0xce, 0x5a,
		0x86, 0x65, 0x6a, 0xf7, 0x72, 0x64, 0xc9, 0xcb, 0x2c, 0xd0, 0x1b, 0x0b, 0xe5, 0x36, 0xe7, 0x73,
		0x63, 0xa7, 0x88, 0xa6, 0xc5, 0x4d, 0x80, 0xa7, 0x99, 0xbf, 0xad, 0x58, 0x9c, 0xfb, 0xcc, 0x33,
		0xd8, 0xb7, 0x38, 0xc6, 0x49, 0xa0, 0xb5, 0x88, 0x94, 0xf5, 0x9a, 0xa6, 0xde, 0xce, 0xce, 0x45,
		0xd1, 0x6f, 0x74, 0x1f, 0x2e, 0x4a, 0x7e, 0xa3, 0x9b, 0xbc, 0x2c, 0x4d, 0xbf, 0x25, 0xaf, 0xcb,
		0x17, 0x45, 0xbf, 0x32, 0x7f, 0x5d, 0xbd, 0x28, 0xfa, 0xd5, 0xee, 0xee, 0x5f, 0x7f, 0x7d, 0xdc,
		0xfd, 0xbe, 0xf7, 0xf8, 0xfa, 0x37, 0xda, 0xdb, 0xf2, 0xed, 0xda, 0x7c, 0x14, 0xed, 0xd3, 0xd6,
		0x9f, 0x64, 0xcf, 0xe3, 0xef, 0xff, 0x67, 0xef, 0xdd, 0x9f, 0xda, 0xd8, 0x95, 0xfd, 0xd1, 0xdf,
		0xf3, 0x57, 0x50, 0xae, 0x53, 0x75, 0x93, 0x73, 0x96, 0x03, 0x7e, 0x60, 0x20, 0x55, 0xb7, 0x76,
		0x11, 0x30, 0xd9, 0xbe, 0xcb, 0x60, 0x17, 0x76, 0x92, 0xb5, 0xbf, 0x09, 0x87, 0x92, 0x67, 0x64,
		0x5b, 0x95, 0x79, 0xad, 0x91, 0xcc, 0xe3, 0xae, 0xf0, 0xbf, 0x7f, 0xcb, 0x6f, 0x83, 0x31, 0x8c,
		0x34, 0xd2, 0x4c, 0x0b, 0xf7, 0xaa, 0x7d, 0x0e, 0xe0, 0x78, 0x66, 0x34, 0x52, 0xbf, 0xfb, 0xd3,
		0xdd, 0x59, 0x1e, 0xc8, 0x7f, 0x19, 0x3c, 0x11, 0x9b, 0xf2, 0x95, 0xd9, 0x08, 0xa7, 0x1a, 0x0a,
		0x27, 0x25, 0xe1, 0x44, 0x8a, 0xfd, 0xe3, 0xe2, 0xd9, 0xd5, 0x3f, 0xa5, 0x3f, 0xaa, 0x0f, 0x9f,
		0x3e, 0xfc, 0x73, 0xf0, 0xf0, 0xf4, 0xc3, 0xdf, 0xcf, 0x7d, 0xad, 0xf4, 0xc7, 0xc1, 0xc3, 0xa7,
		0x0d, 0xff, 0x52, 0x7b, 0xf8, 0x94, 0xf0, 0x1e, 0xfb, 0x0f, 0xef, 0xd7, 0xbe, 0x3a, 0xfe, 0xbc,
		0xbc, 0xe9, 0x82, 0xea, 0x86, 0x0b, 0x2a, 0x9b, 0x2e, 0xa8, 0x6c, 0xb8, 0x60, 0xe3, 0x92, 0xca,
		0x1b, 0x2e, 0xd8, 0x7f, 0xf8, 0xbd, 0xf6, 0xfd, 0xf7, 0xcf, 0x7f, 0xb5, 0xf6, 0xf0, 0xe1, 0xf7,
		0xa6, 0x7f, 0x3b, 0x78, 0xf8, 0xfd, 0xe9, 0x03, 0x8a, 0xea, 0xe4, 0xa2, 0x1a, 0xc9, 0x33, 0x7b,
		0xf2, 0xb4, 0x4f, 0x71, 0xbd, 0x83, 0xbd, 0x4e, 0x4c, 0x76, 0xcb, 0xdd, 0xd7, 0x58, 0xb2, 0x5b,
		0x77, 0x31, 0x90, 0x91, 0x14, 0xb7, 0xc6, 0x3a, 0x1d, 0x0d, 0x99, 0x8d, 0x77, 0x39, 0x12, 0xda,
		0x1c, 0x60, 0xa9, 0x39, 0xc2, 0xa8, 0x17, 0x4a, 0xa9, 0x1f, 0x32, 0x99, 0x09, 0x34, 0x52, 0x2f,
		0x04, 0x32, 0xed, 0x41, 0x6b, 0x96, 0x24, 0xc6, 0x24, 0x48, 0x41, 0x4b, 0xa2, 0x4f, 0xbb, 0xcc,
		0x48, 0x27, 0x2d, 0xd4, 0x79, 0x5c, 0xed, 0x4a, 0x45, 0x62, 0xd1, 0x45, 0x24, 0xba, 0x89, 0x23,
		0x05, 0x4d, 0x68, 0xa4, 0x05, 0x35, 0x12, 0x90, 0x3f, 0x40, 0xb9, 0x2b, 0x24, 0x8f, 0x3a, 0xed,
		0x11, 0xeb, 0x39, 0x5a, 0x85, 0x03, 0x4d, 0x7d, 0x90, 0x72, 0xc7, 0x97, 0xfc, 0x10, 0x24, 0x0e,
		0x40, 0x11, 0x81, 0x90, 0x0a, 0x69, 0xa0, 0x88, 0x28, 0x58, 0x26, 0xef, 0xca, 0x92, 0x17, 0xa6,
		0x48, 0xce, 0xe9, 0x49, 0xbe, 0xa5, 0x4d, 0xae, 0x69, 0x4b, 0x9e, 0x69, 0x4b, 0x8e, 0x69, 0x4b,
		0x7e, 0x99, 0x15, 0x2d, 0xaa, 0x19, 0xf6, 0xc2, 0x5c, 0x46, 0x14, 0x67, 0xdc, 0xad, 0x78, 0x6e,
		0x8b, 0xd1, 0xa4, 0x8f, 0x6e, 0xa7, 0xb8, 0xe5, 0xe9, 0x72, 0xe2, 0xa9, 0x73, 0xdf, 0x3a, 0x72,
		0xdc, 0x7a, 0x73, 0xd9, 0xba, 0x72, 0xd6, 0xda, 0x73, 0xd3, 0xda, 0x73, 0xd0, 0xda, 0x73, 0xcd,
		0xd9, 0x1a, 0x71, 0xa9, 0x73, 0xc4, 0xcb, 0xa0, 0xbf, 0x4b, 0x03, 0xc1, 0xc4, 0x7d, 0x3a, 0x20,
		0xe3, 0x42, 0x03, 0xa5, 0xf0, 0xa9, 0x0a, 0x8d, 0xd9, 0x52, 0x3e, 0x13, 0xae, 0x81, 0x04, 0xe7,
		0x2f, 0x78, 0x7c, 0xd6, 0xb8, 0xee, 0x8c, 0xff, 0x5f, 0xf7, 0x3f, 0xed, 0x7a, 0x5a, 0x32, 0x9c,
		0x4c, 0x37, 0xe3, 0x5a, 0xe2, 0xb6, 0x9a, 0x11, 0x8a, 0x9d, 0xcb, 0x6e, 0xfd, 0xba, 0xdd, 0x6a,
		0x36, 0x4e, 0xfe, 0x73, 0xdd, 0x68, 0x7f, 0xab, 0x15, 0x20, 0xc0, 0x31, 0x35, 0xbf, 0x63, 0xb3,
		0xf2, 0xad, 0x7d, 0x31, 0x7e, 0xbb, 0xea, 0xf5, 0xd7, 0x8b, 0xc6, 0xc9, 0x71, 0xa7, 0xfb, 0x26,
		0xdf, 0xb2, 0x71, 0xf1, 0x67, 0xa7, 0x7b, 0xdc, 0xad, 0x5f, 0x77, 0xda, 0x67, 0x6f, 0xfc, 0x18,
		0xcf, 0xbf, 0x36, 0xbb, 0x6f, 0xf6, 0x20, 0xbf, 0xb5, 0x2f, 0xbe, 0x55, 0xaf, 0xcf, 0x9a, 0xad,
		0xef, 0x9d, 0x76, 0xfd, 0xe4, 0x2d, 0xbe, 0xe1, 0x13, 0xa1, 0x53, 0x7d, 0x93, 0xd4, 0x5a, 0x1e,
		0x53, 0xeb, 0xb7, 0x76, 0xb3, 0xf3, 0x76, 0xdf, 0xae, 0xfe, 0xad, 0x7d, 0xf1, 0xa6, 0x45, 0xe9,
		0x5b, 0x7c, 0xb9, 0x89, 0x00, 0x6d, 0x1e, 0x7f, 0xae, 0x37, 0xeb, 0xa7, 0xdb, 0xa1, 0x0f, 0xdf,
		0x2a, 0x95, 0xce, 0xf5, 0x61, 0xed, 0x6d, 0xeb, 0xc3, 0x09, 0xc1, 0xbe, 0x65, 0x75, 0x38, 0x39,
		0xc2, 0x6d, 0xe0, 0xc8, 0x25, 0xc1, 0xbe, 0xe1, 0xb7, 0x7c, 0xeb, 0x7e, 0x86, 0xe6, 0xf3, 0x4b,
		0x75, 0x87, 0xab, 0xac, 0xe3, 0x2e, 0x98, 0xb1, 0x99, 0x66, 0x6c, 0x54, 0xb1, 0x1c, 0x6a, 0xa9,
		0x1a, 0x05, 0x50, 0x86, 0x44, 0x92, 0xe6, 0x9d, 0xc6, 0x93, 0x59, 0x34, 0x0f, 0x55, 0x88, 0x33,
		0xab, 0x21, 0x23, 0xd4, 0x11, 0x10, 0x5a, 0x91, 0x0e, 0x6a, 0x88, 0x86, 0xa4, 0xbb, 0xaa, 0x48,
		0xe7, 0xca, 0xf4, 0x5d, 0x90, 0x4a, 0xdc, 0xc9, 0x53, 0x74, 0x32, 0x5a, 0x7e, 0x9d, 0x32, 0x5f,
		0xfe, 0xc6, 0x2b, 0xbb, 0x2b, 0xbb, 0xab, 0xb2, 0xbb, 0x99, 0x60, 0x13, 0xa5, 0x36, 0xef, 0xe5,
		0x4d, 0xdb, 0xbc, 0x15, 0x2f, 0x6c, 0xc3, 0xb4, 0xc9, 0x2f, 0xa7, 0xe2, 0xf5, 0x0a, 0xcd, 0x65,
		0x0a, 0x69, 0x71, 0xc9, 0x2b, 0xdb, 0x9b, 0x2c, 0xbb, 0x9a, 0x38, 0x1d, 0x24, 0x93, 0xf6, 0x51,
		0x4b, 0xef, 0xc8, 0xa6, 0x71, 0x94, 0xd3, 0x35, 0xca, 0x69, 0x19, 0xe5, 0xf4, 0x4b, 0x3a, 0x46,
		0x49, 0x9a, 0xbd, 0x5c, 0xd0, 0x46, 0xf2, 0x2d, 0x7c, 0x4a, 0x55, 0x49, 0x77, 0x50, 0x2e, 0x75,
		0x2f, 0x9d, 0x73, 0x54, 0xc9, 0x31, 0xa6, 0xcb, 0x29, 0xaa, 0xe6, 0x10, 0x53, 0xe7, 0x0c, 0x53,
		0xe7, 0x08, 0x53, 0xe7, 0x04, 0xf5, 0x5a, 0x20, 0xb2, 0xa9, 0xf6, 0x02, 0x19, 0x0c, 0x62, 0x3a,
		0x20, 0x22, 0x8c, 0xd5, 0xe1, 0x27, 0x2b, 0xf7, 0xc8, 0x18, 0x83, 0xb2, 0x87, 0x18, 0x14, 0xc4,
		0xa0, 0x18, 0x61, 0x8c, 0x15, 0x23, 0x25, 0x4d, 0x73, 0x18, 0x2d, 0xcd, 0x60, 0x52, 0x36, 0x7f,
		0x51, 0x86, 0x6c, 0xe9, 0x60, 0x1b, 0xbd, 0xec, 0xa3, 0x8b, 0x8d, 0xb4, 0xb3, 0x93, 0x76, 0xb6,
		0xd2, 0xce, 0x5e, 0x29, 0x63, 0x1f, 0x8a, 0x94, 0x93, 0xb6, 0xb9, 0x4a, 0x41, 0x57, 0x0f, 0x95,
		0xa5, 0xb2, 0xd2, 0x53, 0xc8, 0xa0, 0xa7, 0x35, 0x8a, 0xb6, 0x56, 0x28, 0x3a, 0x5b, 0x9f, 0x98,
		0x69, 0x75, 0xa2, 0xbb, 0xb5, 0x89, 0xb1, 0x56, 0x26, 0xc6, 0x5a, 0x97, 0x18, 0x6b, 0x55, 0x92,
		0x6f, 0xa5, 0x90, 0xb6, 0xd6, 0x23, 0xa6, 0x1a, 0x5e, 0xe8, 0xac, 0x1d, 0xd7, 0x5e, 0x23, 0x6e,
		0x59, 0xa3, 0x8a, 0x2b, 0x1d, 0x5b, 0x68, 0xa2, 0x9a, 0xd9, 0xba, 0x06, 0x13, 0x57, 0x79, 0x15,
		0x0e, 0xa5, 0xb0, 0xba, 0x88, 0x4e, 0x3d, 0x8c, 0x2a, 0x18, 0x55, 0x30, 0xaa, 0x60, 0xa0, 0x2a,
		0x98, 0xf0, 0x62, 0x30, 0xf2, 0x7b, 0x34, 0xd6, 0xa8, 0x7f, 0x35, 0xf4, 0xa7, 0x2d, 0x5c, 0x92,
		0x60, 0xa0, 0xaf, 0x99, 0x97, 0xc6, 0xc2, 0xf9, 0x73, 0x16, 0x18, 0x68, 0x25, 0x6a, 0xa6, 0xff,
		0xe2, 0x04, 0x90, 0x6e, 0xe0, 0xbe, 0x67, 0x31, 0x71, 0x04, 0x0b, 0x83, 0x53, 0x36, 0x60, 0xd3,
		0x7c, 0xa4, 0xbe, 0xee, 0x0b, 0x1a, 0x3b, 0x07, 0x9c, 0x93, 0x3b, 0xeb, 0x8e, 0xaa, 0x5a, 0x3e,
		0xaa, 0x1e, 0xd5, 0x0e, 0xca, 0x47, 0xfb, 0x16, 0x9d, 0x19, 0x90, 0x46, 0x0a, 0x76, 0x5a, 0x5a,
		0x55, 0x9d, 0xa6, 0x56, 0x15, 0x6d, 0x2d, 0xb4, 0xb5, 0xd0, 0xd6, 0x42, 0x5b, 0x0b, 0x6d, 0x2d,
		0xb4, 0xb5, 0xd0, 0xd6, 0x42, 0x5b, 0xeb, 0xcd, 0xd9, 0x5a, 0x6f, 0xb9, 0x1d, 0xce, 0x1c, 0x73,
		0xb6, 0xf8, 0x6d, 0x77, 0x89, 0xb8, 0x48, 0xdd, 0x58, 0x2d, 0x19, 0x0a, 0x4f, 0x88, 0xb8, 0x43,
		0x05, 0x9f, 0xff, 0x72, 0x7d, 0xbc, 0x58, 0x40, 0x9a, 0xa6, 0x69, 0x5b, 0x8a, 0xa8, 0x7e, 0xe9,
		0x3c, 0x8d, 0xc1, 0xaa, 0x37, 0x9f, 0x20, 0x84, 0x06, 0x38, 0x84, 0x17, 0x67, 0xdb, 0xa6, 0x8a,
		0x41, 0x9a, 0xdd, 0x00, 0x01, 0x48, 0x66, 0xfd, 0x12, 0x04, 0x20, 0x29, 0xca, 0x16, 0xf5, 0x26,
		0x38, 0xbc, 0xc8, 0xe9, 0x60, 0xf6, 0x82, 0x69, 0x3b, 0xe0, 0x2c, 0xef, 0x95, 0x33, 0x14, 0x09,
		0xdb, 0xdf, 0x98, 0x76, 0xf0, 0x11, 0x8a, 0xa4, 0x87, 0x01, 0x57, 0xd4, 0xac, 0x8e, 0x31, 0x71,
		0x5a, 0xc7, 0xc3, 0x69, 0x1a, 0x0b, 0x97, 0x1a, 0x21, 0x88, 0x71, 0x39, 0x8c, 0xcb, 0xe5, 0x1c,
		0x97, 0xd3, 0x35, 0xc6, 0xad, 0xe0, 0xd3, 0x49, 0x2c, 0x4e, 0xfb, 0x38, 0xc8, 0xd9, 0x7d, 0x71,
		0xf6, 0x2f, 0x2c, 0x81, 0x60, 0x4a, 0x30, 0x18, 0x17, 0x10, 0xc6, 0x05, 0x85, 0x71, 0x81, 0xa1,
		0x39, 0x78, 0x05, 0x7e, 0xf6, 0xaf, 0xce, 0x40, 0xff, 0x53, 0x41, 0xa0, 0x73, 0xf8, 0xaf, 0xde,
		0xc0, 0xff, 0xfc, 0x3f, 0x03, 0xb3, 0xe9, 0x4c, 0x24, 0x02, 0x0c, 0x49, 0xd8, 0xb5, 0xdb, 0x1b,
		0x4a, 0x0c, 0x2c, 0xee, 0x6f, 0x30, 0xd8, 0xac, 0x99, 0xe3, 0x1e, 0x1f, 0x29, 0xb9, 0xb3, 0xfe,
		0x48, 0x4d, 0x25, 0x10, 0x32, 0x3d, 0x5b, 0xa0, 0x63, 0x58, 0xae, 0x40, 0xe9, 0x0a, 0xad, 0xe3,
		0x2c, 0x56, 0xc5, 0x9a, 0xde, 0xb1, 0x16, 0xab, 0xdc, 0x65, 0x7c, 0xbc, 0xc5, 0xe2, 0x61, 0x5a,
		0xc7, 0x5c, 0xe8, 0xa3, 0x24, 0x1d, 0x13, 0xe3, 0x85, 0x4e, 0x1b, 0x61, 0x61, 0x1f, 0x4c, 0xee,
		0x8a, 0xfe, 0x01, 0xfa, 0x07, 0xe8, 0x1f, 0x6c, 0xab, 0x7f, 0x10, 0x11, 0x31, 0x9c, 0x87, 0xe8,
		0x8b, 0x1a, 0xe5, 0xc1, 0xaa, 0x4c, 0x28, 0x55, 0x35, 0xde, 0xb3, 0x1e, 0x8c, 0xfc, 0xf1, 0x6e,
		0x3c, 0xe0, 0xd4, 0xac, 0xfc, 0x86, 0x29, 0x3d, 0x93, 0x50, 0x9e, 0x92, 0xd2, 0xee, 0x32, 0xe1,
		0xa3, 0x6d, 0x02, 0x9b, 0x62, 0xba, 0x99, 0xb7, 0x89, 0x18, 0x5e, 0x1f, 0xf3, 0xce, 0x74, 0x39,
		0x3a, 0x66, 0xad, 0xd9, 0x02, 0x17, 0xd1, 0x62, 0x25, 0xea, 0xb3, 0x0a, 0x8d, 0x5a, 0x81, 0x7a,
		0xac, 0x3e, 0x7b, 0x81, 0x39, 0x6b, 0x7c, 0x97, 0x3d, 0x34, 0xe7, 0x09, 0xa7, 0x21, 0x34, 0x47,
		0xc7, 0x89, 0x66, 0x87, 0xcb, 0x99, 0x1c, 0x1f, 0x0c, 0x4c, 0x4e, 0x35, 0x35, 0x28, 0xa7, 0x8a,
		0xa8, 0x9c, 0x2c, 0x9c, 0x0b, 0x44, 0xe5, 0x28, 0x8a, 0x95, 0x14, 0xa8, 0x9c, 0xaa, 0x4e, 0x58,
		0x4e, 0x15, 0x71, 0x39, 0x88, 0xcb, 0x81, 0xe2, 0x7f, 0x23, 0x2e, 0x07, 0x71, 0x39, 0x59, 0x87,
		0xd9, 0x10, 0x97, 0x83, 0xb8, 0x9c, 0x97, 0x6f, 0x84, 0xb8, 0x1c, 0x1d, 0x37, 0xc4, 0xb8, 0xbb,
		0x69, 0x01, 0x61, 0x5c, 0x50, 0x18, 0x17, 0x18, 0xfa, 0xa2, 0xb1, 0x3b, 0x88, 0xcb, 0x41, 0x5c,
		0x8e, 0xe6, 0x9b, 0x23, 0x2e, 0x27, 0x23, 0x8e, 0x7b, 0x7c, 0xa4, 0x88, 0xcb, 0x81, 0x71, 0xb6,
		0x88, 0xcb, 0x49, 0x70, 0x10, 0x88, 0xcb, 0x79, 0xe1, 0x61, 0x88, 0xcb, 0x91, 0xb4, 0x0f, 0x10,
		0x97, 0x83, 0xfe, 0x01, 0xfa, 0x07, 0x5b, 0xed, 0x1f, 0x20, 0x2e, 0xc7, 0xea, 0x20, 0x14, 0x20,
		0x5c, 0x4e, 0x75, 0x0e, 0x10, 0xa8, 0x82, 0x41, 0xe6, 0x54, 0x67, 0x80, 0x81, 0x2a, 0x62, 0x73,
		0xf2, 0xb6, 0x0c, 0x11, 0x9b, 0x93, 0x2d, 0xef, 0xe5, 0x80, 0xce, 0x79, 0xca, 0x6d, 0x88, 0xcf,
		0xd1, 0x72, 0xaa, 0x19, 0x02, 0x74, 0xaa, 0x50, 0x10, 0x3a, 0x2c, 0x70, 0xe9, 0x9d, 0x3a, 0x3c,
		0x67, 0x7a, 0xb9, 0x1a, 0x36, 0x67, 0x0f, 0xb1, 0x39, 0x59, 0x3b, 0x12, 0xdb, 0x86, 0xcd, 0x51,
		0x36, 0xe8, 0x17, 0xe7, 0xee, 0x51, 0xd2, 0x8f, 0x69, 0x5f, 0xe5, 0xd0, 0xe7, 0x36, 0xb9, 0x42,
		0xfc, 0xbe, 0xd0, 0x9e, 0x49, 0xb1, 0x8f, 0x1f, 0xa7, 0xa6, 0xdd, 0xee, 0x94, 0xd1, 0x00, 0x08,
		0x0c, 0x35, 0xa8, 0x44, 0x2a, 0x68, 0x44, 0x6a, 0x30, 0x5f, 0x19, 0x05, 0x06, 0x0a, 0x8c, 0x44,
		0xab, 0x54, 0x07, 0xf3, 0xb1, 0x41, 0xa4, 0x01, 0xc5, 0xc7, 0x94, 0x03, 0x5b, 0x29, 0xc3, 0x82,
		0x08, 0xdf, 0xcb, 0x2e, 0x8c, 0x87, 0xf0, 0x3d, 0xcd, 0x61, 0xb7, 0x05, 0xdd, 0x8c, 0x58, 0x20,
		0x6a, 0x69, 0x3a, 0xd5, 0xcf, 0xb9, 0x28, 0xc5, 0x9c, 0x2f, 0x4d, 0x39, 0x76, 0x0d, 0x21, 0x26,
		0x9d, 0x39, 0x74, 0xdd, 0x59, 0x07, 0xcd, 0x39, 0x72, 0x13, 0x79, 0x53, 0x1d, 0xd9, 0x24, 0x9d,
		0x39, 0x6f, 0x53, 0x47, 0x60, 0x2e, 0x57, 0x68, 0xe4, 0x54, 0x72, 0x8a, 0x29, 0x5e, 0x65, 0x15,
		0x63, 0x51, 0xb0, 0x16, 0x89, 0x08, 0x7d, 0xe6, 0x14, 0xe7, 0x2d, 0x80, 0x35, 0xcc, 0x1a, 0x5e,
		0xbb, 0x23, 0x1a, 0x25, 0x68, 0x94, 0xa0, 0x51, 0xa2, 0x44, 0x37, 0xbd, 0x30, 0xf4, 0x28, 0x09,
		0x34, 0x58, 0x25, 0xa5, 0x12, 0x60, 0x21, 0xe4, 0x78, 0x23, 0x2e, 0x68, 0x5c, 0xf4, 0x18, 0xd7,
		0x50, 0xcf, 0xf4, 0xe8, 0x6e, 0x28, 0x7c, 0x50, 0xf8, 0xa0, 0xf0, 0x51, 0xa2, 0x1b, 0x4d, 0x83,
		0x90, 0x75, 0x0c, 0x40, 0xd6, 0x36, 0xf8, 0xd8, 0x92, 0x81, 0xc7, 0x57, 0x69, 0xb6, 0x4a, 0xe7,
		0x80, 0x63, 0x6b, 0x06, 0x1b, 0x5f, 0x61, 0xde, 0x1e, 0x76, 0xde, 0x3e, 0x13, 0x43, 0x42, 0x2d,
		0x25, 0xb9, 0x2e, 0xf9, 0x14, 0x52, 0x93, 0x68, 0x3a, 0xa0, 0xe9, 0x80, 0xa6, 0x03, 0x06, 0x53,
		0x31, 0x98, 0x8a, 0xc1, 0x54, 0x0c, 0xa6, 0x6e, 0x67, 0x30, 0xd5, 0x0b, 0x1d, 0xe2, 0x15, 0xc7,
		0xba, 0x29, 0xbd, 0x0d, 0xb2, 0x72, 0x2f, 0x34, 0x44, 0xd0, 0x10, 0x41, 0x43, 0x44, 0xd9, 0x10,
		0xa9, 0x94, 0x35, 0x18, 0x22, 0x07, 0x68, 0x88, 0xa0, 0x21, 0xb2, 0x25, 0x86, 0x88, 0xee, 0x4a,
		0x65, 0x34, 0x3f, 0xb2, 0x31, 0x3f, 0x7c, 0xea, 0xa6, 0xb7, 0x3b, 0xc6, 0x37, 0x41, 0x83, 0x03,
		0x0d, 0x0e, 0x34, 0x38, 0xd0, 0xe0, 0x40, 0x83, 0x03, 0x0d, 0x0e, 0x34, 0x38, 0xd0, 0xe0, 0xd8,
		0xb4, 0xcd, 0x01, 0xbd, 0x13, 0xc5, 0x61, 0xa8, 0x01, 0xbd, 0xbe, 0xb8, 0x13, 0x9a, 0x1e, 0x68,
		0x7a, 0xa0, 0xe9, 0xa1, 0x44, 0x37, 0x2c, 0xd2, 0x89, 0xd6, 0x38, 0x4a, 0x71, 0x8f, 0xd9, 0x3b,
		0xe5, 0x6e, 0x7e, 0x68, 0x46, 0xb2, 0xac, 0xed, 0xd1, 0xa1, 0x86, 0x7b, 0xe9, 0x42, 0x6a, 0x2c,
		0x6e, 0x68, 0x07, 0xc2, 0x65, 0xa1, 0xde, 0x74, 0x6c, 0xa1, 0x4e, 0xc4, 0xcb, 0xe2, 0xae, 0xb6,
		0x20, 0x5f, 0xd2, 0x19, 0x0a, 0x9a, 0x4c, 0x4d, 0xbd, 0xcc, 0x5a, 0xdb, 0x32, 0x66, 0x25, 0xc5,
		0xfe, 0x71, 0xf1, 0xec, 0xea, 0x9f, 0xd2, 0x1f, 0xd5, 0x87, 0x4f, 0x1f, 0xfe, 0x39, 0x78, 0x78,
		0xfa, 0xe1, 0xef, 0xe7, 0xbe, 0x56, 0xfa, 0xe3, 0xe0, 0xe1, 0xd3, 0x86, 0x7f, 0xa9, 0x3d, 0x7c,
		0x4a, 0x78, 0x8f, 0xfd, 0x87, 0xf7, 0x6b, 0x5f, 0x1d, 0x7f, 0x5e, 0xde, 0x74, 0x41, 0x75, 0xc3,
		0x05, 0x95, 0x4d, 0x17, 0x54, 0x36, 0x5c, 0xb0, 0x71, 0x49, 0xe5, 0x0d, 0x17, 0xec, 0x3f, 0xfc,
		0x5e, 0xfb, 0xfe, 0xfb, 0xe7, 0xbf, 0x5a, 0x7b, 0xf8, 0xf0, 0x7b, 0xd3, 0xbf, 0x1d, 0x3c, 0xfc,
		0xfe, 0xf4, 0x61, 0x1b, 0x44, 0x17, 0x92, 0x55, 0xf6, 0x64, 0x95, 0xbf, 0x20, 0x7f, 0x93, 0x9e,
		0x66, 0x18, 0xb3, 0x41, 0x8a, 0x58, 0xd2, 0xd2, 0xb7, 0x9a, 0xde, 0x07, 0xbd, 0x4c, 0xf4, 0x32,
		0xd1, 0xcb, 0x54, 0xa2, 0x9b, 0xde, 0x20, 0x2a, 0x4e, 0xb9, 0xa8, 0x38, 0xe9, 0x82, 0x94, 0xb2,
		0x1d, 0xa1, 0x8e, 0xf6, 0x83, 0x29, 0xdb, 0x0d, 0x66, 0x29, 0xc1, 0x88, 0x08, 0xe3, 0x22, 0x73,
		0x75, 0x09, 0xb2, 0xf9, 0xed, 0x50, 0x9e, 0xa1, 0x3c, 0x43, 0x79, 0x96, 0x67, 0x6c, 0x08, 0xab,
		0x9c, 0x32, 0x75, 0xa0, 0xb0, 0xca, 0xc9, 0xac, 0x82, 0x7b, 0x9b, 0xdd, 0x1a, 0x55, 0x5b, 0xdd,
		0xaa, 0xb5, 0x6a, 0x54, 0xe8, 0x63, 0x6b, 0xa6, 0xef, 0x9a, 0x18, 0x05, 0x01, 0xf5, 0x8a, 0x34,
		0x70, 0x48, 0xc4, 0x47, 0x9e, 0xda, 0xce, 0x2f, 0xfb, 0xd1, 0x3f, 0x77, 0x37, 0xec, 0xca, 0x66,
		0xd6, 0xb0, 0xc0, 0xae, 0x6c, 0x8a, 0xb2, 0x46, 0xb9, 0x2b, 0xdb, 0x94, 0xcc, 0x79, 0x7a, 0x4b,
		0x7d, 0x7e, 0x23, 0x1c, 0xad, 0x8a, 0x36, 0xfa, 0x56, 0xd9, 0xe8, 0xa9, 0x47, 0xab, 0x4e, 0x39,
		0x47, 0xdf, 0x6c, 0xd5, 0xd9, 0xfd, 0x80, 0x0d, 0x57, 0xdd, 0xc3, 0xe1, 0xaa, 0x39, 0x33, 0xae,
		0x31, 0x06, 0x36, 0xc6, 0xc8, 0xe9, 0x18, 0x3a, 0x25, 0x63, 0x6b, 0x63, 0xf0, 0x15, 0xf3, 0x5a,
		0xc7, 0x0c, 0xe5, 0x35, 0x2a, 0xd6, 0x35, 0xd9, 0x42, 0x23, 0xdb, 0xa7, 0x36, 0x65, 0xb3, 0x10,
		0x03, 0x66, 0xc5, 0x81, 0x29, 0xb1, 0x60, 0x5c, 0x3c, 0x18, 0x17, 0x13, 0xc6, 0xc5, 0x85, 0x1e,
		0xb1, 0xa1, 0x49, 0x7c, 0x68, 0x17, 0x23, 0x4b, 0xbb, 0x41, 0xf7, 0x2c, 0xa6, 0x1d, 0x43, 0xf3,
		0xd8, 0x9e, 0x0a, 0x17, 0xcd, 0x23, 0x28, 0xb5, 0xcf, 0x67, 0x33, 0x29, 0x6c, 0xb2, 0x11, 0x3a,
		0xa6, 0x85, 0x4f, 0x66, 0x42, 0x28, 0x33, 0x61, 0x94, 0x99, 0x50, 0xd2, 0x2b, 0x9c, 0x34, 0x0b,
		0xa9, 0xc5, 0x2e, 0x74, 0x4d, 0xc8, 0x96, 0x47, 0x74, 0xcf, 0x5c, 0x1a, 0x08, 0x26, 0xee, 0xd5,
		0x2b, 0xff, 0x13, 0xd9, 0x31, 0x06, 0xa6, 0xd0, 0x16, 0x1a, 0xb3, 0xa5, 0x7f, 0x26, 0xdc, 0x20,
		0x6b, 0xcd, 0x37, 0xaa, 0xfb, 0xf5, 0xe2, 0xa2, 0xde, 0xbc, 0xae, 0x5f, 0x9c, 0x1c, 0xb7, 0x3b,
		0x5f, 0x9b, 0xc7, 0xdd, 0x46, 0xeb, 0xe2, 0xba, 0xfb, 0x9f, 0x76, 0xbd, 0x60, 0x72, 0x92, 0x2f,
		0xd7, 0x3e, 0x02, 0x7b, 0xf5, 0xbf, 0x7f, 0x8c, 0xdd, 0xf9, 0xd1, 0xd6, 0x75, 0x2e, 0xbb, 0xf5,
		0xeb, 0x76, 0xab, 0xd9, 0x38, 0xf9, 0xcf, 0xf5, 0x74, 0x1b, 0x0b, 0xc6, 0x1e, 0xfc, 0x60, 0xe4,
		0xce, 0x57, 0x5b, 0x33, 0xdb, 0x18, 0x96, 0xb1, 0xa6, 0x79, 0x96, 0xe1, 0xd2, 0x05, 0x54, 0xcd,
		0xe9, 0x3c, 0x97, 0x8e, 0x98, 0x7d, 0xc8, 0x67, 0x3f, 0x77, 0x75, 0x3a, 0x82, 0x3b, 0xca, 0xf9,
		0xa0, 0xee, 0x64, 0x31, 0xf5, 0xd5, 0x85, 0xce, 0x3e, 0xe3, 0xb3, 0x9f, 0x3a, 0x46, 0x1f, 0xea,
		0x23, 0x1b, 0x1d, 0xd5, 0x87, 0x7c, 0xd4, 0x13, 0xde, 0x0d, 0x37, 0xe0, 0xdb, 0xcf, 0x6e, 0x0c,
		0xdc, 0xbb, 0xc7, 0xc1, 0xc8, 0xe8, 0xdd, 0xa3, 0x77, 0xaf, 0x57, 0x53, 0x4c, 0x38, 0xdf, 0x9c,
		0x7f, 0x3f, 0xbb, 0xbf, 0x19, 0x0f, 0xbf, 0x84, 0x1e, 0x3e, 0x7a, 0xf8, 0xe8, 0xe1, 0x43, 0xf6,
		0xf0, 0x75, 0x0b, 0xac, 0xc5, 0x8d, 0x63, 0xea, 0x87, 0x82, 0x16, 0x69, 0xe0, 0x46, 0x21, 0x9b,
		0x76, 0x6a, 0x36, 0xec, 0x21, 0xaf, 0x3d, 0xd1, 0x10, 0xe1, 0x98, 0x11, 0x6e, 0xc6, 0x85, 0x5c,
		0x16, 0xc2, 0x2e, 0x5b, 0xa1, 0x97, 0x95, 0xf0, 0xcb, 0x5c, 0x08, 0x66, 0x2e, 0x0c, 0x33, 0x17,
		0x8a, 0x66, 0xc3, 0x25, 0x0f, 0x86, 0x38, 0xc7, 0x94, 0xb0, 0xdc, 0x24, 0x34, 0xcd, 0x53, 0xf4,
		0x06, 0xd9, 0x69, 0x9a, 0xae, 0xcd, 0x8a, 0xd0, 0xcc, 0x44, 0x69, 0x96, 0x22, 0x35, 0x1f, 0xd1,
		0x9a, 0xb5, 0x88, 0xcd, 0x4d, 0xd4, 0xe6, 0x26, 0x72, 0x73, 0x13, 0xbd, 0x66, 0x45, 0xb0, 0x61,
		0x51, 0x9c, 0x99, 0x48, 0x5e, 0x3c, 0x28, 0x33, 0x99, 0xbc, 0xc6, 0xe8, 0x19, 0x09, 0xe5, 0xa7,
		0xc2, 0x79, 0x2f, 0xa3, 0xc7, 0x65, 0x25, 0xa4, 0xf3, 0x10, 0xd6, 0xf9, 0x0a, 0xed, 0xbc, 0x84,
		0x77, 0xee, 0x42, 0x3c, 0x77, 0x61, 0x9e, 0xbb, 0x50, 0xcf, 0x46, 0xb8, 0x67, 0x24, 0xe4, 0x17,
		0xbb, 0x69, 0x0c, 0x8e, 0xf0, 0x2a, 0xdf, 0x7a, 0x94, 0xf4, 0xcd, 0x40, 0x14, 0x5e, 0xb5, 0x91,
		0x0f, 0x32, 0x7c, 0x66, 0x7b, 0x96, 0x91, 0xfc, 0xf8, 0x71, 0x9a, 0x45, 0xdc, 0x5d, 0xe8, 0x9e,
		0x77, 0x6f, 0x83, 0x5a, 0x33, 0xa0, 0x54, 0xcd, 0xf8, 0xde, 0xc4, 0x24, 0xaa, 0x3b, 0xed, 0x0b,
		0xc0, 0x81, 0x5b, 0xb7, 0x11, 0xca, 0x68, 0x23, 0xa0, 0x8d, 0x80, 0x36, 0x02, 0xda, 0x08, 0xb9,
		0x3b, 0x84, 0x8b, 0x07, 0x12, 0x9e, 0x3d, 0xd3, 0x2c, 0xa6, 0xcf, 0xf3, 0xac, 0xb9, 0x25, 0x5b,
		0xe7, 0x30, 0x37, 0x27, 0x31, 0x4f, 0x45, 0x00, 0x43, 0x21, 0xe4, 0xad, 0x18, 0xc0, 0x28, 0x08,
		0x30, 0x8a, 0x02, 0x8c, 0xc2, 0xc8, 0x56, 0x71, 0x64, 0xac, 0x40, 0xf2, 0x73, 0x36, 0x9f, 0x91,
		0xee, 0xc5, 0x60, 0xe4, 0xf7, 0x68, 0x9c, 0x07, 0xdb, 0xa7, 0x1f, 0xcc, 0xa1, 0xfc, 0x68, 0x3d,
		0x03, 0x3d, 0x54, 0xff, 0xcb, 0x47, 0xcc, 0xed, 0xe8, 0x1e, 0x20, 0x62, 0x99, 0x86, 0x5f, 0x5b,
		0x86, 0xe6, 0x81, 0x25, 0xca, 0xeb, 0x30, 0x30, 0x5c, 0xc3, 0x12, 0x09, 0xf8, 0x98, 0x34, 0xc9,
		0x1d, 0x92, 0xe6, 0x13, 0xd2, 0xd4, 0x3d, 0xc8, 0xe5, 0x4d, 0xd0, 0xe8, 0xbb, 0xed, 0x78, 0xea,
		0xd5, 0xbb, 0xb7, 0xf9, 0x7e, 0x19, 0xca, 0x98, 0xec, 0x53, 0xaa, 0x6b, 0x16, 0x56, 0xc6, 0xa9,
		0x55, 0xf4, 0xa2, 0xd1, 0x8b, 0x46, 0x2f, 0x1a, 0xbd, 0x68, 0xf4, 0xa2, 0x33, 0xe4, 0x7b, 0x2d,
		0x83, 0xa2, 0xd2, 0x4a, 0xfa, 0x34, 0x03, 0xa6, 0xd2, 0xee, 0xfd, 0xd6, 0xb9, 0xd1, 0x86, 0x06,
		0x61, 0xa5, 0xa6, 0x81, 0xc3, 0x1c, 0xd7, 0xa0, 0x7b, 0xea, 0x8a, 0xf2, 0x42, 0xec, 0x1a, 0xd8,
		0xa5, 0xec, 0x1e, 0xe4, 0x79, 0xd4, 0x26, 0xa6, 0xec, 0x28, 0xaf, 0xc6, 0xb6, 0xc1, 0x62, 0x76,
		0x38, 0x84, 0x39, 0x87, 0x84, 0x60, 0x08, 0xf7, 0x1a, 0x0a, 0x77, 0x90, 0xc2, 0x1d, 0x27, 0x71,
		0xd9, 0x38, 0xe0, 0x0d, 0x55, 0x9d, 0x26, 0x55, 0x87, 0xe4, 0x6f, 0xe5, 0x20, 0x3a, 0xcb, 0x14,
		0x3f, 0x46, 0xbc, 0xad, 0x7a, 0x52, 0x56, 0xf0, 0x37, 0x43, 0x1d, 0xab, 0x5e, 0x7d, 0xae, 0xd9,
		0x8e, 0x56, 0xd3, 0xf6, 0x47, 0xb3, 0x9f, 0xbb, 0x4f, 0x0b, 0xfd, 0x9f, 0x7e, 0xb0, 0x9b, 0x25,
		0x14, 0x7a, 0xc7, 0x68, 0x87, 0xac, 0xe9, 0x8b, 0xcf, 0x7e, 0x5e, 0x5f, 0x4e, 0xde, 0xb3, 0x3e,
		0x7f, 0xef, 0x27, 0x7f, 0xeb, 0xec, 0xa7, 0x95, 0x3f, 0xd3, 0xd8, 0x5d, 0x96, 0xf8, 0x27, 0xbd,
		0xcf, 0x30, 0xbf, 0x54, 0x68, 0x32, 0x2e, 0xc6, 0x64, 0x95, 0x4d, 0x29, 0xe4, 0x39, 0x0b, 0xea,
		0x1e, 0xf5, 0xe9, 0xb4, 0xab, 0x47, 0x06, 0xb9, 0xa4, 0xc2, 0x39, 0xb9, 0x5b, 0x79, 0x62, 0xe9,
		0xb0, 0x5a, 0xad, 0x1d, 0x54, 0xab, 0x7b, 0x07, 0x95, 0x83, 0xbd, 0xa3, 0xfd, 0xfd, 0x52, 0xad,
		0x94, 0x41, 0x06, 0xbe, 0xd0, 0x8a, 0x5d, 0x1a, 0x53, 0xf7, 0xf3, 0xf8, 0x64, 0x83, 0x91, 0xe7,
		0x59, 0x4d, 0xa0, 0x19, 0xeb, 0x09, 0x50, 0xfa, 0xa1, 0x90, 0x49, 0x11, 0x10, 0x00, 0x8d, 0x60,
		0x56, 0x17, 0x3c, 0x60, 0x57, 0x90, 0x2c, 0x59, 0x29, 0x57, 0x16, 0x32, 0xd9, 0xbd, 0x27, 0x1f,
		0x56, 0x31, 0xc3, 0x1b, 0xfa, 0x29, 0xd7, 0x00, 0xd5, 0x16, 0x38, 0x1d, 0x8c, 0x75, 0x69, 0xd1,
		0x63, 0x3c, 0x8b, 0xc6, 0x5c, 0x8f, 0x1f, 0x87, 0x5d, 0xb9, 0x9e, 0x0f, 0x65, 0x61, 0x57, 0x2e,
		0x75, 0x5b, 0x1b, 0xbb, 0x72, 0x6d, 0xb1, 0xfe, 0x35, 0xde, 0x95, 0x6b, 0x55, 0x7e, 0x65, 0xd7,
		0x92, 0xeb, 0xd1, 0x53, 0xb1, 0x1f, 0x17, 0x34, 0x61, 0x9a, 0x8f, 0x50, 0xcd, 0x5a, 0xb8, 0xe6,
		0x26, 0x64, 0x73, 0x13, 0xb6, 0xb9, 0x09, 0xdd, 0xb7, 0x11, 0xf8, 0xca, 0xac, 0x1f, 0x17, 0x0b,
		0xb8, 0x20, 0x81, 0x43, 0x8b, 0xcc, 0xcd, 0xbe, 0xd7, 0xc6, 0xea, 0xc3, 0xb1, 0x2b, 0x97, 0x6d,
		0x22, 0x3b, 0x5f, 0xd1, 0x9d, 0x97, 0x08, 0xcf, 0x5d, 0x94, 0xe7, 0x2e, 0xd2, 0x73, 0x17, 0xed,
		0xd9, 0x88, 0xf8, 0x8c, 0x44, 0xfd, 0x62, 0x37, 0xb1, 0x2b, 0x97, 0x69, 0xd1, 0xf8, 0xb4, 0x2b,
		0xd7, 0xaa, 0xfa, 0xc1, 0xc6, 0x5c, 0xb2, 0x7e, 0x1c, 0xcf, 0xa1, 0x37, 0xd7, 0xfc, 0xc9, 0x6f,
		0xbc, 0x3d, 0x17, 0x1a, 0x0b, 0x68, 0x2c, 0xa0, 0xb1, 0x80, 0xc6, 0x42, 0xfe, 0xfe, 0xe1, 0x53,
		0xa1, 0x9f, 0x5f, 0x8d, 0xf1, 0x7c, 0x01, 0xf9, 0x94, 0x18, 0x97, 0xb0, 0xc4, 0xf8, 0x8d, 0xab,
		0x86, 0xbc, 0x55, 0x04, 0x18, 0x55, 0x01, 0x46, 0x65, 0x80, 0x51, 0x1d, 0xd9, 0xaa, 0x90, 0x8c,
		0x55, 0x49, 0x6e, 0x2a, 0x65, 0xf1, 0x60, 0x16, 0xb8, 0x34, 0xbf, 0xae, 0x38, 0x2b, 0xc1, 0xc8,
		0xf1, 0x32, 0x72, 0x22, 0xf1, 0x7c, 0x5b, 0xf2, 0xe4, 0xa6, 0x6e, 0x20, 0xa8, 0x1d, 0x58, 0xea,
		0x07, 0x8a, 0x1a, 0x02, 0xa7, 0x8e, 0xc0, 0xa9, 0x25, 0x70, 0xea, 0x29, 0x1f, 0x35, 0x95, 0x93,
		0xba, 0x5a, 0xec, 0x7e, 0x6e, 0x9d, 0x31, 0xd6, 0xe4, 0x46, 0xf6, 0x61, 0xd4, 0x8d, 0xde, 0xca,
		0x41, 0xbe, 0x55, 0xb4, 0x4f, 0xc3, 0xac, 0x63, 0xc5, 0xba, 0x25, 0xe5, 0x5d, 0x39, 0xb0, 0x41,
		0xc6, 0x93, 0x12, 0x36, 0x7b, 0xe8, 0x19, 0x97, 0x0b, 0x01, 0xf0, 0xd3, 0xd7, 0x0d, 0xa8, 0x32,
		0x1a, 0x50, 0x68, 0x40, 0xa1, 0x01, 0x85, 0x06, 0x94, 0x35, 0x06, 0x54, 0x5e, 0x7e, 0x3f, 0x10,
		0xff, 0x1f, 0x54, 0x1c, 0x00, 0x48, 0x3c, 0x00, 0x4c, 0x5c, 0x00, 0x92, 0x7a, 0x83, 0xa9, 0xe6,
		0xa0, 0xa9, 0x3b, 0xb0, 0x6a, 0x0f, 0xac, 0xfa, 0x03, 0xab, 0x06, 0xf3, 0x55, 0x87, 0x39, 0xab,
		0x45, 0x38, 0xf1, 0x85, 0x35, 0xb9, 0x33, 0x62, 0x81, 0xa8, 0x55, 0x21, 0xc8, 0x9c, 0x99, 0x96,
		0x3a, 0x04, 0xb0, 0x94, 0x7c, 0x87, 0x5d, 0x3c, 0xfd, 0x0f, 0x86, 0x0c, 0xde, 0x81, 0x32, 0x0c,
		0x03, 0xa8, 0x79, 0xb3, 0xb6, 0x2c, 0x20, 0xc3, 0x32, 0xd6, 0xd6, 0x05, 0x68, 0x30, 0x01, 0x30,
		0xf1, 0xfc, 0x98, 0xd4, 0xc9, 0x1d, 0x92, 0xba, 0x24, 0xa9, 0xe7, 0xd3, 0x04, 0xe4, 0xcd, 0x50,
		0xff, 0x3b, 0x5c, 0xc5, 0x4e, 0x6e, 0xcd, 0xdb, 0xf2, 0x7f, 0xff, 0x3c, 0x47, 0x09, 0x79, 0xa1,
		0x43, 0xbc, 0x22, 0x0b, 0x04, 0x8d, 0xfb, 0x24, 0xdb, 0x02, 0xae, 0x57, 0x4d, 0xd4, 0x67, 0xd6,
		0x86, 0x01, 0x15, 0x0c, 0xa8, 0x60, 0x40, 0x05, 0x03, 0x2a, 0x18, 0x50, 0xc1, 0x80, 0x0a, 0xc0,
		0x80, 0x4a, 0xa5, 0x0c, 0x28, 0xa0, 0x72, 0x80, 0x01, 0x15, 0x0c, 0xa8, 0x60, 0x40, 0x05, 0x03,
		0x2a, 0x18, 0x50, 0xb1, 0x8e, 0xd4, 0xa1, 0x4c, 0x33, 0xc5, 0x30, 0x0a, 0x86, 0x51, 0x30, 0x8c,
		0x92, 0x38, 0x8c, 0xb2, 0x3a, 0xe3, 0x0c, 0x5a, 0x18, 0x05, 0xc6, 0xfc, 0x35, 0x0c, 0xa3, 0x60,
		0x18, 0x05, 0xc3, 0x28, 0x18, 0x46, 0xc1, 0x30, 0x0a, 0x86, 0x51, 0x9e, 0x95, 0x3b, 0x80, 0xf4,
		0xd4, 0x0e, 0x90, 0x91, 0x72, 0x4b, 0x3d, 0x01, 0x64, 0xb8, 0xd6, 0x62, 0x41, 0xdb, 0x31, 0x3f,
		0x74, 0x61, 0x58, 0x43, 0x20, 0x01, 0x48, 0x43, 0xd6, 0x16, 0xab, 0xda, 0x96, 0xb9, 0xa2, 0xe8,
		0x62, 0x01, 0x70, 0xb1, 0x6a, 0x80, 0x5d, 0xac, 0x1a, 0xba, 0x58, 0xe8, 0x62, 0xa1, 0x8b, 0x85,
		0x2e, 0x16, 0xba, 0x58, 0xe8, 0x62, 0x01, 0x76, 0xb1, 0x6a, 0xe8, 0x62, 0x59, 0xe5, 0x62, 0xe1,
		0x18, 0xe3, 0x6d, 0x9a, 0xe2, 0x8d, 0x0e, 0x67, 0x42, 0x87, 0x13, 0xd9, 0x62, 0xab, 0xa6, 0x7b,
		0xa3, 0xfb, 0x9d, 0x9f, 0xfb, 0xed, 0x47, 0x1e, 0x2f, 0xf6, 0x42, 0x40, 0x4e, 0xf7, 0x62, 0x45,
		0xe8, 0x6a, 0xa3, 0xab, 0x8d, 0xae, 0x36, 0xba, 0xda, 0xe8, 0x6a, 0xa3, 0xab, 0x0d, 0xcc, 0xd5,
		0xee, 0x85, 0xa1, 0x47, 0x49, 0x00, 0xc9, 0xcb, 0x2e, 0xa1, 0xf1, 0x94, 0x8f, 0xf1, 0x24, 0x1c,
		0x60, 0xb6, 0x93, 0x70, 0xd0, 0x74, 0x42, 0xd3, 0x09, 0x4d, 0x27, 0x34, 0x9d, 0xd0, 0x74, 0x42,
		0xd3, 0x09, 0x62, 0x3d, 0xdd, 0x21, 0x20, 0xc3, 0x69, 0x1f, 0xcb, 0xe9, 0x9e, 0xfc, 0x87, 0xe5,
		0x74, 0x36, 0x58, 0x37, 0x6b, 0xcb, 0xc2, 0x72, 0x3a, 0xdb, 0xa4, 0xf3, 0x63, 0x52, 0xc7, 0x72,
		0x3a, 0x69, 0x52, 0x3f, 0x40, 0x52, 0xb7, 0xc3, 0x0c, 0x82, 0xb3, 0x0a, 0xcc, 0x31, 0xe5, 0x15,
		0x26, 0x11, 0x1e, 0xb4, 0x38, 0x89, 0xf0, 0x30, 0x50, 0x82, 0x81, 0x12, 0x0c, 0x94, 0x60, 0xa0,
		0x04, 0x03, 0x25, 0x18, 0x28, 0xc1, 0x40, 0x09, 0x06, 0x4a, 0x30, 0x50, 0x82, 0x81, 0x12, 0xf4,
		0x1e, 0x31, 0x50, 0xf2, 0xd6, 0x48, 0xbd, 0xbc, 0x8f, 0x0d, 0x87, 0x30, 0x54, 0x82, 0xa1, 0x12,
		0xf0, 0xa1, 0x92, 0x98, 0xfa, 0xa1, 0xa0, 0x40, 0x3b, 0x0e, 0x3d, 0xb7, 0x38, 0x0c, 0xa0, 0x60,
		0x00, 0x05, 0x03, 0x28, 0x18, 0x40, 0xc1, 0x00, 0x0a, 0x06, 0x50, 0xb0, 0xe5, 0x50, 0x12, 0x5d,
		0x85, 0xf5, 0xb0, 0xcf, 0x2d, 0x08, 0x5b, 0x0e, 0x65, 0x4e, 0x02, 0xd8, 0x72, 0x08, 0x6b, 0x1e,
		0xb7, 0xdc, 0xc9, 0xaa, 0x41, 0x76, 0xb2, 0xb0, 0xe9, 0x10, 0x3a, 0x59, 0xe8, 0x64, 0xa1, 0x93,
		0x85, 0x4e, 0x16, 0x3a, 0x59, 0x90, 0x9d, 0x2c, 0x6c, 0x3a, 0x64, 0x97, 0x93, 0x85, 0xdd, 0x55,
		0xb0, 0xe9, 0x10, 0xba, 0x9c, 0x6b, 0x2e, 0x27, 0xb2, 0x05, 0x36, 0x1d, 0x42, 0x07, 0x3c, 0x13,
		0x8e, 0xe3, 0x90, 0xc6, 0xd1, 0x72, 0x9c, 0x3f, 0x8b, 0x0e, 0x36, 0x3a, 0xd8, 0xe8, 0x60, 0xa3,
		0x83, 0x8d, 0x0e, 0x36, 0x3c, 0x07, 0x9b, 0xc7, 0x45, 0xce, 0xdc, 0xa2, 0x18, 0x2f, 0x0c, 0x90,
		0x7f, 0x7d, 0x04, 0x60, 0x2d, 0xb3, 0xc3, 0x42, 0x30, 0xf8, 0x06, 0xd2, 0x99, 0x54, 0xb9, 0x79,
		0xa4, 0x47, 0xbd, 0x02, 0x20, 0xfc, 0x2e, 0x20, 0x0a, 0x82, 0x49, 0x49, 0xf0, 0x28, 0x6a, 0x8d,
		0xb2, 0xc0, 0x0c, 0xc5, 0xde, 0x44, 0x5d, 0x07, 0x00, 0x97, 0x06, 0xab, 0x78, 0x05, 0x3e, 0xb5,
		0x2d, 0x36, 0x0e, 0x62, 0x71, 0x0b, 0x50, 0x1f, 0xee, 0xd5, 0x65, 0xce, 0x2b, 0x02, 0x4a, 0x35,
		0xe0, 0x0b, 0x05, 0x5c, 0x20, 0x00, 0xcc, 0x68, 0x7d, 0x99, 0x77, 0x00, 0x56, 0xcb, 0x58, 0xcf,
		0x3b, 0x7b, 0xd5, 0xc3, 0xfd, 0x83, 0x7d, 0x64, 0xa0, 0xb7, 0xe1, 0x73, 0xda, 0xb3, 0xaa, 0xab,
		0x77, 0x28, 0xf6, 0x6c, 0x34, 0x97, 0x69, 0x30, 0xf2, 0x69, 0x4c, 0xc6, 0xdc, 0x08, 0xd8, 0x66,
		0x2e, 0x55, 0x01, 0xae, 0xad, 0x1e, 0x8c, 0xfc, 0xb1, 0x02, 0x83, 0xc5, 0x8c, 0x70, 0x56, 0x03,
		0x43, 0x24, 0x00, 0x11, 0x05, 0x00, 0x63, 0x30, 0xc0, 0xf0, 0x31, 0x6b, 0x3c, 0x7f, 0x08, 0x68,
		0x4d, 0xd0, 0x90, 0x01, 0x8b, 0x85, 0x21, 0x40, 0x60, 0x7b, 0x71, 0x33, 0x0b, 0x41, 0x0b, 0x89,
		0x51, 0x20, 0xe2, 0x68, 0x16, 0xab, 0x43, 0x3c, 0xcd, 0x36, 0xe3, 0x69, 0x80, 0x19, 0x26, 0x88,
		0x2f, 0xda, 0x3e, 0x93, 0xb0, 0x20, 0x20, 0x64, 0x71, 0x17, 0x26, 0x20, 0x80, 0xd4, 0x2d, 0x22,
		0x8c, 0x9e, 0x6a, 0x50, 0x44, 0x18, 0xbd, 0xb2, 0x2a, 0x44, 0x18, 0x25, 0x5c, 0x18, 0x22, 0x8c,
		0xac, 0xd2, 0xc9, 0x88, 0x30, 0x7a, 0x2a, 0x77, 0x60, 0x45, 0x27, 0x21, 0x45, 0x23, 0x81, 0x44,
		0x1f, 0x73, 0x34, 0xe2, 0xde, 0x6d, 0x11, 0x8b, 0x16, 0x8e, 0x83, 0x20, 0x14, 0x53, 0x3e, 0xc8,
		0x93, 0x41, 0x0b, 0xdc, 0x19, 0x52, 0x9f, 0x44, 0x44, 0x0c, 0xc7, 0xec, 0xb9, 0x1b, 0x46, 0x34,
		0x70, 0x26, 0x86, 0xd3, 0x58, 0x7e, 0xef, 0x8e, 0xff, 0x2f, 0x66, 0xbd, 0x5d, 0x22, 0x44, 0x5c,
		0xe4, 0x54, 0xf0, 0xc5, 0x6f, 0xbb, 0x62, 0x14, 0x04, 0xd4, 0x2b, 0xd2, 0xc0, 0x21, 0x11, 0x1f,
		0x79, 0x93, 0x57, 0x99, 0x7d, 0xc8, 0x67, 0x3f, 0x77, 0xf9, 0xa8, 0x27, 0xbc, 0x1b, 0x3e, 0xfb,
		0xb9, 0xcb, 0xe9, 0x60, 0xac, 0x23, 0x8a, 0x1e, 0xe3, 0x82, 0x3f, 0xfa, 0x6b, 0xfe, 0xc7, 0xe2,
		0xd3, 0x5d, 0x2e, 0x88, 0xc8, 0xd3, 0x92, 0x2d, 0x70, 0x11, 0x8f, 0x1c, 0x11, 0xcc, 0xe4, 0x56,
		0x6b, 0xb1, 0x2f, 0x9f, 0x07, 0xd1, 0xf5, 0xf8, 0xff, 0x2e, 0x59, 0xef, 0xfa, 0x58, 0x88, 0xb8,
		0x43, 0x05, 0x9f, 0xff, 0x72, 0xdd, 0x9d, 0xbc, 0x77, 0x7d, 0x75, 0x4f, 0x66, 0x9f, 0xf1, 0xd9,
		0xcf, 0xeb, 0xce, 0x74, 0x4f, 0x66, 0x3f, 0xaf, 0x3b, 0xd3, 0xf7, 0x6d, 0x8e, 0xb7, 0x64, 0xf5,
		0x8f, 0xf9, 0xef, 0x8b, 0x0f, 0xaf, 0x3b, 0x93, 0x1d, 0x79, 0xb7, 0x1d, 0xac, 0x99, 0xed, 0x13,
		0x33, 0x16, 0x02, 0x63, 0xfb, 0x72, 0x12, 0xaf, 0x0f, 0x5c, 0x9a, 0xb5, 0x69, 0x59, 0x18, 0x13,
		0xd7, 0x98, 0x5c, 0x73, 0x11, 0x3b, 0x85, 0x73, 0x16, 0xd4, 0x3d, 0x3a, 0x21, 0xec, 0x7c, 0x3c,
		0xb3, 0xc2, 0x39, 0xb9, 0x5b, 0x59, 0x41, 0xe9, 0xb0, 0x5a, 0xad, 0x1d, 0x54, 0xab, 0x7b, 0x07,
		0x95, 0x83, 0xbd, 0xa3, 0xfd, 0xfd, 0x52, 0xad, 0x94, 0x03, 0xd6, 0xa2, 0xd0, 0x8a, 0x5d, 0x1a,
		0x53, 0xf7, 0xf3, 0x98, 0x2c, 0x82, 0x91, 0xe7, 0xbd, 0x69, 0xea, 0xcf, 0x59, 0xf5, 0x41, 0x55,
		0x79, 0x39, 0x28, 0x3b, 0x70, 0x4a, 0x2e, 0x5b, 0xf5, 0x96, 0x9d, 0x92, 0xc9, 0xe6, 0x49, 0x19,
		0x31, 0x72, 0x5e, 0x0c, 0x0c, 0x8d, 0x71, 0x33, 0x64, 0x58, 0x30, 0x8c, 0x9a, 0x0d, 0x83, 0x9a,
		0x67, 0x97, 0x0c, 0x58, 0xa5, 0x30, 0x75, 0x61, 0xb2, 0xe2, 0x90, 0x65, 0x11, 0x57, 0x86, 0x9e,
		0xd3, 0x22, 0x80, 0x92, 0xd1, 0xe3, 0x16, 0x31, 0xfd, 0x72, 0x46, 0x0f, 0xcc, 0x21, 0x76, 0x9f,
		0x6f, 0x8c, 0x3e, 0xaf, 0x58, 0x7c, 0xee, 0x31, 0xf7, 0xdc, 0x63, 0xeb, 0xb9, 0xc7, 0xd0, 0xdf,
		0x96, 0x91, 0x72, 0xca, 0xb2, 0x75, 0x71, 0x0b, 0x2c, 0xe0, 0x82, 0x04, 0x0e, 0x2d, 0xe6, 0xd0,
		0x70, 0x62, 0x09, 0x01, 0x5c, 0x59, 0x44, 0xd6, 0x41, 0x8d, 0x5c, 0xd2, 0xbe, 0xb9, 0xa5, 0x79,
		0xf3, 0x4c, 0xeb, 0xc2, 0x48, 0xe3, 0xe6, 0x9d, 0xb6, 0x05, 0x93, 0xa6, 0x05, 0x93, 0x96, 0x05,
		0x93, 0x86, 0x7d, 0xdb, 0xe1, 0xdb, 0xdc, 0xd2, 0xaa, 0x8f, 0x6a, 0xa2, 0x6b, 0xd5, 0x3c, 0x78,
		0x7e, 0x26, 0xe5, 0x73, 0x80, 0x72, 0xe7, 0x5c, 0xd3, 0x9c, 0x63, 0x8e, 0x0e, 0x42, 0x4d, 0x32,
		0x14, 0x54, 0x17, 0x90, 0x81, 0x7a, 0x90, 0x2a, 0x1e, 0xf3, 0x44, 0x3f, 0x42, 0x28, 0xf9, 0x85,
		0x46, 0x9a, 0x30, 0x72, 0x4a, 0x60, 0xa9, 0x75, 0x4b, 0x32, 0xd8, 0x57, 0x6f, 0x35, 0x95, 0x91,
		0x61, 0x2c, 0xea, 0x96, 0xb2, 0xc1, 0x50, 0xe4, 0xe7, 0x4d, 0xcf, 0x9e, 0x8f, 0x8e, 0x34, 0x3a,
		0xd2, 0xe8, 0x48, 0xa3, 0x23, 0x8d, 0x8e, 0xf4, 0x9b, 0x74, 0xa4, 0x73, 0x69, 0x2e, 0x96, 0x63,
		0xf3, 0x30, 0x74, 0xa4, 0xd1, 0x5b, 0x41, 0x47, 0x1a, 0x1d, 0x69, 0xf0, 0xa4, 0x59, 0x2d, 0x1f,
		0x55, 0x8f, 0x6a, 0x07, 0xe5, 0x23, 0x74, 0x9f, 0xd1, 0x7d, 0x7e, 0x2b, 0xee, 0x33, 0x22, 0x01,
		0x35, 0x3c, 0x17, 0x0a, 0x12, 0x30, 0xe3, 0x22, 0x95, 0xfc, 0x61, 0x80, 0xd9, 0xd5, 0xa0, 0x64,
		0x80, 0x01, 0x7c, 0x67, 0x31, 0x0b, 0x2e, 0x6b, 0x48, 0xb2, 0x02, 0x7c, 0x64, 0x5b, 0x39, 0x92,
		0x7d, 0xa5, 0x08, 0x88, 0xca, 0x90, 0x6c, 0x2b, 0x41, 0x4c, 0xd3, 0x68, 0xc6, 0xea, 0x01, 0x88,
		0x5a, 0x28, 0x64, 0x82, 0x2d, 0xce, 0x55, 0x11, 0x98, 0x55, 0x01, 0xe6, 0x04, 0xb3, 0x99, 0x3b,
		0x1b, 0x62, 0xa3, 0xac, 0xd8, 0x27, 0x3f, 0xb6, 0x31, 0xc8, 0x29, 0x79, 0x70, 0x88, 0x19, 0xae,
		0xd0, 0x4f, 0xb3, 0x06, 0xe8, 0xd5, 0x70, 0xb1, 0x43, 0x26, 0xc5, 0x0d, 0x86, 0x8b, 0x19, 0x8c,
		0x17, 0x2f, 0x64, 0x91, 0x48, 0xcb, 0x36, 0x61, 0x96, 0x55, 0x62, 0x2c, 0xf3, 0x04, 0x58, 0xe6,
		0x89, 0xae, 0xcc, 0x13, 0x5a, 0x76, 0x69, 0x5a, 0xd3, 0xc5, 0x02, 0x85, 0x1e, 0x0b, 0x5c, 0x16,
		0x0c, 0x8a, 0x59, 0x4c, 0xa3, 0x5c, 0xf0, 0xe8, 0xea, 0x43, 0x4d, 0x7b, 0xa3, 0x99, 0x44, 0x8e,
		0x33, 0xc3, 0x28, 0x64, 0x89, 0x49, 0xc8, 0x07, 0x83, 0x90, 0x35, 0xe6, 0x20, 0x37, 0x8c, 0x41,
		0x6e, 0x98, 0x82, 0xdc, 0x30, 0x04, 0x76, 0xc7, 0xb5, 0x32, 0xc3, 0x04, 0xe4, 0x34, 0xf5, 0x30,
		0xcb, 0x99, 0x74, 0xd9, 0xce, 0x9a, 0xcb, 0xa1, 0x44, 0x36, 0x97, 0xa9, 0x83, 0x79, 0x4c, 0x15,
		0xcc, 0x67, 0x6a, 0x20, 0x02, 0x73, 0xb2, 0x7d, 0x34, 0x02, 0x73, 0x72, 0xfc, 0x0f, 0x5c, 0x19,
		0x41, 0x0d, 0x51, 0x0f, 0x19, 0x19, 0x1d, 0x2f, 0xd3, 0x26, 0x22, 0x73, 0xd6, 0x69, 0x13, 0xc2,
		0x54, 0x3a, 0x84, 0xe5, 0xbc, 0x79, 0x58, 0xce, 0x1f, 0xdb, 0x62, 0xee, 0xe4, 0xdb, 0x17, 0x39,
		0xcf, 0x3e, 0xc8, 0x39, 0xf5, 0x3d, 0xce, 0xee, 0x69, 0x57, 0x6f, 0x09, 0xf1, 0x95, 0x83, 0x8f,
		0x97, 0xd3, 0x54, 0xb3, 0x3c, 0xa6, 0x96, 0xe5, 0x36, 0x95, 0x0c, 0xa7, 0x8e, 0x6d, 0xc1, 0xd4,
		0xb1, 0xab, 0x2c, 0x09, 0x39, 0xcf, 0xa9, 0x61, 0x38, 0x15, 0x6c, 0x2b, 0xa6, 0x82, 0x5d, 0xbd,
		0x11, 0x1c, 0xea, 0x95, 0xad, 0x60, 0x2a, 0x83, 0x89, 0x7f, 0x27, 0xf4, 0xc2, 0x98, 0x67, 0x97,
		0x2a, 0x9d, 0x3d, 0x0f, 0xb3, 0xa4, 0x72, 0x52, 0x1e, 0xb3, 0xa4, 0xba, 0x29, 0x04, 0xb3, 0xa4,
		0x98, 0x25, 0x4d, 0xb0, 0x6b, 0xd9, 0x67, 0x49, 0x33, 0x4b, 0xc8, 0x64, 0x98, 0x80, 0xc9, 0x38,
		0xe1, 0x92, 0xa1, 0xf3, 0x9c, 0x47, 0x42, 0x25, 0xaf, 0xc6, 0x25, 0x39, 0x55, 0x32, 0xe7, 0x19,
		0x7e, 0xce, 0xb2, 0x09, 0x4f, 0x1e, 0xf9, 0x8f, 0xbc, 0x49, 0x29, 0xaf, 0xca, 0xe3, 0x5c, 0x69,
		0x0a, 0xdd, 0x29, 0x00, 0x8a, 0x1d, 0x8b, 0xec, 0xde, 0x5c, 0x91, 0x9d, 0x95, 0x0e, 0xf8, 0xd8,
		0xfb, 0xa0, 0x31, 0x0d, 0xb2, 0x40, 0xdf, 0xcf, 0x4d, 0xcc, 0x95, 0x67, 0x1a, 0xe6, 0xb2, 0x53,
		0xda, 0x27, 0x23, 0x6f, 0xe2, 0x73, 0x94, 0xf6, 0xf6, 0xd0, 0xed, 0x47, 0xb7, 0x1f, 0xdd, 0x7e,
		0x74, 0xfb, 0xd1, 0xed, 0x47, 0xb7, 0x1f, 0xdd, 0x7e, 0x74, 0xfb, 0xd1, 0xed, 0x47, 0xb7, 0x1f,
		0xdd, 0x7e, 0x74, 0xfb, 0xad, 0x77, 0xe2, 0x44, 0x16, 0xe6, 0xc2, 0xc2, 0x54, 0xc8, 0xa0, 0x80,
		0x0a, 0x5d, 0x29, 0x74, 0xa5, 0xd0, 0x95, 0x42, 0x57, 0xca, 0x4a, 0x57, 0x8a, 0xb9, 0x34, 0x10,
		0x4c, 0xdc, 0xc7, 0xb4, 0x9f, 0x65, 0x9d, 0x69, 0x16, 0x01, 0xd5, 0xc6, 0xec, 0xd5, 0x3e, 0x13,
		0x9e, 0xc3, 0xc4, 0xdb, 0xee, 0xd7, 0x8b, 0x8b, 0x7a, 0xf3, 0xba, 0x7e, 0x71, 0x72, 0xdc, 0xee,
		0x7c, 0x6d, 0x1e, 0x77, 0x1b, 0xad, 0x8b, 0xeb, 0xce, 0xd7, 0xcf, 0xdd, 0xe6, 0xb7, 0xeb, 0xee,
		0x7f, 0xda, 0xf5, 0xac, 0x24, 0xc0, 0xc4, 0x8c, 0xe4, 0x99, 0xc2, 0x1d, 0x73, 0x1a, 0x8c, 0xd1,
		0xb9, 0xec, 0xd6, 0xaf, 0xdb, 0x97, 0xf5, 0xb3, 0xfa, 0x65, 0xfd, 0xe2, 0xa4, 0x5e, 0x78, 0x8b,
		0x1e, 0x50, 0x9e, 0x5b, 0xdb, 0xa9, 0x7f, 0x39, 0xaf, 0x5f, 0x74, 0xaf, 0x9b, 0x8d, 0x4e, 0x17,
		0x37, 0x57, 0xbb, 0xa4, 0xb8, 0xac, 0x9f, 0xb7, 0xba, 0xf5, 0xeb, 0xfa, 0xc5, 0x69, 0xbb, 0xd5,
		0xb8, 0xc0, 0x1d, 0xd6, 0x4d, 0xbe, 0x9f, 0x1b, 0x17, 0xa7, 0x8d, 0x8b, 0x2f, 0xd7, 0x9d, 0xc6,
		0x29, 0xee, 0xad, 0x76, 0xea, 0x3d, 0x69, 0x35, 0x5b, 0x97, 0x6f, 0x6d, 0x2c, 0xf4, 0x95, 0xed,
		0xe6, 0x2a, 0x76, 0xd2, 0xda, 0x79, 0xb3, 0x3d, 0x2b, 0x0d, 0xb7, 0xf9, 0xce, 0xac, 0x57, 0xa5,
		0xb9, 0xee, 0xdd, 0x76, 0x34, 0xa9, 0x34, 0x1a, 0x0f, 0xcb, 0x22, 0x0e, 0x66, 0x38, 0xfe, 0x65,
		0x3c, 0xee, 0x85, 0x2d, 0x2a, 0xad, 0x89, 0x6b, 0x61, 0x8b, 0x4a, 0x58, 0x8a, 0xd5, 0x78, 0xbc,
		0x6a, 0xc1, 0x37, 0x1e, 0x25, 0x7d, 0xb3, 0x31, 0xaa, 0x45, 0x6c, 0xca, 0x60, 0xb2, 0xbf, 0xd0,
		0x9e, 0xd9, 0x06, 0x1f, 0x3f, 0x4e, 0x15, 0xf8, 0xee, 0x44, 0x2e, 0xdb, 0xa2, 0xfd, 0xde, 0x01,
		0xa6, 0xc9, 0xf9, 0xec, 0x09, 0x03, 0x8a, 0xce, 0x2c, 0xfe, 0xd5, 0x3c, 0xde, 0x35, 0x17, 0x7c,
		0xab, 0x59, 0x3c, 0xab, 0x6e, 0xe2, 0x31, 0xec, 0x21, 0x64, 0xe9, 0x19, 0x14, 0x8c, 0x34, 0x52,
		0xcf, 0xc2, 0x17, 0xd0, 0x2b, 0x07, 0xf5, 0x49, 0x2b, 0x3d, 0x77, 0xd2, 0x44, 0xb2, 0xa6, 0x48,
		0x35, 0x13, 0x12, 0xd5, 0x48, 0x9b, 0xa6, 0x69, 0x52, 0x0f, 0x31, 0xa6, 0x27, 0x1d, 0x0d, 0x64,
		0xa3, 0xd7, 0xc5, 0x34, 0xe1, 0x52, 0x6a, 0x76, 0x21, 0xb5, 0xbb, 0x8c, 0x26, 0x5c, 0x44, 0xb3,
		0x2e, 0xa1, 0x29, 0x17, 0xd0, 0xb8, 0xcb, 0x67, 0xdc, 0xc5, 0x33, 0xee, 0xd2, 0xc1, 0x52, 0x17,
		0xda, 0x5d, 0x34, 0x83, 0x2e, 0x99, 0x09, 0x17, 0xcc, 0xa4, 0xcb, 0xa5, 0x41, 0xba, 0xbf, 0xcb,
		0x91, 0x46, 0x34, 0xba, 0x4c, 0x7a, 0x5d, 0x24, 0xfd, 0x2e, 0x51, 0x26, 0x2e, 0x90, 0x5e, 0x97,
		0x27, 0xed, 0xe1, 0x6a, 0xb6, 0x13, 0x8d, 0xda, 0x87, 0x1a, 0x64, 0x88, 0x29, 0x7b, 0x30, 0x9d,
		0xa4, 0x50, 0xe7, 0x6f, 0xb5, 0x2b, 0x15, 0x89, 0x46, 0x17, 0xb1, 0x98, 0x21, 0x92, 0x14, 0xd4,
		0xa1, 0x9d, 0x2a, 0xd4, 0xc8, 0x41, 0xfe, 0x30, 0xe5, 0xae, 0x90, 0x3c, 0xf6, 0xb4, 0xc7, 0xad,
		0xf7, 0x98, 0x15, 0x8e, 0x57, 0xdb, 0xb1, 0xca, 0x1d, 0x67, 0xf2, 0x43, 0x49, 0xf6, 0xcd, 0x84,
		0xc7, 0xb6, 0x1c, 0xab, 0xeb, 0xd2, 0xa4, 0xe6, 0xb6, 0x9a, 0x42, 0x56, 0x57, 0xbc, 0x5a, 0x15,
		0xac, 0x9a, 0x22, 0x4d, 0xba, 0x9b, 0x8a, 0xc4, 0xaf, 0x4c, 0xf4, 0x12, 0xf4, 0xad, 0x44, 0xd7,
		0xc9, 0x68, 0xf8, 0x75, 0x8a, 0x7c, 0xf9, 0x1b, 0xaf, 0xec, 0xae, 0xec, 0xae, 0xca, 0xee, 0x66,
		0x82, 0x4d, 0x94, 0xda, 0xbc, 0x97, 0x37, 0x6d, 0xf3, 0x56, 0xbc, 0xb0, 0x0d, 0x05, 0x27, 0xf4,
		0xfd, 0x51, 0xc0, 0x04, 0xa3, 0xaf, 0x37, 0x09, 0x5c, 0x69, 0xf2, 0xb7, 0xbc, 0xe8, 0x95, 0x2d,
		0x4e, 0x36, 0x0a, 0x32, 0x71, 0xf0, 0x43, 0x26, 0xa8, 0xa1, 0x16, 0xac, 0x90, 0x0d, 0x42, 0x28,
		0x07, 0x17, 0x94, 0x83, 0x06, 0xca, 0xc1, 0x80, 0x74, 0xcc, 0x92, 0x74, 0xb4, 0xdf, 0x82, 0x3a,
		0xee, 0x93, 0xef, 0xe1, 0x53, 0xc2, 0xba, 0x4f, 0xba, 0x87, 0x72, 0x93, 0x46, 0xa5, 0x63, 0x6c,
		0x2a, 0x31, 0xb4, 0x74, 0x31, 0x32, 0xd5, 0x18, 0x58, 0xea, 0x18, 0x57, 0xea, 0x18, 0x56, 0xea,
		0x18, 0x95, 0x5e, 0xfb, 0x43, 0x76, 0x12, 0xe5, 0xcc, 0x52, 0x91, 0xde, 0xf7, 0x45, 0x51, 0x8a,
		0x84, 0xa1, 0x93, 0x32, 0x84, 0xac, 0x1c, 0x2a, 0x4e, 0x13, 0x12, 0xd6, 0x13, 0xfa, 0x4d, 0x1b,
		0xe2, 0xd5, 0x16, 0xca, 0xd5, 0x16, 0xb2, 0xd5, 0x16, 0x9a, 0x35, 0xeb, 0x3d, 0x29, 0x87, 0x54,
		0x35, 0x84, 0x4e, 0xd3, 0x84, 0x48, 0xd7, 0x43, 0xa1, 0x53, 0x46, 0x33, 0xe5, 0x03, 0x49, 0xd9,
		0xbd, 0x2a, 0x93, 0xba, 0x53, 0x4d, 0xe0, 0x56, 0x9c, 0xac, 0xad, 0x3c, 0x31, 0x1b, 0x05, 0xc6,
		0xd6, 0x0a, 0x0c, 0xd5, 0x49, 0xce, 0x0a, 0xe6, 0x9f, 0x36, 0x73, 0x50, 0x93, 0x7e, 0x4d, 0xad,
		0x67, 0x75, 0xb0, 0x8f, 0x5e, 0x36, 0xd2, 0xc5, 0x4e, 0xda, 0xd9, 0x4a, 0x3b, 0x7b, 0x69, 0x67,
		0xb3, 0x7c, 0x82, 0xdb, 0xa9, 0x53, 0xa0, 0xcb, 0xc6, 0x53, 0x41, 0xba, 0x59, 0x58, 0x3a, 0xa6,
		0xb4, 0xea, 0x99, 0xba, 0xaa, 0x21, 0x21, 0xb4, 0x98, 0xe8, 0x3e, 0x88, 0x8a, 0xb7, 0xd4, 0xf3,
		0x8a, 0xbf, 0x82, 0xf0, 0x36, 0x28, 0x2e, 0x04, 0x8d, 0xae, 0xe1, 0xc5, 0x3a, 0x8b, 0xc6, 0xcd,
		0x14, 0x85, 0x2f, 0xb6, 0xe2, 0xf3, 0x97, 0xf6, 0xf5, 0xf7, 0x7a, 0xb3, 0x79, 0xfd, 0xe7, 0x45,
		0xeb, 0xfb, 0xc5, 0x75, 0xa7, 0x7b, 0x7a, 0x7d, 0xd2, 0x3a, 0x3f, 0xff, 0x7a, 0xd1, 0xe8, 0xfe,
		0x47, 0x17, 0x54, 0xc6, 0x40, 0x41, 0xb7, 0x66, 0x88, 0xc8, 0x7c, 0x37, 0x2e, 0x5a, 0xd7, 0xc7,
		0xa7, 0xdf, 0xea, 0x97, 0xdd, 0x46, 0x47, 0x63, 0x35, 0xb6, 0x46, 0xe8, 0xa7, 0xb1, 0xf7, 0x6e,
		0xd7, 0xeb, 0x97, 0xdb, 0xf5, 0xc6, 0xd7, 0xf5, 0xbf, 0xda, 0xad, 0xcb, 0xee, 0x56, 0xbe, 0xf4,
		0x75, 0xe7, 0xeb, 0xe7, 0x93, 0xd6, 0xc5, 0x59, 0xfd, 0x14, 0x1a, 0x88, 0xe8, 0xca, 0x6e, 0x80,
		0x8a, 0x66, 0x25, 0xc5, 0x85, 0x6b, 0x50, 0x3b, 0x69, 0x18, 0xbc, 0xae, 0x77, 0xa0, 0xba, 0x01,
		0xc8, 0x97, 0xf6, 0xc6, 0x9b, 0x06, 0x1a, 0x6c, 0x1a, 0x6a, 0xa4, 0x69, 0xa6, 0xf0, 0xc3, 0x5c,
		0xe1, 0xa7, 0xe1, 0xa2, 0x4c, 0xc3, 0x8d, 0x2e, 0xb3, 0x68, 0x3e, 0xf8, 0x60, 0xa6, 0xd2, 0xc6,
		0xfa, 0x23, 0x35, 0xdd, 0x70, 0x32, 0x93, 0xb3, 0x05, 0x5a, 0x4a, 0x72, 0x05, 0x09, 0x1b, 0x6c,
		0x40, 0x41, 0x70, 0x11, 0xb3, 0x60, 0x60, 0x02, 0x12, 0x7c, 0xa8, 0x17, 0x12, 0x6c, 0x64, 0x06,
		0x68, 0xe1, 0x7d, 0x6d, 0x7f, 0xbf, 0xf2, 0x63, 0xaf, 0xb8, 0x7f, 0xf5, 0xbb, 0xb6, 0xbf, 0xff,
		0x63, 0xaf, 0x58, 0xbe, 0xfa, 0xb1, 0x57, 0x3c, 0x1a, 0xff, 0x55, 0x9d, 0xfc, 0xf2, 0x4f, 0xf9,
		0xe1, 0x77, 0x6d, 0xfc, 0x0f, 0xd5, 0xab, 0xe5, 0xdf, 0x2b, 0x7f, 0x56, 0x1e, 0x7e, 0xff, 0x28,
		0x15, 0xf7, 0x67, 0x7f, 0x55, 0x27, 0x7f, 0x1d, 0xcd, 0xfe, 0x9a, 0x8c, 0xdd, 0x9c, 0xfc, 0xfa,
		0xe1, 0x53, 0x56, 0x0f, 0xd2, 0x67, 0xd0, 0x5e, 0xe9, 0x3c, 0x3f, 0x93, 0x83, 0x5c, 0x0b, 0xff,
		0xfb, 0xe6, 0x4e, 0x51, 0xe3, 0xfc, 0xd3, 0x2b, 0x20, 0xc0, 0xf9, 0xab, 0x9c, 0x60, 0xb9, 0x57,
		0x99, 0x46, 0x2e, 0xb5, 0xa0, 0xea, 0xf5, 0xa1, 0xe9, 0x8d, 0xa2, 0xe8, 0xf5, 0xa0, 0xe7, 0x15,
		0x90, 0xb6, 0x0a, 0x89, 0x34, 0x35, 0x7c, 0xc3, 0x9a, 0xb6, 0x54, 0xc1, 0x39, 0x68, 0xb2, 0x06,
		0x31, 0x1f, 0xf3, 0xc2, 0xce, 0x62, 0x3e, 0xc6, 0xa8, 0x54, 0xd3, 0x98, 0x8f, 0x61, 0x81, 0xa8,
		0x55, 0x35, 0x24, 0x64, 0x52, 0x58, 0x97, 0x9a, 0xe2, 0x0d, 0x7a, 0xaa, 0xa6, 0xf4, 0xa5, 0x34,
		0x34, 0x57, 0xe4, 0x6a, 0x8e, 0x17, 0x98, 0xf0, 0x21, 0x1f, 0xf4, 0x94, 0x99, 0x81, 0x3f, 0x02,
		0x73, 0xfd, 0x3f, 0x8c, 0x9c, 0x8a, 0x5d, 0x86, 0xde, 0x56, 0x16, 0xfa, 0xac, 0x60, 0xd8, 0x17,
		0xbf, 0xdf, 0x2b, 0x77, 0x28, 0x4c, 0x84, 0xe3, 0x3f, 0x59, 0x3e, 0x72, 0xf1, 0xfb, 0xbd, 0x4a,
		0x33, 0x41, 0xac, 0xe9, 0xc9, 0xc6, 0xdc, 0xb7, 0xb9, 0xa6, 0xe7, 0x59, 0xfa, 0xd6, 0x5d, 0xd6,
		0xf3, 0x2c, 0x45, 0xbf, 0xe5, 0xda, 0x9e, 0xe4, 0x95, 0x2f, 0x2a, 0x7b, 0x68, 0xa2, 0xc0, 0x87,
		0xde, 0x89, 0xa2, 0x52, 0x91, 0xcf, 0xd3, 0x0b, 0xb1, 0xd0, 0x07, 0x0b, 0x7d, 0x36, 0x93, 0x96,
		0x42, 0xb1, 0xcf, 0xe3, 0xcb, 0xb1, 0xe0, 0x07, 0x0b, 0x7e, 0x52, 0xa9, 0x53, 0x2c, 0xf8, 0xd1,
		0x1b, 0xf0, 0x42, 0xfc, 0xbe, 0xe1, 0x40, 0x16, 0x16, 0xfc, 0x3c, 0x4f, 0xb2, 0x58, 0xf0, 0xa3,
		0xac, 0xef, 0xd6, 0x05, 0x06, 0x16, 0xfc, 0xa0, 0xc0, 0xd8, 0x31, 0xa2, 0x3f, 0x53, 0x9a, 0x81,
		0x5a, 0xcd, 0x42, 0xcd, 0x61, 0x48, 0x4c, 0x34, 0x99, 0x67, 0x2f, 0xed, 0x6c, 0xa6, 0x9d, 0xdd,
		0xd2, 0xc5, 0x63, 0xf3, 0x4f, 0x34, 0xf5, 0x06, 0x51, 0xf1, 0x11, 0x33, 0x15, 0x63, 0xea, 0xdc,
		0xa4, 0xc5, 0x10, 0xbf, 0xd9, 0x72, 0xa0, 0xc7, 0x5b, 0x85, 0x48, 0x6b, 0x15, 0x03, 0x07, 0x81,
		0x74, 0x99, 0x40, 0xb0, 0x16, 0x68, 0xd7, 0xe9, 0xd3, 0xe6, 0x7f, 0xfe, 0xd8, 0x2b, 0x1e, 0xce,
		0x1e, 0x39, 0xfb, 0xe8, 0xc7, 0x5e, 0xb1, 0xb4, 0x7c, 0xd6, 0xf4, 0xc3, 0x1f, 0x7b, 0xc5, 0xda,
		0xf2, 0x81, 0x93, 0xcf, 0x26, 0xb7, 0x59, 0x3c, 0x75, 0xfc, 0xd1, 0xf2, 0x56, 0xff, 0xec, 0x4f,
		0x3e, 0xf9, 0xb1, 0x57, 0xac, 0xcc, 0x3e, 0xa8, 0x3d, 0xfc, 0xae, 0xae, 0xdc, 0xf8, 0x60, 0xb2,
		0xce, 0xf9, 0x3f, 0x1e, 0x3d, 0x59, 0xf5, 0x21, 0xa2, 0xf2, 0x90, 0x24, 0x36, 0x90, 0x04, 0x3c,
		0x88, 0x1f, 0x62, 0x94, 0x81, 0x8a, 0xd6, 0xf7, 0x53, 0x1a, 0x5e, 0xd2, 0xd1, 0xef, 0xd2, 0xe4,
		0xc7, 0xf4, 0xf7, 0xf2, 0x92, 0x63, 0x7e, 0x97, 0xf7, 0x27, 0xa4, 0xfb, 0xe1, 0xe7, 0xcf, 0x8f,
		0x1f, 0xfe, 0xa9, 0x3c, 0xc8, 0x5f, 0x88, 0x38, 0x65, 0xa3, 0x12, 0xf1, 0x2d, 0x9e, 0x24, 0x0a,
		0x32, 0x14, 0x64, 0x09, 0x05, 0x99, 0x8d, 0x7a, 0x1a, 0x25, 0xa2, 0x51, 0x89, 0x88, 0x24, 0x81,
		0xa2, 0x15, 0x45, 0x6b, 0xea, 0x1b, 0xc7, 0xe1, 0x48, 0xd0, 0x9f, 0x3f, 0x8b, 0x82, 0xc4, 0x03,
		0x2a, 0x3e, 0xa1, 0xeb, 0x85, 0xde, 0xf8, 0x13, 0x49, 0x8b, 0x14, 0x82, 0xce, 0x39, 0x0a, 0x5e,
		0xe3, 0x82, 0x17, 0x7d, 0xf5, 0x37, 0x2a, 0x2f, 0xd1, 0x75, 0x47, 0x31, 0x87, 0x62, 0x6e, 0xce,
		0x0d, 0xe8, 0xb6, 0xa1, 0xbc, 0x7c, 0x59, 0x5e, 0x22, 0x85, 0xa0, 0xe0, 0x45, 0xc1, 0xab, 0x4d,
		0xf0, 0x86, 0x31, 0x1b, 0xb0, 0x00, 0xdd, 0x36, 0x74, 0xec, 0x37, 0x09, 0x5e, 0xa4, 0x10, 0x74,
		0xec, 0x51, 0xf0, 0x1a, 0x13, 0xbc, 0xe8, 0xd8, 0xbf, 0x51, 0x79, 0x89, 0x8e, 0x3d, 0x8a, 0x39,
		0x14, 0x73, 0x73, 0x6e, 0x40, 0xb7, 0x0d, 0xe5, 0xe5, 0xcb, 0xf2, 0x12, 0x29, 0x04, 0x05, 0x2f,
		0x0a, 0xde, 0xd4, 0x37, 0x76, 0x42, 0x2f, 0x8c, 0x3f, 0x4d, 0x48, 0xf9, 0x9f, 0xf2, 0x03, 0xfa,
		0xdb, 0xd6, 0xc8, 0xc3, 0xb7, 0x70, 0x70, 0xd8, 0x5f, 0x56, 0xaf, 0x98, 0xd4, 0x59, 0x8d, 0xc5,
		0x02, 0x12, 0xdf, 0x6b, 0xac, 0xbe, 0xd2, 0x51, 0x7c, 0xd5, 0xa4, 0xc1, 0x60, 0x52, 0x98, 0x0e,
		0xae, 0xfc, 0xca, 0xc4, 0x48, 0x06, 0x43, 0x7d, 0xfb, 0x17, 0xfd, 0xfc, 0x0e, 0x35, 0xdf, 0xd7,
		0x60, 0x7b, 0x7e, 0x8d, 0x23, 0x17, 0x8c, 0x8c, 0x5a, 0xc0, 0xa3, 0xd2, 0x28, 0x42, 0x77, 0xb0,
		0xd1, 0x77, 0x72, 0x89, 0x88, 0x8d, 0xbe, 0x8d, 0x9f, 0x2c, 0x36, 0xfa, 0xc6, 0xfe, 0x0b, 0x4f,
		0x76, 0x16, 0xfb, 0x2f, 0x18, 0x95, 0x6a, 0xd8, 0xe8, 0xdb, 0x8c, 0x71, 0x8f, 0x8d, 0xbe, 0xf3,
		0xb6, 0x42, 0xb1, 0xd1, 0x37, 0x36, 0xfa, 0x36, 0x7a, 0x05, 0xcc, 0x46, 0xdf, 0x4f, 0xfa, 0xd8,
		0x3e, 0xfa, 0xdb, 0x70, 0xc3, 0xef, 0xfa, 0x9d, 0x58, 0xed, 0x90, 0xbc, 0xf2, 0x27, 0xb6, 0xfd,
		0xd6, 0xeb, 0x0c, 0x60, 0xdb, 0xef, 0x24, 0xd4, 0xae, 0xbb, 0xfd, 0xf7, 0x0b, 0xf4, 0xfd, 0x96,
		0x9b, 0x80, 0xcb, 0x75, 0xc6, 0x56, 0xdc, 0x4d, 0xe5, 0x5e, 0xe0, 0xef, 0x24, 0x36, 0x2a, 0xe9,
		0x06, 0x25, 0xdb, 0x98, 0x17, 0x36, 0x22, 0xc9, 0x06, 0x3c, 0xff, 0xc6, 0xeb, 0xef, 0xf3, 0xf8,
		0x93, 0x27, 0x6f, 0xf6, 0xda, 0x1b, 0xbd, 0xfe, 0x26, 0xcf, 0xbc, 0xc5, 0x6b, 0xab, 0x7f, 0xbc,
		0xf2, 0xe5, 0xfa, 0x56, 0xd6, 0x56, 0x70, 0x42, 0x3f, 0x0a, 0x83, 0x99, 0x7c, 0x7a, 0xbc, 0xae,
		0x85, 0xc7, 0xb0, 0xf2, 0x9d, 0x27, 0x6f, 0xf5, 0x7c, 0x1b, 0xd0, 0x8d, 0x7e, 0xf2, 0x4b, 0xfe,
		0xef, 0xaa, 0x5f, 0x1b, 0x79, 0x44, 0xf4, 0xc3, 0xd8, 0x7f, 0xee, 0x9d, 0x5f, 0x71, 0x58, 0x13,
		0x3b, 0xa2, 0x89, 0x1d, 0xcc, 0xa7, 0x8e, 0xe3, 0x62, 0x71, 0x92, 0x14, 0xb0, 0xa9, 0x91, 0xe5,
		0x72, 0x7b, 0x37, 0xbf, 0xd4, 0xda, 0x49, 0x6c, 0x7a, 0xa9, 0x97, 0xfb, 0xb2, 0xbe, 0x1a, 0xc0,
		0x48, 0x12, 0xa0, 0x48, 0x78, 0x50, 0xb2, 0x11, 0x06, 0xe9, 0x08, 0x82, 0x74, 0x84, 0x20, 0xf9,
		0x41, 0xaa, 0x09, 0xad, 0xd7, 0x3a, 0x95, 0x16, 0x7a, 0xc4, 0xf9, 0x15, 0x79, 0x24, 0xa0, 0xc9,
		0xa7, 0x1d, 0x2c, 0x2f, 0xb1, 0x63, 0xce, 0x41, 0x02, 0x82, 0x50, 0x0d, 0x3d, 0xe5, 0x3f, 0xe8,
		0xe0, 0x75, 0x82, 0xd1, 0x63, 0x1e, 0x24, 0x9e, 0x74, 0xe0, 0xcc, 0x4f, 0x53, 0x72, 0xc4, 0xc1,
		0xec, 0xba, 0xb7, 0x31, 0xdb, 0x40, 0x82, 0xe4, 0xd2, 0x46, 0x3d, 0xe1, 0x0d, 0x37, 0x48, 0x4e,
		0x92, 0x66, 0x7c, 0x30, 0xfd, 0x5e, 0xc3, 0xfc, 0x8d, 0x76, 0x97, 0x56, 0xc7, 0xf2, 0xd7, 0xdd,
		0x85, 0x3c, 0xdc, 0x95, 0xa2, 0xe1, 0x17, 0xad, 0xa5, 0xf6, 0xec, 0x89, 0xd7, 0x27, 0x8b, 0x27,
		0x2e, 0x7f, 0xbd, 0xfe, 0x3c, 0x7f, 0xe2, 0xf5, 0x8c, 0xb0, 0x75, 0x79, 0x10, 0x89, 0xcc, 0x73,
		0x99, 0xce, 0xee, 0x4a, 0x1d, 0xdd, 0x95, 0xb9, 0xbb, 0x8c, 0xdc, 0x8d, 0xdc, 0x6d, 0x8c, 0xbb,
		0x65, 0xe3, 0x5f, 0xa9, 0x99, 0x5b, 0x22, 0xee, 0x65, 0x4f, 0x74, 0x20, 0xe1, 0x6e, 0xa7, 0x89,
		0x14, 0x24, 0xdc, 0x5f, 0x13, 0x23, 0xc4, 0x9c, 0x21, 0xe1, 0x9c, 0x49, 0x8c, 0x0e, 0x9b, 0x5f,
		0x80, 0xa6, 0x34, 0x9a, 0xd2, 0x68, 0x4a, 0xa3, 0xb2, 0xdd, 0x6e, 0x65, 0x3b, 0x93, 0x86, 0x99,
		0x19, 0xd2, 0x27, 0xd3, 0xe7, 0xa1, 0x19, 0x8d, 0x66, 0x34, 0x72, 0x76, 0x26, 0x9c, 0x9d, 0x91,
		0x11, 0x3d, 0x67, 0xec, 0x2d, 0x34, 0xa1, 0x93, 0x59, 0x94, 0xe9, 0xf7, 0xd6, 0x88, 0xf9, 0x9c,
		0xcc, 0xe2, 0x91, 0xb3, 0x74, 0xd0, 0x78, 0xde, 0x46, 0xe3, 0x79, 0x46, 0xd5, 0x92, 0xfa, 0x75,
		0x72, 0x95, 0x9c, 0x7a, 0xdd, 0x43, 0xc3, 0x19, 0xd5, 0xeb, 0xd3, 0xe5, 0x48, 0x43, 0x63, 0xd5,
		0x0b, 0x5d, 0x97, 0x85, 0xac, 0xdb, 0xa5, 0xe6, 0x92, 0xba, 0x08, 0xaa, 0x5a, 0x2e, 0x81, 0x4b,
		0xa0, 0xa8, 0xe4, 0xa2, 0x91, 0x84, 0x86, 0x8b, 0x46, 0xa8, 0xde, 0x50, 0xbd, 0x61, 0x6c, 0x08,
		0x55, 0xdc, 0xb6, 0x7b, 0x90, 0xd1, 0x28, 0xbb, 0xb8, 0x50, 0x34, 0xc2, 0x98, 0x10, 0xc6, 0x84,
		0x90, 0xa3, 0x8d, 0x73, 0x74, 0x56, 0xf1, 0xa0, 0x68, 0xb4, 0x95, 0xb1, 0xa0, 0x57, 0xad, 0xc7,
		0x74, 0x7b, 0x6a, 0xc2, 0x3c, 0xee, 0x93, 0x5e, 0xcc, 0x9c, 0xe4, 0x16, 0xf2, 0xec, 0xfb, 0x68,
		0x24, 0xa3, 0x91, 0x8c, 0x46, 0x32, 0xaa, 0xd4, 0xed, 0x56, 0xa9, 0x53, 0x61, 0x98, 0x99, 0x9d,
		0x7c, 0x36, 0x79, 0x1c, 0x9a, 0xca, 0x68, 0x2a, 0x23, 0x5f, 0x67, 0xc1, 0xd7, 0x19, 0x59, 0xcb,
		0x33, 0xb6, 0xde, 0x42, 0x83, 0x39, 0x91, 0x31, 0x99, 0x7a, 0x67, 0xcd, 0x98, 0xcd, 0x81, 0x8c,
		0xcd, 0x1c, 0xa0, 0xc1, 0x8c, 0x06, 0x33, 0x1a, 0xcc, 0xa8, 0x58, 0xb7, 0x5e, 0xb1, 0x06, 0x19,
		0x5a, 0xcb, 0x01, 0x9a, 0xca, 0x68, 0x2a, 0x23, 0x47, 0x1b, 0xe7, 0xe8, 0xcc, 0xec, 0xe4, 0x60,
		0x3b, 0x8d, 0xe4, 0xc0, 0xa4, 0x85, 0x1c, 0x98, 0x30, 0x8f, 0x59, 0x20, 0xe8, 0x20, 0x26, 0x82,
		0xba, 0x45, 0x87, 0xc5, 0xce, 0x88, 0x89, 0xe4, 0xd6, 0xf2, 0x33, 0xd7, 0xa2, 0xf1, 0x8c, 0xc6,
		0x33, 0x1a, 0xcf, 0xa8, 0x6a, 0xb7, 0x5b, 0xd5, 0xae, 0x0b, 0xc6, 0xcc, 0x6c, 0xe9, 0xc6, 0xe2,
		0xd1, 0x27, 0xd3, 0x27, 0xa3, 0x65, 0x8d, 0x96, 0x35, 0xb2, 0x7b, 0xd6, 0xec, 0x9e, 0x91, 0xa1,
		0xbd, 0xce, 0xed, 0x5b, 0x68, 0x76, 0x4b, 0x9b, 0xa1, 0x3a, 0x37, 0xdc, 0x84, 0x4d, 0x9e, 0xa8,
		0x44, 0x43, 0xa6, 0x34, 0x23, 0x61, 0x49, 0x06, 0xda, 0xdd, 0x36, 0xd8, 0xdd, 0x89, 0x4b, 0x28,
		0x16, 0x3b, 0xef, 0x51, 0xd2, 0x8f, 0x69, 0x3f, 0xc9, 0xae, 0xcf, 0xd5, 0xea, 0x41, 0x82, 0xef,
		0xb6, 0x67, 0x9c, 0xfa, 0xf1, 0xe3, 0xcc, 0xba, 0xd9, 0x9d, 0x90, 0xa2, 0x01, 0x86, 0x88, 0xc2,
		0x58, 0xc2, 0x2d, 0x9d, 0x7c, 0x1b, 0x1d, 0x51, 0x74, 0x44, 0xd1, 0x11, 0x45, 0xcb, 0x74, 0xbb,
		0x2d, 0xd3, 0xb1, 0x28, 0xcc, 0xcc, 0xf5, 0x6c, 0x87, 0x31, 0x7a, 0x9b, 0xe8, 0x6d, 0x22, 0x4f,
		0x67, 0xc0, 0xd3, 0x19, 0xf9, 0x97, 0x13, 0x96, 0xde, 0x42, 0x97, 0x32, 0x81, 0x09, 0x99, 0x72,
		0x57, 0xcd, 0x98, 0xc9, 0xb7, 0x34, 0x2e, 0xf2, 0x51, 0x14, 0x79, 0xf7, 0x32, 0xe6, 0xf2, 0xca,
		0x55, 0x68, 0x36, 0xa3, 0xd9, 0x8c, 0x66, 0x33, 0xaa, 0xd8, 0x6d, 0x57, 0xb1, 0x4b, 0x91, 0x98,
		0xa1, 0xf9, 0x7c, 0x4b, 0xe3, 0xce, 0xe4, 0x99, 0x68, 0x45, 0xa3, 0x15, 0x8d, 0x2c, 0x9e, 0x1d,
		0x8b, 0x67, 0x66, 0x4d, 0x2f, 0x39, 0x7c, 0x2b, 0x8d, 0xea, 0xc4, 0x86, 0xa6, 0x9e, 0x4d, 0x36,
		0x62, 0x63, 0xc7, 0x61, 0x44, 0xe3, 0xc9, 0x74, 0xa5, 0xe4, 0x16, 0xf6, 0xf2, 0x1a, 0xb4, 0xaf,
		0xd1, 0xbe, 0xde, 0x40, 0x52, 0xf7, 0xf2, 0xda, 0x77, 0x71, 0x25, 0xda, 0xd8, 0xa8, 0x80, 0x53,
		0x2a, 0xe0, 0xa4, 0xe4, 0xaa, 0xea, 0x16, 0xa6, 0x73, 0x0f, 0x15, 0x49, 0x58, 0x99, 0x94, 0xd3,
		0x90, 0xb4, 0x26, 0xd2, 0x4e, 0x4b, 0xe2, 0xda, 0x48, 0x5d, 0x1b, 0xc9, 0xeb, 0x23, 0x7d, 0x39,
		0x16, 0x90, 0x64, 0x05, 0x65, 0x96, 0x58, 0x5c, 0x28, 0xd5, 0x63, 0x73, 0x23, 0xd9, 0x48, 0xf4,
		0xdc, 0xdc, 0xc4, 0x26, 0x6f, 0x65, 0x78, 0x7e, 0x0a, 0xf6, 0xd1, 0xc5, 0x46, 0xda, 0xd9, 0x49,
		0x3b, 0x5b, 0xe9, 0x67, 0x2f, 0x35, 0x36, 0x53, 0x64, 0xb7, 0xc5, 0xf2, 0xf5, 0x8d, 0xcf, 0x97,
		0xee, 0x19, 0xba, 0x51, 0xdd, 0x1c, 0x66, 0x35, 0x2d, 0x5b, 0x41, 0x3f, 0xdc, 0xcc, 0xe6, 0x9e,
		0xa7, 0x14, 0x37, 0xd3, 0xdb, 0xa0, 0xbc, 0x41, 0x79, 0x83, 0xf2, 0x46, 0x91, 0x72, 0x46, 0x01,
		0x0b, 0x03, 0x1d, 0xe2, 0xe6, 0x28, 0xc5, 0x3d, 0x66, 0xaf, 0xf3, 0x23, 0xd5, 0x99, 0xa6, 0xa3,
		0x59, 0xbd, 0x42, 0x58, 0x93, 0x30, 0x4e, 0x49, 0x26, 0x06, 0x76, 0xa6, 0x17, 0x86, 0x1e, 0x25,
		0x81, 0xce, 0xad, 0x29, 0xbd, 0x91, 0xad, 0x61, 0x81, 0xa8, 0x55, 0x35, 0x6e, 0x4c, 0x55, 0xc3,
		0xad, 0x2e, 0x49, 0x30, 0x48, 0xcf, 0x59, 0xfa, 0x36, 0x6b, 0xb1, 0xb0, 0x73, 0x16, 0xa4, 0x56,
		0x33, 0x9a, 0x1c, 0xed, 0x57, 0x6f, 0xfb, 0x6d, 0x66, 0xac, 0x1c, 0x95, 0xcb, 0x95, 0xca, 0x41,
		0x79, 0xaf, 0x52, 0x3b, 0xdc, 0xaf, 0x1e, 0x1c, 0xec, 0x1f, 0xee, 0x1d, 0x6a, 0x7e, 0xd2, 0x59,
		0x4c, 0x1c, 0xc1, 0xc2, 0xe0, 0x94, 0x0d, 0xd8, 0x64, 0x62, 0xfa, 0x9e, 0xb6, 0xfb, 0x3f, 0xfc,
		0xa1, 0xf1, 0xf0, 0xc8, 0x9d, 0xb1, 0xc3, 0xdb, 0xcb, 0xec, 0xf0, 0x0e, 0x2c, 0x3a, 0xbc, 0x77,
		0x30, 0xee, 0x72, 0xf5, 0x46, 0x44, 0xf5, 0x48, 0xb7, 0xac, 0x3e, 0x44, 0x59, 0x0d, 0x8b, 0xdd,
		0xf7, 0x50, 0x32, 0xdb, 0x72, 0x54, 0xa5, 0xc3, 0x6a, 0xb5, 0x76, 0x50, 0xad, 0xee, 0x1d, 0x54,
		0x0e, 0xf6, 0x8e, 0xf6, 0xf7, 0x4b, 0xb5, 0xd2, 0x3e, 0x8a, 0xe6, 0x6d, 0x15, 0xcd, 0x2e, 0x75,
		0x98, 0x4f, 0x3c, 0xad, 0xd2, 0xb9, 0x54, 0xd6, 0x70, 0xaf, 0x35, 0x1a, 0x2a, 0xa3, 0xcc, 0x57,
		0x3b, 0x8e, 0x32, 0xca, 0x7c, 0x5b, 0x64, 0x7e, 0x05, 0x8f, 0xea, 0x8d, 0x08, 0xf8, 0x77, 0xd9,
		0x3e, 0xf7, 0x01, 0x58, 0x5e, 0x54, 0x11, 0xab, 0xb7, 0xb8, 0x5e, 0x19, 0x40, 0xb6, 0xc0, 0x51,
		0xcd, 0x7f, 0x55, 0x40, 0xe7, 0x2e, 0x57, 0xa1, 0x06, 0x2f, 0x5b, 0xac, 0x61, 0xfe, 0xab, 0x1c,
		0x5a, 0x57, 0xfe, 0x84, 0x24, 0x4e, 0x47, 0x2d, 0xf1, 0x9c, 0x26, 0xe1, 0xac, 0x68, 0xcf, 0x22,
		0x1e, 0x03, 0xf1, 0x18, 0xf2, 0x72, 0x47, 0x39, 0x51, 0xa3, 0xd0, 0x09, 0x61, 0xa3, 0xf9, 0xab,
		0x10, 0xe9, 0x52, 0xea, 0x94, 0x90, 0x8d, 0xc0, 0x90, 0x83, 0xfd, 0xaf, 0xed, 0xa7, 0x2c, 0x70,
		0x7a, 0x47, 0x07, 0x84, 0xab, 0x8c, 0x22, 0x03, 0x45, 0x46, 0xc2, 0x65, 0x2a, 0x43, 0xb8, 0xa6,
		0x7c, 0x3a, 0x8a, 0x49, 0xcf, 0xd3, 0x80, 0xad, 0x78, 0x74, 0x37, 0x84, 0x58, 0x20, 0xc4, 0x22,
		0x37, 0x76, 0x4b, 0xe7, 0xc3, 0xe4, 0x0f, 0xb1, 0x48, 0x9f, 0x33, 0x4f, 0x99, 0x2b, 0xcf, 0x06,
		0xd3, 0x85, 0x08, 0x52, 0x14, 0x37, 0x28, 0x6e, 0x10, 0x41, 0x8a, 0x08, 0x52, 0x94, 0x37, 0x28,
		0x6f, 0xb6, 0x47, 0xde, 0x20, 0x82, 0xd4, 0x84, 0x10, 0xd6, 0x24, 0x8c, 0x53, 0x92, 0x89, 0x81,
		0x9d, 0x41, 0x04, 0xe9, 0xc6, 0xad, 0x41, 0x04, 0xa9, 0xc4, 0xc2, 0x10, 0x41, 0xfa, 0xdc, 0x93,
		0x30, 0x67, 0x8d, 0x08, 0x52, 0x7d, 0xc6, 0x85, 0xfe, 0xbb, 0x20, 0x82, 0x74, 0x03, 0xd5, 0x22,
		0x82, 0x14, 0x18, 0xbb, 0x23, 0x9a, 0xc8, 0x9a, 0xa3, 0x42, 0x04, 0x29, 0x8a, 0x66, 0x44, 0x90,
		0x6e, 0x91, 0xcc, 0x47, 0x04, 0x29, 0x22, 0x48, 0x51, 0xc0, 0x67, 0x2c, 0xe0, 0x11, 0x41, 0x0a,
		0x06, 0x41, 0xaa, 0x82, 0x61, 0xda, 0xd1, 0x0b, 0x20, 0x95, 0x68, 0x06, 0x29, 0x7f, 0x3e, 0x7a,
		0xdb, 0x84, 0xfd, 0x49, 0xef, 0x25, 0x33, 0xcb, 0x85, 0x26, 0xe3, 0xe2, 0x58, 0x08, 0xc9, 0xf6,
		0x62, 0xe7, 0x2c, 0xa8, 0x7b, 0xd4, 0x1f, 0xef, 0x9e, 0x9c, 0x84, 0x1a, 0x4b, 0xe0, 0x95, 0x2b,
		0xd3, 0xd9, 0xb3, 0x85, 0x56, 0xec, 0xd2, 0x98, 0xba, 0x9f, 0xc7, 0x6f, 0x1d, 0x8c, 0x3c, 0xcf,
		0xee, 0xa6, 0xa7, 0xeb, 0xe4, 0x9f, 0x41, 0xd7, 0xd3, 0x75, 0x82, 0xdf, 0xb2, 0xbe, 0xa7, 0x49,
		0xdb, 0x7f, 0x6a, 0xd9, 0x64, 0x13, 0x4d, 0x4f, 0x79, 0xd8, 0x17, 0xb7, 0x24, 0xa6, 0x45, 0x3f,
		0x74, 0x47, 0x9e, 0xc4, 0x6c, 0xba, 0xa7, 0x17, 0x62, 0xfb, 0x53, 0x6c, 0x7f, 0xfa, 0xf4, 0x8b,
		0x38, 0x5e, 0x00, 0x5b, 0x9f, 0x6e, 0x57, 0xef, 0xf1, 0x27, 0x52, 0x31, 0xb3, 0x09, 0x03, 0x9d,
		0xd9, 0x73, 0xcf, 0x27, 0x8f, 0xc5, 0x21, 0x03, 0x38, 0x64, 0x00, 0x19, 0x3d, 0x53, 0x46, 0xcf,
		0x68, 0xce, 0xc0, 0x13, 0x3e, 0xdf, 0xc2, 0x51, 0x03, 0x72, 0x76, 0xa7, 0xb6, 0xad, 0x36, 0x62,
		0x7b, 0x27, 0x92, 0x99, 0x52, 0xb2, 0x52, 0xda, 0xce, 0x2e, 0xa3, 0x9d, 0x6d, 0xbf, 0x9d, 0x4d,
		0x3c, 0x2f, 0x74, 0x26, 0x53, 0xd2, 0x27, 0x83, 0x38, 0xe4, 0xd5, 0xf0, 0xd3, 0x1b, 0xc8, 0x29,
		0xe4, 0x3d, 0xb4, 0xbc, 0x51, 0x21, 0x3f, 0x5d, 0x8e, 0x34, 0x70, 0xf6, 0x11, 0x66, 0xa4, 0x52,
		0x96, 0x39, 0xb4, 0x19, 0x1d, 0x4a, 0xe0, 0x8c, 0x14, 0xf3, 0x81, 0x0a, 0xf1, 0xec, 0x34, 0xf9,
		0xbd, 0xb4, 0xc8, 0xf9, 0x94, 0x49, 0x20, 0x1d, 0xc9, 0x1e, 0x95, 0x9a, 0x85, 0x34, 0x79, 0x36,
		0x5d, 0x5b, 0x56, 0x2d, 0x1f, 0x55, 0x8f, 0x6a, 0x07, 0xe5, 0xa3, 0xfd, 0x1c, 0xf7, 0xce, 0x50,
		0xda, 0xe0, 0x2a, 0x43, 0xbf, 0xd0, 0xa5, 0xdc, 0x89, 0x59, 0x24, 0x65, 0x98, 0xaf, 0x40, 0x14,
		0x96, 0x17, 0xa3, 0x4a, 0x42, 0x95, 0x94, 0x9b, 0x4a, 0x92, 0x2e, 0x53, 0x90, 0x2c, 0x47, 0xd0,
		0xc3, 0x6b, 0xd4, 0x8f, 0x54, 0x46, 0x4d, 0x4d, 0x2f, 0x4b, 0x3a, 0x4b, 0x88, 0xf6, 0xc9, 0xc8,
		0x9b, 0x9c, 0x68, 0x9f, 0x78, 0x9c, 0x22, 0x5f, 0x22, 0x5f, 0xe6, 0xc7, 0x97, 0xf2, 0x45, 0x32,
		0x92, 0xc5, 0x30, 0x9a, 0x18, 0xf3, 0xef, 0x11, 0x8b, 0xc6, 0x1b, 0x5e, 0xec, 0x13, 0xe6, 0x8d,
		0x62, 0x85, 0x40, 0xe9, 0xfa, 0x2d, 0xb6, 0x9b, 0x61, 0x89, 0x47, 0x62, 0x9f, 0x6f, 0x25, 0xbb,
		0xce, 0x5e, 0x1d, 0x99, 0xd5, 0x34, 0xb3, 0xfa, 0x8c, 0xfb, 0x44, 0x38, 0xc3, 0x34, 0xdc, 0xba,
		0xb8, 0x07, 0xb2, 0x2b, 0xb2, 0x2b, 0xb2, 0xab, 0x7e, 0x76, 0xed, 0xb3, 0xd8, 0x9f, 0xe4, 0x03,
		0x6e, 0x68, 0xcc, 0x95, 0xbc, 0xcc, 0xb5, 0x3b, 0xa0, 0x49, 0x8b, 0x26, 0x2d, 0xba, 0x9a, 0x2f,
		0x3e, 0x73, 0x48, 0x62, 0x37, 0x1d, 0xd7, 0xad, 0xdd, 0x01, 0xb9, 0x0e, 0xb9, 0x0e, 0xb9, 0xee,
		0xc5, 0x67, 0x32, 0x57, 0x9e, 0xcf, 0x98, 0x8b, 0x9c, 0x85, 0x9c, 0x85, 0x9c, 0xf5, 0xf2, 0x33,
		0x27, 0xe9, 0x6f, 0x25, 0x3d, 0xb6, 0xb8, 0x12, 0xb9, 0x0c, 0xb9, 0x0c, 0xb9, 0xec, 0xc5, 0x67,
		0xfa, 0xd4, 0x0f, 0x63, 0x85, 0x0c, 0xc5, 0xec, 0x3a, 0xc4, 0x83, 0x23, 0x87, 0xa5, 0xe4, 0x30,
		0xd9, 0xa6, 0xd1, 0x05, 0x72, 0x43, 0x98, 0xa7, 0xd4, 0x29, 0x7a, 0x09, 0xae, 0x5a, 0xdc, 0x02,
		0x07, 0x30, 0x18, 0x22, 0x74, 0x6d, 0x04, 0xaf, 0x8d, 0xf0, 0xf5, 0x31, 0x80, 0x1c, 0x23, 0x48,
		0x32, 0x84, 0xba, 0xea, 0x59, 0x3b, 0x79, 0xe5, 0x56, 0x3f, 0x29, 0x5a, 0xfb, 0xa4, 0x6c, 0xeb,
		0x90, 0xa2, 0xab, 0xa3, 0x8e, 0xb6, 0x0d, 0x9a, 0xfa, 0xbd, 0xe8, 0xaa, 0xf5, 0xd7, 0x59, 0xdb,
		0x9f, 0xa2, 0xed, 0x82, 0x96, 0x36, 0x0b, 0xba, 0xb7, 0x56, 0x7f, 0xeb, 0x1c, 0xad, 0xbb, 0x9d,
		0x51, 0xe7, 0x80, 0x2b, 0x00, 0x63, 0x4d, 0x46, 0x82, 0x79, 0xec, 0xff, 0xa7, 0xae, 0xba, 0x3e,
		0x5e, 0xdc, 0x01, 0xd5, 0x31, 0xaa, 0x63, 0x54, 0xc7, 0xa8, 0x8e, 0x51, 0x1d, 0xa3, 0x3a, 0x46,
		0x75, 0x6c, 0xca, 0xe5, 0xce, 0xbc, 0x32, 0x53, 0x10, 0x41, 0x77, 0xa5, 0x42, 0x46, 0x3b, 0x29,
		0xaa, 0x04, 0xc7, 0x4f, 0xbb, 0x3e, 0x9f, 0x3e, 0x2d, 0xcb, 0x50, 0x5a, 0x7f, 0x50, 0x74, 0x95,
		0x4a, 0xae, 0x17, 0x57, 0x62, 0xc0, 0x1a, 0xc3, 0x69, 0x29, 0x79, 0x5b, 0x3d, 0x60, 0xed, 0x4a,
		0x96, 0x4b, 0x2f, 0xc2, 0xd5, 0x12, 0xd7, 0xb4, 0x89, 0x10, 0x34, 0x0e, 0xa4, 0xed, 0x91, 0xc2,
		0x8f, 0xbd, 0xe2, 0xd1, 0xd5, 0x3f, 0xd5, 0x87, 0x9f, 0x3f, 0x8b, 0xef, 0xf7, 0x7e, 0x94, 0x8a,
		0x47, 0x57, 0xbf, 0x4b, 0x3f, 0xf6, 0x8a, 0xe5, 0xab, 0x0f, 0x2b, 0x9f, 0xfc, 0x28, 0x15, 0xcb,
		0x57, 0x93, 0x6f, 0xfe, 0xae, 0xfc, 0xd8, 0x2b, 0x96, 0xae, 0x3e, 0x24, 0x3f, 0x85, 0x2b, 0x99,
		0xb7, 0x68, 0x75, 0x1a, 0x7f, 0x29, 0xbf, 0xca, 0xff, 0x2a, 0xbe, 0xcb, 0x7f, 0x15, 0x40, 0x96,
		0x13, 0x8d, 0x85, 0x97, 0xd4, 0x00, 0xad, 0x47, 0x62, 0x4f, 0xa6, 0xb5, 0x19, 0x8a, 0x3d, 0x14,
		0x7b, 0xfa, 0xc5, 0x9e, 0x1d, 0x79, 0x3a, 0x35, 0x0e, 0x43, 0xee, 0x42, 0xee, 0x42, 0xee, 0x7a,
		0x9d, 0xbb, 0xc2, 0x88, 0xc6, 0xc5, 0xb1, 0x97, 0x32, 0xe2, 0xf2, 0x4c, 0xb6, 0x7a, 0x31, 0xf2,
		0x1a, 0xf2, 0x5a, 0x6e, 0xbc, 0xc6, 0x5c, 0x1a, 0x08, 0x26, 0xee, 0xe5, 0x66, 0xae, 0x2f, 0x18,
		0x4e, 0xa6, 0x51, 0x6b, 0x63, 0xf6, 0xa8, 0xcf, 0x84, 0xa7, 0x48, 0xc3, 0x9f, 0xb4, 0xce, 0xdb,
		0xad, 0x8b, 0xfa, 0x45, 0xf7, 0xba, 0xd5, 0xae, 0x5f, 0x5e, 0x77, 0xba, 0xc7, 0xdd, 0xaf, 0x1d,
		0xd9, 0xf3, 0x9f, 0x04, 0xa0, 0xb8, 0x52, 0x84, 0x33, 0xe5, 0x04, 0xc6, 0xc6, 0xc5, 0xf1, 0x49,
		0xb7, 0xf1, 0xad, 0x5e, 0xc8, 0xa2, 0x05, 0x43, 0xca, 0xb5, 0x9e, 0x36, 0x3a, 0xc7, 0x9f, 0x9b,
		0xf5, 0x53, 0x1b, 0xd6, 0xaa, 0xbc, 0xab, 0xef, 0xcc, 0x84, 0xea, 0x1e, 0x32, 0xd4, 0x44, 0x11,
		0x89, 0xa7, 0xa2, 0x48, 0x52, 0x09, 0xcd, 0xae, 0x43, 0xfd, 0x83, 0xfa, 0x27, 0x37, 0xfd, 0xe3,
		0x51, 0xd2, 0x57, 0xd4, 0x3d, 0x07, 0x72, 0x31, 0xa4, 0x49, 0xfc, 0xf9, 0xe3, 0xc7, 0xdd, 0xe9,
		0xff, 0x96, 0x81, 0xe6, 0x69, 0x78, 0x78, 0x77, 0xe2, 0xf6, 0x64, 0xcb, 0xb4, 0xa2, 0x18, 0x84,
		0x4a, 0x5c, 0x3b, 0xb9, 0x10, 0xd9, 0x16, 0xd9, 0x16, 0x5d, 0xb4, 0x17, 0x9f, 0x19, 0x53, 0x3f,
		0xbc, 0x91, 0x42, 0x7d, 0x2e, 0x5e, 0x70, 0x79, 0x29, 0xf2, 0x19, 0xf2, 0x59, 0x6e, 0x7c, 0x66,
		0x49, 0xf5, 0x36, 0xa7, 0x31, 0x23, 0x9e, 0x92, 0x3a, 0x5b, 0x5e, 0x8a, 0x8c, 0x86, 0x8c, 0x86,
		0x0a, 0xed, 0x65, 0x3e, 0x9b, 0x77, 0x4d, 0x56, 0xae, 0xd7, 0x5e, 0xbb, 0x03, 0x72, 0x1d, 0x72,
		0x1d, 0x72, 0xdd, 0x8b, 0xcf, 0x14, 0xd4, 0x8f, 0x68, 0x4c, 0x84, 0x52, 0xc7, 0xaf, 0xd5, 0x8b,
		0xb1, 0xf2, 0x0d, 0x79, 0x2d, 0x25, 0xaf, 0xc9, 0x57, 0xbe, 0x79, 0x24, 0xf6, 0x8b, 0x9c, 0xde,
		0xd0, 0x98, 0x49, 0xb4, 0x95, 0x5c, 0x3b, 0xf8, 0x27, 0xf7, 0x41, 0xd0, 0xbd, 0x21, 0x92, 0xd7,
		0x46, 0xfa, 0xda, 0x58, 0x40, 0x1f, 0x2b, 0xc8, 0xb1, 0x84, 0x24, 0x6b, 0xa8, 0xab, 0xa3, 0xb5,
		0x93, 0x57, 0x4b, 0x8a, 0xad, 0xc9, 0x6f, 0x05, 0x2c, 0x73, 0xba, 0x24, 0xd9, 0xda, 0x8b, 0xb4,
		0xda, 0xf5, 0x8b, 0x93, 0xd6, 0xc5, 0x59, 0xe3, 0xcb, 0xf5, 0x71, 0xf3, 0xf8, 0xf2, 0xfc, 0xba,
		0x53, 0xff, 0x56, 0xbf, 0x6c, 0x74, 0xff, 0x53, 0x48, 0xd3, 0x57, 0x9b, 0xa7, 0x1a, 0xc0, 0x9c,
		0x12, 0x82, 0x3e, 0x7f, 0xb5, 0xaf, 0x17, 0x7f, 0x5e, 0xb4, 0xbe, 0x5f, 0x14, 0xf2, 0x00, 0xd3,
		0x6b, 0x7a, 0x85, 0xf3, 0xc6, 0x45, 0xeb, 0xd2, 0xe6, 0x17, 0xf8, 0x7e, 0x7c, 0x79, 0xd1, 0xb8,
		0xf8, 0x62, 0xf3, 0x2b, 0x9c, 0x5c, 0x36, 0xba, 0x8d, 0x93, 0xe3, 0xa6, 0xd5, 0x74, 0x74, 0xfc,
		0xff, 0xa5, 0xa2, 0x23, 0xa5, 0x2b, 0xaf, 0xc0, 0xf4, 0xc1, 0x97, 0x29, 0x3b, 0x9c, 0x59, 0x31,
		0x72, 0xa8, 0x9d, 0x4d, 0xb6, 0x90, 0x0c, 0x7c, 0x07, 0x2d, 0x21, 0xb4, 0x84, 0x2c, 0xb4, 0x84,
		0xe4, 0xe3, 0xcf, 0x6b, 0x56, 0x50, 0x09, 0x0c, 0xdb, 0x8b, 0x61, 0x4c, 0xf9, 0x30, 0xf4, 0xdc,
		0xb4, 0x9c, 0xbf, 0xbc, 0x11, 0x32, 0x3f, 0x32, 0xff, 0x9b, 0xae, 0x3d, 0x96, 0x9a, 0xe0, 0xf4,
		0x94, 0xce, 0x0f, 0xb0, 0xf6, 0x78, 0x47, 0xdd, 0xcd, 0xc2, 0xda, 0x63, 0x93, 0x5b, 0x9b, 0x76,
		0x32, 0x94, 0x91, 0x3d, 0xde, 0xa2, 0x06, 0x20, 0xe4, 0x66, 0x90, 0xa6, 0x17, 0xd7, 0x60, 0xcb,
		0x54, 0x6f, 0x51, 0xdc, 0x47, 0x94, 0xa3, 0x02, 0x7e, 0x41, 0x01, 0xcf, 0xb6, 0xe8, 0xcd, 0xa9,
		0x61, 0x97, 0x3a, 0xcc, 0x27, 0x5e, 0xaa, 0x2e, 0x20, 0xa5, 0xb2, 0xc2, 0xb5, 0x6b, 0x92, 0xad,
		0xb4, 0xad, 0xfa, 0xbc, 0x8c, 0xfa, 0xdc, 0x94, 0x3e, 0xaf, 0xbc, 0xc1, 0xad, 0xdd, 0x22, 0x35,
		0xce, 0x02, 0x2e, 0x88, 0x44, 0xf1, 0xc1, 0x9a, 0x74, 0x9b, 0xdf, 0x00, 0xd5, 0x39, 0xaa, 0x73,
		0x54, 0xe7, 0xa8, 0xce, 0x51, 0x9d, 0xa3, 0x3a, 0x47, 0x75, 0x9e, 0x9f, 0x3a, 0x17, 0x34, 0xbe,
		0x21, 0x5e, 0x1a, 0x7d, 0x3e, 0xbb, 0xc3, 0x76, 0x28, 0x74, 0xd4, 0xe3, 0x9b, 0xf4, 0xf8, 0x1b,
		0x55, 0xdf, 0x5c, 0x10, 0x51, 0x54, 0x24, 0xf2, 0x9d, 0x94, 0x7d, 0x39, 0xbf, 0x06, 0x53, 0x59,
		0x56, 0x08, 0x48, 0x10, 0x72, 0xea, 0x84, 0x81, 0xab, 0x44, 0x7b, 0x18, 0x63, 0x47, 0x25, 0x9e,
		0xc5, 0xd6, 0x62, 0x7f, 0x4f, 0x28, 0x7a, 0xdd, 0x57, 0xa0, 0x8e, 0x65, 0xcf, 0x35, 0x72, 0x87,
		0xee, 0x39, 0xaa, 0x75, 0x74, 0xcf, 0xd1, 0x3d, 0x47, 0xf7, 0x1c, 0xdd, 0x73, 0x74, 0xcf, 0xf3,
		0x54, 0xe3, 0x45, 0xc1, 0x7c, 0x9a, 0x4a, 0x97, 0x4f, 0xef, 0x80, 0xee, 0x39, 0xba, 0xe7, 0x6f,
		0x50, 0x7d, 0x8f, 0x69, 0x5b, 0x30, 0xe7, 0x17, 0xcf, 0x7c, 0x68, 0x06, 0x3a, 0xe7, 0xe8, 0x9c,
		0xa3, 0x73, 0x8e, 0x5a, 0x5d, 0x41, 0xab, 0x2b, 0x30, 0xde, 0x52, 0xa1, 0xb3, 0x00, 0x9d, 0x73,
		0x54, 0xea, 0xe8, 0x9c, 0xa3, 0x73, 0x8e, 0xce, 0x39, 0x3a, 0xe7, 0xe8, 0x9c, 0xe7, 0xa9, 0xc6,
		0xd3, 0x3a, 0xe7, 0xf3, 0x3b, 0xa0, 0x73, 0x8e, 0xce, 0x39, 0x3a, 0xe7, 0xe8, 0x9c, 0xa3, 0x73,
		0x8e, 0xce, 0x39, 0x3a, 0xe7, 0xfa, 0xb5, 0xfa, 0x1b, 0x98, 0x8c, 0x29, 0xdf, 0x57, 0x6e, 0x27,
		0xed, 0x78, 0xcc, 0xee, 0xca, 0x23, 0xb3, 0x6c, 0xbf, 0x27, 0xa3, 0x77, 0x96, 0xba, 0x66, 0x7c,
		0x15, 0x36, 0xb7, 0xc4, 0x86, 0x7b, 0x29, 0xb9, 0x5b, 0xbd, 0xb9, 0xe5, 0x28, 0x48, 0xde, 0x5f,
		0xf5, 0x51, 0x80, 0xe2, 0x48, 0xe2, 0x9a, 0xd9, 0xf2, 0xe4, 0xec, 0x11, 0x6c, 0x8d, 0xf6, 0xa8,
		0x35, 0xda, 0xbf, 0x8f, 0x2f, 0x4f, 0xbf, 0x1f, 0x5f, 0xd6, 0xaf, 0x17, 0xb3, 0x85, 0xec, 0x6f,
		0x8f, 0x76, 0x76, 0x6c, 0x75, 0x6b, 0xb4, 0x93, 0xd6, 0x45, 0xf7, 0xb2, 0xd5, 0x6c, 0xd6, 0x2f,
		0xaf, 0x4f, 0x8e, 0x2f, 0x4f, 0x6d, 0x7e, 0x95, 0xcf, 0xc7, 0x27, 0x7f, 0xb6, 0x9b, 0xc7, 0x17,
		0x75, 0x9b, 0x5f, 0xe2, 0xec, 0xf2, 0xab, 0xcd, 0xcb, 0x6f, 0x36, 0x2e, 0xea, 0xb6, 0xd3, 0xd1,
		0xd9, 0xf1, 0xe7, 0xcb, 0xc6, 0x89, 0xcd, 0x6f, 0xd0, 0xb8, 0xe8, 0xd6, 0xbf, 0x5c, 0x1e, 0x77,
		0xeb, 0xa7, 0xd7, 0x27, 0x8d, 0xcb, 0x93, 0xaf, 0x8d, 0xae, 0xcd, 0x6f, 0xd3, 0x6e, 0x7d, 0xaf,
		0x5f, 0x5e, 0x77, 0xbe, 0xb6, 0xdb, 0xcd, 0xff, 0xd8, 0xfc, 0x1e, 0x9d, 0x6e, 0xeb, 0xf2, 0xf8,
		0x8b, 0xd5, 0xd2, 0xa9, 0x53, 0xbf, 0xe8, 0xd8, 0xdd, 0x49, 0xf3, 0xe4, 0xdf, 0xc7, 0x9d, 0x4e,
		0xa3, 0x63, 0xf3, 0x2b, 0x74, 0x2f, 0x8f, 0x2f, 0x3a, 0x27, 0xf5, 0xc6, 0xb7, 0xfa, 0xa5, 0xdd,
		0x6c, 0x7d, 0x69, 0xb5, 0x58, 0x3a, 0x69, 0x7f, 0x7d, 0x73, 0xad, 0x40, 0xff, 0x40, 0xef, 0x46,
		0xdd, 0xbb, 0xe9, 0xb4, 0xce, 0xba, 0x6f, 0xcd, 0xbb, 0x69, 0xb5, 0xeb, 0x97, 0xc7, 0xdd, 0xc6,
		0xc5, 0x97, 0xeb, 0xce, 0x7f, 0x3a, 0xdd, 0xfa, 0xb9, 0xd5, 0xca, 0x6b, 0x7e, 0x3e, 0xe7, 0xad,
		0xd3, 0xaf, 0x4d, 0xab, 0xf5, 0xf0, 0xd3, 0x63, 0xb9, 0xfe, 0xda, 0x3e, 0x3d, 0xee, 0x5a, 0xfd,
		0x4a, 0x9f, 0x5b, 0xad, 0xee, 0x75, 0xb3, 0x75, 0x7c, 0x5a, 0xdf, 0xe2, 0x0e, 0xcb, 0x57, 0x19,
		0x46, 0x7b, 0x47, 0x9c, 0xba, 0xc5, 0x28, 0xbc, 0xa5, 0xb1, 0x7c, 0xcc, 0x77, 0xe5, 0x5a, 0x8c,
		0xfc, 0x62, 0xe4, 0x37, 0x9d, 0x50, 0x49, 0x13, 0xf9, 0x95, 0x6d, 0x9c, 0xaa, 0xd0, 0x30, 0x55,
		0x31, 0x15, 0xad, 0x60, 0x1c, 0xa5, 0x49, 0x3d, 0xa7, 0xcc, 0x8b, 0xa6, 0x4d, 0x35, 0xeb, 0x48,
		0x7a, 0x2a, 0xe8, 0xa0, 0x54, 0x29, 0x65, 0x5d, 0x5b, 0x96, 0xb6, 0xc1, 0xa9, 0x96, 0xbd, 0x83,
		0xae, 0x90, 0xde, 0xa5, 0x38, 0xf9, 0xc2, 0xf1, 0x68, 0x30, 0x16, 0x57, 0xd4, 0x4d, 0xc4, 0x85,
		0x92, 0xba, 0x6c, 0x77, 0x45, 0x02, 0x7e, 0x5a, 0xc9, 0x03, 0x3f, 0xfb, 0xf1, 0xa3, 0x4f, 0x27,
		0xf9, 0xe1, 0xa4, 0x0a, 0xf0, 0x94, 0x72, 0x27, 0x66, 0xd1, 0x2c, 0x7b, 0x5d, 0x38, 0x76, 0x5d,
		0xbe, 0xc3, 0x23, 0xea, 0xb0, 0x3e, 0x73, 0x76, 0x26, 0xdd, 0xce, 0xf9, 0x4e, 0x4c, 0x3d, 0x22,
		0xa8, 0xbb, 0x23, 0xc2, 0x1d, 0xb2, 0xb3, 0x78, 0xe6, 0xc7, 0x37, 0x32, 0xce, 0x6c, 0xfa, 0x92,
		0x5b, 0xa9, 0x61, 0x67, 0xaf, 0x6e, 0xcb, 0x28, 0x33, 0xfa, 0xf7, 0x88, 0x45, 0xe3, 0xe5, 0x17,
		0xfb, 0x84, 0x79, 0x32, 0xd3, 0xf8, 0xd6, 0xce, 0x7d, 0xfd, 0x56, 0x92, 0x3b, 0xf9, 0x84, 0x6f,
		0x1a, 0xfd, 0xe9, 0x71, 0xec, 0x88, 0x21, 0xdd, 0x19, 0x92, 0xd8, 0xbd, 0x25, 0x31, 0xdd, 0x61,
		0x81, 0xcb, 0x1c, 0x22, 0x28, 0xdf, 0x11, 0x43, 0x22, 0x26, 0xff, 0xb6, 0x60, 0x9f, 0xff, 0x87,
		0xef, 0x44, 0xc3, 0x7b, 0xce, 0x1c, 0xe2, 0xed, 0x2c, 0x56, 0xf3, 0x33, 0x18, 0x12, 0xbe, 0x33,
		0x5e, 0x12, 0x75, 0xe5, 0x57, 0xd4, 0x27, 0x23, 0x6f, 0x72, 0xb4, 0x7d, 0xe2, 0xf1, 0x6d, 0x01,
		0x91, 0x4a, 0xb3, 0x6f, 0x5a, 0x36, 0xd6, 0xc6, 0xce, 0xda, 0xd8, 0x5a, 0x17, 0x7b, 0x67, 0x12,
		0x9d, 0xc3, 0xa1, 0x24, 0xeb, 0xe2, 0xcc, 0x67, 0xdc, 0x27, 0xc2, 0x19, 0xea, 0x90, 0x67, 0x8b,
		0x7b, 0x65, 0x2d, 0xd0, 0x76, 0x58, 0xc0, 0x69, 0x3c, 0xb6, 0x13, 0x58, 0x20, 0xc2, 0xf1, 0xbf,
		0xfd, 0x0c, 0x48, 0xbf, 0x4f, 0x9d, 0xf1, 0x47, 0xcf, 0x8a, 0x3d, 0x2f, 0x74, 0x26, 0xb0, 0xb9,
		0x1d, 0xc6, 0x77, 0xc2, 0xfe, 0x0e, 0xd9, 0x71, 0x59, 0xbf, 0x4f, 0xe3, 0xf1, 0xbd, 0xc4, 0x7d,
		0x44, 0xc7, 0xcf, 0x08, 0x76, 0x6e, 0x87, 0x44, 0xfc, 0x0c, 0x18, 0xdf, 0x99, 0xe2, 0xd4, 0x46,
		0x31, 0x4a, 0x46, 0x94, 0x8c, 0x28, 0x19, 0xed, 0x93, 0x8c, 0x99, 0xb8, 0x6c, 0x57, 0xaf, 0xb9,
		0x6c, 0x72, 0x58, 0xdd, 0x74, 0x18, 0xdd, 0x42, 0x92, 0x89, 0xee, 0xea, 0x78, 0xdc, 0x97, 0xc9,
		0x77, 0xf3, 0x3e, 0xbd, 0x40, 0x96, 0x05, 0x2e, 0xc2, 0x98, 0x0c, 0x5e, 0xa7, 0xc2, 0x95, 0x76,
		0x88, 0xd3, 0x0b, 0x5e, 0xd9, 0xf7, 0x64, 0x3e, 0x60, 0x62, 0x91, 0x29, 0x23, 0x22, 0x15, 0xe3,
		0xa9, 0xb2, 0x42, 0x50, 0x59, 0xe8, 0x29, 0x0b, 0x39, 0xf5, 0x78, 0x69, 0xba, 0xb0, 0x47, 0x52,
		0xbf, 0xad, 0xe0, 0xcc, 0x4f, 0x53, 0x32, 0xf4, 0x31, 0xbb, 0x0e, 0xa7, 0xa5, 0x63, 0x08, 0x3f,
		0x65, 0x88, 0x21, 0xfb, 0xd2, 0x8c, 0x89, 0x34, 0xdc, 0x95, 0xa2, 0xe0, 0x54, 0x7a, 0x60, 0xf2,
		0xbc, 0xeb, 0x19, 0x51, 0x67, 0x98, 0xa6, 0x9b, 0x2a, 0x38, 0x69, 0xd6, 0x96, 0x8a, 0x4d, 0xaa,
		0x72, 0x76, 0x19, 0x39, 0x1b, 0x39, 0xdb, 0x10, 0x67, 0xcb, 0x10, 0xb0, 0x06, 0xc6, 0x4e, 0x60,
		0xe8, 0x65, 0x96, 0xed, 0xc8, 0xcc, 0x74, 0x4e, 0x62, 0x51, 0xa6, 0xdf, 0x5b, 0x23, 0xe6, 0xf3,
		0xa8, 0xb7, 0x7c, 0x27, 0x09, 0x23, 0xfa, 0xd1, 0x65, 0x68, 0x4a, 0xa3, 0x29, 0xfd, 0x12, 0x61,
		0x29, 0x68, 0xdd, 0xd5, 0xab, 0xd1, 0xac, 0x46, 0xe5, 0x9b, 0x52, 0xf9, 0x4a, 0x67, 0xee, 0x24,
		0x3d, 0xc1, 0x74, 0x1e, 0xa1, 0x22, 0x09, 0x83, 0x89, 0xdb, 0xe2, 0xb4, 0x6d, 0xad, 0xa4, 0x9f,
		0x4d, 0xec, 0x56, 0x96, 0x25, 0x16, 0x17, 0xce, 0xac, 0x97, 0x94, 0x78, 0xef, 0xc9, 0x5d, 0xfe,
		0xc8, 0x05, 0x6f, 0xa4, 0xca, 0x2e, 0x3a, 0xd8, 0x46, 0x33, 0xfb, 0xe8, 0x62, 0x23, 0xed, 0xec,
		0xa4, 0x9d, 0xad, 0xf4, 0xb3, 0x97, 0x1a, 0x9b, 0x29, 0xb2, 0xdb, 0x62, 0xf9, 0xca, 0x29, 0x93,
		0x35, 0xca, 0xf1, 0x28, 0xe9, 0xab, 0x95, 0x7d, 0xac, 0xe9, 0x9b, 0x83, 0x14, 0xf7, 0x68, 0xcf,
		0xfc, 0xa5, 0x8f, 0x1f, 0x77, 0x57, 0xff, 0xb7, 0x74, 0x8f, 0xa6, 0xaa, 0x70, 0x77, 0xc2, 0xf0,
		0x19, 0xb5, 0x61, 0x31, 0x2b, 0x39, 0x15, 0x3d, 0xf9, 0xf4, 0x7e, 0xe6, 0xaa, 0xd3, 0xf5, 0xe8,
		0xaf, 0x5d, 0x25, 0x73, 0x23, 0x8d, 0x47, 0xba, 0xba, 0x94, 0x47, 0x7f, 0x49, 0x45, 0xf6, 0xe4,
		0xcf, 0x4b, 0x06, 0xae, 0xa0, 0xa4, 0xa8, 0xd2, 0x28, 0x28, 0xdb, 0xfb, 0xd4, 0xa2, 0xfd, 0x66,
		0x91, 0xfd, 0x96, 0x3e, 0xf7, 0xae, 0xae, 0x40, 0xd2, 0x28, 0x8e, 0x55, 0x85, 0xa1, 0xac, 0x1a,
		0xcc, 0x08, 0x0c, 0xb9, 0x14, 0xc1, 0x7a, 0xd0, 0x42, 0x32, 0xd2, 0xaa, 0xc5, 0xe5, 0x2b, 0xa3,
		0xc8, 0x40, 0x91, 0x81, 0x2e, 0x1f, 0xba, 0x7c, 0xe8, 0xf2, 0xa1, 0xcb, 0x87, 0x2e, 0xdf, 0xf6,
		0xb8, 0x7c, 0x2a, 0xd6, 0x86, 0x19, 0x8f, 0x4f, 0x22, 0xe5, 0xab, 0x60, 0xbf, 0x69, 0xcd, 0x03,
		0xfc, 0x49, 0xef, 0x25, 0x35, 0x51, 0xa1, 0xc9, 0xb8, 0x38, 0x16, 0x42, 0x32, 0x7f, 0x70, 0xce,
		0x82, 0xba, 0x47, 0xfd, 0x59, 0x56, 0x55, 0x42, 0xeb, 0x14, 0xce, 0xc9, 0xdd, 0xca, 0x95, 0xe9,
		0xda, 0xea, 0x16, 0x5a, 0xb1, 0x4b, 0x63, 0xea, 0x7e, 0x1e, 0xbf, 0x75, 0x30, 0xf2, 0x3c, 0xbb,
		0x11, 0x0d, 0x1b, 0x99, 0x21, 0x03, 0x78, 0xc3, 0x46, 0xf2, 0xdf, 0x32, 0xac, 0x83, 0x44, 0xe2,
		0x5f, 0xd7, 0x76, 0x2b, 0xe3, 0x1e, 0xde, 0x49, 0xec, 0x64, 0x02, 0xd1, 0x90, 0x4c, 0x14, 0x24,
		0x67, 0xfd, 0x54, 0xac, 0x9e, 0x8c, 0xb5, 0x37, 0xbd, 0x6c, 0x42, 0x72, 0x51, 0x25, 0x93, 0xc2,
		0x8b, 0x80, 0x6d, 0x05, 0x82, 0x78, 0x9e, 0x04, 0xd6, 0x0f, 0xf8, 0xf1, 0x27, 0x4f, 0xde, 0xfe,
		0xb5, 0xb7, 0x96, 0x7b, 0xdb, 0x67, 0xde, 0x51, 0xe6, 0xdd, 0x1e, 0xbf, 0xd1, 0x72, 0xdd, 0x2b,
		0x6b, 0x2e, 0x4c, 0x86, 0xf6, 0xf7, 0x89, 0x43, 0xd7, 0x91, 0x39, 0xcb, 0x06, 0x50, 0xcb, 0xef,
		0x3c, 0x79, 0xdb, 0xe7, 0x23, 0x0b, 0x1b, 0x5d, 0xa1, 0x97, 0x5c, 0x9c, 0xe5, 0xd3, 0x9e, 0xb3,
		0x3d, 0x5f, 0xf3, 0x44, 0x12, 0x7b, 0x18, 0x89, 0x3d, 0x87, 0x47, 0x1e, 0x01, 0xeb, 0x17, 0x24,
		0xe9, 0x60, 0x93, 0x1f, 0xbc, 0xdc, 0xcc, 0xcd, 0xef, 0xb2, 0xb6, 0xef, 0x9b, 0xde, 0xe5, 0xe5,
		0xc0, 0xce, 0xab, 0x1e, 0x69, 0x12, 0x8f, 0xf3, 0xe5, 0x63, 0x91, 0x75, 0x14, 0xa5, 0x1d, 0x41,
		0x69, 0x47, 0xef, 0xd5, 0x63, 0x53, 0x93, 0xdc, 0xaf, 0x85, 0x35, 0x0a, 0xc4, 0xf5, 0x59, 0x50,
		0x1c, 0x1b, 0xcc, 0x23, 0x09, 0x8c, 0xdb, 0xa3, 0xab, 0x92, 0x41, 0xdc, 0xf6, 0x92, 0x42, 0xdc,
		0xca, 0x06, 0x20, 0x6e, 0xac, 0xff, 0xf6, 0x90, 0x6d, 0x2f, 0x11, 0x89, 0x1e, 0xc3, 0xe9, 0x9c,
		0x04, 0x2e, 0x11, 0x61, 0x7c, 0x9f, 0x00, 0xa1, 0x98, 0xd8, 0x91, 0x5f, 0x56, 0xb9, 0x06, 0x23,
		0x9f, 0xc6, 0x53, 0x95, 0x93, 0xe0, 0x70, 0xe6, 0x32, 0xa3, 0x9a, 0xe0, 0xbb, 0xf5, 0x60, 0xe4,
		0x8f, 0x17, 0xf3, 0x60, 0x00, 0x15, 0xea, 0x3e, 0x2a, 0xad, 0x4d, 0xc8, 0x2f, 0xab, 0x17, 0x69,
		0x66, 0x97, 0x3d, 0x64, 0x17, 0x20, 0xec, 0x22, 0xcf, 0x02, 0x5c, 0xc4, 0x2c, 0x18, 0xc8, 0x50,
		0xff, 0xa1, 0x01, 0x8a, 0xa6, 0x01, 0xe9, 0x79, 0x93, 0xbe, 0x37, 0x09, 0xa9, 0x79, 0x7e, 0xc1,
		0x6b, 0x78, 0xd8, 0x65, 0xa5, 0xf6, 0xf8, 0xcc, 0x90, 0xf0, 0x91, 0xf0, 0xe5, 0x4b, 0x9b, 0x13,
		0x96, 0x32, 0xab, 0x51, 0xfe, 0x90, 0x0d, 0x86, 0x34, 0x2e, 0x7a, 0xe4, 0x9e, 0xc6, 0x45, 0xd6,
		0x4f, 0xce, 0x01, 0x4f, 0x2f, 0x44, 0x13, 0x08, 0x49, 0xfb, 0xa9, 0xf3, 0x53, 0x4c, 0x96, 0x8d,
		0x90, 0xc9, 0x3a, 0x2c, 0xb2, 0x0b, 0xbb, 0xac, 0xff, 0x69, 0xe9, 0xdd, 0x3e, 0xfa, 0x6b, 0xfc,
		0xc7, 0xeb, 0xc9, 0x85, 0xd7, 0xde, 0x5b, 0x2a, 0xb2, 0x2b, 0x1f, 0xd1, 0xd5, 0x12, 0xc9, 0x95,
		0x8b, 0xe0, 0xaa, 0x49, 0x08, 0xd6, 0x2f, 0xb2, 0xc0, 0xa5, 0x77, 0xc9, 0x45, 0xc3, 0xe2, 0x0a,
		0x94, 0x09, 0xe8, 0x16, 0xa9, 0xc9, 0x8f, 0x44, 0xdd, 0x46, 0x25, 0xe6, 0x0c, 0x4b, 0x76, 0x17,
		0x95, 0x4b, 0xe5, 0x28, 0x54, 0xe0, 0xa8, 0x21, 0x01, 0x17, 0xd3, 0x14, 0x25, 0xaf, 0x4b, 0xd1,
		0xf9, 0xf2, 0x41, 0x2e, 0x37, 0x95, 0xf9, 0x56, 0x94, 0x4b, 0xd5, 0x83, 0xea, 0x61, 0xa5, 0x56,
		0x3d, 0xc8, 0x70, 0x4f, 0x34, 0xe5, 0x74, 0xae, 0x0c, 0x48, 0x6b, 0x8f, 0x70, 0x51, 0x74, 0x86,
		0x33, 0x6a, 0x4f, 0x28, 0xb0, 0x57, 0x2f, 0x42, 0x99, 0x8d, 0x76, 0xdc, 0x3c, 0x64, 0x43, 0x04,
		0x2d, 0x92, 0xc0, 0x4d, 0x3a, 0xc3, 0x7b, 0xe9, 0xa2, 0x27, 0xb3, 0xe3, 0x04, 0x8d, 0x83, 0xc4,
		0x22, 0xb9, 0xf0, 0xf3, 0xa7, 0xfb, 0x4f, 0xf5, 0xa1, 0x38, 0xfe, 0x51, 0x9e, 0xff, 0xe8, 0x4e,
		0x7f, 0x7c, 0x7a, 0xf4, 0xe3, 0xfd, 0xcf, 0x9f, 0x1f, 0x7f, 0xfe, 0x74, 0xff, 0xe7, 0xc3, 0xbf,
		0xde, 0xff, 0x9f, 0xdf, 0x3f, 0x7e, 0xfe, 0xfc, 0x9f, 0x9f, 0x3f, 0x8b, 0x57, 0x8f, 0xbe, 0xf1,
		0xa1, 0x90, 0x0f, 0x6f, 0xb2, 0xe0, 0x57, 0x71, 0x14, 0x15, 0xdd, 0xf0, 0x36, 0x28, 0x8a, 0x98,
		0x44, 0xc5, 0x69, 0x18, 0x41, 0x82, 0x51, 0x37, 0xdd, 0x01, 0x03, 0x0b, 0xc8, 0xb5, 0x76, 0x07,
		0x95, 0xbd, 0xf0, 0x56, 0x29, 0x0e, 0xf1, 0xe4, 0x3a, 0x54, 0x5f, 0xc8, 0x08, 0x18, 0x86, 0x78,
		0x83, 0x61, 0x88, 0x44, 0x20, 0x73, 0x19, 0x30, 0x39, 0x2a, 0xc5, 0x2d, 0x92, 0x05, 0x30, 0xd2,
		0x4c, 0x61, 0x44, 0x63, 0x69, 0xa0, 0xc1, 0xea, 0x45, 0xa8, 0xdd, 0x30, 0xa0, 0xb6, 0x3d, 0x26,
		0x61, 0x34, 0xbc, 0xe7, 0x45, 0xe2, 0xba, 0x31, 0xe5, 0x12, 0xfc, 0xf2, 0xe8, 0x2a, 0x64, 0x18,
		0x54, 0x01, 0xf2, 0x74, 0x61, 0x3e, 0x98, 0xf1, 0xfe, 0xc7, 0x5e, 0xf1, 0x88, 0x14, 0xfb, 0xc7,
		0xc5, 0xb3, 0xab, 0x7f, 0xca, 0x0f, 0xef, 0x3f, 0x3d, 0xfe, 0xfb, 0xc3, 0x7f, 0x7f, 0xf8, 0x57,
		0x3e, 0x31, 0x0a, 0x1e, 0x51, 0x19, 0x1c, 0xc4, 0xf4, 0xeb, 0xc8, 0x65, 0xc8, 0x65, 0xb3, 0x7d,
		0x1e, 0x90, 0xd1, 0x80, 0xd6, 0xaa, 0x12, 0x0c, 0x76, 0xb8, 0x6d, 0xd9, 0x9b, 0x3d, 0xcc, 0xde,
		0x2c, 0x12, 0x59, 0xa9, 0xea, 0x97, 0x76, 0xde, 0x70, 0x1e, 0x67, 0x6c, 0xf0, 0x33, 0x2e, 0x98,
		0x23, 0xd3, 0x76, 0x73, 0x79, 0x8d, 0xe6, 0x9e, 0x9b, 0x28, 0x91, 0xa1, 0x48, 0xe4, 0xc4, 0x1d,
		0x36, 0x5d, 0xc6, 0x9d, 0x30, 0x10, 0x2c, 0x18, 0x31, 0x71, 0x3f, 0xcd, 0xe0, 0x48, 0xf7, 0xd9,
		0x7c, 0xe6, 0x1e, 0x6f, 0x60, 0x0e, 0x2d, 0xeb, 0x6f, 0x5f, 0x93, 0xcd, 0x24, 0x84, 0x29, 0x29,
		0x16, 0x13, 0x9e, 0x94, 0x84, 0x67, 0x2b, 0x6f, 0x76, 0xac, 0x53, 0xac, 0x64, 0xca, 0x52, 0xc5,
		0xda, 0x57, 0xb6, 0xfa, 0x17, 0x17, 0x66, 0x9b, 0xca, 0x4c, 0xa6, 0xa6, 0x92, 0x9f, 0x7e, 0x92,
		0x76, 0xfa, 0x2c, 0x28, 0xf6, 0xe2, 0x90, 0xb8, 0x0e, 0xe1, 0xa2, 0x18, 0xfd, 0x4a, 0xd0, 0x3c,
		0xfa, 0x99, 0xf0, 0xfd, 0xd3, 0x5b, 0xa0, 0xec, 0x41, 0xd9, 0x23, 0x25, 0x7b, 0xd4, 0xe5, 0x88,
		0x13, 0x8e, 0x02, 0x41, 0xe3, 0x44, 0x8e, 0x8c, 0x82, 0x43, 0xa3, 0xe8, 0xd8, 0xc8, 0x3b, 0x38,
		0xa9, 0x1c, 0x9d, 0x94, 0x56, 0x7e, 0x5a, 0xc7, 0x47, 0x87, 0x89, 0xaf, 0xe0, 0x08, 0xa5, 0x72,
		0x88, 0x74, 0x6f, 0x59, 0x7a, 0x07, 0x49, 0xeb, 0x2e, 0x42, 0x1f, 0x7f, 0x9d, 0x4c, 0x33, 0x8d,
		0xcd, 0x5a, 0x12, 0xbb, 0x6a, 0x3a, 0x69, 0x71, 0x31, 0x6a, 0x23, 0xd4, 0x46, 0xd9, 0x6a, 0xa3,
		0x44, 0xa0, 0xe8, 0xa7, 0x84, 0x77, 0x80, 0xda, 0x08, 0xb5, 0x91, 0xa6, 0x2d, 0xab, 0x96, 0x8f,
		0xaa, 0x47, 0xb5, 0x83, 0xf2, 0x11, 0xea, 0xa0, 0xb4, 0x3a, 0x88, 0xc6, 0x71, 0x18, 0xab, 0x69,
		0xa0, 0xd9, 0xa5, 0xa8, 0x7f, 0x50, 0xff, 0xa0, 0xfe, 0x41, 0xfd, 0x83, 0xfa, 0x07, 0xf5, 0x8f,
		0xbc, 0xfe, 0xf1, 0x47, 0x9e, 0x60, 0xe9, 0xa2, 0x73, 0x4f, 0x6e, 0x81, 0xfa, 0x08, 0xf5, 0x11,
		0x46, 0xe7, 0x50, 0x1f, 0x61, 0x74, 0x0e, 0x35, 0x53, 0x1a, 0xcd, 0x14, 0x3a, 0x82, 0x2a, 0x6a,
		0xa4, 0xd9, 0xa5, 0xa8, 0x89, 0x50, 0x13, 0xa1, 0x26, 0x42, 0x4d, 0x84, 0x9a, 0x08, 0x35, 0x51,
		0x1a, 0x4d, 0x34, 0x0a, 0x52, 0x7a, 0x48, 0x8f, 0x6e, 0x80, 0x5a, 0x09, 0xb5, 0x12, 0x6a, 0x25,
		0xd4, 0x4a, 0xa8, 0x95, 0x50, 0x2b, 0xa5, 0xd3, 0x4a, 0xbf, 0x82, 0xf0, 0x36, 0x28, 0x46, 0x71,
		0x28, 0x42, 0x55, 0xbd, 0xf4, 0xe8, 0x16, 0xa8, 0x99, 0x50, 0x33, 0x65, 0xab, 0x99, 0x30, 0x93,
		0x84, 0x9a, 0x09, 0x33, 0x49, 0x6f, 0x40, 0x1f, 0x85, 0x23, 0x91, 0x1a, 0xe8, 0xfd, 0xcc, 0x3d,
		0x50, 0x23, 0xa1, 0x46, 0x42, 0x5f, 0x09, 0x35, 0x12, 0xfa, 0x4a, 0xa8, 0x9b, 0x52, 0xe9, 0x26,
		0x75, 0xa8, 0xf7, 0xa3, 0xab, 0x51, 0x1f, 0xa1, 0x3e, 0x42, 0x0f, 0x09, 0xf5, 0x11, 0x7a, 0x48,
		0xa8, 0x85, 0x14, 0xb4, 0x90, 0x2a, 0xd8, 0x7b, 0xe5, 0x5a, 0xd4, 0x40, 0xa8, 0x81, 0x50, 0x03,
		0xa1, 0x06, 0x42, 0x0d, 0x84, 0x1a, 0x48, 0x41, 0x03, 0xa5, 0x85, 0x7b, 0x3f, 0x73, 0x0f, 0xd4,
		0x48, 0xa8, 0x91, 0x30, 0x46, 0x87, 0x1a, 0x09, 0x63, 0x74, 0xa8, 0x9b, 0x52, 0xe9, 0x26, 0x55,
		0xc0, 0xf7, 0xca, 0xb5, 0xa8, 0x8b, 0x50, 0x17, 0xa1, 0x2e, 0x42, 0x5d, 0x84, 0xba, 0x08, 0x75,
		0x51, 0x2a, 0x5d, 0x94, 0x0e, 0xf2, 0xbd, 0x76, 0x07, 0xd4, 0x4b, 0xa8, 0x97, 0x50, 0x2f, 0xa1,
		0x5e, 0x42, 0xbd, 0x84, 0x7a, 0x49, 0xe1, 0x1b, 0xaf, 0x35, 0x83, 0x3e, 0x0e, 0x82, 0x50, 0x4c,
		0xc7, 0xba, 0x24, 0xea, 0x09, 0xcd, 0x9d, 0x21, 0xf5, 0x49, 0xb4, 0x18, 0x5d, 0x46, 0x45, 0xbf,
		0xb8, 0x3a, 0xbc, 0xec, 0x99, 0x5f, 0x77, 0x13, 0x37, 0x15, 0x9f, 0x3e, 0x41, 0xc4, 0x23, 0x47,
		0xcc, 0x66, 0x75, 0x15, 0x1a, 0xf5, 0xee, 0x59, 0x63, 0x71, 0xd3, 0xeb, 0xe7, 0x7e, 0xbd, 0xee,
		0x2c, 0xef, 0x6f, 0xa0, 0x8d, 0xba, 0x48, 0x22, 0x4f, 0x17, 0x32, 0x74, 0xf2, 0x6d, 0x9c, 0x1a,
		0x86, 0x33, 0x96, 0x54, 0xa6, 0x0d, 0xba, 0x34, 0x10, 0x4c, 0xdc, 0x4b, 0xce, 0x1a, 0x4c, 0x32,
		0x5d, 0xaf, 0x31, 0xbb, 0xf5, 0x67, 0xc2, 0xa9, 0x4a, 0xbd, 0xc7, 0x7c, 0x0c, 0x62, 0x02, 0xf2,
		0x7e, 0x2c, 0xce, 0xb9, 0x94, 0x9e, 0x97, 0x34, 0xf9, 0x16, 0xeb, 0x23, 0x01, 0x29, 0x2a, 0x2d,
		0x32, 0xcd, 0x62, 0xd5, 0x0d, 0x93, 0x47, 0x8b, 0x27, 0x2e, 0xf7, 0x0a, 0x59, 0xe8, 0xf6, 0x94,
		0xeb, 0x64, 0xbe, 0xb0, 0x62, 0x99, 0xfd, 0x6f, 0x7d, 0x36, 0xe1, 0x3d, 0x0b, 0x16, 0x4b, 0x23,
		0x2f, 0xe6, 0x36, 0x2c, 0x94, 0xdc, 0x30, 0x87, 0xb5, 0x22, 0xc1, 0x1c, 0xe2, 0xd5, 0xc5, 0x90,
		0xc6, 0x36, 0x2c, 0xfa, 0xc6, 0xbf, 0x25, 0x31, 0xbd, 0x60, 0x4e, 0x97, 0x12, 0xdf, 0x86, 0x05,
		0x0f, 0x44, 0x64, 0xc3, 0x32, 0xff, 0xb6, 0x63, 0x37, 0x9d, 0x9e, 0xf7, 0x8d, 0x3a, 0x82, 0x74,
		0x04, 0xb1, 0x82, 0x5c, 0x59, 0xd4, 0xba, 0xa1, 0xf1, 0x89, 0x47, 0x6e, 0x6d, 0x58, 0xad, 0x7f,
		0x63, 0x85, 0xd6, 0x8a, 0x98, 0x15, 0x2c, 0x45, 0xbc, 0x51, 0x3d, 0x0a, 0x83, 0x66, 0x38, 0x18,
		0x4b, 0xd8, 0x26, 0x0b, 0x7e, 0xd9, 0xb0, 0x6a, 0x6e, 0xc7, 0xe6, 0x7a, 0xa1, 0x43, 0xbc, 0x2e,
		0xf1, 0xac, 0xd8, 0xd3, 0xc1, 0xd1, 0xd1, 0x61, 0xd9, 0x86, 0x85, 0xba, 0xa1, 0xc3, 0x4f, 0x48,
		0xcf, 0xa3, 0x1d, 0x47, 0xd0, 0xfd, 0x7d, 0xb7, 0xfc, 0x95, 0xb7, 0xc2, 0x9e, 0x15, 0xcc, 0xc6,
		0xef, 0x03, 0xc7, 0x86, 0x85, 0xf6, 0x63, 0xe2, 0xd3, 0x4b, 0xea, 0x91, 0x7b, 0x2b, 0xf4, 0x17,
		0x77, 0x83, 0x91, 0x0d, 0x0b, 0x1d, 0x86, 0x5c, 0xb4, 0x89, 0x6b, 0x05, 0xa9, 0xf6, 0x3d, 0x12,
		0xd0, 0xc3, 0xbd, 0x72, 0xc5, 0x86, 0xd5, 0x86, 0x53, 0x07, 0xa1, 0x1b, 0x93, 0x80, 0x47, 0x61,
		0x6c, 0x85, 0xbf, 0x18, 0x8a, 0xa0, 0xe5, 0x5a, 0x41, 0xb6, 0x3d, 0xc2, 0x99, 0xd3, 0xe8, 0x9c,
		0x5e, 0xd8, 0x21, 0x0c, 0xc2, 0xc3, 0x31, 0xd9, 0x9e, 0x70, 0x9f, 0x38, 0xae, 0x1d, 0xc2, 0xf6,
		0x2c, 0x8c, 0x6f, 0x49, 0x6c, 0xc5, 0x62, 0x19, 0xa5, 0x13, 0xa9, 0x40, 0xdc, 0x26, 0x19, 0x58,
		0x21, 0xc8, 0x5c, 0xee, 0xd9, 0x61, 0xd6, 0xdc, 0xf4, 0x8e, 0x39, 0x6b, 0x8d, 0xac, 0x10, 0x5e,
		0xc3, 0x4a, 0xb9, 0xd2, 0x8e, 0xc3, 0xbb, 0x7b, 0x5b, 0x7c, 0x9c, 0x66, 0xdb, 0x16, 0x1b, 0xdc,
		0x0a, 0x85, 0xcb, 0x5d, 0xcf, 0x0a, 0x43, 0x76, 0xc8, 0xa2, 0x88, 0x59, 0x41, 0xa3, 0xc4, 0xdb,
		0xb7, 0x61, 0x9d, 0x77, 0xe5, 0xfd, 0xc8, 0xa3, 0x16, 0x19, 0x02, 0xfb, 0x27, 0x97, 0x67, 0xed,
		0x46, 0x60, 0x85, 0x54, 0xe5, 0x82, 0x38, 0xbf, 0xba, 0x61, 0x67, 0xfc, 0xc3, 0x8a, 0x38, 0x37,
		0x8b, 0xc5, 0x88, 0x78, 0x5d, 0x2b, 0x0c, 0x81, 0xe1, 0x7d, 0x44, 0x63, 0x67, 0x48, 0x82, 0x80,
		0x5a, 0x11, 0x40, 0xa4, 0x61, 0x60, 0x45, 0x9c, 0x33, 0x0e, 0xa3, 0x6f, 0x53, 0x3a, 0xb0, 0x28,
		0xde, 0xd9, 0x1e, 0xde, 0xf3, 0xb1, 0xc7, 0xf8, 0x35, 0x60, 0x56, 0x85, 0xbc, 0x2e, 0x5c, 0x2b,
		0x32, 0x0a, 0x2e, 0xb7, 0xc2, 0x8a, 0x71, 0x42, 0x3f, 0x0a, 0x39, 0x13, 0xd4, 0x96, 0xb8, 0x77,
		0x4c, 0x07, 0x23, 0x8f, 0xc4, 0xa5, 0xc3, 0xb2, 0x15, 0x2e, 0x4d, 0x8f, 0x09, 0x2b, 0x92, 0xcc,
		0xb7, 0xb7, 0x24, 0x68, 0x5b, 0xe3, 0x20, 0x94, 0xac, 0x30, 0x0d, 0x2a, 0x35, 0x3b, 0x04, 0x55,
		0xc9, 0x26, 0x5b, 0xf6, 0x54, 0x58, 0x21, 0xfe, 0x1d, 0x12, 0xdd, 0x92, 0xe8, 0x34, 0x14, 0xa5,
		0x52, 0x3b, 0x0e, 0xfb, 0xcc, 0x0e, 0x87, 0x61, 0xc0, 0x06, 0xa4, 0xc7, 0xc4, 0x04, 0x65, 0x12,
		0x50, 0x2b, 0x1c, 0x86, 0x3e, 0xe1, 0x56, 0xac, 0x33, 0xb2, 0x23, 0x5a, 0x30, 0xb6, 0x65, 0x3f,
		0x7f, 0x3f, 0x8e, 0xca, 0xe7, 0x56, 0xa4, 0x97, 0xef, 0x0e, 0x6b, 0x4d, 0x12, 0x71, 0x4b, 0x76,
		0x56, 0xd0, 0x30, 0x38, 0xdc, 0x3b, 0xef, 0x31, 0x61, 0x47, 0x9c, 0xa3, 0x64, 0x85, 0x09, 0x1b,
		0xdb, 0x82, 0xe2, 0xbc, 0x2b, 0xef, 0xfb, 0x9e, 0x1d, 0xa8, 0x8d, 0xf2, 0x8d, 0x47, 0x02, 0x7b,
		0xf4, 0xec, 0x77, 0x31, 0x77, 0xc0, 0x2f, 0x89, 0xcb, 0x42, 0x2b, 0xbc, 0x70, 0x61, 0x07, 0x2c,
		0xb2, 0x1f, 0x59, 0xb2, 0x9b, 0x9d, 0x51, 0x6f, 0x51, 0x96, 0x62, 0x87, 0x23, 0x4b, 0x9c, 0xe1,
		0x69, 0xa7, 0x69, 0x85, 0x17, 0x1b, 0x33, 0x77, 0x40, 0x6d, 0x31, 0x07, 0x2d, 0x51, 0x07, 0x37,
		0x21, 0x73, 0xe8, 0xd9, 0x5f, 0x1d, 0x4b, 0x32, 0xb3, 0x97, 0x8e, 0x73, 0x1a, 0xde, 0x06, 0x5c,
		0xc4, 0x96, 0x20, 0xba, 0x7d, 0xe2, 0x74, 0xa8, 0xf3, 0x35, 0x70, 0xc2, 0x40, 0xc4, 0xa1, 0xe7,
		0x51, 0xb7, 0x71, 0x66, 0x51, 0x7c, 0xb6, 0x65, 0x07, 0xa0, 0x2b, 0xe6, 0xe5, 0x4a, 0xd9, 0x16,
		0xb0, 0x91, 0x18, 0x59, 0x16, 0xea, 0xee, 0xdb, 0x05, 0x95, 0x9c, 0x28, 0x60, 0x27, 0x0c, 0x02,
		0xea, 0x58, 0xe1, 0xe2, 0x88, 0x09, 0x5a, 0xee, 0xdf, 0x96, 0x64, 0xf2, 0xfb, 0x0e, 0x8b, 0x6c,
		0x09, 0xd3, 0x4f, 0x94, 0x5b, 0xfd, 0x73, 0xc7, 0x9e, 0x5a, 0xa5, 0x99, 0x03, 0x71, 0xc1, 0x1c,
		0x5b, 0xd0, 0x47, 0x5f, 0x88, 0xa0, 0xbf, 0x28, 0x8d, 0xec, 0xa8, 0x08, 0x8b, 0xdc, 0x60, 0x12,
		0x57, 0x6c, 0x86, 0x61, 0x64, 0x45, 0xc4, 0xd9, 0x0f, 0x5d, 0xea, 0xdb, 0x12, 0xb3, 0x3b, 0x0d,
		0x1d, 0xfe, 0x9d, 0xc5, 0xd4, 0xa3, 0x9c, 0x7f, 0x8d, 0xec, 0x31, 0xd2, 0x38, 0x8b, 0x3a, 0xcc,
		0x0a, 0xf0, 0x84, 0x1f, 0xd1, 0x81, 0x55, 0xe8, 0xea, 0x19, 0x4e, 0xb5, 0x64, 0x07, 0xf4, 0xd3,
		0xb1, 0x22, 0xdc, 0xe4, 0x73, 0x4b, 0x9c, 0xcb, 0xa0, 0x4f, 0xb8, 0x45, 0x69, 0xbd, 0xb2, 0x67,
		0x87, 0x09, 0xf6, 0x77, 0xf9, 0xa8, 0x52, 0xb2, 0xa5, 0x20, 0x88, 0xdb, 0x63, 0x28, 0x06, 0x0e,
		0xb1, 0xa5, 0x56, 0xf4, 0x8b, 0x3d, 0xbe, 0xf9, 0x8c, 0xb9, 0x6a, 0xe7, 0x24, 0xb0, 0x28, 0x43,
		0x56, 0xb2, 0x26, 0x43, 0x36, 0x81, 0x56, 0x5b, 0x15, 0x74, 0x9e, 0xc5, 0x96, 0x2c, 0x62, 0x35,
		0xcb, 0x60, 0x8a, 0x2c, 0xb2, 0xa8, 0x92, 0x89, 0x08, 0xdf, 0x9a, 0x7c, 0xd9, 0x4c, 0x96, 0x55,
		0xbb, 0xe1, 0x2f, 0x1a, 0x7c, 0x1e, 0xd9, 0x61, 0xdc, 0x44, 0x9d, 0x5b, 0x26, 0x9c, 0xa1, 0x2d,
		0xde, 0x42, 0xa9, 0x72, 0x54, 0xb5, 0xc6, 0x66, 0x68, 0xdd, 0xd0, 0xf8, 0xcc, 0xaa, 0x22, 0xed,
		0xde, 0x20, 0x8a, 0x42, 0x8f, 0x39, 0xf7, 0xc4, 0x99, 0xb4, 0xfb, 0x64, 0xc1, 0xc0, 0x12, 0x2d,
		0x47, 0x63, 0x8f, 0x04, 0x56, 0xf8, 0x91, 0x51, 0x68, 0x85, 0x64, 0x70, 0x28, 0xb7, 0xa4, 0x1a,
		0x27, 0x6e, 0xda, 0x61, 0x3c, 0xf6, 0x5d, 0xd7, 0x0a, 0x03, 0xa1, 0xc7, 0xad, 0x70, 0x74, 0xa9,
		0x13, 0x5a, 0x02, 0x00, 0x75, 0xf9, 0x9e, 0x45, 0xd9, 0xfe, 0x96, 0x25, 0x76, 0xe1, 0xd9, 0xc8,
		0x0e, 0x7b, 0xdb, 0x67, 0xe1, 0x5d, 0xd9, 0x8a, 0xb2, 0x51, 0x8f, 0x05, 0x74, 0x10, 0x87, 0x23,
		0x2b, 0xe2, 0x1c, 0x91, 0x1d, 0xe8, 0x34, 0xff, 0x3e, 0x66, 0x96, 0x88, 0x29, 0x3a, 0xc3, 0xd4,
		0x57, 0x6c, 0x09, 0x6e, 0x90, 0xd8, 0x09, 0xa8, 0x68, 0x7b, 0x76, 0xb8, 0x5a, 0x7e, 0xe4, 0xd8,
		0x94, 0x93, 0xa9, 0x7d, 0x3f, 0x3f, 0xbe, 0xb0, 0x03, 0xff, 0x69, 0x49, 0x7d, 0xc5, 0x34, 0x8e,
		0x7c, 0x6e, 0x15, 0xbe, 0x67, 0x9e, 0xa8, 0x3d, 0xb1, 0xa7, 0x24, 0xfb, 0xa6, 0x62, 0x85, 0xb2,
		0x8d, 0xa2, 0xe8, 0x7c, 0xe4, 0x09, 0xe6, 0xb1, 0xe0, 0xd7, 0xe7, 0x51, 0xe0, 0x5a, 0xd2, 0xaf,
		0x61, 0x26, 0x1d, 0xf6, 0xab, 0xb6, 0xc0, 0x0e, 0x8e, 0xed, 0xb0, 0x13, 0xa2, 0x30, 0xa8, 0xd9,
		0x51, 0x2f, 0x3c, 0x6d, 0x44, 0x6b, 0xc9, 0xb6, 0x8e, 0xb8, 0x15, 0x3d, 0x27, 0xef, 0x7a, 0xe1,
		0xdd, 0x1c, 0x1b, 0x63, 0x55, 0x78, 0xb3, 0x61, 0x85, 0xaf, 0xc0, 0x87, 0x96, 0x60, 0x22, 0xa6,
		0xed, 0xc5, 0x1a, 0x56, 0x84, 0xb3, 0xe2, 0xbe, 0x73, 0x78, 0x70, 0x60, 0x89, 0x6b, 0x4b, 0x88,
		0x1d, 0xfd, 0xe5, 0x88, 0xf0, 0xbf, 0x39, 0xac, 0x1e, 0xb8, 0x6d, 0x2b, 0x4c, 0xda, 0x38, 0x8a,
		0xad, 0x32, 0x67, 0xcf, 0x4f, 0x7c, 0xc1, 0xed, 0xaa, 0x11, 0x71, 0xc6, 0xeb, 0x5e, 0x2e, 0xf9,
		0xb2, 0xdf, 0xb6, 0x04, 0xdc, 0xc7, 0xc3, 0xbe, 0xb8, 0x25, 0x31, 0x6d, 0x86, 0x61, 0xd4, 0xb3,
		0xa4, 0x57, 0xd6, 0xc8, 0x13, 0x31, 0xb1, 0xa7, 0x72, 0xe8, 0xc4, 0xb2, 0xba, 0xa1, 0x3e, 0xeb,
		0xc5, 0xd4, 0x22, 0x57, 0x52, 0xd0, 0xd8, 0xb7, 0xa4, 0x15, 0xf4, 0x30, 0xf4, 0x69, 0x14, 0x10,
		0x5b, 0x80, 0x7f, 0x96, 0x18, 0x38, 0xa5, 0xaa, 0x1d, 0x9d, 0x3e, 0xff, 0xb6, 0x04, 0x9c, 0x4a,
		0x1c, 0x41, 0x3d, 0xc6, 0xcf, 0xa9, 0x20, 0xcd, 0x56, 0xab, 0x6d, 0x65, 0x28, 0xcc, 0x22, 0x0d,
		0xec, 0xd9, 0x31, 0x81, 0xc3, 0xa2, 0x7e, 0x8f, 0x51, 0x1c, 0x46, 0x27, 0x81, 0x67, 0x85, 0x93,
		0xee, 0x55, 0x58, 0x64, 0x4b, 0x93, 0x0c, 0xce, 0xee, 0xba, 0xe1, 0x59, 0x38, 0xb2, 0xcc, 0x9d,
		0x20, 0x8e, 0x47, 0xee, 0xed, 0x28, 0x6e, 0x5b, 0xcc, 0x8a, 0xb0, 0xc2, 0x5f, 0x1f, 0xc4, 0x95,
		0xbd, 0xca, 0xe5, 0x69, 0xd7, 0x0e, 0x47, 0x27, 0xa0, 0xa2, 0x75, 0x43, 0xe3, 0x21, 0x25, 0xae,
		0x45, 0xd6, 0x2d, 0xe5, 0x8e, 0x1d, 0x38, 0xeb, 0x49, 0x6b, 0x07, 0x7e, 0x4e, 0x9c, 0xa6, 0x2d,
		0xcc, 0xc6, 0x7a, 0x7e, 0xe5, 0x60, 0x2f, 0x22, 0xf1, 0x98, 0x1c, 0xac, 0x70, 0x1f, 0xdc, 0xa1,
		0x2d, 0xfd, 0x4a, 0x67, 0x69, 0xd4, 0xb3, 0x2f, 0xa7, 0x56, 0x08, 0xb2, 0x83, 0xbd, 0x0a, 0x11,
		0x65, 0xbf, 0x67, 0xd1, 0x84, 0x9e, 0x99, 0x0c, 0xfb, 0x62, 0x0b, 0x14, 0xa8, 0x4f, 0xb8, 0xb0,
		0x66, 0xec, 0xe8, 0x54, 0x98, 0x75, 0x5d, 0x9f, 0x58, 0x52, 0xfc, 0x6c, 0x47, 0xe3, 0xf8, 0x88,
		0xd8, 0x11, 0xb8, 0x73, 0x3d, 0x6e, 0xc5, 0x00, 0x4f, 0x8f, 0x44, 0x7d, 0x4b, 0x12, 0x26, 0xa7,
		0x77, 0xcc, 0x3e, 0xe1, 0x6a, 0x47, 0xf8, 0xd3, 0x9a, 0x5e, 0x2e, 0xb6, 0xe4, 0x77, 0x2d, 0x01,
		0xad, 0xf6, 0x3b, 0x6c, 0x60, 0xcd, 0x98, 0xd9, 0xb1, 0xfb, 0xf5, 0xad, 0x6b, 0x4b, 0xf4, 0xa8,
		0x1d, 0xb2, 0x40, 0x74, 0xc3, 0xc9, 0x8f, 0x0e, 0x8d, 0x99, 0x1d, 0x13, 0x39, 0xbc, 0x0a, 0x8b,
		0xee, 0x6c, 0x09, 0x26, 0xf9, 0xd4, 0x65, 0xe4, 0x9c, 0x30, 0xcf, 0x22, 0x84, 0x8a, 0xeb, 0x58,
		0xa1, 0xc4, 0x78, 0x1c, 0x59, 0x15, 0xa1, 0xb3, 0x2b, 0xd7, 0x3f, 0x5e, 0x76, 0xab, 0xef, 0xfa,
		0xc4, 0xa6, 0xfe, 0x48, 0x51, 0x14, 0xd9, 0xd1, 0x5c, 0xd1, 0x12, 0x07, 0x91, 0x08, 0xdf, 0xa2,
		0x51, 0x4d, 0x63, 0x95, 0x36, 0xc1, 0x31, 0x47, 0x1e, 0xbd, 0x0b, 0xed, 0x08, 0xce, 0xf1, 0x51,
		0x64, 0xe5, 0x08, 0xf5, 0x53, 0x5b, 0x46, 0xa8, 0x4f, 0x21, 0xc2, 0x27, 0xb6, 0x8c, 0x9f, 0xb4,
		0x64, 0x9d, 0x2b, 0x03, 0x5b, 0x3e, 0xdb, 0x01, 0x13, 0x76, 0x1c, 0x51, 0xf7, 0x47, 0x76, 0x54,
		0x8d, 0x94, 0xac, 0x9a, 0x31, 0x74, 0xc6, 0x7a, 0x76, 0x68, 0x33, 0x61, 0x09, 0x73, 0xb1, 0x40,
		0xd0, 0xd8, 0xa3, 0xe4, 0xc6, 0x8a, 0x32, 0x1c, 0x31, 0xb2, 0x25, 0x86, 0x34, 0x27, 0xd8, 0x49,
		0x53, 0x9c, 0x4b, 0x4b, 0xfa, 0x89, 0x2c, 0xdb, 0x45, 0x77, 0x68, 0x7c, 0xc3, 0xec, 0x68, 0x9c,
		0x15, 0x85, 0x41, 0x69, 0x7f, 0xdf, 0x12, 0x0b, 0xb7, 0x17, 0x06, 0x76, 0x4c, 0xd2, 0xb7, 0x24,
		0xe4, 0x11, 0xf3, 0xb8, 0x67, 0x17, 0x67, 0x9d, 0xb7, 0x1b, 0xf6, 0x8c, 0x95, 0xb0, 0x09, 0x7b,
		0x70, 0xe3, 0x72, 0x3b, 0x6a, 0x5d, 0x9e, 0xfa, 0x37, 0xa5, 0xb3, 0x5b, 0xd7, 0x12, 0x07, 0xc7,
		0x96, 0x1e, 0xbb, 0x03, 0x5b, 0x3a, 0x29, 0x4e, 0x3a, 0x39, 0x58, 0x71, 0xf2, 0xbe, 0xcb, 0x2d,
		0x49, 0x38, 0x46, 0x71, 0x18, 0xcd, 0x8b, 0x4a, 0xdb, 0x65, 0x2b, 0xc0, 0xd6, 0xac, 0xdf, 0xbe,
		0xed, 0xde, 0x47, 0xd4, 0x4a, 0xf1, 0x75, 0x49, 0x85, 0x25, 0xe2, 0xcb, 0x09, 0xfb, 0x7d, 0x4a,
		0xad, 0x01, 0x7b, 0x9d, 0x36, 0xac, 0x80, 0x7a, 0x39, 0x8c, 0x3b, 0x61, 0xa3, 0xd3, 0xb4, 0x25,
		0x4d, 0x46, 0x84, 0xdf, 0xb0, 0x03, 0x85, 0x74, 0x33, 0x8d, 0x87, 0x37, 0xa2, 0x63, 0xd7, 0x8d,
		0x2d, 0x29, 0x91, 0xf7, 0x23, 0x8f, 0x77, 0xad, 0x71, 0xd3, 0xa7, 0x66, 0xae, 0x4d, 0x69, 0x27,
		0x8f, 0x44, 0xae, 0x1d, 0x1e, 0xcf, 0xa9, 0x67, 0x51, 0x45, 0xf7, 0x90, 0x73, 0x66, 0x0d, 0xea,
		0xa3, 0x4d, 0xc4, 0xd0, 0x16, 0x59, 0x60, 0xc7, 0xb0, 0xb1, 0xbd, 0xbd, 0x43, 0x9b, 0x5a, 0xd5,
		0x9d, 0x70, 0x9f, 0x38, 0xae, 0x35, 0xf4, 0x6a, 0xdb, 0x10, 0x2c, 0x7b, 0xea, 0x01, 0xce, 0xbe,
		0x9c, 0xb6, 0x3a, 0x36, 0x41, 0x3c, 0xec, 0x02, 0xa6, 0x10, 0xe1, 0x37, 0xc3, 0x01, 0x73, 0x88,
		0x67, 0x55, 0x77, 0xa2, 0x89, 0x7b, 0x66, 0x87, 0xab, 0xce, 0x7c, 0x12, 0xdf, 0x37, 0x3a, 0xa7,
		0x56, 0xb4, 0x5c, 0x24, 0xa5, 0xf2, 0x79, 0x64, 0xd1, 0xe4, 0x00, 0xee, 0xbb, 0xbc, 0xe1, 0xd8,
		0x51, 0x0c, 0x3d, 0xa9, 0x7c, 0x6c, 0x9c, 0x76, 0x6d, 0x1c, 0xeb, 0x67, 0x53, 0x3d, 0xac, 0xeb,
		0x06, 0x7f, 0xd9, 0x51, 0x0b, 0x3b, 0xef, 0xb9, 0x58, 0xb2, 0xa4, 0xd7, 0xb9, 0x3d, 0xdd, 0x2c,
		0x87, 0xb6, 0xa4, 0x4a, 0xc8, 0x78, 0xa1, 0x91, 0x25, 0x8d, 0x8e, 0x6f, 0x6f, 0x49, 0xd0, 0x6e,
		0x5b, 0xb1, 0xaf, 0xd4, 0x0e, 0xd0, 0x4f, 0x64, 0x47, 0xec, 0xbe, 0x38, 0xe0, 0x81, 0x4d, 0x1e,
		0x43, 0xfd, 0xf8, 0xe2, 0xd8, 0x8a, 0x50, 0x97, 0x6f, 0x47, 0x1b, 0x97, 0xc0, 0x0e, 0xc5, 0xcf,
		0x4b, 0x67, 0xa7, 0x4d, 0x4b, 0x82, 0xb2, 0x5d, 0xd7, 0x0a, 0xff, 0x30, 0x26, 0x2e, 0x0b, 0xcf,
		0x8f, 0x4f, 0xac, 0x98, 0x3b, 0xcb, 0x59, 0x64, 0x65, 0xe3, 0x29, 0x3b, 0xa2, 0xdd, 0xfd, 0x52,
		0xed, 0xbc, 0x1f, 0xdb, 0x63, 0x03, 0xfa, 0xa1, 0x43, 0xbe, 0xd1, 0x98, 0xb3, 0x30, 0x28, 0xd9,
		0xd3, 0x50, 0xa2, 0x56, 0xb5, 0xa3, 0x2e, 0xb7, 0x72, 0x60, 0x55, 0xc0, 0xc8, 0x92, 0xae, 0xe6,
		0xcc, 0x96, 0x72, 0x67, 0x36, 0x60, 0x82, 0x78, 0xdf, 0x63, 0x12, 0x45, 0x34, 0xb6, 0xb0, 0x45,
		0xd2, 0xec, 0x05, 0xda, 0xe1, 0x2d, 0x8d, 0x3d, 0x16, 0x58, 0x21, 0xd0, 0x38, 0x3f, 0xb0, 0xa8,
		0x7a, 0xfb, 0x69, 0x08, 0xc9, 0xae, 0xb8, 0xf8, 0xa2, 0xf3, 0xcc, 0xd9, 0x5f, 0x96, 0xe4, 0xcc,
		0x7b, 0x76, 0xc0, 0x01, 0xed, 0x98, 0xb5, 0x7e, 0x57, 0xde, 0x1f, 0x8e, 0x02, 0x61, 0x4d, 0xa3,
		0x24, 0x16, 0xf4, 0x59, 0xc0, 0x7a, 0x44, 0x09, 0x7b, 0x2f, 0x75, 0xc5, 0xd5, 0x3b, 0x03, 0xbb,
		0x20, 0xf7, 0xf6, 0x8f, 0x82, 0x67, 0x05, 0x40, 0xeb, 0x61, 0xbe, 0x00, 0xb5, 0x9c, 0xfe, 0xb7,
		0x3e, 0x93, 0x03, 0x5d, 0x9a, 0x5f, 0x14, 0x8d, 0xbc, 0x98, 0x43, 0x5a, 0x10, 0xb9, 0x61, 0x0e,
		0x6b, 0x4d, 0x5b, 0xf8, 0x48, 0xf6, 0x1a, 0x33, 0xbf, 0xb8, 0x1b, 0xff, 0x96, 0xc4, 0xf4, 0x82,
		0x39, 0x5d, 0x29, 0xbd, 0x69, 0x7e, 0x61, 0x03, 0x11, 0x41, 0x5a, 0xce, 0xdf, 0xb0, 0x76, 0xc7,
		0xe9, 0x79, 0xdf, 0xa8, 0x23, 0x48, 0x47, 0x10, 0x50, 0xe4, 0x34, 0x2b, 0xdf, 0xf6, 0xc8, 0x2d,
		0xa4, 0x55, 0xf9, 0x37, 0xa0, 0xa4, 0x78, 0xc4, 0x40, 0x91, 0x36, 0xf1, 0x46, 0xf5, 0x28, 0x0c,
		0x66, 0x28, 0x0d, 0x39, 0xeb, 0xdf, 0xfc, 0xea, 0x38, 0xac, 0xcd, 0xf2, 0x42, 0x87, 0x78, 0x5d,
		0xe2, 0x81, 0xda, 0xa3, 0xc1, 0xd1, 0xd1, 0x61, 0x19, 0xd2, 0x82, 0xd6, 0xfa, 0x4f, 0x7c, 0x95,
		0xeb, 0x3f, 0x91, 0x01, 0xd1, 0xf3, 0xfb, 0xc0, 0x81, 0xb4, 0xa0, 0x65, 0x79, 0x23, 0x28, 0x79,
		0xce, 0xdd, 0x60, 0x04, 0x69, 0x41, 0xc3, 0x90, 0x0b, 0xa9, 0xb9, 0x2a, 0x19, 0x90, 0xd2, 0xbc,
		0x3d, 0x7a, 0x05, 0xd2, 0xaa, 0x66, 0x3d, 0x23, 0xbb, 0x31, 0x09, 0x78, 0x24, 0x35, 0x75, 0x22,
		0x83, 0xb5, 0x89, 0xa0, 0xe5, 0x82, 0x22, 0xab, 0x1e, 0xe1, 0xcc, 0x91, 0xc3, 0xd0, 0x65, 0xc1,
		0x7c, 0x93, 0x06, 0x08, 0x15, 0x59, 0xa8, 0x72, 0x16, 0xc2, 0xea, 0x2c, 0x8c, 0x6f, 0x49, 0x0c,
		0x6a, 0x51, 0x33, 0xb0, 0x53, 0x85, 0xb8, 0x4d, 0x32, 0x28, 0x00, 0x8b, 0x22, 0xc0, 0x52, 0xcf,
		0x93, 0x59, 0x91, 0xad, 0x11, 0x28, 0xa1, 0x30, 0xac, 0x94, 0x2b, 0xed, 0x38, 0xbc, 0xbb, 0x87,
		0x66, 0x1b, 0x37, 0xdb, 0xd0, 0x6c, 0x3d, 0x50, 0x8a, 0x86, 0x4b, 0xb5, 0xe9, 0xc9, 0x80, 0x8e,
		0x58, 0x14, 0x31, 0x50, 0x34, 0x44, 0xbc, 0x7d, 0x48, 0xeb, 0xb9, 0x2b, 0xef, 0x47, 0x1e, 0x05,
		0xa8, 0xe8, 0xf6, 0x4f, 0x2e, 0xcf, 0xda, 0x8d, 0x00, 0x94, 0x54, 0xe2, 0x82, 0x38, 0xbf, 0xba,
		0x61, 0x47, 0x48, 0x8d, 0xa1, 0xcc, 0x20, 0x6e, 0x37, 0xad, 0x6b, 0xed, 0x82, 0x52, 0x74, 0xc3,
		0xfb, 0x88, 0xc6, 0xd2, 0x23, 0xb9, 0x32, 0x08, 0x09, 0xcb, 0xb4, 0xb2, 0xc8, 0x20, 0xfe, 0x13,
		0x87, 0x91, 0x74, 0x9f, 0xce, 0xcc, 0xe2, 0x40, 0xed, 0xe1, 0x3d, 0x1f, 0x7b, 0x0e, 0x5f, 0x03,
		0x06, 0x32, 0xa4, 0x70, 0xe1, 0x82, 0x8a, 0x78, 0xba, 0x1c, 0x94, 0x36, 0x76, 0x42, 0x3f, 0x0a,
		0x39, 0x93, 0xed, 0xbf, 0x6f, 0x7e, 0x61, 0x31, 0x1d, 0x8c, 0x3c, 0x12, 0xcb, 0x8d, 0x0a, 0xca,
		0xc0, 0xf1, 0x63, 0x02, 0x54, 0xb2, 0x68, 0x8a, 0x80, 0x87, 0x66, 0x70, 0x96, 0x40, 0xa9, 0xbe,
		0x4a, 0x0d, 0x96, 0x00, 0x28, 0x41, 0xb4, 0xa5, 0x4e, 0x05, 0x28, 0x31, 0xb9, 0xd2, 0x81, 0xb6,
		0x1d, 0x87, 0x7d, 0x06, 0xcb, 0x00, 0x1d, 0xb0, 0x01, 0xe9, 0xb1, 0x29, 0x1e, 0x47, 0xaa, 0xd8,
		0x3a, 0x83, 0x50, 0x0b, 0xe1, 0xa0, 0xd6, 0x13, 0xc1, 0xf2, 0xf6, 0xc6, 0xb6, 0xd4, 0xe7, 0xef,
		0xc7, 0x51, 0xf9, 0x1c, 0x54, 0x9a, 0xe8, 0xee, 0xb0, 0xd6, 0x24, 0x11, 0x07, 0xb6, 0x53, 0x82,
		0x86, 0xc1, 0xe1, 0xde, 0x79, 0x8f, 0x09, 0x58, 0xfe, 0x68, 0x09, 0x94, 0x09, 0x15, 0x43, 0x43,
		0xfd, 0xdc, 0x95, 0xf7, 0x7d, 0x0f, 0x56, 0x16, 0xb4, 0x2c, 0xd7, 0xa9, 0x2a, 0x2b, 0xfd, 0xf2,
		0x5d, 0xcc, 0x1d, 0xab, 0x4b, 0xe2, 0xb2, 0x10, 0x94, 0x77, 0x25, 0x60, 0xc1, 0x6b, 0xfa, 0x11,
		0xb0, 0xdd, 0xe9, 0x8c, 0x7a, 0x8d, 0x40, 0xd0, 0xb8, 0x4f, 0x1c, 0x0a, 0xcb, 0x71, 0x21, 0xce,
		0xf0, 0xb4, 0xd3, 0x04, 0xe5, 0xb5, 0xc4, 0xcc, 0x1d, 0x50, 0x68, 0x66, 0x0a, 0x30, 0xb1, 0x39,
		0xad, 0xd5, 0xfc, 0xab, 0x03, 0x2c, 0xf3, 0x72, 0xe9, 0x38, 0x2a, 0x48, 0xf5, 0x0c, 0x50, 0x52,
		0xc4, 0xe9, 0x50, 0xe7, 0x6b, 0xe0, 0x84, 0x81, 0x88, 0x43, 0xcf, 0xa3, 0x6e, 0xe3, 0x0c, 0x60,
		0x7c, 0xaa, 0x05, 0x0b, 0x90, 0x10, 0xf3, 0x72, 0xa5, 0x0c, 0x2d, 0xb9, 0x2e, 0x46, 0x40, 0x43,
		0x77, 0x7d, 0x98, 0x90, 0x9b, 0x89, 0xe2, 0x71, 0xc2, 0x20, 0xa0, 0x0e, 0x28, 0xd3, 0x58, 0x4c,
		0xd0, 0x1b, 0xff, 0x06, 0x96, 0x61, 0xeb, 0x3b, 0x2c, 0x82, 0x16, 0x5e, 0x9c, 0x8e, 0xf6, 0xfe,
		0xdc, 0x81, 0x87, 0xad, 0x9e, 0x19, 0xa4, 0x17, 0xcc, 0x81, 0x96, 0x6d, 0xff, 0x42, 0x04, 0xfd,
		0x45, 0x69, 0x04, 0x0b, 0x91, 0xbe, 0xda, 0x45, 0x0e, 0x54, 0x64, 0xcd, 0x0f, 0x5d, 0xea, 0x43,
		0x8b, 0x7d, 0xac, 0x16, 0xc0, 0xc9, 0x57, 0x7b, 0x67, 0x02, 0xdf, 0xed, 0x30, 0x50, 0x49, 0x4a,
		0x3f, 0xa2, 0x03, 0x90, 0xa8, 0xb8, 0x79, 0xb3, 0x26, 0x58, 0x50, 0x21, 0x07, 0x94, 0x9b, 0xef,
		0x73, 0x60, 0x4e, 0x46, 0xd0, 0x27, 0x1c, 0x60, 0xf8, 0xbf, 0xec, 0xc1, 0x32, 0x19, 0xfe, 0x2e,
		0x1f, 0x55, 0x4a, 0xd0, 0x80, 0xcd, 0x1c, 0x9e, 0x01, 0x13, 0x38, 0x04, 0x5a, 0x6d, 0xc8, 0x17,
		0x78, 0x3e, 0xd7, 0x8c, 0xc8, 0x6b, 0xe7, 0x24, 0x00, 0x18, 0x61, 0x2f, 0x81, 0x8b, 0xb0, 0x4f,
		0x20, 0x71, 0x20, 0x83, 0x6b, 0x33, 0x9f, 0x1e, 0x20, 0xc9, 0x03, 0x85, 0xc1, 0xb0, 0x08, 0x20,
		0xf2, 0x9a, 0x08, 0x1f, 0x5c, 0xbc, 0x7d, 0x26, 0x23, 0xaa, 0x93, 0xe9, 0x81, 0x9f, 0x47, 0xb0,
		0x94, 0xb4, 0x74, 0x03, 0xdc, 0x6c, 0xac, 0xcf, 0x52, 0xe5, 0xa8, 0x0a, 0x4e, 0x27, 0xb6, 0x6e,
		0x68, 0x7c, 0x06, 0xb2, 0x38, 0xaa, 0x37, 0x88, 0xa2, 0xd0, 0x63, 0xce, 0x3d, 0x71, 0x9c, 0x70,
		0x14, 0x08, 0xa9, 0x11, 0x95, 0x99, 0x48, 0x7d, 0x1a, 0x7b, 0x24, 0x00, 0xe5, 0x4f, 0x44, 0x21,
		0x28, 0x4e, 0x74, 0x28, 0x07, 0x86, 0x36, 0x8e, 0x9b, 0xb0, 0x8c, 0x9a, 0xbe, 0xeb, 0x82, 0x52,
		0x80, 0x3d, 0x0e, 0xca, 0xb1, 0xa1, 0x4e, 0x08, 0x0c, 0x30, 0xe4, 0xf2, 0x3d, 0x80, 0x59, 0xb8,
		0x16, 0x30, 0x7b, 0xe5, 0x6c, 0x04, 0xcb, 0xae, 0xf3, 0x59, 0x78, 0x57, 0x06, 0x55, 0x26, 0xe2,
		0xb1, 0x80, 0x0e, 0xe4, 0xda, 0x13, 0x65, 0xa0, 0x3e, 0x60, 0xa1, 0x28, 0xfc, 0xfb, 0x98, 0x01,
		0x63, 0xff, 0xf9, 0x7c, 0x9b, 0x0a, 0x34, 0x27, 0x74, 0x3a, 0xa8, 0xb3, 0xed, 0xc1, 0x32, 0xc5,
		0xfd, 0xc8, 0x81, 0x18, 0x03, 0xae, 0x7d, 0x3f, 0x3f, 0xbe, 0x80, 0x85, 0x17, 0x02, 0x86, 0x43,
		0x9d, 0xc6, 0xcb, 0xce, 0x41, 0xe6, 0xb9, 0xe7, 0x89, 0x98, 0x13, 0x78, 0xa5, 0x50, 0x37, 0x15,
		0x50, 0x4a, 0x26, 0x8a, 0xa2, 0xf3, 0x91, 0x27, 0x98, 0xc7, 0x82, 0x5f, 0xb2, 0x8d, 0x7f, 0xb3,
		0xe3, 0xc6, 0xfd, 0x2a, 0xb4, 0xb4, 0xdf, 0x31, 0x2c, 0x3d, 0x18, 0x85, 0x41, 0x0d, 0x56, 0x5d,
		0xcf, 0xb4, 0x11, 0x15, 0xb0, 0x6d, 0x1a, 0x71, 0x50, 0x3d, 0x70, 0xee, 0x7a, 0xe1, 0xdd, 0x3c,
		0x77, 0x0c, 0x32, 0xec, 0xd3, 0x00, 0x65, 0x7b, 0xf2, 0x21, 0xb0, 0xdc, 0xe3, 0xb4, 0x8d, 0x43,
		0x03, 0x54, 0xb8, 0x20, 0xee, 0x3b, 0x87, 0x07, 0x07, 0xc0, 0x5c, 0x19, 0x42, 0x60, 0xf5, 0xdf,
		0x20, 0xc2, 0xff, 0x26, 0x3d, 0xd8, 0x35, 0x83, 0xb3, 0x8b, 0x62, 0x90, 0xe6, 0xd4, 0xf9, 0x89,
		0x2f, 0x38, 0x4c, 0xcc, 0xac, 0x33, 0x5e, 0xdf, 0x72, 0x69, 0x97, 0xfd, 0x36, 0x30, 0x50, 0x09,
		0x0f, 0xfb, 0xe2, 0x96, 0xc4, 0xb4, 0x19, 0x86, 0x51, 0x0f, 0x58, 0x0f, 0x83, 0x91, 0x27, 0x62,
		0x02, 0x0f, 0x01, 0x7d, 0x02, 0x14, 0xff, 0xdc, 0x67, 0xbd, 0x98, 0x02, 0x74, 0x29, 0x04, 0x8d,
		0x7d, 0x60, 0x2d, 0xd9, 0x86, 0xa1, 0x4f, 0xa3, 0x80, 0x40, 0x03, 0x9c, 0x00, 0x53, 0xd4, 0xa5,
		0x2a, 0xac, 0x4e, 0x42, 0x7f, 0x03, 0x03, 0x2d, 0x11, 0x47, 0x50, 0x8f, 0xf1, 0x73, 0x2a, 0x48,
		0xb3, 0xd5, 0x6a, 0x83, 0x0e, 0x35, 0x00, 0xd4, 0x3c, 0x1e, 0xac, 0xce, 0xad, 0x00, 0xfb, 0xd2,
		0x8c, 0x3d, 0xf9, 0x93, 0xc0, 0x03, 0xe5, 0x7c, 0x79, 0x15, 0x16, 0x41, 0x2b, 0xee, 0xe4, 0xec,
		0xae, 0x1b, 0x9e, 0x85, 0x23, 0xa0, 0xe6, 0xa9, 0xf4, 0xe8, 0xda, 0x0c, 0x7b, 0x92, 0x82, 0xf2,
		0xc3, 0x26, 0x03, 0x8a, 0x2f, 0x65, 0x06, 0x14, 0x67, 0x61, 0x20, 0x07, 0x54, 0x28, 0xcf, 0x17,
		0xca, 0x20, 0x9f, 0xc3, 0x1d, 0x58, 0xf8, 0xb8, 0x49, 0x09, 0x23, 0x3f, 0x27, 0x4e, 0x13, 0x1a,
		0xd1, 0xb3, 0x9e, 0x5f, 0x39, 0xd8, 0x8b, 0x48, 0x3c, 0x3e, 0x46, 0x50, 0xe6, 0xa8, 0x3b, 0x84,
		0xd6, 0xf7, 0x68, 0x96, 0x3e, 0x39, 0xfb, 0x72, 0x0a, 0x4a, 0x40, 0x4c, 0x26, 0xd4, 0x95, 0xfd,
		0x1e, 0xc0, 0x4e, 0xca, 0x33, 0xd9, 0xf0, 0x05, 0x5a, 0x4a, 0x7c, 0x31, 0x48, 0x0a, 0x9e, 0x90,
		0xe8, 0xba, 0x3e, 0x01, 0x56, 0x8c, 0x04, 0xab, 0x61, 0x62, 0x44, 0x60, 0x05, 0x40, 0x5c, 0x8f,
		0x83, 0x1a, 0xdc, 0xe1, 0x91, 0xa8, 0x0f, 0x2c, 0x70, 0x7b, 0x7a, 0xc7, 0xe0, 0x0a, 0x27, 0x58,
		0x61, 0x21, 0x70, 0x35, 0xc2, 0xd0, 0xf2, 0x37, 0xc0, 0xc0, 0x4c, 0x7d, 0xe9, 0xe1, 0x8f, 0x19,
		0x99, 0xe7, 0xdf, 0xba, 0xd0, 0xbc, 0xf6, 0x76, 0xc8, 0x02, 0xd1, 0x0d, 0x27, 0x3f, 0x3a, 0x34,
		0x66, 0xb0, 0x3a, 0xb9, 0x8e, 0x7d, 0xf8, 0x3b, 0x68, 0x4e, 0xbc, 0x4f, 0x5d, 0x46, 0xce, 0x09,
		0xf3, 0x00, 0x66, 0x76, 0x5d, 0x07, 0x94, 0x50, 0xe7, 0x71, 0x04, 0x32, 0xd2, 0x01, 0x33, 0x07,
		0x37, 0x5e, 0x5e, 0xab, 0xef, 0xfa, 0x04, 0x62, 0xfd, 0x7b, 0x14, 0x45, 0xb0, 0x9a, 0xc3, 0x00,
		0x73, 0x14, 0x88, 0xf0, 0x01, 0xb6, 0xc2, 0x1e, 0x8b, 0xf8, 0x09, 0x2e, 0x2d, 0xf2, 0xe8, 0x5d,
		0x08, 0x2b, 0xc8, 0xc1, 0x47, 0x11, 0xe8, 0x51, 0x5f, 0xa7, 0xd0, 0x46, 0x7d, 0xcd, 0x66, 0x12,
		0x42, 0x1b, 0x53, 0x01, 0x6c, 0x3d, 0x2b, 0x0d, 0x7a, 0x3f, 0xc3, 0x82, 0x83, 0x39, 0x8e, 0xa8,
		0xfb, 0x23, 0x58, 0x28, 0xda, 0x12, 0xc8, 0x9e, 0xcf, 0x67, 0xac, 0x07, 0x4b, 0xba, 0x0b, 0x60,
		0x44, 0xce, 0x02, 0x41, 0x63, 0x8f, 0x92, 0x1b, 0x50, 0x30, 0x63, 0x31, 0x82, 0xe6, 0xbb, 0xcf,
		0x09, 0x6a, 0x52, 0x3c, 0x7d, 0x09, 0xac, 0xae, 0x75, 0xd9, 0xb6, 0xad, 0x43, 0xe3, 0x1b, 0x06,
		0xab, 0xa1, 0x41, 0x14, 0x06, 0xa5, 0xfd, 0x7d, 0x60, 0x16, 0x56, 0x2f, 0x0c, 0x60, 0x4d, 0x6a,
		0x03, 0xe6, 0x9a, 0xc6, 0x3c, 0xee, 0xc1, 0xa4, 0xf0, 0xf3, 0x76, 0x03, 0x5e, 0xfb, 0x52, 0x88,
		0xb9, 0xbf, 0x1b, 0x70, 0x33, 0xf6, 0x9e, 0xd8, 0xc5, 0xa5, 0xb3, 0x5b, 0x17, 0x98, 0x61, 0x0c,
		0xad, 0x97, 0xd6, 0x00, 0x5a, 0x27, 0x98, 0x49, 0xc5, 0x22, 0xa8, 0x13, 0xf3, 0x5d, 0x0e, 0x2c,
		0x01, 0x31, 0x76, 0x95, 0xe7, 0x45, 0x24, 0xed, 0x32, 0x28, 0x90, 0x1c, 0xeb, 0xb7, 0x6f, 0xbb,
		0xf7, 0x11, 0x05, 0x2d, 0x16, 0x2e, 0xa9, 0x00, 0x26, 0x16, 0x9c, 0xb0, 0xdf, 0xa7, 0x14, 0x1c,
		0x58, 0xe1, 0xb4, 0x01, 0x0a, 0xaa, 0xe0, 0x30, 0xee, 0x84, 0x8d, 0x4e, 0x13, 0x5a, 0x98, 0x9d,
		0x08, 0xbf, 0x01, 0x2b, 0xeb, 0x3e, 0x1b, 0x55, 0xd8, 0x88, 0x8e, 0x5d, 0x37, 0x06, 0x56, 0x6a,
		0xe6, 0x47, 0x1e, 0xef, 0x82, 0x73, 0xbf, 0xa6, 0x66, 0x16, 0xc4, 0x70, 0xb6, 0x47, 0x22, 0x60,
		0x83, 0xa8, 0x4f, 0x3d, 0x80, 0x95, 0x54, 0x43, 0xce, 0x19, 0xb8, 0x2c, 0x6a, 0x9b, 0x88, 0x21,
		0x34, 0xde, 0x83, 0xd5, 0x6c, 0x7d, 0x6f, 0xef, 0x10, 0x62, 0x2b, 0x0f, 0x78, 0xf3, 0xdf, 0x39,
		0xb4, 0xa6, 0x47, 0xab, 0x4d, 0xc3, 0xe1, 0xe1, 0x2c, 0xcf, 0xbe, 0x9c, 0xb6, 0x3a, 0x10, 0x53,
		0xa6, 0x30, 0x13, 0xba, 0x44, 0xf8, 0xcd, 0x70, 0xc0, 0x1c, 0xe2, 0x81, 0xac, 0x4a, 0x9f, 0x98,
		0xef, 0xb0, 0x5c, 0x30, 0xe6, 0x93, 0xf8, 0xbe, 0xd1, 0x39, 0x05, 0xd5, 0x32, 0x86, 0x94, 0xca,
		0xe7, 0x11, 0xc0, 0x4e, 0x97, 0x63, 0x27, 0xba, 0xe1, 0xc0, 0x2a, 0x4e, 0x9a, 0x54, 0x46, 0x34,
		0x4e, 0xbb, 0x90, 0xc7, 0x0b, 0x40, 0xac, 0x73, 0x71, 0xdd, 0xe0, 0x2f, 0x58, 0x35, 0x2e, 0xf3,
		0x9e, 0x31, 0x25, 0x60, 0x3d, 0x01, 0xe1, 0x75, 0xd7, 0x19, 0x42, 0x0b, 0xd9, 0x92, 0xf1, 0x82,
		0x22, 0x60, 0x0d, 0xca, 0xa6, 0x03, 0xa1, 0x41, 0xed, 0x13, 0x85, 0x95, 0xfc, 0x8e, 0x60, 0xc5,
		0x1c, 0x8b, 0x03, 0x1e, 0x40, 0xb4, 0x40, 0xeb, 0xc7, 0x17, 0xc7, 0xa0, 0x42, 0x09, 0x3e, 0xac,
		0xf2, 0xe0, 0x20, 0x06, 0x36, 0x55, 0xfc, 0xec, 0xb4, 0x09, 0x2c, 0x28, 0xd5, 0x75, 0x7d, 0x60,
		0x83, 0x7a, 0x59, 0x78, 0x7e, 0x7c, 0x02, 0x6a, 0x1e, 0x0c, 0x67, 0x11, 0xe8, 0x46, 0x01, 0xb0,
		0xa2, 0x77, 0xfd, 0x52, 0xed, 0xbc, 0x1f, 0xc3, 0xb3, 0x4d, 0xfc, 0xd0, 0x21, 0xdf, 0x68, 0xcc,
		0x59, 0x18, 0x94, 0xe0, 0x15, 0x48, 0xd6, 0xaa, 0xb0, 0xea, 0x6a, 0x2a, 0x07, 0x20, 0x1d, 0x75,
		0x60, 0xdd, 0xff, 0x18, 0xb4, 0xf2, 0x23, 0x36, 0x60, 0x82, 0x78, 0xdf, 0x63, 0x12, 0x45, 0x34,
		0x06, 0x5c, 0x02, 0x3f, 0x5b, 0x68, 0x3b, 0xbc, 0xa5, 0xb1, 0xc7, 0x02, 0x50, 0x82, 0x82, 0xf3,
		0x03, 0x80, 0x55, 0x53, 0x4f, 0x5d, 0x77, 0x98, 0x71, 0xbe, 0x45, 0xe5, 0xf2, 0xd9, 0x5f, 0xc0,
		0x72, 0x5c, 0x3d, 0x58, 0x30, 0x14, 0x58, 0x33, 0xc1, 0xee, 0xca, 0xfb, 0xc3, 0x51, 0x20, 0xc0,
		0x15, 0xc2, 0xb3, 0xa0, 0xcf, 0x02, 0xd6, 0x23, 0x52, 0x58, 0xc7, 0x44, 0xdf, 0xbc, 0x7a, 0x97,
		0xee, 0x3e, 0x9b, 0xff, 0xf5, 0xf9, 0x7f, 0xd9, 0xb0, 0x57, 0x85, 0x3f, 0xe9, 0xfd, 0xc4, 0xc6,
		0x1c, 0xbf, 0xf0, 0x86, 0xaf, 0x34, 0x19, 0x17, 0xc7, 0x42, 0xc4, 0x85, 0x4f, 0x2f, 0x6c, 0x63,
		0xe1, 0x9c, 0x05, 0x75, 0x8f, 0xfa, 0x34, 0x10, 0xbc, 0xf0, 0x69, 0x67, 0xef, 0x8f, 0x17, 0xbe,
		0x49, 0xee, 0x56, 0xbe, 0x59, 0x3a, 0xac, 0x56, 0x6b, 0x07, 0xd5, 0xea, 0xde, 0x41, 0xe5, 0x60,
		0xef, 0x68, 0x7f, 0xbf, 0x54, 0x2b, 0xed, 0xbf, 0x70, 0x71, 0x2b, 0x76, 0x69, 0x4c, 0xdd, 0xcf,
		0xe3, 0x55, 0x07, 0x23, 0xcf, 0x93, 0x7a, 0xd9, 0xe3, 0x20, 0x08, 0x05, 0x11, 0x2c, 0x0c, 0x5e,
		0x7e, 0x17, 0xee, 0x0c, 0xa9, 0x4f, 0x22, 0x22, 0x86, 0xe3, 0xbd, 0xd9, 0x65, 0x54, 0xf4, 0x8b,
		0x6c, 0x3e, 0xeb, 0x8c, 0xef, 0x3e, 0xf7, 0x6b, 0xe1, 0x85, 0x35, 0x73, 0x11, 0x8f, 0x1c, 0x11,
		0xcc, 0x68, 0xaa, 0x51, 0xef, 0x9e, 0x2d, 0x06, 0xa7, 0xf1, 0xeb, 0xe7, 0x7e, 0x7d, 0x9e, 0xd8,
		0xd6, 0x0f, 0xf6, 0xf1, 0x27, 0x4f, 0xde, 0xfa, 0xb5, 0xb7, 0x4d, 0xfe, 0x96, 0xcf, 0xbc, 0x5b,
		0xd2, 0x77, 0x7a, 0xfc, 0x26, 0xcb, 0xf5, 0xae, 0xac, 0xb5, 0xb0, 0x7c, 0x50, 0x91, 0x0b, 0x22,
		0xe8, 0xda, 0x6a, 0x1f, 0x63, 0xed, 0x57, 0xbf, 0xf9, 0xe4, 0x8d, 0xff, 0x64, 0x81, 0x3b, 0x26,
		0xa9, 0x27, 0x1f, 0x9f, 0x84, 0x41, 0x9f, 0x0d, 0x0a, 0x9f, 0x76, 0xca, 0x4f, 0xfe, 0xa1, 0x1d,
		0xd3, 0x3e, 0xbb, 0x7b, 0x7e, 0x77, 0x96, 0xd1, 0x97, 0xe7, 0x5e, 0xbf, 0x13, 0x8e, 0x62, 0x87,
		0x6e, 0xa4, 0xa2, 0x31, 0x5b, 0xdd, 0x86, 0xb1, 0x3b, 0x55, 0x9c, 0x93, 0x87, 0x6c, 0x20, 0xc9,
		0x7f, 0x13, 0x7e, 0x1c, 0x0f, 0x46, 0x63, 0x6e, 0x28, 0x7c, 0xda, 0x11, 0xf1, 0x88, 0x6e, 0xa2,
		0xdd, 0xe5, 0xb7, 0xc6, 0x6b, 0x92, 0xa4, 0x85, 0x53, 0xf6, 0x3c, 0xfb, 0x2e, 0xb7, 0x74, 0xf3,
		0xbb, 0xac, 0xed, 0xfe, 0xa6, 0x77, 0x79, 0x7e, 0xfb, 0xd7, 0x8f, 0x61, 0x83, 0x70, 0x78, 0xe9,
		0x38, 0x92, 0x1d, 0x4b, 0xd2, 0xe3, 0x91, 0x3e, 0x26, 0xe9, 0xe3, 0x4a, 0x7c, 0x6c, 0x6a, 0x52,
		0x7b, 0xd3, 0x71, 0x2e, 0xbe, 0x40, 0x5c, 0x9f, 0x05, 0x13, 0x26, 0x19, 0xf1, 0xd7, 0xb7, 0x61,
		0x19, 0xad, 0x5e, 0xb9, 0xea, 0x95, 0x17, 0x9b, 0x1d, 0xf6, 0xde, 0x2b, 0x5f, 0x7b, 0xed, 0xd0,
		0x65, 0x0e, 0x5f, 0x8e, 0x08, 0x64, 0x89, 0x41, 0x99, 0x28, 0x94, 0x89, 0x43, 0x9a, 0x48, 0x12,
		0x9a, 0x06, 0xaf, 0xec, 0xf4, 0x39, 0x09, 0x5c, 0x22, 0xc2, 0xf8, 0x7e, 0x33, 0xaf, 0x2e, 0xbe,
		0x3b, 0xc1, 0xba, 0x4a, 0x9d, 0x09, 0x0d, 0x46, 0x3e, 0x8d, 0xa7, 0x6a, 0x27, 0xc1, 0xe1, 0xcc,
		0x65, 0x46, 0x35, 0xc1, 0x77, 0xeb, 0xc1, 0xc8, 0x1f, 0x2f, 0x46, 0xd9, 0x32, 0x7a, 0x41, 0x62,
		0x0c, 0xd9, 0x60, 0x48, 0xe3, 0xe2, 0x24, 0x1b, 0x59, 0x64, 0xfd, 0xe4, 0x3c, 0xf3, 0xf4, 0x42,
		0x64, 0x9b, 0x37, 0xca, 0x36, 0xf2, 0xac, 0xb0, 0x50, 0x98, 0x53, 0x6b, 0xa5, 0x18, 0xd3, 0xbe,
		0x0c, 0x4b, 0x1c, 0x24, 0xf8, 0x6e, 0x7b, 0x61, 0xbd, 0xf5, 0x3f, 0x3d, 0xb5, 0x8e, 0x1e, 0x7d,
		0x36, 0xfe, 0x63, 0x62, 0xad, 0xa5, 0xda, 0x83, 0x44, 0xae, 0x80, 0xbc, 0x4b, 0xa0, 0xc5, 0x35,
		0x90, 0x73, 0x11, 0xd2, 0x49, 0x0b, 0x36, 0xb6, 0x94, 0x5d, 0x7a, 0x97, 0x5c, 0x4c, 0x2c, 0xae,
		0x40, 0xf9, 0x80, 0x6a, 0x55, 0x4d, 0x96, 0x54, 0xca, 0x12, 0xd2, 0xa3, 0x92, 0xe0, 0xab, 0x97,
		0x24, 0x18, 0x8c, 0x6f, 0xfe, 0xe3, 0x9d, 0xde, 0x10, 0xca, 0x98, 0xf1, 0x13, 0xd3, 0x85, 0x24,
		0xe5, 0xaf, 0x5d, 0xf6, 0x8d, 0x78, 0x23, 0xfa, 0xfa, 0x96, 0xaf, 0x5d, 0x77, 0x16, 0x13, 0x67,
		0x6c, 0xa4, 0x9c, 0xb2, 0x01, 0x9b, 0xca, 0x27, 0x13, 0x71, 0xa7, 0xb1, 0x44, 0xcb, 0x7c, 0x2b,
		0xca, 0xa5, 0xea, 0x41, 0xf5, 0xb0, 0x52, 0xab, 0x1e, 0x64, 0xb8, 0x27, 0xef, 0xf4, 0x7c, 0xeb,
		0xca, 0x80, 0xb4, 0xf6, 0x08, 0x17, 0x45, 0x67, 0x38, 0xa3, 0xf6, 0x84, 0x02, 0x7b, 0xf5, 0x22,
		0x94, 0xd9, 0x68, 0xd3, 0xcd, 0x13, 0x47, 0x63, 0x43, 0x8e, 0x04, 0x6e, 0x51, 0x30, 0x9f, 0xca,
		0x58, 0x73, 0x87, 0xc9, 0xac, 0x39, 0x41, 0xe3, 0x20, 0xb1, 0x48, 0x2e, 0xfc, 0xfc, 0xe9, 0xfe,
		0x53, 0x7d, 0x28, 0x8e, 0x7f, 0x94, 0xe7, 0x3f, 0xba, 0xd3, 0x1f, 0x9f, 0x1e, 0xfd, 0x78, 0xff,
		0xf3, 0xe7, 0xc7, 0x9f, 0x3f, 0xdd, 0xff, 0xf9, 0xf0, 0xaf, 0xf7, 0xff, 0xe7, 0xf7, 0x8f, 0x9f,
		0x3f, 0xff, 0xe7, 0xe7, 0xcf, 0xe2, 0xd5, 0xa3, 0x6f, 0x7c, 0x28, 0xe4, 0xc3, 0x9b, 0xe1, 0xad,
		0x92, 0xdb, 0xf5, 0xe4, 0x3a, 0xe4, 0x50, 0xe4, 0x50, 0xf4, 0xba, 0xde, 0xb8, 0xd7, 0x35, 0xcb,
		0x36, 0x24, 0x94, 0x10, 0x2f, 0xa4, 0xb4, 0x50, 0x2e, 0x6c, 0xa1, 0x5c, 0xe0, 0x22, 0x66, 0xc1,
		0x40, 0x4a, 0x65, 0x1b, 0xa0, 0xe1, 0x30, 0xa2, 0xb1, 0x74, 0x5c, 0x7e, 0xf5, 0x22, 0xa4, 0x68,
		0x8c, 0x1f, 0x6c, 0x4f, 0x58, 0x3e, 0x1a, 0xde, 0xf3, 0x22, 0x99, 0x15, 0xf9, 0x27, 0xe6, 0x97,
		0x47, 0x57, 0x21, 0xc3, 0xa0, 0x0a, 0x90, 0xa7, 0x0b, 0xf3, 0xbe, 0xdb, 0xfb, 0x1f, 0x7b, 0xc5,
		0x23, 0x52, 0xec, 0x1f, 0x17, 0xcf, 0xae, 0xc6, 0x1e, 0xda, 0xa7, 0xc7, 0x7f, 0x7f, 0xf8, 0xef,
		0x0f, 0xff, 0xca, 0xc7, 0x25, 0xe3, 0x11, 0xa5, 0x6e, 0x72, 0x66, 0x9b, 0x7e, 0x1d, 0xb9, 0x0c,
		0xb9, 0x6c, 0x0e, 0x28, 0x27, 0xa3, 0x01, 0xad, 0x55, 0x25, 0x18, 0xec, 0x70, 0xdb, 0x82, 0xd5,
		0x7b, 0x18, 0xac, 0x5e, 0xc4, 0xed, 0x95, 0xdc, 0xcd, 0x6d, 0x08, 0x5b, 0x8f, 0x0d, 0x7e, 0xc6,
		0x05, 0x73, 0x24, 0x2c, 0x9f, 0x95, 0x6b, 0x92, 0x49, 0xe4, 0x12, 0x4a, 0x64, 0xdb, 0x24, 0xf2,
		0x6b, 0xe0, 0xaf, 0xc5, 0x17, 0x5d, 0xc6, 0x9d, 0x30, 0x10, 0x2c, 0x18, 0x31, 0x71, 0x3f, 0x0d,
		0x58, 0x27, 0xde, 0xc4, 0x65, 0xa1, 0xc4, 0xda, 0x3d, 0x12, 0x6e, 0x8a, 0x9c, 0x5c, 0x48, 0x4c,
		0x68, 0x2a, 0x04, 0xa7, 0x46, 0x78, 0xaa, 0x04, 0x98, 0x9a, 0x10, 0x53, 0x13, 0xa4, 0x32, 0x61,
		0x4a, 0x8a, 0xc5, 0x84, 0x27, 0x25, 0xe1, 0xd9, 0xca, 0x9b, 0x1d, 0xeb, 0x14, 0x2b, 0x99, 0xa1,
		0x51, 0xb1, 0xf6, 0x95, 0xad, 0xfe, 0xc5, 0x85, 0xd9, 0x66, 0x6e, 0x92, 0xa9, 0xa9, 0xe4, 0xa7,
		0x9f, 0xe0, 0xe4, 0x0b, 0x2c, 0x28, 0xf6, 0xe2, 0x90, 0xb8, 0x0e, 0xe1, 0xa2, 0x18, 0xfd, 0x12,
		0x5c, 0x5e, 0xf8, 0xac, 0xdf, 0x02, 0x65, 0x0f, 0xca, 0x1e, 0x29, 0xd9, 0xa3, 0x2e, 0x47, 0x9c,
		0x70, 0x14, 0x08, 0x1a, 0x27, 0x72, 0x64, 0x14, 0x1c, 0x1a, 0x45, 0xc7, 0x46, 0xde, 0xc1, 0x49,
		0xe5, 0xe8, 0xa4, 0xb4, 0xf2, 0xd3, 0x3a, 0x3e, 0x3a, 0x4c, 0x7c, 0x05, 0x47, 0x28, 0x95, 0x43,
		0xa4, 0x7b, 0xcb, 0xd2, 0x3b, 0x48, 0x5a, 0x77, 0xf1, 0x9d, 0x99, 0x6f, 0x67, 0xac, 0x99, 0xc6,
		0x66, 0x2d, 0x89, 0x5d, 0x35, 0x9d, 0xb4, 0xb8, 0x18, 0xb5, 0x11, 0x6a, 0xa3, 0x6c, 0xb5, 0x51,
		0x22, 0x0c, 0xe8, 0x53, 0xc2, 0x3b, 0x40, 0x6d, 0x84, 0xda, 0x48, 0xd3, 0x96, 0x55, 0xcb, 0x47,
		0xd5, 0xa3, 0xda, 0x41, 0xf9, 0x08, 0x75, 0x50, 0x5a, 0x1d, 0x44, 0xe3, 0x38, 0x8c, 0xd5, 0x34,
		0xd0, 0xec, 0x52, 0xd4, 0x3f, 0xa8, 0x7f, 0x50, 0xff, 0xa0, 0xfe, 0x41, 0xfd, 0x83, 0xfa, 0x47,
		0x5e, 0xff, 0xf8, 0x23, 0x4f, 0xb0, 0x74, 0xd1, 0xb9, 0x27, 0xb7, 0x40, 0x7d, 0x84, 0xfa, 0x08,
		0xa3, 0x73, 0xa8, 0x8f, 0x30, 0x3a, 0x87, 0x9a, 0x29, 0x8d, 0x66, 0x0a, 0x1d, 0x41, 0x15, 0x35,
		0xd2, 0xec, 0x52, 0xd4, 0x44, 0xa8, 0x89, 0x50, 0x13, 0xa1, 0x26, 0x42, 0x4d, 0x84, 0x9a, 0x28,
		0x8d, 0x26, 0x1a, 0x05, 0x29, 0x3d, 0xa4, 0x47, 0x37, 0x40, 0xad, 0x84, 0x5a, 0x09, 0xb5, 0x12,
		0x6a, 0x25, 0xd4, 0x4a, 0xa8, 0x95, 0xd2, 0x69, 0xa5, 0x5f, 0x41, 0x78, 0x1b, 0x14, 0xa3, 0x38,
		0x14, 0xa1, 0xaa, 0x5e, 0x7a, 0x74, 0x0b, 0xd4, 0x4c, 0xa8, 0x99, 0xb2, 0xd5, 0x4c, 0x98, 0x49,
		0x42, 0xcd, 0x84, 0x99, 0xa4, 0x37, 0xa0, 0x8f, 0xc2, 0x91, 0x48, 0x0d, 0xf4, 0x7e, 0xe6, 0x1e,
		0xa8, 0x91, 0x50, 0x23, 0xa1, 0xaf, 0x84, 0x1a, 0x09, 0x7d, 0x25, 0xd4, 0x4d, 0xa9, 0x74, 0x93,
		0x3a, 0xd4, 0xfb, 0xd1, 0xd5, 0xa8, 0x8f, 0x50, 0x1f, 0xa1, 0x87, 0x84, 0xfa, 0x08, 0x3d, 0x24,
		0xd4, 0x42, 0x0a, 0x5a, 0x48, 0x15, 0xec, 0xbd, 0x72, 0x2d, 0x6a, 0x20, 0xd4, 0x40, 0xa8, 0x81,
		0x50, 0x03, 0xa1, 0x06, 0x42, 0x0d, 0xa4, 0xa0, 0x81, 0xd2, 0xc2, 0xbd, 0x9f, 0xb9, 0x07, 0x6a,
		0x24, 0xd4, 0x48, 0x18, 0xa3, 0x43, 0x8d, 0x84, 0x31, 0x3a, 0xd4, 0x4d, 0xa9, 0x74, 0x93, 0x2a,
		0xe0, 0x7b, 0xe5, 0x5a, 0xd4, 0x45, 0xa8, 0x8b, 0x50, 0x17, 0xa1, 0x2e, 0x42, 0x5d, 0x84, 0xba,
		0x28, 0x95, 0x2e, 0x4a, 0x07, 0xf9, 0x5e, 0xbb, 0x03, 0xea, 0x25, 0xd4, 0x4b, 0xa8, 0x97, 0x50,
		0x2f, 0xa1, 0x5e, 0x42, 0xbd, 0xa4, 0xf0, 0x8d, 0xd7, 0x9a, 0x41, 0x1f, 0x07, 0x41, 0x28, 0xa6,
		0x63, 0x5d, 0x12, 0xf5, 0x84, 0xe6, 0xce, 0x90, 0xfa, 0x24, 0x5a, 0x0c, 0x30, 0xa3, 0xa2, 0x5f,
		0x5c, 0x8e, 0x30, 0xdb, 0x5d, 0x9f, 0x66, 0xb6, 0x18, 0x65, 0x96, 0xb8, 0xb5, 0xf8, 0xf4, 0x39,
		0x22, 0x1e, 0x39, 0x62, 0x36, 0xb1, 0xab, 0xd0, 0xa8, 0x77, 0xcf, 0x1a, 0x8b, 0x5b, 0x5f, 0x2f,
		0x7f, 0xed, 0x8c, 0x1f, 0xb2, 0xfc, 0xfb, 0xba, 0xb3, 0x7c, 0x88, 0x81, 0x8e, 0xea, 0x22, 0x89,
		0x68, 0x5d, 0x88, 0xd3, 0xc9, 0xb7, 0x71, 0xae, 0x05, 0x8e, 0x5b, 0x52, 0x19, 0x42, 0xe8, 0xd2,
		0x40, 0x30, 0x71, 0x2f, 0x39, 0x7c, 0x30, 0xc9, 0xa0, 0xbd, 0xc6, 0xec, 0xd6, 0x9f, 0x09, 0xa7,
		0x2a, 0xa5, 0x1f, 0xf3, 0xe9, 0x88, 0x09, 0xc8, 0xfb, 0xb1, 0x64, 0xe7, 0x52, 0x2a, 0x5f, 0xd2,
		0xfa, 0x5b, 0xac, 0x8f, 0x04, 0xa4, 0xa8, 0xb4, 0xc8, 0x34, 0x8b, 0x55, 0xb7, 0x51, 0x1e, 0x2d,
		0x9e, 0xb8, 0xdc, 0x2b, 0x64, 0xa1, 0xe6, 0x53, 0xae, 0x93, 0xf9, 0xc2, 0x8a, 0x65, 0xf6, 0xbf,
		0xf5, 0xd9, 0x84, 0xf7, 0x2c, 0x58, 0x2c, 0x8d, 0xbc, 0x98, 0xdb, 0xb0, 0x50, 0x72, 0xc3, 0x1c,
		0xd6, 0x8a, 0x04, 0x73, 0x88, 0x57, 0x17, 0x43, 0x1a, 0xdb, 0xb0, 0xe8, 0x1b, 0xff, 0x96, 0xc4,
		0xf4, 0x82, 0x39, 0x5d, 0x4a, 0x7c, 0x1b, 0x16, 0x3c, 0x10, 0x91, 0x0d, 0xcb, 0xfc, 0xdb, 0x8e,
		0xdd, 0x74, 0x7a, 0xde, 0x37, 0xea, 0x08, 0xd2, 0x11, 0xc4, 0x0a, 0x72, 0x65, 0x51, 0xeb, 0x86,
		0xc6, 0x27, 0x1e, 0xb9, 0xb5, 0x61, 0xb5, 0xfe, 0x8d, 0x15, 0x5a, 0x2b, 0x62, 0x56, 0xb0, 0x14,
		0xf1, 0x46, 0xf5, 0x28, 0x0c, 0x9a, 0xe1, 0x60, 0x2c, 0x61, 0x9b, 0x2c, 0xf8, 0x65, 0xc3, 0xaa,
		0xb9, 0x1d, 0x9b, 0xeb, 0x85, 0x0e, 0xf1, 0xba, 0xc4, 0xb3, 0x62, 0x4f, 0x07, 0x47, 0x47, 0x87,
		0x65, 0x1b, 0x16, 0xea, 0x86, 0x0e, 0x3f, 0x21, 0x3d, 0x8f, 0x76, 0x1c, 0x41, 0xf7, 0xf7, 0xdd,
		0xf2, 0x57, 0xde, 0x0a, 0x7b, 0x56, 0x30, 0x1b, 0xbf, 0x0f, 0x1c, 0x1b, 0x16, 0xda, 0x8f, 0x89,
		0x4f, 0x2f, 0xa9, 0x47, 0xee, 0xad, 0xd0, 0x5f, 0xdc, 0x0d, 0x46, 0x36, 0x2c, 0x74, 0x18, 0x72,
		0xd1, 0x26, 0xae, 0x15, 0xa4, 0xda, 0xf7, 0x48, 0x40, 0x0f, 0xf7, 0xca, 0x15, 0x1b, 0x56, 0x1b,
		0x4e, 0x1d, 0x84, 0x6e, 0x4c, 0x02, 0x1e, 0x85, 0xb1, 0x15, 0xfe, 0x62, 0x28, 0x82, 0x96, 0x6b,
		0x05, 0xd9, 0xf6, 0x08, 0x67, 0x4e, 0xa3, 0x73, 0x7a, 0x61, 0x87, 0x30, 0x08, 0x0f, 0xc7, 0x64,
		0x7b, 0xc2, 0x7d, 0xe2, 0xb8, 0x76, 0x08, 0xdb, 0xb3, 0x30, 0xbe, 0x25, 0xb1, 0x15, 0x8b, 0x65,
		0x94, 0x4e, 0xa4, 0x02, 0x71, 0x9b, 0x64, 0x60, 0x85, 0x20, 0x73, 0xb9, 0x67, 0x87, 0x59, 0x73,
		0xd3, 0x3b, 0xe6, 0xac, 0x35, 0xb2, 0x42, 0x78, 0x0d, 0x2b, 0xe5, 0x4a, 0x3b, 0x0e, 0xef, 0xee,
		0x6d, 0xf1, 0x71, 0x9a, 0x6d, 0x5b, 0x6c, 0x70, 0x2b, 0x14, 0x2e, 0x77, 0x3d, 0x2b, 0x0c, 0xd9,
		0x21, 0x8b, 0x22, 0x66, 0x05, 0x8d, 0x12, 0x6f, 0xdf, 0x86, 0x75, 0xde, 0x95, 0xf7, 0x23, 0x8f,
		0x5a, 0x64, 0x08, 0xec, 0x9f, 0x5c, 0x9e, 0xb5, 0x1b, 0x81, 0x15, 0x52, 0x95, 0x0b, 0xe2, 0xfc,
		0xea, 0x86, 0x9d, 0xf1, 0x0f, 0x2b, 0xe2, 0xdc, 0x2c, 0x16, 0x23, 0xe2, 0x75, 0xad, 0x30, 0x04,
		0x86, 0xf7, 0x11, 0x8d, 0x9d, 0x21, 0x09, 0x02, 0x6a, 0x45, 0x00, 0x91, 0x86, 0x81, 0x15, 0x71,
		0xce, 0x38, 0x8c, 0xbe, 0x4d, 0xe9, 0xc0, 0xa2, 0x78, 0x67, 0x7b, 0x78, 0xcf, 0xc7, 0x1e, 0xe3,
		0xd7, 0x80, 0x59, 0x15, 0xf2, 0xba, 0x70, 0xad, 0xc8, 0x28, 0xb8, 0xdc, 0x0a, 0x2b, 0xc6, 0x09,
		0xfd, 0x28, 0xe4, 0x4c, 0x50, 0x5b, 0xe2, 0xde, 0x31, 0x1d, 0x8c, 0x3c, 0x12, 0x97, 0x0e, 0xcb,
		0x56, 0xb8, 0x34, 0x3d, 0x26, 0xac, 0x48, 0x32, 0xdf, 0xde, 0x92, 0xa0, 0x6d, 0x8d, 0x83, 0x50,
		0xb2, 0xc2, 0x34, 0xa8, 0xd4, 0xec, 0x10, 0x54, 0x25, 0x9b, 0x6c, 0xd9, 0x53, 0x61, 0x85, 0xf8,
		0x77, 0x48, 0x74, 0x4b, 0xa2, 0xd3, 0x50, 0x94, 0x4a, 0xed, 0x38, 0xec, 0x33, 0x3b, 0x1c, 0x86,
		0x01, 0x1b, 0x90, 0x1e, 0x13, 0x13, 0x94, 0x49, 0x40, 0xad, 0x70, 0x18, 0xfa, 0x84, 0x5b, 0xb1,
		0xce, 0xc8, 0x8e, 0x68, 0xc1, 0xd8, 0x96, 0xfd, 0xfc, 0xfd, 0x38, 0x2a, 0x9f, 0x5b, 0x91, 0x5e,
		0xbe, 0x3b, 0xac, 0x35, 0x49, 0xc4, 0x2d, 0xd9, 0x59, 0x41, 0xc3, 0xe0, 0x70, 0xef, 0xbc, 0xc7,
		0x84, 0x1d, 0x71, 0x8e, 0x92, 0x15, 0x26, 0x6c, 0x6c, 0x0b, 0x8a, 0xf3, 0xae, 0xbc, 0xef, 0x7b,
		0x76, 0xa0, 0x36, 0xca, 0x37, 0x1e, 0x09, 0xec, 0xd1, 0xb3, 0xdf, 0xc5, 0xdc, 0x01, 0xbf, 0x24,
		0x2e, 0x0b, 0xad, 0xf0, 0xc2, 0x85, 0x1d, 0xb0, 0xc8, 0x7e, 0x64, 0xc9, 0x6e, 0x76, 0x46, 0xbd,
		0x45, 0x59, 0x8a, 0x1d, 0x8e, 0x2c, 0x71, 0x86, 0xa7, 0x9d, 0xa6, 0x15, 0x5e, 0x6c, 0xcc, 0xdc,
		0x01, 0xb5, 0xc5, 0x1c, 0xb4, 0x44, 0x1d, 0xdc, 0x84, 0xcc, 0xa1, 0x67, 0x7f, 0x75, 0x2c, 0xc9,
		0xcc, 0x5e, 0x3a, 0xce, 0x69, 0x78, 0x1b, 0x70, 0x11, 0x5b, 0x82, 0xe8, 0xf6, 0x89, 0xd3, 0xa1,
		0xce, 0xd7, 0xc0, 0x09, 0x03, 0x11, 0x87, 0x9e, 0x47, 0xdd, 0xc6, 0x99, 0x45, 0xf1, 0xd9, 0x96,
		0x1d, 0x80, 0xae, 0x98, 0x97, 0x2b, 0x65, 0x5b, 0xc0, 0x46, 0x62, 0x64, 0x59, 0xa8, 0xbb, 0x6f,
		0x17, 0x54, 0x72, 0xa2, 0x80, 0x9d, 0x30, 0x08, 0xa8, 0x63, 0x85, 0x8b, 0x23, 0x26, 0x68, 0xb9,
		0x7f, 0x5b, 0x92, 0xc9, 0xef, 0x3b, 0x2c, 0xb2, 0x25, 0x4c, 0x3f, 0x51, 0x6e, 0xf5, 0xcf, 0x1d,
		0x7b, 0x6a, 0x95, 0x66, 0x0e, 0xc4, 0x05, 0x73, 0x6c, 0x41, 0x1f, 0x7d, 0x21, 0x82, 0xfe, 0xa2,
		0x34, 0xb2, 0xa3, 0x22, 0x2c, 0x72, 0x83, 0x49, 0x5c, 0xb1, 0x19, 0x86, 0x91, 0x15, 0x11, 0x67,
		0x3f, 0x74, 0xa9, 0x6f, 0x4b, 0xcc, 0xee, 0x34, 0x74, 0xf8, 0x77, 0x16, 0x53, 0x8f, 0x72, 0xfe,
		0x35, 0xb2, 0xc7, 0x48, 0xe3, 0x2c, 0xea, 0x30, 0x2b, 0xc0, 0x13, 0x7e, 0x44, 0x07, 0x56, 0xa1,
		0xab, 0x67, 0x38, 0xd5, 0x92, 0x1d, 0xd0, 0x4f, 0xc7, 0x8a, 0x70, 0x93, 0xcf, 0x2d, 0x71, 0x2e,
		0x83, 0x3e, 0xe1, 0x16, 0xa5, 0xf5, 0xca, 0x9e, 0x1d, 0x26, 0xd8, 0xdf, 0xe5, 0xa3, 0x4a, 0xc9,
		0x96, 0x82, 0x20, 0x6e, 0x8f, 0xa1, 0x18, 0x38, 0xc4, 0x96, 0x5a, 0xd1, 0x2f, 0xf6, 0xf8, 0xe6,
		0x33, 0xe6, 0xaa, 0x9d, 0x93, 0xc0, 0xa2, 0x0c, 0x59, 0xc9, 0x9a, 0x0c, 0xd9, 0x04, 0x5a, 0x6d,
		0x55, 0xd0, 0x79, 0x16, 0x5b, 0xb2, 0x88, 0xd5, 0x2c, 0x83, 0x29, 0xb2, 0xc8, 0xa2, 0x4a, 0x26,
		0x22, 0x7c, 0x6b, 0xf2, 0x65, 0x33, 0x59, 0x56, 0xed, 0x86, 0xbf, 0x68, 0xf0, 0x79, 0x64, 0x87,
		0x71, 0x13, 0x75, 0x6e, 0x99, 0x70, 0x86, 0xb6, 0x78, 0x0b, 0xa5, 0xca, 0x51, 0xd5, 0x1a, 0x9b,
		0xa1, 0x75, 0x43, 0xe3, 0x33, 0xab, 0x8a, 0xb4, 0x7b, 0x83, 0x28, 0x0a, 0x3d, 0xe6, 0xdc, 0x13,
		0x67, 0xd2, 0xf9, 0x93, 0x05, 0x03, 0x4b, 0xb4, 0x1c, 0x8d, 0x3d, 0x12, 0x58, 0xe1, 0x47, 0x46,
		0xa1, 0x15, 0x92, 0xc1, 0xa1, 0xdc, 0x92, 0x6a, 0x9c, 0xb8, 0x69, 0x87, 0xf1, 0xd8, 0x77, 0x5d,
		0x2b, 0x0c, 0x84, 0x1e, 0xb7, 0xc2, 0xd1, 0xa5, 0x4e, 0x68, 0x09, 0x00, 0xd4, 0xe5, 0x7b, 0x16,
		0x65, 0xfb, 0x5b, 0x96, 0xd8, 0x85, 0x67, 0x23, 0x3b, 0xec, 0x6d, 0x9f, 0x85, 0x77, 0x65, 0x2b,
		0xca, 0x46, 0x3d, 0x16, 0xd0, 0x41, 0x1c, 0x8e, 0xac, 0x88, 0x73, 0x44, 0x76, 0xa0, 0xd3, 0xfc,
		0xfb, 0x98, 0x59, 0x22, 0xa6, 0xe8, 0x0c, 0x53, 0x5f, 0xb1, 0x25, 0xb8, 0x41, 0x62, 0x27, 0xa0,
		0xa2, 0xed, 0xd9, 0xe1, 0x6a, 0xf9, 0x91, 0x63, 0x53, 0x4e, 0xa6, 0xf6, 0xfd, 0xfc, 0xf8, 0xc2,
		0x0e, 0xfc, 0xa7, 0x25, 0xf5, 0x15, 0xd3, 0x38, 0xf2, 0xb9, 0x55, 0xf8, 0x9e, 0x79, 0xa2, 0xf6,
		0xc4, 0x9e, 0x92, 0xec, 0x9b, 0x8a, 0x15, 0xca, 0x36, 0x8a, 0xa2, 0xf3, 0x91, 0x27, 0x98, 0xc7,
		0x82, 0x5f, 0x9f, 0x47, 0x81, 0x6b, 0x49, 0xbf, 0x86, 0x99, 0x74, 0xd8, 0xaf, 0xda, 0x02, 0x3b,
		0x38, 0xb6, 0xc3, 0x4e, 0x88, 0xc2, 0xa0, 0x66, 0x47, 0xbd, 0xf0, 0xb4, 0x11, 0xad, 0x25, 0xdb,
		0x3a, 0xe2, 0x56, 0xf4, 0x9c, 0xbc, 0xeb, 0x85, 0x77, 0x73, 0x6c, 0x8c, 0x55, 0xe1, 0xcd, 0x86,
		0x15, 0xbe, 0x02, 0x1f, 0x5a, 0x82, 0x89, 0x98, 0xb6, 0x17, 0x6b, 0x58, 0x11, 0xce, 0x8a, 0xfb,
		0xce, 0xe1, 0xc1, 0x81, 0x25, 0xae, 0x2d, 0x21, 0x76, 0xf4, 0x97, 0x23, 0xc2, 0xff, 0xe6, 0xb0,
		0x7a, 0xe0, 0xb6, 0xad, 0x30, 0x69, 0xe3, 0x28, 0xb6, 0xca, 0x9c, 0x3d, 0x3f, 0xf1, 0x05, 0xb7,
		0xab, 0x46, 0xc4, 0x19, 0xaf, 0x7b, 0xb9, 0xe4, 0xcb, 0x7e, 0xdb, 0x12, 0x70, 0x1f, 0x0f, 0xfb,
		0xe2, 0x96, 0xc4, 0xb4, 0x19, 0x86, 0x51, 0xcf, 0x92, 0x5e, 0x59, 0x23, 0x4f, 0xc4, 0xc4, 0x9e,
		0xca, 0xa1, 0x13, 0xcb, 0xea, 0x86, 0xfa, 0xac, 0x17, 0x53, 0x8b, 0x5c, 0x49, 0x41, 0x63, 0xdf,
		0x92, 0x56, 0xd0, 0xc3, 0xd0, 0xa7, 0x51, 0x40, 0x6c, 0x01, 0xfe, 0x59, 0x62, 0xe0, 0x94, 0xaa,
		0x76, 0x74, 0xfa, 0xfc, 0xdb, 0x12, 0x70, 0x2a, 0x71, 0x04, 0xf5, 0x18, 0x3f, 0xa7, 0x82, 0x34,
		0x5b, 0xad, 0xb6, 0x95, 0xa1, 0x30, 0x8b, 0x34, 0xb0, 0x67, 0xc7, 0x04, 0x0e, 0x8b, 0xfa, 0x3d,
		0x46, 0x71, 0x18, 0x9d, 0x04, 0x9e, 0x15, 0x4e, 0xba, 0x57, 0x61, 0x91, 0x2d, 0x4d, 0x32, 0x38,
		0xbb, 0xeb, 0x86, 0x67, 0xe1, 0xc8, 0x32, 0x77, 0x82, 0x38, 0x1e, 0xb9, 0xb7, 0xa3, 0xb8, 0x6d,
		0x31, 0x2b, 0xc2, 0x0a, 0x7f, 0x7d, 0x10, 0x57, 0xf6, 0x2a, 0x97, 0xa7, 0x5d, 0x3b, 0x1c, 0x9d,
		0x80, 0x8a, 0xd6, 0x0d, 0x8d, 0x87, 0x94, 0xb8, 0x16, 0x59, 0xb7, 0x94, 0x3b, 0x76, 0xe0, 0xac,
		0x27, 0xad, 0x1d, 0xf8, 0x39, 0x71, 0x9a, 0xb6, 0x30, 0x1b, 0xeb, 0xf9, 0x95, 0x83, 0xbd, 0x88,
		0xc4, 0x63, 0x72, 0xb0, 0xc2, 0x7d, 0x70, 0x87, 0xb6, 0xf4, 0x2b, 0x9d, 0xa5, 0x51, 0xcf, 0xbe,
		0x9c, 0x5a, 0x21, 0xc8, 0x0e, 0xf6, 0x2a, 0x44, 0x94, 0xfd, 0x9e, 0x45, 0x13, 0x7a, 0x66, 0x32,
		0xec, 0x8b, 0x2d, 0x50, 0xa0, 0x3e, 0xe1, 0xc2, 0x9a, 0xb1, 0xa3, 0x53, 0x61, 0xd6, 0x75, 0x7d,
		0x62, 0x49, 0xf1, 0xb3, 0x1d, 0x8d, 0xe3, 0x23, 0x62, 0x47, 0xe0, 0xce, 0xf5, 0xb8, 0x15, 0x03,
		0x3c, 0x3d, 0x12, 0xf5, 0x2d, 0x49, 0x98, 0x9c, 0xde, 0x31, 0xfb, 0x84, 0xab, 0x1d, 0xe1, 0x4f,
		0x6b, 0x7a, 0xb9, 0xd8, 0x92, 0xdf, 0xb5, 0x04, 0xb4, 0xda, 0xef, 0xb0, 0x81, 0x35, 0x63, 0x66,
		0xc7, 0xee, 0xd7, 0xb7, 0xae, 0x2d, 0xd1, 0xa3, 0x76, 0xc8, 0x02, 0xd1, 0x0d, 0x27, 0x3f, 0x3a,
		0x34, 0x66, 0x76, 0x4c, 0xe4, 0xf0, 0x2a, 0x2c, 0xba, 0xb3, 0x25, 0x98, 0xe4, 0x53, 0x97, 0x91,
		0x73, 0xc2, 0x3c, 0x8b, 0x10, 0x2a, 0xae, 0x63, 0x85, 0x12, 0xe3, 0x71, 0x64, 0x55, 0x84, 0xce,
		0xae, 0x5c, 0xff, 0x78, 0xd9, 0xad, 0xbe, 0xeb, 0x13, 0x9b, 0xfa, 0x23, 0x45, 0x51, 0x64, 0x47,
		0x73, 0x45, 0x4b, 0x1c, 0x44, 0x22, 0x7c, 0x8b, 0x46, 0x35, 0x8d, 0x55, 0xda, 0x04, 0xc7, 0x1c,
		0x79, 0xf4, 0x2e, 0xb4, 0x23, 0x38, 0xc7, 0x47, 0x91, 0x95, 0x23, 0xd4, 0x4f, 0x6d, 0x19, 0xa1,
		0x3e, 0x85, 0x08, 0x9f, 0xd8, 0x32, 0x7e, 0xd2, 0x92, 0x75, 0xae, 0x0c, 0x6c, 0xf9, 0x6c, 0x07,
		0x4c, 0xd8, 0x71, 0x44, 0xdd, 0x1f, 0xd9, 0x51, 0x35, 0x52, 0xb2, 0x6a, 0xc6, 0xd0, 0x19, 0xeb,
		0xd9, 0xa1, 0xcd, 0x84, 0x25, 0xcc, 0xc5, 0x02, 0x41, 0x63, 0x8f, 0x92, 0x1b, 0x2b, 0xca, 0x70,
		0xc4, 0xc8, 0x96, 0x18, 0xd2, 0x9c, 0x60, 0x27, 0x4d, 0x71, 0x2e, 0x2d, 0xe9, 0x27, 0xb2, 0x6c,
		0x17, 0xdd, 0xa1, 0xf1, 0x0d, 0xb3, 0xa3, 0x71, 0x56, 0x14, 0x06, 0xa5, 0xfd, 0x7d, 0x4b, 0x2c,
		0xdc, 0x5e, 0x18, 0xd8, 0x31, 0x49, 0xdf, 0x92, 0x90, 0x47, 0xcc, 0xe3, 0x9e, 0x5d, 0x9c, 0x75,
		0xde, 0x6e, 0xd8, 0x33, 0x56, 0xc2, 0x26, 0xec, 0xc1, 0x8d, 0xcb, 0xed, 0xa8, 0x75, 0x79, 0xea,
		0xdf, 0x94, 0xce, 0x6e, 0x5d, 0x4b, 0x1c, 0x1c, 0x5b, 0x7a, 0xec, 0x0e, 0x6c, 0xe9, 0xa4, 0x38,
		0xe9, 0xe4, 0x60, 0xc5, 0xc9, 0xfb, 0x2e, 0xb7, 0x24, 0xe1, 0x18, 0xc5, 0x61, 0x34, 0x2f, 0x2a,
		0x6d, 0x97, 0xad, 0x00, 0x5b, 0xb3, 0x7e, 0xfb, 0xb6, 0x7b, 0x1f, 0x51, 0x2b, 0xc5, 0xd7, 0x25,
		0x15, 0x96, 0x88, 0x2f, 0x27, 0xec, 0xf7, 0x29, 0xb5, 0x06, 0xec, 0x75, 0xda, 0xb0, 0x02, 0xea,
		0xe5, 0x30, 0xee, 0x84, 0x8d, 0x4e, 0xd3, 0x96, 0x34, 0x19, 0x11, 0x7e, 0xc3, 0x0e, 0x14, 0xd2,
		0xcd, 0x34, 0x1e, 0xde, 0x88, 0x8e, 0x5d, 0x37, 0xb6, 0xa4, 0x44, 0xde, 0x8f, 0x3c, 0xde, 0xb5,
		0xc6, 0x4d, 0x9f, 0x9a, 0xb9, 0x36, 0xa5, 0x9d, 0x3c, 0x12, 0xb9, 0x76, 0x78, 0x3c, 0xa7, 0x9e,
		0x45, 0x15, 0xdd, 0x43, 0xce, 0x99, 0x35, 0xa8, 0x8f, 0x36, 0x11, 0x43, 0x5b, 0x64, 0x81, 0x1d,
		0xc3, 0xc6, 0xf6, 0xf6, 0x0e, 0x6d, 0x6a, 0x55, 0x77, 0xc2, 0x7d, 0xe2, 0xb8, 0xd6, 0xd0, 0xab,
		0x6d, 0x43, 0xb0, 0xec, 0xa9, 0x07, 0x38, 0xfb, 0x72, 0xda, 0xea, 0xd8, 0x04, 0xf1, 0xb0, 0x0b,
		0x98, 0x42, 0x84, 0xdf, 0x0c, 0x07, 0xcc, 0x21, 0x9e, 0x55, 0xdd, 0x89, 0x26, 0xee, 0x99, 0x1d,
		0xae, 0x3a, 0xf3, 0x49, 0x7c, 0xdf, 0xe8, 0x9c, 0x5a, 0xd1, 0x72, 0x91, 0x94, 0xca, 0xe7, 0x91,
		0x45, 0x93, 0x03, 0xb8, 0xef, 0xf2, 0x86, 0x63, 0x47, 0x31, 0xf4, 0xa4, 0xf2, 0xb1, 0x71, 0xda,
		0xb5, 0x71, 0xac, 0x9f, 0x4d, 0xf5, 0xb0, 0xae, 0x1b, 0xfc, 0x65, 0x47, 0x2d, 0xec, 0xbc, 0xe7,
		0x62, 0xc9, 0x92, 0x5e, 0xe7, 0xf6, 0x74, 0xb3, 0x1c, 0xda, 0x92, 0x2a, 0x21, 0xe3, 0x85, 0x46,
		0x96, 0x34, 0x3a, 0xbe, 0xbd, 0x25, 0x41, 0xbb, 0x6d, 0xc5, 0xbe, 0x52, 0x3b, 0x40, 0x3f, 0x91,
		0x1d, 0xb1, 0xfb, 0xe2, 0x80, 0x07, 0x36, 0x79, 0x0c, 0xf5, 0xe3, 0x8b, 0x63, 0x2b, 0x42, 0x5d,
		0xbe, 0x1d, 0x6d, 0x5c, 0x02, 0x3b, 0x14, 0x3f, 0x2f, 0x9d, 0x9d, 0x36, 0x2d, 0x09, 0xca, 0x76,
		0x5d, 0x2b, 0xfc, 0xc3, 0x98, 0xb8, 0x2c, 0x3c, 0x3f, 0x3e, 0xb1, 0x62, 0xee, 0x2c, 0x67, 0x91,
		0x95, 0x8d, 0xa7, 0xec, 0x88, 0x76, 0xf7, 0x4b, 0xb5, 0xf3, 0x7e, 0x6c, 0x8f, 0x0d, 0xe8, 0x87,
		0x0e, 0xf9, 0x46, 0x63, 0xce, 0xc2, 0xa0, 0x64, 0x4f, 0x43, 0x89, 0x5a, 0xd5, 0x8e, 0xba, 0xdc,
		0xca, 0x81, 0x55, 0x01, 0x23, 0x4b, 0xba, 0x9a, 0x33, 0x5b, 0xca, 0x9d, 0xd9, 0x80, 0x09, 0xe2,
		0x7d, 0x8f, 0x49, 0x14, 0xd1, 0xd8, 0xc2, 0x16, 0x49, 0xb3, 0x17, 0x68, 0x87, 0xb7, 0x34, 0xf6,
		0x58, 0x60, 0x85, 0x40, 0xe3, 0xfc, 0xc0, 0xa2, 0xea, 0xed, 0xa7, 0x21, 0x24, 0xbb, 0xe2, 0xe2,
		0x8b, 0xce, 0x33, 0x67, 0x7f, 0x59, 0x92, 0x33, 0xef, 0xd9, 0x01, 0x07, 0xb4, 0x63, 0xd6, 0xfa,
		0x5d, 0x79, 0x7f, 0x38, 0x0a, 0x84, 0x35, 0x8d, 0x92, 0x58, 0xd0, 0x67, 0x01, 0xeb, 0x11, 0x25,
		0xec, 0xbd, 0xd4, 0x15, 0x57, 0xef, 0x0c, 0xec, 0x82, 0xdc, 0xdb, 0x3f, 0x0a, 0x9e, 0x15, 0x00,
		0xad, 0x87, 0xf9, 0x02, 0xd4, 0x72, 0xfa, 0xdf, 0xfa, 0x4c, 0x0e, 0x74, 0x69, 0x7e, 0x51, 0x34,
		0xf2, 0x62, 0x0e, 0x69, 0x41, 0xe4, 0x86, 0x39, 0xac, 0x35, 0x6d, 0xe1, 0x23, 0xd9, 0x6b, 0xcc,
		0xfc, 0xe2, 0x6e, 0xfc, 0x5b, 0x12, 0xd3, 0x0b, 0xe6, 0x74, 0xa5, 0xf4, 0xa6, 0xf9, 0x85, 0x0d,
		0x44, 0x04, 0x69, 0x39, 0x7f, 0xc3, 0xda, 0x1d, 0xa7, 0xe7, 0x7d, 0xa3, 0x8e, 0x20, 0x1d, 0x41,
		0x40, 0x91, 0xd3, 0xac, 0x7c, 0xdb, 0x23, 0xb7, 0x90, 0x56, 0xe5, 0xdf, 0x80, 0x92, 0xe2, 0x11,
		0x03, 0x45, 0xda, 0xc4, 0x1b, 0xd5, 0xa3, 0x30, 0x98, 0xa1, 0x34, 0xe4, 0xac, 0x7f, 0xf3, 0xab,
		0xe3, 0xb0, 0x36, 0xcb, 0x0b, 0x1d, 0xe2, 0x75, 0x89, 0x07, 0x6a, 0x8f, 0x06, 0x47, 0x47, 0x87,
		0x65, 0x48, 0x0b, 0x5a, 0xeb, 0x3f, 0xf1, 0x55, 0xae, 0xff, 0x44, 0x06, 0x44, 0xcf, 0xef, 0x03,
		0x07, 0xd2, 0x82, 0x96, 0xe5, 0x8d, 0xa0, 0xe4, 0x39, 0x77, 0x83, 0x11, 0xa4, 0x05, 0x0d, 0x43,
		0x2e, 0xa4, 0xe6, 0xaa, 0x64, 0x40, 0x4a, 0xf3, 0xf6, 0xe8, 0x15, 0x48, 0xab, 0x9a, 0xf5, 0x8c,
		0xec, 0xc6, 0x24, 0xe0, 0x91, 0xd4, 0xd4, 0x89, 0x0c, 0xd6, 0x26, 0x82, 0x96, 0x0b, 0x8a, 0xac,
		0x7a, 0x84, 0x33, 0x47, 0x0e, 0x43, 0x97, 0x05, 0xf3, 0x4d, 0x1a, 0x20, 0x54, 0x64, 0xa1, 0xca,
		0x59, 0x08, 0xab, 0xb3, 0x30, 0xbe, 0x25, 0x31, 0xa8, 0x45, 0xcd, 0xc0, 0x4e, 0x15, 0xe2, 0x36,
		0xc9, 0xa0, 0x00, 0x2c, 0x8a, 0x00, 0x4b, 0x3d, 0x4f, 0x66, 0x45, 0xb6, 0x46, 0xa0, 0x84, 0xc2,
		0xb0, 0x52, 0xae, 0xb4, 0xe3, 0xf0, 0xee, 0x1e, 0x9a, 0x6d, 0xdc, 0x6c, 0x43, 0xb3, 0xf5, 0x40,
		0x29, 0x1a, 0x2e, 0xd5, 0xa6, 0x27, 0x03, 0x3a, 0x62, 0x51, 0xc4, 0x40, 0xd1, 0x10, 0xf1, 0xf6,
		0x21, 0xad, 0xe7, 0xae, 0xbc, 0x1f, 0x79, 0x14, 0xa0, 0xa2, 0xdb, 0x3f, 0xb9, 0x3c, 0x6b, 0x37,
		0x02, 0x50, 0x52, 0x89, 0x0b, 0xe2, 0xfc, 0xea, 0x86, 0x1d, 0x21, 0x35, 0x86, 0x32, 0x83, 0xb8,
		0xdd, 0xb4, 0xae, 0xb5, 0x0b, 0x4a, 0xd1, 0x0d, 0xef, 0x23, 0x1a, 0x4b, 0x8f, 0xe4, 0xca, 0x20,
		0x24, 0x2c, 0xd3, 0xca, 0x22, 0x83, 0xf8, 0x4f, 0x1c, 0x46, 0xd2, 0x7d, 0x3a, 0x33, 0x8b, 0x03,
		0xb5, 0x87, 0xf7, 0x7c, 0xec, 0x39, 0x7c, 0x0d, 0x18, 0xc8, 0x90, 0xc2, 0x85, 0x0b, 0x2a, 0xe2,
		0xe9, 0x72, 0x50, 0xda, 0xd8, 0x09, 0xfd, 0x28, 0xe4, 0x4c, 0xb6, 0xff, 0xbe, 0xf9, 0x85, 0xc5,
		0x74, 0x30, 0xf2, 0x48, 0x2c, 0x37, 0x2a, 0x28, 0x03, 0xc7, 0x8f, 0x09, 0x50, 0xc9, 0xa2, 0x29,
		0x02, 0x1e, 0x9a, 0xc1, 0x59, 0x02, 0xa5, 0xfa, 0x2a, 0x35, 0x58, 0x02, 0xa0, 0x04, 0xd1, 0x96,
		0x3a, 0x15, 0xa0, 0xc4, 0xe4, 0x4a, 0x07, 0xda, 0x76, 0x1c, 0xf6, 0x19, 0x2c, 0x03, 0x74, 0xc0,
		0x06, 0xa4, 0xc7, 0xa6, 0x78, 0x1c, 0xa9, 0x62, 0xeb, 0x0c, 0x42, 0x2d, 0x84, 0x83, 0x5a, 0x4f,
		0x04, 0xcb, 0xdb, 0x1b, 0xdb, 0x52, 0x9f, 0xbf, 0x1f, 0x47, 0xe5, 0x73, 0x50, 0x69, 0xa2, 0xbb,
		0xc3, 0x5a, 0x93, 0x44, 0x1c, 0xd8, 0x4e, 0x09, 0x1a, 0x06, 0x87, 0x7b, 0xe7, 0x3d, 0x26, 0x60,
		0xf9, 0xa3, 0x25, 0x50, 0x26, 0x54, 0x0c, 0x0d, 0xf5, 0x73, 0x57, 0xde, 0xf7, 0x3d, 0x58, 0x59,
		0xd0, 0xb2, 0x5c, 0xa7, 0xaa, 0xac, 0xf4, 0xcb, 0x77, 0x31, 0x77, 0xac, 0x2e, 0x89, 0xcb, 0x42,
		0x50, 0xde, 0x95, 0x80, 0x05, 0xaf, 0xe9, 0x47, 0xc0, 0x76, 0xa7, 0x33, 0xea, 0x35, 0x02, 0x41,
		0xe3, 0x3e, 0x71, 0x28, 0x2c, 0xc7, 0x85, 0x38, 0xc3, 0xd3, 0x4e, 0x13, 0x94, 0xd7, 0x12, 0x33,
		0x77, 0x40, 0xa1, 0x99, 0x29, 0xc0, 0xc4, 0xe6, 0xb4, 0x56, 0xf3, 0xaf, 0x0e, 0xb0, 0xcc, 0xcb,
		0xa5, 0xe3, 0xa8, 0x20, 0xd5, 0x33, 0x40, 0x49, 0x11, 0xa7, 0x43, 0x9d, 0xaf, 0x81, 0x13, 0x06,
		0x22, 0x0e, 0x3d, 0x8f, 0xba, 0x8d, 0x33, 0x80, 0xf1, 0xa9, 0x16, 0x2c, 0x40, 0x42, 0xcc, 0xcb,
		0x95, 0x32, 0xb4, 0xe4, 0xba, 0x18, 0x01, 0x0d, 0xdd, 0xf5, 0x61, 0x42, 0x6e, 0x26, 0x8a, 0xc7,
		0x09, 0x83, 0x80, 0x3a, 0xa0, 0x4c, 0x63, 0x31, 0x41, 0x6f, 0xfc, 0x1b, 0x58, 0x86, 0xad, 0xef,
		0xb0, 0x08, 0x5a, 0x78, 0x71, 0x3a, 0xda, 0xfb, 0x73, 0x07, 0x1e, 0xb6, 0x7a, 0x66, 0x90, 0x5e,
		0x30, 0x07, 0x5a, 0xb6, 0xfd, 0x0b, 0x11, 0xf4, 0x17, 0xa5, 0x11, 0x2c, 0x44, 0xfa, 0x6a, 0x17,
		0x39, 0x50, 0x91, 0x35, 0x3f, 0x74, 0xa9, 0x0f, 0x2d, 0xf6, 0xb1, 0x5a, 0x00, 0x27, 0x5f, 0xed,
		0x9d, 0x09, 0x7c, 0xb7, 0xc3, 0x40, 0x25, 0x29, 0xfd, 0x88, 0x0e, 0x40, 0xa2, 0xe2, 0xe6, 0xcd,
		0x9a, 0x60, 0x41, 0x85, 0x1c, 0x50, 0x6e, 0xbe, 0xcf, 0x81, 0x39, 0x19, 0x41, 0x9f, 0x70, 0x80,
		0xe1, 0xff, 0xb2, 0x07, 0xcb, 0x64, 0xf8, 0xbb, 0x7c, 0x54, 0x29, 0x41, 0x03, 0x36, 0x73, 0x78,
		0x06, 0x4c, 0xe0, 0x10, 0x68, 0xb5, 0x21, 0x5f, 0xe0, 0xf9, 0x5c, 0x33, 0x22, 0xaf, 0x9d, 0x93,
		0x00, 0x60, 0x84, 0xbd, 0x04, 0x2e, 0xc2, 0x3e, 0x81, 0xc4, 0x81, 0x0c, 0xae, 0xcd, 0x7c, 0x7a,
		0x80, 0x24, 0x0f, 0x14, 0x06, 0xc3, 0x22, 0x80, 0xc8, 0x6b, 0x22, 0x7c, 0x70, 0xf1, 0xf6, 0x99,
		0x8c, 0xa8, 0x4e, 0xa6, 0x07, 0x7e, 0x1e, 0xc1, 0x52, 0xd2, 0xd2, 0x0d, 0x70, 0xb3, 0xb1, 0x3e,
		0x4b, 0x95, 0xa3, 0x2a, 0x38, 0x9d, 0xd8, 0xba, 0xa1, 0xf1, 0x19, 0xc8, 0xe2, 0xa8, 0xde, 0x20,
		0x8a, 0x42, 0x8f, 0x39, 0xf7, 0xc4, 0x71, 0xc2, 0x51, 0x20, 0xa4, 0x46, 0x54, 0x66, 0x22, 0xf5,
		0x69, 0xec, 0x91, 0x00, 0x94, 0x3f, 0x11, 0x85, 0xa0, 0x38, 0xd1, 0xa1, 0x1c, 0x18, 0xda, 0x38,
		0x6e, 0xc2, 0x32, 0x6a, 0xfa, 0xae, 0x0b, 0x4a, 0x01, 0xf6, 0x38, 0x28, 0xc7, 0x86, 0x3a, 0x21,
		0x30, 0xc0, 0x90, 0xcb, 0xf7, 0x00, 0x66, 0xe1, 0x5a, 0xc0, 0xec, 0x95, 0xb3, 0x11, 0x2c, 0xbb,
		0xce, 0x67, 0xe1, 0x5d, 0x19, 0x54, 0x99, 0x88, 0xc7, 0x02, 0x3a, 0x90, 0x6b, 0x4f, 0x94, 0x81,
		0xfa, 0x80, 0x85, 0xa2, 0xf0, 0xef, 0x63, 0x06, 0x8c, 0xfd, 0xe7, 0xf3, 0x6d, 0x2a, 0xd0, 0x9c,
		0xd0, 0xe9, 0xa0, 0xce, 0xb6, 0x07, 0xcb, 0x14, 0xf7, 0x23, 0x07, 0x62, 0x0c, 0xb8, 0xf6, 0xfd,
		0xfc, 0xf8, 0x02, 0x16, 0x5e, 0x08, 0x18, 0x0e, 0x75, 0x1a, 0x2f, 0x3b, 0x07, 0x99, 0xe7, 0x9e,
		0x27, 0x62, 0x4e, 0xe0, 0x95, 0x42, 0xdd, 0x54, 0x40, 0x29, 0x99, 0x28, 0x8a, 0xce, 0x47, 0x9e,
		0x60, 0x1e, 0x0b, 0x7e, 0xc9, 0x36, 0xfe, 0xcd, 0x8e, 0x1b, 0xf7, 0xab, 0xd0, 0xd2, 0x7e, 0xc7,
		0xb0, 0xf4, 0x60, 0x14, 0x06, 0x35, 0x58, 0x75, 0x3d, 0xd3, 0x46, 0x54, 0xc0, 0xb6, 0x69, 0xc4,
		0x41, 0xf5, 0xc0, 0xb9, 0xeb, 0x85, 0x77, 0xf3, 0xdc, 0x31, 0xc8, 0xb0, 0x4f, 0x03, 0x94, 0xed,
		0xc9, 0x87, 0xc0, 0x72, 0x8f, 0xd3, 0x36, 0x0e, 0x0d, 0x50, 0xe1, 0x82, 0xb8, 0xef, 0x1c, 0x1e,
		0x1c, 0x00, 0x73, 0x65, 0x08, 0x81, 0xd5, 0x7f, 0x83, 0x08, 0xff, 0x9b, 0xf4, 0x60, 0xd7, 0x0c,
		0xce, 0x2e, 0x8a, 0x41, 0x9a, 0x53, 0xe7, 0x27, 0xbe, 0xe0, 0x30, 0x31, 0xb3, 0xce, 0x78, 0x7d,
		0xcb, 0xa5, 0x5d, 0xf6, 0xdb, 0xc0, 0x40, 0x25, 0x3c, 0xec, 0x8b, 0x5b, 0x12, 0xd3, 0x66, 0x18,
		0x46, 0x3d, 0x60, 0x3d, 0x0c, 0x46, 0x9e, 0x88, 0x09, 0x3c, 0x04, 0xf4, 0x09, 0x50, 0xfc, 0x73,
		0x9f, 0xf5, 0x62, 0x0a, 0xd0, 0xa5, 0x10, 0x34, 0xf6, 0x81, 0xb5, 0x64, 0x1b, 0x86, 0x3e, 0x8d,
		0x02, 0x02, 0x0d, 0x70, 0x02, 0x4c, 0x51, 0x97, 0xaa, 0xb0, 0x3a, 0x09, 0xfd, 0x0d, 0x0c, 0xb4,
		0x44, 0x1c, 0x41, 0x3d, 0xc6, 0xcf, 0xa9, 0x20, 0xcd, 0x56, 0xab, 0x0d, 0x3a, 0xd4, 0x00, 0x50,
		0xf3, 0x78, 0xb0, 0x3a, 0xb7, 0x02, 0xec, 0x4b, 0x33, 0xf6, 0xe4, 0x4f, 0x02, 0x0f, 0x94, 0xf3,
		0xe5, 0x55, 0x58, 0x04, 0xad, 0xb8, 0x93, 0xb3, 0xbb, 0x6e, 0x78, 0x16, 0x8e, 0x80, 0x9a, 0xa7,
		0xd2, 0xa3, 0x6b, 0x33, 0xec, 0x49, 0x0a, 0xca, 0x0f, 0x9b, 0x0c, 0x28, 0xbe, 0x94, 0x19, 0x50,
		0x9c, 0x85, 0x81, 0x1c, 0x50, 0xa1, 0x3c, 0x5f, 0x28, 0x83, 0x7c, 0x0e, 0x77, 0x60, 0xe1, 0xe3,
		0x26, 0x25, 0x8c, 0xfc, 0x9c, 0x38, 0x4d, 0x68, 0x44, 0xcf, 0x7a, 0x7e, 0xe5, 0x60, 0x2f, 0x22,
		0xf1, 0xf8, 0x18, 0x41, 0x99, 0xa3, 0xee, 0x10, 0x5a, 0xdf, 0xa3, 0x59, 0xfa, 0xe4, 0xec, 0xcb,
		0x29, 0x28, 0x01, 0x31, 0x99, 0x50, 0x57, 0xf6, 0x7b, 0x00, 0x3b, 0x29, 0xcf, 0x64, 0xc3, 0x17,
		0x68, 0x29, 0xf1, 0xc5, 0x20, 0x29, 0x78, 0x42, 0xa2, 0xeb, 0xfa, 0x04, 0x58, 0x31, 0x12, 0xac,
		0x86, 0x89, 0x11, 0x81, 0x15, 0x00, 0x71, 0x3d, 0x0e, 0x6a, 0x70, 0x87, 0x47, 0xa2, 0x3e, 0xb0,
		0xc0, 0xed, 0xe9, 0x1d, 0x83, 0x2b, 0x9c, 0x60, 0x85, 0x85, 0xc0, 0xd5, 0x08, 0x43, 0xcb, 0xdf,
		0x00, 0x03, 0x33, 0xf5, 0xa5, 0x87, 0x3f, 0x66, 0x64, 0x9e, 0x7f, 0xeb, 0x42, 0xf3, 0xda, 0xdb,
		0x21, 0x0b, 0x44, 0x37, 0x9c, 0xfc, 0xe8, 0xd0, 0x98, 0xc1, 0xea, 0xe4, 0x3a, 0xf6, 0xe1, 0xef,
		0xa0, 0x39, 0xf1, 0x3e, 0x75, 0x19, 0x39, 0x27, 0xcc, 0x03, 0x98, 0xd9, 0x75, 0x1d, 0x50, 0x42,
		0x9d, 0xc7, 0x11, 0xc8, 0x48, 0x07, 0xcc, 0x1c, 0xdc, 0x78, 0x79, 0xad, 0xbe, 0xeb, 0x13, 0x88,
		0xf5, 0xef, 0x51, 0x14, 0xc1, 0x6a, 0x0e, 0x03, 0xcc, 0x51, 0x20, 0xc2, 0x07, 0xd8, 0x0a, 0x7b,
		0x2c, 0xe2, 0x27, 0xb8, 0xb4, 0xc8, 0xa3, 0x77, 0x21, 0xac, 0x20, 0x07, 0x1f, 0x45, 0xa0, 0x47,
		0x7d, 0x9d, 0x42, 0x1b, 0xf5, 0x35, 0x9b, 0x49, 0x08, 0x6d, 0x4c, 0x05, 0xb0, 0xf5, 0xac, 0x34,
		0xe8, 0xfd, 0x0c, 0x0b, 0x0e, 0xe6, 0x38, 0xa2, 0xee, 0x8f, 0x60, 0xa1, 0x68, 0x4b, 0x20, 0x7b,
		0x3e, 0x9f, 0xb1, 0x1e, 0x2c, 0xe9, 0x2e, 0x80, 0x11, 0x39, 0x0b, 0x04, 0x8d, 0x3d, 0x4a, 0x6e,
		0x40, 0xc1, 0x8c, 0xc5, 0x08, 0x9a, 0xef, 0x3e, 0x27, 0xa8, 0x49, 0xf1, 0xf4, 0x25, 0xb0, 0xba,
		0xd6, 0x65, 0xdb, 0xb6, 0x0e, 0x8d, 0x6f, 0x18, 0xac, 0x86, 0x06, 0x51, 0x18, 0x94, 0xf6, 0xf7,
		0x81, 0x59, 0x58, 0xbd, 0x30, 0x80, 0x35, 0xa9, 0x0d, 0x98, 0x6b, 0x1a, 0xf3, 0xb8, 0x07, 0x93,
		0xc2, 0xcf, 0xdb, 0x0d, 0x78, 0xed, 0x4b, 0x21, 0xe6, 0xfe, 0x6e, 0xc0, 0xcd, 0xd8, 0x7b, 0x62,
		0x17, 0x97, 0xce, 0x6e, 0x5d, 0x60, 0x86, 0x31, 0xb4, 0x5e, 0x5a, 0x03, 0x68, 0x9d, 0x60, 0x26,
		0x15, 0x8b, 0xa0, 0x4e, 0xcc, 0x77, 0x39, 0xb0, 0x04, 0xc4, 0xd8, 0x55, 0x9e, 0x17, 0x91, 0xb4,
		0xcb, 0xa0, 0x40, 0x72, 0xac, 0xdf, 0xbe, 0xed, 0xde, 0x47, 0x14, 0xb4, 0x58, 0xb8, 0xa4, 0x02,
		0x98, 0x58, 0x70, 0xc2, 0x7e, 0x9f, 0x52, 0x70, 0x60, 0x85, 0xd3, 0x06, 0x28, 0xa8, 0x82, 0xc3,
		0xb8, 0x13, 0x36, 0x3a, 0x4d, 0x68, 0x61, 0x76, 0x22, 0xfc, 0x06, 0xac, 0xac, 0xfb, 0x6c, 0x54,
		0x61, 0x23, 0x3a, 0x76, 0xdd, 0x18, 0x58, 0xa9, 0x99, 0x1f, 0x79, 0xbc, 0x0b, 0xce, 0xfd, 0x9a,
		0x9a, 0x59, 0x10, 0xc3, 0xd9, 0x1e, 0x89, 0x80, 0x0d, 0xa2, 0x3e, 0xf5, 0x00, 0x56, 0x52, 0x0d,
		0x39, 0x67, 0xe0, 0xb2, 0xa8, 0x6d, 0x22, 0x86, 0xd0, 0x78, 0x0f, 0x56, 0xb3, 0xf5, 0xbd, 0xbd,
		0x43, 0x88, 0xad, 0x3c, 0xe0, 0xcd, 0x7f, 0xe7, 0xd0, 0x9a, 0x1e, 0xad, 0x36, 0x0d, 0x87, 0x87,
		0xb3, 0x3c, 0xfb, 0x72, 0xda, 0xea, 0x40, 0x4c, 0x99, 0xc2, 0x4c, 0xe8, 0x12, 0xe1, 0x37, 0xc3,
		0x01, 0x73, 0x88, 0x07, 0xb2, 0x2a, 0x7d, 0x62, 0xbe, 0xc3, 0x72, 0xc1, 0x98, 0x4f, 0xe2, 0xfb,
		0x46, 0xe7, 0x14, 0x54, 0xcb, 0x18, 0x52, 0x2a, 0x9f, 0x47, 0x00, 0x3b, 0x5d, 0x8e, 0x9d, 0xe8,
		0x86, 0x03, 0xab, 0x38, 0x69, 0x52, 0x19, 0xd1, 0x38, 0xed, 0x42, 0x1e, 0x2f, 0x00, 0xb1, 0xce,
		0xc5, 0x75, 0x83, 0xbf, 0x60, 0xd5, 0xb8, 0xcc, 0x7b, 0xc6, 0x94, 0x80, 0xf5, 0x04, 0x84, 0xd7,
		0x5d, 0x67, 0x08, 0x2d, 0x64, 0x4b, 0xc6, 0x0b, 0x8a, 0x80, 0x35, 0x28, 0x9b, 0x0e, 0x84, 0x06,
		0xb5, 0x4f, 0x14, 0x56, 0xf2, 0x3b, 0x82, 0x15, 0x73, 0x2c, 0x0e, 0x78, 0x00, 0xd1, 0x02, 0xad,
		0x1f, 0x5f, 0x1c, 0x83, 0x0a, 0x25, 0xf8, 0xb0, 0xca, 0x83, 0x83, 0x18, 0xd8, 0x54, 0xf1, 0xb3,
		0xd3, 0x26, 0xb0, 0xa0, 0x54, 0xd7, 0xf5, 0x81, 0x0d, 0xea, 0x65, 0xe1, 0xf9, 0xf1, 0x09, 0xa8,
		0x79, 0x30, 0x9c, 0x45, 0xa0, 0x1b, 0x05, 0xc0, 0x8a, 0xde, 0xf5, 0x4b, 0xb5, 0xf3, 0x7e, 0x0c,
		0xcf, 0x36, 0xf1, 0x43, 0x87, 0x7c, 0xa3, 0x31, 0x67, 0x61, 0x50, 0x82, 0x57, 0x20, 0x59, 0xab,
		0xc2, 0xaa, 0xab, 0xa9, 0x1c, 0x80, 0x74, 0xd4, 0x81, 0x75, 0xff, 0x63, 0xd0, 0xca, 0x8f, 0xd8,
		0x80, 0x09, 0xe2, 0x7d, 0x8f, 0x49, 0x14, 0xd1, 0x18, 0x70, 0x09, 0xfc, 0x6c, 0xa1, 0xed, 0xf0,
		0x96, 0xc6, 0x1e, 0x0b, 0x40, 0x09, 0x0a, 0xce, 0x0f, 0x00, 0x56, 0x4d, 0x3d, 0x75, 0xdd, 0x61,
		0xc6, 0xf9, 0x16, 0x95, 0xcb, 0x67, 0x7f, 0x01, 0xcb, 0x71, 0xf5, 0x60, 0xc1, 0x50, 0x60, 0xcd,
		0x04, 0xbb, 0x2b, 0xef, 0x0f, 0x47, 0x81, 0x00, 0x57, 0x08, 0xcf, 0x82, 0x3e, 0x0b, 0x58, 0x8f,
		0x48, 0x61, 0x1d, 0x13, 0x7d, 0xf3, 0xea, 0x5d, 0xba, 0xfb, 0x6c, 0xfe, 0xd7, 0xe7, 0xff, 0x65,
		0xc3, 0x5e, 0x15, 0xfe, 0xa4, 0xf7, 0x13, 0x1b, 0x73, 0xfc, 0xc2, 0x1b, 0xbe, 0xd2, 0x64, 0x5c,
		0x1c, 0x0b, 0x11, 0x17, 0x3e, 0xbd, 0xb0, 0x8d, 0x85, 0x73, 0x16, 0xd4, 0x3d, 0xea, 0xd3, 0x40,
		0xf0, 0xc2, 0xa7, 0x9d, 0xbd, 0x3f, 0x5e, 0xf8, 0x26, 0xb9, 0x5b, 0xf9, 0x66, 0xe9, 0xb0, 0x5a,
		0xad, 0x1d, 0x54, 0xab, 0x7b, 0x07, 0x95, 0x83, 0xbd, 0xa3, 0xfd, 0xfd, 0x52, 0xad, 0xb4, 0xff,
		0xc2, 0xc5, 0xad, 0xd8, 0xa5, 0x31, 0x75, 0x3f, 0x8f, 0x57, 0x1d, 0x8c, 0x3c, 0x4f, 0xea, 0x65,
		0x8f, 0x83, 0x20, 0x14, 0x44, 0xb0, 0x30, 0x78, 0xf9, 0x5d, 0xb8, 0x33, 0xa4, 0x3e, 0x89, 0x88,
		0x18, 0x8e, 0xf7, 0x66, 0x97, 0x51, 0xd1, 0x2f, 0xb2, 0xf9, 0xac, 0x33, 0xbe, 0xbb, 0xfc, 0xb5,
		0xc8, 0x05, 0x11, 0x74, 0xf9, 0x41, 0xe1, 0x85, 0x95, 0x73, 0x11, 0x8f, 0x1c, 0x11, 0xcc, 0x28,
		0xab, 0x51, 0xef, 0x9e, 0x2d, 0xc6, 0xa7, 0xf1, 0xeb, 0xe5, 0xaf, 0x9d, 0xf1, 0x1d, 0xaf, 0x5f,
		0x99, 0xac, 0xb6, 0x7e, 0xc6, 0x8f, 0x3f, 0x79, 0xb2, 0x01, 0xaf, 0xbd, 0xb8, 0xec, 0x0b, 0x3f,
		0xf3, 0x9a, 0x52, 0xaf, 0xf7, 0xf8, 0xa5, 0x96, 0x4b, 0x5f, 0x59, 0x76, 0xc1, 0x0b, 0x1d, 0xe2,
		0x15, 0xe3, 0x70, 0x24, 0x28, 0x5f, 0x5b, 0xf4, 0x52, 0xb0, 0xae, 0x7e, 0xeb, 0xc9, 0x4b, 0xff,
		0xc9, 0x02, 0x77, 0x4c, 0x60, 0x4f, 0x3e, 0x3e, 0x09, 0x83, 0x3e, 0x1b, 0xac, 0xd3, 0x68, 0xa1,
		0x1d, 0xd3, 0x3e, 0xbb, 0x7b, 0x7e, 0x83, 0x16, 0xc5, 0x6e, 0x4e, 0xd1, 0x0b, 0x9d, 0x62, 0x2c,
		0x9e, 0xdb, 0x82, 0x4e, 0x38, 0x8a, 0x1d, 0xba, 0x91, 0xb4, 0xc6, 0xbc, 0x76, 0x1b, 0xc6, 0xee,
		0x54, 0x9b, 0x4e, 0x9e, 0xb5, 0x81, 0x4e, 0xff, 0x4d, 0xf8, 0x71, 0x3c, 0x18, 0x8d, 0x59, 0xa4,
		0xf0, 0x69, 0x47, 0xc4, 0x23, 0xba, 0x89, 0xa0, 0x97, 0xdf, 0x5a, 0x59, 0x9a, 0x24, 0x71, 0x9c,
		0xb2, 0xe7, 0x59, 0xbb, 0xe0, 0xcc, 0x77, 0x6a, 0xc3, 0xfb, 0x2c, 0xd1, 0x5d, 0x93, 0xef, 0x6d,
		0x92, 0x30, 0xcf, 0x1e, 0xc3, 0xab, 0xc7, 0x91, 0xe4, 0x58, 0xa4, 0x8e, 0x27, 0xe9, 0x31, 0x49,
		0x1f, 0x97, 0xf4, 0xb1, 0xc9, 0x1e, 0x9f, 0x9a, 0x64, 0x57, 0x14, 0x76, 0x61, 0x44, 0x83, 0xe9,
		0x81, 0x16, 0x97, 0xcc, 0xc5, 0x82, 0xc1, 0xee, 0x2a, 0xab, 0xed, 0xbe, 0x78, 0xe4, 0xcf, 0xc8,
		0x83, 0xd6, 0xe2, 0xae, 0xcd, 0xf1, 0x6d, 0x2e, 0xa7, 0xf7, 0xbc, 0x5e, 0xfc, 0x41, 0xf9, 0xf5,
		0x8c, 0x10, 0x92, 0xca, 0xbb, 0x67, 0xf8, 0x6f, 0xba, 0x42, 0x32, 0x18, 0xc4, 0x74, 0x40, 0x9e,
		0x13, 0x1b, 0x1b, 0xc4, 0xc7, 0xca, 0x15, 0x48, 0xc3, 0xa0, 0x68, 0x78, 0x93, 0x68, 0x5a, 0x7c,
		0x61, 0x71, 0x74, 0xaf, 0x6f, 0xc5, 0xc2, 0xf6, 0x5d, 0x5c, 0xf2, 0xca, 0x9b, 0xbd, 0x7c, 0xe8,
		0x89, 0x0f, 0x5f, 0x86, 0x08, 0x94, 0x88, 0x41, 0x96, 0x28, 0x94, 0x89, 0x43, 0x99, 0x48, 0x54,
		0x89, 0x25, 0xa1, 0x29, 0xfc, 0xca, 0xbe, 0xbf, 0x46, 0x44, 0x49, 0xf5, 0x9d, 0x9a, 0xfe, 0x53,
		0x24, 0x2b, 0x69, 0xf2, 0x52, 0x21, 0xb3, 0x54, 0xe4, 0xa6, 0x4a, 0x76, 0xa9, 0xc9, 0x2f, 0x35,
		0x19, 0xa6, 0x25, 0x47, 0x39, 0x4f, 0x2f, 0xa1, 0x97, 0x9a, 0x98, 0x4c, 0x17, 0x17, 0xb8, 0x94,
		0x3b, 0x31, 0x8b, 0x5e, 0xd5, 0xf0, 0x2f, 0x07, 0xc2, 0x56, 0x6e, 0x22, 0xb9, 0x7b, 0x33, 0x42,
		0xde, 0x93, 0xbc, 0x4c, 0x96, 0xa0, 0xd3, 0x10, 0xb6, 0x16, 0x02, 0x4f, 0x4b, 0xe8, 0xda, 0x08,
		0x5e, 0x1b, 0xe1, 0xeb, 0x62, 0x00, 0x39, 0x46, 0x50, 0x08, 0xdb, 0x4c, 0x16, 0x39, 0xa9, 0xb7,
		0x49, 0x75, 0xea, 0x5c, 0xc4, 0x2c, 0x18, 0xa8, 0x1c, 0xf9, 0x5c, 0x58, 0x1f, 0xbe, 0x33, 0xb3,
		0x1f, 0x12, 0x7b, 0x51, 0x70, 0x19, 0x77, 0xc8, 0x84, 0x7c, 0x94, 0x83, 0xde, 0xd3, 0x1b, 0x48,
		0xee, 0xff, 0x29, 0xed, 0x93, 0x91, 0x27, 0xa6, 0xe1, 0x55, 0x8f, 0x53, 0x94, 0x13, 0x28, 0x27,
		0xde, 0xa6, 0x9c, 0xe8, 0x85, 0xa1, 0x47, 0x49, 0x90, 0x46, 0x50, 0x94, 0x00, 0x08, 0x8a, 0x48,
		0x8d, 0x01, 0x56, 0x52, 0x3d, 0x2a, 0xd6, 0x18, 0xb2, 0x39, 0xb2, 0xb9, 0x1d, 0x6c, 0xce, 0xa2,
		0xa2, 0xf2, 0x86, 0x2f, 0x18, 0xfd, 0x48, 0xe1, 0xda, 0xd9, 0xd2, 0x7f, 0x28, 0x9d, 0x8e, 0x1a,
		0x95, 0x3d, 0x79, 0xf1, 0x9b, 0x6a, 0x31, 0x15, 0xad, 0x3d, 0x36, 0x8a, 0x52, 0xdc, 0xa3, 0x4d,
		0x84, 0xa0, 0x71, 0xa0, 0xbc, 0x1b, 0x8b, 0x1b, 0xbd, 0x7f, 0xff, 0x63, 0xaf, 0x78, 0x74, 0xf5,
		0xfb, 0x47, 0xa9, 0x78, 0x74, 0x35, 0xfd, 0xb5, 0x34, 0xf9, 0x31, 0xfd, 0xbd, 0xfc, 0x63, 0xaf,
		0x58, 0x9d, 0xff, 0xbe, 0xff, 0x63, 0xaf, 0xb8, 0x7f, 0xf5, 0xe1, 0xe7, 0xcf, 0x8f, 0x1f, 0xfe,
		0xa9, 0x3c, 0xc8, 0x5f, 0xb8, 0x3b, 0x7b, 0xd8, 0x87, 0xdf, 0xef, 0x7f, 0x94, 0x8a, 0xe5, 0xab,
		0xf9, 0x1f, 0x95, 0x1f, 0x7b, 0xc5, 0xf2, 0xd5, 0x87, 0x0f, 0x05, 0xe5, 0x57, 0xb9, 0x4a, 0xb3,
		0x95, 0xad, 0x4e, 0xe3, 0x2f, 0x6d, 0xfb, 0xf9, 0xbf, 0x90, 0x36, 0xf4, 0xbf, 0x52, 0xec, 0xa8,
		0xd2, 0x95, 0x0f, 0x7f, 0xe4, 0xc8, 0x9b, 0xb5, 0xb7, 0xc9, 0x9b, 0xa4, 0xd8, 0x3f, 0x2e, 0x9e,
		0x5d, 0xfd, 0x53, 0xfa, 0xa3, 0xfa, 0xf0, 0xe9, 0xc3, 0x3f, 0x07, 0x0f, 0x4f, 0x3f, 0xfc, 0xfd,
		0xdc, 0xd7, 0x4a, 0x7f, 0x1c, 0x3c, 0x7c, 0xda, 0xf0, 0x2f, 0xb5, 0x87, 0x4f, 0x09, 0xef, 0xb1,
		0xff, 0xf0, 0x7e, 0xed, 0xab, 0xe3, 0xcf, 0xcb, 0x9b, 0x2e, 0xa8, 0x6e, 0xb8, 0xa0, 0xb2, 0xe9,
		0x82, 0xca, 0x86, 0x0b, 0x36, 0x2e, 0xa9, 0xbc, 0xe1, 0x82, 0xfd, 0x87, 0xdf, 0x6b, 0xdf, 0x7f,
		0xff, 0xfc, 0x57, 0x6b, 0x0f, 0x1f, 0x7e, 0x6f, 0xfa, 0xb7, 0x83, 0x87, 0xdf, 0x9f, 0x3e, 0x7c,
		0xd8, 0x7d, 0x5f, 0x1a, 0xf3, 0xdb, 0xe1, 0x94, 0x05, 0x4b, 0x57, 0x6b, 0x9c, 0x39, 0xe5, 0xb4,
		0x37, 0x24, 0xb0, 0x90, 0xca, 0xc0, 0x52, 0x59, 0xf6, 0x52, 0xfc, 0x9d, 0xd9, 0xe7, 0x98, 0x71,
		0xdb, 0x38, 0x15, 0x45, 0x41, 0x06, 0xea, 0x7e, 0xdb, 0xfc, 0x06, 0xe8, 0xb8, 0xa1, 0xe3, 0xf6,
		0x26, 0x1d, 0x37, 0x41, 0x06, 0x45, 0x31, 0xbe, 0xcb, 0x96, 0xf9, 0x6d, 0x23, 0x16, 0x88, 0x4a,
		0x59, 0x83, 0x59, 0x78, 0x90, 0xe2, 0x16, 0x97, 0x24, 0x18, 0xd0, 0xd4, 0xea, 0xfa, 0x9f, 0x54,
		0x57, 0xef, 0xcc, 0x90, 0x86, 0xca, 0xbc, 0xab, 0x49, 0xf8, 0x6d, 0xbc, 0xdd, 0x37, 0xe2, 0x8d,
		0xa8, 0xc6, 0xfb, 0x9d, 0xc5, 0xc4, 0x11, 0x2c, 0x0c, 0x4e, 0xd9, 0x80, 0x4d, 0x81, 0x95, 0xa9,
		0xef, 0xfb, 0xf0, 0x87, 0x86, 0x23, 0x20, 0x77, 0xe0, 0x8f, 0xa0, 0x5a, 0x3e, 0xaa, 0x1e, 0xd5,
		0x0e, 0xca, 0x47, 0xfb, 0x80, 0xcf, 0xe2, 0x5d, 0x3e, 0x57, 0xdb, 0xe6, 0x1c, 0x0f, 0xe9, 0x5d,
		0x51, 0x39, 0x89, 0x07, 0xd4, 0x37, 0x5e, 0x35, 0xab, 0x9f, 0x5a, 0xeb, 0xe5, 0x87, 0x0f, 0xff,
		0xfd, 0xe1, 0x5f, 0x5b, 0x6c, 0x36, 0x6b, 0x45, 0x56, 0x24, 0x44, 0x42, 0xae, 0x1b, 0xe4, 0x2a,
		0xc8, 0xc8, 0xa7, 0x90, 0xc2, 0xdd, 0xc5, 0xaf, 0xbb, 0x52, 0x38, 0xa1, 0x1d, 0x25, 0x10, 0xe5,
		0xe4, 0xf7, 0xe3, 0xc5, 0xc3, 0xaf, 0x17, 0xbf, 0xbe, 0x08, 0xaf, 0x94, 0xdf, 0xfe, 0x04, 0x5b,
		0x2f, 0x9b, 0x86, 0x52, 0x4b, 0x3f, 0x49, 0x6a, 0x0f, 0x84, 0x53, 0x99, 0xf3, 0x46, 0x60, 0xc1,
		0xa9, 0xa4, 0xbd, 0x8d, 0x25, 0x28, 0x98, 0x92, 0x7e, 0x4c, 0xfb, 0x32, 0x67, 0x36, 0xd7, 0x2c,
		0x12, 0xf6, 0x75, 0xa1, 0x3d, 0x93, 0x2b, 0x1f, 0x3f, 0xce, 0x04, 0xc3, 0xee, 0xec, 0xd8, 0x32,
		0x64, 0xd1, 0x69, 0x35, 0x87, 0x34, 0x87, 0x6e, 0x2a, 0x02, 0x79, 0x71, 0x6f, 0x64, 0x19, 0xb4,
		0x8c, 0x0c, 0xfa, 0xa6, 0x19, 0x14, 0xf1, 0x8e, 0x18, 0x27, 0xc3, 0x38, 0x99, 0x91, 0x38, 0x19,
		0xe2, 0x1d, 0x11, 0xef, 0x88, 0x72, 0x02, 0xe5, 0xc4, 0x6b, 0xa7, 0x8e, 0x78, 0x47, 0xc4, 0x3b,
		0x22, 0x9b, 0x23, 0xde, 0x31, 0x09, 0xa3, 0x23, 0xde, 0x11, 0xf1, 0x8e, 0x88, 0x77, 0x44, 0xbc,
		0xa3, 0x46, 0xde, 0x44, 0xbc, 0x23, 0x22, 0xd1, 0x10, 0xef, 0xa8, 0x28, 0xb0, 0x90, 0xca, 0x10,
		0xef, 0xa8, 0x66, 0x80, 0xee, 0x20, 0xde, 0x11, 0x1d, 0x37, 0x74, 0xdc, 0x10, 0xef, 0x08, 0xd6,
		0x6f, 0x43, 0xbc, 0xe3, 0xea, 0x42, 0x10, 0xef, 0x98, 0xea, 0x3f, 0xc4, 0x3b, 0x02, 0x3a, 0x0b,
		0xc4, 0x3b, 0x26, 0x12, 0x80, 0x88, 0x77, 0xdc, 0x32, 0xb3, 0xf9, 0x4d, 0xe2, 0x1d, 0x65, 0x60,
		0x42, 0x3b, 0x9a, 0xe1, 0x8e, 0xcf, 0xf4, 0x99, 0x55, 0xdf, 0xfc, 0x74, 0xfd, 0xe7, 0x66, 0x2d,
		0x96, 0x93, 0xf5, 0x5f, 0x4c, 0xd4, 0x6c, 0x79, 0xd5, 0x34, 0x48, 0xd6, 0x74, 0x79, 0x55, 0x93,
		0x29, 0x37, 0x5f, 0x5e, 0xdc, 0x24, 0x51, 0x13, 0xe6, 0xa4, 0xdb, 0x23, 0x49, 0xad, 0xba, 0xa9,
		0xb4, 0x90, 0x08, 0x26, 0xa7, 0x8b, 0x2e, 0x0b, 0x99, 0x34, 0xf5, 0x36, 0xda, 0xfa, 0x35, 0x61,
		0xcf, 0x54, 0x2d, 0x1b, 0x97, 0xa6, 0x1b, 0xec, 0xcb, 0xd8, 0xc6, 0x44, 0x58, 0xc6, 0xc4, 0x7d,
		0x5f, 0xcb, 0xd8, 0xf7, 0xd5, 0x9e, 0xde, 0xc5, 0xaf, 0xa9, 0x25, 0x79, 0xaa, 0x7d, 0x41, 0xd9,
		0x24, 0xa7, 0x55, 0xe6, 0x6c, 0xea, 0x76, 0xfe, 0x2c, 0xcd, 0x2e, 0xbf, 0x8e, 0x3d, 0x8b, 0xed,
		0xea, 0x59, 0x3c, 0x3d, 0xbd, 0xe4, 0x0d, 0x8b, 0x67, 0xdf, 0xc7, 0x6e, 0xc5, 0xd8, 0xad, 0x78,
		0xf5, 0x8b, 0xd8, 0xad, 0x18, 0xd1, 0xfb, 0x88, 0xde, 0x37, 0x1c, 0x75, 0xc3, 0xac, 0x0f, 0x66,
		0x7d, 0x10, 0xbd, 0xaf, 0xb0, 0x17, 0x08, 0xca, 0x45, 0x2e, 0x47, 0x2e, 0x7f, 0xe1, 0xd4, 0x11,
		0x94, 0x8b, 0xa0, 0x5c, 0x04, 0xe5, 0x6e, 0xb8, 0x1b, 0x82, 0x72, 0x73, 0xe3, 0x4d, 0x04, 0xe5,
		0x22, 0x5c, 0x12, 0x41, 0xb9, 0x8a, 0x02, 0x0b, 0xa9, 0x0c, 0x41, 0xb9, 0x6a, 0x06, 0xe8, 0x0e,
		0x82, 0x72, 0xd1, 0x71, 0x43, 0xc7, 0x0d, 0x41, 0xb9, 0x60, 0xfd, 0x36, 0x04, 0xe5, 0xae, 0x2e,
		0x04, 0x41, 0xb9, 0xa9, 0xfe, 0x43, 0x50, 0x2e, 0xa0, 0xb3, 0x40, 0x50, 0x6e, 0x22, 0x01, 0x88,
		0xa0, 0xdc, 0x2d, 0x33, 0x9b, 0xed, 0x05, 0xe5, 0x3e, 0x02, 0x08, 0xcd, 0xfe, 0xca, 0xa2, 0xfd,
		0x68, 0x67, 0xf2, 0xa4, 0x47, 0x7f, 0xe4, 0xd0, 0x78, 0x34, 0xa0, 0x77, 0xa2, 0x38, 0x0c, 0x23,
		0x2e, 0x0f, 0x8e, 0x58, 0x5e, 0x8a, 0xf8, 0x08, 0xc4, 0x47, 0xa4, 0x60, 0x77, 0x69, 0x7c, 0xc4,
		0x9c, 0xf2, 0xd4, 0x3d, 0xef, 0xc5, 0x1d, 0xd4, 0x5c, 0xef, 0x12, 0xba, 0xde, 0xe8, 0x7a, 0x9b,
		0x74, 0xbd, 0x65, 0x59, 0x62, 0x71, 0xa1, 0x24, 0xd2, 0x6d, 0x23, 0xd1, 0x48, 0x2b, 0x40, 0x0d,
		0x6c, 0x92, 0x9a, 0x5d, 0x74, 0xb0, 0x8d, 0x56, 0xf6, 0xd1, 0xc5, 0x46, 0xda, 0xd9, 0x49, 0x3b,
		0x5b, 0xe9, 0x66, 0xaf, 0x74, 0x2e, 0x93, 0xa2, 0xe3, 0xa3, 0xcc, 0x76, 0x8b, 0x1b, 0xb0, 0xc0,
		0xa5, 0xe9, 0x3d, 0xed, 0x65, 0x8e, 0x71, 0x72, 0xbb, 0x94, 0x27, 0xa2, 0xc7, 0x5d, 0x4f, 0xcd,
		0x94, 0x3a, 0x99, 0xd3, 0x08, 0x93, 0xea, 0x66, 0x56, 0x63, 0x4c, 0x6b, 0x8c, 0x79, 0x4d, 0x31,
		0xb1, 0xa6, 0xe8, 0x49, 0x4a, 0xba, 0x53, 0x0e, 0x67, 0x6f, 0xa4, 0xba, 0xd4, 0x11, 0x8e, 0xf5,
		0x48, 0x47, 0x4e, 0xf1, 0xa5, 0x14, 0x7b, 0x5b, 0xf0, 0xa9, 0x88, 0x13, 0xd4, 0x68, 0x24, 0xde,
		0xd5, 0xd9, 0xfd, 0x50, 0xea, 0xa1, 0xd4, 0x43, 0xa9, 0x07, 0x50, 0xea, 0xa5, 0x4e, 0x6e, 0x3d,
		0xe5, 0xd1, 0x03, 0x0d, 0xb7, 0xd2, 0x93, 0xec, 0x9a, 0xff, 0xa7, 0x87, 0x05, 0x76, 0x74, 0x27,
		0xbf, 0x34, 0x0b, 0xb7, 0xb5, 0xdb, 0x6a, 0x4e, 0x86, 0x2d, 0xee, 0x6b, 0x20, 0x11, 0xa3, 0x89,
		0x3d, 0x1e, 0x1f, 0x95, 0xc6, 0x24, 0x59, 0x56, 0x47, 0xa5, 0x3b, 0x69, 0x96, 0xc9, 0x99, 0xbd,
		0x83, 0x71, 0x97, 0x2b, 0x0b, 0x8d, 0x2d, 0xe5, 0xd0, 0xe7, 0x46, 0x71, 0xae, 0x18, 0x0a, 0x45,
		0x83, 0x0b, 0x0d, 0x2e, 0x34, 0xb8, 0xb2, 0x31, 0xb8, 0x02, 0xf9, 0x1a, 0xce, 0x17, 0xbd, 0xcc,
		0x23, 0x0d, 0xf7, 0x4a, 0x05, 0xb1, 0x32, 0x68, 0x6f, 0xad, 0xd4, 0x0c, 0x11, 0xd7, 0x8d, 0x29,
		0xe7, 0x05, 0x8d, 0x26, 0x82, 0xc6, 0x1d, 0x34, 0xb3, 0x93, 0xfa, 0x77, 0xf4, 0x99, 0x9d, 0xbd,
		0xa9, 0x1a, 0xd8, 0xdb, 0xf5, 0x58, 0x88, 0x81, 0x7b, 0xeb, 0x42, 0x83, 0x6c, 0x7c, 0x40, 0x96,
		0xc5, 0x38, 0x05, 0xed, 0xaf, 0x70, 0x65, 0x62, 0xcb, 0x75, 0x16, 0x0f, 0x6c, 0x7c, 0x4a, 0xa6,
		0x55, 0x50, 0xff, 0x65, 0x60, 0xe7, 0xb5, 0xde, 0xf1, 0xe1, 0x0f, 0x8b, 0x84, 0x49, 0x0d, 0x85,
		0xc9, 0x8b, 0xc2, 0x04, 0x0b, 0x65, 0xb2, 0x2f, 0x94, 0x41, 0xd1, 0xba, 0x26, 0x5a, 0x91, 0x0c,
		0xb3, 0x27, 0x43, 0xf8, 0x8a, 0xe6, 0x1d, 0xac, 0x75, 0x69, 0x52, 0x7c, 0x06, 0xfc, 0x91, 0x29,
		0xe6, 0xd4, 0xa5, 0x7d, 0x16, 0x50, 0xb7, 0xa8, 0x29, 0xe8, 0xf2, 0xac, 0xaa, 0xd3, 0x18, 0x09,
		0x2c, 0x34, 0x5c, 0x1a, 0x08, 0x26, 0xee, 0x3f, 0x13, 0x4e, 0xf5, 0xc7, 0x46, 0xe7, 0x7b, 0xd3,
		0x6c, 0x9d, 0x1c, 0x37, 0xaf, 0x4f, 0xeb, 0x67, 0x8d, 0x8b, 0xfa, 0xe9, 0xf5, 0x45, 0xfd, 0xaf,
		0xee, 0xf5, 0xbf, 0x5b, 0xed, 0x82, 0x89, 0x90, 0x29, 0x37, 0x22, 0x27, 0xff, 0x31, 0x23, 0x79,
		0x1f, 0xef, 0x4f, 0xb3, 0x71, 0xf1, 0xa7, 0x7e, 0x79, 0xf0, 0xf0, 0x87, 0x6d, 0xbb, 0x71, 0x7a,
		0xd9, 0x6a, 0x1b, 0xd8, 0x87, 0x77, 0x30, 0xa5, 0x2c, 0x06, 0xcb, 0xd5, 0x83, 0xe5, 0x31, 0x75,
		0x46, 0xb1, 0x06, 0xc1, 0xb5, 0x20, 0xbd, 0xf9, 0x0d, 0x53, 0x86, 0x08, 0x53, 0x4e, 0x4d, 0xde,
		0x24, 0xf9, 0x31, 0xf4, 0x9e, 0xf4, 0xa6, 0x18, 0x7a, 0xc7, 0xd0, 0x7b, 0x22, 0xaa, 0x53, 0x9f,
		0xfa, 0xbc, 0xd1, 0x3c, 0x2b, 0xe5, 0x25, 0x48, 0x33, 0x45, 0xd2, 0x2a, 0x96, 0x70, 0xad, 0xdd,
		0x47, 0x5f, 0x49, 0xd7, 0xa2, 0x5c, 0x69, 0xf1, 0xdb, 0x6e, 0x2a, 0x90, 0xfb, 0x8e, 0xb6, 0xaa,
		0xaf, 0x0b, 0x7a, 0x27, 0xfe, 0x1d, 0x46, 0x7c, 0xfe, 0x8b, 0x54, 0x19, 0x58, 0xfa, 0x63, 0x56,
		0x38, 0xe2, 0x02, 0x0d, 0x48, 0xcf, 0xa3, 0xc5, 0x5e, 0xdf, 0x4d, 0x5f, 0x6a, 0xb0, 0x72, 0x2f,
		0x2c, 0x37, 0x18, 0x0b, 0x63, 0xf5, 0x9d, 0xd8, 0xd9, 0xea, 0x5a, 0x83, 0xf1, 0xbe, 0x6d, 0x4b,
		0xa1, 0x41, 0xca, 0x3a, 0x9f, 0x35, 0xb2, 0x4b, 0x2d, 0x0a, 0x35, 0x30, 0xa2, 0x35, 0x86, 0x68,
		0x3a, 0x06, 0x45, 0x2b, 0xd4, 0x08, 0x03, 0xc3, 0x30, 0x41, 0xd3, 0x32, 0xf6, 0x13, 0x0d, 0xeb,
		0xea, 0xa3, 0x8e, 0xc7, 0xea, 0xd6, 0xd5, 0x45, 0x1b, 0x9a, 0x9b, 0x81, 0xe8, 0x62, 0x7d, 0x13,
		0x22, 0xc0, 0x9c, 0x28, 0x30, 0x25, 0x12, 0x8c, 0x8b, 0x06, 0xe3, 0x22, 0xc2, 0xa8, 0xa8, 0xd0,
		0x1c, 0x63, 0xd3, 0x44, 0xb1, 0xda, 0xbc, 0x58, 0x83, 0xde, 0xac, 0x66, 0xaf, 0x56, 0xdf, 0x41,
		0xe4, 0x2b, 0xfd, 0x35, 0x79, 0xbd, 0xd9, 0x78, 0xbf, 0x4b, 0xbf, 0x6b, 0x57, 0x8b, 0xf5, 0x67,
		0xd0, 0x21, 0xae, 0x4f, 0x96, 0xfa, 0xb9, 0xef, 0xa6, 0x72, 0x8d, 0x35, 0xc4, 0x50, 0x52, 0x85,
		0x0a, 0x5e, 0x9a, 0xb1, 0x26, 0xcd, 0xcb, 0xb2, 0x03, 0x23, 0x33, 0xb1, 0xd7, 0xcb, 0x68, 0xaf,
		0xa3, 0xbd, 0x8e, 0xf6, 0x3a, 0xda, 0xeb, 0x68, 0xaf, 0xa3, 0xbd, 0x8e, 0xf6, 0x3a, 0xda, 0xeb,
		0x68, 0xaf, 0x1b, 0xb1, 0xd7, 0x75, 0x18, 0x7f, 0x99, 0x98, 0xeb, 0x12, 0xa3, 0xc5, 0x0d, 0x58,
		0xeb, 0x98, 0xf1, 0xdc, 0x4c, 0x43, 0xf0, 0xb2, 0x9e, 0x0b, 0xaa, 0x81, 0x9c, 0xf8, 0x4c, 0xd7,
		0xe0, 0x49, 0x4b, 0x63, 0xa7, 0x94, 0x26, 0x1c, 0x76, 0x57, 0xcb, 0xcc, 0xea, 0xc2, 0xee, 0x6a,
		0x7a, 0x0d, 0xa5, 0x25, 0x98, 0x9a, 0x92, 0x7e, 0x4c, 0xfb, 0x3a, 0x7a, 0x4b, 0x1f, 0xa4, 0xeb,
		0x2d, 0x3d, 0x11, 0xd2, 0x1f, 0x3f, 0xce, 0x22, 0x68, 0xbb, 0x53, 0xbe, 0x06, 0x2d, 0xbf, 0x04,
		0x8d, 0xfb, 0xc4, 0xa1, 0xc5, 0xf1, 0xfe, 0x69, 0x90, 0x63, 0xab, 0xb7, 0x43, 0xf8, 0xc6, 0x98,
		0x29, 0x59, 0x1f, 0x65, 0x99, 0x82, 0x2c, 0x63, 0x7d, 0x04, 0x6f, 0x28, 0x12, 0x1d, 0x82, 0x37,
		0xb2, 0x62, 0x4f, 0x53, 0x81, 0x1f, 0xfb, 0x63, 0xc1, 0x69, 0xd8, 0x17, 0x46, 0x30, 0x40, 0x5b,
		0x28, 0x78, 0xa1, 0x14, 0xf5, 0x07, 0x83, 0x97, 0xb7, 0xc6, 0x70, 0x30, 0x18, 0x61, 0x60, 0x4a,
		0x28, 0x18, 0x17, 0x0e, 0xc6, 0x85, 0x84, 0x49, 0x61, 0xa1, 0x2f, 0x06, 0xb9, 0x63, 0x45, 0x30,
		0x38, 0xbd, 0xcf, 0x63, 0xc2, 0x07, 0xda, 0xe8, 0x13, 0xed, 0x4e, 0x8e, 0xf9, 0xd3, 0x42, 0x60,
		0xf1, 0xa7, 0x1f, 0xcc, 0xfe, 0x9e, 0x44, 0x91, 0xa0, 0x04, 0xa3, 0x75, 0x44, 0x54, 0x47, 0x3d,
		0x83, 0xf2, 0xff, 0xd1, 0xdd, 0x51, 0x05, 0xa0, 0x0a, 0x40, 0x15, 0x80, 0x2a, 0xc0, 0x5a, 0x15,
		0xf0, 0x63, 0xa9, 0x02, 0xfe, 0x5f, 0x67, 0x14, 0xc7, 0x34, 0x10, 0xef, 0x3f, 0xec, 0x7e, 0xfc,
		0xb8, 0xbb, 0xf8, 0xc6, 0xd5, 0xec, 0x92, 0x55, 0xb9, 0xc7, 0x9f, 0xf9, 0x6c, 0x71, 0x67, 0xe5,
		0xf0, 0x9b, 0x01, 0x6d, 0x92, 0xab, 0x37, 0x53, 0xbf, 0x13, 0x7a, 0x7a, 0x1d, 0xe8, 0x77, 0x70,
		0x43, 0xa7, 0x48, 0xef, 0xc4, 0x27, 0x41, 0x3d, 0xea, 0x53, 0x11, 0xdf, 0x17, 0xc3, 0xa0, 0xe8,
		0x0c, 0x27, 0x0d, 0x9c, 0x8d, 0x38, 0xbd, 0x93, 0x1a, 0x6b, 0x03, 0x5e, 0x6f, 0xde, 0x0e, 0xef,
		0xd5, 0x36, 0x65, 0xbf, 0x1f, 0x45, 0x9a, 0xc1, 0x03, 0x56, 0x1b, 0xf3, 0xd5, 0x5e, 0xd2, 0x3e,
		0x62, 0x56, 0x11, 0xb3, 0x8a, 0x61, 0x4a, 0x0c, 0x53, 0x62, 0x98, 0x12, 0x7d, 0x54, 0xf4, 0x51,
		0xd1, 0x47, 0x45, 0x1f, 0x15, 0xc3, 0x94, 0x18, 0xa6, 0x44, 0x15, 0x80, 0x2a, 0x00, 0x55, 0x00,
		0xaa, 0x00, 0x0c, 0x53, 0x6e, 0x75, 0x98, 0xd2, 0xe2, 0x18, 0x14, 0xf0, 0x22, 0x8c, 0x47, 0x21,
		0x28, 0xac, 0xc3, 0x00, 0x4c, 0x49, 0xf0, 0x4a, 0x31, 0x56, 0x69, 0x07, 0x32, 0x9a, 0x39, 0x5d,
		0x7c, 0x52, 0x4b, 0x5c, 0x52, 0x1b, 0x7a, 0xb9, 0x8c, 0xd5, 0x18, 0x66, 0x6d, 0x49, 0xac, 0xc6,
		0xd0, 0x1a, 0x47, 0xc4, 0x59, 0xf7, 0xd9, 0x3a, 0x85, 0xd8, 0x09, 0x19, 0x3b, 0x21, 0x67, 0xef,
		0xdc, 0xe1, 0xac, 0xfb, 0x47, 0x6b, 0xc7, 0x59, 0xf7, 0x28, 0xf5, 0x50, 0xea, 0x6d, 0x8f, 0xd4,
		0xc3, 0x59, 0xf7, 0x32, 0x0b, 0xc3, 0x59, 0xf7, 0x38, 0xeb, 0x1e, 0x67, 0xdd, 0x6b, 0x14, 0x88,
		0xfa, 0xee, 0x82, 0xb3, 0xee, 0x71, 0xd6, 0x3d, 0x1a, 0x5c, 0x68, 0x70, 0x81, 0x37, 0xb8, 0x70,
		0xd6, 0xbd, 0x42, 0xe8, 0x0c, 0x67, 0xdd, 0xeb, 0xfd, 0x0f, 0x67, 0xdd, 0x27, 0x79, 0x00, 0xce,
		0xba, 0x5f, 0xdb, 0x72, 0x9c, 0x75, 0x6f, 0xdc, 0x16, 0x35, 0xe8, 0x15, 0xed, 0xe0, 0xac, 0xfb,
		0x9c, 0x85, 0x09, 0x0e, 0x19, 0xc7, 0x59, 0xf7, 0x00, 0x44, 0x2b, 0x92, 0x21, 0xce, 0xba, 0x37,
		0x14, 0xca, 0xd9, 0xc1, 0x59, 0xf7, 0x1a, 0x55, 0x1d, 0xce, 0xba, 0x7f, 0x21, 0x64, 0x8a, 0xb3,
		0xee, 0xcd, 0x9a, 0x8a, 0x3b, 0x38, 0xeb, 0x7e, 0x07, 0x67, 0xdd, 0x6b, 0x7c, 0x3e, 0xce, 0xba,
		0x4f, 0x2c, 0xf9, 0x31, 0xf4, 0x9e, 0xf4, 0xa6, 0x18, 0x7a, 0xc7, 0xd0, 0x7b, 0x22, 0xaa, 0xc3,
		0x59, 0xf7, 0x6f, 0xb9, 0xe2, 0x20, 0x6d, 0xb5, 0x8a, 0xa1, 0x4a, 0x83, 0x14, 0x85, 0x29, 0x0a,
		0x25, 0x06, 0xef, 0x0c, 0x92, 0xc3, 0x58, 0x30, 0xaa, 0xe2, 0x98, 0x0b, 0x4d, 0xc6, 0xc5, 0xb1,
		0x10, 0x6a, 0x88, 0xec, 0xc2, 0x39, 0x0b, 0xea, 0x1e, 0x1d, 0x8b, 0x38, 0xae, 0xa6, 0xd1, 0x0a,
		0xe7, 0xe4, 0x6e, 0xe5, 0x0e, 0xa5, 0xc3, 0x6a, 0xb5, 0x76, 0x50, 0xad, 0xee, 0x1d, 0x54, 0x0e,
		0xf6, 0x8e, 0xf6, 0xf7, 0x4b, 0x35, 0x15, 0x47, 0xab, 0xd0, 0x8a, 0x5d, 0x1a, 0x53, 0xf7, 0xf3,
		0x78, 0x5b, 0x82, 0x91, 0xe7, 0x19, 0xdd, 0xfd, 0x94, 0x4c, 0x68, 0x94, 0xf9, 0x0a, 0x4a, 0xa5,
		0x2d, 0x06, 0xd8, 0x4d, 0x8e, 0xd1, 0x92, 0xb3, 0x4b, 0xb2, 0x6f, 0x26, 0x3c, 0x52, 0xd5, 0xa3,
		0x34, 0x71, 0x84, 0x12, 0x27, 0xa7, 0xf7, 0xc4, 0x92, 0x9d, 0xd4, 0xeb, 0xfb, 0x9e, 0x60, 0xcf,
		0xe7, 0x66, 0x5c, 0xd2, 0xbd, 0x5e, 0x18, 0x0c, 0x52, 0xe6, 0x9f, 0xa4, 0xe1, 0x2e, 0x6d, 0xa0,
		0xab, 0x18, 0xe2, 0xa9, 0x0c, 0x6e, 0x55, 0xc3, 0x3a, 0xb5, 0x01, 0x9d, 0xda, 0x50, 0x4e, 0x6b,
		0x10, 0xeb, 0xe5, 0x76, 0x69, 0x43, 0x36, 0x45, 0x9d, 0xb9, 0x4a, 0x1d, 0xf9, 0x33, 0x53, 0x5e,
		0x66, 0xc7, 0x96, 0x21, 0x8b, 0xca, 0x15, 0x3a, 0x2a, 0x15, 0x36, 0x4a, 0x16, 0x32, 0x4a, 0x17,
		0x2e, 0x22, 0x83, 0x5a, 0xca, 0xa0, 0xb2, 0x85, 0x82, 0x05, 0x97, 0x72, 0x27, 0x66, 0x91, 0x92,
		0x2d, 0xb6, 0x38, 0xf1, 0xd5, 0x9b, 0xc8, 0x1a, 0xe2, 0x4a, 0x21, 0x22, 0xe5, 0x90, 0x50, 0x9a,
		0x10, 0x90, 0x96, 0x90, 0x4f, 0xda, 0x10, 0x8f, 0xb6, 0x90, 0x8e, 0xb6, 0x10, 0x8e, 0xae, 0x90,
		0x8d, 0x59, 0x87, 0x4f, 0x39, 0x04, 0x93, 0xbe, 0xa8, 0x4e, 0xb1, 0x88, 0x4e, 0xc2, 0xa2, 0x97,
		0x90, 0xb3, 0x91, 0x1a, 0xfd, 0xab, 0xd9, 0x91, 0xc8, 0xe5, 0xc8, 0xe5, 0x96, 0x71, 0x39, 0x8b,
		0x8a, 0xca, 0x1b, 0x9e, 0x06, 0x85, 0x9b, 0x0e, 0x6d, 0xab, 0xa1, 0x9d, 0xc4, 0x04, 0x3d, 0x9b,
		0x3a, 0x49, 0xa0, 0x03, 0xd7, 0xa6, 0x0d, 0xbf, 0x96, 0x29, 0xe8, 0x75, 0x77, 0xf6, 0xb0, 0x0f,
		0xbf, 0xdf, 0xff, 0x28, 0x15, 0xcb, 0x57, 0xf3, 0x3f, 0x2a, 0x3f, 0xf6, 0x8a, 0xe5, 0xab, 0x34,
		0xc8, 0xad, 0xab, 0x34, 0x5b, 0xa9, 0x13, 0x89, 0x95, 0x2d, 0x98, 0xf5, 0xb5, 0x0d, 0x4d, 0x81,
		0x41, 0xba, 0xca, 0x32, 0xe5, 0xa0, 0x87, 0x37, 0x6b, 0x6f, 0x93, 0x37, 0x11, 0xbc, 0x97, 0x3d,
		0x78, 0x6f, 0xf7, 0x7d, 0x69, 0xcc, 0x6f, 0x87, 0x53, 0x16, 0x2c, 0x5d, 0xad, 0x71, 0xe6, 0x94,
		0xd3, 0xde, 0x90, 0xc0, 0x42, 0x2a, 0x03, 0x4b, 0x65, 0xd9, 0x4b, 0xf1, 0x77, 0x66, 0x9f, 0x63,
		0xc6, 0x6d, 0xe3, 0x54, 0x14, 0x05, 0x19, 0xa8, 0xfb, 0x6d, 0xf3, 0x1b, 0xa0, 0xe3, 0x86, 0x8e,
		0xdb, 0x9b, 0x74, 0xdc, 0x04, 0x19, 0x14, 0xc5, 0xf8, 0x2e, 0x5b, 0xe6, 0xb7, 0xa5, 0xee, 0x7a,
		0xa2, 0xa1, 0xdb, 0x89, 0xa6, 0x2e, 0x27, 0x1a, 0xf0, 0x51, 0x3a, 0xbb, 0x9a, 0xe8, 0xee, 0x62,
		0xae, 0xb9, 0x8b, 0x89, 0x89, 0x4e, 0x18, 0x3a, 0xba, 0xd5, 0xeb, 0xec, 0x56, 0x62, 0xea, 0x08,
		0x74, 0x77, 0x27, 0x31, 0x72, 0x16, 0x39, 0xe1, 0xf1, 0x6c, 0x73, 0x8e, 0x87, 0xf4, 0xae, 0x98,
		0xba, 0xe1, 0x1d, 0x30, 0xdf, 0x78, 0xd5, 0xac, 0x7e, 0x6a, 0xad, 0x97, 0x1f, 0x3e, 0xfc, 0xf7,
		0x87, 0x7f, 0x6d, 0xb1, 0xd9, 0xfc, 0xc6, 0xf0, 0x4b, 0xb2, 0x60, 0x4f, 0x3d, 0xd8, 0x25, 0x09,
		0x2c, 0x67, 0x02, 0x54, 0xc4, 0xbb, 0x14, 0x47, 0x31, 0xc7, 0x62, 0x26, 0x32, 0x97, 0xe5, 0xc0,
		0x97, 0xf2, 0x60, 0x4b, 0x2d, 0xe0, 0x4a, 0x39, 0x30, 0xe5, 0x6b, 0xdb, 0x23, 0x49, 0xa1, 0xfa,
		0x28, 0xb3, 0x90, 0x08, 0xeb, 0x92, 0x9e, 0x16, 0x5f, 0xa6, 0xc2, 0xcd, 0xb4, 0xf5, 0xfc, 0xbf,
		0x6c, 0xd8, 0xce, 0xa4, 0xdb, 0xa8, 0x61, 0xfb, 0x5e, 0xd8, 0xb7, 0x74, 0xfb, 0xf5, 0xfc, 0x46,
		0xad, 0x6f, 0xc3, 0xe3, 0x4f, 0x9e, 0x6c, 0xc8, 0x6b, 0x1b, 0xa1, 0xb4, 0x01, 0xcf, 0xbc, 0xb2,
		0xf4, 0xab, 0x3e, 0x7e, 0xbb, 0xe5, 0x3b, 0xac, 0xac, 0xbf, 0xe0, 0x53, 0xce, 0xc9, 0x60, 0x52,
		0x2c, 0xf9, 0x78, 0xe5, 0x2b, 0x4d, 0x5a, 0x67, 0xdf, 0x78, 0xf2, 0xd6, 0xcf, 0x03, 0xa6, 0x36,
		0x06, 0x2a, 0x5e, 0x0a, 0x44, 0xac, 0x06, 0x1a, 0x36, 0x3c, 0x2e, 0x49, 0x28, 0x21, 0x71, 0xa8,
		0x20, 0x71, 0x28, 0xe0, 0xa9, 0xab, 0xbf, 0x58, 0x9c, 0x24, 0x85, 0x6c, 0x02, 0x11, 0x15, 0x9c,
		0xf9, 0x6e, 0x6d, 0x78, 0xa3, 0xf9, 0xc6, 0xbc, 0x38, 0xf1, 0xf5, 0x15, 0xec, 0xda, 0xab, 0xb1,
		0xa3, 0x24, 0x31, 0xa2, 0x84, 0x47, 0x24, 0x1b, 0xf5, 0x91, 0x8e, 0xee, 0x48, 0x47, 0x71, 0x92,
		0x1f, 0xa1, 0x9a, 0x14, 0x7c, 0x0d, 0x1f, 0x56, 0xe0, 0xf4, 0x86, 0xc6, 0x4c, 0xdc, 0xbf, 0xbe,
		0x17, 0xcb, 0xc8, 0xe2, 0xec, 0x8a, 0xd7, 0xd4, 0x7c, 0x22, 0x57, 0x2e, 0x71, 0xe8, 0x50, 0x26,
		0x54, 0x28, 0x49, 0x0e, 0xaa, 0xc1, 0x40, 0xe5, 0xe0, 0x9f, 0x72, 0xb0, 0x4f, 0x9e, 0x5c, 0xf4,
		0x98, 0x6c, 0x89, 0xc3, 0x75, 0x4b, 0x2a, 0xb9, 0xe7, 0x5e, 0x38, 0x28, 0x26, 0x24, 0x96, 0x47,
		0x72, 0xa2, 0x9a, 0xe0, 0xbb, 0xf5, 0x60, 0xe4, 0x8f, 0x17, 0xf4, 0x60, 0x89, 0x2d, 0x31, 0x3f,
		0xa8, 0xdd, 0xc5, 0x2f, 0xaf, 0x4e, 0xc9, 0xde, 0xa8, 0x50, 0xcf, 0x67, 0xb7, 0xb8, 0x5e, 0xfc,
		0xf2, 0xd2, 0x10, 0xeb, 0x67, 0xcc, 0x85, 0x67, 0x74, 0x97, 0x4b, 0x7b, 0xa3, 0x41, 0x91, 0x06,
		0x22, 0x66, 0xcf, 0x68, 0xdb, 0xb5, 0xd3, 0x7d, 0xfc, 0x75, 0x94, 0xfb, 0xf6, 0xc9, 0xfd, 0xe9,
		0x09, 0x72, 0x1a, 0xdf, 0xb0, 0x24, 0x1b, 0xf2, 0xf8, 0xe0, 0xe7, 0x97, 0x25, 0xd3, 0x00, 0x25,
		0xd4, 0x00, 0xf6, 0x6b, 0x80, 0xa4, 0x40, 0xf3, 0xd7, 0x6c, 0x46, 0x35, 0x1b, 0x52, 0x91, 0xb4,
		0xa4, 0x49, 0x4c, 0x85, 0xd4, 0x52, 0x92, 0x9c, 0x2a, 0xe9, 0xa5, 0x26, 0xc1, 0xd4, 0xa4, 0x98,
		0x9e, 0x24, 0xcd, 0x84, 0xf8, 0xa4, 0x6b, 0x22, 0x68, 0x40, 0x7a, 0x1e, 0x75, 0xd5, 0x93, 0xed,
		0xf3, 0x1b, 0x48, 0xee, 0x5b, 0xca, 0xf6, 0x1b, 0xb6, 0x26, 0xeb, 0x15, 0x98, 0x23, 0x2d, 0x93,
		0x68, 0x63, 0x16, 0x6d, 0x4c, 0xa3, 0x8f, 0x79, 0xd4, 0x22, 0xf6, 0xd9, 0x27, 0xec, 0xd5, 0x5b,
		0x58, 0x28, 0xb6, 0xac, 0x30, 0x85, 0xcc, 0x49, 0x66, 0x32, 0xbd, 0xe0, 0x3f, 0x27, 0x31, 0x9e,
		0x90, 0xd9, 0x91, 0xd9, 0x2d, 0x66, 0x76, 0x36, 0xeb, 0xd7, 0xa7, 0x36, 0x41, 0x35, 0x4d, 0x0b,
		0x41, 0x3d, 0xad, 0x02, 0x97, 0x4d, 0xde, 0xea, 0x9f, 0xbf, 0x7e, 0xb9, 0xee, 0xd4, 0x2f, 0xbf,
		0x35, 0x4e, 0xea, 0xc6, 0xcf, 0xe9, 0xcd, 0x24, 0x45, 0xd7, 0xe3, 0x1d, 0x8f, 0x42, 0x06, 0xbb,
		0x8f, 0xfc, 0xc8, 0x5d, 0x29, 0xdb, 0x5f, 0x32, 0x36, 0x72, 0x3a, 0x7e, 0x52, 0x7d, 0xfa, 0xd8,
		0xe9, 0x1f, 0x9d, 0xe9, 0x53, 0x5f, 0x8c, 0x9a, 0xc8, 0xef, 0x77, 0xa2, 0x4a, 0x71, 0x49, 0xdd,
		0xa1, 0xa8, 0x33, 0xa0, 0xb7, 0x73, 0x40, 0xef, 0x28, 0x47, 0xef, 0xc8, 0xc2, 0x96, 0x0e, 0x73,
		0xea, 0xc7, 0x9e, 0x0e, 0x59, 0xf6, 0x74, 0x40, 0x2e, 0xc5, 0x18, 0x06, 0xc6, 0x30, 0xd0, 0xad,
		0x41, 0xb7, 0x06, 0x63, 0x18, 0x18, 0xc3, 0x40, 0x66, 0xc7, 0x18, 0x06, 0xc6, 0x30, 0x30, 0x86,
		0xb1, 0x31, 0x86, 0xa1, 0x0d, 0xd6, 0x2d, 0x13, 0xc2, 0x80, 0x87, 0xea, 0x4e, 0x08, 0x0d, 0x40,
		0x58, 0x77, 0x46, 0x74, 0x99, 0x06, 0xd4, 0x2d, 0x41, 0x89, 0x05, 0x6b, 0x71, 0x58, 0x49, 0xa0,
		0x4c, 0x29, 0x76, 0x29, 0x0d, 0x28, 0xeb, 0xe5, 0x20, 0x44, 0xa2, 0xa0, 0x43, 0x62, 0x10, 0x56,
		0x19, 0x41, 0x58, 0xd9, 0x83, 0xb0, 0x66, 0x0f, 0x4c, 0x0e, 0xbf, 0x9a, 0x5f, 0xa0, 0x19, 0x78,
		0x55, 0x46, 0xe0, 0x95, 0x41, 0xbb, 0x37, 0x23, 0xe0, 0x15, 0x89, 0xa2, 0xe2, 0x4c, 0x3a, 0x49,
		0x46, 0x2d, 0x17, 0x57, 0x62, 0x7a, 0x01, 0x03, 0x97, 0xb9, 0xa5, 0x17, 0xa4, 0x6b, 0x7a, 0x25,
		0xfb, 0x6c, 0xea, 0x49, 0x0c, 0xf8, 0x5c, 0x01, 0xdb, 0x38, 0xbe, 0x08, 0x79, 0x0b, 0x79, 0x0b,
		0x79, 0xeb, 0x35, 0xde, 0x62, 0xae, 0x12, 0x77, 0x31, 0x17, 0xf9, 0x0b, 0xf9, 0x0b, 0xf9, 0xeb,
		0xe5, 0x67, 0x46, 0x31, 0x0b, 0x13, 0xd5, 0xfa, 0xad, 0xbd, 0xdf, 0xe2, 0x4a, 0xe4, 0x32, 0xe4,
		0xb2, 0xdc, 0xb8, 0x6c, 0xc4, 0x02, 0x71, 0xa8, 0xc0, 0x64, 0x12, 0x11, 0x78, 0xc5, 0xce, 0x56,
		0x6a, 0x73, 0xc1, 0x52, 0x64, 0x85, 0x52, 0xb5, 0x49, 0x4a, 0xdb, 0x99, 0x4a, 0x47, 0xf7, 0xa3,
		0x07, 0xb5, 0x41, 0x68, 0xb9, 0x6f, 0x59, 0x79, 0x7f, 0x3f, 0xc7, 0x4d, 0x33, 0x94, 0x89, 0xb9,
		0xca, 0x54, 0x09, 0x85, 0x8e, 0x8a, 0x95, 0x37, 0xbb, 0x0e, 0x15, 0x10, 0x2a, 0xa0, 0x6d, 0x36,
		0xf3, 0x52, 0xc5, 0x12, 0xeb, 0x77, 0x22, 0xd9, 0xdc, 0x79, 0xf9, 0x20, 0x6c, 0xe8, 0x14, 0xe9,
		0x9d, 0xf8, 0x24, 0xa8, 0x47, 0x7d, 0x2a, 0xe2, 0xfb, 0x22, 0x11, 0xa1, 0x9f, 0xa8, 0xa7, 0xd0,
		0x33, 0x34, 0x36, 0x41, 0x92, 0x29, 0x84, 0x65, 0xd3, 0xc6, 0x62, 0xaf, 0x72, 0xcc, 0xe1, 0x4d,
		0xb2, 0x38, 0xbb, 0xc9, 0x02, 0xfc, 0x3b, 0x72, 0xf9, 0xa8, 0x49, 0x96, 0x78, 0xfe, 0xa7, 0x72,
		0xa6, 0xee, 0x0f, 0x6c, 0x22, 0x82, 0x99, 0x8c, 0x34, 0xd2, 0x07, 0x9b, 0x88, 0x68, 0x4f, 0x5e,
		0xbf, 0x06, 0x3a, 0x91, 0x15, 0x12, 0x79, 0x77, 0x1c, 0x5b, 0x7b, 0x43, 0x99, 0x46, 0x63, 0x6b,
		0xef, 0x94, 0xa4, 0xc3, 0x58, 0x40, 0xc5, 0x6d, 0x18, 0xff, 0x2a, 0xb2, 0x80, 0x0b, 0x12, 0x38,
		0x2f, 0xb5, 0x1a, 0x5b, 0xff, 0x6a, 0x36, 0x3d, 0xc7, 0x02, 0x2a, 0xc6, 0x8f, 0x04, 0xd9, 0x72,
		0x6c, 0xbe, 0x36, 0x5d, 0x1d, 0xc7, 0x9e, 0xee, 0xf1, 0xeb, 0xe8, 0x87, 0xb5, 0x2b, 0x60, 0x74,
		0xa3, 0xd9, 0x7c, 0x68, 0xb2, 0x8a, 0x22, 0x7b, 0x1c, 0xc4, 0xc6, 0x43, 0x55, 0x13, 0x7c, 0xaf,
		0xc2, 0x20, 0x48, 0x5f, 0xf0, 0xe4, 0xa6, 0xc3, 0xe4, 0xdb, 0x76, 0x00, 0x20, 0x48, 0x5f, 0xbc,
		0x49, 0x8b, 0x61, 0xfc, 0x5e, 0x50, 0x60, 0x0f, 0x54, 0x0c, 0x69, 0x1c, 0x50, 0x21, 0x1f, 0x51,
		0x58, 0x5c, 0xf9, 0x36, 0x7a, 0xce, 0x24, 0x23, 0xb6, 0xb7, 0x17, 0x4e, 0x48, 0x44, 0x8c, 0x66,
		0x22, 0x09, 0xd2, 0x55, 0x5a, 0x3e, 0x71, 0x26, 0x50, 0xc3, 0x7b, 0xf5, 0xd2, 0x8b, 0xe5, 0x2d,
		0xd4, 0x8a, 0x2f, 0x4a, 0x96, 0x15, 0x5f, 0xc8, 0x91, 0x75, 0x5a, 0xf2, 0xd6, 0x46, 0xe6, 0xda,
		0xc8, 0x5d, 0x0b, 0xd9, 0x2b, 0x06, 0x90, 0x65, 0x6b, 0x01, 0x25, 0xd9, 0xe1, 0x11, 0x5b, 0x10,
		0xd7, 0x8d, 0x29, 0xe7, 0xe9, 0xab, 0x1d, 0x56, 0x6f, 0xf6, 0x47, 0x2e, 0xb9, 0x02, 0x55, 0x96,
		0xd1, 0xc1, 0x3a, 0xfa, 0x58, 0x48, 0x17, 0x2b, 0x69, 0x67, 0x29, 0xed, 0xac, 0xa5, 0x95, 0xc5,
		0xd4, 0x58, 0x4d, 0x91, 0xe5, 0xd4, 0x63, 0xda, 0x1b, 0xe9, 0x45, 0xbe, 0xca, 0x7f, 0xa3, 0xa6,
		0x39, 0x48, 0x37, 0x5b, 0x63, 0xde, 0x05, 0x60, 0x16, 0x19, 0x5d, 0x61, 0xeb, 0x8c, 0x26, 0x5a,
		0xa8, 0xe4, 0x28, 0xe5, 0x1a, 0x07, 0xbc, 0x90, 0x69, 0x90, 0xab, 0x26, 0xd2, 0xa0, 0xe9, 0xa5,
		0xbd, 0x22, 0x14, 0x5f, 0x28, 0xbe, 0x34, 0x89, 0x2f, 0x55, 0xcb, 0x41, 0xab, 0x05, 0x61, 0xc0,
		0x92, 0xd0, 0x64, 0x51, 0x68, 0xb3, 0x2c, 0x74, 0xb2, 0xa8, 0x7e, 0x56, 0xd5, 0xcd, 0xb2, 0xc6,
		0x58, 0xd7, 0x18, 0x0b, 0x1b, 0x61, 0xe5, 0x74, 0x2c, 0x9d, 0x92, 0xb5, 0xf5, 0x59, 0x28, 0x06,
		0xd9, 0x73, 0x47, 0xd3, 0x44, 0xb0, 0x55, 0xeb, 0x45, 0xcb, 0x64, 0xb0, 0xc5, 0x0d, 0x5f, 0x19,
		0x10, 0xf6, 0xcf, 0xfe, 0x43, 0x7a, 0xfa, 0xb8, 0xd2, 0xf1, 0xe2, 0x3a, 0xc7, 0x39, 0x2f, 0xee,
		0xfa, 0xbf, 0xaf, 0xbf, 0xfe, 0x7f, 0x69, 0x78, 0xff, 0x9c, 0x06, 0xf0, 0xa5, 0xe0, 0xac, 0x42,
		0x40, 0xef, 0x44, 0x71, 0x18, 0x46, 0xc5, 0x41, 0x1c, 0x8e, 0x22, 0x7d, 0xaa, 0xef, 0xc9, 0x7d,
		0x51, 0xfb, 0xa1, 0xf6, 0x43, 0xed, 0x07, 0x4a, 0xfb, 0xa5, 0xf7, 0xd3, 0x75, 0xfa, 0xeb, 0xcf,
		0xf9, 0xed, 0x8b, 0xff, 0x3d, 0x16, 0x26, 0xfc, 0xc9, 0xdf, 0x33, 0xff, 0x9e, 0xb9, 0x05, 0x0b,
		0xe5, 0x6f, 0xe8, 0x08, 0x2a, 0x78, 0xb1, 0x1f, 0xc6, 0xb7, 0x24, 0x76, 0x15, 0xfa, 0xaf, 0xbd,
		0x20, 0x4f, 0x9e, 0xdc, 0x19, 0x65, 0x30, 0xca, 0x60, 0x94, 0xc1, 0xa0, 0x64, 0xb0, 0x13, 0x8e,
		0x02, 0x41, 0xe3, 0x5a, 0x55, 0xa3, 0x14, 0xd6, 0xe1, 0x7e, 0xe8, 0x19, 0xcf, 0x3e, 0xff, 0x4f,
		0x0f, 0x0b, 0xec, 0xe8, 0x1e, 0xd7, 0xae, 0x59, 0xb2, 0xad, 0xdd, 0x56, 0xf3, 0xf8, 0xf6, 0xc5,
		0x7d, 0x0d, 0x8c, 0x0e, 0xd7, 0xc4, 0x21, 0x8f, 0x8f, 0x4a, 0xe3, 0x58, 0xf7, 0xac, 0x8e, 0x4a,
		0xad, 0xcf, 0x13, 0x98, 0xd3, 0x7b, 0x07, 0xe3, 0x2e, 0x36, 0xfa, 0xc1, 0x11, 0x71, 0x7e, 0x19,
		0x32, 0xc4, 0xd6, 0x6f, 0x8d, 0x96, 0x18, 0x5a, 0x62, 0x68, 0x89, 0xa1, 0x25, 0x86, 0x96, 0x18,
		0x5a, 0x62, 0x68, 0x89, 0xa1, 0x25, 0xf6, 0xf6, 0x2c, 0xb1, 0x4c, 0x93, 0xff, 0x8a, 0x9d, 0x7b,
		0xd7, 0xee, 0xb3, 0xb9, 0xac, 0xe8, 0x69, 0x8d, 0xc8, 0xee, 0x5a, 0x29, 0xcf, 0xda, 0x27, 0xbb,
		0xa4, 0x2f, 0xf8, 0xee, 0x1c, 0x22, 0xbe, 0xbb, 0x40, 0xdd, 0xee, 0xa6, 0x41, 0xe6, 0xec, 0xbc,
		0x54, 0xbe, 0x74, 0x31, 0x5d, 0x41, 0x63, 0xb6, 0x80, 0xeb, 0x27, 0x7f, 0xf3, 0xa7, 0x1f, 0x5c,
		0x1f, 0xf7, 0x05, 0xbf, 0xae, 0xcf, 0x56, 0x78, 0x7d, 0x4e, 0x9c, 0xfa, 0x78, 0x81, 0x32, 0x3d,
		0x81, 0xd3, 0x9f, 0xbb, 0x59, 0x40, 0xe9, 0xac, 0xa7, 0xb0, 0x7a, 0xa2, 0x57, 0xae, 0xcf, 0xf0,
		0x73, 0x4a, 0x52, 0xae, 0xef, 0xf0, 0x73, 0xb2, 0x3b, 0x75, 0x1f, 0xe2, 0xb5, 0x9b, 0x4a, 0xf5,
		0x25, 0x4e, 0x7b, 0x06, 0x29, 0xb9, 0x33, 0x1b, 0xae, 0x2c, 0x28, 0x21, 0xf5, 0x8c, 0xf2, 0x61,
		0x61, 0x4b, 0xbb, 0xa6, 0xa7, 0x3e, 0x55, 0x1d, 0x3d, 0xd4, 0xd3, 0x9d, 0x61, 0x96, 0x83, 0xa6,
		0x58, 0x74, 0x53, 0x2d, 0x8e, 0x02, 0xe6, 0x10, 0xae, 0x50, 0xc2, 0xf4, 0xe8, 0x6a, 0x2c, 0x63,
		0xca, 0x30, 0x0c, 0xb0, 0xd5, 0x65, 0x4c, 0x13, 0xb2, 0x4b, 0x59, 0xc7, 0xb4, 0x72, 0x0f, 0x2c,
		0x64, 0x32, 0x17, 0xff, 0xc2, 0x42, 0xa6, 0x2c, 0x0b, 0x99, 0xa2, 0x74, 0xa1, 0xd4, 0x95, 0x66,
		0x57, 0x69, 0x4e, 0x0a, 0xcb, 0x97, 0x0c, 0x04, 0x90, 0x11, 0xff, 0x6f, 0x30, 0x04, 0xf0, 0xf6,
		0xcb, 0x97, 0x66, 0x24, 0x83, 0x95, 0x4b, 0x06, 0x54, 0xfb, 0xba, 0xe4, 0xc2, 0xca, 0x25, 0x94,
		0x5c, 0xd9, 0x48, 0xae, 0xd4, 0x95, 0x4b, 0x2e, 0x75, 0x48, 0xc4, 0x47, 0x1e, 0x11, 0xb4, 0x38,
		0xa4, 0xc4, 0xa5, 0xb1, 0xbe, 0xd4, 0xf5, 0x33, 0xf7, 0xc6, 0xdc, 0xb5, 0x79, 0xc6, 0xd5, 0xcd,
		0xc0, 0xc6, 0x18, 0xd9, 0x18, 0x43, 0x1b, 0x61, 0xec, 0x74, 0x0c, 0x9e, 0x92, 0xd1, 0xf5, 0x99,
		0x2a, 0x6b, 0xf4, 0x46, 0x83, 0x39, 0x97, 0xb2, 0x30, 0x98, 0xf1, 0x69, 0x51, 0x8c, 0x1f, 0xa3,
		0x11, 0xdb, 0x5d, 0xd5, 0x70, 0xaf, 0x64, 0xfd, 0xf2, 0xcc, 0x1d, 0x1f, 0x16, 0xca, 0xa0, 0x78,
		0x45, 0xf1, 0x8a, 0xe2, 0x35, 0x6b, 0x8f, 0x50, 0xa7, 0x67, 0xf8, 0x9c, 0x87, 0x88, 0x85, 0x32,
		0xe9, 0xe4, 0x09, 0x16, 0xca, 0xa0, 0x0c, 0x46, 0x19, 0x0c, 0x59, 0x06, 0x23, 0x3c, 0x53, 0x72,
		0x61, 0x08, 0xcf, 0x44, 0x78, 0x26, 0xc2, 0x33, 0x8d, 0x48, 0x47, 0x7d, 0x77, 0xb1, 0xb1, 0x50,
		0x26, 0x8c, 0xd9, 0x80, 0x05, 0xc5, 0x28, 0x0e, 0x45, 0xe8, 0x84, 0x9e, 0x46, 0x33, 0xec, 0xc9,
		0x8d, 0xd1, 0x0a, 0x43, 0x2b, 0x0c, 0xad, 0x30, 0x50, 0x56, 0x18, 0x73, 0x69, 0x20, 0x98, 0xb8,
		0xd7, 0xec, 0x0d, 0x6b, 0xd0, 0x1c, 0x85, 0xc6, 0x6c, 0x69, 0x9f, 0x09, 0xd7, 0x48, 0xc6, 0xf3,
		0x17, 0x6f, 0x5c, 0x74, 0xba, 0xc7, 0xcd, 0xe6, 0x75, 0xfb, 0xb2, 0xd5, 0x6d, 0x9d, 0xb4, 0x9a,
		0xd7, 0xdd, 0xff, 0xb4, 0xeb, 0xba, 0x48, 0x7a, 0xa2, 0x53, 0xb9, 0x36, 0x23, 0x52, 0xaf, 0x21,
		0xf9, 0x68, 0x1b, 0x4e, 0x1b, 0x97, 0xf5, 0x93, 0x6e, 0xf3, 0x3f, 0xd7, 0x27, 0xad, 0x8b, 0x8b,
		0xfa, 0x49, 0xb7, 0x7e, 0x5a, 0x80, 0x68, 0x51, 0x19, 0x7a, 0xfb, 0xcf, 0x5f, 0xda, 0xdb, 0xf4,
		0xba, 0x8d, 0x2f, 0xe7, 0x5b, 0xf5, 0xbe, 0xed, 0xc6, 0xf9, 0x36, 0xbd, 0x6e, 0xa7, 0x7b, 0xdc,
		0x6d, 0x9c, 0x6c, 0xd3, 0x1b, 0xb7, 0x3a, 0xed, 0xb3, 0x6d, 0x7b, 0xdf, 0xca, 0x56, 0x49, 0xac,
		0x4e, 0xa3, 0xb3, 0x4d, 0xef, 0xdb, 0x6c, 0x9d, 0x1c, 0x37, 0xaf, 0x8f, 0xbf, 0x7c, 0xb9, 0xac,
		0x7f, 0x39, 0xee, 0xd6, 0x0b, 0xc0, 0xfc, 0xe3, 0xab, 0xbc, 0xed, 0x67, 0x6c, 0x24, 0x81, 0x3e,
		0x32, 0xfa, 0xc8, 0xe8, 0x23, 0x67, 0xea, 0x23, 0x63, 0xa6, 0x42, 0x72, 0x61, 0x98, 0xa9, 0xc0,
		0x4c, 0x05, 0x66, 0x2a, 0x8c, 0x5a, 0x62, 0x5b, 0xda, 0xd2, 0x4b, 0x8f, 0x35, 0xa1, 0xa7, 0xa6,
		0x0a, 0x6d, 0x2e, 0xb4, 0xb9, 0xd0, 0xe6, 0x32, 0x64, 0x73, 0x4d, 0x4a, 0x81, 0xb5, 0x9d, 0x27,
		0xec, 0x41, 0x0e, 0xef, 0xdf, 0xff, 0xd8, 0x2b, 0x1e, 0x5d, 0xfd, 0xfe, 0x51, 0x2a, 0x1e, 0x5d,
		0x4d, 0x7f, 0x2d, 0x4d, 0x7e, 0x4c, 0x7f, 0x2f, 0xff, 0xd8, 0x2b, 0x56, 0xe7, 0xbf, 0xef, 0xff,
		0xd8, 0x2b, 0xee, 0x5f, 0x7d, 0xf8, 0xf9, 0xf3, 0xe3, 0x87, 0x7f, 0x2a, 0x0f, 0xf2, 0x17, 0xee,
		0xce, 0x1e, 0xf6, 0xe1, 0xf7, 0xfb, 0x1f, 0xa5, 0x62, 0xf9, 0x6a, 0xfe, 0x47, 0xe5, 0xc7, 0x5e,
		0xb1, 0x7c, 0xf5, 0xe1, 0xc3, 0x9b, 0x1e, 0x19, 0x01, 0x69, 0xa3, 0x6d, 0x1e, 0x4e, 0x81, 0xad,
		0xa0, 0xa6, 0xed, 0x49, 0x56, 0x5b, 0x6d, 0xec, 0x2e, 0x9b, 0x17, 0x40, 0xeb, 0x07, 0xd5, 0x88,
		0x6e, 0xaa, 0x5f, 0xa7, 0xab, 0x9c, 0xfc, 0xfe, 0x56, 0x7b, 0x42, 0xa9, 0x35, 0xed, 0xc0, 0x76,
		0x50, 0x69, 0xb7, 0x1f, 0x60, 0x3b, 0xa8, 0x0d, 0x9c, 0x99, 0x7f, 0x4f, 0xa8, 0x67, 0x79, 0x11,
		0xfb, 0x42, 0xa5, 0x38, 0xde, 0xfc, 0x7a, 0x43, 0xad, 0x9c, 0x65, 0xc6, 0xed, 0xa1, 0x6a, 0xa9,
		0xda, 0x43, 0xd5, 0xb0, 0x3d, 0x14, 0xb6, 0x87, 0x4a, 0x27, 0x0b, 0x54, 0xda, 0x43, 0xd5, 0x34,
		0xb4, 0x87, 0xaa, 0x61, 0x7b, 0x28, 0xe3, 0x11, 0x16, 0x6c, 0x0f, 0x85, 0xed, 0xa1, 0x32, 0x0e,
		0x5d, 0x62, 0x93, 0x95, 0x7c, 0x42, 0x92, 0xd8, 0x1e, 0x0a, 0xdb, 0x43, 0xa9, 0x9f, 0x03, 0xb6,
		0x87, 0x42, 0xc9, 0x85, 0x92, 0x4b, 0x7a, 0xe5, 0xd8, 0x1e, 0x2a, 0x0f, 0x13, 0x43, 0x27, 0xc3,
		0xea, 0x67, 0x5c, 0xdd, 0x0c, 0x6c, 0x8c, 0x91, 0x8d, 0x31, 0xb4, 0x11, 0xc6, 0x4e, 0xc7, 0xe0,
		0x29, 0x19, 0x5d, 0x9f, 0xa9, 0xb2, 0x46, 0x6f, 0xd8, 0x1e, 0xca, 0xfc, 0xd1, 0x61, 0x7b, 0x28,
		0x14, 0xaf, 0x28, 0x5e, 0xb7, 0x52, 0xbc, 0x62, 0x7b, 0x28, 0x08, 0xf2, 0x17, 0xdb, 0x43, 0xa1,
		0x0c, 0x46, 0x19, 0xbc, 0xad, 0x32, 0x18, 0x8b, 0x2e, 0x24, 0x17, 0x86, 0x45, 0x17, 0x58, 0x74,
		0x81, 0x45, 0x17, 0x46, 0xa4, 0xa3, 0xbe, 0xbb, 0x60, 0x7b, 0x28, 0x6c, 0x0f, 0x85, 0x56, 0x18,
		0x5a, 0x61, 0xb6, 0x58, 0x61, 0xd8, 0x1e, 0x0a, 0xdb, 0x43, 0x61, 0x7b, 0xa8, 0x2d, 0x79, 0x5d,
		0x6c, 0x0f, 0xf5, 0xa6, 0x5f, 0x17, 0xdb, 0x43, 0x6d, 0xc3, 0xfb, 0x62, 0x7b, 0xa8, 0x37, 0xfc,
		0xbe, 0xd8, 0x1e, 0x0a, 0xa0, 0x7f, 0x8c, 0xed, 0xa1, 0xd0, 0x47, 0x46, 0x1f, 0x79, 0x7b, 0x7d,
		0x64, 0xcc, 0x54, 0x48, 0x2e, 0x0c, 0x33, 0x15, 0x98, 0xa9, 0xc0, 0x4c, 0x85, 0x51, 0x4b, 0x0c,
		0xdb, 0x43, 0x69, 0x31, 0xbf, 0xb0, 0x3d, 0x14, 0xda, 0x5c, 0x68, 0x73, 0xc1, 0x6c, 0x0f, 0x55,
		0xdb, 0xae, 0xf6, 0x50, 0xa4, 0xd8, 0x3f, 0x2e, 0x9e, 0x5d, 0xfd, 0x53, 0xfa, 0xa3, 0xfa, 0xf0,
		0xe9, 0xc3, 0x3f, 0x07, 0x0f, 0x4f, 0x3f, 0xfc, 0xfd, 0xdc, 0xd7, 0x4a, 0x7f, 0x1c, 0x3c, 0x7c,
		0xda, 0xf0, 0x2f, 0xb5, 0x87, 0x4f, 0x09, 0xef, 0xb1, 0xff, 0xf0, 0x7e, 0xed, 0xab, 0xe3, 0xcf,
		0xcb, 0x9b, 0x2e, 0xa8, 0x6e, 0xb8, 0xa0, 0xb2, 0xe9, 0x82, 0xca, 0x86, 0x0b, 0x36, 0x2e, 0xa9,
		0xbc, 0xe1, 0x82, 0xfd, 0x87, 0xdf, 0x6b, 0xdf, 0x7f, 0xff, 0xfc, 0x57, 0x6b, 0x0f, 0x1f, 0x7e,
		0x6f, 0xfa, 0xb7, 0x83, 0x87, 0xdf, 0x9f, 0x3e, 0x7c, 0xd8, 0x7d, 0x5f, 0x2a, 0xff, 0xd8, 0x2b,
		0x1e, 0x4e, 0xbb, 0x3d, 0x95, 0xae, 0xd6, 0x9a, 0x40, 0x4d, 0x9b, 0x3a, 0x6d, 0x41, 0xcf, 0x2c,
		0xa4, 0x3e, 0xb0, 0xd4, 0x87, 0x8d, 0xc4, 0x92, 0xea, 0x55, 0xd0, 0x8d, 0xc4, 0x6a, 0xab, 0xed,
		0x8a, 0x6a, 0x60, 0x1b, 0x89, 0xd5, 0x56, 0x9a, 0x17, 0xd5, 0xb0, 0x91, 0xd8, 0xea, 0xc5, 0xd8,
		0x48, 0x2c, 0xed, 0xf6, 0xc3, 0x6c, 0x24, 0xf6, 0x1c, 0x67, 0x82, 0x68, 0x24, 0xb6, 0xce, 0x8b,
		0xd8, 0x48, 0x2c, 0xc5, 0xf1, 0xe6, 0xda, 0x48, 0xac, 0x96, 0x43, 0x23, 0x31, 0x3f, 0xf2, 0xb8,
		0x7c, 0x03, 0xb1, 0xc9, 0x55, 0xd8, 0x38, 0x2c, 0xc3, 0x10, 0xc4, 0x56, 0x37, 0x0e, 0xf3, 0x48,
		0x8f, 0x7a, 0x69, 0x3b, 0x87, 0xad, 0xde, 0x04, 0x5b, 0x87, 0x99, 0x8b, 0xbe, 0x61, 0xeb, 0xb0,
		0x2c, 0x5b, 0x87, 0x4d, 0xa8, 0x3a, 0x7d, 0xfb, 0x9d, 0xe9, 0x6d, 0xb0, 0x71, 0x18, 0xb6, 0xdf,
		0xc9, 0x29, 0x48, 0x8d, 0x8d, 0xc3, 0xf4, 0x36, 0x0e, 0x9b, 0x32, 0x34, 0xf6, 0x0d, 0x33, 0xa0,
		0xd7, 0xd7, 0x05, 0x17, 0xf6, 0x0d, 0x43, 0xc1, 0x95, 0x8d, 0xe0, 0x4a, 0xdd, 0x37, 0x2c, 0x9d,
		0xbd, 0xa0, 0xd5, 0x6e, 0xd0, 0x64, 0x3f, 0x68, 0xb3, 0x23, 0x74, 0xb2, 0xa5, 0x7e, 0xf6, 0xd4,
		0xcd, 0xa6, 0xc6, 0xd8, 0xd5, 0x18, 0xdb, 0x1a, 0x61, 0xdf, 0x74, 0x6c, 0x9c, 0x92, 0x9d, 0xf5,
		0xd9, 0x23, 0xcf, 0x46, 0x68, 0x8a, 0x3a, 0xb8, 0xf3, 0x91, 0xa2, 0x3c, 0xd2, 0x70, 0xaf, 0xd9,
		0xbb, 0x82, 0x43, 0x24, 0xce, 0x77, 0x6e, 0xc4, 0x02, 0x51, 0x29, 0x17, 0x34, 0x02, 0xe8, 0x66,
		0xbb, 0x77, 0xa0, 0xf1, 0x96, 0x7a, 0x71, 0x9d, 0xfa, 0x77, 0x73, 0xb1, 0x50, 0x13, 0x38, 0x4f,
		0xcd, 0x8a, 0x63, 0xe3, 0xed, 0x17, 0x60, 0xc2, 0x9a, 0xa1, 0x07, 0x18, 0x84, 0x10, 0x6a, 0x92,
		0x4c, 0xcf, 0x9f, 0xa9, 0x01, 0x40, 0x68, 0xe6, 0x67, 0xba, 0x57, 0x3d, 0xdc, 0x3f, 0xd8, 0xb7,
		0xf8, 0x60, 0xdf, 0xc1, 0xbc, 0xdb, 0xd5, 0x3b, 0x40, 0x64, 0x6b, 0x40, 0x3d, 0xd0, 0x60, 0xe4,
		0xd3, 0x78, 0x9a, 0xb9, 0xd2, 0xaf, 0x23, 0x74, 0x34, 0xdc, 0x5c, 0xdc, 0x53, 0x4f, 0xe3, 0x4d,
		0x7d, 0x24, 0x72, 0x85, 0x0d, 0x40, 0xb1, 0x01, 0x28, 0x7a, 0x50, 0xe8, 0x41, 0x59, 0xe1, 0x41,
		0x61, 0x03, 0x50, 0x08, 0xf2, 0x17, 0x1b, 0x80, 0xa2, 0x0c, 0x46, 0x19, 0xbc, 0xad, 0x32, 0x18,
		0xcb, 0x6a, 0x01, 0x84, 0x5b, 0xb0, 0xac, 0xd6, 0x44, 0x34, 0x05, 0xcb, 0x6a, 0xb3, 0x3f, 0x3d,
		0xf4, 0x83, 0x95, 0x8f, 0x05, 0x1b, 0x9c, 0xa0, 0x25, 0x86, 0x96, 0x18, 0x5a, 0x62, 0x68, 0x89,
		0xa1, 0x25, 0x86, 0x96, 0x18, 0x5a, 0x62, 0x68, 0x89, 0xe5, 0x66, 0x89, 0x85, 0x51, 0x44, 0xdd,
		0xe2, 0x12, 0xe0, 0x51, 0xe4, 0x82, 0x38, 0xbf, 0x34, 0xda, 0x63, 0x1b, 0x1e, 0x80, 0x56, 0x19,
		0x5a, 0x65, 0x68, 0x95, 0x81, 0xb2, 0xca, 0x10, 0xe5, 0xa5, 0xba, 0x73, 0x88, 0xf2, 0xd2, 0x69,
		0x2a, 0x20, 0xca, 0x2b, 0x1f, 0x3b, 0xca, 0x80, 0x35, 0x6c, 0xd4, 0x2a, 0xce, 0xfc, 0x4c, 0x11,
		0xe5, 0x65, 0xe6, 0x6e, 0x88, 0xf2, 0x4a, 0xa5, 0x61, 0x11, 0xe5, 0x65, 0xca, 0xc6, 0x4a, 0xd5,
		0x80, 0xe5, 0x39, 0xbd, 0x96, 0xae, 0x21, 0xcb, 0x73, 0x52, 0x55, 0x7b, 0x83, 0x96, 0xb5, 0x87,
		0xa4, 0x6a, 0xd8, 0xa2, 0xd1, 0xcb, 0xc5, 0xd6, 0x4e, 0xd3, 0x0e, 0x23, 0x63, 0x33, 0x7d, 0x77,
		0xa5, 0xff, 0x00, 0xb4, 0x9e, 0x4e, 0xe7, 0x91, 0xc7, 0xaf, 0x9b, 0xe3, 0xf5, 0xbd, 0xd5, 0x6e,
		0x4e, 0x2a, 0x3e, 0x12, 0x36, 0x73, 0x4a, 0xbd, 0xfb, 0x00, 0x9b, 0x39, 0x3d, 0xe5, 0xc5, 0xfc,
		0xbb, 0x38, 0x3d, 0xe1, 0x3e, 0xec, 0xdf, 0xa4, 0x70, 0xa2, 0xf9, 0xf5, 0x6d, 0x1a, 0x9f, 0x5e,
		0x96, 0x0d, 0x9b, 0x9e, 0x60, 0x3d, 0xe5, 0x7b, 0x37, 0x3d, 0xbd, 0x01, 0xb6, 0x71, 0xca, 0x30,
		0x8c, 0xba, 0xd5, 0x6d, 0x9c, 0x52, 0xd6, 0x52, 0xe8, 0xa9, 0x9d, 0xc0, 0x66, 0x4e, 0x99, 0x12,
		0xbc, 0x36, 0xc2, 0xd7, 0xc2, 0x00, 0xd9, 0xd8, 0x9c, 0xca, 0xcd, 0x9c, 0x9c, 0x30, 0x70, 0xd9,
		0x58, 0xa7, 0x12, 0x0d, 0x2d, 0x9d, 0x56, 0x6f, 0x96, 0x73, 0x7f, 0x14, 0x6c, 0xec, 0x64, 0x82,
		0xa5, 0xb4, 0xb3, 0x96, 0x56, 0x16, 0xcb, 0x27, 0x08, 0x90, 0xba, 0x3f, 0xca, 0x82, 0x6b, 0xf4,
		0xe5, 0xd3, 0x97, 0xb7, 0xd4, 0x93, 0x41, 0x2f, 0x61, 0x06, 0x3d, 0x43, 0x76, 0x35, 0xc6, 0xb6,
		0xc6, 0xd8, 0xd7, 0x08, 0x1b, 0xeb, 0x89, 0x0f, 0xa7, 0x8d, 0xee, 0xa6, 0x65, 0xef, 0xc5, 0x8d,
		0x98, 0xab, 0x7f, 0x5c, 0x38, 0x73, 0x75, 0x51, 0x84, 0xde, 0xec, 0x98, 0x36, 0x86, 0x37, 0xc1,
		0xf8, 0xe6, 0x04, 0x80, 0x29, 0x41, 0x60, 0x5c, 0x20, 0x18, 0x17, 0x0c, 0x46, 0x05, 0x84, 0x1e,
		0x41, 0xa1, 0x49, 0x60, 0x2c, 0xde, 0x54, 0x1b, 0xf4, 0x66, 0x8d, 0x5e, 0xf5, 0x95, 0x09, 0xaf,
		0xe9, 0x79, 0x9d, 0x50, 0x92, 0xb5, 0x06, 0x91, 0x69, 0xcb, 0x81, 0xf5, 0x9d, 0xb3, 0x86, 0x33,
		0x2e, 0xb0, 0x20, 0x1a, 0x89, 0x22, 0x0b, 0x04, 0x8d, 0xfb, 0xc4, 0xa1, 0xdc, 0x80, 0x74, 0x7f,
		0xfa, 0x04, 0xbd, 0xb2, 0xbe, 0x84, 0xb2, 0x1e, 0x65, 0x3d, 0xca, 0x7a, 0x1d, 0x6f, 0xaa, 0xcb,
		0x48, 0xdc, 0x24, 0x5c, 0xf4, 0x53, 0xd7, 0x06, 0x19, 0xa3, 0x9b, 0xc6, 0xf4, 0x8a, 0x1a, 0x63,
		0x22, 0xc7, 0xa4, 0xe8, 0x31, 0x2f, 0x82, 0x4c, 0x8b, 0xa2, 0xcc, 0x44, 0x52, 0x66, 0xa2, 0x29,
		0x13, 0x11, 0xa5, 0x57, 0x54, 0x69, 0x16, 0x59, 0xc6, 0x44, 0x97, 0x09, 0x7f, 0xd7, 0xbc, 0xff,
		0x6b, 0xd8, 0x1f, 0xce, 0x4c, 0x80, 0x65, 0x21, 0xc8, 0xb2, 0x13, 0x68, 0x59, 0x09, 0xb6, 0xcc,
		0x05, 0x5c, 0xe6, 0x82, 0x2e, 0x53, 0x81, 0x67, 0x46, 0xf0, 0x19, 0x12, 0x80, 0xe6, 0xfc, 0xf5,
		0x0c, 0xfd, 0xf7, 0x2c, 0xfc, 0xf9, 0xec, 0xfc, 0x7b, 0xf3, 0x74, 0x64, 0xa2, 0x78, 0x21, 0xdd,
		0x74, 0x89, 0xc4, 0xc4, 0x93, 0x16, 0xc7, 0x99, 0x83, 0xb9, 0xbe, 0xae, 0xf5, 0xca, 0xa8, 0xf5,
		0x50, 0xeb, 0xa1, 0xd6, 0x03, 0xa0, 0xf5, 0x4c, 0x99, 0xff, 0x59, 0xb8, 0x01, 0xd9, 0xb9, 0x03,
		0x19, 0xb9, 0x05, 0x99, 0xb9, 0x07, 0x59, 0x0a, 0xcc, 0xec, 0x05, 0x67, 0xd6, 0x02, 0x34, 0x37,
		0x41, 0x9a, 0x9b, 0x40, 0xcd, 0x45, 0xb0, 0x9a, 0x15, 0xb0, 0x86, 0x05, 0x6d, 0x76, 0x6e, 0xc6,
		0x33, 0x16, 0x63, 0xcc, 0x82, 0x41, 0x16, 0xfc, 0x36, 0x37, 0x1f, 0x0f, 0xdf, 0xd9, 0x79, 0xfe,
		0x06, 0xcf, 0xbe, 0x60, 0x2e, 0x96, 0xbf, 0x59, 0x1d, 0x1a, 0x8a, 0xea, 0xa3, 0x56, 0x34, 0xa3,
		0x15, 0x59, 0x1f, 0x95, 0xe2, 0x1b, 0x54, 0x8a, 0xac, 0x8f, 0x3a, 0x11, 0x9a, 0x4e, 0x34, 0x1f,
		0x82, 0x5b, 0x53, 0x8a, 0x07, 0x19, 0x3c, 0xab, 0xbd, 0x28, 0x72, 0x1b, 0x93, 0xdd, 0xa7, 0xff,
		0xcb, 0xde, 0xbb, 0xf7, 0xb6, 0x8d, 0x3c, 0xe9, 0xc2, 0xff, 0xe7, 0x53, 0x18, 0xc2, 0xef, 0x00,
		0xf6, 0x39, 0x61, 0x74, 0xb1, 0x2e, 0xb6, 0x81, 0xc5, 0x42, 0xb1, 0x95, 0x19, 0xbd, 0x23, 0x5b,
		0x5a, 0x5b, 0x99, 0xdf, 0x0c, 0x1c, 0x8d, 0x40, 0x4b, 0x6d, 0x9b, 0x3b, 0x34, 0xa9, 0x25, 0x5b,
		0x99, 0x78, 0x63, 0x7d, 0xf7, 0x17, 0xba, 0xdf, 0x13, 0x89, 0xac, 0xea, 0x26, 0xa9, 0x27, 0x18,
		0x4c, 0x64, 0xc5, 0xea, 0x16, 0xbb, 0xab, 0x9f, 0x7a, 0xaa, 0xba, 0x2e, 0xf3, 0xd0, 0x91, 0xd5,
		0x37, 0x26, 0x3f, 0x8f, 0x32, 0xd2, 0xa0, 0xac, 0xd7, 0xd6, 0xd1, 0xef, 0x3f, 0x68, 0xd0, 0xd7,
		0x4b, 0xb3, 0x42, 0x65, 0x43, 0x65, 0x43, 0x65, 0x43, 0x65, 0x43, 0x65, 0x43, 0x65, 0x8f, 0xde,
		0xb8, 0x9f, 0xab, 0xec, 0xff, 0xe8, 0xf4, 0x3d, 0x4f, 0x38, 0xf2, 0xf8, 0x24, 0xfd, 0xe1, 0x43,
		0x7a, 0xf6, 0x1b, 0xad, 0xc9, 0x47, 0x16, 0xf5, 0x88, 0xbf, 0xe1, 0xbd, 0xd9, 0xc8, 0x5d, 0xf1,
		0x2d, 0xb6, 0xda, 0x3f, 0x56, 0x5e, 0x76, 0xa2, 0x42, 0x31, 0x3f, 0xe7, 0x2d, 0xf4, 0xa5, 0x0e,
		0x7e, 0xd2, 0xe8, 0x69, 0x21, 0xe5, 0x73, 0xfe, 0x3a, 0xbd, 0x1a, 0xb9, 0xbc, 0xfa, 0x46, 0x9a,
		0xf3, 0x16, 0xf3, 0x88, 0xbe, 0xe2, 0xc2, 0x8d, 0xf8, 0x26, 0x7f, 0x75, 0x7b, 0xbf, 0x8c, 0x96,
		0x60, 0xe9, 0xa7, 0xf6, 0xe5, 0x7c, 0x01, 0xe6, 0xaf, 0xdb, 0xd5, 0xe1, 0xf3, 0x56, 0x67, 0xcf,
		0xbf, 0xf2, 0x73, 0x98, 0x6a, 0x37, 0xea, 0x0f, 0x46, 0xb4, 0xe3, 0xd7, 0x26, 0xd5, 0x76, 0xc8,
		0xaf, 0x7e, 0x68, 0xcb, 0x7a, 0xad, 0x8d, 0x4e, 0x5e, 0xe6, 0x6b, 0x7d, 0x06, 0x05, 0x65, 0xbf,
		0xd6, 0x26, 0x25, 0x2d, 0x03, 0xc6, 0x2d, 0x3a, 0xcc, 0xa8, 0x1c, 0x1b, 0x34, 0x4e, 0xb1, 0x44,
		0xc3, 0x44, 0x18, 0x7f, 0x53, 0x11, 0x2d, 0x71, 0x19, 0xad, 0xa4, 0x06, 0xa6, 0xe3, 0x11, 0xd9,
		0x63, 0x41, 0x99, 0x14, 0x14, 0x2d, 0xf1, 0x4f, 0x52, 0xda, 0x1d, 0x6d, 0x98, 0x1d, 0x4b, 0x58,
		0x1d, 0x5b, 0x82, 0x5d, 0x0e, 0x09, 0x76, 0x31, 0xf2, 0x72, 0x21, 0xc1, 0x2e, 0xc2, 0x09, 0x76,
		0x5d, 0xbf, 0xd3, 0xe3, 0xcb, 0xaa, 0x1b, 0x8d, 0xfe, 0x3e, 0x16, 0xdd, 0x7d, 0x90, 0x4a, 0xa7,
		0x12, 0x74, 0x94, 0x81, 0x8f, 0x32, 0x10, 0x52, 0x02, 0x46, 0xf1, 0x70, 0x45, 0xb0, 0xf9, 0xc4,
		0x39, 0x71, 0x65, 0x11, 0x5b, 0x38, 0x3c, 0x02, 0x3c, 0x0d, 0x45, 0xa6, 0x7f, 0x18, 0x7d, 0xa9,
		0x9c, 0x0d, 0x46, 0x98, 0x41, 0x7d, 0x6d, 0x1a, 0xa6, 0x6e, 0x7b, 0x6b, 0xf3, 0x28, 0x68, 0x4f,
		0xc1, 0x74, 0x78, 0x57, 0x5d, 0x67, 0x89, 0xdb, 0xfa, 0xe2, 0x69, 0x82, 0xf6, 0x3e, 0x26, 0x9e,
		0xf3, 0x56, 0xa4, 0xd5, 0x15, 0x1c, 0xdc, 0x01, 0x26, 0xe5, 0x75, 0x70, 0x47, 0xb2, 0x57, 0x29,
		0x43, 0x06, 0x0f, 0x5f, 0xc6, 0x0e, 0xcc, 0x24, 0x98, 0x49, 0x30, 0x93, 0x0e, 0xdc, 0x4c, 0xea,
		0x5b, 0x8e, 0x24, 0x69, 0x1b, 0xbe, 0x0d, 0x5d, 0xce, 0x60, 0x28, 0xc1, 0x50, 0x82, 0xa1, 0x94,
		0x48, 0x43, 0x49, 0x0d, 0x91, 0x84, 0xe9, 0xa4, 0xd4, 0x74, 0x8a, 0x24, 0xb1, 0x0e, 0xd9, 0x9c,
		0x64, 0x67, 0x75, 0x18, 0xaa, 0x79, 0x09, 0x08, 0x37, 0x08, 0x37, 0x08, 0x37, 0x08, 0xf7, 0x0f,
		0xe5, 0x9d, 0x2f, 0x36, 0x9f, 0x33, 0x16, 0x7f, 0xb1, 0x82, 0xd5, 0xe2, 0x7f, 0x2b, 0xd1, 0x43,
		0x3c, 0xc5, 0xad, 0x10, 0x35, 0xb6, 0xdf, 0xb8, 0x51, 0x89, 0x1a, 0xa3, 0x8e, 0x5c, 0xd7, 0x1d,
		0x2a, 0x46, 0x18, 0x8a, 0x3e, 0x88, 0x79, 0xab, 0x0f, 0xaa, 0x50, 0x72, 0x74, 0x84, 0xa6, 0xef,
		0x08, 0x1d, 0xb6, 0xbd, 0x14, 0x2d, 0x2a, 0x45, 0x05, 0x8d, 0x52, 0x24, 0x01, 0x95, 0x3a, 0xf1,
		0x27, 0x85, 0x46, 0xe1, 0x71, 0x11, 0xbb, 0xe8, 0x34, 0x0f, 0xdf, 0x4d, 0xc8, 0x94, 0x75, 0x13,
		0x0f, 0xd0, 0x23, 0x33, 0xc4, 0x9d, 0x5a, 0xf8, 0xbb, 0xb3, 0x90, 0x26, 0x3b, 0x9a, 0x2c, 0xaa,
		0x31, 0x9d, 0xd1, 0x64, 0x91, 0xd0, 0x84, 0x25, 0x34, 0x55, 0x29, 0x4c, 0x52, 0xba, 0xe2, 0xc9,
		0x6a, 0xf0, 0x6a, 0xaa, 0x15, 0xfc, 0xf0, 0xb0, 0x35, 0x1f, 0x0a, 0x2d, 0x62, 0x81, 0x5e, 0x07,
		0x81, 0x5e, 0xa1, 0x5b, 0xc4, 0x4e, 0xcf, 0x0c, 0x5d, 0x87, 0xd8, 0xd9, 0x88, 0x68, 0x10, 0xcb,
		0x7f, 0x48, 0xa9, 0x0f, 0x2b, 0xdb, 0xa1, 0x65, 0x3b, 0xbc, 0x2c, 0x87, 0x38, 0x1a, 0x5e, 0x23,
		0xba, 0x06, 0xb1, 0xa3, 0x7a, 0x2c, 0x0c, 0x5d, 0x04, 0x87, 0xc3, 0xa2, 0x4d, 0x6c, 0x74, 0x60,
		0x80, 0x0b, 0x0e, 0xd8, 0x61, 0x81, 0x1d, 0x1e, 0x58, 0x61, 0x82, 0x06, 0x2e, 0x88, 0x60, 0x83,
		0xce, 0xb2, 0x61, 0xb4, 0x74, 0x38, 0x2c, 0x9f, 0x1d, 0x2c, 0x21, 0xba, 0xba, 0x54, 0x48, 0x59,
		0x57, 0xcb, 0xe3, 0xd6, 0x81, 0x1d, 0x29, 0xeb, 0x00, 0xf6, 0xc3, 0x04, 0x76, 0x86, 0x9e, 0xb0,
		0x94, 0xfc, 0x90, 0x95, 0x27, 0x32, 0xf1, 0x45, 0x36, 0xde, 0xc8, 0x09, 0x33, 0xfc, 0x70, 0xc3,
		0x0d, 0x3b, 0xca, 0xe0, 0x47, 0x19, 0x0c, 0x29, 0x81, 0x23, 0x5a, 0x58, 0x22, 0x86, 0x27, 0x3e,
		0xfe, 0xa9, 0x80, 0x87, 0x72, 0xf2, 0xd1, 0x4d, 0xbc, 0x74, 0x4b, 0x7c, 0xd8, 0xfc, 0xb2, 0x94,
		0x9e, 0xb9, 0xd2, 0x0b, 0x0f, 0x65, 0xe4, 0xf2, 0x3f, 0xc2, 0x7a, 0x7a, 0x96, 0x7c, 0xba, 0x68,
		0x32, 0x3e, 0x94, 0x11, 0x94, 0x11, 0x94, 0x11, 0x94, 0x11, 0xa1, 0xbc, 0x23, 0x35, 0x70, 0xed,
		0x0f, 0x52, 0x03, 0x77, 0x9a, 0x06, 0xa9, 0x81, 0xfb, 0x6d, 0x3d, 0x52, 0x03, 0xe3, 0x26, 0x0d,
		0x48, 0x0d, 0x4c, 0x90, 0xfb, 0x29, 0x39, 0x79, 0x18, 0xdb, 0xcc, 0xad, 0x58, 0x26, 0x61, 0x4c,
		0x7e, 0x98, 0xbd, 0x8b, 0xfc, 0x8b, 0x25, 0x46, 0x4f, 0xe5, 0x88, 0x44, 0x0a, 0x06, 0x52, 0x30,
		0x14, 0x00, 0x51, 0xac, 0xf2, 0x2f, 0x56, 0xa1, 0x07, 0xa9, 0x17, 0x31, 0x11, 0xb7, 0x58, 0x24,
		0x5e, 0x4c, 0xa5, 0x2b, 0xca, 0x51, 0xcc, 0xe1, 0x2e, 0xe2, 0x49, 0x2e, 0xde, 0xc9, 0xa2, 0x97,
		0x73, 0x88, 0x5e, 0x66, 0x74, 0x06, 0x22, 0x7a, 0x79, 0xfe, 0xcd, 0x43, 0x47, 0x2f, 0x3f, 0x98,
		0x9d, 0xbf, 0xfb, 0x3d, 0x83, 0xb8, 0xdc, 0xc9, 0x4c, 0x0a, 0x37, 0x0f, 0x4f, 0x13, 0xd7, 0x9c,
		0x41, 0x5c, 0xb3, 0xc2, 0x63, 0xcc, 0x76, 0x9c, 0xd9, 0x8e, 0x35, 0xcb, 0xf1, 0x8e, 0x86, 0x35,
		0x46, 0xe6, 0x8b, 0x67, 0xb8, 0x08, 0xa6, 0xbc, 0xf8, 0x5d, 0xbf, 0xe8, 0x65, 0xa9, 0xff, 0x11,
		0x82, 0x2f, 0x87, 0xd0, 0xaf, 0x1d, 0xd7, 0x76, 0x3d, 0x3a, 0xa8, 0x1d, 0x0f, 0x07, 0x68, 0x05,
		0xb4, 0x02, 0x5a, 0x23, 0x05, 0xad, 0x64, 0xd7, 0x9a, 0x84, 0xd7, 0x98, 0xc4, 0xd7, 0x96, 0x84,
		0x3e, 0x6c, 0x8e, 0x6b, 0x49, 0xae, 0xe8, 0x12, 0xa6, 0x6b, 0x47, 0xce, 0x8b, 0x25, 0xca, 0x48,
		0x23, 0x8e, 0x6b, 0x44, 0xee, 0xad, 0xe2, 0xbf, 0x26, 0x64, 0xdd, 0xbd, 0x88, 0xdc, 0x45, 0xb4,
		0x62, 0x48, 0xb7, 0x08, 0x4a, 0xe5, 0xd3, 0x95, 0xc6, 0x07, 0xd1, 0x02, 0xd1, 0x02, 0xd1, 0x02,
		0xd1, 0x02, 0xd1, 0x02, 0xd1, 0x02, 0xd1, 0x02, 0xd1, 0x8a, 0x1c, 0xd1, 0xc2, 0x3d, 0xf0, 0x4e,
		0xf7, 0xc0, 0x61, 0x83, 0x9d, 0xd4, 0xdd, 0x01, 0x87, 0x88, 0x65, 0x0a, 0x70, 0x01, 0xfc, 0x8e,
		0x51, 0x6c, 0x02, 0xd7, 0x82, 0x0d, 0x17, 0x78, 0x14, 0x3e, 0xd0, 0x88, 0x25, 0xb0, 0x28, 0x5c,
		0x20, 0xd1, 0xbe, 0x4b, 0x1f, 0xf2, 0xa4, 0xaa, 0x3f, 0xa1, 0xa9, 0x40, 0xa1, 0x08, 0x6a, 0xce,
		0xe4, 0x7e, 0xa7, 0x71, 0xf7, 0x33, 0xb5, 0xdb, 0x6f, 0xee, 0xb8, 0xf5, 0x41, 0xb7, 0x5c, 0xc1,
		0x56, 0xef, 0xb1, 0xb7, 0x9c, 0x7b, 0xba, 0xdb, 0x36, 0xfe, 0x7c, 0x53, 0x76, 0xd8, 0x90, 0x00,
		0xb5, 0xfe, 0x02, 0xd7, 0xf6, 0xdb, 0x33, 0x1a, 0x66, 0x6f, 0x57, 0x44, 0x10, 0x97, 0x43, 0x70,
		0xd7, 0x42, 0x50, 0x17, 0x42, 0x68, 0x57, 0x41, 0x68, 0x97, 0x40, 0x28, 0xd3, 0x9f, 0x16, 0x0a,
		0xf6, 0x8d, 0x36, 0x09, 0x5e, 0x1b, 0x2f, 0x6c, 0x2d, 0xbc, 0x80, 0xa1, 0x5c, 0x81, 0xfd, 0x69,
		0x61, 0xfc, 0x67, 0xe1, 0xfd, 0x65, 0x61, 0xfd, 0x63, 0x64, 0xfe, 0x30, 0x32, 0xff, 0x17, 0x89,
		0xbf, 0x8b, 0x97, 0x85, 0x06, 0x0d, 0xbd, 0x0a, 0x59, 0x2b, 0x84, 0xa4, 0x26, 0x08, 0xaa, 0x4c,
		0x73, 0xb8, 0x97, 0x11, 0xe9, 0xc8, 0xe8, 0x23, 0x38, 0x80, 0x2a, 0xd3, 0xc1, 0x2b, 0x54, 0x28,
		0x2a, 0x8c, 0xef, 0x48, 0xe1, 0x3d, 0x9a, 0x1d, 0x61, 0x0c, 0x97, 0x8f, 0x00, 0xc0, 0x16, 0x87,
		0x43, 0xc1, 0xe9, 0xe1, 0x81, 0xb4, 0x1e, 0x81, 0x63, 0x01, 0x70, 0xcc, 0x7a, 0x3c, 0x98, 0x80,
		0x6d, 0x9a, 0x82, 0x85, 0xa4, 0x85, 0x0a, 0xc9, 0x0b, 0x4d, 0xe7, 0xa2, 0x79, 0x99, 0x6d, 0x3d,
		0xe2, 0x2e, 0x9b, 0x62, 0x60, 0xc2, 0xc3, 0x1b, 0xee, 0x10, 0x87, 0x3c, 0xcc, 0x64, 0x87, 0x7a,
		0x5d, 0xc3, 0x72, 0x94, 0x9a, 0x9e, 0x0e, 0x8d, 0x72, 0xd3, 0x91, 0x01, 0x03, 0x2e, 0x50, 0x60,
		0x07, 0x07, 0x76, 0x90, 0xe0, 0x04, 0x0b, 0x1a, 0xd0, 0x20, 0x02, 0x0f, 0x3a, 0x03, 0x87, 0xd1,
		0xe0, 0xe1, 0x30, 0x80, 0xb6, 0x1a, 0x44, 0xe9, 0xd1, 0x36, 0x5f, 0xcc, 0x00, 0xcb, 0x5f, 0x7d,
		0x63, 0xf2, 0xf3, 0xc8, 0x99, 0x9f, 0xa4, 0x52, 0xd4, 0xfd, 0x07, 0x46, 0xfc, 0x5f, 0x1a, 0x1d,
		0x2a, 0x00, 0x2a, 0x00, 0x2a, 0x00, 0x2a, 0x20, 0xb6, 0x2a, 0xe0, 0x7e, 0xae, 0x02, 0xfe, 0xa3,
		0xd3, 0xf7, 0x3c, 0xe1, 0xc8, 0xe3, 0x93, 0xf4, 0x87, 0x0f, 0xe9, 0xd9, 0x6f, 0xb4, 0x26, 0x1f,
		0x59, 0xc4, 0x3d, 0x7f, 0xc3, 0x7b, 0xb3, 0x91, 0xa3, 0xd4, 0xd8, 0x00, 0xc5, 0x60, 0x76, 0x0b,
		0x04, 0x58, 0x28, 0x3b, 0xb5, 0xe4, 0x4d, 0x24, 0x2b, 0x42, 0xc5, 0x13, 0x37, 0x30, 0xaf, 0x30,
		0x55, 0x9d, 0x7e, 0xeb, 0x5b, 0xf1, 0x48, 0x51, 0x6e, 0x0a, 0x11, 0x7f, 0xec, 0xb2, 0x15, 0xb9,
		0x68, 0xbf, 0xcd, 0xd2, 0x84, 0x5a, 0x2f, 0x9c, 0x3e, 0x4b, 0xd4, 0x7a, 0x51, 0x43, 0x36, 0x71,
		0x03, 0x4a, 0xe7, 0x65, 0x4c, 0x09, 0xa7, 0x63, 0xf6, 0xfc, 0xbe, 0x6d, 0x4a, 0x61, 0x3c, 0x0b,
		0xb3, 0x2b, 0x08, 0xab, 0x0f, 0x6c, 0x18, 0x1b, 0x19, 0x72, 0xfc, 0x07, 0x97, 0xcb, 0x7a, 0x44,
		0x86, 0x5c, 0x04, 0x88, 0x38, 0x7d, 0x86, 0xdc, 0xfc, 0x94, 0x5a, 0xae, 0x33, 0x39, 0xa7, 0x86,
		0x1c, 0x4e, 0x43, 0x58, 0xf7, 0x25, 0x4f, 0x30, 0x56, 0xc5, 0xe9, 0xbf, 0x0c, 0x1f, 0x7d, 0x10,
		0xc7, 0x44, 0x63, 0x92, 0x5e, 0x50, 0xa4, 0xbd, 0x9f, 0x00, 0xa6, 0x00, 0x53, 0x80, 0x29, 0xd2,
		0x8d, 0xf7, 0xfd, 0x83, 0x74, 0x63, 0xd2, 0x71, 0x91, 0x6e, 0x8c, 0x74, 0x63, 0x06, 0x68, 0xa4,
		0x1b, 0x25, 0x96, 0x75, 0x5d, 0x7a, 0x86, 0xd9, 0xed, 0x7a, 0xc2, 0xf7, 0x09, 0x39, 0xd7, 0x7c,
		0x4c, 0x10, 0x2f, 0x10, 0x2f, 0x10, 0xaf, 0x48, 0x11, 0x2f, 0xb2, 0xd3, 0xb9, 0x64, 0xb6, 0x9e,
		0x13, 0x8c, 0x35, 0x79, 0xd6, 0xc8, 0x91, 0xaf, 0xf9, 0xca, 0x7d, 0xcd, 0x13, 0xae, 0xdd, 0xda,
		0x1a, 0x9e, 0xd1, 0xde, 0x05, 0x4b, 0xe1, 0x39, 0xe4, 0xad, 0xd5, 0x52, 0xc7, 0xc7, 0xf7, 0x19,
		0xe3, 0xbc, 0xf5, 0x76, 0x9f, 0x35, 0xce, 0x5b, 0xe3, 0x97, 0xd9, 0xd1, 0x5f, 0xe3, 0xd7, 0xb9,
		0xfb, 0x8c, 0x91, 0x9f, 0xbe, 0x2e, 0xdc, 0x67, 0x8c, 0x42, 0xeb, 0xe4, 0xcb, 0x97, 0x0f, 0x27,
		0xdf, 0x4f, 0x07, 0xfb, 0x7f, 0x90, 0x2e, 0x52, 0xa1, 0x45, 0xb9, 0xb4, 0xf5, 0xbb, 0xea, 0x1f,
		0x6c, 0xeb, 0xfb, 0x97, 0xca, 0x05, 0xfe, 0x17, 0xe1, 0x0a, 0x47, 0x29, 0x16, 0x84, 0xe7, 0xf0,
		0x17, 0x71, 0xf8, 0x47, 0x22, 0x66, 0x1a, 0x8f, 0x65, 0xe3, 0x53, 0xeb, 0x7b, 0xf6, 0x7d, 0x7e,
		0x70, 0x71, 0xf2, 0xbd, 0x34, 0x58, 0x7d, 0xf3, 0x6d, 0xd3, 0xaf, 0x65, 0xdf, 0x97, 0x06, 0x17,
		0x5b, 0xfe, 0xa5, 0x38, 0xb8, 0xd8, 0x71, 0x8c, 0xc2, 0xe0, 0x78, 0xed, 0x57, 0x87, 0xef, 0xe7,
		0xb6, 0x7d, 0x20, 0xbf, 0xe5, 0x03, 0xa7, 0xdb, 0x3e, 0x70, 0xba, 0xe5, 0x03, 0x5b, 0xbf, 0x52,
		0x6e, 0xcb, 0x07, 0x0a, 0x83, 0xb7, 0xb5, 0xdf, 0x3f, 0xde, 0xfc, 0xab, 0xc5, 0xc1, 0xc9, 0xdb,
		0xb6, 0x7f, 0x2b, 0x0d, 0xde, 0x2e, 0x4e, 0x0e, 0x19, 0x0a, 0x21, 0x6e, 0xea, 0xc5, 0x2d, 0x7a,
		0x8a, 0xe1, 0x20, 0xad, 0x73, 0xdb, 0xef, 0x19, 0x93, 0x78, 0x17, 0x22, 0xdb, 0x7c, 0x36, 0x22,
		0x2c, 0x73, 0x58, 0xe6, 0xb0, 0xcc, 0x23, 0x65, 0x99, 0xfb, 0xd2, 0xb3, 0x9c, 0x27, 0x4a, 0xab,
		0xfc, 0x2c, 0x86, 0x98, 0xf7, 0x62, 0x76, 0xe8, 0x5d, 0x92, 0x8b, 0x83, 0x02, 0xf9, 0x80, 0x7c,
		0x40, 0xbe, 0x48, 0x21, 0x1f, 0xdd, 0xf1, 0xa4, 0xb6, 0xa9, 0xc9, 0x6d, 0xe9, 0xd4, 0x22, 0xe9,
		0x5e, 0xe5, 0xf2, 0xb9, 0xc1, 0xc9, 0xf7, 0xc2, 0x20, 0xbc, 0x7c, 0xb4, 0x28, 0x1e, 0x9c, 0xc3,
		0xb6, 0x4b, 0xfd, 0xf5, 0xf3, 0xc7, 0x27, 0xb0, 0x3d, 0xe2, 0xc8, 0xf5, 0x5d, 0xcf, 0x7a, 0xb2,
		0x1c, 0xa3, 0xe7, 0xb9, 0xd2, 0xed, 0xb8, 0x36, 0x9d, 0xee, 0x5b, 0x1d, 0x18, 0xfa, 0x0f, 0xfa,
		0x0f, 0xfa, 0x2f, 0x52, 0xfa, 0xcf, 0xea, 0x0a, 0x47, 0x5a, 0xf2, 0x95, 0xb8, 0x87, 0x20, 0x45,
		0xa7, 0xf5, 0xea, 0xe4, 0xab, 0x7d, 0x34, 0x7d, 0x86, 0xbc, 0xea, 0xea, 0xcd, 0x5d, 0xb3, 0x5c,
		0xab, 0xb5, 0x1b, 0xb7, 0xf5, 0x66, 0xfd, 0xb2, 0x5e, 0x6b, 0x37, 0xff, 0x6c, 0x54, 0xa8, 0x44,
		0x7a, 0x14, 0xdd, 0xe2, 0x93, 0xfa, 0x25, 0x89, 0xc3, 0x7a, 0xa6, 0xcb, 0x70, 0x55, 0xbd, 0xad,
		0x5c, 0x36, 0x6b, 0x7f, 0xb6, 0x2f, 0xeb, 0x37, 0x37, 0x95, 0xcb, 0x66, 0xe5, 0x2a, 0x15, 0xc5,
		0xd8, 0x26, 0xa6, 0xa7, 0xff, 0xf8, 0x4b, 0xe3, 0x90, 0x1e, 0xb7, 0xfa, 0xcb, 0xf5, 0x41, 0x3d,
		0x6f, 0xa3, 0x7a, 0x7d, 0x48, 0x8f, 0x7b, 0xd7, 0x2c, 0x37, 0xab, 0x97, 0x87, 0xf4, 0xc4, 0xf5,
		0xbb, 0xc6, 0xa7, 0x43, 0x7b, 0xde, 0xd3, 0x83, 0x42, 0xac, 0xbb, 0xea, 0xdd, 0x21, 0x3d, 0x6f,
		0xad, 0x7e, 0x59, 0xae, 0xb5, 0xcb, 0xbf, 0xfc, 0x72, 0x5b, 0xf9, 0xa5, 0xdc, 0xac, 0x44, 0xad,
		0x60, 0x46, 0x4b, 0x37, 0x7f, 0xd6, 0x62, 0x1f, 0xf7, 0xfa, 0xfe, 0xb3, 0xe8, 0x1a, 0x2f, 0x3d,
		0xdb, 0x37, 0x6c, 0xf3, 0x41, 0xd8, 0x86, 0x2f, 0xcd, 0xce, 0xdf, 0x74, 0x76, 0xf2, 0xb6, 0x09,
		0x60, 0x2f, 0xc3, 0x5e, 0x86, 0xbd, 0x1c, 0x29, 0x7b, 0x79, 0x7e, 0x46, 0x11, 0xc3, 0xba, 0xdf,
		0xca, 0xf5, 0x2d, 0x47, 0x9e, 0xe6, 0x18, 0x02, 0xd8, 0x28, 0x0b, 0x19, 0xd1, 0xa6, 0x61, 0xf1,
		0x90, 0x85, 0x23, 0xae, 0xb4, 0x2c, 0x62, 0xc5, 0xf1, 0x63, 0xef, 0xc8, 0x50, 0xec, 0x8b, 0x4c,
		0x13, 0x30, 0x66, 0xfc, 0x30, 0x50, 0xc9, 0xf9, 0x9e, 0x32, 0xe4, 0x6f, 0x29, 0xdf, 0xd3, 0x4c,
		0xfe, 0xac, 0x50, 0x2a, 0xc4, 0x78, 0x63, 0xdf, 0x45, 0x73, 0xb4, 0xa4, 0x47, 0x39, 0x0b, 0xa7,
		0xff, 0x22, 0xbc, 0x71, 0x69, 0x29, 0x86, 0x20, 0xe7, 0x3c, 0xe1, 0x98, 0x34, 0x45, 0x0e, 0xe8,
		0x44, 0xa4, 0xa5, 0x95, 0x63, 0x85, 0x6a, 0xce, 0xb8, 0x49, 0xaf, 0x85, 0x6b, 0xd6, 0xb8, 0x09,
		0x55, 0xc9, 0x9b, 0x37, 0xae, 0x4d, 0xb2, 0xd8, 0xcc, 0x91, 0xf8, 0xa2, 0xa2, 0xef, 0x87, 0xae,
		0xc9, 0xc3, 0x65, 0xe3, 0xac, 0xda, 0x39, 0xee, 0x78, 0x15, 0x8c, 0x87, 0x57, 0xca, 0x23, 0xcc,
		0x59, 0xa7, 0x74, 0xc9, 0xe6, 0x19, 0xad, 0x74, 0x32, 0x4a, 0x49, 0xa2, 0x9c, 0x20, 0x43, 0x39,
		0xc1, 0x68, 0x36, 0x0d, 0x9e, 0x97, 0x11, 0x4c, 0x60, 0xab, 0xe0, 0x00, 0x35, 0x74, 0xd0, 0x2d,
		0x38, 0xf4, 0xea, 0x47, 0xb8, 0x5b, 0xf0, 0xfc, 0x55, 0x64, 0x3a, 0x04, 0xcf, 0x5e, 0xa0, 0x2f,
		0x70, 0xd0, 0x4d, 0xd5, 0xde, 0x11, 0x58, 0x69, 0x33, 0xe0, 0x9e, 0x6b, 0x5b, 0x9d, 0x57, 0xe3,
		0xd1, 0xf5, 0xfe, 0x31, 0xbd, 0xae, 0xe5, 0x3c, 0xed, 0xdf, 0x14, 0x78, 0x7d, 0x08, 0x34, 0x07,
		0x0e, 0xc6, 0x59, 0xd1, 0x1c, 0x78, 0xdf, 0xe6, 0xc0, 0x6b, 0xb2, 0x67, 0x08, 0x47, 0x7a, 0xaf,
		0xc1, 0x7b, 0x05, 0x6f, 0x1b, 0x10, 0xad, 0x83, 0xf9, 0x4c, 0x39, 0xb4, 0x0e, 0x46, 0xeb, 0x60,
		0x25, 0xc7, 0x84, 0xe2, 0xb8, 0xd0, 0x1d, 0x1b, 0x6a, 0x4f, 0x08, 0x0a, 0x67, 0x33, 0x7a, 0x07,
		0xd0, 0x3a, 0x98, 0xd6, 0x62, 0x47, 0xc5, 0x7f, 0x00, 0x17, 0x80, 0x4b, 0x01, 0x70, 0x85, 0xae,
		0xf8, 0x8f, 0x52, 0xd4, 0x4a, 0x8e, 0x25, 0xfd, 0xf1, 0xa4, 0x3e, 0xa6, 0x6c, 0xc7, 0x95, 0xed,
		0xd8, 0xb2, 0x1c, 0xdf, 0x70, 0xc7, 0x38, 0xe4, 0x71, 0xa6, 0xe3, 0x23, 0x6b, 0xf2, 0x86, 0x52,
		0xd4, 0xfb, 0x7c, 0x31, 0x94, 0xa2, 0x46, 0x29, 0x6a, 0x94, 0xa2, 0x66, 0x81, 0x46, 0xba, 0x51,
		0x62, 0x5a, 0x8a, 0xba, 0xeb, 0x77, 0x7a, 0xa4, 0x75, 0xa8, 0x47, 0x03, 0x82, 0x72, 0x81, 0x72,
		0x81, 0x72, 0x45, 0x8a, 0x72, 0x11, 0x9c, 0xcb, 0xc5, 0xb3, 0x59, 0x00, 0xe1, 0x02, 0xe1, 0x02,
		0xe1, 0x0a, 0xb4, 0x55, 0xc5, 0x53, 0xd0, 0xab, 0x03, 0xa1, 0x57, 0x3d, 0x1a, 0xe6, 0xb0, 0x48,
		0xb0, 0x68, 0xbc, 0x96, 0xa0, 0x58, 0xa0, 0x58, 0xa0, 0x58, 0xe4, 0x7d, 0x3e, 0xc8, 0x76, 0xf3,
		0xf0, 0xda, 0x7c, 0x90, 0x1e, 0x84, 0x23, 0x74, 0xf9, 0xf8, 0xc1, 0x07, 0xd3, 0x93, 0xc9, 0x4e,
		0xde, 0x8e, 0xef, 0xb3, 0x46, 0xae, 0x35, 0xfd, 0xe1, 0xf4, 0x3e, 0x63, 0xe4, 0x5a, 0x27, 0xe8,
		0x02, 0xa2, 0x7b, 0x03, 0xd0, 0x25, 0x64, 0x1f, 0xec, 0x28, 0x02, 0x3b, 0xd0, 0xb5, 0x41, 0x4f,
		0xd7, 0x86, 0xf4, 0x71, 0x76, 0x78, 0xbe, 0xcf, 0xc6, 0x47, 0x3e, 0xdb, 0x5a, 0x43, 0x82, 0xf1,
		0xc9, 0x46, 0x2f, 0x11, 0x48, 0x65, 0xf4, 0xa4, 0x12, 0x2d, 0x47, 0xa2, 0xe3, 0x26, 0xa0, 0x2e,
		0x41, 0xbc, 0x38, 0x28, 0x5c, 0x05, 0x70, 0x15, 0xc0, 0x55, 0x10, 0x3d, 0x57, 0xc1, 0xf8, 0x78,
		0x1a, 0x72, 0x38, 0x3a, 0x3c, 0x06, 0x7b, 0xad, 0x5f, 0xdf, 0x72, 0xe4, 0x19, 0x03, 0xdf, 0x2f,
		0xa0, 0xa6, 0x12, 0xf1, 0xe0, 0x8a, 0xea, 0xef, 0x64, 0x50, 0x52, 0x69, 0x69, 0x4b, 0x13, 0x50,
		0x52, 0x29, 0x57, 0xc8, 0xa3, 0x9c, 0x12, 0xf5, 0x68, 0x89, 0x77, 0x07, 0x91, 0xd6, 0xf5, 0x5f,
		0xd3, 0xad, 0x94, 0xfa, 0x81, 0xa5, 0xce, 0xff, 0xda, 0x82, 0x54, 0x1b, 0xb3, 0x52, 0xff, 0x29,
		0x8e, 0xfb, 0x6c, 0x9f, 0x5c, 0xc3, 0xf1, 0x68, 0xb9, 0xd5, 0x45, 0x69, 0x5e, 0x12, 0x96, 0x84,
		0x67, 0x84, 0x72, 0xfe, 0x95, 0x20, 0xad, 0x16, 0x1f, 0xeb, 0x95, 0x28, 0x7f, 0x6e, 0xfe, 0x8a,
		0xa5, 0x18, 0x2d, 0xc5, 0xe7, 0x2b, 0x1c, 0x8f, 0xf1, 0x4a, 0x54, 0x2f, 0xaf, 0xb1, 0x14, 0xe3,
		0xa5, 0xa8, 0xe5, 0x9a, 0x58, 0x8a, 0x89, 0x54, 0xfc, 0x02, 0xa9, 0x98, 0x2c, 0xc5, 0xed, 0xdd,
		0xef, 0x58, 0x8a, 0xf1, 0x52, 0xfc, 0x72, 0x5b, 0x49, 0x45, 0xdc, 0x94, 0x68, 0x21, 0x34, 0x90,
		0x68, 0xfe, 0x50, 0x6d, 0xc6, 0xf3, 0x46, 0xd7, 0x97, 0x46, 0xcf, 0xf5, 0x24, 0x61, 0xa7, 0xf1,
		0x85, 0x41, 0xe1, 0xf3, 0xff, 0xe9, 0x72, 0xc1, 0xe7, 0x0f, 0x9f, 0xff, 0xf6, 0x27, 0xa2, 0xf7,
		0xf9, 0x0f, 0xcf, 0xa5, 0xe1, 0xf4, 0x5f, 0x1e, 0x48, 0xea, 0xda, 0x4e, 0x8f, 0x68, 0x11, 0x89,
		0x18, 0x5a, 0xb0, 0x6d, 0xb3, 0x37, 0x04, 0x89, 0x18, 0x71, 0xda, 0xaa, 0x62, 0xa1, 0x70, 0x8a,
		0x54, 0xd7, 0x43, 0x21, 0x5c, 0xbe, 0xd7, 0xa1, 0x27, 0x5c, 0xb3, 0x41, 0x41, 0xb8, 0x40, 0xb8,
		0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x40, 0xb8, 0x0e, 0x9d, 0x70, 0xbd,
		0x98, 0x1d, 0xc3, 0xec, 0x76, 0x3d, 0xe1, 0xfb, 0x74, 0x84, 0x6b, 0x71, 0x50, 0x10, 0x2e, 0x10,
		0x2e, 0x10, 0xae, 0x48, 0x11, 0x2e, 0xba, 0xe3, 0x79, 0x44, 0x9c, 0x83, 0x45, 0x9e, 0x7b, 0x95,
		0x5a, 0xcc, 0xbe, 0x58, 0x4d, 0xea, 0xc8, 0x0d, 0x4e, 0xbe, 0x17, 0x06, 0xe1, 0xe5, 0xa3, 0x45,
		0xf1, 0xe0, 0x1c, 0x49, 0x3e, 0xa9, 0xbf, 0x7e, 0xfe, 0xf8, 0x04, 0xd9, 0x25, 0xb1, 0xd4, 0x7b,
		0xf3, 0x46, 0xb9, 0x74, 0x6a, 0x8f, 0xaa, 0xf9, 0x2e, 0xb4, 0x1e, 0xb4, 0x1e, 0xb4, 0x1e, 0x5a,
		0x63, 0x6b, 0xf6, 0x32, 0xa0, 0x35, 0x36, 0xd2, 0x38, 0x36, 0x3b, 0x08, 0xd0, 0x1a, 0x9b, 0xdf,
		0xc9, 0xa3, 0x7c, 0x4f, 0xd1, 0x1a, 0x9b, 0x67, 0x34, 0xb4, 0xc6, 0x0e, 0xa5, 0x61, 0xd1, 0x1a,
		0x3b, 0x82, 0x96, 0x93, 0xec, 0x10, 0x9b, 0x4d, 0xb2, 0x03, 0x9b, 0x09, 0x36, 0x13, 0x6c, 0xa6,
		0x08, 0xda, 0x4c, 0xa1, 0x8f, 0xe6, 0x11, 0x0a, 0x12, 0x47, 0x8e, 0xfe, 0xe1, 0x5a, 0x36, 0x7e,
		0xd7, 0xb2, 0x25, 0x5c, 0xc9, 0x1e, 0x02, 0xc1, 0x9a, 0xb6, 0x9d, 0x36, 0x9e, 0x3c, 0xb7, 0x4f,
		0xd8, 0xf5, 0x61, 0x65, 0x5c, 0xd0, 0x2d, 0xd0, 0x2d, 0xd0, 0xad, 0x48, 0xd1, 0xad, 0xf0, 0x7d,
		0x40, 0xd7, 0xac, 0xe7, 0x12, 0xcd, 0xa5, 0xec, 0xb4, 0x2f, 0xe8, 0xec, 0xbf, 0x65, 0x30, 0xf1,
		0x57, 0x7e, 0x9e, 0xf6, 0x0f, 0xed, 0xa6, 0x62, 0x88, 0xbf, 0x6e, 0x47, 0x0a, 0xe9, 0x4f, 0xfb,
		0x7d, 0x8b, 0x2e, 0x1d, 0x02, 0xaf, 0x8d, 0x0c, 0x0c, 0x06, 0x06, 0x03, 0x83, 0x23, 0x85, 0xc1,
		0x1d, 0xb7, 0xef, 0x48, 0xe1, 0xa1, 0xed, 0x21, 0x8c, 0x5e, 0x18, 0xbd, 0x11, 0xd8, 0x2a, 0xb4,
		0x3d, 0x3c, 0x54, 0x3b, 0xb8, 0x67, 0x76, 0xfe, 0x66, 0x22, 0x62, 0xeb, 0x43, 0x83, 0x89, 0x81,
		0x89, 0x81, 0x89, 0x81, 0x89, 0x81, 0x89, 0x81, 0x89, 0x81, 0x89, 0x81, 0x89, 0x25, 0x8f, 0x89,
		0xbd, 0x53, 0x28, 0xf3, 0xa9, 0xb2, 0xe3, 0xb8, 0x72, 0x1c, 0x12, 0x14, 0x46, 0xcc, 0x53, 0x7e,
		0xe7, 0x59, 0xbc, 0x98, 0xbd, 0x89, 0x03, 0x32, 0xed, 0xf6, 0x84, 0xd3, 0x19, 0x71, 0x24, 0xc3,
		0x11, 0xf2, 0x1f, 0xd7, 0xfb, 0xdb, 0xb0, 0x1c, 0x5f, 0x9a, 0x4e, 0x47, 0xa4, 0x57, 0xdf, 0xf0,
		0xd7, 0xde, 0x49, 0x9b, 0x8f, 0xd2, 0x4f, 0xf7, 0x5c, 0xdb, 0xea, 0xbc, 0x4e, 0xa9, 0x9f, 0xe5,
		0x3c, 0xad, 0xbf, 0x63, 0x08, 0x47, 0x7a, 0xaf, 0x63, 0x27, 0x66, 0x08, 0xe5, 0x93, 0xf2, 0xa5,
		0xd7, 0xef, 0x48, 0x67, 0xa2, 0xcf, 0xea, 0xb3, 0x2f, 0x7f, 0x33, 0xfe, 0x62, 0xd5, 0xc9, 0xf7,
		0x6a, 0xaf, 0xfc, 0xec, 0xaf, 0xbe, 0xd1, 0x2e, 0x3f, 0x4a, 0xbf, 0xdd, 0x18, 0x7d, 0xcd, 0x4f,
		0xb3, 0x6f, 0xb9, 0xf6, 0x46, 0x65, 0xf8, 0xad, 0xdb, 0x77, 0xa3, 0x6f, 0xfd, 0x4e, 0x8d, 0x8c,
		0xec, 0xf7, 0x89, 0x3d, 0xa5, 0x69, 0xc8, 0xeb, 0x46, 0xc5, 0x82, 0x9d, 0xae, 0xd8, 0x97, 0xd2,
		0xa5, 0x6a, 0x96, 0x2f, 0xcb, 0x52, 0x7a, 0x81, 0xe4, 0x6f, 0xa8, 0x4a, 0x2b, 0xb6, 0x18, 0x32,
		0x34, 0x3f, 0x18, 0xa2, 0x0e, 0x11, 0x7e, 0x61, 0x04, 0x1a, 0xec, 0x4c, 0xd5, 0xbd, 0xae, 0xf0,
		0x44, 0xf7, 0xe3, 0x70, 0x59, 0x9c, 0xbe, 0x6d, 0xb3, 0xae, 0x7e, 0xc8, 0x33, 0xac, 0xf5, 0xec,
		0x06, 0x38, 0xb5, 0x5a, 0x4e, 0xeb, 0x7e, 0xe7, 0x74, 0xf7, 0xd3, 0xb6, 0xdb, 0x6f, 0xee, 0x28,
		0x11, 0x41, 0x25, 0x41, 0x89, 0x04, 0xec, 0xb1, 0xd3, 0xcc, 0x3b, 0xbc, 0xdb, 0x5e, 0xfe, 0x7c,
		0x67, 0x7e, 0xfc, 0x1b, 0x3f, 0xd9, 0xb3, 0x7d, 0xf7, 0x8a, 0x61, 0x8f, 0x76, 0xd8, 0x11, 0xda,
		0x9d, 0xf8, 0xf1, 0xc2, 0x6f, 0x5f, 0xce, 0x1f, 0x2c, 0x65, 0xaa, 0x33, 0xf5, 0xc4, 0xfc, 0x78,
		0x09, 0x17, 0x8c, 0xd5, 0xd1, 0xef, 0xff, 0x64, 0x73, 0xa6, 0xb7, 0xb2, 0x3f, 0xf9, 0xb5, 0x5d,
		0xdd, 0x40, 0xfb, 0xb8, 0x79, 0x16, 0xdd, 0x38, 0x8e, 0x90, 0xc3, 0x1d, 0xdb, 0x65, 0xa3, 0xf6,
		0x74, 0xd5, 0x04, 0x76, 0xc5, 0x04, 0x76, 0xb5, 0xac, 0xba, 0x52, 0xa6, 0xcf, 0xc6, 0x7c, 0xcc,
		0xae, 0xac, 0xdd, 0x98, 0x45, 0xaa, 0x2b, 0xfc, 0x8e, 0x67, 0xf5, 0xf6, 0x02, 0xcf, 0xd9, 0x5e,
		0x2d, 0x7e, 0x78, 0xc7, 0xe5, 0xd8, 0xcf, 0x08, 0xdc, 0xdb, 0xe3, 0x18, 0xc4, 0xb3, 0x18, 0x4c,
		0xf4, 0xc2, 0x7a, 0x0b, 0x43, 0x7b, 0x05, 0x43, 0x7b, 0xff, 0x02, 0x8b, 0x26, 0x8f, 0x16, 0xdf,
		0xdb, 0x43, 0x37, 0xdb, 0x37, 0x5f, 0x7a, 0x7b, 0x6a, 0xda, 0x59, 0x4d, 0x00, 0x2a, 0x9d, 0xb8,
		0x03, 0x54, 0x09, 0xc7, 0x7c, 0xb0, 0xf7, 0xb8, 0x25, 0x58, 0x48, 0x60, 0x19, 0x7f, 0x10, 0x27,
		0x0c, 0x27, 0x4c, 0xd3, 0x09, 0x7b, 0x70, 0x5d, 0x5b, 0x98, 0x4e, 0x90, 0x23, 0x96, 0x55, 0x7f,
		0xc4, 0xa6, 0xd5, 0x43, 0x8c, 0x47, 0xf3, 0xc5, 0xb2, 0x2d, 0xe1, 0x07, 0x3e, 0x73, 0xeb, 0x23,
		0x25, 0xe4, 0x10, 0x5a, 0x86, 0x7d, 0x7a, 0x98, 0x47, 0x70, 0xf4, 0xe4, 0xb1, 0x3b, 0x80, 0xc1,
		0x1a, 0x52, 0x05, 0x69, 0x38, 0x15, 0xae, 0xa1, 0xd4, 0xec, 0x0b, 0x97, 0xaf, 0xae, 0x6e, 0x2b,
		0x77, 0x77, 0xed, 0x4f, 0xe5, 0xeb, 0x6a, 0xed, 0xcf, 0x7d, 0x77, 0x3d, 0x44, 0x4f, 0xa8, 0x60,
		0xde, 0xdc, 0xd9, 0xf7, 0xbe, 0x6e, 0xd4, 0xee, 0xf6, 0xf7, 0x4e, 0x06, 0xf0, 0x43, 0x87, 0xfc,
		0x9e, 0xd5, 0xc6, 0xef, 0xc5, 0x38, 0x7c, 0xcf, 0x5a, 0xae, 0x5d, 0x69, 0xfe, 0x5a, 0xb9, 0xbd,
		0xa9, 0x34, 0x63, 0xb2, 0xac, 0xf9, 0x14, 0xb3, 0x9b, 0xb9, 0xa5, 0x09, 0x7d, 0x02, 0xb9, 0x9c,
		0x83, 0xbb, 0x9a, 0x49, 0x5d, 0xcc, 0xc1, 0x5c, 0xcb, 0x34, 0xac, 0xe2, 0x45, 0xf6, 0xf7, 0x27,
		0x10, 0xc3, 0x0f, 0x81, 0xb0, 0x83, 0xb0, 0x6b, 0xe2, 0x0b, 0x7d, 0xcb, 0x91, 0xd9, 0x62, 0x00,
		0xaa, 0xb0, 0x47, 0xe5, 0x94, 0x80, 0x91, 0x26, 0xc1, 0xae, 0xbb, 0x02, 0xdf, 0xd3, 0x86, 0x0c,
		0x3b, 0x08, 0x1b, 0x09, 0x42, 0x11, 0x33, 0x30, 0x08, 0x76, 0xbf, 0xa7, 0x7d, 0xc9, 0x42, 0xd4,
		0xe9, 0x25, 0x59, 0x36, 0xa6, 0xcb, 0xab, 0x96, 0x42, 0xdd, 0x33, 0xb9, 0x82, 0xd8, 0x53, 0xf9,
		0x8c, 0x3e, 0x05, 0xed, 0x03, 0xed, 0x03, 0x87, 0xec, 0x0f, 0xe6, 0xf4, 0xdc, 0xbe, 0x14, 0x46,
		0xd7, 0xf2, 0xa5, 0xe5, 0x3c, 0xf5, 0x2d, 0xff, 0x59, 0x78, 0xfb, 0x1f, 0xb5, 0x4d, 0x83, 0xe0,
		0xe4, 0xe1, 0xe4, 0x69, 0x3a, 0x79, 0xc1, 0xc5, 0xf1, 0x28, 0x60, 0xd9, 0xc8, 0x60, 0xe5, 0x21,
		0x03, 0x90, 0xc0, 0xc0, 0xe0, 0xb2, 0x0e, 0x32, 0x01, 0x3e, 0x1b, 0xb6, 0xf6, 0x71, 0xea, 0x78,
		0xc8, 0x86, 0xee, 0x33, 0x46, 0xa1, 0xf5, 0x56, 0x2c, 0x14, 0xee, 0x33, 0x46, 0xae, 0x75, 0x9f,
		0x31, 0xce, 0x87, 0x3f, 0xdd, 0x67, 0x8c, 0xfc, 0xf8, 0x87, 0xef, 0xb9, 0xc1, 0x5b, 0x71, 0xe1,
		0xc7, 0xd3, 0xc1, 0xdb, 0xe8, 0x23, 0xe3, 0x9f, 0xf2, 0x83, 0xb7, 0xfb, 0xac, 0x71, 0x3e, 0xf9,
		0x29, 0xf3, 0xfe, 0x74, 0xf0, 0x96, 0x39, 0xb9, 0x38, 0xce, 0xe7, 0xce, 0xf3, 0xe7, 0xc5, 0x52,
		0xee, 0x7c, 0x3c, 0xfa, 0xf4, 0xc7, 0xfb, 0x8c, 0x71, 0x36, 0x99, 0x62, 0xf2, 0xd6, 0x7d, 0xc6,
		0xc8, 0xce, 0xe7, 0x19, 0xbf, 0x79, 0x9f, 0x31, 0x8a, 0xf3, 0xc9, 0x46, 0xef, 0x2d, 0xcf, 0x38,
		0x7c, 0x6b, 0x3e, 0xd4, 0xf7, 0xc2, 0xe8, 0x9d, 0xfb, 0x8c, 0x71, 0x3a, 0x79, 0xa3, 0x38, 0x7c,
		0x63, 0xe1, 0x17, 0x4a, 0x83, 0xb7, 0xfc, 0xc2, 0x44, 0x67, 0x83, 0xb7, 0xd3, 0xf1, 0xab, 0xf3,
		0x95, 0x6f, 0x7f, 0x36, 0xfc, 0xf6, 0xfb, 0xfb, 0x5a, 0x5a, 0x41, 0x36, 0x8f, 0xa2, 0x7a, 0x75,
		0xea, 0xaf, 0x63, 0xec, 0xe1, 0xa6, 0x3d, 0x3c, 0x09, 0x50, 0xa3, 0xbb, 0xc5, 0x19, 0x1a, 0x78,
		0x80, 0xe0, 0x72, 0x3c, 0x16, 0x92, 0xf9, 0xe6, 0xbc, 0x65, 0x47, 0x7f, 0x8d, 0x5f, 0xe7, 0xe6,
		0xe2, 0xf8, 0x96, 0x2b, 0x8c, 0x64, 0xe3, 0xe4, 0xcb, 0x97, 0x0f, 0x27, 0xdf, 0x4f, 0x07, 0xfb,
		0x7f, 0xf0, 0x82, 0xeb, 0x14, 0xc4, 0x0c, 0x0b, 0x92, 0xb0, 0xe4, 0x38, 0xba, 0xfa, 0x8f, 0x6e,
		0x9c, 0xa1, 0x1f, 0x58, 0x30, 0xc6, 0x02, 0xec, 0xa1, 0x1e, 0x70, 0x89, 0xa4, 0xcf, 0x6e, 0x64,
		0x83, 0x79, 0x86, 0xd5, 0x0d, 0xe8, 0x4d, 0x18, 0x7d, 0x14, 0x3e, 0x04, 0xf8, 0x10, 0x34, 0xf9,
		0x10, 0xba, 0xae, 0x94, 0xa2, 0x6b, 0xfc, 0x4f, 0xdf, 0xec, 0x06, 0x72, 0xe1, 0xed, 0xf1, 0x99,
		0xa0, 0xd8, 0xab, 0x94, 0xf0, 0xa6, 0x22, 0x89, 0x32, 0x72, 0x9f, 0xfd, 0x9d, 0xed, 0xed, 0xe8,
		0x53, 0xc0, 0x16, 0x60, 0x8b, 0x26, 0x6c, 0x89, 0x5d, 0x1c, 0xdb, 0x4d, 0xa5, 0xf9, 0xef, 0xfa,
		0xed, 0x6f, 0xed, 0xea, 0xcd, 0x5d, 0xb3, 0x7c, 0x73, 0x59, 0x69, 0x37, 0xff, 0x6c, 0x54, 0xe2,
		0x13, 0xce, 0x56, 0xcb, 0x35, 0x72, 0x8d, 0x78, 0xc4, 0x89, 0xd5, 0x4e, 0xe3, 0xf1, 0x3d, 0x7f,
		0xbf, 0xab, 0xc6, 0xe1, 0x8b, 0x5e, 0x55, 0x3e, 0x95, 0x3f, 0xd7, 0x9a, 0x33, 0xc1, 0x8d, 0xc5,
		0xe2, 0x9e, 0xfe, 0x7e, 0xfb, 0x29, 0x76, 0xe1, 0x77, 0x89, 0xce, 0x98, 0xdc, 0x29, 0x71, 0xf0,
		0x88, 0x34, 0x67, 0x72, 0x42, 0x24, 0x78, 0xb2, 0x26, 0x1d, 0x31, 0x0a, 0x2b, 0x31, 0x7a, 0xae,
		0x35, 0x8e, 0x4b, 0xdc, 0x3d, 0x81, 0x72, 0xe5, 0xa3, 0xc8, 0xa5, 0x44, 0x2e, 0xe5, 0x8f, 0xc5,
		0x6b, 0x7f, 0x7a, 0xbe, 0x36, 0xc2, 0x7e, 0x54, 0x3d, 0x0b, 0xaa, 0x0e, 0xaa, 0x1e, 0x4c, 0x78,
		0x17, 0x85, 0x78, 0x97, 0xcc, 0xf2, 0x1f, 0x89, 0xf0, 0x6e, 0x0a, 0x23, 0x84, 0x00, 0x07, 0x16,
		0xe4, 0x30, 0x02, 0x4d, 0x23, 0xd8, 0x61, 0x05, 0x9c, 0x4c, 0xd0, 0xc9, 0x04, 0x9e, 0x4c, 0xf0,
		0x83, 0xd1, 0xb9, 0x7d, 0xcb, 0xc6, 0xec, 0x7b, 0x20, 0xb6, 0xa2, 0xfb, 0x3e, 0x0e, 0xde, 0x9d,
		0x01, 0x7f, 0x77, 0xd7, 0x6f, 0x48, 0x77, 0x0d, 0xd9, 0x51, 0xa2, 0x38, 0x52, 0xb4, 0x47, 0x8b,
		0xea, 0x88, 0x91, 0x1f, 0x35, 0xf2, 0x23, 0x47, 0x7e, 0xf4, 0x82, 0x1d, 0xc1, 0x10, 0x06, 0xe3,
		0x11, 0x49, 0x6d, 0xce, 0xf0, 0x77, 0xc0, 0xeb, 0x5e, 0xec, 0x44, 0x54, 0x28, 0x8b, 0x56, 0x8d,
		0xac, 0x35, 0x1b, 0x6a, 0xed, 0x9d, 0x74, 0x20, 0xf6, 0x40, 0x6e, 0x7e, 0x4e, 0xbe, 0x53, 0x63,
		0xf4, 0x25, 0x57, 0xdf, 0xd8, 0xc9, 0x3e, 0x0d, 0xbe, 0xcd, 0x7b, 0x6c, 0x31, 0x89, 0x4a, 0x22,
		0x54, 0x45, 0x01, 0x55, 0x10, 0x58, 0x1c, 0x58, 0xdc, 0xbe, 0xc0, 0x16, 0x58, 0x65, 0x10, 0x34,
		0x33, 0x0a, 0xd3, 0xbc, 0x68, 0xb1, 0x59, 0xd1, 0x18, 0x9f, 0xd2, 0x9b, 0xce, 0x5d, 0x04, 0xb0,
		0x45, 0x38, 0xdd, 0x1d, 0x7d, 0x64, 0x5b, 0x97, 0x78, 0x3e, 0x04, 0xac, 0x41, 0xe0, 0x48, 0xb2,
		0xac, 0xc1, 0xa9, 0x6c, 0x87, 0x37, 0x01, 0x67, 0x23, 0x85, 0xb3, 0xfb, 0xb2, 0xb0, 0xfb, 0x60,
		0xf7, 0xc5, 0xcb, 0xee, 0x0b, 0x7a, 0xf8, 0xc2, 0xfa, 0x2a, 0x69, 0x7d, 0x97, 0xc4, 0x07, 0x92,
		0xec, 0x60, 0x52, 0x1e, 0x50, 0x9e, 0x83, 0x4a, 0x7d, 0x60, 0xd9, 0x0e, 0x2e, 0xdb, 0x01, 0x66,
		0x3b, 0xc8, 0xe1, 0x0e, 0x74, 0xc8, 0x83, 0x4d, 0x76, 0xc0, 0xd7, 0xb4, 0x6d, 0x18, 0x9f, 0xeb,
		0x4f, 0x15, 0x70, 0x70, 0xdf, 0x2b, 0xb1, 0x2f, 0x96, 0x0d, 0x0a, 0x38, 0x20, 0x81, 0x17, 0x1a,
		0xb8, 0x20, 0x82, 0x1d, 0x2a, 0xd8, 0x21, 0x83, 0x1d, 0x3a, 0x68, 0x20, 0x84, 0x08, 0x4a, 0xc2,
		0x1b, 0xfe, 0x3f, 0x95, 0xdb, 0xd0, 0xbe, 0xe3, 0xad, 0x44, 0xe0, 0x2c, 0x22, 0xbd, 0x5d, 0x08,
		0xf6, 0x60, 0x78, 0x48, 0x3a, 0xa2, 0x2b, 0x1c, 0x4a, 0x75, 0x3d, 0x6b, 0x7b, 0x37, 0x1f, 0x1b,
		0x38, 0x0c, 0x1c, 0x06, 0x0e, 0x1f, 0x24, 0x0e, 0xef, 0x5d, 0xba, 0x6c, 0x57, 0x14, 0x28, 0x12,
		0x0e, 0x49, 0xdb, 0x64, 0x6f, 0xfa, 0x87, 0xf6, 0x4c, 0x1d, 0x71, 0x35, 0xdd, 0x63, 0x82, 0xd7,
		0xb5, 0xe1, 0x99, 0x9a, 0xf0, 0xcd, 0xc6, 0x67, 0x6c, 0xe7, 0x46, 0x7c, 0xdc, 0x96, 0xb7, 0x94,
		0xa1, 0x39, 0x9f, 0xea, 0x2d, 0x0d, 0x51, 0x1a, 0x2e, 0x12, 0xdb, 0xfa, 0x2e, 0x9a, 0xa3, 0xb5,
		0x12, 0xc4, 0x34, 0x25, 0xa5, 0x86, 0x09, 0x92, 0x00, 0x07, 0x76, 0x09, 0x76, 0x09, 0x76, 0x99,
		0x30, 0x76, 0x19, 0x2c, 0x01, 0x71, 0x67, 0x53, 0x9f, 0x50, 0xa7, 0x85, 0x4b, 0x60, 0xdc, 0x79,
		0x41, 0x2a, 0x37, 0x57, 0x8d, 0x7a, 0xf5, 0xa6, 0x19, 0x24, 0xb1, 0x71, 0x37, 0x75, 0xef, 0x93,
		0xf3, 0x64, 0x1e, 0xae, 0xbc, 0xb4, 0x2c, 0xb5, 0xfa, 0x65, 0xb9, 0x96, 0x8a, 0x03, 0x1f, 0x64,
		0x5e, 0x88, 0xdb, 0xca, 0x75, 0xbd, 0x59, 0x49, 0x45, 0x9c, 0x42, 0xb5, 0x12, 0xd7, 0x88, 0x59,
		0xef, 0xcd, 0x0d, 0x51, 0x83, 0xe4, 0xd9, 0x78, 0xca, 0x03, 0x49, 0x67, 0xb1, 0x47, 0xb3, 0x57,
		0x69, 0x92, 0xdb, 0xdd, 0x23, 0xb5, 0xb1, 0xa6, 0x95, 0xe9, 0x63, 0xcc, 0x5e, 0x05, 0x0a, 0x3f,
		0xa5, 0x13, 0xae, 0x10, 0x82, 0x45, 0x7a, 0x8b, 0xc7, 0x70, 0x7b, 0x47, 0xc4, 0xe7, 0x71, 0x71,
		0x1f, 0x3d, 0x9e, 0x8e, 0x8b, 0x7b, 0x4d, 0xfc, 0x9b, 0x20, 0xdc, 0x76, 0x2b, 0xd7, 0x2e, 0x11,
		0x8c, 0xb5, 0x1e, 0x8e, 0xbb, 0x88, 0x27, 0x31, 0xc4, 0x58, 0xdb, 0xed, 0x98, 0x36, 0x1d, 0xba,
		0x8e, 0x87, 0x43, 0x40, 0x14, 0x70, 0x15, 0xb8, 0x1a, 0xa5, 0x80, 0x28, 0xa2, 0xc8, 0xc7, 0x35,
		0x31, 0x26, 0xe3, 0xc8, 0x84, 0x07, 0x9f, 0x1c, 0x00, 0x38, 0x80, 0x80, 0x17, 0x10, 0xb8, 0x80,
		0x81, 0x1d, 0x20, 0xd8, 0x81, 0x82, 0x1d, 0x30, 0x88, 0xfd, 0x02, 0x44, 0x92, 0x4b, 0x05, 0x24,
		0xb3, 0x01, 0x2d, 0x47, 0x0a, 0xef, 0xd1, 0xec, 0x30, 0x7a, 0x1a, 0xe7, 0x53, 0x10, 0x6f, 0x3d,
		0xcf, 0x9d, 0x25, 0x39, 0xdc, 0x70, 0xc2, 0xce, 0x26, 0xf8, 0xb1, 0x1e, 0x53, 0x0c, 0xb7, 0xcf,
		0x4c, 0x08, 0xa4, 0x0c, 0x89, 0x94, 0x21, 0xd2, 0x36, 0x64, 0xb2, 0x1e, 0xa3, 0xee, 0x4c, 0x25,
		0x76, 0x52, 0xd3, 0xdf, 0xe6, 0x30, 0x5a, 0x97, 0x9c, 0xd6, 0xe6, 0x56, 0xeb, 0x33, 0x3d, 0x12,
		0x8b, 0x8b, 0x19, 0x40, 0xfa, 0xab, 0x6f, 0x4c, 0x7e, 0x1e, 0x79, 0x1c, 0x23, 0x1a, 0x7a, 0x40,
		0x28, 0x34, 0x29, 0xdf, 0x92, 0x82, 0x32, 0xd4, 0x7f, 0x4d, 0x5e, 0xa6, 0x13, 0x40, 0x11, 0xa9,
		0x50, 0x44, 0xf4, 0x3c, 0x18, 0xda, 0x28, 0xb2, 0x3c, 0x19, 0x2a, 0x89, 0x29, 0x8c, 0x75, 0x15,
		0x65, 0x8a, 0x0c, 0x43, 0xf3, 0x84, 0xb5, 0x4e, 0xff, 0xf0, 0x9c, 0xd1, 0x23, 0xee, 0x30, 0x57,
		0x66, 0x78, 0x5f, 0x9b, 0x86, 0x39, 0xec, 0x75, 0x36, 0x8f, 0x82, 0x38, 0x49, 0xa6, 0xe3, 0xbb,
		0xbc, 0xf5, 0x8c, 0xe1, 0xb0, 0xba, 0xb6, 0x9e, 0x31, 0x3c, 0x56, 0xcb, 0xf6, 0xbf, 0x8b, 0xc7,
		0xa8, 0xad, 0x43, 0xe1, 0xd6, 0xb6, 0xf9, 0x20, 0x6c, 0xe3, 0xc1, 0x76, 0x3b, 0x7f, 0x1b, 0xee,
		0xe3, 0xa3, 0x2f, 0x24, 0x33, 0xd7, 0xde, 0x30, 0x21, 0xb8, 0x37, 0xb8, 0x37, 0xb8, 0x37, 0xb8,
		0x37, 0xb8, 0x37, 0xb8, 0x37, 0xb8, 0x37, 0xb8, 0x37, 0xb8, 0x37, 0xb8, 0xf7, 0xa1, 0x71, 0x6f,
		0xdf, 0xfa, 0x5f, 0xa1, 0x90, 0x79, 0x8f, 0xa6, 0x03, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef,
		0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x4e, 0x3a, 0xef, 0xee,
		0x3f, 0x28, 0x88, 0x6f, 0x5c, 0x9a, 0x05, 0x2c, 0x1b, 0x21, 0x8e, 0x07, 0x4b, 0xb0, 0x11, 0xe2,
		0x48, 0x2f, 0xed, 0x49, 0x0f, 0x71, 0xbc, 0x9f, 0x87, 0x38, 0xfe, 0x47, 0xa7, 0xef, 0x79, 0xc2,
		0x91, 0xc7, 0x27, 0xe9, 0x0f, 0x1f, 0xd2, 0xb3, 0xdf, 0x68, 0x4d, 0x3e, 0xb2, 0x88, 0xb3, 0xfe,
		0x86, 0xf7, 0x66, 0x23, 0x77, 0xc5, 0xb7, 0xc8, 0x46, 0x4b, 0x46, 0x2a, 0x9b, 0x80, 0x38, 0xdb,
		0x7f, 0xae, 0x77, 0x23, 0x90, 0xf5, 0x3f, 0xca, 0x60, 0x4c, 0x93, 0xe6, 0x35, 0x1d, 0x69, 0xaf,
		0x01, 0x50, 0x1b, 0x3e, 0x14, 0x49, 0x25, 0x00, 0x3a, 0x81, 0x1c, 0x90, 0x14, 0x56, 0x30, 0x25,
		0x43, 0xd1, 0xaf, 0xf1, 0xb0, 0x11, 0x4f, 0x6a, 0xcb, 0x21, 0xa9, 0x0d, 0x49, 0x6d, 0x3f, 0xe6,
		0x55, 0x48, 0x6a, 0xdb, 0x6f, 0x40, 0x24, 0xb5, 0xc1, 0xe2, 0x83, 0xc5, 0x07, 0x8b, 0x0f, 0x16,
		0x5f, 0x14, 0x2d, 0x3e, 0x24, 0xb5, 0x11, 0xfb, 0x1f, 0x91, 0xd4, 0x86, 0x0b, 0x7e, 0x68, 0x23,
		0x5c, 0xf0, 0xe3, 0x82, 0x7f, 0x69, 0x68, 0x5c, 0xf0, 0xab, 0x87, 0xf7, 0xb5, 0x69, 0x70, 0xc1,
		0xbf, 0xdf, 0xd6, 0xe3, 0x82, 0x3f, 0xf2, 0xdb, 0x8f, 0x0b, 0xfe, 0x68, 0x71, 0x6b, 0x24, 0xb5,
		0x81, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b, 0x83, 0x7b,
		0x83, 0x7b, 0x83, 0x7b, 0xab, 0xe7, 0xde, 0x48, 0x6a, 0x03, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06,
		0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0x06, 0xef, 0xa6, 0xe7, 0xdd,
		0x48, 0x6a, 0x4b, 0x26, 0xcb, 0x46, 0x88, 0x63, 0x24, 0x09, 0x36, 0x42, 0x1c, 0xe9, 0xa5, 0x1d,
		0x49, 0x6d, 0x48, 0x6a, 0x63, 0x92, 0xe2, 0x03, 0x48, 0x6a, 0xa3, 0x4c, 0x6b, 0x3a, 0x8a, 0x48,
		0x4e, 0xdb, 0xdd, 0xe8, 0x99, 0xd0, 0x83, 0x39, 0xa1, 0x3d, 0x98, 0x29, 0xfa, 0x49, 0x46, 0x44,
		0x54, 0xe3, 0xd8, 0x1d, 0xd4, 0x13, 0x2f, 0x2e, 0x41, 0x82, 0xe5, 0x4c, 0x7f, 0x4f, 0xc6, 0x43,
		0x7f, 0xd0, 0x5d, 0x78, 0x3d, 0xfa, 0x83, 0xa2, 0x3f, 0xe8, 0x4f, 0x9e, 0x0a, 0xfd, 0x41, 0xa3,
		0x64, 0xf8, 0x23, 0x95, 0x5a, 0x99, 0x75, 0x8f, 0x54, 0x6a, 0x5a, 0xe3, 0x87, 0x3c, 0x95, 0x7a,
		0xac, 0xe9, 0x0d, 0xff, 0xd5, 0x97, 0xe2, 0x85, 0xcf, 0xdd, 0xb8, 0x3c, 0x0d, 0xfc, 0x8d, 0xb8,
		0xd5, 0x3f, 0x6c, 0xa7, 0x23, 0x6e, 0xf5, 0x99, 0xe4, 0xde, 0xea, 0x19, 0x66, 0xb7, 0xeb, 0x09,
		0xdf, 0xe7, 0x74, 0x3e, 0x9e, 0x33, 0x8c, 0x3d, 0x59, 0x9b, 0xd8, 0xdd, 0xec, 0xcf, 0x57, 0xfe,
		0x6b, 0x9e, 0x71, 0xed, 0xd7, 0xf6, 0xe0, 0x8c, 0x71, 0x8e, 0x86, 0x29, 0xa5, 0xf0, 0x1c, 0xb6,
		0xed, 0x98, 0x4d, 0x74, 0x7c, 0x7c, 0x9f, 0x31, 0xce, 0x5b, 0x6f, 0xf7, 0x59, 0xe3, 0xbc, 0x35,
		0x7e, 0x99, 0x1d, 0xfd, 0x35, 0x7e, 0x9d, 0xbb, 0xcf, 0x18, 0xf9, 0xe9, 0xeb, 0xc2, 0x7d, 0xc6,
		0x28, 0xb4, 0x4e, 0xbe, 0x7c, 0xf9, 0x70, 0xf2, 0xfd, 0x74, 0xb0, 0xff, 0x07, 0x8f, 0xff, 0xcf,
		0xfd, 0x97, 0x2f, 0xbd, 0xef, 0x37, 0x83, 0xe1, 0xff, 0x6b, 0x83, 0xd6, 0xff, 0x3b, 0xf9, 0xcf,
		0x14, 0xdb, 0xd3, 0xb5, 0x78, 0x6e, 0x94, 0xdf, 0xc7, 0xf8, 0x74, 0x14, 0x71, 0x3a, 0xf6, 0x3e,
		0x1d, 0x17, 0x6f, 0x43, 0x19, 0x36, 0x8d, 0xc7, 0xb2, 0xf1, 0xa9, 0xf5, 0x3d, 0xf3, 0x3e, 0x3f,
		0x38, 0xb9, 0x38, 0x39, 0x5e, 0x7d, 0xef, 0xe2, 0xe4, 0x7b, 0xe6, 0x7d, 0x61, 0x70, 0x7c, 0xbc,
		0xe1, 0x5f, 0xfe, 0x73, 0xd3, 0x18, 0x27, 0x6f, 0xc7, 0xc7, 0xc7, 0x93, 0x73, 0xb1, 0x74, 0x56,
		0xee, 0x33, 0xd9, 0xd6, 0x7f, 0x8e, 0x5e, 0x8e, 0xff, 0x3f, 0x3b, 0x6d, 0x3b, 0xfd, 0xf2, 0xc9,
		0xc6, 0x33, 0xf6, 0x9e, 0x1d, 0x42, 0xfe, 0xba, 0x68, 0xfd, 0xbf, 0x8b, 0x93, 0xef, 0xc5, 0xc1,
		0xf4, 0xf5, 0xe8, 0xff, 0x27, 0x6f, 0xc7, 0x1f, 0xfe, 0xef, 0x97, 0x2f, 0x1f, 0x3e, 0xfc, 0xdf,
		0x93, 0xf1, 0x03, 0x4f, 0x7e, 0xef, 0xff, 0x8e, 0xff, 0xf5, 0x3f, 0x2f, 0x2e, 0xd6, 0xde, 0x3a,
		0x39, 0xfe, 0x3f, 0x1f, 0xe2, 0x08, 0x0b, 0x08, 0x34, 0x09, 0x20, 0x38, 0x28, 0x5c, 0x02, 0x73,
		0x0f, 0xe6, 0x1e, 0xcc, 0xbd, 0x38, 0x9b, 0x7b, 0x08, 0xe2, 0x56, 0x49, 0x66, 0x11, 0xc4, 0xbd,
		0xff, 0x3c, 0x08, 0xe2, 0x8e, 0xec, 0xd6, 0x23, 0x88, 0x1b, 0xdc, 0x9a, 0x89, 0x5b, 0x7f, 0xb5,
		0x3c, 0xd9, 0x37, 0x6d, 0xa3, 0x63, 0x79, 0x9d, 0xbe, 0x25, 0x0d, 0xab, 0x2b, 0x1c, 0x69, 0x3d,
		0x5a, 0xc2, 0xe3, 0xa3, 0xdb, 0x3f, 0x98, 0x13, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x9c,
		0x89, 0x81, 0x9f, 0xe6, 0x18, 0x19, 0x78, 0x09, 0x0c, 0x1c, 0x0c, 0x1c, 0x0c, 0x3c, 0x91, 0x0c,
		0x3c, 0x9f, 0x3b, 0xcf, 0x9f, 0x17, 0x4b, 0xb9, 0x73, 0xd0, 0x70, 0xd0, 0x70, 0xd2, 0x91, 0x90,
		0x6d, 0xf2, 0xf3, 0xa0, 0xfd, 0x71, 0x50, 0x56, 0xd2, 0x7a, 0x28, 0xdd, 0x8e, 0x9e, 0x0a, 0x4d,
		0x94, 0x76, 0x25, 0x70, 0x68, 0xa2, 0x14, 0x65, 0x0b, 0x10, 0x91, 0xbf, 0xda, 0x2c, 0x3c, 0x44,
		0xfe, 0x52, 0x9c, 0x0a, 0x44, 0xfe, 0xc2, 0x11, 0x05, 0x47, 0x14, 0x1c, 0x51, 0x88, 0xfc, 0xfd,
		0xd9, 0xda, 0x20, 0xf2, 0x77, 0xc7, 0x3d, 0x40, 0xe4, 0x2f, 0x22, 0x7f, 0x63, 0x75, 0x3a, 0x10,
		0xf9, 0xbb, 0xff, 0xe9, 0x40, 0xe4, 0xef, 0x2e, 0x10, 0x82, 0xc8, 0xdf, 0x83, 0x71, 0x8b, 0x22,
		0xf2, 0x17, 0xe6, 0x1e, 0xcc, 0x3d, 0x98, 0x7b, 0x30, 0xf7, 0x10, 0xf9, 0xab, 0x9c, 0xcc, 0x22,
		0xee, 0x60, 0xff, 0x79, 0x10, 0x77, 0x10, 0xd9, 0xad, 0x47, 0xe4, 0x2f, 0xb8, 0x35, 0x13, 0xb7,
		0x46, 0xe4, 0x2f, 0x18, 0x38, 0x18, 0x38, 0x18, 0xf8, 0x61, 0x30, 0x70, 0x44, 0xfe, 0x82, 0x81,
		0x83, 0x81, 0x83, 0x81, 0xef, 0xbd, 0xf5, 0x88, 0xfc, 0x05, 0x0d, 0xe7, 0x19, 0x09, 0x91, 0xbf,
		0x3b, 0x47, 0xfe, 0x26, 0xab, 0xd0, 0xfc, 0x24, 0xf0, 0x17, 0x95, 0xe6, 0xb9, 0x44, 0x38, 0x42,
		0xa2, 0x1b, 0xfb, 0x52, 0xf3, 0x63, 0x61, 0x8d, 0x63, 0xad, 0x79, 0x9a, 0x30, 0x74, 0xd2, 0xf0,
		0x73, 0xf2, 0x4a, 0xf3, 0x39, 0x54, 0x9a, 0x8f, 0x88, 0x1b, 0x01, 0x95, 0xe6, 0xf7, 0x7b, 0x2a,
		0xb2, 0x4a, 0xf3, 0x43, 0xd6, 0xfc, 0x95, 0x21, 0xdd, 0x64, 0x32, 0x2e, 0x6d, 0xbe, 0x49, 0x06,
		0x95, 0xe6, 0x23, 0xee, 0x6f, 0x44, 0xbe, 0x49, 0xcc, 0xcc, 0x1f, 0x72, 0xff, 0xe1, 0x4c, 0x6e,
		0x1f, 0x5c, 0xd7, 0x16, 0xa6, 0x43, 0x29, 0xb4, 0x53, 0xfd, 0x9f, 0x4d, 0x50, 0xba, 0xdf, 0x94,
		0xf1, 0x52, 0x06, 0x6a, 0xcd, 0xf6, 0x60, 0x71, 0x70, 0x40, 0x31, 0xa0, 0x18, 0x50, 0x7c, 0x90,
		0x50, 0xec, 0x4b, 0xcf, 0x72, 0x9e, 0x38, 0x90, 0xf8, 0x2c, 0x41, 0x48, 0xdc, 0xf3, 0x44, 0x47,
		0x74, 0x85, 0xd3, 0x61, 0xa0, 0xc3, 0x0b, 0x63, 0x03, 0x87, 0x81, 0xc3, 0xc0, 0xe1, 0x83, 0xc4,
		0x61, 0xf2, 0x60, 0x56, 0x86, 0x20, 0x56, 0xa6, 0xab, 0x73, 0x86, 0x00, 0x05, 0xce, 0xab, 0x72,
		0xe6, 0x7b, 0x52, 0xee, 0xab, 0x71, 0x15, 0xd7, 0xa1, 0x0c, 0x57, 0xe1, 0xac, 0x57, 0xe0, 0xaa,
		0xb6, 0x94, 0x31, 0xe8, 0x54, 0xc9, 0xb6, 0x46, 0xf4, 0xd6, 0xb8, 0x95, 0x20, 0xa6, 0x29, 0x29,
		0x35, 0xcc, 0x4c, 0xbb, 0x8c, 0x46, 0x05, 0xbb, 0x04, 0xbb, 0x04, 0xbb, 0x3c, 0x48, 0x76, 0x39,
		0x0e, 0x07, 0x97, 0xaf, 0x9e, 0x78, 0xe4, 0x30, 0xf5, 0x09, 0x75, 0x5a, 0xaa, 0x3a, 0xf9, 0xaa,
		0x1f, 0x4d, 0x5f, 0xf0, 0xc5, 0xcb, 0x57, 0x6e, 0xae, 0x1a, 0xf5, 0xea, 0x4d, 0xb3, 0xdd, 0xfc,
		0xb3, 0x51, 0xa1, 0x3e, 0x16, 0x23, 0x75, 0xef, 0xb3, 0x84, 0x98, 0x32, 0xf1, 0x9f, 0xe9, 0xb2,
		0xd4, 0xea, 0x97, 0xe5, 0x5a, 0x2a, 0x0e, 0x7c, 0x90, 0x79, 0x21, 0x6e, 0x2b, 0xd7, 0xf5, 0x66,
		0x25, 0xea, 0x11, 0xe3, 0xad, 0xa8, 0x01, 0x21, 0xa2, 0xa5, 0x96, 0xc6, 0x8b, 0x42, 0xb4, 0x14,
		0x55, 0x84, 0x9f, 0xde, 0x60, 0x29, 0x82, 0x90, 0xbe, 0x10, 0xb1, 0x52, 0xef, 0x14, 0x0a, 0xe3,
		0x90, 0xb5, 0xd1, 0xdc, 0xcf, 0xa5, 0x6a, 0x96, 0x2f, 0xcb, 0x52, 0x86, 0x0b, 0x07, 0x49, 0x5d,
		0x5b, 0x4e, 0xc5, 0x16, 0x43, 0x16, 0xe6, 0x87, 0x63, 0xe9, 0x43, 0x13, 0x7e, 0x61, 0xa4, 0xec,
		0x59, 0x3e, 0x5f, 0x2c, 0xe5, 0xf3, 0x99, 0xd2, 0x69, 0x29, 0x73, 0x5e, 0x28, 0x64, 0x8b, 0x61,
		0x78, 0x44, 0xaa, 0xee, 0x75, 0x85, 0x27, 0xba, 0x1f, 0x87, 0x8b, 0xe7, 0xf4, 0x6d, 0x5b, 0xe9,
		0x9e, 0x11, 0x01, 0x47, 0x14, 0x00, 0x23, 0x15, 0x2a, 0x30, 0x50, 0x1f, 0x44, 0x04, 0x03, 0x87,
		0xfd, 0x8f, 0xf6, 0x7e, 0x9f, 0xd8, 0x53, 0xa0, 0xc2, 0x0a, 0x92, 0x46, 0x01, 0x0a, 0x20, 0x37,
		0x3a, 0xe4, 0x65, 0x3f, 0x31, 0xd9, 0x7d, 0xb3, 0xf7, 0xd8, 0xe8, 0x80, 0xf1, 0xb3, 0xa1, 0xe2,
		0x65, 0x03, 0xc6, 0xc7, 0x06, 0x8e, 0x87, 0x0d, 0xe3, 0x85, 0xa1, 0xf1, 0xb6, 0x84, 0xf5, 0xaa,
		0x90, 0x79, 0x4f, 0xc8, 0xbc, 0x24, 0x64, 0xde, 0x10, 0x5e, 0x08, 0x0b, 0x1a, 0x7f, 0x9a, 0x5a,
		0xc5, 0x96, 0x30, 0x61, 0x4f, 0x33, 0x19, 0xda, 0x34, 0x68, 0x50, 0x62, 0x16, 0xca, 0xf1, 0x19,
		0xda, 0xd1, 0x49, 0xe1, 0xd8, 0xa4, 0x75, 0x64, 0x52, 0x39, 0x2e, 0xc9, 0x1d, 0x95, 0xe4, 0x8e,
		0x49, 0x72, 0x47, 0xa4, 0x5a, 0x93, 0x22, 0xb4, 0x63, 0x91, 0x2e, 0x5c, 0x28, 0x64, 0x78, 0x10,
		0xf8, 0x5a, 0x48, 0xbe, 0x16, 0xd4, 0x1d, 0xa0, 0x90, 0xab, 0x05, 0xb0, 0xf5, 0xf7, 0xe0, 0x69,
		0xef, 0x08, 0xc5, 0x60, 0x6a, 0xab, 0x07, 0x57, 0x32, 0xc1, 0x6c, 0xf4, 0xe0, 0x36, 0x39, 0xa9,
		0x0d, 0x1e, 0xcc, 0xe6, 0xde, 0x75, 0x6d, 0x03, 0x1e, 0x2d, 0xe5, 0x47, 0x2a, 0xb5, 0x17, 0xf3,
		0x57, 0x74, 0x88, 0x76, 0x3b, 0x3e, 0x3f, 0x3f, 0x0c, 0x3f, 0xfe, 0x8d, 0x9f, 0x6c, 0xe5, 0xbe,
		0x5b, 0xc8, 0xbd, 0x75, 0x3b, 0xec, 0x14, 0xdf, 0x0e, 0xfd, 0x78, 0x47, 0xb6, 0xaf, 0xf3, 0x0f,
		0xd6, 0x38, 0x25, 0x9c, 0x8e, 0xd9, 0xf3, 0xfb, 0xf6, 0x6e, 0x4b, 0xbc, 0x10, 0xfa, 0xbf, 0xf8,
		0xb1, 0x9f, 0xec, 0xe1, 0x6e, 0x86, 0xe3, 0xce, 0xec, 0x76, 0x1f, 0x16, 0x1b, 0x8c, 0xad, 0xee,
		0xcb, 0x4a, 0x03, 0xb3, 0xcf, 0xc0, 0x2c, 0x33, 0x30, 0x9b, 0x0c, 0x77, 0x1a, 0x77, 0x35, 0xcc,
		0x52, 0x9d, 0xe9, 0x5e, 0xee, 0xb8, 0x80, 0x0b, 0xb6, 0xd6, 0xee, 0x6d, 0xc4, 0xf6, 0xf4, 0x48,
		0xec, 0x6d, 0x3e, 0x05, 0x31, 0x97, 0xc2, 0x99, 0x47, 0x41, 0xcd, 0xa1, 0xd0, 0xe6, 0x4f, 0x68,
		0x73, 0x27, 0xb4, 0x79, 0x43, 0xcb, 0xaa, 0xf6, 0xf5, 0x20, 0x0c, 0x05, 0x4f, 0x7a, 0xae, 0x6d,
		0x4c, 0x56, 0x31, 0xa0, 0x5f, 0x6d, 0x69, 0x94, 0x60, 0xee, 0xb5, 0x4c, 0x50, 0xf7, 0x5a, 0x06,
		0xee, 0x35, 0xb8, 0xd7, 0x78, 0x6d, 0x79, 0x82, 0xec, 0xcb, 0x80, 0x59, 0x96, 0x3c, 0x5e, 0xf4,
		0x25, 0x16, 0x63, 0x04, 0x8a, 0x9b, 0xdc, 0xcc, 0x88, 0x8c, 0x00, 0xd1, 0x92, 0x00, 0x00, 0x00,
		0x40, 0x6c, 0x00, 0x20, 0x5c, 0x34, 0x60, 0x98, 0xa8, 0x3f, 0x9a, 0xe8, 0xbe, 0x85, 0x28, 0xbe,
		0xcb, 0x72, 0xe3, 0xee, 0x73, 0xad, 0xdc, 0xac, 0xd6, 0x6f, 0x82, 0x8a, 0x0f, 0x41, 0xb4, 0x1e,
		0x51, 0x21, 0x9c, 0xdf, 0xff, 0xa8, 0x95, 0x6f, 0x52, 0x3a, 0x4a, 0xfa, 0x10, 0x3d, 0xc0, 0x75,
		0xa3, 0x76, 0xa7, 0xda, 0x27, 0xde, 0xe2, 0x3e, 0x9e, 0x2c, 0xca, 0xcb, 0x36, 0x1f, 0x84, 0x6d,
		0x98, 0xb6, 0xed, 0x76, 0xc6, 0x3a, 0xe7, 0xc5, 0xed, 0x86, 0xd0, 0x5f, 0x9b, 0x87, 0x83, 0x0a,
		0x83, 0x0a, 0x83, 0x0a, 0x8b, 0xb6, 0x0a, 0xab, 0x95, 0x3f, 0x56, 0x6a, 0xed, 0x72, 0xad, 0x56,
		0xbf, 0x1c, 0x69, 0xb1, 0xf6, 0x75, 0xfd, 0xaa, 0x12, 0x7f, 0x55, 0xd6, 0xa8, 0xdc, 0xb6, 0x6f,
		0x2a, 0x7f, 0x34, 0x7f, 0xad, 0x37, 0xe2, 0xac, 0xd0, 0xaa, 0x37, 0x77, 0xcd, 0xf2, 0xcd, 0x65,
		0xa5, 0x3d, 0xda, 0xa6, 0x38, 0x3f, 0xc9, 0x70, 0x43, 0x1a, 0xb7, 0x95, 0x4f, 0xd5, 0x3f, 0x0e,
		0x58, 0x41, 0x27, 0xf0, 0x7e, 0x6a, 0xc9, 0x72, 0x4d, 0xef, 0xe5, 0x81, 0x3d, 0x22, 0xbd, 0xef,
		0xa8, 0x2c, 0x7e, 0x91, 0xf6, 0x84, 0x14, 0x50, 0xdd, 0x42, 0xed, 0x74, 0x71, 0xb3, 0x4f, 0x50,
		0x5d, 0xa0, 0x60, 0xba, 0xc0, 0x2e, 0xeb, 0x1c, 0x5c, 0xd6, 0xd4, 0x8c, 0x07, 0x2e, 0x6b, 0xb8,
		0xac, 0x41, 0xf7, 0xe1, 0xb2, 0xde, 0x19, 0xb3, 0xe1, 0xb2, 0x06, 0x00, 0x00, 0x00, 0x60, 0xef,
		0x6b, 0xb6, 0xf7, 0xe1, 0xb2, 0x8e, 0x96, 0x5d, 0x0c, 0x97, 0xf5, 0xae, 0x2b, 0x06, 0x97, 0x35,
		0x54, 0x18, 0x54, 0x18, 0x54, 0x18, 0x5c, 0xd6, 0x91, 0x56, 0x68, 0x70, 0x59, 0x27, 0x4a, 0x41,
		0x27, 0xde, 0x65, 0xbd, 0x6f, 0x42, 0x12, 0x97, 0xc7, 0x7a, 0x8f, 0xac, 0xa3, 0x64, 0xa7, 0x4d,
		0xec, 0x93, 0x1d, 0xc0, 0xb8, 0x21, 0x1c, 0xf9, 0x12, 0x8f, 0xdd, 0x87, 0xdd, 0xb3, 0x24, 0x86,
		0xbf, 0x8c, 0xdc, 0x08, 0xe4, 0x46, 0x2c, 0xff, 0x22, 0x72, 0x23, 0x70, 0xd1, 0x14, 0xab, 0x8b,
		0xa6, 0x17, 0xb3, 0x63, 0x98, 0x4f, 0x96, 0xf3, 0x64, 0x48, 0xeb, 0x25, 0x84, 0xbd, 0xbe, 0x32,
		0x0e, 0x0c, 0x75, 0x18, 0xea, 0x09, 0x35, 0xd4, 0x03, 0x97, 0xe2, 0x0f, 0x51, 0x72, 0x3f, 0x64,
		0x69, 0xfd, 0x70, 0xe5, 0xdd, 0x08, 0x0a, 0x78, 0x90, 0xd4, 0x84, 0xa6, 0x2a, 0x7d, 0x4f, 0x59,
		0x0b, 0x7d, 0x10, 0xae, 0xde, 0x5d, 0xe4, 0x96, 0x96, 0xa0, 0x04, 0x3d, 0xe9, 0xf2, 0x2a, 0xaa,
		0x02, 0xd2, 0x8a, 0x80, 0x03, 0x7d, 0xa8, 0x41, 0x6d, 0x61, 0x7a, 0x8e, 0xe5, 0x3c, 0x85, 0xd3,
		0xc3, 0xb3, 0x51, 0xa0, 0x85, 0xa1, 0x85, 0x11, 0xf2, 0xb1, 0xcd, 0x7a, 0xca, 0x46, 0xe2, 0xd0,
		0x7f, 0xb3, 0x5e, 0xfa, 0x2f, 0x86, 0x70, 0xa4, 0x67, 0x8d, 0x1c, 0xdd, 0x81, 0xcf, 0xfd, 0xf2,
		0x40, 0x38, 0xfa, 0x38, 0xfa, 0x20, 0xe0, 0x20, 0xe0, 0x20, 0xe0, 0x20, 0xe0, 0x87, 0x4c, 0xc0,
		0x13, 0x78, 0x41, 0xf6, 0xd8, 0x7d, 0xd0, 0x99, 0xc9, 0xf1, 0xa9, 0xfb, 0xa0, 0x21, 0x7f, 0x63,
		0x68, 0xd7, 0x48, 0xf3, 0xc1, 0x0e, 0x90, 0xc3, 0x31, 0xff, 0x28, 0xdc, 0xeb, 0x70, 0xaf, 0x87,
		0x02, 0x80, 0xbd, 0xdd, 0xeb, 0xa1, 0x79, 0x7d, 0x38, 0x3e, 0x9f, 0x05, 0x9f, 0x07, 0x9f, 0x8f,
		0x68, 0x3d, 0xef, 0xa1, 0x64, 0xbf, 0x86, 0x0f, 0x37, 0x1b, 0x0f, 0x13, 0xae, 0x66, 0x77, 0x16,
		0x35, 0xbb, 0x89, 0x8e, 0x11, 0xf9, 0x71, 0x22, 0x3f, 0x56, 0xe4, 0xc7, 0x2b, 0x24, 0x55, 0x0e,
		0x28, 0x39, 0x41, 0x8f, 0xdd, 0x6c, 0x80, 0x3d, 0x23, 0x15, 0x7e, 0x2a, 0x7e, 0x7b, 0x33, 0x52,
		0x86, 0x03, 0x49, 0x76, 0x30, 0x29, 0x0f, 0x28, 0xcf, 0x41, 0xa5, 0x3e, 0xb0, 0x6c, 0x07, 0x97,
		0xed, 0x00, 0xb3, 0x1d, 0xe4, 0x70, 0x07, 0x9a, 0xc0, 0x31, 0x41, 0x72, 0xc0, 0x97, 0x2c, 0x27,
		0xb3, 0xdb, 0xf5, 0x84, 0xef, 0xd3, 0x77, 0x0e, 0x5e, 0x1c, 0x1c, 0x0d, 0x84, 0xa3, 0x05, 0x0d,
		0x5c, 0x10, 0xc1, 0x0e, 0x15, 0xec, 0x90, 0xc1, 0x0e, 0x1d, 0x34, 0x10, 0x42, 0x04, 0x25, 0xb3,
		0xa7, 0xe5, 0x6b, 0x20, 0x4c, 0x0f, 0x03, 0x4b, 0x6c, 0xe0, 0x8c, 0x70, 0xcc, 0x86, 0x29, 0xa5,
		0xf0, 0x1c, 0xf2, 0xf6, 0xbb, 0xa9, 0xfb, 0x8c, 0x71, 0x6e, 0x1a, 0x8f, 0x65, 0xe3, 0x53, 0xeb,
		0x7b, 0x6e, 0x70, 0x7c, 0xb1, 0xfc, 0xf3, 0xc9, 0xf7, 0xc2, 0x20, 0x85, 0x96, 0xf6, 0x1b, 0xd6,
		0xed, 0xab, 0x6d, 0x3a, 0xf4, 0x8a, 0x69, 0x34, 0x2a, 0x34, 0x12, 0x34, 0x12, 0x34, 0xd2, 0x41,
		0x6a, 0x24, 0x5b, 0x98, 0x8f, 0x4c, 0xed, 0xec, 0x4b, 0xb4, 0xda, 0x68, 0x74, 0x27, 0xf4, 0xe1,
		0x43, 0x7a, 0xe5, 0xbf, 0x21, 0x80, 0xf9, 0xa3, 0xff, 0x4f, 0x2e, 0x7b, 0x46, 0xaf, 0x0d, 0xab,
		0x9b, 0x42, 0x2f, 0xee, 0xc8, 0xf7, 0xe2, 0x7e, 0xec, 0x3e, 0xa4, 0x67, 0xd7, 0x4e, 0xe9, 0x89,
		0x0f, 0x7f, 0xf4, 0xf7, 0x6b, 0x9a, 0xc4, 0x51, 0x72, 0x44, 0x7e, 0xa5, 0x77, 0x6d, 0x76, 0x9a,
		0xc3, 0x6f, 0xdb, 0xae, 0x8c, 0xbf, 0xed, 0xe8, 0xef, 0xd7, 0xbd, 0x6e, 0xfa, 0xe8, 0x25, 0x25,
		0xcc, 0xed, 0xbe, 0xe5, 0x48, 0xe1, 0x3d, 0x9a, 0x14, 0xce, 0xcc, 0x59, 0x8e, 0xf6, 0x6c, 0x48,
		0xb8, 0xb9, 0xe0, 0xe6, 0x82, 0x9b, 0x2b, 0x4a, 0x6e, 0xae, 0xd9, 0xd9, 0x34, 0x86, 0x6a, 0x9f,
		0xdc, 0x9e, 0x58, 0x1e, 0x9e, 0xd6, 0xb0, 0xc8, 0x1e, 0xa8, 0x61, 0x61, 0x3d, 0xc2, 0xa6, 0xd0,
		0x60, 0x53, 0x58, 0x8f, 0x49, 0x35, 0x27, 0xa8, 0xc0, 0x64, 0x36, 0x20, 0xd1, 0x25, 0xd9, 0xd6,
		0x43, 0x40, 0xc6, 0x05, 0x19, 0x61, 0x85, 0x0d, 0x5e, 0x38, 0x61, 0x86, 0x1d, 0x6e, 0xb8, 0x61,
		0x47, 0x19, 0xfc, 0x28, 0x83, 0x21, 0x15, 0x70, 0x44, 0x0b, 0x4b, 0xc4, 0xf0, 0xc4, 0x06, 0x53,
		0x0c, 0x26, 0x8f, 0x32, 0x53, 0xe8, 0x67, 0x20, 0x96, 0x61, 0x1a, 0x9e, 0x0b, 0xcc, 0x54, 0x80,
		0x9a, 0x32, 0x70, 0x53, 0x05, 0x72, 0xca, 0xc1, 0x4e, 0x39, 0xe8, 0xa9, 0x04, 0x3f, 0x1e, 0x10,
		0x64, 0x02, 0xc3, 0xd9, 0xc2, 0x90, 0xbb, 0x82, 0xb7, 0x9e, 0x16, 0x7a, 0xd7, 0xf0, 0x56, 0x06,
		0x56, 0x62, 0x9c, 0xa3, 0x31, 0xf3, 0x55, 0x0e, 0xc5, 0xe8, 0x62, 0x06, 0xc8, 0xfe, 0xea, 0x1b,
		0x93, 0x9f, 0x47, 0x7e, 0xc2, 0x77, 0xf1, 0x10, 0x34, 0x06, 0x21, 0x4b, 0xf9, 0xfd, 0x07, 0x85,
		0xfa, 0x71, 0x69, 0x36, 0xa8, 0x48, 0xa8, 0x48, 0xa8, 0x48, 0xa8, 0x48, 0xa8, 0xc8, 0x88, 0xaa,
		0xc8, 0xfb, 0xb9, 0x8a, 0xfc, 0x8f, 0x4e, 0xdf, 0xf3, 0x84, 0x23, 0x8f, 0x4f, 0xd2, 0x1f, 0x3e,
		0xa4, 0x67, 0xbf, 0xd1, 0x9a, 0x7c, 0x64, 0x11, 0xd7, 0xfd, 0x0d, 0xef, 0xcd, 0x46, 0xee, 0x8a,
		0x6f, 0xb1, 0xd1, 0xb6, 0x91, 0xb6, 0x96, 0x2b, 0xdf, 0xa4, 0x4f, 0x1e, 0xad, 0x75, 0x14, 0xba,
		0x0e, 0xed, 0x2e, 0x00, 0xed, 0x76, 0x0c, 0xf1, 0x4d, 0x5e, 0x48, 0x61, 0x8b, 0x17, 0x21, 0xbd,
		0x57, 0xc3, 0x75, 0x8c, 0xce, 0xf3, 0x28, 0x93, 0x5c, 0x89, 0x13, 0xe7, 0xd1, 0xb4, 0x7d, 0x15,
		0x5e, 0x9c, 0xa8, 0x3b, 0x70, 0x5a, 0xd4, 0x0e, 0x75, 0xda, 0xe0, 0x83, 0x75, 0xaa, 0xaa, 0x2c,
		0x18, 0x61, 0x8e, 0x5b, 0x4b, 0x17, 0x5c, 0x69, 0x16, 0xc7, 0xf4, 0x91, 0xaa, 0xa0, 0x85, 0xea,
		0xf4, 0x59, 0xe6, 0xaf, 0x6e, 0xc5, 0x23, 0x49, 0x2c, 0x03, 0x9f, 0xa0, 0x12, 0xe2, 0xe6, 0x9e,
		0xdd, 0xee, 0xf6, 0x37, 0x6e, 0xf6, 0x2c, 0xca, 0xbc, 0x17, 0x21, 0xe0, 0xba, 0xb5, 0xc8, 0xe1,
		0xd6, 0x42, 0x99, 0xb5, 0x82, 0x5b, 0x8b, 0xe4, 0xf1, 0x30, 0xdc, 0x5a, 0xc0, 0x25, 0x03, 0x97,
		0x0c, 0x5c, 0x32, 0x70, 0xc9, 0xc0, 0x25, 0xa3, 0xc0, 0x25, 0x83, 0x5b, 0x8b, 0x23, 0xdc, 0x5a,
		0x40, 0x45, 0x42, 0x45, 0x42, 0x45, 0x42, 0x45, 0x42, 0x45, 0xe2, 0xd6, 0x22, 0x5e, 0xd6, 0x72,
		0xf2, 0x5d, 0xc4, 0x1c, 0x4e, 0xc0, 0x23, 0xcd, 0x1e, 0xe2, 0x3d, 0xba, 0xbc, 0xa9, 0x17, 0xd3,
		0x68, 0xc5, 0xda, 0x33, 0x09, 0xb8, 0x7e, 0xc1, 0x4e, 0x91, 0xfa, 0xe1, 0x75, 0x89, 0x32, 0xb2,
		0x84, 0xe3, 0x9d, 0x25, 0x4c, 0x69, 0x86, 0xa9, 0x15, 0xc3, 0x38, 0xe6, 0x0a, 0x53, 0xd6, 0xc8,
		0x62, 0x28, 0x8a, 0x43, 0x55, 0x64, 0x1c, 0xf9, 0xc2, 0x91, 0x33, 0x60, 0x91, 0x2f, 0xac, 0xc9,
		0x9a, 0x64, 0xb0, 0x1a, 0x29, 0xad, 0xc3, 0xc5, 0xca, 0x20, 0x93, 0xfa, 0x1f, 0x8b, 0x78, 0x12,
		0x43, 0x8c, 0xa5, 0x89, 0x49, 0x20, 0x8d, 0x41, 0x20, 0xaf, 0xc3, 0x90, 0x03, 0xae, 0x02, 0x57,
		0x63, 0x89, 0xab, 0x64, 0x75, 0x18, 0xcc, 0x27, 0x41, 0x5f, 0x7d, 0xc1, 0x24, 0x8b, 0x98, 0x44,
		0x31, 0x37, 0x14, 0x73, 0xe3, 0x86, 0x08, 0x76, 0xa8, 0x88, 0xa6, 0x47, 0x88, 0xaf, 0x98, 0x5b,
		0xdf, 0x72, 0x64, 0x31, 0xcf, 0x50, 0xcb, 0x8d, 0xb2, 0xb0, 0x68, 0xb8, 0x0e, 0x61, 0xdb, 0xfe,
		0x30, 0xb8, 0x8e, 0x29, 0x3a, 0x8a, 0x29, 0x82, 0xd7, 0xb5, 0xe1, 0x89, 0x3a, 0x90, 0x6d, 0x1d,
		0x9f, 0xb0, 0x75, 0x16, 0xf3, 0x71, 0x5b, 0xde, 0x52, 0xf3, 0x5b, 0xec, 0xb7, 0x34, 0x7b, 0x96,
		0xcf, 0x17, 0x4b, 0xf9, 0x7c, 0xa6, 0x74, 0x5a, 0xca, 0x9c, 0x17, 0x0a, 0xd9, 0x62, 0xb6, 0x10,
		0xe3, 0x5d, 0x8e, 0xe8, 0x25, 0x42, 0x92, 0x2a, 0x07, 0x8f, 0x3c, 0xa5, 0x86, 0xa4, 0x54, 0x3b,
		0xcb, 0x6d, 0x65, 0xc6, 0x63, 0x83, 0x78, 0x82, 0x78, 0x82, 0x78, 0x1e, 0x24, 0xf1, 0x14, 0x4e,
		0xff, 0x45, 0x78, 0xe3, 0x0b, 0x24, 0x86, 0x4a, 0xc2, 0x79, 0xc2, 0x31, 0x2b, 0x4e, 0xff, 0x65,
		0xb8, 0x08, 0x83, 0x04, 0x01, 0x3c, 0x5a, 0x97, 0x00, 0xe2, 0x01, 0xf1, 0x80, 0x78, 0xb4, 0x2e,
		0x39, 0x42, 0xeb, 0x92, 0x08, 0xea, 0x27, 0xb4, 0x2e, 0x81, 0x46, 0x82, 0x46, 0x82, 0x46, 0xa2,
		0x95, 0x5b, 0xb4, 0x2e, 0x61, 0xc7, 0x7e, 0x04, 0x25, 0x06, 0x0a, 0x4a, 0xa4, 0x0a, 0xf9, 0x56,
		0x12, 0x90, 0x48, 0x10, 0xcb, 0xad, 0x27, 0x50, 0x86, 0x84, 0x55, 0x50, 0xb2, 0x09, 0x84, 0x1f,
		0xea, 0x66, 0x09, 0x08, 0x93, 0x89, 0x08, 0x76, 0x1f, 0x70, 0xf8, 0xe1, 0x08, 0x48, 0x74, 0xc1,
		0xa9, 0xd2, 0xde, 0xea, 0xbf, 0x89, 0xd7, 0x15, 0xcf, 0xc0, 0x51, 0x08, 0x14, 0x4d, 0xd5, 0x2c,
		0x5f, 0x96, 0xa5, 0x0c, 0xd9, 0xaf, 0xfd, 0xda, 0x72, 0x2a, 0xb6, 0x18, 0x9e, 0x28, 0x3f, 0x1c,
		0x82, 0xa6, 0xae, 0xcd, 0x6f, 0x0b, 0x23, 0xd1, 0x5e, 0xbb, 0xa6, 0xea, 0x5e, 0x57, 0x78, 0xa2,
		0xfb, 0x71, 0xb8, 0x82, 0x4e, 0xdf, 0xb6, 0x95, 0x6e, 0x1c, 0x11, 0xb3, 0x52, 0xc7, 0xa8, 0x52,
		0xa1, 0xe2, 0x69, 0xd9, 0x39, 0x54, 0xb0, 0xe3, 0xbe, 0xff, 0x61, 0xdd, 0xef, 0x13, 0x7b, 0x4a,
		0x47, 0x58, 0xa9, 0x50, 0x21, 0x0d, 0x01, 0xe4, 0x80, 0x77, 0xff, 0xf7, 0xdb, 0xf9, 0xdd, 0xf7,
		0x6f, 0xb7, 0xdf, 0xdc, 0x71, 0x87, 0x83, 0xee, 0x2c, 0xe7, 0x8e, 0xee, 0xb1, 0x93, 0x3c, 0x3b,
		0xb8, 0xdb, 0xce, 0xfd, 0x7c, 0x1f, 0x76, 0xd8, 0x83, 0x3d, 0x43, 0xfa, 0x03, 0x85, 0xee, 0xef,
		0x19, 0xa2, 0xbf, 0x77, 0x28, 0x7e, 0x10, 0x5b, 0x22, 0x9c, 0xcd, 0x10, 0xd4, 0x36, 0x08, 0x6d,
		0x03, 0x84, 0xe6, 0xfa, 0xa1, 0x39, 0x3d, 0xed, 0xe9, 0xdf, 0x37, 0x64, 0x7d, 0x4c, 0xe8, 0x9e,
		0x2c, 0xe7, 0xc9, 0x90, 0xd6, 0x4b, 0x80, 0x0d, 0x58, 0xba, 0x32, 0x9a, 0x8f, 0xb3, 0xe7, 0x22,
		0x06, 0x33, 0xa6, 0x03, 0x1b, 0xcf, 0x61, 0x8c, 0x65, 0x1a, 0xe3, 0x38, 0xac, 0x31, 0x4c, 0x66,
		0xfc, 0x92, 0x19, 0xbb, 0x64, 0xc6, 0x2d, 0x2f, 0xf1, 0x09, 0x6c, 0xac, 0x2e, 0x05, 0x5e, 0x67,
		0x8b, 0x41, 0xf6, 0x7c, 0x22, 0xe5, 0xc5, 0x00, 0x1f, 0x0d, 0x17, 0x48, 0x1d, 0xce, 0xc4, 0x0a,
		0xef, 0x77, 0x23, 0xf2, 0x95, 0x11, 0x05, 0x3a, 0x53, 0x86, 0xba, 0x0e, 0xc2, 0xd9, 0x9c, 0x91,
		0x5b, 0xda, 0x62, 0xa1, 0x70, 0x5a, 0x88, 0xd0, 0xf2, 0x2a, 0x32, 0xb6, 0x5a, 0x5c, 0xd4, 0xfe,
		0xfd, 0x7e, 0x9a, 0xd8, 0x16, 0xa6, 0xe7, 0x58, 0xce, 0x53, 0x38, 0x3d, 0x3c, 0x1b, 0x05, 0x5a,
		0x18, 0x5a, 0x38, 0xa1, 0x5a, 0xf8, 0xc1, 0x75, 0x6d, 0x11, 0xc8, 0xff, 0x38, 0xb3, 0x9e, 0xb2,
		0x91, 0x38, 0xf4, 0xdf, 0xac, 0x97, 0xfe, 0x8b, 0x31, 0xf5, 0x79, 0x84, 0x38, 0xf7, 0xcb, 0x03,
		0xe1, 0xe8, 0xe3, 0xe8, 0x83, 0x80, 0x83, 0x80, 0x83, 0x80, 0x83, 0x80, 0x1f, 0x32, 0x01, 0x4f,
		0xa8, 0x6f, 0x7d, 0xdf, 0xa8, 0x23, 0x5a, 0xbf, 0xfa, 0x1e, 0x61, 0x44, 0x3b, 0x38, 0xd5, 0xdf,
		0x85, 0xd8, 0x9a, 0x7d, 0xb7, 0x84, 0x7e, 0x2b, 0x52, 0x3b, 0xdd, 0x09, 0xd0, 0x2d, 0xfe, 0x8f,
		0x97, 0x7d, 0xfb, 0x62, 0xfe, 0x60, 0x21, 0xc7, 0x2d, 0x40, 0x66, 0x4f, 0x65, 0xf4, 0x5c, 0xdb,
		0xea, 0xec, 0xc2, 0x46, 0x97, 0x7b, 0x88, 0x6c, 0x18, 0xe0, 0x27, 0x9b, 0xb7, 0xdb, 0x3d, 0xc6,
		0xce, 0x2c, 0x73, 0x1f, 0x56, 0x19, 0x8c, 0x45, 0xee, 0xcb, 0x1a, 0x03, 0xb3, 0xc4, 0xc0, 0xac,
		0x30, 0x30, 0x0b, 0x0c, 0x77, 0x0c, 0x77, 0xbd, 0x77, 0x48, 0x99, 0xbd, 0x9e, 0xfd, 0x3a, 0x16,
		0x90, 0xd7, 0xfd, 0x6f, 0xc9, 0x96, 0x3e, 0xcd, 0x7c, 0x59, 0x96, 0x51, 0x73, 0x59, 0xe6, 0xf5,
		0x5c, 0xfb, 0x20, 0x6f, 0xca, 0x46, 0x0f, 0x1e, 0x97, 0x6b, 0xb2, 0xce, 0x54, 0x2a, 0x02, 0x9a,
		0xe7, 0x81, 0x7a, 0x07, 0x06, 0x2c, 0xc5, 0xa6, 0xdd, 0x2a, 0xdf, 0x53, 0xa4, 0x0f, 0xc7, 0x24,
		0xdf, 0x4f, 0xe4, 0xd5, 0xd8, 0xe3, 0x41, 0x8b, 0x9c, 0xa5, 0xba, 0xe2, 0xd1, 0xec, 0xdb, 0xd2,
		0x10, 0xdf, 0x7a, 0xae, 0x27, 0xf7, 0x85, 0xf4, 0xad, 0xf2, 0xb3, 0x79, 0xd8, 0x80, 0xeb, 0x7f,
		0x35, 0x1e, 0x6c, 0x38, 0xee, 0x6d, 0xe5, 0xff, 0xab, 0x5c, 0x36, 0xdb, 0xb7, 0xf5, 0xcf, 0xcd,
		0x4a, 0xd0, 0xe1, 0xc2, 0xd9, 0x7a, 0xa1, 0x63, 0xbd, 0x29, 0x62, 0xbc, 0x09, 0xce, 0x29, 0xd5,
		0x79, 0x25, 0x3f, 0xb7, 0xe4, 0xe7, 0x97, 0xf6, 0x1c, 0x87, 0xb4, 0xa9, 0x03, 0xca, 0x4c, 0xe8,
		0xe8, 0xec, 0xb5, 0x93, 0x39, 0x3e, 0x92, 0x61, 0xeb, 0xc0, 0x50, 0x14, 0x7c, 0x08, 0x59, 0xe0,
		0x21, 0x40, 0x50, 0xe6, 0xfb, 0xe0, 0x38, 0x69, 0xbd, 0xb0, 0xe0, 0xe4, 0xf2, 0xb0, 0xc0, 0x49,
		0xe0, 0x24, 0x70, 0x12, 0x38, 0x19, 0x43, 0x9c, 0x24, 0xe6, 0x91, 0x24, 0xfc, 0x11, 0x40, 0x06,
		0x20, 0x3b, 0x5c, 0x20, 0x0b, 0x9f, 0x86, 0x47, 0x91, 0x7e, 0xb7, 0xd4, 0xfb, 0x6d, 0xb8, 0x11,
		0x17, 0x9e, 0xdb, 0x97, 0x96, 0xf3, 0x34, 0x39, 0xdb, 0xb3, 0xb7, 0x27, 0x78, 0xdb, 0x15, 0x8f,
		0x96, 0x63, 0x49, 0xcb, 0x75, 0xfc, 0xed, 0xff, 0x34, 0xfb, 0x97, 0xe0, 0xbd, 0x54, 0x07, 0x48,
		0x7d, 0xfb, 0xf9, 0xe0, 0x8b, 0xa9, 0x6f, 0x44, 0xc9, 0xdb, 0x7d, 0x5f, 0x78, 0x61, 0xf1, 0x82,
		0x30, 0x15, 0x79, 0x11, 0xcc, 0xdc, 0xf1, 0xd3, 0x1a, 0x0f, 0xaf, 0x14, 0xa9, 0xab, 0x1c, 0x69,
		0xc8, 0x4b, 0xc0, 0x36, 0x5a, 0xc9, 0x78, 0x65, 0xaf, 0x2a, 0x61, 0x22, 0xc4, 0x96, 0x1a, 0x89,
		0x85, 0x06, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x12,
		0x4b, 0x26, 0x72, 0x40, 0x09, 0xfd, 0x5b, 0xe2, 0x81, 0xd2, 0x8b, 0xf1, 0x1b, 0xe9, 0x40, 0x77,
		0xe2, 0x47, 0xa4, 0xf1, 0x54, 0xa3, 0x06, 0x9d, 0xd3, 0x9f, 0x1a, 0x93, 0x6f, 0xd9, 0x2e, 0x0f,
		0xbf, 0xe5, 0xe8, 0xa7, 0xd7, 0xf6, 0x84, 0x38, 0x45, 0x20, 0x55, 0x20, 0x58, 0xaf, 0xb8, 0x50,
		0xbd, 0xe1, 0x42, 0x07, 0x20, 0xe4, 0x10, 0x80, 0xa0, 0x15, 0x70, 0x11, 0x80, 0xb0, 0xbf, 0xfc,
		0x20, 0x00, 0x01, 0x56, 0x20, 0xac, 0xc0, 0x28, 0x5a, 0x81, 0xb8, 0x58, 0x43, 0x00, 0x02, 0x70,
		0x12, 0x38, 0x09, 0x9c, 0x04, 0x4e, 0x32, 0xe0, 0x24, 0x02, 0x10, 0x00, 0x64, 0x00, 0xb2, 0x28,
		0x01, 0x19, 0xdc, 0xfe, 0x1c, 0xfb, 0x03, 0xb7, 0x7f, 0x38, 0xa9, 0x84, 0xdb, 0x9f, 0x0a, 0xd8,
		0x10, 0x80, 0xb0, 0x79, 0x8d, 0x10, 0x80, 0x00, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02, 0x26, 0x02,
		0x26, 0x02, 0x26, 0x02, 0x26, 0x42, 0xc4, 0x44, 0x10, 0x80, 0xb0, 0x1c, 0x80, 0x10, 0xb4, 0x75,
		0x97, 0xca, 0xf8, 0x83, 0x00, 0x1d, 0xbb, 0x0e, 0xbb, 0x3a, 0xd2, 0x2e, 0x3b, 0xaf, 0xa5, 0x70,
		0xd2, 0x4f, 0xf7, 0x1a, 0x05, 0x95, 0xb6, 0xee, 0x9e, 0xd2, 0x22, 0x4b, 0x1b, 0x37, 0x8a, 0xad,
		0xec, 0xd2, 0xa3, 0xd9, 0xd9, 0xbb, 0xd2, 0xd2, 0xf8, 0x33, 0x28, 0xae, 0x84, 0xe2, 0x4a, 0x5b,
		0x04, 0x6a, 0xff, 0xca, 0x4a, 0xf3, 0x8f, 0x26, 0xa3, 0xac, 0x12, 0x7a, 0x90, 0x48, 0x14, 0x57,
		0x22, 0x14, 0xe0, 0xd0, 0x8e, 0x2c, 0x94, 0x3c, 0xa6, 0x37, 0xe7, 0x62, 0x52, 0xf2, 0x38, 0x70,
		0x84, 0xa3, 0xe9, 0xfb, 0x6e, 0xc7, 0x32, 0xa5, 0xe8, 0x4e, 0x9b, 0x2e, 0x1a, 0x8f, 0xe6, 0x8b,
		0x65, 0x07, 0xa9, 0x14, 0xbe, 0x26, 0x4b, 0x3f, 0x1a, 0x1c, 0x3e, 0x62, 0x9a, 0xde, 0xb7, 0x87,
		0xeb, 0x26, 0x0e, 0xdd, 0xdb, 0x36, 0xae, 0x9e, 0x62, 0xab, 0x2b, 0x1c, 0x69, 0xc9, 0x57, 0x22,
		0x6f, 0x71, 0x18, 0x8f, 0x63, 0x75, 0xf2, 0x55, 0x3e, 0x9a, 0xbe, 0xa0, 0x73, 0x3a, 0x96, 0xaf,
		0xae, 0x6e, 0x2b, 0x77, 0x77, 0xed, 0x4f, 0xe5, 0xeb, 0x6a, 0xed, 0xcf, 0x14, 0x45, 0xdd, 0x6b,
		0x3f, 0x70, 0x61, 0xf5, 0xc5, 0x3f, 0x44, 0x6d, 0xa5, 0xa7, 0xcf, 0x79, 0xdd, 0xa8, 0xdd, 0x11,
		0xb4, 0x66, 0x7e, 0x1f, 0xb5, 0xe7, 0xaa, 0x36, 0x7e, 0x2f, 0x26, 0xf1, 0xb9, 0x6a, 0xb9, 0x76,
		0xa5, 0xf9, 0x6b, 0xe5, 0xf6, 0xa6, 0xd2, 0x4c, 0xe8, 0xb6, 0xe5, 0x75, 0x77, 0x0a, 0x6f, 0xc5,
		0x04, 0xcd, 0xd1, 0x5d, 0x9a, 0x7f, 0x7f, 0x02, 0xc5, 0x35, 0x74, 0x09, 0x82, 0x19, 0xba, 0x60,
		0xa7, 0x60, 0xa7, 0x60, 0xa7, 0xc1, 0xe4, 0xc6, 0x97, 0xde, 0xfe, 0x8d, 0xe1, 0x36, 0x12, 0xd3,
		0xb3, 0x28, 0xe3, 0xcc, 0xde, 0x7e, 0x50, 0x32, 0xbf, 0x68, 0xd2, 0x51, 0xc7, 0x7a, 0x04, 0xe0,
		0x04, 0x00, 0x1c, 0xeb, 0x11, 0x31, 0x53, 0x21, 0xc0, 0x86, 0x2a, 0x66, 0xca, 0x7a, 0xbc, 0x98,
		0x5f, 0xa0, 0xad, 0xbe, 0x31, 0xf9, 0x39, 0x44, 0x18, 0x94, 0x12, 0x70, 0xf3, 0xfb, 0x0f, 0x84,
		0xf8, 0xb6, 0x34, 0x1a, 0x20, 0x0e, 0x10, 0x07, 0x88, 0x4b, 0x30, 0xc4, 0xdd, 0xcf, 0x21, 0xee,
		0x3f, 0x3a, 0x7d, 0xcf, 0x13, 0x8e, 0x3c, 0x3e, 0x49, 0x7f, 0xf8, 0x90, 0x9e, 0xfd, 0x46, 0x6b,
		0xf2, 0x91, 0x45, 0x5c, 0xf0, 0x37, 0xbc, 0x37, 0x1b, 0xb9, 0x2b, 0xbe, 0xa5, 0x10, 0xc0, 0xc6,
		0x13, 0x08, 0x33, 0x5e, 0xfc, 0xf9, 0x9a, 0x47, 0xa5, 0x62, 0xce, 0xe8, 0x7b, 0xcd, 0x5f, 0x46,
		0xa8, 0x48, 0x4e, 0x00, 0x0f, 0x43, 0x70, 0xcf, 0x02, 0xba, 0xe6, 0x6a, 0xd3, 0x6a, 0xe8, 0x9a,
		0xab, 0x4e, 0x55, 0x85, 0x51, 0x51, 0x33, 0xd5, 0xf4, 0xe1, 0xc3, 0x04, 0xbd, 0xd2, 0x56, 0x17,
		0xd5, 0xb4, 0x82, 0xc1, 0x45, 0x0e, 0x70, 0x01, 0xb8, 0xd8, 0xe9, 0x5b, 0x22, 0xe2, 0x24, 0x9e,
		0xa6, 0x27, 0x7c, 0xfa, 0x1a, 0x8e, 0x62, 0xdc, 0x8d, 0x50, 0x44, 0x9c, 0xec, 0x35, 0x2a, 0x22,
		0x4e, 0x54, 0x3f, 0x17, 0x22, 0x4e, 0xe2, 0xba, 0x6d, 0x88, 0x38, 0xd9, 0x71, 0xcd, 0x10, 0x71,
		0xa2, 0xc0, 0xfd, 0x87, 0x88, 0x13, 0xb0, 0x53, 0xb0, 0xd3, 0x98, 0xb1, 0x53, 0x44, 0x9c, 0xec,
		0x0b, 0x37, 0xb8, 0x8e, 0xc5, 0x75, 0x6c, 0x78, 0xc0, 0xc1, 0x75, 0x6c, 0x28, 0xb0, 0x41, 0xc4,
		0xc9, 0xfc, 0x79, 0x10, 0x71, 0x02, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0x82, 0x40, 0x1c, 0x22, 0x4e,
		0x7e, 0x20, 0xce, 0xd1, 0x8f, 0x38, 0x89, 0x48, 0x89, 0xa4, 0xd5, 0x80, 0x93, 0x18, 0x55, 0x45,
		0xfa, 0x4d, 0xbc, 0xee, 0xe5, 0x44, 0x08, 0xe6, 0x4a, 0x0a, 0xee, 0x3a, 0x22, 0x75, 0x15, 0x05,
		0x73, 0x0d, 0xc5, 0xb0, 0xc0, 0xd4, 0xca, 0x39, 0xd1, 0x57, 0x50, 0x6a, 0xe5, 0x64, 0xa0, 0x86,
		0xd4, 0xe2, 0x06, 0xa9, 0x2f, 0x1b, 0x35, 0x9e, 0x96, 0xa1, 0x56, 0xd4, 0x4b, 0xcf, 0xde, 0xa3,
		0x4a, 0xd4, 0xe8, 0xb7, 0xe3, 0x51, 0x1f, 0x6a, 0x87, 0xaf, 0x7a, 0x14, 0xcb, 0xe2, 0x50, 0xa3,
		0x07, 0x8b, 0x4a, 0x65, 0xa8, 0x27, 0xdb, 0x7d, 0x30, 0xed, 0xfd, 0xcb, 0x42, 0x4d, 0x3e, 0x97,
		0x8c, 0x9a, 0x50, 0x3b, 0x8a, 0x5a, 0x58, 0xc3, 0x2a, 0x7a, 0x05, 0xa1, 0x76, 0x13, 0x45, 0x1e,
		0xfe, 0x83, 0x6a, 0x50, 0xd4, 0x1e, 0x84, 0x10, 0x22, 0x4d, 0xe5, 0x33, 0x88, 0x7e, 0x60, 0xde,
		0x7e, 0x22, 0xaf, 0xc6, 0xde, 0x0b, 0x1c, 0x95, 0x37, 0x64, 0xd2, 0x86, 0x6d, 0x3e, 0x08, 0x3b,
		0xbc, 0xfb, 0x6d, 0x61, 0xac, 0xf0, 0xbd, 0xda, 0x26, 0x0b, 0x2d, 0x2f, 0xaa, 0xd7, 0x8d, 0x5a,
		0xf5, 0xb2, 0xda, 0x84, 0x43, 0x2f, 0xcc, 0xb1, 0x84, 0x4b, 0x2f, 0xd8, 0xb1, 0x8d, 0xbb, 0x53,
		0x2f, 0xf1, 0x11, 0x7c, 0x37, 0x9f, 0x6b, 0xb5, 0x76, 0xad, 0xfc, 0xb1, 0x52, 0x6b, 0x37, 0xff,
		0x6c, 0x54, 0x92, 0x1b, 0xc2, 0x37, 0xc3, 0xc1, 0x04, 0xc6, 0x83, 0x55, 0xfe, 0x20, 0x7b, 0xb6,
		0x78, 0xc5, 0x84, 0x29, 0xb9, 0x64, 0xeb, 0xfd, 0x63, 0x08, 0xa7, 0x63, 0xf6, 0xfc, 0xbe, 0x1d,
		0xdc, 0x25, 0xbc, 0xb4, 0x5f, 0x6b, 0x23, 0x42, 0x37, 0x43, 0x37, 0x43, 0x37, 0x43, 0x37, 0x2f,
		0x3f, 0x60, 0xe3, 0xae, 0xf2, 0xf9, 0xaa, 0xfe, 0xef, 0xea, 0x6d, 0xa5, 0x5d, 0xb9, 0xb9, 0x2c,
		0x37, 0xee, 0x3e, 0xd7, 0xca, 0xcd, 0x6a, 0xfd, 0x26, 0xb9, 0x4a, 0xba, 0xf1, 0xef, 0xca, 0x2c,
		0x70, 0xbb, 0x7d, 0x5b, 0xfe, 0x77, 0xfb, 0xba, 0x7e, 0x55, 0x49, 0xa2, 0xc6, 0x5e, 0x7a, 0xd0,
		0x66, 0xf9, 0x97, 0x5f, 0x2a, 0x57, 0x54, 0xcf, 0x0a, 0x0d, 0xbe, 0xb6, 0xea, 0x52, 0xda, 0x46,
		0xcf, 0x73, 0x7b, 0xe6, 0x13, 0x91, 0x02, 0x5f, 0x1d, 0x30, 0xbc, 0xbd, 0x3e, 0x54, 0x0a, 0xa0,
		0x01, 0xa0, 0x01, 0xa0, 0x01, 0xfb, 0x4a, 0xcc, 0x83, 0xeb, 0xda, 0xc2, 0x74, 0x28, 0x28, 0x40,
		0x16, 0xc1, 0x2b, 0xe4, 0x77, 0xbe, 0x43, 0xa1, 0x4c, 0x8f, 0x2f, 0xab, 0xa2, 0x50, 0x25, 0xe5,
		0xba, 0x67, 0xfb, 0xed, 0x5f, 0x46, 0x5f, 0x27, 0x4a, 0xc5, 0x51, 0xa6, 0x37, 0xd4, 0x86, 0x29,
		0xa5, 0x67, 0x3d, 0xf4, 0x65, 0x80, 0xac, 0xee, 0xf5, 0x38, 0xf5, 0xc5, 0xd1, 0x70, 0xeb, 0xc2,
		0xa8, 0x33, 0x70, 0xeb, 0x72, 0xa4, 0xf2, 0xd6, 0x25, 0x82, 0x39, 0x1d, 0x59, 0x90, 0x2f, 0x90,
		0xaf, 0xb8, 0x90, 0xaf, 0xa0, 0x07, 0x6f, 0x36, 0x40, 0xc0, 0x48, 0x80, 0xad, 0x82, 0x17, 0x98,
		0x18, 0x10, 0x1e, 0x45, 0xb2, 0x23, 0x49, 0x79, 0x34, 0x19, 0x8e, 0x28, 0xf5, 0x51, 0x65, 0x3b,
		0xb2, 0x6c, 0x47, 0x97, 0xe7, 0x08, 0xd3, 0x38, 0x60, 0x42, 0xba, 0xaa, 0x42, 0x1f, 0xed, 0x0d,
		0x94, 0x34, 0x44, 0xa6, 0xf6, 0x0e, 0x14, 0x35, 0x70, 0x0e, 0x37, 0xb1, 0x1b, 0x84, 0x0d, 0x06,
		0x38, 0xe0, 0x80, 0x11, 0x16, 0xb8, 0xe0, 0x81, 0x1d, 0x26, 0xd8, 0xe1, 0x82, 0x17, 0x36, 0x68,
		0xe0, 0x83, 0x08, 0x46, 0xe8, 0xdc, 0x34, 0x2a, 0x11, 0xe0, 0x28, 0x7c, 0x4e, 0x3a, 0xfd, 0x6e,
		0x10, 0xec, 0xc4, 0x28, 0x68, 0xdc, 0x10, 0x8e, 0xf9, 0x60, 0x0b, 0x06, 0x2c, 0x5e, 0x1a, 0x9d,
		0x48, 0x6e, 0x16, 0x3c, 0xdb, 0x8f, 0xa6, 0xed, 0x0b, 0x60, 0x3c, 0x30, 0x1e, 0x18, 0x7f, 0x68,
		0x18, 0x1f, 0xde, 0x35, 0xbf, 0x15, 0xde, 0xb3, 0x51, 0x81, 0x77, 0xad, 0x6c, 0x3f, 0xa4, 0xab,
		0x7f, 0x6d, 0x3c, 0x3e, 0xd7, 0xff, 0x26, 0x9f, 0x34, 0x45, 0xfd, 0xf4, 0xf5, 0x47, 0xe0, 0xb8,
		0x29, 0x98, 0x65, 0x90, 0x95, 0x67, 0x5f, 0x3e, 0x64, 0x91, 0x75, 0x3a, 0x39, 0x0a, 0x21, 0x43,
		0xb4, 0x46, 0x1e, 0x07, 0xb5, 0x23, 0x52, 0xf8, 0xf0, 0xe9, 0xc0, 0xa7, 0x13, 0x5f, 0x94, 0x27,
		0x53, 0xd0, 0x84, 0xb5, 0x2a, 0xd6, 0x14, 0x72, 0x89, 0x60, 0xac, 0x0d, 0x25, 0xe9, 0x17, 0xa1,
		0x24, 0xd6, 0x00, 0x3b, 0x5c, 0x6e, 0x06, 0x84, 0x0d, 0xbf, 0x8b, 0x87, 0xe2, 0x36, 0xb7, 0x1e,
		0x01, 0xb0, 0x0c, 0x00, 0x1b, 0xa6, 0xd4, 0x4f, 0x34, 0xe0, 0x95, 0xcc, 0x65, 0x4e, 0x74, 0x2b,
		0xb6, 0x26, 0xbc, 0x64, 0xe4, 0x98, 0xf0, 0xb8, 0xc7, 0xd6, 0x85, 0x42, 0x02, 0x03, 0x70, 0xa0,
		0xe8, 0x80, 0x89, 0x68, 0xba, 0x4f, 0xa8, 0xe0, 0x63, 0x9d, 0x33, 0xd0, 0x8b, 0x15, 0x55, 0xd4,
		0x0b, 0xb3, 0xb9, 0xc6, 0x0e, 0x32, 0x9c, 0x60, 0xc3, 0x0e, 0x3a, 0xdc, 0xe0, 0xa3, 0x0c, 0x84,
		0x94, 0x81, 0x91, 0x0a, 0x50, 0xa2, 0x05, 0x27, 0x62, 0x90, 0xa2, 0x37, 0x25, 0x15, 0x98, 0x96,
		0x9c, 0xa6, 0xe6, 0x56, 0xd3, 0x93, 0xbf, 0x32, 0x2c, 0xbf, 0xe0, 0x10, 0x0a, 0x0d, 0x4d, 0x85,
		0xd9, 0x9f, 0x0a, 0x0d, 0x41, 0xe5, 0x59, 0xa8, 0x24, 0xa8, 0x24, 0xa8, 0x24, 0xa8, 0xa4, 0x03,
		0x54, 0x49, 0x51, 0xaa, 0xe4, 0xab, 0x40, 0xbb, 0x45, 0xca, 0xfa, 0xab, 0x7c, 0x93, 0x34, 0x99,
		0xd4, 0xd3, 0x3f, 0x7c, 0x8e, 0x04, 0xb7, 0x63, 0x88, 0x6f, 0xf2, 0x42, 0x0a, 0x5b, 0xbc, 0x08,
		0xe9, 0xbd, 0x1a, 0xae, 0x63, 0x74, 0x9e, 0x4d, 0xe7, 0x49, 0xf0, 0x3a, 0x17, 0x46, 0x01, 0x40,
		0x8c, 0xde, 0x85, 0xa8, 0x39, 0x16, 0x5a, 0x54, 0x8e, 0x56, 0xda, 0xcb, 0xfd, 0x39, 0xa5, 0xd3,
		0x75, 0xc9, 0xbf, 0x74, 0x6b, 0x91, 0x26, 0xf5, 0x6a, 0x1e, 0x69, 0xba, 0xfa, 0x9f, 0xbd, 0xba,
		0x15, 0x8f, 0x24, 0x71, 0x00, 0x74, 0xa2, 0x38, 0x20, 0x09, 0xa6, 0x08, 0xd2, 0x8b, 0xf9, 0xe7,
		0x74, 0x3f, 0x60, 0xed, 0xf2, 0x1f, 0xaa, 0x60, 0x6a, 0x7f, 0x76, 0x0e, 0xfe, 0xec, 0xf8, 0xf0,
		0x76, 0xf8, 0xb3, 0xe1, 0xcf, 0x86, 0xf3, 0x00, 0xce, 0x03, 0x38, 0x0f, 0xe0, 0x3c, 0x80, 0xf3,
		0x00, 0xfe, 0xec, 0xed, 0x8c, 0x16, 0xfe, 0x6c, 0xa8, 0x24, 0xa8, 0x24, 0xa8, 0x24, 0xa8, 0xa4,
		0xc8, 0xaa, 0x24, 0xf8, 0xb3, 0xf5, 0x59, 0x7f, 0x09, 0x77, 0x3a, 0x52, 0x7a, 0x9e, 0x22, 0xe1,
		0x73, 0x0c, 0xd0, 0x6f, 0x8f, 0xd1, 0xe5, 0x88, 0x64, 0x38, 0x72, 0x91, 0x8d, 0x69, 0x4e, 0xdc,
		0xa2, 0x90, 0xc6, 0x31, 0x71, 0x83, 0xc6, 0xf3, 0x4d, 0xea, 0xf1, 0x26, 0x4f, 0xd4, 0xc8, 0x21,
		0x17, 0x2e, 0x0a, 0x5c, 0x1d, 0xb9, 0x70, 0x7b, 0x3c, 0x12, 0xea, 0x1b, 0xa1, 0xf6, 0x45, 0xa4,
		0x4d, 0x7b, 0xd4, 0xbe, 0x88, 0x93, 0xb9, 0x83, 0xfa, 0x46, 0x11, 0xd8, 0x09, 0xd4, 0x37, 0x02,
		0xc6, 0x03, 0xe3, 0x81, 0xf1, 0xb1, 0xc3, 0x78, 0xd4, 0x37, 0x82, 0x4b, 0x67, 0x37, 0x97, 0x0e,
		0x95, 0xdf, 0x51, 0x87, 0x2b, 0x87, 0xc0, 0xc5, 0x38, 0x88, 0x49, 0x61, 0xec, 0xdf, 0xc4, 0x2b,
		0x11, 0x77, 0x4b, 0xd5, 0x2c, 0x5f, 0x0e, 0x97, 0x33, 0x5c, 0xa1, 0xed, 0x6b, 0xcb, 0xa9, 0xd8,
		0x62, 0x08, 0xd4, 0x7e, 0x38, 0x2d, 0x9e, 0xba, 0x36, 0xbf, 0x2d, 0x8c, 0x94, 0x3d, 0xcb, 0xe7,
		0x8b, 0xa5, 0x7c, 0x3e, 0x53, 0x3a, 0x2d, 0x65, 0xce, 0x0b, 0x85, 0x6c, 0x31, 0x54, 0xff, 0xb3,
		0xba, 0xd7, 0x15, 0x9e, 0xe8, 0x7e, 0x1c, 0xae, 0x9e, 0xd3, 0xb7, 0x6d, 0xa5, 0x9b, 0x46, 0x04,
		0x12, 0xda, 0xc0, 0x21, 0x15, 0xca, 0x4d, 0xa9, 0x1a, 0x0e, 0x52, 0xe8, 0x91, 0xa3, 0x5c, 0x56,
		0x22, 0xd3, 0x31, 0x67, 0x83, 0x64, 0x44, 0xa1, 0x7d, 0x8e, 0x27, 0x7c, 0xe1, 0x7d, 0x15, 0xdd,
		0x71, 0xf7, 0x74, 0xe3, 0xc1, 0x76, 0x3b, 0x7f, 0x87, 0xe8, 0x9f, 0xb3, 0x79, 0x38, 0x34, 0xd0,
		0x61, 0xb4, 0xb4, 0xd0, 0x40, 0xe7, 0x48, 0x65, 0x03, 0x9d, 0x4d, 0x12, 0x1e, 0xbe, 0x97, 0xce,
		0xc6, 0x51, 0xd1, 0x56, 0x07, 0x6d, 0x75, 0xb4, 0x39, 0x26, 0xd0, 0x56, 0x07, 0x6d, 0x75, 0x14,
		0xfb, 0x1e, 0x71, 0xed, 0x8c, 0x6b, 0xe7, 0x1f, 0x0c, 0x64, 0xbb, 0x1d, 0xd3, 0x66, 0xb9, 0x72,
		0x9e, 0x8d, 0x8c, 0xab, 0x88, 0x08, 0xc1, 0x01, 0x17, 0x2c, 0xb0, 0xc3, 0x03, 0x3b, 0x4c, 0xf0,
		0xc2, 0x05, 0x9d, 0x07, 0xfc, 0x28, 0x16, 0x57, 0x11, 0xbe, 0xf4, 0x2c, 0xe7, 0x09, 0x17, 0xcd,
		0x3f, 0x43, 0xdf, 0x7f, 0x84, 0x67, 0x3c, 0xb8, 0x7d, 0x87, 0x05, 0x80, 0xe7, 0x83, 0x03, 0x83,
		0x81, 0xc1, 0xc0, 0xe0, 0x03, 0xc3, 0xe0, 0x51, 0xa0, 0xc9, 0xc8, 0xf7, 0xc1, 0x81, 0xc3, 0xe7,
		0x84, 0x63, 0x4e, 0xd6, 0xe0, 0x9e, 0x54, 0x88, 0x18, 0x33, 0x9e, 0xfa, 0x96, 0x23, 0x4f, 0x73,
		0x8c, 0x09, 0x4f, 0x1c, 0xf9, 0x4e, 0xb7, 0xa3, 0xd2, 0x4a, 0xd4, 0xab, 0xcc, 0xb7, 0xda, 0xb3,
		0x2f, 0x7e, 0x6d, 0x39, 0x6c, 0x19, 0x8f, 0x4c, 0xaa, 0x6d, 0xeb, 0x34, 0xbf, 0x9b, 0x76, 0x7f,
		0xb8, 0x09, 0xd9, 0x22, 0xf3, 0x44, 0x9f, 0x3c, 0xb3, 0x23, 0x2d, 0xd7, 0xb9, 0xb2, 0x9e, 0xac,
		0xf1, 0x65, 0x2d, 0xdb, 0x7c, 0x83, 0xf7, 0x8c, 0x7b, 0x6f, 0x7e, 0x4b, 0xde, 0xde, 0x67, 0xf2,
		0x67, 0x85, 0x52, 0x21, 0x41, 0x02, 0xf0, 0x2e, 0x1e, 0xa3, 0xb6, 0xa2, 0x9c, 0xa8, 0xcb, 0xa8,
		0xae, 0x84, 0xd3, 0x7f, 0x11, 0xde, 0xf8, 0x7a, 0x99, 0x31, 0x49, 0x37, 0xcf, 0x30, 0x76, 0xc5,
		0xe9, 0xbf, 0x0c, 0x01, 0x60, 0x10, 0xd1, 0x6c, 0xd9, 0x56, 0x82, 0xac, 0xd1, 0x7e, 0xaf, 0xc7,
		0x67, 0x8d, 0x2e, 0x0e, 0x0e, 0x6b, 0x14, 0xd6, 0x28, 0xac, 0x51, 0x58, 0xa3, 0xb0, 0x46, 0x61,
		0x8d, 0xc2, 0x1a, 0x85, 0x35, 0x0a, 0x6b, 0x14, 0xd6, 0x28, 0xac, 0x51, 0x58, 0xa3, 0xb0, 0x46,
		0x93, 0x62, 0x8d, 0x22, 0x4b, 0x6b, 0xa7, 0xe0, 0xfa, 0x8d, 0x91, 0xdd, 0x1b, 0xdf, 0x8d, 0x7a,
		0x47, 0xfa, 0xdb, 0xc9, 0x77, 0xae, 0x0d, 0xbf, 0xf2, 0xc7, 0xd1, 0x73, 0x6c, 0x78, 0x2f, 0xc6,
		0xad, 0xe9, 0xc9, 0x02, 0xa5, 0xa8, 0x03, 0xa4, 0xd0, 0x92, 0x5e, 0xab, 0x9b, 0x03, 0xf1, 0x90,
		0x51, 0x80, 0xfc, 0x03, 0x6e, 0x49, 0x3f, 0x83, 0x11, 0x54, 0x35, 0x43, 0x55, 0x33, 0xc0, 0x29,
		0xe0, 0x14, 0xe1, 0xe5, 0xfa, 0xbd, 0x2e, 0xb8, 0x4c, 0xc2, 0x65, 0x92, 0x4a, 0xb8, 0xa0, 0x75,
		0x25, 0x20, 0xbc, 0x3c, 0x02, 0x2e, 0x14, 0x84, 0x97, 0x03, 0x83, 0x81, 0xc1, 0xc0, 0xe0, 0xc8,
		0x62, 0x30, 0x2e, 0xf4, 0x89, 0xff, 0xe0, 0x42, 0x5f, 0xe5, 0x6a, 0xcf, 0xbe, 0x38, 0x2e, 0xf4,
		0x03, 0x4c, 0x84, 0x0b, 0xfd, 0xe8, 0xee, 0x3d, 0x2e, 0xf4, 0xf5, 0x8c, 0x8a, 0x0b, 0x7d, 0x5c,
		0xe8, 0x13, 0x8b, 0x16, 0xc2, 0xcb, 0x77, 0xa5, 0x4c, 0x08, 0x2f, 0x87, 0x35, 0x0a, 0x6b, 0x14,
		0xd6, 0x28, 0xac, 0x51, 0x58, 0xa3, 0xb0, 0x46, 0x61, 0x8d, 0xc2, 0x1a, 0x85, 0x35, 0x0a, 0x6b,
		0x14, 0xd6, 0x28, 0xac, 0x51, 0x84, 0x97, 0x93, 0x8a, 0x72, 0x32, 0xc3, 0xcb, 0xa3, 0xdd, 0x10,
		0x64, 0xc7, 0xe8, 0xf2, 0xc3, 0xeb, 0x0c, 0x12, 0x32, 0x0a, 0x0a, 0x5d, 0x41, 0x94, 0x6d, 0x58,
		0xf4, 0xbb, 0x82, 0xec, 0x8e, 0x16, 0x91, 0xeb, 0x10, 0xb2, 0x1b, 0x3e, 0xa0, 0x55, 0x88, 0x06,
		0x01, 0x8a, 0x4c, 0xaf, 0x90, 0x0d, 0x32, 0x12, 0x85, 0x5e, 0x21, 0xc1, 0x42, 0xe0, 0x43, 0x85,
		0xbc, 0x87, 0xee, 0x05, 0x92, 0x43, 0x2f, 0x90, 0x40, 0x03, 0xa1, 0x17, 0xc8, 0x0e, 0x1f, 0x1c,
		0x6a, 0xe6, 0x89, 0x23, 0x37, 0x74, 0x07, 0x90, 0x85, 0xb1, 0x82, 0xf6, 0x50, 0x98, 0x37, 0x56,
		0x9d, 0x2c, 0xb4, 0xbc, 0xa8, 0x5e, 0x37, 0x6a, 0xd5, 0xcb, 0x6a, 0x33, 0x64, 0x2f, 0x91, 0x0c,
		0x7a, 0x89, 0x1c, 0xa1, 0x97, 0x48, 0x4c, 0xec, 0x8d, 0xd0, 0x17, 0x37, 0xf3, 0x46, 0xd4, 0x5d,
		0xe1, 0x48, 0x4b, 0xbe, 0x86, 0x4b, 0xae, 0x9b, 0xe9, 0xb0, 0x30, 0x06, 0x41, 0x75, 0xf2, 0x55,
		0x3e, 0x9a, 0x3e, 0x61, 0x16, 0xda, 0xcd, 0xe7, 0x5a, 0xad, 0x5d, 0x2b, 0x7f, 0xac, 0xd4, 0xda,
		0xcd, 0x3f, 0x1b, 0x95, 0xb0, 0x52, 0x38, 0x72, 0xa4, 0xfa, 0x24, 0x57, 0x19, 0xc4, 0x77, 0xee,
		0x33, 0x1c, 0x8c, 0x42, 0x78, 0x01, 0xf1, 0xb3, 0x55, 0xfe, 0x20, 0x7b, 0xb6, 0x77, 0x7a, 0x5c,
		0x6e, 0x03, 0x55, 0xd6, 0x4e, 0x00, 0x46, 0xd6, 0xfb, 0xc7, 0x10, 0x4e, 0xc7, 0xec, 0xf9, 0x7d,
		0x3b, 0x9c, 0x49, 0x3c, 0xdb, 0xaf, 0xb5, 0x11, 0xa1, 0x9b, 0xa1, 0x9b, 0xa1, 0x9b, 0xa1, 0x9b,
		0x97, 0x1f, 0xb0, 0x71, 0x57, 0xf9, 0x7c, 0x55, 0xff, 0x77, 0xf5, 0xb6, 0xd2, 0xae, 0xdc, 0x5c,
		0x96, 0x1b, 0x77, 0x9f, 0x6b, 0xe5, 0x66, 0xb5, 0x7e, 0x93, 0x5c, 0x25, 0xdd, 0xf8, 0x77, 0xa5,
		0x5d, 0x69, 0xfe, 0x5a, 0xb9, 0xbd, 0xa9, 0x34, 0xdb, 0xb7, 0xe5, 0x7f, 0xb7, 0xaf, 0xeb, 0x57,
		0x95, 0x24, 0x6a, 0xec, 0xa5, 0x07, 0x6d, 0x96, 0x7f, 0xf9, 0xa5, 0x72, 0x45, 0xf5, 0xac, 0xd0,
		0xe0, 0x6b, 0xab, 0x2e, 0xa5, 0x6d, 0xf4, 0x3c, 0xb7, 0x67, 0x3e, 0x11, 0x29, 0xf0, 0xd5, 0x01,
		0xc3, 0xdb, 0xeb, 0x43, 0xa5, 0x00, 0x1a, 0x00, 0x1a, 0x00, 0x1a, 0xb0, 0xaf, 0xc4, 0x3c, 0xb8,
		0xae, 0x2d, 0x4c, 0x87, 0x82, 0x02, 0x64, 0x71, 0xe7, 0xc2, 0x7a, 0xe7, 0x12, 0xf4, 0xde, 0x9e,
		0xe7, 0x8e, 0x25, 0xc0, 0x05, 0xfc, 0x1e, 0xb7, 0x2a, 0xef, 0x08, 0xb7, 0x36, 0xe8, 0x96, 0xf2,
		0x6d, 0x65, 0x6a, 0xaf, 0x4b, 0x23, 0xfa, 0xcd, 0xdb, 0x6d, 0xdb, 0x7e, 0xbe, 0x09, 0x3b, 0x6c,
		0x40, 0xca, 0xf6, 0x7b, 0xbb, 0xf7, 0xc3, 0x9f, 0x57, 0x1c, 0x18, 0x7e, 0x6a, 0xc7, 0xed, 0xdd,
		0xef, 0x8a, 0x6b, 0x6f, 0x85, 0x1d, 0x44, 0x41, 0x87, 0x50, 0xc8, 0x41, 0x15, 0x70, 0x68, 0x85,
		0x1b, 0x5a, 0xc1, 0x86, 0x53, 0xa8, 0xb4, 0x47, 0x7e, 0xdf, 0x2b, 0xa9, 0x54, 0xc7, 0x75, 0x7c,
		0xe9, 0x99, 0x96, 0x23, 0xba, 0xc6, 0xe4, 0xc4, 0x07, 0xbc, 0xa6, 0x5d, 0x1b, 0x49, 0xf1, 0x8d,
		0x6d, 0x06, 0x37, 0xb6, 0x5a, 0xf9, 0x65, 0xb2, 0x6f, 0x6c, 0xcd, 0x17, 0xd1, 0x35, 0xc4, 0xb7,
		0x9e, 0x6d, 0x75, 0x2c, 0x39, 0x92, 0x6f, 0x9f, 0xe0, 0xee, 0x76, 0xd3, 0xa8, 0xe1, 0xcc, 0xb9,
		0x2c, 0xcc, 0x39, 0x98, 0x73, 0x71, 0x31, 0xe7, 0xc2, 0xd6, 0xe0, 0xdb, 0x74, 0x80, 0xe8, 0x1c,
		0xa9, 0x9b, 0x06, 0x8f, 0x58, 0xe1, 0x4d, 0xd4, 0x31, 0xd6, 0x7a, 0x98, 0xd9, 0x0e, 0x35, 0xcf,
		0xe1, 0xa6, 0x71, 0xf6, 0x46, 0xa6, 0xf0, 0x66, 0x67, 0x7a, 0x0a, 0x88, 0xbd, 0xec, 0x64, 0x65,
		0xe8, 0x09, 0x8f, 0x3c, 0xf9, 0xd1, 0xe7, 0x80, 0x00, 0x46, 0x28, 0xe0, 0x82, 0x04, 0x76, 0x68,
		0x60, 0x87, 0x08, 0x5e, 0xa8, 0xa0, 0x81, 0x0c, 0x22, 0xe8, 0x20, 0x87, 0x90, 0x25, 0x1e, 0x41,
		0x2f, 0x53, 0x8b, 0x44, 0x82, 0x5a, 0x9c, 0x78, 0x52, 0x5c, 0xc9, 0xe1, 0x85, 0x13, 0x66, 0x14,
		0xc0, 0x0d, 0x37, 0xec, 0x28, 0x83, 0x1f, 0x65, 0x30, 0xa4, 0x06, 0x8e, 0x68, 0x61, 0x89, 0x18,
		0x9e, 0x66, 0x4b, 0x40, 0x5e, 0x09, 0x64, 0x4d, 0xe2, 0xc9, 0x6b, 0x04, 0xaf, 0xd1, 0x96, 0xb3,
		0x88, 0xe6, 0xe9, 0x12, 0xee, 0x55, 0xca, 0xb7, 0xba, 0x46, 0xcf, 0x73, 0xa5, 0x18, 0xe5, 0xd7,
		0x1b, 0x9e, 0xf8, 0x9f, 0xbe, 0xe5, 0x89, 0x2e, 0x9f, 0x42, 0xd8, 0x36, 0x21, 0xb1, 0xfc, 0x2d,
		0x04, 0x0a, 0x3c, 0x9a, 0xb6, 0x0f, 0x1d, 0xa4, 0x4e, 0x07, 0x19, 0xbe, 0x07, 0x35, 0x14, 0x51,
		0x35, 0x34, 0xdc, 0x1b, 0x68, 0x22, 0x62, 0xb9, 0x0f, 0x1f, 0x4f, 0xf1, 0x53, 0x55, 0x94, 0x3d,
		0x10, 0x55, 0xe4, 0x0b, 0x7b, 0xa2, 0x18, 0x5e, 0xdc, 0xae, 0xe0, 0xd5, 0x42, 0x2b, 0x73, 0xf1,
		0x29, 0xa0, 0xeb, 0xea, 0x1f, 0xd3, 0x60, 0x45, 0x68, 0x21, 0x68, 0x21, 0x68, 0x21, 0x68, 0x21,
		0x06, 0xb9, 0x47, 0x61, 0x24, 0x3e, 0x2d, 0x17, 0x29, 0x0f, 0x20, 0x71, 0x81, 0xa2, 0xb9, 0xfe,
		0xa5, 0x0f, 0x7d, 0xb3, 0xfd, 0x9e, 0x9f, 0x5e, 0x0d, 0x8e, 0x49, 0x6f, 0xba, 0xfa, 0xdf, 0xf4,
		0x66, 0x9a, 0xf4, 0x36, 0xe2, 0x88, 0x3e, 0xb2, 0xae, 0xe6, 0xf7, 0xfc, 0xf6, 0xe5, 0xfc, 0xf1,
		0x1a, 0xa6, 0x7c, 0x6e, 0x0f, 0xcf, 0x63, 0xb7, 0x32, 0x79, 0x8e, 0xe1, 0x3b, 0xfe, 0xfa, 0x5b,
		0x24, 0x8d, 0x72, 0xe9, 0xa4, 0x93, 0xa2, 0xfc, 0xf3, 0x6c, 0xe7, 0x3c, 0xb7, 0x2f, 0x85, 0xe1,
		0x3e, 0xfc, 0xb7, 0xe8, 0x48, 0x9f, 0xfe, 0x86, 0x6a, 0xcb, 0x3c, 0xb8, 0xb1, 0xa2, 0x22, 0x4e,
		0xb8, 0xb1, 0xc2, 0x8d, 0x15, 0xa9, 0xbe, 0x22, 0xbf, 0xb1, 0xda, 0x08, 0x01, 0x7c, 0xb6, 0xe2,
		0xe6, 0xe9, 0x78, 0x2c, 0xb9, 0x2c, 0x2c, 0x39, 0xdc, 0x69, 0xc5, 0xc5, 0x8c, 0x3b, 0x34, 0x1b,
		0x8e, 0x1a, 0xc8, 0x66, 0x03, 0x13, 0x47, 0xf3, 0x6c, 0x3d, 0x50, 0xe4, 0x7c, 0x5a, 0x01, 0x84,
		0xb1, 0x43, 0x99, 0x0a, 0x48, 0x53, 0x08, 0x6d, 0xaa, 0x20, 0x4e, 0x39, 0xd4, 0x29, 0x87, 0x3c,
		0xb5, 0xd0, 0xc7, 0x03, 0x81, 0x4c, 0x50, 0xc8, 0x0e, 0x89, 0xb3, 0x09, 0xcc, 0x6e, 0xd7, 0x13,
		0xbe, 0xcf, 0x2f, 0xc6, 0xd3, 0x93, 0x39, 0x9d, 0xf0, 0x7d, 0x22, 0xca, 0xf4, 0x73, 0x83, 0xa6,
		0x4a, 0xf0, 0xd4, 0x00, 0xa2, 0xaa, 0xc1, 0x54, 0x1b, 0xa8, 0x6a, 0x03, 0x57, 0x3d, 0x20, 0xcb,
		0x0b, 0xb6, 0xcc, 0xa0, 0x3b, 0x5b, 0x32, 0xb6, 0x3b, 0x85, 0xad, 0x27, 0xce, 0xea, 0x19, 0x6a,
		0xf0, 0xf1, 0x88, 0xa9, 0x3b, 0xd3, 0xcf, 0xd6, 0xf2, 0x5e, 0x89, 0xb0, 0xab, 0x01, 0x91, 0x95,
		0x9d, 0xfb, 0x9a, 0x57, 0xb8, 0x77, 0x6b, 0x7b, 0x78, 0xa6, 0x70, 0xce, 0x86, 0x29, 0xa5, 0xf0,
		0x1c, 0x65, 0xdb, 0x39, 0x9b, 0xf8, 0xf8, 0xf8, 0x3e, 0x63, 0x9c, 0xb7, 0xde, 0xee, 0xb3, 0xc6,
		0x79, 0x6b, 0xfc, 0x32, 0x3b, 0xfa, 0x6b, 0xfc, 0x3a, 0x77, 0x9f, 0x31, 0xf2, 0xd3, 0xd7, 0x85,
		0xfb, 0x8c, 0x51, 0x68, 0x9d, 0x7c, 0xf9, 0xf2, 0xe1, 0xe4, 0xfb, 0xe9, 0x60, 0xff, 0x0f, 0xa6,
		0x94, 0x3d, 0x5a, 0x4b, 0xe5, 0xd6, 0xd5, 0xef, 0xaa, 0x7f, 0x68, 0xdb, 0xbf, 0xbf, 0x54, 0x6e,
		0xe0, 0xbf, 0x14, 0xee, 0xa0, 0x92, 0x99, 0x06, 0xef, 0x13, 0x0c, 0x9e, 0x45, 0x80, 0xa7, 0x12,
		0xf0, 0x34, 0x8d, 0xc7, 0xb2, 0xf1, 0xa9, 0xf5, 0x3d, 0xfb, 0x3e, 0x3f, 0xb8, 0x38, 0xf9, 0x5e,
		0x1a, 0xac, 0xbe, 0xf9, 0xb6, 0xe9, 0xd7, 0xb2, 0xef, 0x4b, 0x83, 0x8b, 0x2d, 0xff, 0x52, 0x1c,
		0x5c, 0xec, 0x38, 0x46, 0x61, 0x70, 0xbc, 0xf6, 0xab, 0xc3, 0xf7, 0x73, 0xdb, 0x3e, 0x90, 0xdf,
		0xf2, 0x81, 0xd3, 0x6d, 0x1f, 0x38, 0xdd, 0xf2, 0x81, 0xad, 0x5f, 0x29, 0xb7, 0xe5, 0x03, 0x85,
		0xc1, 0xdb, 0xda, 0xef, 0x1f, 0x6f, 0xfe, 0xd5, 0xe2, 0xe0, 0xe4, 0x6d, 0xdb, 0xbf, 0x95, 0x06,
		0x6f, 0x17, 0x27, 0x50, 0x25, 0x7c, 0xaa, 0x04, 0xe2, 0xac, 0x5e, 0x9c, 0x93, 0xa7, 0x58, 0xdf,
		0xc5, 0xfb, 0x39, 0x06, 0xb1, 0xec, 0xd6, 0xf9, 0xec, 0xf6, 0x0c, 0xa9, 0xc2, 0xc2, 0x9e, 0xd1,
		0x8c, 0xd9, 0x8c, 0xf0, 0x3d, 0xc2, 0xf7, 0x08, 0xdf, 0x23, 0x7c, 0x8f, 0xf0, 0x3d, 0xae, 0x76,
		0x80, 0x57, 0x04, 0x91, 0x47, 0xcc, 0x11, 0xcf, 0x6b, 0x73, 0xf1, 0x44, 0x40, 0x27, 0x43, 0x11,
		0x5b, 0x4e, 0x57, 0x7c, 0x53, 0xa7, 0x85, 0xc7, 0xd3, 0x41, 0x05, 0x43, 0x05, 0x43, 0x05, 0x43,
		0x05, 0x43, 0x05, 0x2f, 0x9c, 0xb8, 0xbe, 0xe5, 0xc8, 0x33, 0x85, 0xaa, 0xb7, 0xa0, 0x60, 0xaa,
		0x5b, 0xd3, 0x79, 0x4a, 0xe4, 0xcd, 0xdf, 0xb5, 0xe5, 0x28, 0x03, 0x2c, 0xc5, 0x7a, 0x6d, 0x6d,
		0xda, 0x51, 0x7f, 0x16, 0x0d, 0xf3, 0x7e, 0xf2, 0xcc, 0x51, 0x06, 0xf1, 0x95, 0xf5, 0x64, 0x8d,
		0x9b, 0x63, 0x2b, 0x9b, 0x7f, 0xa0, 0xd0, 0x95, 0x7a, 0x6d, 0x7e, 0x3b, 0x38, 0x51, 0xca, 0x15,
		0x0a, 0x07, 0x24, 0x4c, 0xf0, 0x63, 0xea, 0x35, 0x9f, 0x62, 0x15, 0xf4, 0xc9, 0x94, 0x80, 0xba,
		0x36, 0x4f, 0xf4, 0x12, 0x52, 0x37, 0x27, 0x1f, 0x6e, 0x7e, 0x3b, 0xcd, 0x1a, 0x6d, 0x7f, 0x14,
		0xa5, 0x6c, 0xd6, 0xe9, 0x0f, 0xb7, 0xc3, 0xc7, 0xaf, 0x8f, 0x17, 0x65, 0xd3, 0x9b, 0xa4, 0x69,
		0xaf, 0xfc, 0x67, 0x88, 0xe1, 0xfc, 0x30, 0x3b, 0x33, 0x94, 0x38, 0x31, 0x98, 0x35, 0x33, 0x12,
		0x3d, 0xa2, 0xe9, 0x9c, 0x40, 0xa2, 0xc7, 0x21, 0xeb, 0x7c, 0x76, 0x67, 0xc3, 0xbc, 0x0d, 0x90,
		0x30, 0x1f, 0xc3, 0x35, 0x28, 0xdd, 0x15, 0xc0, 0xb2, 0x25, 0xc6, 0x39, 0x1a, 0x13, 0xda, 0xf2,
		0xe1, 0xc3, 0x84, 0x08, 0xa4, 0xc7, 0x98, 0x7c, 0xc0, 0xba, 0x6f, 0xdc, 0xcc, 0x8c, 0x5d, 0xf7,
		0x05, 0xed, 0x99, 0xb6, 0x97, 0xe8, 0x70, 0xeb, 0xbe, 0x1c, 0x74, 0x1f, 0x74, 0x1f, 0x74, 0x5f,
		0x24, 0x74, 0x1f, 0x92, 0x1c, 0x23, 0xed, 0xc2, 0xc3, 0x2d, 0x67, 0xbc, 0xc0, 0x54, 0x1b, 0xa8,
		0x6a, 0x03, 0x57, 0x3d, 0x20, 0xcb, 0x0b, 0xb6, 0xcc, 0xa0, 0xab, 0xce, 0xf0, 0x58, 0xf7, 0x9d,
		0x20, 0xc9, 0x91, 0xe2, 0x0f, 0x92, 0x1c, 0x79, 0x75, 0x11, 0x92, 0x1c, 0x29, 0xff, 0x20, 0xc9,
		0x11, 0x49, 0x8e, 0x11, 0x50, 0x77, 0x7a, 0xc1, 0x13, 0x49, 0x8e, 0x6a, 0xc0, 0x13, 0x59, 0x61,
		0x48, 0x72, 0x4c, 0x90, 0x2a, 0x81, 0x38, 0x23, 0xc9, 0x31, 0xe2, 0x56, 0xea, 0x11, 0x92, 0x1c,
		0x37, 0x9e, 0x60, 0x24, 0x39, 0xc2, 0xf7, 0x08, 0xdf, 0x23, 0x7c, 0x8f, 0xf0, 0x3d, 0x46, 0xc3,
		0xf7, 0x88, 0x24, 0xc7, 0x03, 0x55, 0xc4, 0x48, 0x72, 0x84, 0x0a, 0x86, 0x0a, 0x86, 0x0a, 0x86,
		0x0a, 0xd6, 0xad, 0x82, 0x91, 0xe4, 0x18, 0xf6, 0x0f, 0x92, 0x1c, 0x59, 0xa6, 0x45, 0x92, 0x23,
		0xaf, 0x28, 0x21, 0xc9, 0x31, 0xe1, 0xc2, 0x04, 0x3f, 0xa6, 0x5e, 0xf3, 0x09, 0x49, 0x8e, 0x1b,
		0xe6, 0x89, 0x79, 0x92, 0x23, 0x67, 0xb0, 0xfd, 0x51, 0x2c, 0x73, 0x1c, 0xef, 0x46, 0x2b, 0x12,
		0x97, 0x34, 0x8f, 0x48, 0x37, 0xdc, 0xfa, 0x4d, 0xbc, 0x72, 0x39, 0x2b, 0x52, 0x35, 0xcb, 0x97,
		0x65, 0x29, 0x99, 0x3a, 0x7a, 0x5d, 0x5b, 0x4e, 0xc5, 0x16, 0x43, 0x5b, 0xcf, 0xe7, 0x51, 0xef,
		0x43, 0xba, 0xb2, 0x30, 0x43, 0xf6, 0x2c, 0x9f, 0x2f, 0x96, 0xf2, 0xf9, 0x4c, 0xe9, 0xb4, 0x94,
		0x39, 0x2f, 0x14, 0xb2, 0xc5, 0x2c, 0x83, 0x66, 0x4f, 0xd5, 0xbd, 0xae, 0xf0, 0x44, 0xf7, 0xe3,
		0x70, 0x5b, 0x9c, 0xbe, 0x6d, 0x47, 0x5a, 0x7a, 0x98, 0x11, 0x3c, 0xe6, 0xc8, 0x9d, 0x62, 0x49,
		0xf0, 0x8a, 0x17, 0x56, 0xa7, 0xd0, 0x6f, 0x5c, 0xdf, 0x39, 0x8a, 0xcd, 0xf9, 0x49, 0x62, 0xff,
		0xf1, 0x4d, 0x27, 0x24, 0x49, 0xdd, 0xc8, 0x27, 0x2b, 0x4c, 0xdc, 0x7b, 0x7c, 0x34, 0x2a, 0x6d,
		0xa7, 0xf1, 0x0c, 0x3a, 0x8d, 0x93, 0x0c, 0x8d, 0x4e, 0xe3, 0x5b, 0xe1, 0xfb, 0x70, 0x3a, 0x8d,
		0x93, 0x5f, 0x16, 0x30, 0x16, 0x25, 0xe0, 0x28, 0x42, 0xb0, 0xa1, 0xe8, 0xc0, 0x08, 0xb2, 0x12,
		0x04, 0xec, 0xb4, 0x35, 0x04, 0x58, 0x6a, 0x06, 0x10, 0xd7, 0x08, 0x20, 0xaf, 0x09, 0x00, 0x68,
		0x07, 0xb4, 0xc7, 0x0e, 0xda, 0xa9, 0x73, 0xf0, 0x69, 0x19, 0x22, 0x27, 0x53, 0x64, 0x62, 0x8c,
		0x6c, 0xcc, 0x91, 0x13, 0x66, 0x14, 0xc0, 0x0d, 0x37, 0xec, 0x28, 0x83, 0x1f, 0x65, 0x30, 0xa4,
		0x06, 0x8e, 0xe8, 0xbd, 0x2c, 0x1c, 0x3e, 0x47, 0xb6, 0x70, 0x95, 0x05, 0xa6, 0xe2, 0x59, 0x0e,
		0x47, 0x55, 0xc9, 0x79, 0x22, 0x5e, 0x54, 0xbd, 0x62, 0x94, 0x7e, 0x18, 0xab, 0x6b, 0xf4, 0x3c,
		0x57, 0x8a, 0xd1, 0x65, 0xb4, 0xe1, 0x89, 0xff, 0xe9, 0x5b, 0x9e, 0xe8, 0xf2, 0x29, 0x84, 0x6d,
		0x13, 0x12, 0xcb, 0xdf, 0x95, 0x78, 0x34, 0xfb, 0xf6, 0xe8, 0x04, 0x3e, 0x9a, 0xb6, 0x0f, 0x1d,
		0xa4, 0x4e, 0x07, 0x19, 0xbe, 0x07, 0x35, 0x14, 0x51, 0x35, 0x34, 0xdc, 0x1b, 0x68, 0x22, 0x62,
		0xb9, 0x7f, 0x70, 0x5d, 0x5b, 0x98, 0x0e, 0xa7, 0x2a, 0xca, 0x1e, 0x88, 0x2a, 0xf2, 0x85, 0x3d,
		0x51, 0x0c, 0x2f, 0x6e, 0x57, 0xf0, 0x6a, 0xa1, 0x95, 0xb9, 0xf8, 0x14, 0xd0, 0x75, 0xf5, 0x8f,
		0xca, 0x55, 0xfb, 0xba, 0x7e, 0x55, 0x81, 0x16, 0x82, 0x16, 0x82, 0x16, 0x82, 0x16, 0xe2, 0x90,
		0x7b, 0xe1, 0xf4, 0x5f, 0x84, 0x37, 0xbe, 0x9e, 0x66, 0xd4, 0x44, 0x0c, 0xf9, 0x71, 0x4c, 0xf9,
		0x70, 0x08, 0x43, 0xd8, 0x53, 0xff, 0x46, 0x2e, 0x0c, 0x81, 0x3a, 0xa6, 0x32, 0x32, 0x51, 0x07,
		0x84, 0xa1, 0x91, 0x04, 0xb7, 0x51, 0xef, 0x34, 0x4a, 0xf5, 0x34, 0xb4, 0x91, 0xc0, 0x4f, 0x4c,
		0x1b, 0xc9, 0x48, 0x1f, 0xb9, 0xa8, 0x24, 0x52, 0x91, 0x36, 0x32, 0x31, 0xec, 0xe6, 0x12, 0x43,
		0x55, 0xf4, 0x20, 0x2a, 0x45, 0x72, 0x93, 0x1b, 0x09, 0x50, 0x0a, 0x07, 0x47, 0xc1, 0x41, 0x24,
		0xd8, 0x27, 0x03, 0x4a, 0x26, 0x95, 0x44, 0xea, 0x95, 0xc4, 0x10, 0x52, 0xa7, 0x47, 0xda, 0x82,
		0xc9, 0xd6, 0xfe, 0x92, 0x11, 0x40, 0x2a, 0x52, 0xb2, 0xef, 0x38, 0xc2, 0x0e, 0x5e, 0x73, 0x7c,
		0x46, 0xc0, 0xa7, 0x03, 0x05, 0x94, 0xcc, 0x70, 0xc1, 0x12, 0xa1, 0x6d, 0x76, 0x0a, 0xdb, 0x9c,
		0xf0, 0x36, 0x92, 0xca, 0xd0, 0x26, 0x37, 0xa8, 0xc9, 0x0d, 0x67, 0xda, 0xdb, 0x42, 0xb5, 0x68,
		0x1a, 0x36, 0x18, 0x61, 0x72, 0x66, 0xc2, 0xef, 0xf2, 0xf2, 0x19, 0x0c, 0xbb, 0xc5, 0x34, 0x71,
		0x4b, 0x64, 0x6e, 0x34, 0x4a, 0xb7, 0x19, 0x43, 0xc0, 0x00, 0xb5, 0x4f, 0x8c, 0xcd, 0x07, 0xc6,
		0xe6, 0xf3, 0xe2, 0xb9, 0xf0, 0xd7, 0x6b, 0x97, 0x51, 0xc5, 0x19, 0xa5, 0x1e, 0x4c, 0xa7, 0xfb,
		0x8f, 0xd5, 0x1d, 0x11, 0x25, 0xe2, 0x60, 0xc5, 0xf9, 0xd0, 0x11, 0x0f, 0x58, 0x44, 0x2c, 0x3a,
		0xad, 0x2f, 0x12, 0x01, 0x8b, 0xf1, 0x71, 0x57, 0x92, 0x07, 0x2c, 0x9a, 0x7d, 0xe9, 0x1a, 0xf4,
		0xa8, 0xb2, 0x76, 0x20, 0x56, 0xe6, 0xe1, 0xb9, 0xba, 0xcb, 0xe2, 0xea, 0x0e, 0x41, 0x8c, 0x51,
		0x82, 0x26, 0x35, 0x10, 0x45, 0x0b, 0x55, 0xc4, 0x90, 0xc5, 0x06, 0x5d, 0xb3, 0x81, 0x3b, 0xd3,
		0x53, 0xca, 0xdc, 0x01, 0x92, 0xb5, 0xf3, 0xb6, 0xb2, 0x16, 0x90, 0x68, 0x7f, 0x1c, 0x05, 0x88,
		0x53, 0x0e, 0x75, 0xca, 0x21, 0x4f, 0x2d, 0xf4, 0xf1, 0x40, 0x20, 0x13, 0x14, 0xb2, 0x43, 0xe2,
		0x9c, 0xdd, 0x75, 0xff, 0xbb, 0xef, 0x4b, 0xc3, 0x72, 0xa4, 0xf0, 0xbe, 0x9a, 0xb6, 0xca, 0x56,
		0x90, 0xcb, 0x13, 0xa3, 0x26, 0x6c, 0xd4, 0xc0, 0x54, 0x03, 0xa8, 0xaa, 0x06, 0x57, 0x6d, 0x20,
		0xab, 0x0d, 0x6c, 0xf5, 0x80, 0x2e, 0x2f, 0xf8, 0x32, 0x83, 0xf0, 0x6c, 0xc9, 0xf4, 0xd4, 0x84,
		0x3d, 0xcd, 0x29, 0x2c, 0x0a, 0x5b, 0x42, 0x51, 0xd8, 0xe0, 0x0f, 0x86, 0xa2, 0xb0, 0xfc, 0xf3,
		0xa2, 0x28, 0x6c, 0x62, 0x45, 0x29, 0x9f, 0x3b, 0xcf, 0x9f, 0x17, 0x4b, 0xb9, 0x73, 0xd4, 0x86,
		0x8d, 0xdd, 0x2c, 0xe8, 0x71, 0xb5, 0xd5, 0xb4, 0x92, 0xcf, 0x9e, 0xf0, 0x9f, 0x5d, 0xbb, 0xab,
		0xdc, 0xb6, 0x9a, 0xcf, 0x0c, 0xe3, 0x0a, 0xc6, 0x15, 0x8c, 0x2b, 0x18, 0x57, 0x30, 0xae, 0x16,
		0x4e, 0x5c, 0x4f, 0x78, 0x1d, 0xe1, 0x48, 0xf3, 0x49, 0xa0, 0xeb, 0x06, 0x0c, 0x2c, 0x18, 0x58,
		0x30, 0xb0, 0x12, 0x2e, 0x4a, 0xd9, 0x4c, 0x06, 0x96, 0x15, 0x2c, 0xab, 0xf8, 0x5b, 0x56, 0xc2,
		0x31, 0x1f, 0x6c, 0xa1, 0xd0, 0xa0, 0x9a, 0x4e, 0xc8, 0xcc, 0x81, 0x98, 0xab, 0xe8, 0xc0, 0x6e,
		0x83, 0xdd, 0x06, 0xbb, 0x0d, 0x76, 0x5b, 0xcc, 0xed, 0x36, 0xbe, 0xfa, 0x3f, 0xdb, 0x00, 0x92,
		0xb8, 0x1e, 0x50, 0x32, 0x94, 0xf0, 0x8b, 0xf9, 0xcd, 0x78, 0xf8, 0x47, 0x9d, 0x0e, 0x9e, 0xcc,
		0x07, 0x95, 0x08, 0x95, 0x08, 0x95, 0x08, 0x95, 0x08, 0x95, 0xb8, 0x29, 0x33, 0xcb, 0xf8, 0xfb,
		0xa1, 0xe7, 0x2b, 0xd4, 0x8c, 0x67, 0x0a, 0xa6, 0xfa, 0xec, 0x8c, 0x7d, 0x07, 0xa9, 0xdf, 0x14,
		0x3d, 0x1b, 0xfc, 0xa7, 0xf1, 0xd3, 0xa8, 0x6b, 0xd3, 0xc2, 0x7f, 0xca, 0x2b, 0x4a, 0x87, 0xe8,
		0x3f, 0x55, 0xd2, 0xec, 0x30, 0xb2, 0xd2, 0x05, 0x87, 0x6a, 0x72, 0x6d, 0x39, 0xcb, 0x51, 0x6b,
		0xcb, 0x8d, 0xe7, 0x83, 0x2d, 0x07, 0x5b, 0x0e, 0xb6, 0x1c, 0x6c, 0x39, 0xd8, 0x72, 0xb0, 0xe5,
		0x60, 0xcb, 0xc1, 0x96, 0x83, 0x2d, 0x07, 0x5b, 0x0e, 0xb6, 0x1c, 0x6c, 0xb9, 0xe4, 0xdb, 0x72,
		0xb1, 0x4a, 0x42, 0x67, 0xaa, 0x80, 0xbe, 0x36, 0x8f, 0xb2, 0x22, 0xaf, 0x93, 0xd2, 0xa1, 0x93,
		0xbf, 0xd3, 0x33, 0xc6, 0x95, 0x5e, 0xae, 0x41, 0x94, 0x66, 0xad, 0xe7, 0x71, 0xa4, 0xa8, 0x3c,
		0x6c, 0x73, 0xfc, 0xb0, 0x93, 0xbf, 0xdb, 0x1f, 0xa7, 0x4f, 0xd7, 0x2e, 0xf7, 0xa5, 0x3b, 0xff,
		0x69, 0x62, 0xc5, 0xbe, 0x8b, 0x87, 0xb8, 0x33, 0x88, 0x7a, 0xca, 0xfd, 0x2a, 0xbc, 0x47, 0xdb,
		0xfd, 0x87, 0xbf, 0x4e, 0xcc, 0x6c, 0x26, 0x54, 0x8a, 0xd1, 0xe5, 0xe8, 0x40, 0xa5, 0x98, 0x18,
		0x3a, 0x32, 0x50, 0x29, 0x66, 0xfb, 0xd2, 0xb0, 0x57, 0x8a, 0x61, 0x2e, 0xa2, 0xb5, 0x76, 0x30,
		0xd9, 0x95, 0xaf, 0x02, 0xa8, 0x54, 0x06, 0x99, 0x2a, 0xa1, 0x53, 0x03, 0x84, 0xaa, 0x86, 0x52,
		0x6d, 0x90, 0xaa, 0x0d, 0x5a, 0xf5, 0x40, 0xac, 0x1a, 0x4b, 0x91, 0xdb, 0x47, 0xcc, 0x0d, 0xbd,
		0xb3, 0x89, 0x54, 0xe5, 0x3d, 0xac, 0x9d, 0x70, 0x35, 0xf9, 0x0f, 0xf3, 0x05, 0x55, 0x9b, 0x07,
		0xa1, 0xc9, 0x27, 0xa5, 0x4c, 0x29, 0xe8, 0x50, 0x0e, 0x1a, 0x95, 0x84, 0x2e, 0x65, 0xa1, 0x5d,
		0x69, 0x68, 0x57, 0x1e, 0x7a, 0x95, 0x88, 0x1a, 0x65, 0xa2, 0x48, 0xa9, 0xcc, 0x96, 0x52, 0xd9,
		0x05, 0xe4, 0xda, 0x89, 0x55, 0x97, 0x67, 0xb1, 0xc6, 0xc6, 0xb3, 0x09, 0xf1, 0x4f, 0x2b, 0x10,
		0x92, 0x99, 0x33, 0x49, 0x61, 0xa1, 0x99, 0xad, 0x0e, 0x2d, 0x65, 0x25, 0x67, 0xa0, 0xb2, 0xa1,
		0xb2, 0xa1, 0xb2, 0xa1, 0xb2, 0xa1, 0xb2, 0x8f, 0xb4, 0x95, 0xb4, 0x59, 0xc5, 0x60, 0x85, 0xf7,
		0xe7, 0x8a, 0xc3, 0x7a, 0xa6, 0x7f, 0xd4, 0x82, 0xd2, 0x91, 0xae, 0x30, 0x1f, 0x4d, 0xca, 0x75,
		0x6d, 0x7a, 0x4d, 0x61, 0x3f, 0xb3, 0xf9, 0x35, 0x06, 0x68, 0x28, 0x86, 0xac, 0x65, 0x91, 0xd3,
		0x10, 0x0e, 0x14, 0x35, 0x91, 0x53, 0x5e, 0x2a, 0x27, 0x52, 0x42, 0xf7, 0x2e, 0x99, 0xb3, 0xb5,
		0x60, 0x55, 0xee, 0x2c, 0x86, 0xd2, 0xb3, 0x9e, 0x9e, 0x84, 0x67, 0x88, 0xaf, 0xc2, 0x91, 0x46,
		0xc7, 0xed, 0x8f, 0x98, 0xa1, 0x62, 0xb3, 0x72, 0xd3, 0x97, 0x80, 0x5d, 0x09, 0xbb, 0x12, 0x76,
		0x25, 0xec, 0x4a, 0xd8, 0x95, 0x0a, 0x4f, 0x6c, 0xdf, 0x72, 0x64, 0xb6, 0xa8, 0xc1, 0xa6, 0x2c,
		0xc2, 0xa6, 0x84, 0x4d, 0x09, 0x9b, 0x12, 0x36, 0x65, 0x02, 0x44, 0xae, 0x58, 0x28, 0x9c, 0x16,
		0x60, 0x55, 0xc2, 0xaa, 0x8c, 0xa8, 0x55, 0x19, 0xeb, 0x18, 0x2c, 0x45, 0x39, 0x2a, 0xb3, 0xf9,
		0x22, 0x97, 0xab, 0x32, 0xbd, 0x82, 0x4d, 0x2b, 0x89, 0x9b, 0x3d, 0x8a, 0x56, 0xf2, 0x4a, 0x7d,
		0xf2, 0xf0, 0xac, 0x59, 0x2c, 0xfc, 0x07, 0x65, 0xc0, 0x9a, 0x69, 0x64, 0x4a, 0xa1, 0x2e, 0x7a,
		0x7b, 0x3c, 0x5d, 0xc2, 0x82, 0xb7, 0x73, 0x08, 0xde, 0x8e, 0x91, 0x13, 0x06, 0xc1, 0xdb, 0x08,
		0xde, 0xfe, 0xf9, 0x92, 0x21, 0x78, 0x9b, 0x7a, 0x41, 0x11, 0xbc, 0x1d, 0x77, 0xe5, 0xa0, 0x51,
		0x49, 0xe8, 0x52, 0x16, 0xda, 0x95, 0x86, 0x76, 0xe5, 0xa1, 0x57, 0x89, 0xa8, 0xb5, 0xdb, 0x11,
		0xbc, 0xcd, 0xc8, 0xc6, 0x11, 0xbc, 0xbd, 0xfb, 0x9a, 0x21, 0x78, 0x1b, 0x2a, 0x1b, 0x2a, 0x1b,
		0x2a, 0x1b, 0x2a, 0x1b, 0x2a, 0x1b, 0xc1, 0xdb, 0xac, 0x7f, 0x70, 0xd1, 0xae, 0x74, 0x7a, 0x5c,
		0xb4, 0xe3, 0xa2, 0x5d, 0x93, 0xc8, 0x21, 0x78, 0x3b, 0x81, 0xb3, 0x21, 0x78, 0x7b, 0x77, 0x31,
		0x44, 0xf0, 0x36, 0xec, 0x4a, 0xd8, 0x95, 0xb0, 0x2b, 0x61, 0x57, 0xc2, 0xae, 0x44, 0xf0, 0x36,
		0x6c, 0x4a, 0xd8, 0x94, 0xb0, 0x29, 0x61, 0x53, 0x86, 0x12, 0x39, 0x04, 0x6f, 0xc3, 0xaa, 0x8c,
		0xb2, 0x55, 0x89, 0xe0, 0xed, 0x3d, 0xe6, 0x8b, 0x6e, 0xf0, 0xb6, 0x8a, 0xb0, 0xd9, 0xa3, 0x88,
		0xc6, 0x6e, 0xdf, 0x8d, 0x9e, 0x1d, 0x1d, 0x3d, 0xf8, 0x0f, 0xde, 0xe1, 0x76, 0xf4, 0x60, 0xee,
		0xbc, 0x10, 0xd1, 0xa3, 0x75, 0xc8, 0x5d, 0x3d, 0x78, 0xf3, 0x1e, 0x94, 0xe4, 0x3b, 0x28, 0xeb,
		0xe7, 0x91, 0x43, 0x3f, 0x8f, 0x5d, 0xa6, 0x42, 0x3f, 0x8f, 0x58, 0xfa, 0x17, 0xd1, 0xcf, 0x63,
		0x69, 0x02, 0xb3, 0xfb, 0xdf, 0x7d, 0x5f, 0x1a, 0x96, 0x23, 0x85, 0xf7, 0xd5, 0xb4, 0xd5, 0xa5,
		0x86, 0xad, 0x4e, 0x8c, 0x2e, 0xd0, 0x51, 0x03, 0x53, 0x0d, 0xa0, 0xaa, 0x1a, 0x5c, 0xb5, 0x81,
		0xac, 0x36, 0xb0, 0xd5, 0x03, 0xba, 0xc9, 0x70, 0x50, 0xa8, 0xef, 0x02, 0xdd, 0xb7, 0x1c, 0x79,
		0x9a, 0x53, 0xd8, 0xfd, 0xb9, 0x84, 0x66, 0xcc, 0xc1, 0x1f, 0x0c, 0xcd, 0x98, 0xf9, 0xe7, 0x45,
		0x33, 0xe6, 0xc4, 0x8a, 0x52, 0x3e, 0x77, 0x9e, 0x3f, 0x2f, 0x96, 0x72, 0xe7, 0x68, 0xc1, 0x1c,
		0xbb, 0x59, 0x5a, 0xa8, 0xb5, 0xb1, 0xcd, 0xb4, 0x52, 0x97, 0xd3, 0xb5, 0x6a, 0x5b, 0xa9, 0xca,
		0xe4, 0x82, 0x71, 0x05, 0xe3, 0x0a, 0xc6, 0x15, 0x8c, 0xab, 0x98, 0x19, 0x57, 0x4a, 0x33, 0xad,
		0x14, 0x66, 0x58, 0xc1, 0xc0, 0x82, 0x81, 0x05, 0x03, 0x0b, 0x06, 0xd6, 0x9a, 0x28, 0x29, 0xcf,
		0x88, 0x82, 0x65, 0x05, 0xcb, 0x8a, 0x43, 0xac, 0x54, 0x15, 0xd1, 0x52, 0x5c, 0x3c, 0x4b, 0x75,
		0xd1, 0x2c, 0xd8, 0x6d, 0xb0, 0xdb, 0x60, 0xb7, 0xc1, 0x6e, 0x8b, 0x99, 0xdd, 0xa6, 0xae, 0xa8,
		0x95, 0xa2, 0x62, 0x56, 0xf1, 0x54, 0xc2, 0xd3, 0xc8, 0x0d, 0xe3, 0xd9, 0x7a, 0x7a, 0x36, 0x1e,
		0xfe, 0x51, 0xa7, 0x8d, 0xd7, 0x66, 0x86, 0x9a, 0x84, 0x9a, 0x84, 0x9a, 0x84, 0x9a, 0x84, 0x9a,
		0x5c, 0x54, 0x93, 0xd3, 0x00, 0x70, 0xe3, 0xef, 0x87, 0x9e, 0xaf, 0x50, 0x5b, 0x9e, 0x29, 0x98,
		0xea, 0xb3, 0x33, 0xf6, 0x27, 0xa4, 0x7e, 0x53, 0xf4, 0x6c, 0xf0, 0xa9, 0xc6, 0x4f, 0xa3, 0xae,
		0x4d, 0x0b, 0x9f, 0x2a, 0xaf, 0x28, 0x1d, 0xa2, 0x4f, 0xf5, 0x2c, 0x9f, 0x2f, 0x96, 0xf2, 0xf9,
		0x4c, 0xe9, 0xb4, 0x94, 0x39, 0x2f, 0x14, 0xb2, 0xc5, 0x2c, 0xc2, 0x57, 0x62, 0x37, 0x0b, 0x9c,
		0xac, 0xeb, 0x62, 0xf5, 0x62, 0x7e, 0x53, 0x6a, 0xd5, 0x4d, 0xe6, 0x83, 0x2d, 0x07, 0x5b, 0x0e,
		0xb6, 0x1c, 0x6c, 0x39, 0xd8, 0x72, 0xb0, 0xe5, 0x60, 0xcb, 0xc1, 0x96, 0x83, 0x2d, 0x07, 0x5b,
		0x0e, 0xb6, 0x1c, 0x6c, 0x39, 0xd8, 0x72, 0x61, 0x6c, 0x39, 0xcb, 0x51, 0x6b, 0xcb, 0x8d, 0xe7,
		0x83, 0x2d, 0x07, 0x5b, 0x0e, 0xb6, 0x1c, 0x6c, 0x39, 0xd8, 0x72, 0xb0, 0xe5, 0x60, 0xcb, 0xc1,
		0x96, 0x83, 0x2d, 0x07, 0x5b, 0x0e, 0xb6, 0x1c, 0x6c, 0xb9, 0xe4, 0xdb, 0x72, 0xa8, 0x03, 0xba,
		0x61, 0x9e, 0xc8, 0xd5, 0x01, 0xe5, 0xae, 0xb3, 0x1b, 0xa1, 0x22, 0xa0, 0x8c, 0x65, 0x75, 0xe3,
		0x51, 0x01, 0xb4, 0xef, 0x74, 0x27, 0x65, 0x50, 0xd9, 0xab, 0x80, 0xce, 0xa7, 0x8a, 0x79, 0x25,
		0xd0, 0x0c, 0x2a, 0x81, 0x46, 0xc8, 0xb1, 0x81, 0x4a, 0xa0, 0x87, 0xac, 0xa4, 0xd9, 0x2b, 0x81,
		0x76, 0xa6, 0xa7, 0x5e, 0x91, 0x8f, 0x78, 0x32, 0x9f, 0x1a, 0x1f, 0x71, 0x16, 0x3e, 0xe2, 0x28,
		0x43, 0xa8, 0x6a, 0x28, 0xd5, 0x06, 0xa9, 0xda, 0xa0, 0x55, 0x0f, 0xc4, 0xaa, 0xb1, 0x14, 0xb9,
		0x7d, 0xc4, 0xdc, 0xd0, 0x3b, 0x9b, 0x48, 0x55, 0x5e, 0xfb, 0xda, 0x09, 0x57, 0x93, 0xdf, 0x3e,
		0x5f, 0x50, 0xb5, 0x79, 0xee, 0x9a, 0x7c, 0x52, 0xe8, 0x08, 0x9a, 0x2c, 0x65, 0xa1, 0x5d, 0x69,
		0x68, 0x57, 0x1e, 0x7a, 0x95, 0x88, 0x1a, 0x65, 0xa2, 0x48, 0xa9, 0xcc, 0x96, 0x52, 0x5f, 0x47,
		0x50, 0x75, 0x79, 0xf4, 0x6b, 0x6c, 0x3c, 0x8b, 0x36, 0xde, 0x3b, 0xaf, 0x19, 0xda, 0x78, 0x43,
		0x69, 0x43, 0x69, 0x43, 0x69, 0x43, 0x69, 0x43, 0x69, 0xa3, 0x8d, 0x37, 0xe3, 0x1f, 0xb4, 0xf1,
		0x56, 0x3a, 0x3d, 0xda, 0x78, 0xa3, 0x8d, 0xb7, 0x26, 0x91, 0x43, 0x1b, 0xef, 0x44, 0xce, 0xd6,
		0x82, 0x55, 0xb9, 0xb3, 0x18, 0xce, 0x62, 0x14, 0x14, 0xf6, 0xa7, 0x58, 0x27, 0x33, 0x1b, 0xbe,
		0x04, 0xac, 0x4a, 0x58, 0x95, 0xb0, 0x2a, 0x61, 0x55, 0xc2, 0xaa, 0x54, 0x78, 0x62, 0x95, 0xb6,
		0xc2, 0x58, 0xc5, 0xe0, 0x02, 0x2c, 0x4b, 0x58, 0x96, 0xb0, 0x2c, 0x61, 0x59, 0x26, 0x40, 0xe4,
		0x94, 0xb7, 0xd8, 0x80, 0x5d, 0x09, 0xbb, 0x32, 0x1a, 0x33, 0x70, 0x47, 0x61, 0x29, 0xca, 0x52,
		0x99, 0xcd, 0x17, 0xb9, 0x6c, 0x95, 0x99, 0xb5, 0x9c, 0x56, 0x12, 0x3a, 0x7b, 0x14, 0xad, 0x04,
		0x96, 0xcf, 0xd3, 0xa7, 0x6f, 0x4f, 0x6c, 0x69, 0x94, 0xf9, 0xd8, 0xb0, 0x5b, 0xa6, 0x14, 0xea,
		0x22, 0xb8, 0xb9, 0xd3, 0xa7, 0x8e, 0x74, 0x04, 0x70, 0xe7, 0x10, 0xc0, 0x1d, 0x23, 0x47, 0x0c,
		0x02, 0xb8, 0x11, 0xc0, 0xfd, 0xf3, 0x25, 0x43, 0x00, 0x37, 0xf5, 0x82, 0x22, 0x80, 0x3b, 0xee,
		0xca, 0x41, 0xa3, 0x92, 0xd0, 0xa5, 0x2c, 0xb4, 0x2b, 0x0d, 0xed, 0xca, 0x43, 0xaf, 0x12, 0x51,
		0x6b, 0xb9, 0x23, 0x80, 0x9b, 0x91, 0x8d, 0x23, 0x80, 0x7b, 0xf7, 0x35, 0x43, 0x00, 0x37, 0x94,
		0x36, 0x94, 0x36, 0x94, 0x36, 0x94, 0x36, 0x94, 0x36, 0x02, 0xb8, 0x19, 0xff, 0xe0, 0x9a, 0x5d,
		0xe9, 0xf4, 0xb8, 0x66, 0xc7, 0x35, 0xbb, 0x26, 0x91, 0x43, 0x00, 0x77, 0x22, 0x67, 0x43, 0x00,
		0xf7, 0xee, 0x62, 0x88, 0x00, 0x6e, 0x58, 0x95, 0xb0, 0x2a, 0x61, 0x55, 0xc2, 0xaa, 0x84, 0x55,
		0x89, 0x00, 0x6e, 0x58, 0x96, 0xb0, 0x2c, 0x61, 0x59, 0xc2, 0xb2, 0x0c, 0x2d, 0x72, 0x08, 0xe0,
		0x86, 0x5d, 0x19, 0x5d, 0xbb, 0x12, 0x01, 0xdc, 0x7b, 0xcc, 0x17, 0xe1, 0x00, 0x6e, 0x15, 0x91,
		0xb3, 0x47, 0x51, 0x8d, 0xdf, 0x66, 0x6c, 0x45, 0xc0, 0x7f, 0x50, 0xd0, 0xd9, 0x23, 0x5e, 0x47,
		0xed, 0x30, 0xba, 0x7b, 0xcc, 0x0e, 0x57, 0x6c, 0x3a, 0x7c, 0xbc, 0x8b, 0xf0, 0xf1, 0xe1, 0x3e,
		0x36, 0x91, 0x3b, 0x2e, 0x0c, 0x87, 0x24, 0x3a, 0x87, 0x83, 0xf6, 0x48, 0xd0, 0x09, 0x2e, 0xa1,
		0xd0, 0x72, 0xf5, 0x6e, 0xe0, 0xed, 0xd5, 0xc0, 0x94, 0xda, 0xc3, 0xe6, 0xaa, 0xe7, 0x74, 0xc9,
		0x2b, 0x70, 0xbd, 0x73, 0xbb, 0xd8, 0x95, 0xb9, 0xd2, 0x95, 0xb9, 0xcc, 0xd5, 0xb8, 0xc6, 0xa3,
		0xad, 0x0a, 0xb9, 0x52, 0x67, 0x52, 0xbe, 0x90, 0x0b, 0x0a, 0x88, 0xbd, 0x27, 0xd7, 0xf2, 0x74,
		0xbc, 0x7d, 0xb9, 0x32, 0xe8, 0xcb, 0xa5, 0x13, 0xe8, 0x54, 0x01, 0x9e, 0x72, 0xe0, 0x53, 0x0e,
		0x80, 0x6a, 0x81, 0x30, 0x9e, 0x26, 0x36, 0xfb, 0x9d, 0x9f, 0xfa, 0xc6, 0xe1, 0x0a, 0x1a, 0x86,
		0x2b, 0x6b, 0x14, 0xae, 0xe8, 0xc2, 0x50, 0x81, 0x3b, 0x53, 0xe5, 0x85, 0xa0, 0xea, 0xe8, 0x1a,
		0xc5, 0x17, 0x7e, 0x3a, 0xee, 0x5a, 0x54, 0xc4, 0x84, 0xa9, 0xbc, 0xc0, 0xd3, 0x25, 0x22, 0xfa,
		0x1a, 0x7b, 0x6b, 0x91, 0x9a, 0x98, 0xba, 0xc9, 0x5b, 0x07, 0xdc, 0x69, 0xd8, 0xef, 0x89, 0x8e,
		0xf5, 0x68, 0x75, 0x46, 0x0e, 0x44, 0x43, 0x72, 0xf2, 0x83, 0xb9, 0x79, 0xb3, 0x3e, 0x27, 0x57,
		0x1f, 0xd2, 0x79, 0xea, 0xff, 0x5d, 0xa3, 0x72, 0x59, 0xfd, 0x54, 0xad, 0x5c, 0xc1, 0x9e, 0x82,
		0x3d, 0x05, 0x7b, 0x0a, 0xf6, 0x54, 0xbc, 0xec, 0x29, 0x29, 0xe6, 0x1e, 0x21, 0x4e, 0xc8, 0x5c,
		0x84, 0xb2, 0x6c, 0x9e, 0x71, 0x8e, 0x8a, 0xd3, 0x7f, 0x19, 0x2e, 0xdd, 0x00, 0x97, 0x80, 0x14,
		0x67, 0x34, 0xf1, 0x97, 0x80, 0x6c, 0x65, 0x04, 0xb5, 0x5e, 0xfe, 0x71, 0x94, 0x07, 0x8c, 0xe6,
		0xad, 0x1f, 0x4f, 0xb9, 0x3f, 0xd6, 0xf2, 0x7e, 0xec, 0x77, 0x7e, 0x39, 0xdc, 0xf9, 0x29, 0xa4,
		0x6c, 0xb8, 0xf3, 0x4b, 0xa2, 0xe6, 0xc3, 0x9d, 0x1f, 0x6c, 0x54, 0xd8, 0xa8, 0xb0, 0x51, 0x61,
		0xa3, 0x6a, 0xb7, 0x51, 0x71, 0xe7, 0x17, 0x64, 0x22, 0xdc, 0xf9, 0x45, 0x4f, 0x93, 0xad, 0x4d,
		0x87, 0x3b, 0x3f, 0x1a, 0x11, 0xc1, 0x9d, 0x5f, 0xd2, 0xa4, 0x06, 0x77, 0x7e, 0xac, 0xdf, 0x97,
		0xe5, 0xce, 0xcf, 0x7a, 0x72, 0x4c, 0x5b, 0x74, 0x95, 0x9a, 0x37, 0xeb, 0x73, 0xc2, 0xc6, 0x81,
		0x8d, 0x03, 0x1b, 0x07, 0x36, 0x0e, 0x6c, 0x1c, 0xd8, 0x38, 0xb0, 0x71, 0x60, 0xe3, 0xc0, 0xc6,
		0x81, 0x8d, 0x03, 0x1b, 0x07, 0x36, 0x0e, 0x8d, 0x8d, 0x83, 0xb8, 0x46, 0xd8, 0x53, 0xb0, 0xa7,
		0x60, 0x4f, 0xc1, 0x9e, 0x8a, 0xb4, 0x3d, 0x85, 0xb8, 0x46, 0xdd, 0xca, 0x17, 0x71, 0x8d, 0x5a,
		0xe3, 0x1a, 0xb9, 0xaa, 0x6b, 0x69, 0x0d, 0x6b, 0x64, 0xa8, 0x9a, 0x45, 0x18, 0xd5, 0xf8, 0x2e,
		0x42, 0x92, 0xce, 0x25, 0xe1, 0xfa, 0x25, 0x3b, 0x45, 0x1a, 0x3c, 0xaa, 0x4d, 0x96, 0x69, 0xa4,
		0x38, 0xbc, 0xcc, 0x11, 0xc8, 0x1b, 0x75, 0xe5, 0x1d, 0x9e, 0x8a, 0x3b, 0xc4, 0x51, 0xb7, 0xe4,
		0x06, 0x06, 0x87, 0x41, 0xc1, 0x68, 0x40, 0x70, 0x19, 0x0c, 0xec, 0x06, 0x02, 0xbb, 0x41, 0xc0,
		0x6b, 0x00, 0x44, 0x4b, 0xcb, 0x50, 0x47, 0xc9, 0xa6, 0xcc, 0xee, 0x8b, 0xe5, 0x18, 0x43, 0xf2,
		0xd2, 0xf7, 0xf9, 0xa2, 0xfa, 0x97, 0x66, 0xa1, 0x0e, 0x1c, 0x9e, 0xfb, 0x50, 0x26, 0x9b, 0x2f,
		0x2f, 0xca, 0x57, 0xd7, 0xd5, 0x9b, 0xf6, 0xe7, 0x06, 0x53, 0x22, 0x41, 0x06, 0xc5, 0xc3, 0x90,
		0x48, 0x10, 0x45, 0x9f, 0x08, 0x12, 0x09, 0x18, 0x7d, 0x1e, 0x33, 0x89, 0xb7, 0xba, 0xc2, 0x91,
		0x96, 0x7c, 0xf5, 0xc4, 0x23, 0x87, 0xd4, 0x4f, 0x79, 0x13, 0xc3, 0x4d, 0x4c, 0xaa, 0x3a, 0xf9,
		0xea, 0x1f, 0x4d, 0x5f, 0x81, 0x23, 0xbd, 0xf9, 0xf9, 0xe6, 0xa6, 0x52, 0x6b, 0x8f, 0xd1, 0xf8,
		0xae, 0x59, 0x6e, 0x7e, 0xbe, 0xe3, 0x3a, 0x61, 0xa3, 0x1b, 0x2d, 0x9f, 0xf5, 0x6a, 0x9a, 0xd9,
		0x51, 0x3b, 0x5d, 0xb4, 0xf1, 0x6a, 0x5d, 0xd5, 0xff, 0x7d, 0xc3, 0xe8, 0xc5, 0x7c, 0x9f, 0x8c,
		0x55, 0xfa, 0xdc, 0x88, 0x9b, 0xa7, 0xb7, 0x15, 0x75, 0x34, 0x8e, 0x64, 0xd2, 0x69, 0x57, 0xf8,
		0x1d, 0xcf, 0xea, 0xb1, 0xf8, 0x0f, 0x67, 0x22, 0xb5, 0x38, 0x09, 0x78, 0x23, 0x78, 0x23, 0x78,
		0x23, 0x78, 0x23, 0xa9, 0xc4, 0xfb, 0xd2, 0xb3, 0x9c, 0x27, 0x4e, 0xca, 0x78, 0x76, 0x00, 0xba,
		0xe0, 0xd9, 0xb5, 0xbb, 0x46, 0xcf, 0xb3, 0x5c, 0xcf, 0x92, 0xaf, 0x7c, 0xda, 0x60, 0x79, 0x1a,
		0x3e, 0x9f, 0x45, 0x06, 0xba, 0x46, 0x89, 0xae, 0xf1, 0xfc, 0xaf, 0x3d, 0xe8, 0x9a, 0x08, 0xea,
		0x9a, 0xd1, 0xc6, 0x40, 0xd7, 0x10, 0x4b, 0x7c, 0xdf, 0x72, 0xe4, 0x19, 0xa3, 0xaa, 0xe1, 0x70,
		0x4e, 0xf0, 0x46, 0x97, 0x33, 0x06, 0xc1, 0xa8, 0x88, 0x26, 0x57, 0x14, 0x22, 0xac, 0x2a, 0x7a,
		0x5c, 0x65, 0xfc, 0x2f, 0xa3, 0xb7, 0x43, 0x49, 0x94, 0xb8, 0xea, 0xad, 0x2f, 0x25, 0x68, 0xeb,
		0x63, 0x12, 0xbd, 0xd5, 0x3a, 0x00, 0xe2, 0xfe, 0x22, 0xa4, 0x67, 0x75, 0xf8, 0x18, 0xfb, 0x64,
		0x7c, 0xd0, 0x69, 0xb8, 0x6e, 0xe0, 0xba, 0x01, 0x9d, 0x26, 0x95, 0x78, 0xcb, 0x91, 0xa7, 0x39,
		0x46, 0x3a, 0x7d, 0x0a, 0x3a, 0xad, 0x87, 0x4e, 0x67, 0x15, 0x71, 0xaa, 0x5c, 0x36, 0x5f, 0xca,
		0x9f, 0x9d, 0x16, 0xf3, 0x67, 0xe0, 0xd5, 0x87, 0xca, 0xab, 0x67, 0x32, 0x00, 0x82, 0x0d, 0x82,
		0xcd, 0x46, 0xb0, 0x79, 0x92, 0x24, 0x57, 0x58, 0x36, 0x47, 0x8a, 0xcf, 0xc6, 0x48, 0xbe, 0xda,
		0x5d, 0xa3, 0x7d, 0x5d, 0x69, 0xde, 0x56, 0x2f, 0xdb, 0xd5, 0x9b, 0x5f, 0x2b, 0xb7, 0xd5, 0x26,
		0x79, 0x86, 0x24, 0x28, 0x3e, 0x28, 0x3e, 0x28, 0x3e, 0x28, 0x3e, 0xa2, 0xfa, 0x76, 0x5b, 0xa8,
		0x05, 0x48, 0x6e, 0xfe, 0xd9, 0xa8, 0x20, 0xa2, 0x6f, 0x8f, 0x05, 0x9b, 0xeb, 0x30, 0xc4, 0xf6,
		0xed, 0xb2, 0x5e, 0xb7, 0x95, 0x5a, 0xb9, 0x59, 0xfd, 0xbd, 0x82, 0xe5, 0xda, 0x69, 0xb9, 0xca,
		0x1f, 0xef, 0xea, 0xb5, 0xcf, 0xcd, 0x0a, 0xa2, 0x22, 0x0f, 0x21, 0x2a, 0x72, 0x92, 0x47, 0xc9,
		0x44, 0xf4, 0x47, 0xa3, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x93, 0x4a, 0x3c, 0xe2,
		0x20, 0x29, 0x9e, 0x75, 0x78, 0xe2, 0x84, 0x27, 0x9c, 0x0e, 0xa3, 0x0e, 0x58, 0x98, 0x03, 0x9a,
		0x00, 0x9a, 0x00, 0x9a, 0x00, 0x9a, 0x80, 0x54, 0xe2, 0x11, 0xa5, 0xa8, 0xce, 0x66, 0x4c, 0x64,
		0x94, 0x62, 0x16, 0xb7, 0xa9, 0x3b, 0x6d, 0x7d, 0x12, 0x6f, 0x53, 0x0b, 0x05, 0x5c, 0xa3, 0xaa,
		0x1e, 0xb5, 0x75, 0x10, 0xc4, 0xda, 0x95, 0x62, 0xb4, 0xf1, 0x86, 0x2f, 0x5f, 0x6d, 0x61, 0x78,
		0xe2, 0x7f, 0xfa, 0xc2, 0x97, 0xa2, 0xcb, 0x49, 0xb4, 0xb7, 0xce, 0xa9, 0xe0, 0x92, 0xf5, 0xf3,
		0x4d, 0xe3, 0xb6, 0xde, 0xac, 0x5c, 0xe2, 0x6e, 0x15, 0x3c, 0x1f, 0x3c, 0x1f, 0x3c, 0x9f, 0x5c,
		0xe2, 0x71, 0xb7, 0xba, 0xe3, 0x42, 0x4d, 0x70, 0xb8, 0x5a, 0xbf, 0xc1, 0xdd, 0xea, 0x4e, 0x0b,
		0x56, 0xab, 0xde, 0xfc, 0xd6, 0xbe, 0xa9, 0x5f, 0x55, 0xda, 0x0b, 0x4b, 0x77, 0x5b, 0xf9, 0xaf,
		0xcf, 0x95, 0x3b, 0xdc, 0xb2, 0xfe, 0x70, 0xe5, 0x16, 0x95, 0x3e, 0x96, 0xe9, 0xc7, 0x02, 0xb6,
		0x22, 0x5b, 0xd5, 0x5b, 0xd6, 0x35, 0xc3, 0x15, 0x6b, 0x64, 0x6c, 0x01, 0x4f, 0xb8, 0x3d, 0x69,
		0xbd, 0x58, 0xff, 0x2b, 0x0c, 0x69, 0xbd, 0x08, 0x8f, 0xcf, 0x02, 0x58, 0x9b, 0x09, 0x44, 0x1c,
		0x44, 0x1c, 0x44, 0x1c, 0x44, 0x9c, 0x54, 0xe2, 0xfb, 0x96, 0x23, 0xb3, 0x45, 0x46, 0x0e, 0x5e,
		0x84, 0xc7, 0x7d, 0xfe, 0xc5, 0x51, 0x17, 0x60, 0xff, 0x79, 0xe0, 0x71, 0x8f, 0xec, 0xd6, 0x17,
		0x0b, 0x85, 0x53, 0xf8, 0xdc, 0x95, 0x8f, 0x7a, 0x08, 0x3e, 0x77, 0x5f, 0xc8, 0x7e, 0x4f, 0x41,
		0x55, 0xaf, 0x95, 0x79, 0xf8, 0x7c, 0xeb, 0x25, 0xf0, 0x77, 0x94, 0xf5, 0x3a, 0x64, 0xfe, 0x8e,
		0xb2, 0x5e, 0x5c, 0xfc, 0x1d, 0x01, 0x33, 0xa0, 0xef, 0xa0, 0xef, 0xa0, 0xef, 0xfb, 0x6e, 0x3d,
		0xaa, 0x0e, 0x80, 0xba, 0x73, 0x50, 0xf7, 0x67, 0xd7, 0x93, 0x9d, 0xbe, 0x34, 0x84, 0x6d, 0x3d,
		0x59, 0x0f, 0x36, 0x63, 0x38, 0xfa, 0xfa, 0x54, 0x7c, 0x04, 0x7e, 0xc8, 0x94, 0xc0, 0xe1, 0xe1,
		0x83, 0x3f, 0x64, 0x0e, 0x0f, 0x1f, 0x3c, 0x87, 0xc4, 0x3f, 0xb8, 0xae, 0x2d, 0x4c, 0x87, 0x33,
		0x10, 0x26, 0x7b, 0x08, 0x7a, 0xc7, 0x7a, 0x72, 0x4c, 0xdb, 0x72, 0x9e, 0x8c, 0x9e, 0xe7, 0x4a,
		0xb7, 0xe3, 0xda, 0x8c, 0x8a, 0x67, 0x7d, 0x2e, 0xa8, 0x06, 0xa8, 0x06, 0xa8, 0x06, 0xa8, 0x06,
		0x52, 0x89, 0x47, 0x9c, 0xe4, 0x8e, 0x0b, 0xd5, 0x28, 0x37, 0x7f, 0x6d, 0xdf, 0x55, 0x9a, 0x9f,
		0x1b, 0xa3, 0xd8, 0xac, 0xfa, 0x65, 0xbd, 0x86, 0x58, 0xc9, 0x3d, 0x16, 0xed, 0xee, 0x16, 0x31,
		0x7f, 0x3b, 0x2d, 0x54, 0xed, 0xaa, 0x81, 0x95, 0xda, 0x69, 0xa5, 0x6e, 0xef, 0x7e, 0x47, 0x37,
		0xbe, 0x83, 0x08, 0x8a, 0xf4, 0xdd, 0x47, 0x69, 0xf4, 0x3c, 0x21, 0x5e, 0x98, 0x3b, 0xf2, 0xad,
		0x4e, 0xc4, 0xe7, 0xed, 0x79, 0x34, 0x6d, 0x1f, 0xee, 0x1e, 0x5c, 0xd9, 0x1e, 0x34, 0xa7, 0xc7,
		0x95, 0x2d, 0xdc, 0x3d, 0x11, 0x56, 0x3a, 0x2c, 0xa7, 0x7b, 0x41, 0xd7, 0x8c, 0xc6, 0x87, 0x0a,
		0x80, 0x0a, 0x80, 0x0a, 0x80, 0x0a, 0xa0, 0x75, 0xeb, 0xf4, 0x0c, 0xb3, 0xdb, 0xf5, 0x84, 0xef,
		0x73, 0x6a, 0x81, 0x73, 0x86, 0xb1, 0x27, 0x6b, 0x13, 0xbb, 0xd0, 0x9d, 0xf9, 0xca, 0x7f, 0xcd,
		0x33, 0xae, 0xfd, 0xda, 0x1e, 0x30, 0x76, 0xf7, 0x48, 0x35, 0x4c, 0x29, 0x85, 0xe7, 0xb0, 0x7a,
		0xa2, 0x46, 0x13, 0x1d, 0x1f, 0xdf, 0x67, 0x8c, 0xf3, 0xd6, 0xdb, 0x7d, 0xd6, 0x38, 0x6f, 0x8d,
		0x5f, 0x66, 0x47, 0x7f, 0x8d, 0x5f, 0xe7, 0xee, 0x33, 0x46, 0x7e, 0xfa, 0xba, 0x70, 0x9f, 0x31,
		0x0a, 0xad, 0x93, 0x2f, 0x5f, 0x3e, 0x9c, 0x7c, 0x3f, 0x1d, 0xec, 0xff, 0x41, 0x3e, 0x8f, 0x41,
		0x8b, 0x73, 0x2b, 0xea, 0x77, 0xd5, 0x3f, 0x94, 0xed, 0xc7, 0x5f, 0x2a, 0x37, 0xe4, 0x5f, 0x8c,
		0x3b, 0xf2, 0x2e, 0x46, 0x4e, 0x34, 0x35, 0xe0, 0x54, 0x04, 0x38, 0x05, 0x02, 0x27, 0xd3, 0x78,
		0x2c, 0x1b, 0x9f, 0x5a, 0xdf, 0xb3, 0xef, 0xf3, 0x83, 0x8b, 0x93, 0xef, 0xa5, 0xc1, 0xea, 0x9b,
		0x6f, 0x9b, 0x7e, 0x2d, 0xfb, 0xbe, 0x34, 0xb8, 0xd8, 0xf2, 0x2f, 0xc5, 0xc1, 0xc5, 0x8e, 0x63,
		0x14, 0x06, 0xc7, 0x6b, 0xbf, 0x3a, 0x7c, 0x3f, 0xb7, 0xed, 0x03, 0xf9, 0x2d, 0x1f, 0x38, 0xdd,
		0xf6, 0x81, 0xd3, 0x2d, 0x1f, 0xd8, 0xfa, 0x95, 0x72, 0x5b, 0x3e, 0x50, 0x18, 0xbc, 0xad, 0xfd,
		0xfe, 0xf1, 0xe6, 0x5f, 0x2d, 0x0e, 0x4e, 0xde, 0xb6, 0xfd, 0x5b, 0x69, 0xf0, 0x76, 0x71, 0x02,
		0xa8, 0xde, 0x1d, 0xaa, 0x21, 0x9e, 0xea, 0xc5, 0x33, 0x7e, 0x8a, 0x0b, 0xe1, 0xa6, 0x01, 0x4e,
		0x18, 0x6f, 0x77, 0x2b, 0x8e, 0xb6, 0x56, 0xf0, 0x01, 0x6d, 0xf4, 0x01, 0x21, 0xb4, 0x27, 0xa2,
		0x3e, 0x20, 0x84, 0xf6, 0xb0, 0x90, 0x7d, 0x84, 0xf6, 0xec, 0xb6, 0x50, 0xcd, 0xcf, 0x37, 0x37,
		0x95, 0x1a, 0xca, 0x9f, 0xed, 0xb4, 0x58, 0x8d, 0xdc, 0x35, 0xe2, 0x53, 0x7e, 0xb8, 0x3e, 0x88,
		0x49, 0x89, 0x6e, 0x4c, 0xca, 0xbb, 0x08, 0x09, 0x69, 0xaa, 0xec, 0x38, 0xae, 0x34, 0xc9, 0x03,
		0x5a, 0x52, 0x7e, 0xe7, 0x59, 0xbc, 0x98, 0x3d, 0x53, 0x3e, 0x0f, 0x05, 0x32, 0xed, 0xf6, 0x84,
		0xd3, 0x19, 0x51, 0x37, 0xc3, 0x11, 0xf2, 0x1f, 0xd7, 0xfb, 0xdb, 0xb0, 0x1c, 0x5f, 0x9a, 0x4e,
		0x47, 0xa4, 0x57, 0xdf, 0xf0, 0xd7, 0xde, 0x49, 0x0f, 0x95, 0x73, 0xda, 0xf6, 0x7b, 0x7e, 0xba,
		0xe3, 0x3a, 0xbe, 0xf4, 0x4c, 0xcb, 0x11, 0x5d, 0x63, 0x38, 0x7a, 0x5a, 0xf6, 0x1d, 0x47, 0xd8,
		0xfe, 0xe4, 0xef, 0xf4, 0x78, 0x92, 0x14, 0xe5, 0x15, 0xac, 0xf4, 0xfa, 0x1d, 0x39, 0xe9, 0x3a,
		0x95, 0xaa, 0xcf, 0x1e, 0xe4, 0x66, 0xfc, 0x25, 0xab, 0x93, 0xef, 0xd8, 0x5e, 0xf9, 0xd9, 0x5f,
		0x7d, 0xa3, 0x7d, 0xdd, 0xb3, 0xfd, 0x76, 0xcd, 0xef, 0xf9, 0xed, 0xcb, 0xf9, 0x43, 0x34, 0x4c,
		0xf9, 0xdc, 0x6e, 0x8e, 0x9f, 0x61, 0xf2, 0x77, 0x7b, 0xc2, 0x71, 0xdf, 0x45, 0x43, 0xda, 0x08,
		0x24, 0x8d, 0xb6, 0x67, 0x17, 0x47, 0xaf, 0x2e, 0x62, 0x73, 0x85, 0xdc, 0x4c, 0xe1, 0x30, 0x4f,
		0x18, 0xcd, 0x12, 0x2e, 0x73, 0x84, 0xdd, 0x0c, 0x61, 0x37, 0x3f, 0x78, 0xcd, 0x8e, 0x68, 0xe9,
		0x16, 0x72, 0xf3, 0x62, 0x26, 0xb1, 0xb6, 0x30, 0x1f, 0x69, 0x4d, 0x8a, 0x99, 0x29, 0x41, 0x98,
		0x2f, 0x9e, 0x6a, 0x4c, 0xd4, 0xdf, 0x87, 0x0f, 0x13, 0xbd, 0x94, 0x1e, 0x41, 0x56, 0x82, 0x80,
		0xbd, 0x97, 0xeb, 0x19, 0x63, 0xcd, 0x6b, 0x98, 0x52, 0x7a, 0xd6, 0x43, 0x5f, 0x8e, 0x4c, 0x0c,
		0x62, 0xa4, 0xdf, 0x3c, 0x0d, 0x2d, 0xf4, 0x67, 0x01, 0xfd, 0x80, 0x7e, 0x40, 0x3f, 0x8d, 0xcc,
		0x5e, 0x59, 0xb4, 0x45, 0x83, 0x53, 0x9d, 0xe9, 0xa9, 0x62, 0x72, 0x81, 0x93, 0xdb, 0x0d, 0x0c,
		0xd0, 0xc2, 0x06, 0x31, 0x9c, 0x50, 0xa3, 0x00, 0x72, 0xb8, 0xa1, 0x47, 0x19, 0x04, 0x29, 0x83,
		0x22, 0x35, 0x90, 0xc4, 0xe4, 0x89, 0xa1, 0xce, 0x87, 0xb1, 0x3c, 0x1e, 0x81, 0xef, 0x0a, 0x5f,
		0x5a, 0x8e, 0xc9, 0x92, 0x2c, 0xb4, 0x76, 0xaa, 0x16, 0x27, 0x63, 0x92, 0x15, 0xde, 0xc2, 0x4d,
		0x6c, 0xa0, 0xa6, 0x02, 0xdc, 0x14, 0x82, 0x9c, 0x2a, 0xb0, 0x53, 0x0e, 0x7a, 0xca, 0xc1, 0x4f,
		0x2d, 0x08, 0xf2, 0x80, 0x21, 0x13, 0x28, 0xf2, 0x99, 0xf0, 0x5b, 0x4f, 0x0c, 0x6b, 0xb4, 0xf8,
		0x1a, 0x21, 0x3b, 0x67, 0x9c, 0x83, 0x35, 0x7a, 0x7c, 0xfa, 0x87, 0xf7, 0xd0, 0x1f, 0x69, 0x88,
		0x26, 0x5f, 0xdb, 0xa3, 0x33, 0x05, 0x73, 0xa9, 0x0a, 0x91, 0x9b, 0x4d, 0x98, 0x8c, 0x28, 0xf3,
		0xe9, 0x9f, 0x96, 0x8a, 0x2d, 0x52, 0x19, 0xca, 0x38, 0x9b, 0x35, 0x29, 0xd1, 0xe7, 0xb3, 0x9d,
		0x62, 0x9d, 0x61, 0xf0, 0x3e, 0x41, 0x60, 0x57, 0x04, 0xd8, 0x91, 0x82, 0x1d, 0xc2, 0x82, 0x93,
		0x14, 0xb5, 0x7e, 0x30, 0xd0, 0x0f, 0xb1, 0x4d, 0x54, 0x34, 0xbb, 0x22, 0x45, 0x78, 0xf0, 0xd1,
		0xf8, 0xd1, 0x76, 0xf6, 0x31, 0x85, 0x3b, 0xcd, 0xc6, 0xd7, 0x15, 0xf6, 0xb4, 0xf1, 0x82, 0x34,
		0xcd, 0x72, 0xa9, 0x71, 0xa4, 0x27, 0x28, 0xaa, 0x91, 0x6b, 0x8c, 0x5f, 0x95, 0x67, 0xcf, 0x47,
		0x1a, 0x28, 0x45, 0x2f, 0xbf, 0xa4, 0xdd, 0xf9, 0x73, 0xa3, 0xfe, 0x3d, 0x2f, 0xa6, 0xf7, 0x6a,
		0x4c, 0xa4, 0x8b, 0xab, 0x27, 0xff, 0xea, 0x4c, 0xb8, 0x12, 0xc3, 0x95, 0x98, 0x7e, 0xef, 0x30,
		0xae, 0xc4, 0x14, 0x6a, 0x49, 0xb6, 0x2b, 0x31, 0x76, 0x18, 0x53, 0x0d, 0x67, 0xcc, 0xb0, 0xc6,
		0x0e, 0x6f, 0x2a, 0x60, 0x4e, 0x21, 0xdc, 0xa9, 0x82, 0x3d, 0xe5, 0xf0, 0xa7, 0x1c, 0x06, 0xd5,
		0xc2, 0x21, 0xaf, 0xf9, 0xc4, 0x75, 0x39, 0xc6, 0x05, 0x93, 0xb3, 0x09, 0xcc, 0xee, 0x8b, 0xe5,
		0x18, 0x4f, 0x9e, 0xdb, 0xef, 0xf9, 0xfc, 0xb2, 0x3c, 0x3d, 0x9e, 0x4b, 0xb3, 0xbe, 0x57, 0xd2,
		0x0c, 0x2a, 0xcb, 0x3c, 0x0d, 0x37, 0x7c, 0xaa, 0x84, 0x51, 0x0d, 0x70, 0xaa, 0x1a, 0x56, 0xb5,
		0xc1, 0xab, 0x36, 0x98, 0xd5, 0x03, 0xb7, 0xfc, 0x5e, 0xab, 0x23, 0xfe, 0xcb, 0x21, 0x76, 0x18,
		0x9e, 0x4d, 0xc4, 0x14, 0x83, 0xfa, 0xd3, 0x03, 0xce, 0xe6, 0xc6, 0xd1, 0x08, 0xc9, 0xca, 0xa1,
		0x59, 0x07, 0x44, 0x6b, 0x84, 0x6a, 0x5d, 0x90, 0xad, 0x1d, 0xba, 0xb5, 0x43, 0xb8, 0x5e, 0x28,
		0x57, 0x03, 0xe9, 0x8a, 0xa0, 0x5d, 0x39, 0xc4, 0xcf, 0x26, 0x14, 0xdf, 0x3a, 0x76, 0xbf, 0x2b,
		0xc6, 0x2c, 0x58, 0xfd, 0xe1, 0x99, 0xe2, 0xc5, 0xf2, 0xd7, 0x50, 0x2c, 0xbf, 0x6a, 0x1a, 0xb5,
		0x6a, 0x57, 0x08, 0x3a, 0x15, 0x43, 0x04, 0x14, 0x84, 0x6e, 0x45, 0x11, 0x19, 0x85, 0x11, 0x19,
		0xc5, 0x11, 0x0d, 0x05, 0xa2, 0x56, 0x91, 0x28, 0x56, 0x28, 0xb3, 0x25, 0x66, 0x8f, 0x6f, 0xfe,
		0xe9, 0x89, 0xa7, 0x4f, 0x65, 0xde, 0x9b, 0xe9, 0x97, 0x34, 0xcc, 0xbd, 0x90, 0x1a, 0xfd, 0x83,
		0xff, 0xa4, 0x30, 0x9e, 0x6c, 0xf7, 0xc1, 0x5c, 0xba, 0xd5, 0x1e, 0x9e, 0x03, 0x63, 0xd1, 0x49,
		0x95, 0x5e, 0xf8, 0x61, 0xf1, 0xb5, 0x41, 0x97, 0x6d, 0x1d, 0x55, 0xf9, 0xad, 0x59, 0xbe, 0x2c,
		0x4b, 0xe9, 0xe9, 0x91, 0xe1, 0x6b, 0xcb, 0xa9, 0xd8, 0x62, 0x08, 0x51, 0xbe, 0x7a, 0x7d, 0x7d,
		0x34, 0xe9, 0x58, 0xbf, 0xf0, 0x0d, 0xb2, 0x67, 0xf9, 0x7c, 0xb1, 0x94, 0xcf, 0x67, 0x4a, 0xa7,
		0xa5, 0xcc, 0x79, 0xa1, 0x90, 0x2d, 0x72, 0x54, 0x06, 0xfb, 0xe9, 0x97, 0xaa, 0x7b, 0x5d, 0xe1,
		0x89, 0xee, 0xc7, 0xd7, 0xd4, 0xc5, 0x91, 0xd3, 0xb7, 0xed, 0x77, 0xc9, 0xc4, 0x6b, 0x85, 0xb2,
		0x9e, 0xb2, 0x9c, 0x31, 0x11, 0x36, 0x6d, 0x5b, 0x37, 0x27, 0x5f, 0xff, 0x2a, 0xe0, 0xe5, 0xe0,
		0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0,
		0xe5, 0x87, 0xc6, 0xcb, 0x9d, 0xd7, 0xc8, 0xf0, 0xf2, 0xd9, 0x57, 0x01, 0x2f, 0x07, 0x2f, 0x07,
		0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0x07, 0x2f, 0xd7,
		0xc9, 0xcb, 0x13, 0x15, 0x92, 0xc3, 0x9c, 0x49, 0xbb, 0x75, 0xde, 0x68, 0x65, 0xd8, 0xae, 0xa6,
		0x17, 0xad, 0xbf, 0xb1, 0x04, 0xbc, 0x4a, 0x23, 0x39, 0x8f, 0xa2, 0x93, 0xa8, 0xdb, 0xc8, 0x35,
		0x1a, 0xe3, 0x45, 0x19, 0x7d, 0x62, 0xe5, 0xc7, 0xf2, 0x70, 0x89, 0x7e, 0x19, 0xad, 0x10, 0x4b,
		0x4a, 0xaf, 0xbe, 0x03, 0xa9, 0xe0, 0x30, 0xa6, 0x7c, 0x69, 0x4a, 0xa1, 0x3e, 0x28, 0x79, 0x3c,
		0x6d, 0xc2, 0x63, 0x92, 0x73, 0x88, 0x49, 0x4e, 0x90, 0xe9, 0x8c, 0x98, 0x64, 0xc4, 0x24, 0xd3,
		0x2d, 0x25, 0x62, 0x92, 0xe1, 0x63, 0x4d, 0xa2, 0x62, 0x88, 0x80, 0x82, 0xd0, 0xad, 0x28, 0x22,
		0xa3, 0x30, 0x22, 0xa3, 0x38, 0xa2, 0xa1, 0x40, 0xd4, 0xdb, 0xec, 0x47, 0xf0, 0xb1, 0x1e, 0xe9,
		0x00, 0x78, 0xf8, 0x58, 0xe3, 0x2b, 0xbf, 0xf0, 0xb1, 0xc2, 0xc7, 0xaa, 0x0b, 0xaf, 0x11, 0x93,
		0x0c, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e,
		0x0e, 0x5e, 0x0e, 0x5e, 0x7e, 0xa0, 0xbc, 0x1c, 0x31, 0xc9, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5,
		0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0x1a, 0x66,
		0x42, 0x4c, 0x72, 0x84, 0x63, 0x92, 0x55, 0x06, 0x72, 0x1e, 0xc5, 0x31, 0x24, 0xf9, 0x6e, 0xb4,
		0x40, 0x49, 0x89, 0x48, 0x8e, 0x75, 0xa9, 0x67, 0xc5, 0x07, 0x3c, 0xd6, 0x07, 0x3b, 0xa5, 0x24,
		0xf6, 0x3c, 0x56, 0x47, 0x39, 0x15, 0xd3, 0xde, 0x7f, 0x8c, 0xc7, 0x2a, 0xd5, 0x31, 0x9d, 0xae,
		0xd5, 0x35, 0xa5, 0x30, 0x7c, 0xd1, 0x71, 0x9d, 0xee, 0x54, 0x96, 0x14, 0x36, 0x9c, 0xd8, 0xfe,
		0x15, 0xd0, 0x7d, 0x22, 0xaa, 0xde, 0x2f, 0x74, 0x9f, 0x48, 0xa0, 0xf7, 0x0a, 0xdd, 0x27, 0xf6,
		0x5f, 0x32, 0x75, 0xdd, 0x27, 0xb6, 0xa0, 0xa4, 0x86, 0x7e, 0x14, 0xdb, 0xbe, 0x09, 0x3a, 0x54,
		0xc4, 0x0d, 0xc6, 0x35, 0xc2, 0xb9, 0x2e, 0x58, 0xd7, 0x0e, 0xef, 0xda, 0x61, 0x5e, 0x2f, 0xdc,
		0x27, 0xd3, 0xf5, 0xa4, 0x3c, 0x1b, 0x4c, 0x71, 0x33, 0xa2, 0x75, 0x25, 0xa0, 0x3a, 0x95, 0x5d,
		0x03, 0xf4, 0x6b, 0x53, 0x01, 0x3a, 0x55, 0x41, 0x04, 0x54, 0x82, 0x6e, 0xd5, 0x10, 0x19, 0x15,
		0x11, 0x19, 0x55, 0x11, 0x0d, 0x95, 0xa1, 0x56, 0x75, 0x28, 0x56, 0x21, 0xda, 0x54, 0xc9, 0x6c,
		0xe2, 0x9e, 0x67, 0xb9, 0x9e, 0x25, 0x5f, 0xf5, 0x9d, 0xb7, 0x59, 0xd7, 0xe6, 0xe9, 0x37, 0xd1,
		0x24, 0xe5, 0x7a, 0xc2, 0xa6, 0xb4, 0xab, 0x9b, 0x28, 0xa8, 0x9d, 0x08, 0xa9, 0x9f, 0xa8, 0xa8,
		0xa1, 0xc8, 0xa9, 0xa3, 0xc8, 0xa9, 0xa5, 0x68, 0xa9, 0x27, 0x3d, 0x6a, 0x4a, 0x93, 0xba, 0x9a,
		0x2d, 0xbd, 0xb6, 0x30, 0xac, 0x35, 0xc4, 0xe8, 0x5b, 0x8e, 0xcc, 0x16, 0x75, 0x02, 0xc6, 0x44,
		0x7f, 0x14, 0x35, 0x7e, 0x85, 0x5b, 0xd3, 0x79, 0x1a, 0xae, 0xc6, 0xbd, 0xd6, 0x03, 0xa9, 0x17,
		0x30, 0x8f, 0x26, 0x01, 0x4e, 0xda, 0x91, 0x3b, 0x22, 0xc4, 0x62, 0xed, 0xeb, 0xfc, 0x6e, 0xda,
		0x7d, 0x11, 0xa1, 0xef, 0xf3, 0xc9, 0x33, 0x3b, 0xd2, 0x72, 0x9d, 0x2b, 0xeb, 0xc9, 0x1a, 0xc7,
		0xa3, 0x69, 0xff, 0x5e, 0x83, 0xf7, 0x11, 0x10, 0x61, 0xf3, 0x1b, 0x44, 0xf8, 0x27, 0x22, 0x5c,
		0x2c, 0x14, 0x4e, 0x0b, 0x10, 0xe3, 0x68, 0x71, 0x11, 0xfd, 0xb3, 0xb7, 0xde, 0x1d, 0xc6, 0xf3,
		0x6a, 0x80, 0xa9, 0x94, 0xa6, 0x7b, 0xc8, 0xad, 0xbc, 0x4f, 0xcb, 0x6d, 0x24, 0x7c, 0x07, 0xf0,
		0x1d, 0xc0, 0x77, 0x00, 0xdf, 0x01, 0x7c, 0x07, 0x89, 0xf0, 0x1d, 0xe8, 0x4b, 0xe5, 0x5a, 0x55,
		0x20, 0x3a, 0x52, 0xba, 0xe6, 0x20, 0xbe, 0x35, 0xb5, 0xab, 0x97, 0xeb, 0xad, 0x86, 0x69, 0x6e,
		0x78, 0x6f, 0x52, 0xe9, 0x3c, 0xad, 0x3e, 0x7b, 0x4b, 0x23, 0x05, 0x4b, 0xf4, 0xad, 0x94, 0xa6,
		0xdc, 0x9a, 0x39, 0xd9, 0x8c, 0x59, 0x28, 0xfe, 0xd6, 0xa0, 0xe6, 0xad, 0xff, 0x92, 0xd6, 0x12,
		0x52, 0x71, 0x14, 0x97, 0x38, 0xfe, 0xcb, 0xe9, 0xb2, 0xdd, 0x4d, 0x57, 0x6d, 0xf8, 0xb6, 0xbf,
		0xe5, 0x7d, 0xa5, 0x8d, 0x04, 0xd4, 0x23, 0x80, 0xca, 0x7a, 0x1a, 0x9a, 0xcd, 0xbc, 0x68, 0x98,
		0x77, 0xa8, 0xa4, 0x71, 0x50, 0xe6, 0x1b, 0x22, 0x8f, 0xa2, 0x66, 0xa6, 0x21, 0xf2, 0x28, 0xc1,
		0x66, 0x18, 0x2a, 0x69, 0xcc, 0xcc, 0xad, 0x89, 0xe1, 0xb4, 0xa2, 0xec, 0x40, 0x63, 0x08, 0x38,
		0xae, 0xca, 0x3e, 0x49, 0xeb, 0xec, 0x45, 0x71, 0x9a, 0xfd, 0x51, 0x14, 0xc2, 0xa5, 0x73, 0x20,
		0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x20, 0x2d, 0x8c, 0x4b, 0xac, 0x2d, 0x5c, 0xda, 0xec, 0x48, 0xeb,
		0xab, 0xd0, 0x7f, 0xed, 0x39, 0xf9, 0x1e, 0xb8, 0xee, 0xd4, 0xf2, 0x05, 0x70, 0xdd, 0x19, 0x25,
		0x15, 0x14, 0x39, 0x55, 0x14, 0x39, 0x95, 0x14, 0x2d, 0xd5, 0xa4, 0x47, 0x45, 0x69, 0x52, 0x55,
		0xfa, 0xed, 0xec, 0x35, 0xc4, 0x78, 0x70, 0x5d, 0x5b, 0x98, 0x4e, 0x14, 0xae, 0x3b, 0xb3, 0x88,
		0xd4, 0x62, 0x5b, 0x63, 0x64, 0x76, 0x81, 0xae, 0x80, 0xae, 0x80, 0xae, 0x80, 0xae, 0x80, 0xae,
		0xc4, 0x99, 0xae, 0x20, 0xb3, 0x0b, 0x99, 0x5d, 0xf3, 0x85, 0x40, 0x66, 0xd7, 0xf6, 0xaf, 0x83,
		0xcc, 0xae, 0xa8, 0xc2, 0xe9, 0xb2, 0x08, 0x23, 0xb3, 0xeb, 0xa7, 0x22, 0x8c, 0xcc, 0xae, 0x08,
		0x72, 0x11, 0xfd, 0xb3, 0x23, 0xb3, 0x8b, 0x4f, 0xcc, 0x91, 0xd9, 0x05, 0xdf, 0x01, 0x7c, 0x07,
		0xf0, 0x1d, 0xc0, 0x77, 0x00, 0xdf, 0x41, 0x52, 0x7c, 0x07, 0xc8, 0xec, 0x3a, 0x42, 0x66, 0x57,
		0x1c, 0x66, 0x44, 0x66, 0x57, 0xe2, 0x32, 0xbb, 0x74, 0x04, 0x7f, 0x1e, 0x25, 0x34, 0xb1, 0x4b,
		0x61, 0x3b, 0x26, 0xf5, 0xe7, 0x3f, 0x59, 0x45, 0xb1, 0x7f, 0x13, 0xaf, 0xda, 0xac, 0x37, 0x3d,
		0x6d, 0x15, 0xf5, 0xb5, 0x53, 0x8c, 0x54, 0x1b, 0x45, 0x3d, 0xed, 0x13, 0xd1, 0x66, 0x30, 0xee,
		0x8a, 0x12, 0x6d, 0x08, 0xc3, 0xa8, 0x46, 0xf4, 0x28, 0x8c, 0x00, 0x4a, 0xa0, 0x47, 0x61, 0x50,
		0x54, 0x40, 0xc3, 0xc2, 0x1f, 0x1e, 0x7a, 0x34, 0x2f, 0x5c, 0xdf, 0x4e, 0x45, 0x4d, 0x50, 0xd4,
		0x36, 0x3d, 0x41, 0x5b, 0x42, 0x82, 0x9d, 0x42, 0x5b, 0x42, 0xfa, 0x89, 0xd1, 0x96, 0x30, 0x3e,
		0x2c, 0x44, 0x5d, 0x5b, 0x42, 0xbf, 0xf7, 0x68, 0x48, 0x4b, 0x3c, 0x78, 0xc2, 0xfc, 0x5b, 0x78,
		0x1a, 0xba, 0x11, 0xae, 0x7c, 0x01, 0xb5, 0x4d, 0x08, 0x33, 0x68, 0x42, 0x18, 0x67, 0xf0, 0xd6,
		0x05, 0xe2, 0xda, 0xc1, 0x5c, 0x3b, 0xa8, 0xeb, 0x05, 0xf7, 0x64, 0xfa, 0x5b, 0x95, 0x5f, 0xb6,
		0xae, 0x81, 0xb0, 0x31, 0x42, 0x61, 0xcb, 0x51, 0x59, 0xc5, 0x6e, 0xc6, 0x97, 0xf3, 0x0a, 0xe7,
		0xac, 0x38, 0xfd, 0x97, 0xe1, 0x52, 0xab, 0xac, 0x60, 0x72, 0x25, 0x1e, 0xcd, 0xbe, 0x3d, 0x3a,
		0x28, 0xb7, 0xe5, 0x9b, 0xab, 0xfa, 0x75, 0x62, 0x1c, 0x3e, 0x0a, 0x58, 0xba, 0xf8, 0xd6, 0xb3,
		0xad, 0x8e, 0x25, 0x47, 0xbe, 0x06, 0x63, 0xe2, 0x01, 0x50, 0x4c, 0x55, 0x36, 0x7c, 0x07, 0xb0,
		0x15, 0xb0, 0x15, 0xb0, 0x15, 0xb0, 0x15, 0xb0, 0x15, 0x85, 0x27, 0x56, 0x7d, 0x28, 0x98, 0x8e,
		0xd0, 0xaf, 0x1f, 0x84, 0x7a, 0x7d, 0xf8, 0x30, 0x8a, 0xdf, 0xea, 0x1a, 0x4b, 0x1a, 0xc9, 0xdf,
		0xf4, 0xa6, 0xfa, 0x78, 0xaf, 0x64, 0xf0, 0x8d, 0x67, 0xd7, 0xee, 0x1a, 0xca, 0xf3, 0xee, 0x67,
		0x22, 0xbe, 0x3c, 0xbd, 0xaa, 0x26, 0xe8, 0x73, 0x82, 0x9a, 0x01, 0xb3, 0x49, 0x04, 0xb3, 0xf1,
		0xfc, 0xaf, 0x3d, 0x30, 0x9b, 0x03, 0x64, 0x36, 0xa3, 0x8d, 0x07, 0xb3, 0x89, 0x19, 0xb3, 0xe9,
		0x5b, 0x8e, 0x3c, 0xd3, 0xc0, 0x6b, 0x54, 0xc6, 0x96, 0xe9, 0xc9, 0x7f, 0xd7, 0x10, 0x18, 0xad,
		0x33, 0xbf, 0x5d, 0x77, 0xb2, 0x9b, 0xe6, 0xfc, 0xf5, 0x28, 0x24, 0xfa, 0xea, 0x48, 0xfc, 0xd4,
		0x99, 0x8f, 0x1e, 0x15, 0x91, 0x2b, 0x1d, 0xb0, 0xc8, 0x25, 0x34, 0xac, 0xbe, 0x05, 0xc3, 0x75,
		0x67, 0x31, 0xd4, 0xe3, 0x1a, 0x87, 0x33, 0x3c, 0x31, 0x26, 0x23, 0x9c, 0xe1, 0x07, 0x6a, 0x32,
		0xc2, 0x19, 0x1e, 0x47, 0x93, 0xd1, 0x97, 0x9e, 0xa6, 0xfb, 0xfa, 0x33, 0x68, 0xe5, 0x9d, 0xd7,
		0x6c, 0x74, 0x63, 0xdc, 0x71, 0x5f, 0x7a, 0xfd, 0x71, 0x6e, 0x81, 0xf1, 0x22, 0xe4, 0xb3, 0xdb,
		0x55, 0xaf, 0xa8, 0xb7, 0x7d, 0x11, 0xf5, 0x2e, 0xe6, 0x09, 0xe2, 0xc8, 0x8b, 0x5a, 0xfd, 0xb2,
		0x5c, 0xab, 0xfd, 0xd9, 0xbe, 0xac, 0x5f, 0x37, 0x3e, 0x37, 0x2b, 0x57, 0xe0, 0x11, 0xe0, 0x11,
		0xe0, 0x11, 0xe0, 0x11, 0xe0, 0x11, 0x2a, 0x4f, 0xac, 0xd5, 0x15, 0x8e, 0xb4, 0xe4, 0xab, 0xa6,
		0x8b, 0x75, 0x95, 0x1e, 0xe8, 0xea, 0xe4, 0x51, 0x3f, 0x9a, 0xbe, 0xc6, 0x8e, 0x62, 0x8d, 0x72,
		0xf3, 0xd7, 0x89, 0xce, 0x2b, 0x37, 0xab, 0xf5, 0x9b, 0xf6, 0x75, 0xa5, 0xf9, 0x6b, 0xfd, 0x4a,
		0x35, 0x7a, 0x8c, 0xdc, 0x66, 0xbe, 0x96, 0x7a, 0xb4, 0x9a, 0xab, 0xd2, 0x55, 0xfe, 0x68, 0xd4,
		0xaa, 0x97, 0xd5, 0x66, 0xed, 0xcf, 0xf6, 0x55, 0xe5, 0x53, 0xf5, 0xa6, 0x72, 0x95, 0x3a, 0x04,
		0x27, 0xb1, 0xe6, 0x55, 0x5f, 0x63, 0x7b, 0x58, 0x73, 0x05, 0x92, 0xde, 0xac, 0xdc, 0xde, 0x8c,
		0x96, 0xfd, 0xbf, 0x3e, 0x57, 0x6e, 0xab, 0x5a, 0x56, 0x5d, 0xe9, 0x8c, 0xad, 0xa4, 0xf1, 0x8f,
		0x64, 0x5a, 0xc1, 0xbe, 0xf0, 0xbe, 0xea, 0x48, 0x3a, 0xdb, 0xf6, 0x45, 0x60, 0x79, 0xc2, 0xf2,
		0x84, 0xe5, 0x09, 0xcb, 0x13, 0x96, 0xa7, 0x4a, 0xcb, 0xb3, 0x67, 0x98, 0xdd, 0xae, 0x27, 0x7c,
		0x5f, 0x87, 0xe1, 0x79, 0xae, 0x70, 0xce, 0xc9, 0x1a, 0x27, 0x3e, 0xf2, 0x69, 0xbe, 0xb3, 0x5f,
		0xf3, 0x1a, 0xf6, 0x76, 0x6d, 0x8f, 0xcf, 0xf4, 0xf4, 0x84, 0x97, 0xc2, 0x73, 0xb4, 0x35, 0x7a,
		0x49, 0x1d, 0x1f, 0xdf, 0x67, 0x8c, 0xf3, 0xd6, 0xdb, 0x7d, 0xd6, 0x38, 0x6f, 0x8d, 0x5f, 0x66,
		0x47, 0x7f, 0x8d, 0x5f, 0xe7, 0xee, 0x33, 0x46, 0x7e, 0xfa, 0xba, 0x70, 0x9f, 0x31, 0x0a, 0xad,
		0x93, 0x2f, 0x5f, 0x3e, 0x9c, 0x7c, 0x3f, 0x1d, 0xec, 0xff, 0x41, 0xf5, 0xe6, 0x44, 0x4b, 0xc7,
		0x96, 0xd6, 0xef, 0xaa, 0x7f, 0x68, 0xdf, 0xd7, 0xbf, 0x54, 0x6e, 0xec, 0xbf, 0x34, 0xec, 0x6c,
		0x92, 0xab, 0xf5, 0xea, 0x05, 0xe3, 0x22, 0xc0, 0x58, 0x2b, 0x18, 0x9b, 0xc6, 0x63, 0xd9, 0xf8,
		0xd4, 0xfa, 0x9e, 0x7d, 0x9f, 0x1f, 0x5c, 0x9c, 0x7c, 0x2f, 0x0d, 0x56, 0xdf, 0x7c, 0xdb, 0xf4,
		0x6b, 0xd9, 0xf7, 0xa5, 0xc1, 0xc5, 0x96, 0x7f, 0x29, 0x0e, 0x2e, 0x76, 0x1c, 0xa3, 0x30, 0x38,
		0x5e, 0xfb, 0xd5, 0xe1, 0xfb, 0xb9, 0x6d, 0x1f, 0xc8, 0x6f, 0xf9, 0xc0, 0xe9, 0xb6, 0x0f, 0x9c,
		0x6e, 0xf9, 0xc0, 0xd6, 0xaf, 0x94, 0xdb, 0xf2, 0x81, 0xc2, 0xe0, 0x6d, 0xed, 0xf7, 0x8f, 0x37,
		0xff, 0x6a, 0x71, 0x70, 0xf2, 0xb6, 0xed, 0xdf, 0x4a, 0x83, 0xb7, 0x8b, 0x13, 0xa8, 0x26, 0xf5,
		0xaa, 0x09, 0x62, 0xae, 0x5e, 0xcc, 0x93, 0xaf, 0xa8, 0x11, 0x6d, 0x1c, 0x45, 0x8f, 0xae, 0x27,
		0x1e, 0x85, 0x27, 0x9c, 0x8e, 0x86, 0x98, 0xe3, 0x85, 0xb9, 0xe1, 0xb7, 0x85, 0xdf, 0x16, 0x7e,
		0x5b, 0xf8, 0x6d, 0xe1, 0xb7, 0x55, 0x78, 0x62, 0x91, 0xac, 0x9a, 0x20, 0x2f, 0x01, 0x92, 0x55,
		0xd9, 0x2b, 0x36, 0x6f, 0x9d, 0x1f, 0xc9, 0xaa, 0x07, 0x2b, 0x72, 0xb9, 0x42, 0x01, 0xe9, 0xaa,
		0x30, 0x20, 0x0f, 0xd7, 0x80, 0xf4, 0x84, 0xf4, 0x5e, 0x0d, 0x69, 0xbd, 0xe8, 0x08, 0x03, 0x5a,
		0x9c, 0x1c, 0x26, 0x64, 0x12, 0x4c, 0x48, 0xd4, 0x3b, 0x3a, 0x50, 0x13, 0x12, 0xf5, 0x8e, 0xe2,
		0x6a, 0x42, 0x66, 0x8b, 0x1a, 0x6c, 0xc8, 0x22, 0x6c, 0x48, 0xd8, 0x90, 0xb0, 0x21, 0x61, 0x43,
		0x26, 0x40, 0xe4, 0x8a, 0x99, 0x0c, 0x6c, 0x48, 0xd8, 0x90, 0x87, 0x6b, 0x43, 0xfa, 0x42, 0xf6,
		0x7b, 0x1a, 0x8b, 0xf5, 0xae, 0xcc, 0xaf, 0xbe, 0x94, 0x42, 0x09, 0xd6, 0x2b, 0xac, 0x57, 0x58,
		0xaf, 0xb0, 0x5e, 0x61, 0xbd, 0xaa, 0xb6, 0x5e, 0x71, 0x01, 0x0a, 0xe3, 0x35, 0x31, 0x96, 0x04,
		0xaa, 0xf5, 0xc2, 0x78, 0x55, 0x2c, 0x72, 0xa8, 0xd6, 0x0b, 0xd3, 0xf5, 0x80, 0x4d, 0xd7, 0xbe,
		0x2f, 0x8c, 0x8e, 0xdf, 0x7b, 0x54, 0x6f, 0xb4, 0xce, 0x66, 0x86, 0xe9, 0x98, 0x04, 0xd3, 0x11,
		0xb1, 0xb3, 0x07, 0x6a, 0x3a, 0x22, 0x76, 0x36, 0x8e, 0xa6, 0xe3, 0x83, 0xeb, 0xda, 0xc2, 0x74,
		0x74, 0x14, 0x3c, 0xc8, 0x26, 0x45, 0x3d, 0xc7, 0xba, 0xc1, 0x7f, 0xd9, 0x71, 0xdc, 0x71, 0xed,
		0x21, 0x35, 0x7d, 0xfe, 0xfd, 0xce, 0xb3, 0x78, 0x31, 0x7b, 0x93, 0x96, 0x82, 0x69, 0xb7, 0x27,
		0x9c, 0x71, 0x67, 0x40, 0xc3, 0x11, 0xf2, 0x1f, 0xd7, 0xfb, 0xdb, 0xb0, 0x1c, 0x5f, 0x9a, 0x4e,
		0x47, 0xa4, 0x57, 0xdf, 0xf0, 0xd7, 0xde, 0x49, 0x0f, 0x41, 0x27, 0x6d, 0xfb, 0x3d, 0x3f, 0xdd,
		0x71, 0x1d, 0x5f, 0x7a, 0xa6, 0xe5, 0x88, 0xee, 0xb8, 0xdf, 0xa0, 0xec, 0x3b, 0x8e, 0xb0, 0xfd,
		0xc9, 0xdf, 0xe9, 0x5e, 0xae, 0x67, 0x8c, 0x5f, 0x1a, 0xa6, 0x94, 0x9e, 0xf5, 0xd0, 0x97, 0xc2,
		0x1f, 0xbd, 0xdb, 0xf3, 0xac, 0x17, 0xd3, 0x7b, 0x1d, 0x7f, 0x6a, 0xed, 0x8d, 0xf1, 0x97, 0x4b,
		0xa9, 0xb8, 0x3d, 0x90, 0x5e, 0xbf, 0x23, 0x27, 0x6d, 0x13, 0x52, 0xf5, 0xd9, 0xc2, 0xdc, 0x8c,
		0x1f, 0xba, 0x3a, 0x79, 0xe6, 0xf6, 0xca, 0xcf, 0xfe, 0xea, 0x1b, 0xed, 0xeb, 0x9e, 0xed, 0xb7,
		0x6b, 0x7e, 0xcf, 0x6f, 0x5f, 0xce, 0x17, 0xa5, 0x61, 0xca, 0xe7, 0x76, 0x73, 0xbc, 0x26, 0x93,
		0xbf, 0xdb, 0x8d, 0x5c, 0x63, 0xfc, 0xaa, 0x3c, 0x5b, 0x91, 0xe1, 0x7b, 0x8d, 0xf1, 0xf3, 0x8f,
		0x3e, 0xb1, 0xf2, 0xe3, 0x84, 0xcd, 0xbc, 0x8b, 0xe7, 0x79, 0x62, 0x3c, 0x4b, 0x6a, 0xda, 0x5d,
		0xa8, 0x6c, 0x73, 0xa1, 0x88, 0x28, 0x2b, 0x23, 0xc8, 0x2a, 0x89, 0xb1, 0x06, 0x42, 0xac, 0x9a,
		0x08, 0x6b, 0x23, 0xc0, 0xda, 0x88, 0xaf, 0x1e, 0xc2, 0x1b, 0x6f, 0x76, 0xa1, 0x8c, 0xd8, 0x6a,
		0xe8, 0xc9, 0xac, 0xb2, 0x17, 0xf3, 0x62, 0x0f, 0x66, 0x65, 0x8d, 0x94, 0xe3, 0xa9, 0x88, 0x7d,
		0x69, 0x4a, 0x85, 0x9a, 0x78, 0x3c, 0x9d, 0x1a, 0x55, 0x9c, 0x55, 0xa5, 0x8a, 0x73, 0x50, 0xc5,
		0x50, 0xc5, 0x50, 0xc5, 0x89, 0x52, 0xc5, 0x57, 0x96, 0x9a, 0xc4, 0xa6, 0x94, 0xe9, 0xfb, 0x6e,
		0xc7, 0x32, 0xa5, 0xe8, 0x8e, 0xc2, 0x49, 0x0c, 0x5f, 0xf8, 0xbe, 0xe5, 0x3a, 0xbe, 0xfa, 0xab,
		0x85, 0xad, 0xdf, 0x04, 0x57, 0x0d, 0x71, 0x83, 0x71, 0x8d, 0x70, 0xae, 0x0b, 0xd6, 0xb5, 0xc3,
		0xbb, 0x76, 0x98, 0xd7, 0x0b, 0xf7, 0x6a, 0x60, 0x5f, 0x11, 0xfc, 0xab, 0xb7, 0xc8, 0x34, 0x5a,
		0x66, 0x3a, 0x2c, 0xb4, 0x4d, 0x96, 0xda, 0xb6, 0xff, 0x7c, 0xeb, 0xc9, 0x31, 0x6d, 0xcb, 0x79,
		0x32, 0x7a, 0x9e, 0x2b, 0xdd, 0x8e, 0x6b, 0xfb, 0xe9, 0x91, 0x82, 0x92, 0x22, 0x3d, 0xd5, 0x51,
		0xd3, 0x17, 0x69, 0xdb, 0xed, 0x98, 0xb6, 0x61, 0x39, 0x5d, 0xf1, 0x2d, 0x95, 0x28, 0x49, 0xac,
		0x59, 0xbe, 0x2c, 0x4b, 0xe9, 0xa9, 0x95, 0xc6, 0x6b, 0xcb, 0xa9, 0xd8, 0x62, 0x08, 0x26, 0xbe,
		0xda, 0xa8, 0xa3, 0xd4, 0xb5, 0xf9, 0x6d, 0x61, 0xe6, 0xec, 0x59, 0x3e, 0x5f, 0x2c, 0xe5, 0xf3,
		0x99, 0xd2, 0x69, 0x29, 0x73, 0x5e, 0x28, 0x64, 0x8b, 0x4a, 0x5b, 0x4f, 0xd5, 0xbd, 0xae, 0xf0,
		0x44, 0xf7, 0xe3, 0x6b, 0xea, 0xe2, 0xc8, 0xe9, 0xdb, 0x36, 0x42, 0x65, 0x76, 0x5e, 0xba, 0x8e,
		0xdf, 0x7b, 0x34, 0x5e, 0x84, 0xf4, 0xac, 0x8e, 0x7a, 0x4a, 0xbb, 0x38, 0x39, 0x58, 0x2c, 0x58,
		0x2c, 0x58, 0x2c, 0x58, 0x2c, 0x58, 0xac, 0xc2, 0x13, 0xdb, 0xb7, 0x1c, 0x59, 0xcc, 0x6b, 0x20,
		0xb1, 0x67, 0x48, 0xb6, 0x60, 0x61, 0x83, 0x48, 0xb6, 0x40, 0xb2, 0x85, 0x52, 0x91, 0x43, 0xb2,
		0x85, 0x66, 0xe3, 0x27, 0x72, 0x52, 0x88, 0xfc, 0x0b, 0x18, 0x95, 0x43, 0xbb, 0x4e, 0x5a, 0xe2,
		0xc1, 0x13, 0xe6, 0xdf, 0x3a, 0x4a, 0xd0, 0xad, 0x7e, 0x01, 0x18, 0x97, 0x30, 0x2e, 0x61, 0x5c,
		0xc2, 0xb8, 0x84, 0x71, 0xa9, 0x01, 0x84, 0x8d, 0x11, 0x0a, 0x5b, 0xce, 0x93, 0x8e, 0xcb, 0x92,
		0xbc, 0xc2, 0x39, 0x2b, 0x4e, 0xff, 0x65, 0xb8, 0xd4, 0x0a, 0x89, 0xf8, 0x62, 0xbd, 0x9a, 0xdb,
		0xf2, 0xcd, 0x55, 0xfd, 0x3a, 0x05, 0x9e, 0xb2, 0xf3, 0xe2, 0x89, 0x6f, 0x3d, 0xdb, 0xea, 0x58,
		0x72, 0x94, 0x1c, 0x61, 0x28, 0x09, 0x7a, 0x5f, 0x3b, 0x25, 0x1b, 0xbe, 0x03, 0xd8, 0x0a, 0xd8,
		0x0a, 0xd8, 0x0a, 0xd8, 0x0a, 0xd8, 0x8a, 0xc2, 0x13, 0x8b, 0x80, 0x8e, 0x0f, 0xa3, 0x28, 0xfc,
		0xae, 0xb1, 0xa4, 0x91, 0xfc, 0x4d, 0x6f, 0xaa, 0x8b, 0xda, 0x4f, 0x16, 0xdf, 0x78, 0x76, 0xed,
		0xae, 0xc6, 0x8a, 0x8a, 0xcb, 0xd3, 0xab, 0x2f, 0xa8, 0x98, 0x01, 0xb3, 0x49, 0x04, 0xb3, 0x41,
		0x41, 0xc5, 0x03, 0x65, 0x36, 0x28, 0xa8, 0x18, 0x47, 0x66, 0x83, 0x82, 0x8a, 0x5c, 0x7f, 0x70,
		0xc7, 0xaf, 0x74, 0x7a, 0xdc, 0xf1, 0xe3, 0x8e, 0x5f, 0x93, 0xc8, 0xa1, 0xa0, 0x62, 0xe2, 0x66,
		0xc3, 0x85, 0xfe, 0xee, 0x62, 0xa8, 0xc7, 0x35, 0x0e, 0x67, 0x78, 0x62, 0x4c, 0x46, 0x38, 0xc3,
		0x0f, 0xd4, 0x64, 0x84, 0x33, 0x3c, 0x8e, 0x26, 0xa3, 0x2f, 0x3d, 0x4d, 0xf7, 0xf5, 0x67, 0xd0,
		0xca, 0x3b, 0xaf, 0xd9, 0xe8, 0xc6, 0xb8, 0xe3, 0xbe, 0xf4, 0xfa, 0xe3, 0x9a, 0x87, 0xc6, 0x8b,
		0x90, 0xcf, 0x6e, 0x57, 0xbd, 0xa2, 0xde, 0xf6, 0x45, 0xd4, 0xbb, 0x98, 0x27, 0x88, 0x23, 0x2f,
		0x6a, 0xf5, 0xcb, 0x72, 0xad, 0xf6, 0x67, 0xfb, 0xb2, 0x7e, 0xdd, 0xf8, 0xdc, 0xac, 0x5c, 0x81,
		0x47, 0x80, 0x47, 0x80, 0x47, 0x80, 0x47, 0x80, 0x47, 0xa8, 0x3c, 0xb1, 0x56, 0x57, 0x38, 0xd2,
		0x92, 0xaf, 0x9a, 0x2e, 0xd6, 0x55, 0x7a, 0xa0, 0xab, 0x93, 0x47, 0xfd, 0x68, 0xfa, 0x1a, 0xf0,
		0x62, 0xba, 0xe0, 0x8d, 0x72, 0xf3, 0xd7, 0x89, 0xce, 0x2b, 0x37, 0xab, 0xf5, 0x9b, 0xf6, 0x75,
		0xa5, 0xf9, 0x6b, 0xfd, 0x4a, 0x35, 0x7a, 0x8c, 0xdc, 0x66, 0xbe, 0x72, 0x7f, 0xfc, 0x91, 0x16,
		0x9f, 0xfc, 0xd2, 0x06, 0x54, 0xfe, 0x68, 0xd4, 0xaa, 0x97, 0xd5, 0x66, 0xed, 0xcf, 0xf6, 0x55,
		0xe5, 0x53, 0xf5, 0xa6, 0x72, 0x95, 0x3a, 0x04, 0x27, 0xb1, 0xe6, 0x55, 0x5f, 0x63, 0x7b, 0x58,
		0x73, 0x05, 0x92, 0xde, 0xac, 0xdc, 0xde, 0x8c, 0x96, 0xfd, 0xbf, 0x3e, 0x57, 0x6e, 0xab, 0x5a,
		0x56, 0x5d, 0xe9, 0x8c, 0xad, 0xa4, 0xf1, 0x8f, 0x64, 0x5a, 0xc1, 0xbe, 0xf0, 0xbe, 0xea, 0x48,
		0x3a, 0xdb, 0xf6, 0x45, 0x60, 0x79, 0xc2, 0xf2, 0x84, 0xe5, 0x09, 0xcb, 0x13, 0x96, 0xa7, 0x4a,
		0xcb, 0xb3, 0x67, 0x98, 0xdd, 0xae, 0x27, 0x7c, 0x5f, 0x87, 0xe1, 0x79, 0xae, 0x70, 0xce, 0xc9,
		0x1a, 0x27, 0x3e, 0xf2, 0x69, 0xbe, 0xb3, 0x5f, 0xf3, 0x1a, 0xf6, 0x76, 0x6d, 0x8f, 0xcf, 0x34,
		0xcc, 0xdd, 0x30, 0xa5, 0x14, 0x9e, 0xa3, 0xc5, 0xb0, 0x1e, 0x7d, 0x81, 0xe3, 0xe3, 0xfb, 0x8c,
		0x71, 0xde, 0x7a, 0xbb, 0xcf, 0x1a, 0xe7, 0xad, 0xf1, 0xcb, 0xec, 0xe8, 0xaf, 0xf1, 0xeb, 0xdc,
		0x7d, 0xc6, 0xc8, 0x4f, 0x5f, 0x17, 0xee, 0x33, 0x46, 0xa1, 0x75, 0xf2, 0xe5, 0xcb, 0x87, 0x93,
		0xef, 0xa7, 0x83, 0xfd, 0x3f, 0xa8, 0xde, 0x9c, 0x68, 0xe9, 0xd8, 0xd2, 0xfa, 0x5d, 0xf5, 0x0f,
		0xed, 0xfb, 0xfa, 0x97, 0xca, 0x8d, 0xfd, 0x97, 0x86, 0x9d, 0x7d, 0x97, 0x60, 0x67, 0x80, 0x5e,
		0x30, 0x2e, 0x02, 0x8c, 0xb5, 0x82, 0xb1, 0x69, 0x3c, 0x96, 0x8d, 0x4f, 0xad, 0xef, 0xd9, 0xf7,
		0xf9, 0xc1, 0xc5, 0xc9, 0xf7, 0xd2, 0x60, 0xf5, 0xcd, 0xb7, 0x4d, 0xbf, 0x96, 0x7d, 0x5f, 0x1a,
		0x5c, 0x6c, 0xf9, 0x97, 0xe2, 0xe0, 0x62, 0xc7, 0x31, 0x0a, 0x83, 0xe3, 0xb5, 0x5f, 0x1d, 0xbe,
		0x9f, 0xdb, 0xf6, 0x81, 0xfc, 0x96, 0x0f, 0x9c, 0x6e, 0xfb, 0xc0, 0xe9, 0x96, 0x0f, 0x6c, 0xfd,
		0x4a, 0xb9, 0x2d, 0x1f, 0x28, 0x0c, 0xde, 0xd6, 0x7e, 0xff, 0x78, 0xf3, 0xaf, 0x16, 0x07, 0x27,
		0x6f, 0xdb, 0xfe, 0xad, 0x34, 0x78, 0xbb, 0x38, 0x81, 0x6a, 0x52, 0xaf, 0x9a, 0x20, 0xe6, 0xea,
		0xc5, 0x3c, 0xf9, 0x8a, 0x1a, 0xd1, 0xc6, 0x51, 0xf4, 0xe8, 0x7a, 0xe2, 0x51, 0x78, 0xc2, 0xe9,
		0x68, 0x88, 0x39, 0x5e, 0x98, 0x1b, 0x7e, 0x5b, 0xf8, 0x6d, 0xe1, 0xb7, 0x85, 0xdf, 0x16, 0x7e,
		0x5b, 0x85, 0x27, 0x16, 0xc9, 0xaa, 0x09, 0xf2, 0x12, 0x20, 0x59, 0x95, 0xbd, 0xcd, 0xe5, 0xd6,
		0xf9, 0x91, 0xac, 0x7a, 0xb0, 0x22, 0x97, 0x2b, 0xa0, 0xfe, 0x34, 0x0c, 0xc8, 0x03, 0x36, 0x20,
		0x3d, 0x21, 0xbd, 0x57, 0x43, 0x5a, 0x2f, 0x3a, 0xc2, 0x80, 0x16, 0x27, 0x87, 0x09, 0x99, 0x04,
		0x13, 0x12, 0xf5, 0x8e, 0x0e, 0xd4, 0x84, 0x44, 0xbd, 0xa3, 0xb8, 0x9a, 0x90, 0xd9, 0xa2, 0x06,
		0x1b, 0xb2, 0x08, 0x1b, 0x12, 0x36, 0x24, 0x6c, 0x48, 0xd8, 0x90, 0x09, 0x10, 0xb9, 0x62, 0x26,
		0x03, 0x1b, 0x12, 0x36, 0xe4, 0xe1, 0xda, 0x90, 0xbe, 0x90, 0xfd, 0x9e, 0xc6, 0x62, 0xbd, 0x2b,
		0xf3, 0xab, 0x2f, 0xa5, 0x50, 0x82, 0xf5, 0x0a, 0xeb, 0x15, 0xd6, 0x2b, 0xac, 0x57, 0x58, 0xaf,
		0xaa, 0xad, 0x57, 0x5c, 0x80, 0xc2, 0x78, 0x4d, 0x8c, 0x25, 0x81, 0x6a, 0xbd, 0x30, 0x5e, 0x15,
		0x8b, 0x1c, 0xaa, 0xf5, 0xc2, 0x74, 0x3d, 0x64, 0xd3, 0xb5, 0xf7, 0x68, 0xbc, 0x08, 0xe9, 0x59,
		0x1d, 0x0d, 0x66, 0xeb, 0x7c, 0x6e, 0x98, 0x8f, 0x49, 0x30, 0x1f, 0x11, 0x3f, 0x7b, 0xa0, 0xe6,
		0x23, 0xe2, 0x67, 0xe3, 0x6a, 0x3e, 0x16, 0xf3, 0x1a, 0xec, 0xc7, 0x33, 0xd8, 0x8f, 0xb0, 0x1f,
		0x61, 0x3f, 0xc2, 0x7e, 0x4c, 0x80, 0xc8, 0x65, 0xcf, 0xf2, 0xf9, 0x62, 0x29, 0x9f, 0xcf, 0x94,
		0x4e, 0x4b, 0x99, 0xf3, 0x42, 0x21, 0x5b, 0xcc, 0x22, 0xa2, 0x16, 0x26, 0xe5, 0x01, 0x9b, 0x94,
		0x7d, 0x5f, 0x18, 0x1d, 0xbf, 0xf7, 0xa8, 0xde, 0xa0, 0x9c, 0xcd, 0x0c, 0x73, 0x12, 0xe6, 0x24,
		0xcc, 0x49, 0x98, 0x93, 0x30, 0x27, 0x15, 0x9e, 0xd8, 0x07, 0xd7, 0xb5, 0x85, 0xe9, 0xe8, 0xa8,
		0xa1, 0x97, 0x4d, 0x8a, 0x7a, 0x7e, 0x17, 0x63, 0x11, 0x4c, 0x95, 0x1d, 0xc7, 0x1d, 0x97, 0xb3,
		0x55, 0x22, 0x80, 0x29, 0xbf, 0xf3, 0x2c, 0x5e, 0xcc, 0xde, 0xa4, 0x4b, 0x7d, 0xda, 0xed, 0x09,
		0x67, 0xdc, 0x6c, 0xde, 0x70, 0x84, 0xfc, 0xc7, 0xf5, 0xfe, 0x36, 0x2c, 0xc7, 0x97, 0xa6, 0xd3,
		0x11, 0xe9, 0xd5, 0x37, 0xfc, 0xb5, 0x77, 0xd2, 0x43, 0xd0, 0x49, 0xdb, 0x7e, 0xcf, 0x4f, 0x77,
		0x5c, 0xc7, 0x97, 0x9e, 0x69, 0x39, 0xa2, 0x3b, 0x6e, 0x61, 0x2f, 0xfb, 0x8e, 0x23, 0x6c, 0x7f,
		0xf2, 0x77, 0xba, 0x97, 0xeb, 0x19, 0xe3, 0x97, 0x86, 0x29, 0xa5, 0x67, 0x3d, 0xf4, 0xa5, 0xf0,
		0x47, 0xef, 0xf6, 0x3c, 0xeb, 0xc5, 0xf4, 0x5e, 0xc7, 0x9f, 0x5a, 0x7b, 0xc3, 0x97, 0xa6, 0x54,
		0x51, 0x2a, 0x22, 0xe5, 0x4b, 0xaf, 0xdf, 0x91, 0x93, 0x46, 0x7c, 0xa9, 0xfa, 0x6c, 0x5d, 0x6e,
		0xc6, 0xcf, 0x5c, 0x9d, 0x3c, 0x72, 0x7b, 0xe5, 0x67, 0x7f, 0xf5, 0x8d, 0xf6, 0x75, 0xcf, 0xf6,
		0xdb, 0x35, 0xbf, 0xe7, 0xb7, 0x2f, 0xe7, 0x6b, 0xd2, 0x30, 0xe5, 0x73, 0xbb, 0x39, 0x5e, 0x92,
		0xc9, 0xdf, 0xed, 0x46, 0xae, 0x31, 0x7e, 0x55, 0x9e, 0x2d, 0xc8, 0xf0, 0xbd, 0xc6, 0xf8, 0xf1,
		0x47, 0x9f, 0x58, 0xf9, 0xf1, 0x6e, 0xb4, 0x18, 0xef, 0xe2, 0x79, 0x9a, 0x78, 0x46, 0x66, 0x3a,
		0x9f, 0x43, 0x7e, 0xc1, 0xdc, 0x22, 0x31, 0x55, 0xb3, 0x7c, 0x39, 0xdc, 0x7a, 0xd6, 0x83, 0x9f,
		0xba, 0xb6, 0x9c, 0x8a, 0x2d, 0x86, 0x44, 0xc1, 0xe7, 0x65, 0xc1, 0xa9, 0x6b, 0xf3, 0xdb, 0xc2,
		0x4c, 0x6a, 0x6d, 0xfc, 0x54, 0xdd, 0xeb, 0x0a, 0x4f, 0x74, 0x3f, 0x0e, 0x77, 0xcd, 0xe9, 0xdb,
		0x76, 0xac, 0x84, 0x4d, 0x91, 0x12, 0x88, 0x1b, 0xf8, 0x33, 0xc2, 0x7e, 0x1c, 0xe0, 0x9e, 0x07,
		0xe8, 0xe9, 0x61, 0x98, 0x76, 0x44, 0xe2, 0x33, 0xc6, 0x7d, 0xb6, 0x22, 0x7e, 0xa6, 0x18, 0x8e,
		0x50, 0x24, 0x8f, 0x0e, 0xed, 0x59, 0xa1, 0x93, 0x68, 0x42, 0x69, 0x4e, 0x0d, 0xf7, 0xd6, 0x17,
		0x1d, 0xd7, 0xe9, 0x4e, 0x77, 0xd7, 0x27, 0x17, 0xe9, 0x79, 0x9d, 0xb6, 0x0d, 0x93, 0x11, 0x9f,
		0xcc, 0xa9, 0x21, 0x4a, 0x3c, 0x2c, 0x97, 0xc7, 0x8f, 0xd3, 0xb3, 0xa7, 0xc0, 0x83, 0xc7, 0xed,
		0xa9, 0x53, 0xe6, 0x91, 0x53, 0xe6, 0x79, 0x53, 0xe3, 0x61, 0x8b, 0xb6, 0xf6, 0xbc, 0xb2, 0x78,
		0xcc, 0x93, 0x0d, 0xf8, 0xc2, 0x27, 0x99, 0xdb, 0x31, 0x8d, 0x4b, 0x44, 0x79, 0xa0, 0x8d, 0x1d,
		0xe2, 0x54, 0x40, 0x9d, 0x42, 0xc8, 0x53, 0x05, 0x7d, 0xca, 0x21, 0x50, 0x39, 0x14, 0xaa, 0x85,
		0xc4, 0x78, 0x7a, 0x8c, 0xb8, 0xa0, 0x72, 0x36, 0x81, 0xd9, 0x7d, 0xb1, 0x1c, 0xe3, 0xc9, 0x73,
		0xfb, 0x3d, 0x9f, 0x5f, 0x96, 0xa7, 0xc7, 0x73, 0x69, 0x56, 0x66, 0xe9, 0xe2, 0x85, 0x4d, 0x65,
		0xf0, 0xa9, 0x12, 0x46, 0x35, 0xc0, 0xa9, 0x6a, 0x58, 0xd5, 0x06, 0xaf, 0xda, 0x60, 0x56, 0x0f,
		0xdc, 0xf2, 0xc2, 0x2e, 0x33, 0xfc, 0x2a, 0x83, 0xe1, 0xd9, 0x44, 0x9d, 0x29, 0x8a, 0x28, 0x0e,
		0xd8, 0x99, 0xcc, 0xab, 0x36, 0x5c, 0x27, 0x8b, 0x70, 0x9d, 0x38, 0x43, 0xb5, 0x2e, 0xc8, 0xd6,
		0x0e, 0xdd, 0xda, 0x21, 0x5c, 0x2f, 0x94, 0xab, 0x81, 0x74, 0x45, 0xd0, 0xae, 0x1c, 0xe2, 0x67,
		0x13, 0x8a, 0x6f, 0x1d, 0xbb, 0xdf, 0x15, 0x63, 0x16, 0xac, 0xfe, 0xf0, 0x4c, 0xf1, 0x62, 0xf9,
		0x6b, 0x28, 0x96, 0x5f, 0x3d, 0xa1, 0xe3, 0xca, 0x15, 0x82, 0x4e, 0xc5, 0x10, 0x01, 0x05, 0xa1,
		0x5b, 0x51, 0x44, 0x46, 0x61, 0x44, 0x46, 0x71, 0x44, 0x43, 0x81, 0xa8, 0x55, 0x24, 0x8a, 0x15,
		0xca, 0x6c, 0x89, 0x95, 0xc7, 0x81, 0xae, 0x9d, 0x78, 0x5b, 0x98, 0x8f, 0x9e, 0x78, 0xd4, 0xd9,
		0xea, 0xb1, 0xa4, 0xa7, 0xd5, 0xe3, 0xe8, 0xfa, 0xfc, 0xc3, 0x87, 0xf4, 0x0f, 0xfe, 0x93, 0xc2,
		0x78, 0xb2, 0xdd, 0x07, 0x73, 0xe9, 0xc6, 0x7b, 0x78, 0x0e, 0x8c, 0x45, 0x27, 0x55, 0x7a, 0xe1,
		0x87, 0xc5, 0xd7, 0xc6, 0xe8, 0xc6, 0x3a, 0xd1, 0xf2, 0xab, 0x24, 0xa2, 0x6c, 0xeb, 0xec, 0xca,
		0x22, 0xcd, 0xb6, 0x7f, 0x03, 0x8d, 0x11, 0x68, 0x5b, 0xbf, 0x94, 0x92, 0xc8, 0x34, 0xfd, 0x78,
		0xad, 0x50, 0xd6, 0x53, 0x96, 0x33, 0x26, 0xc2, 0xa6, 0x6d, 0xeb, 0xe6, 0xe4, 0xeb, 0x5f, 0x05,
		0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c, 0xbc, 0x1c,
		0xbc, 0x1c, 0xbc, 0xfc, 0xd0, 0x78, 0xb9, 0xf3, 0x1a, 0x19, 0x5e, 0x3e, 0xfb, 0x2a, 0xe0, 0xe5,
		0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5,
		0xe0, 0xe5, 0x3a, 0x79, 0x79, 0xa2, 0x42, 0x72, 0x14, 0x97, 0x31, 0x99, 0xcd, 0x1b, 0xbd, 0xec,
		0xdb, 0x95, 0xa4, 0xc9, 0x0d, 0xef, 0xa5, 0x97, 0xd0, 0x57, 0x69, 0x38, 0xe7, 0x51, 0xa4, 0xf2,
		0x77, 0xef, 0xa6, 0xcb, 0x32, 0xfc, 0xcc, 0xfa, 0x3b, 0xed, 0xf2, 0x70, 0x9d, 0x7e, 0x19, 0x2d,
		0x53, 0x7b, 0x62, 0xd7, 0xa0, 0xa4, 0xe0, 0x1e, 0xdb, 0x6c, 0x4a, 0xa1, 0xa1, 0x40, 0xbd, 0xa2,
		0x82, 0x3d, 0x47, 0x3a, 0xa3, 0x93, 0x73, 0x88, 0x4e, 0x4e, 0x90, 0x11, 0x8d, 0xe8, 0x64, 0x44,
		0x27, 0xd3, 0x2d, 0x25, 0xa2, 0x93, 0xe1, 0x6d, 0x4d, 0xa2, 0x62, 0x88, 0x80, 0x82, 0xd0, 0xad,
		0x28, 0x22, 0xa3, 0x30, 0x22, 0xa3, 0x38, 0xa2, 0xa1, 0x40, 0xd4, 0x5b, 0xef, 0x47, 0xf0, 0xb6,
		0x1e, 0xe9, 0x00, 0x78, 0x78, 0x5b, 0xe3, 0x2b, 0xbf, 0xf0, 0xb6, 0xc2, 0xdb, 0xaa, 0x0b, 0xaf,
		0x11, 0x9d, 0x0c, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e,
		0x0e, 0x5e, 0x0e, 0x5e, 0x0e, 0x5e, 0x7e, 0xa0, 0xbc, 0x1c, 0xd1, 0xc9, 0xe0, 0xe5, 0xe0, 0xe5,
		0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5, 0xe0, 0xe5,
		0x1a, 0x66, 0x42, 0x74, 0x72, 0xd4, 0xa3, 0x93, 0x55, 0x46, 0x73, 0x1e, 0xc5, 0x36, 0x38, 0x59,
		0x41, 0x5f, 0x46, 0x75, 0x07, 0x13, 0xfd, 0x54, 0x0f, 0xea, 0x88, 0x1f, 0x54, 0x6f, 0xd5, 0x3d,
		0x0e, 0x75, 0x6c, 0xdb, 0xac, 0x32, 0xf6, 0x51, 0x51, 0x54, 0xf2, 0x5c, 0x6d, 0xa9, 0x73, 0x74,
		0x9d, 0x88, 0x95, 0x6f, 0x0b, 0x5d, 0x27, 0x92, 0xe9, 0x9b, 0x42, 0xd7, 0x89, 0xdd, 0x20, 0xd8,
		0xef, 0x3d, 0x1a, 0xd2, 0x12, 0x0f, 0x9e, 0x30, 0xff, 0x16, 0x9e, 0x86, 0xf6, 0x13, 0x2b, 0x5f,
		0x40, 0x6d, 0xa6, 0x57, 0x06, 0x7d, 0x28, 0xe2, 0x0c, 0xde, 0xba, 0x40, 0x5c, 0x3b, 0x98, 0x6b,
		0x07, 0x75, 0xbd, 0xe0, 0x9e, 0x4c, 0xb7, 0x92, 0xf2, 0x0b, 0x86, 0x35, 0x10, 0x36, 0x46, 0x28,
		0x6c, 0x39, 0x4a, 0xf3, 0xc7, 0xa7, 0x7c, 0x39, 0xaf, 0x70, 0xce, 0x8a, 0xd3, 0x7f, 0x19, 0x2e,
		0xb5, 0xca, 0x78, 0x81, 0x2b, 0xf1, 0x68, 0xf6, 0xed, 0xd1, 0x41, 0xb9, 0x2d, 0xdf, 0x5c, 0xd5,
		0xaf, 0x91, 0x7d, 0xbe, 0xfb, 0xe2, 0x89, 0x6f, 0x3d, 0xdb, 0xea, 0x58, 0x72, 0xe4, 0x70, 0x30,
		0x26, 0xa6, 0xbf, 0x62, 0xaa, 0xb2, 0xe1, 0x3b, 0x80, 0xad, 0x80, 0xad, 0x80, 0xad, 0x80, 0xad,
		0x80, 0xad, 0x28, 0x3c, 0xb1, 0xea, 0xc3, 0x20, 0x74, 0x84, 0x3f, 0xfc, 0x38, 0xec, 0x61, 0xa8,
		0x7d, 0xba, 0xc6, 0x92, 0x46, 0xf2, 0x37, 0xbd, 0x39, 0xa9, 0x07, 0x94, 0x56, 0x17, 0xde, 0x90,
		0x0c, 0xbe, 0xf1, 0xec, 0xda, 0x5d, 0xa3, 0xe7, 0x59, 0xae, 0x67, 0xc9, 0x57, 0xf5, 0x54, 0x63,
		0x79, 0x7a, 0x55, 0x95, 0x26, 0xe6, 0x04, 0x35, 0x03, 0x66, 0x93, 0x08, 0x66, 0xe3, 0xf9, 0x5f,
		0x7b, 0x60, 0x36, 0x07, 0xc8, 0x6c, 0x46, 0x1b, 0x0f, 0x66, 0x13, 0x33, 0x66, 0xd3, 0xb7, 0x1c,
		0x79, 0xa6, 0x81, 0xd7, 0x28, 0x8c, 0x7c, 0x4b, 0xdd, 0x9a, 0xce, 0xd3, 0xf0, 0x61, 0xef, 0x95,
		0x9e, 0x0f, 0x3d, 0x11, 0x8f, 0x1a, 0x23, 0xe4, 0xb5, 0x24, 0x64, 0xcc, 0xa6, 0xff, 0xdd, 0xb4,
		0xfb, 0x42, 0xe3, 0xfc, 0x9f, 0x3c, 0xb3, 0x23, 0x2d, 0xd7, 0xb9, 0xb2, 0x9e, 0xac, 0x71, 0xc0,
		0xa9, 0xfa, 0x60, 0x78, 0x3d, 0x21, 0xae, 0x07, 0x2f, 0x72, 0xa5, 0x03, 0x16, 0xb9, 0x84, 0x46,
		0x0f, 0xb7, 0x60, 0xb8, 0xee, 0x2c, 0x86, 0x7a, 0x5c, 0xe3, 0x70, 0x86, 0x27, 0xc6, 0x64, 0x84,
		0x33, 0xfc, 0x40, 0x4d, 0x46, 0x38, 0xc3, 0xe3, 0x68, 0x32, 0xfa, 0xd2, 0xd3, 0x74, 0x5f, 0x7f,
		0x06, 0xad, 0xbc, 0xf3, 0x9a, 0x8d, 0x6e, 0x8c, 0x3b, 0xee, 0x4b, 0xaf, 0x3f, 0x4e, 0x26, 0x30,
		0x5e, 0x84, 0x7c, 0x76, 0xbb, 0xea, 0x15, 0xf5, 0xb6, 0x2f, 0xa2, 0xde, 0xc5, 0x3c, 0x41, 0x1c,
		0x79, 0x51, 0xab, 0x5f, 0x96, 0x6b, 0xb5, 0x3f, 0xdb, 0x97, 0xf5, 0xeb, 0xc6, 0xe7, 0x66, 0xe5,
		0x0a, 0x3c, 0x02, 0x3c, 0x02, 0x3c, 0x02, 0x3c, 0x02, 0x3c, 0x42, 0xe5, 0x89, 0xb5, 0xba, 0xc2,
		0x91, 0x96, 0x7c, 0xd5, 0x74, 0xb1, 0xae, 0xd2, 0x03, 0x5d, 0x9d, 0x3c, 0xea, 0x47, 0xd3, 0x17,
		0xfa, 0x6a, 0xf6, 0x34, 0xca, 0xcd, 0x5f, 0x27, 0x3a, 0xaf, 0xdc, 0xac, 0xd6, 0x6f, 0xda, 0xd7,
		0x95, 0xe6, 0xaf, 0xf5, 0x2b, 0xd5, 0xe8, 0x31, 0x72, 0x9b, 0xf9, 0xca, 0xfd, 0xf1, 0x47, 0x5a,
		0x7c, 0xf2, 0x4b, 0x1b, 0x50, 0xf9, 0xa3, 0x51, 0xab, 0x5e, 0x56, 0x9b, 0xb5, 0x3f, 0xdb, 0x57,
		0x95, 0x4f, 0xd5, 0x9b, 0xca, 0x55, 0xea, 0x10, 0x9c, 0xc4, 0x9a, 0x57, 0x7d, 0x8d, 0xed, 0x61,
		0xcd, 0x15, 0x48, 0x7a, 0xb3, 0x72, 0x7b, 0x33, 0x5a, 0xf6, 0xff, 0xfa, 0x5c, 0xb9, 0xad, 0x6a,
		0x59, 0x75, 0xa5, 0x33, 0xb6, 0x92, 0xc6, 0x3f, 0x92, 0x69, 0x05, 0xfb, 0xc2, 0xfb, 0xaa, 0x23,
		0xe9, 0x6c, 0xdb, 0x17, 0x81, 0xe5, 0x09, 0xcb, 0x13, 0x96, 0x27, 0x2c, 0x4f, 0x58, 0x9e, 0x2a,
		0x2d, 0xcf, 0x9e, 0x61, 0x76, 0xbb, 0x9e, 0xf0, 0x7d, 0x1d, 0x86, 0xe7, 0xb9, 0xc2, 0x39, 0x27,
		0x6b, 0x9c, 0xf8, 0xc8, 0xa7, 0xf9, 0xce, 0x7e, 0xcd, 0x6b, 0xd8, 0xdb, 0xb5, 0x3d, 0x3e, 0xd3,
		0x53, 0xb4, 0x50, 0x0a, 0xcf, 0xd1, 0x62, 0x58, 0x8f, 0xbe, 0xc0, 0xf1, 0xf1, 0x7d, 0xc6, 0x38,
		0x6f, 0xbd, 0xdd, 0x67, 0x8d, 0xf3, 0xd6, 0xf8, 0x65, 0x76, 0xf4, 0xd7, 0xf8, 0x75, 0xee, 0x3e,
		0x63, 0xe4, 0xa7, 0xaf, 0x0b, 0xf7, 0x19, 0xa3, 0xd0, 0x3a, 0xf9, 0xf2, 0xe5, 0xc3, 0xc9, 0xf7,
		0xd3, 0xc1, 0xfe, 0x1f, 0x54, 0x6f, 0x4e, 0xb4, 0x74, 0x6c, 0x69, 0xfd, 0xae, 0xfa, 0x87, 0xf6,
		0x7d, 0xfd, 0x4b, 0xe5, 0xc6, 0xfe, 0x4b, 0xc3, 0xce, 0x26, 0xb9, 0x08, 0xa7, 0x5e, 0x30, 0x2e,
		0x02, 0x8c, 0xb5, 0x82, 0xb1, 0x69, 0x3c, 0x96, 0x8d, 0x4f, 0xad, 0xef, 0xd9, 0xf7, 0xf9, 0xc1,
		0xc5, 0xc9, 0xf7, 0xd2, 0x60, 0xf5, 0xcd, 0xb7, 0x4d, 0xbf, 0x96, 0x7d, 0x5f, 0x1a, 0x5c, 0x6c,
		0xf9, 0x97, 0xe2, 0xe0, 0x62, 0xc7, 0x31, 0x0a, 0x83, 0xe3, 0xb5, 0x5f, 0x1d, 0xbe, 0x9f, 0xdb,
		0xf6, 0x81, 0xfc, 0x96, 0x0f, 0x9c, 0x6e, 0xfb, 0xc0, 0xe9, 0x96, 0x0f, 0x6c, 0xfd, 0x4a, 0xb9,
		0x2d, 0x1f, 0x28, 0x0c, 0xde, 0xd6, 0x7e, 0xff, 0x78, 0xf3, 0xaf, 0x16, 0x07, 0x27, 0x6f, 0xdb,
		0xfe, 0xad, 0x34, 0x78, 0xbb, 0x38, 0x81, 0x6a, 0x52, 0xaf, 0x9a, 0x20, 0xe6, 0xea, 0xc5, 0x3c,
		0xf9, 0x8a, 0x1a, 0xd1, 0xc6, 0x51, 0xf4, 0xe8, 0x7a, 0xe2, 0x51, 0x78, 0xc2, 0xe9, 0x68, 0x88,
		0x39, 0x5e, 0x98, 0x1b, 0x7e, 0x5b, 0xf8, 0x6d, 0xe1, 0xb7, 0x85, 0xdf, 0x16, 0x7e, 0x5b, 0x85,
		0x27, 0x16, 0xc9, 0xaa, 0x09, 0xf2, 0x12, 0x20, 0x59, 0x95, 0xbd, 0x62, 0xf3, 0xd6, 0xf9, 0x91,
		0xac, 0x7a, 0xb0, 0x22, 0x97, 0x2b, 0x14, 0x90, 0xae, 0x0a, 0x03, 0xf2, 0x70, 0x0d, 0x48, 0x4f,
		0x48, 0xef, 0xd5, 0x90, 0xd6, 0x8b, 0x8e, 0x30, 0xa0, 0xc5, 0xc9, 0x61, 0x42, 0x26, 0xc1, 0x84,
		0x44, 0xbd, 0xa3, 0x03, 0x35, 0x21, 0x51, 0xef, 0x28, 0xae, 0x26, 0x64, 0xb6, 0xa8, 0xc1, 0x86,
		0x2c, 0xc2, 0x86, 0x84, 0x0d, 0x09, 0x1b, 0x12, 0x36, 0x64, 0x02, 0x44, 0xae, 0x98, 0xc9, 0xc0,
		0x86, 0x84, 0x0d, 0x79, 0xb8, 0x36, 0xa4, 0x2f, 0x64, 0xbf, 0xa7, 0xb1, 0x58, 0xef, 0xca, 0xfc,
		0xea, 0x4b, 0x29, 0x94, 0x60, 0xbd, 0xc2, 0x7a, 0x85, 0xf5, 0x0a, 0xeb, 0x15, 0xd6, 0xab, 0x6a,
		0xeb, 0x15, 0x17, 0xa0, 0x30, 0x5e, 0x13, 0x63, 0x49, 0xa0, 0x5a, 0x2f, 0x8c, 0x57, 0xc5, 0x22,
		0x87, 0x6a, 0xbd, 0x30, 0x5d, 0x0f, 0xd8, 0x74, 0xed, 0xfb, 0xc2, 0xe8, 0xf8, 0xbd, 0x47, 0xf5,
		0x46, 0xeb, 0x6c, 0x66, 0x98, 0x8e, 0x49, 0x30, 0x1d, 0x11, 0x3b, 0x7b, 0xa0, 0xa6, 0x23, 0x62,
		0x67, 0xe3, 0x68, 0x3a, 0x3e, 0xb8, 0xae, 0x2d, 0x4c, 0x47, 0x47, 0xc1, 0x83, 0x6c, 0x52, 0xd4,
		0x73, 0xac, 0x1b, 0xfc, 0x97, 0x1d, 0xc7, 0x1d, 0xd7, 0x1e, 0x52, 0xd3, 0xe7, 0xdf, 0xef, 0x3c,
		0x8b, 0x17, 0xb3, 0x37, 0x69, 0x29, 0x98, 0x76, 0x7b, 0xc2, 0x19, 0x77, 0x06, 0x34, 0x1c, 0x21,
		0xff, 0x71, 0xbd, 0xbf, 0x0d, 0xcb, 0xf1, 0xa5, 0xe9, 0x74, 0x44, 0x7a, 0xf5, 0x0d, 0x7f, 0xed,
		0x9d, 0xf4, 0x10, 0x74, 0xd2, 0xb6, 0xdf, 0xf3, 0xd3, 0x1d, 0xd7, 0xf1, 0xa5, 0x67, 0x5a, 0x8e,
		0xe8, 0x8e, 0xfb, 0x0d, 0xca, 0xbe, 0xe3, 0x08, 0xdb, 0x9f, 0xfc, 0x9d, 0xee, 0xe5, 0x7a, 0xc6,
		0xf8, 0xa5, 0x61, 0x4a, 0xe9, 0x59, 0x0f, 0x7d, 0x29, 0xfc, 0xd1, 0xbb, 0xbe, 0xe8, 0xb8, 0x4e,
		0xd7, 0xf4, 0x5e, 0x27, 0xcd, 0x0b, 0xd7, 0xdf, 0x9b, 0xf4, 0x2e, 0x4c, 0xa9, 0xb8, 0x42, 0x90,
		0x5e, 0xbf, 0x23, 0x27, 0xbd, 0x13, 0x52, 0xf5, 0xd9, 0xea, 0xdc, 0x8c, 0x9f, 0xbc, 0x3a, 0x79,
		0xf0, 0xf6, 0xca, 0xcf, 0xfe, 0xea, 0x1b, 0xed, 0xeb, 0x9e, 0xed, 0xb7, 0x6b, 0x7e, 0xcf, 0x6f,
		0x5f, 0xce, 0x57, 0xa6, 0x61, 0xca, 0xe7, 0x76, 0x73, 0xbc, 0x30, 0x93, 0xbf, 0xdb, 0x8d, 0x5c,
		0x63, 0xfc, 0xaa, 0x3c, 0x5b, 0x96, 0xe1, 0x7b, 0x77, 0xd3, 0x15, 0x18, 0x7e, 0x66, 0xfd, 0x9d,
		0xf6, 0x84, 0xd7, 0xbc, 0x8b, 0xe7, 0xc9, 0x62, 0x3c, 0x55, 0x6a, 0x1a, 0x5f, 0xa8, 0x6c, 0x78,
		0xa1, 0x88, 0x32, 0x2b, 0xa3, 0xca, 0x2a, 0x29, 0xb2, 0x06, 0x6a, 0xac, 0x9a, 0x12, 0x6b, 0xa3,
		0xc2, 0xda, 0x28, 0xb0, 0x1e, 0xea, 0x1b, 0x6f, 0x9e, 0xa1, 0x8c, 0xe2, 0x6a, 0xe8, 0xce, 0xac,
		0xb2, 0x2b, 0xf3, 0x62, 0x37, 0x66, 0x65, 0x2d, 0x95, 0xe3, 0xa9, 0x88, 0x7d, 0x69, 0x4a, 0x85,
		0x9a, 0x78, 0x3c, 0x9d, 0x1a, 0x55, 0x9c, 0x55, 0xa5, 0x8a, 0x73, 0x50, 0xc5, 0x50, 0xc5, 0x50,
		0xc5, 0x89, 0x52, 0xc5, 0x57, 0x96, 0x9a, 0x14, 0xa7, 0x94, 0xe9, 0xfb, 0x6e, 0xc7, 0x32, 0xa5,
		0xe8, 0x8e, 0x02, 0x4b, 0x0c, 0x5f, 0xf8, 0xbe, 0xe5, 0x3a, 0xbe, 0xfa, 0x4b, 0x86, 0xad, 0xdf,
		0x04, 0x97, 0x0e, 0x71, 0x83, 0x71, 0x8d, 0x70, 0xae, 0x0b, 0xd6, 0xb5, 0xc3, 0xbb, 0x76, 0x98,
		0xd7, 0x0b, 0xf7, 0x6a, 0x60, 0x5f, 0x11, 0xfc, 0xab, 0xb7, 0xc8, 0x34, 0x5a, 0x66, 0x3a, 0x2c,
		0xb4, 0x4d, 0x96, 0xda, 0xb6, 0xff, 0x7c, 0xeb, 0xc9, 0x31, 0x6d, 0xcb, 0x79, 0x32, 0x7a, 0x9e,
		0x2b, 0xdd, 0x8e, 0x6b, 0xfb, 0xe9, 0x91, 0x82, 0x92, 0x22, 0x3d, 0xd5, 0x51, 0xd3, 0x17, 0x69,
		0xdb, 0xed, 0x98, 0xb6, 0x61, 0x39, 0x5d, 0xf1, 0x2d, 0x95, 0x28, 0x49, 0xac, 0x59, 0xbe, 0x2c,
		0x4b, 0xe9, 0xa9, 0x95, 0xc6, 0x6b, 0xcb, 0xa9, 0xd8, 0x62, 0x08, 0x26, 0xbe, 0xda, 0xf8, 0xa3,
		0xd4, 0xb5, 0xf9, 0x6d, 0x61, 0xe6, 0xec, 0x59, 0x3e, 0x5f, 0x2c, 0xe5, 0xf3, 0x99, 0xd2, 0x69,
		0x29, 0x73, 0x5e, 0x28, 0x64, 0x8b, 0x4a, 0x9b, 0x50, 0xd5, 0xbd, 0xae, 0xf0, 0x44, 0xf7, 0xe3,
		0x6b, 0xea, 0xe2, 0xc8, 0xe9, 0xdb, 0x36, 0x82, 0x66, 0x76, 0x5e, 0xba, 0x8e, 0xdf, 0x7b, 0x34,
		0x5e, 0x84, 0xf4, 0xac, 0x8e, 0x7a, 0x4a, 0xbb, 0x38, 0x39, 0x58, 0x2c, 0x58, 0x2c, 0x58, 0x2c,
		0x58, 0x2c, 0x58, 0xac, 0xc2, 0x13, 0xdb, 0xb7, 0x1c, 0x59, 0xcc, 0x6b, 0x20, 0xb1, 0x67, 0x48,
		0xbb, 0x60, 0x61, 0x83, 0x48, 0xbb, 0x40, 0xda, 0x85, 0x52, 0x91, 0x43, 0xda, 0x85, 0x66, 0xe3,
		0x27, 0x72, 0x52, 0x88, 0x4c, 0x0c, 0x18, 0x95, 0x43, 0xbb, 0x4e, 0x5a, 0xe2, 0xc1, 0x13, 0xe6,
		0xdf, 0x3a, 0x8a, 0xd1, 0xad, 0x7e, 0x01, 0x18, 0x97, 0x30, 0x2e, 0x61, 0x5c, 0xc2, 0xb8, 0x84,
		0x71, 0xa9, 0x01, 0x84, 0x8d, 0x11, 0x0a, 0x5b, 0xce, 0x93, 0x8e, 0xcb, 0x92, 0xbc, 0xc2, 0x39,
		0x2b, 0x4e, 0xff, 0x65, 0xb8, 0xd4, 0x0a, 0x89, 0xf8, 0x62, 0xe5, 0x9a, 0xdb, 0xf2, 0xcd, 0x55,
		0xfd, 0x3a, 0x05, 0x9e, 0xb2, 0xf3, 0xe2, 0x89, 0x6f, 0x3d, 0xdb, 0xea, 0x58, 0x72, 0x94, 0x21,
		0x61, 0x28, 0x09, 0x7a, 0x5f, 0x3b, 0x25, 0x1b, 0xbe, 0x03, 0xd8, 0x0a, 0xd8, 0x0a, 0xd8, 0x0a,
		0xd8, 0x0a, 0xd8, 0x8a, 0xc2, 0x13, 0x8b, 0x80, 0x8e, 0x0f, 0xa3, 0x28, 0xfc, 0xae, 0xb1, 0xa4,
		0x91, 0xfc, 0x4d, 0x6f, 0xaa, 0x8b, 0xda, 0x4f, 0x16, 0xdf, 0x78, 0x76, 0xed, 0xae, 0xc6, 0xda,
		0x8a, 0xcb, 0xd3, 0xab, 0x2f, 0xad, 0x98, 0x01, 0xb3, 0x49, 0x04, 0xb3, 0x41, 0x69, 0xc5, 0x03,
		0x65, 0x36, 0x28, 0xad, 0x18, 0x47, 0x66, 0x83, 0xd2, 0x8a, 0x5c, 0x7f, 0x70, 0xc7, 0xaf, 0x74,
		0x7a, 0xdc, 0xf1, 0xe3, 0x8e, 0x5f, 0x93, 0xc8, 0xa1, 0xb4, 0x62, 0xe2, 0x66, 0xc3, 0x85, 0xfe,
		0xee, 0x62, 0xa8, 0xc7, 0x35, 0x0e, 0x67, 0x78, 0x62, 0x4c, 0x46, 0x38, 0xc3, 0x0f, 0xd4, 0x64,
		0x84, 0x33, 0x3c, 0x8e, 0x26, 0xa3, 0x2f, 0x3d, 0x4d, 0xf7, 0xf5, 0x67, 0xd0, 0xca, 0x3b, 0xaf,
		0xd9, 0xe8, 0xc6, 0xb8, 0xe3, 0xbe, 0xf4, 0xfa, 0xe3, 0xea, 0x87, 0xc6, 0x8b, 0x90, 0xcf, 0x6e,
		0x57, 0xbd, 0xa2, 0xde, 0xf6, 0x45, 0xd4, 0xbb, 0x98, 0x27, 0x88, 0x23, 0x2f, 0x6a, 0xf5, 0xcb,
		0x72, 0xad, 0xf6, 0x67, 0xfb, 0xb2, 0x7e, 0xdd, 0xf8, 0xdc, 0xac, 0x5c, 0x81, 0x47, 0x80, 0x47,
		0x80, 0x47, 0x80, 0x47, 0x80, 0x47, 0xa8, 0x3c, 0xb1, 0x56, 0x57, 0x38, 0xd2, 0x92, 0xaf, 0x9a,
		0x2e, 0xd6, 0x55, 0x7a, 0xa0, 0xab, 0x93, 0x47, 0xfd, 0x68, 0xfa, 0x1a, 0xf0, 0x62, 0xba, 0xe0,
		0x8d, 0x72, 0xf3, 0xd7, 0x89, 0xce, 0x2b, 0x37, 0xab, 0xf5, 0x9b, 0xf6, 0x75, 0xa5, 0xf9, 0x6b,
		0xfd, 0x4a, 0x35, 0x7a, 0x8c, 0xdc, 0x66, 0xbe, 0x72, 0x7f, 0xfc, 0x91, 0x16, 0x9f, 0xfc, 0xd2,
		0x06, 0x54, 0xfe, 0x68, 0xd4, 0xaa, 0x97, 0xd5, 0x66, 0xed, 0xcf, 0xf6, 0x55, 0xe5, 0x53, 0xf5,
		0xa6, 0x72, 0x95, 0x3a, 0x04, 0x27, 0xb1, 0xe6, 0x55, 0x5f, 0x63, 0x7b, 0x58, 0x73, 0x05, 0x92,
		0xde, 0xac, 0xdc, 0xde, 0x8c, 0x96, 0xfd, 0xbf, 0x3e, 0x57, 0x6e, 0xab, 0x5a, 0x56, 0x5d, 0xe9,
		0x8c, 0xad, 0xa4, 0xf1, 0x8f, 0x64, 0x5a, 0xc1, 0xbe, 0xf0, 0xbe, 0xea, 0x48, 0x3a, 0xdb, 0xf6,
		0x45, 0x60, 0x79, 0xc2, 0xf2, 0x84, 0xe5, 0x09, 0xcb, 0x13, 0x96, 0xa7, 0x4a, 0xcb, 0xb3, 0x67,
		0x98, 0xdd, 0xae, 0x27, 0x7c, 0x5f, 0x87, 0xe1, 0x79, 0xae, 0x70, 0xce, 0xc9, 0x1a, 0x27, 0x3e,
		0xf2, 0x69, 0xbe, 0xb3, 0x5f, 0xf3, 0x1a, 0xf6, 0x76, 0x6d, 0x8f, 0xcf, 0x34, 0xcc, 0xdd, 0x30,
		0xa5, 0x14, 0x9e, 0xa3, 0xc5, 0xb0, 0x1e, 0x7d, 0x81, 0xe3, 0xe3, 0xfb, 0x8c, 0x71, 0xde, 0x7a,
		0xbb, 0xcf, 0x1a, 0xe7, 0xad, 0xf1, 0xcb, 0xec, 0xe8, 0xaf, 0xf1, 0xeb, 0xdc, 0x7d, 0xc6, 0xc8,
		0x4f, 0x5f, 0x17, 0xee, 0x33, 0x46, 0xa1, 0x75, 0xf2, 0xe5, 0xcb, 0x87, 0x93, 0xef, 0xa7, 0x83,
		0xfd, 0x3f, 0xa8, 0xde, 0x9c, 0x68, 0xe9, 0xd8, 0xd2, 0xfa, 0x5d, 0xf5, 0x0f, 0xed, 0xfb, 0xfa,
		0x97, 0xca, 0x8d, 0xfd, 0x97, 0x86, 0x9d, 0x7d, 0x97, 0x60, 0x67, 0x80, 0x5e, 0x30, 0x2e, 0x02,
		0x8c, 0xb5, 0x82, 0xb1, 0x69, 0x3c, 0x96, 0x8d, 0x4f, 0xad, 0xef, 0xd9, 0xf7, 0xf9, 0xc1, 0xc5,
		0xc9, 0xf7, 0xd2, 0x60, 0xf5, 0xcd, 0xb7, 0x4d, 0xbf, 0x96, 0x7d, 0x5f, 0x1a, 0x5c, 0x6c, 0xf9,
		0x97, 0xe2, 0xe0, 0x62, 0xc7, 0x31, 0x0a, 0x83, 0xe3, 0xb5, 0x5f, 0x1d, 0xbe, 0x9f, 0xdb, 0xf6,
		0x81, 0xfc, 0x96, 0x0f, 0x9c, 0x6e, 0xfb, 0xc0, 0xe9, 0x96, 0x0f, 0x6c, 0xfd, 0x4a, 0xb9, 0x2d,
		0x1f, 0x28, 0x0c, 0xde, 0xd6, 0x7e, 0xff, 0x78, 0xf3, 0xaf, 0x16, 0x07, 0x27, 0x6f, 0xdb, 0xfe,
		0xad, 0x34, 0x78, 0xbb, 0x38, 0x81, 0x6a, 0x52, 0xaf, 0x9a, 0x20, 0xe6, 0xea, 0xc5, 0x3c, 0xf9,
		0x8a, 0x1a, 0xd1, 0xc6, 0x51, 0xf4, 0xe8, 0x7a, 0xe2, 0x51, 0x78, 0xc2, 0xe9, 0x68, 0x88, 0x39,
		0x5e, 0x98, 0x1b, 0x7e, 0x5b, 0xf8, 0x6d, 0xe1, 0xb7, 0x85, 0xdf, 0x16, 0x7e, 0x5b, 0x85, 0x27,
		0x16, 0xc9, 0xaa, 0x09, 0xf2, 0x12, 0x20, 0x59, 0x95, 0xbd, 0xcd, 0xe5, 0xd6, 0xf9, 0x91, 0xac,
		0x7a, 0xb0, 0x22, 0x97, 0x2b, 0xa0, 0xfe, 0x34, 0x0c, 0xc8, 0x03, 0x36, 0x20, 0x3d, 0x21, 0xbd,
		0x57, 0x43, 0x5a, 0x2f, 0x3a, 0xc2, 0x80, 0x16, 0x27, 0x87, 0x09, 0x99, 0x04, 0x13, 0x12, 0xf5,
		0x8e, 0x0e, 0xd4, 0x84, 0x44, 0xbd, 0xa3, 0xb8, 0x9a, 0x90, 0xd9, 0xa2, 0x06, 0x1b, 0xb2, 0x08,
		0x1b, 0x12, 0x36, 0x24, 0x6c, 0x48, 0xd8, 0x90, 0x09, 0x10, 0xb9, 0x62, 0x26, 0x03, 0x1b, 0x12,
		0x36, 0xe4, 0xe1, 0xda, 0x90, 0xbe, 0x90, 0xfd, 0x9e, 0xc6, 0x62, 0xbd, 0x2b, 0xf3, 0xab, 0x2f,
		0xa5, 0x50, 0x82, 0xf5, 0x0a, 0xeb, 0x15, 0xd6, 0x2b, 0xac, 0x57, 0x58, 0xaf, 0xaa, 0xad, 0x57,
		0x5c, 0x80, 0xc2, 0x78, 0x4d, 0x8c, 0x25, 0x81, 0x6a, 0xbd, 0x30, 0x5e, 0x15, 0x8b, 0x1c, 0xaa,
		0xf5, 0xc2, 0x74, 0x3d, 0x64, 0xd3, 0xb5, 0xf7, 0x68, 0xbc, 0x08, 0xe9, 0x59, 0x1d, 0x0d, 0x66,
		0xeb, 0x7c, 0x6e, 0x98, 0x8f, 0x49, 0x30, 0x1f, 0x11, 0x3f, 0x7b, 0xa0, 0xe6, 0x23, 0xe2, 0x67,
		0xe3, 0x6a, 0x3e, 0x16, 0xf3, 0x1a, 0xec, 0xc7, 0x33, 0xd8, 0x8f, 0xb0, 0x1f, 0x61, 0x3f, 0xc2,
		0x7e, 0x4c, 0x80, 0xc8, 0x65, 0xcf, 0xf2, 0xf9, 0x62, 0x29, 0x9f, 0xcf, 0x94, 0x4e, 0x4b, 0x99,
		0xf3, 0x42, 0x21, 0x5b, 0xcc, 0x22, 0xa2, 0x16, 0x26, 0xe5, 0x01, 0x9b, 0x94, 0x7d, 0x5f, 0x18,
		0x1d, 0xbf, 0xf7, 0xa8, 0xde, 0xa0, 0x9c, 0xcd, 0x0c, 0x73, 0x12, 0xe6, 0x24, 0xcc, 0x49, 0x98,
		0x93, 0x30, 0x27, 0x15, 0x9e, 0xd8, 0x07, 0xd7, 0xb5, 0x85, 0xe9, 0xe8, 0xa8, 0xa1, 0x97, 0x4d,
		0x8a, 0x7a, 0x7e, 0x17, 0x63, 0x11, 0x4c, 0x95, 0x1d, 0xc7, 0x1d, 0x97, 0xb3, 0x55, 0x22, 0x80,
		0x29, 0xbf, 0xf3, 0x2c, 0x5e, 0xcc, 0xde, 0xa4, 0x4b, 0x7d, 0xda, 0xed, 0x09, 0x67, 0xdc, 0x6c,
		0xde, 0x70, 0x84, 0xfc, 0xc7, 0xf5, 0xfe, 0x36, 0x2c, 0xc7, 0x97, 0xa6, 0xd3, 0x11, 0xe9, 0xd5,
		0x37, 0xfc, 0xb5, 0x77, 0xd2, 0x43, 0xd0, 0x49, 0xdb, 0x7e, 0xcf, 0x4f, 0x77, 0x5c, 0xc7, 0x97,
		0x9e, 0x69, 0x39, 0xa2, 0x3b, 0x6e, 0x61, 0x2f, 0xfb, 0x8e, 0x23, 0x6c, 0x7f, 0xf2, 0x77, 0xba,
		0x97, 0xeb, 0x19, 0xe3, 0x97, 0x86, 0x29, 0xa5, 0x67, 0x3d, 0xf4, 0xa5, 0xf0, 0x47, 0xef, 0xfa,
		0xa2, 0xe3, 0x3a, 0x5d, 0xd3, 0x7b, 0x9d, 0xf4, 0xc3, 0x5f, 0x7f, 0x2f, 0xed, 0x4b, 0x53, 0xaa,
		0xa8, 0x17, 0x91, 0xf2, 0xa5, 0xd7, 0xef, 0xc8, 0x49, 0x37, 0xbe, 0x54, 0x7d, 0xb6, 0x38, 0x37,
		0xe3, 0x07, 0xaf, 0x4e, 0x9e, 0xbb, 0xbd, 0xf2, 0xb3, 0xbf, 0xfa, 0x46, 0xfb, 0xba, 0x67, 0xfb,
		0xed, 0x9a, 0xdf, 0xf3, 0xdb, 0x97, 0xf3, 0x85, 0x69, 0x98, 0xf2, 0xb9, 0xdd, 0x1c, 0xaf, 0xcb,
		0xe4, 0xef, 0x76, 0x23, 0xd7, 0x18, 0xbf, 0x2a, 0xcf, 0x56, 0x65, 0xf8, 0xde, 0xdd, 0x74, 0x01,
		0x86, 0x9f, 0x59, 0x7f, 0xa7, 0x7d, 0x37, 0x5a, 0x91, 0x77, 0xf1, 0x3c, 0x57, 0x3c, 0x23, 0x33,
		0x9d, 0xd4, 0x21, 0xd3, 0x60, 0x6e, 0x96, 0x98, 0xaa, 0x59, 0xbe, 0x1c, 0xee, 0x3f, 0x2b, 0x04,
		0xa4, 0xae, 0x2d, 0xa7, 0x62, 0x8b, 0x21, 0x65, 0xf0, 0x79, 0xf9, 0x70, 0xea, 0xda, 0xfc, 0xb6,
		0x30, 0x93, 0x5a, 0x6b, 0x3f, 0x55, 0xf7, 0xba, 0xc2, 0x13, 0xdd, 0x8f, 0xc3, 0x5d, 0x73, 0xfa,
		0xb6, 0x1d, 0x2b, 0x61, 0x53, 0xa4, 0x0e, 0x62, 0xa9, 0x06, 0x18, 0x15, 0x40, 0x6c, 0x80, 0x9f,
		0x07, 0xf2, 0xe9, 0x01, 0x99, 0x76, 0x44, 0xe2, 0xd3, 0xc6, 0x7d, 0xca, 0xa2, 0x7f, 0xba, 0x18,
		0x8e, 0x52, 0x54, 0x8f, 0x10, 0xed, 0x89, 0xa1, 0x93, 0x6b, 0x42, 0x99, 0x4e, 0x8d, 0xf9, 0x31,
		0xb5, 0x28, 0x2f, 0x74, 0x2b, 0xa5, 0xa7, 0xdf, 0x33, 0x33, 0x94, 0x78, 0xd8, 0x99, 0xbf, 0x2f,
		0x47, 0x3c, 0x30, 0xa3, 0x5f, 0x4f, 0x81, 0xff, 0x8e, 0xdb, 0x4f, 0xa7, 0xcc, 0x1f, 0xa7, 0xcc,
		0xef, 0xa6, 0xc6, 0xbf, 0x16, 0x6d, 0x3d, 0x79, 0x65, 0xf1, 0x98, 0x24, 0xa9, 0xae, 0xf0, 0xa5,
		0xe5, 0xf0, 0xf2, 0xdc, 0xd9, 0xa9, 0x5a, 0x9c, 0x8c, 0xcb, 0x46, 0x64, 0xbd, 0xd4, 0x60, 0xbf,
		0xc4, 0x50, 0x71, 0x69, 0xa1, 0xf0, 0x92, 0x42, 0xd5, 0xa5, 0x84, 0xf2, 0x4b, 0x08, 0xe5, 0x97,
		0x0e, 0x6a, 0x2f, 0x19, 0xe2, 0xe5, 0x17, 0x62, 0xbf, 0x34, 0x50, 0xdb, 0x6b, 0x47, 0x45, 0x6f,
		0x1d, 0x35, 0xbd, 0x74, 0x14, 0x78, 0xd1, 0x35, 0xf5, 0xca, 0x51, 0xd9, 0x8e, 0x41, 0x79, 0xfb,
		0x85, 0x84, 0xf5, 0xbe, 0x69, 0xa9, 0xd8, 0x22, 0x1d, 0x0d, 0x04, 0x12, 0xd7, 0xcb, 0xa6, 0x15,
		0xe7, 0x0b, 0x44, 0xb5, 0x60, 0x57, 0x04, 0xd8, 0x91, 0x82, 0x1d, 0x9a, 0x6e, 0x24, 0xb1, 0xb7,
		0x4c, 0xe2, 0xa1, 0x1f, 0x62, 0x9b, 0xc8, 0x5e, 0x31, 0xad, 0x98, 0xc6, 0x13, 0xb4, 0x70, 0x29,
		0x46, 0x61, 0xea, 0x1f, 0xd4, 0xa5, 0x18, 0x57, 0x48, 0x51, 0x44, 0xae, 0xc1, 0x18, 0xe2, 0x83,
		0x08, 0xaf, 0xbe, 0xde, 0x45, 0x48, 0xfe, 0xb9, 0xe4, 0x3e, 0x5a, 0xf2, 0x9e, 0x22, 0xbd, 0x6d,
		0x8c, 0x80, 0x84, 0xd3, 0xc8, 0x76, 0x78, 0x49, 0x24, 0x90, 0x42, 0xe2, 0xeb, 0x5b, 0x96, 0x6b,
		0x5b, 0xe2, 0xeb, 0x5a, 0xf2, 0x6b, 0x5a, 0x8e, 0x1b, 0x0c, 0xc6, 0x1b, 0x0b, 0xae, 0x1b, 0x0a,
		0xf6, 0x1b, 0x09, 0xf6, 0x1b, 0x08, 0xde, 0x1b, 0x87, 0x68, 0x69, 0x1e, 0xea, 0xeb, 0xd5, 0x94,
		0xd9, 0x7d, 0xb1, 0x1c, 0x63, 0x78, 0xee, 0xfb, 0x3e, 0x5f, 0x38, 0xc8, 0xd2, 0x2c, 0xd4, 0x37,
		0xce, 0xf3, 0xfa, 0x98, 0x93, 0xcd, 0x97, 0x17, 0xe5, 0xab, 0xeb, 0xea, 0x4d, 0xfb, 0x73, 0x83,
		0x29, 0x02, 0x25, 0xc3, 0x15, 0x81, 0x92, 0x41, 0x04, 0x8a, 0x02, 0xc8, 0x53, 0x06, 0x7d, 0xca,
		0x20, 0x50, 0x0d, 0x14, 0xc6, 0xc3, 0x28, 0x65, 0xbb, 0x64, 0x9d, 0x7b, 0xb5, 0xbb, 0xc2, 0x91,
		0x96, 0x7c, 0xf5, 0x04, 0x47, 0x0a, 0xec, 0x8c, 0x37, 0x31, 0x44, 0xbc, 0xa7, 0xaa, 0x93, 0xaf,
		0xfe, 0xd1, 0xf4, 0x05, 0x7f, 0x18, 0x4d, 0xf3, 0xf3, 0xcd, 0x4d, 0xa5, 0xd6, 0x1e, 0xa3, 0xf1,
		0x5d, 0xb3, 0xdc, 0xfc, 0x7c, 0xc7, 0x75, 0xc2, 0x46, 0x75, 0x02, 0x7c, 0x56, 0xb7, 0x26, 0x73,
		0x64, 0xc8, 0x74, 0xd1, 0xc6, 0xab, 0x75, 0x55, 0xff, 0xf7, 0x0d, 0x63, 0xd8, 0xc4, 0xfb, 0x64,
		0xac, 0xd2, 0xe7, 0x46, 0xdc, 0x42, 0x4b, 0x5a, 0x51, 0x47, 0xe3, 0x48, 0x46, 0x2b, 0x9b, 0x7d,
		0xe9, 0x1a, 0x4f, 0xc2, 0x11, 0x9e, 0x29, 0x45, 0x97, 0x91, 0xa7, 0x2e, 0xcf, 0x03, 0xf6, 0x08,
		0xf6, 0x08, 0xf6, 0x08, 0xf6, 0x48, 0x2a, 0xf1, 0x7c, 0xf9, 0xfb, 0x4c, 0x79, 0xfa, 0xd1, 0x54,
		0x09, 0x1d, 0xb7, 0xef, 0x48, 0xe1, 0x31, 0x3a, 0x2d, 0x66, 0x33, 0xc4, 0x2c, 0x8d, 0x05, 0x6a,
		0x00, 0x6a, 0x00, 0x6a, 0x20, 0xdc, 0x12, 0xb0, 0xa5, 0xb1, 0x3c, 0xbc, 0x4a, 0xe1, 0xf3, 0x5b,
		0xde, 0xe3, 0x69, 0x90, 0xba, 0xa2, 0x1a, 0xd0, 0x14, 0x02, 0x9b, 0x2a, 0x80, 0x53, 0x0e, 0x74,
		0xca, 0x01, 0x4f, 0x2d, 0xf0, 0xf1, 0xfa, 0x17, 0xe2, 0x9f, 0xba, 0x32, 0xa1, 0x5d, 0xac, 0x15,
		0x93, 0x15, 0x54, 0x48, 0x56, 0x54, 0x11, 0x59, 0x41, 0x30, 0xb7, 0xca, 0x8a, 0xc7, 0xaa, 0x6b,
		0x3d, 0x2a, 0xae, 0x68, 0xac, 0xa3, 0x76, 0xac, 0x8a, 0x5a, 0xa4, 0x2a, 0x2b, 0x14, 0xeb, 0x12,
		0x11, 0x7d, 0x15, 0x88, 0xb5, 0x48, 0x0d, 0x02, 0x7b, 0x59, 0xbf, 0x2f, 0xc3, 0xa9, 0x4c, 0x75,
		0xfa, 0x9e, 0x27, 0x1c, 0x39, 0x0a, 0xf1, 0x33, 0xa4, 0xf5, 0xa2, 0xe0, 0x86, 0x6f, 0x7d, 0x4a,
		0xd8, 0x1c, 0xb0, 0x39, 0x60, 0x73, 0xc0, 0xe6, 0x88, 0x95, 0xcd, 0x31, 0x44, 0x2e, 0x69, 0x75,
		0xfe, 0xf6, 0x63, 0x6f, 0x75, 0x7c, 0x76, 0xc6, 0x0c, 0x21, 0xe5, 0x98, 0x8e, 0x3b, 0x2e, 0xe1,
		0xc5, 0x0a, 0x04, 0xb0, 0x72, 0x60, 0xe5, 0xc0, 0xca, 0x81, 0x95, 0x03, 0x2b, 0x07, 0x56, 0x8e,
		0x1a, 0x2b, 0xc7, 0x11, 0xdf, 0xa4, 0xe1, 0x09, 0xb7, 0x27, 0xad, 0x17, 0xeb, 0x7f, 0x47, 0x59,
		0x58, 0x8a, 0x8c, 0x9d, 0xad, 0x33, 0xc3, 0xe6, 0x81, 0xcd, 0x03, 0x9b, 0x07, 0x36, 0x0f, 0x6c,
		0x1e, 0xd8, 0x3c, 0xb0, 0x79, 0x60, 0xf3, 0xc0, 0xe6, 0x81, 0xcd, 0x03, 0x9b, 0x07, 0x36, 0x0f,
		0x99, 0x98, 0xb8, 0x8e, 0x6d, 0x39, 0x42, 0x91, 0x99, 0xb3, 0x38, 0x19, 0x2c, 0x1b, 0x58, 0x36,
		0xb0, 0x6c, 0x60, 0xd9, 0xc0, 0xb2, 0x81, 0x65, 0x03, 0xcb, 0x06, 0x96, 0x0d, 0x2c, 0x1b, 0x58,
		0x36, 0xb0, 0x6c, 0x60, 0xd9, 0x90, 0x89, 0x49, 0xcf, 0xec, 0xfc, 0x2d, 0xa4, 0x82, 0x8c, 0x98,
		0xe9, 0x44, 0xb0, 0x68, 0x60, 0xd1, 0xc0, 0xa2, 0x81, 0x45, 0x13, 0x2b, 0x8b, 0x06, 0x39, 0x31,
		0xb0, 0x2f, 0x60, 0x5f, 0xc0, 0xbe, 0x80, 0x7d, 0x01, 0xfb, 0x02, 0xf6, 0xc5, 0x7e, 0xf6, 0x85,
		0x7c, 0x36, 0x3a, 0xcf, 0x43, 0xbd, 0xa3, 0xc4, 0xc8, 0x58, 0x98, 0x0d, 0x96, 0x06, 0x2c, 0x0d,
		0x58, 0x1a, 0xb0, 0x34, 0x60, 0x69, 0xc0, 0xd2, 0x80, 0xa5, 0x01, 0x4b, 0x03, 0x96, 0x06, 0x2c,
		0x0d, 0x58, 0x1a, 0x89, 0xb5, 0x34, 0x46, 0xbd, 0x53, 0xd4, 0x99, 0x1a, 0xcb, 0xd3, 0xc1, 0xd6,
		0x80, 0xad, 0x01, 0x5b, 0x03, 0xb6, 0x06, 0x6c, 0x0d, 0xd8, 0x1a, 0xb0, 0x35, 0x60, 0x6b, 0xc0,
		0xd6, 0x80, 0xad, 0x01, 0x5b, 0x23, 0x1a, 0xb6, 0x06, 0x5a, 0xf8, 0x6a, 0x68, 0x69, 0x3a, 0x32,
		0x8f, 0xd2, 0x4c, 0x25, 0xdc, 0x8f, 0xf4, 0xf4, 0x34, 0x1d, 0x75, 0xe8, 0x6d, 0x5f, 0x4e, 0x9f,
		0xe9, 0x00, 0x8a, 0xfc, 0x77, 0x85, 0xdf, 0xf1, 0xac, 0x1e, 0x8b, 0x78, 0xce, 0x68, 0xe8, 0xe2,
		0x24, 0xe8, 0xf8, 0x82, 0x52, 0xff, 0xfa, 0xed, 0x62, 0x94, 0xfa, 0x57, 0xa8, 0x01, 0xf9, 0x3b,
		0xbe, 0xf8, 0xd2, 0xb3, 0x9c, 0x27, 0xce, 0x86, 0x2f, 0x67, 0x07, 0xa0, 0x0b, 0x9e, 0x5d, 0xbb,
		0x6b, 0xf4, 0x3c, 0xcb, 0xf5, 0x2c, 0xf9, 0xca, 0xa7, 0x0d, 0x96, 0xa7, 0xe1, 0xeb, 0x55, 0x9b,
		0x81, 0xae, 0x51, 0xa2, 0x6b, 0x3c, 0xff, 0x6b, 0x0f, 0xba, 0x26, 0x82, 0xba, 0x66, 0xb4, 0x31,
		0xd0, 0x35, 0xc4, 0x12, 0xdf, 0xb7, 0x1c, 0x79, 0xc6, 0xa8, 0x6a, 0x38, 0x9a, 0xd2, 0xf2, 0xfa,
		0x4f, 0x19, 0x1d, 0xd9, 0x2a, 0xfc, 0xa5, 0x8a, 0x9c, 0x60, 0xaa, 0xfc, 0xa3, 0x2a, 0x3d, 0x5c,
		0x8c, 0xfe, 0x50, 0x25, 0x7e, 0x50, 0xd5, 0x5b, 0x5f, 0x4a, 0xd0, 0xd6, 0xc7, 0xc4, 0x39, 0xd8,
		0x3a, 0x00, 0xe2, 0xfe, 0x22, 0xa4, 0x67, 0x75, 0xf8, 0x18, 0xfb, 0x64, 0x7c, 0xd0, 0x69, 0xb8,
		0x6e, 0xe0, 0xba, 0x01, 0x9d, 0x26, 0x95, 0x78, 0xcb, 0x91, 0xa7, 0x39, 0x46, 0x3a, 0x7d, 0x0a,
		0x3a, 0xad, 0x87, 0x4e, 0x67, 0x15, 0x71, 0xaa, 0x5c, 0x36, 0x5f, 0xca, 0x9f, 0x9d, 0x16, 0xf3,
		0x67, 0xe0, 0xd5, 0x87, 0xca, 0xab, 0x67, 0x32, 0x00, 0x82, 0x0d, 0x82, 0xcd, 0x46, 0xb0, 0x0d,
		0xc9, 0xa1, 0x0d, 0x57, 0x58, 0xf6, 0x78, 0x12, 0x3e, 0xaf, 0xf8, 0x84, 0xc8, 0xc8, 0x8b, 0xda,
		0x5d, 0xa3, 0x7d, 0x5d, 0x69, 0xde, 0x56, 0x2f, 0xdb, 0xd5, 0x9b, 0x5f, 0x2b, 0xb7, 0xd5, 0x66,
		0xe5, 0x0a, 0x14, 0x1f, 0x14, 0x1f, 0x14, 0x1f, 0x14, 0x9f, 0x98, 0xe2, 0x77, 0x85, 0x23, 0x2d,
		0xf9, 0xea, 0x89, 0x47, 0xce, 0x2b, 0x5a, 0x0e, 0xc7, 0x79, 0x75, 0xf2, 0xd5, 0x3f, 0x9a, 0xbe,
		0x82, 0xba, 0xc0, 0x0b, 0x90, 0xdc, 0xfc, 0xb3, 0x51, 0xe1, 0x3a, 0x5d, 0x23, 0xd6, 0xe4, 0xb3,
		0x86, 0x53, 0x33, 0xd3, 0xcb, 0x0d, 0x0b, 0x36, 0xd7, 0x61, 0x71, 0x64, 0xe5, 0xea, 0xd7, 0xeb,
		0xb6, 0x52, 0x2b, 0x37, 0xab, 0xbf, 0x57, 0xb0, 0x5c, 0x3b, 0x2d, 0x57, 0xf9, 0xe3, 0x5d, 0xbd,
		0xf6, 0xb9, 0x59, 0x89, 0x5b, 0x0e, 0x4b, 0x2b, 0xea, 0xda, 0x2c, 0x92, 0x7c, 0x7f, 0x12, 0x73,
		0xca, 0x44, 0xf4, 0x47, 0xa3, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x83, 0x69, 0x93, 0x4a, 0x3c,
		0xe2, 0x20, 0x29, 0x9e, 0xd5, 0xed, 0x09, 0xcf, 0xf0, 0xa5, 0x29, 0xfb, 0x3e, 0x9f, 0x12, 0x58,
		0x9c, 0x04, 0xba, 0x00, 0xba, 0x00, 0xba, 0x00, 0xba, 0x00, 0x5e, 0x17, 0x5d, 0x5e, 0x97, 0x7a,
		0xa3, 0x72, 0xdb, 0xbe, 0x6b, 0x96, 0x9b, 0x9f, 0xef, 0xe0, 0x75, 0xf9, 0xd9, 0x82, 0x5d, 0xd5,
		0xff, 0x7d, 0x03, 0xb7, 0xc1, 0xf6, 0xf5, 0xf9, 0xdc, 0x80, 0x97, 0xe0, 0x10, 0xbc, 0x04, 0x43,
		0x6d, 0x2c, 0x3c, 0xe1, 0x74, 0x18, 0x7d, 0x05, 0x0b, 0x73, 0x80, 0x25, 0x82, 0x25, 0x82, 0x25,
		0x82, 0x25, 0x92, 0x4a, 0x3c, 0xb2, 0x59, 0xd4, 0x91, 0x84, 0x44, 0x66, 0xb3, 0x64, 0x11, 0x75,
		0xb7, 0xd3, 0xd6, 0x27, 0x31, 0xea, 0xae, 0x50, 0x40, 0xb8, 0x9d, 0xea, 0x51, 0x5b, 0x07, 0x41,
		0xac, 0x5d, 0x29, 0x46, 0x1b, 0x6f, 0xf8, 0xf2, 0xd5, 0x16, 0x86, 0x27, 0xfe, 0xa7, 0x2f, 0x7c,
		0x29, 0xba, 0x9c, 0x44, 0x7b, 0xeb, 0x9c, 0x0a, 0x82, 0xf1, 0x3e, 0xdf, 0x34, 0x6e, 0xeb, 0xcd,
		0xca, 0x25, 0x62, 0xf0, 0xc0, 0xf3, 0xc1, 0xf3, 0xc1, 0xf3, 0xc9, 0x25, 0x1e, 0xde, 0xe0, 0x1d,
		0x17, 0x6a, 0x82, 0xc3, 0xd5, 0xfa, 0x0d, 0x62, 0xf0, 0x76, 0x5a, 0xb0, 0x5a, 0xf5, 0xe6, 0xb7,
		0xf6, 0x4d, 0xfd, 0xaa, 0xd2, 0x5e, 0x58, 0xba, 0xdb, 0xca, 0x7f, 0x7d, 0xae, 0xdc, 0x21, 0x1a,
		0xef, 0x87, 0x2b, 0xb7, 0xa8, 0xf4, 0xb1, 0x4c, 0x3f, 0x16, 0xb0, 0x15, 0xd9, 0xaa, 0xde, 0xb2,
		0xae, 0x19, 0x9c, 0xec, 0x91, 0xb1, 0x05, 0x3c, 0xe1, 0xf6, 0xa4, 0xf5, 0x62, 0xfd, 0xaf, 0x30,
		0xa4, 0xf5, 0x22, 0x3c, 0x3e, 0x0b, 0x60, 0x6d, 0x26, 0x10, 0x71, 0x10, 0x71, 0x10, 0x71, 0x10,
		0x71, 0x52, 0x89, 0xef, 0x5b, 0x8e, 0xcc, 0x16, 0x19, 0x39, 0x78, 0x11, 0x1e, 0xf7, 0xf9, 0x17,
		0x47, 0xfd, 0xa8, 0xfd, 0xe7, 0x81, 0xc7, 0x3d, 0xb2, 0x5b, 0x5f, 0x2c, 0x14, 0x4e, 0xe1, 0x73,
		0x57, 0x3e, 0xea, 0x21, 0xf8, 0xdc, 0x3d, 0xd7, 0x66, 0x0c, 0x63, 0x19, 0x8d, 0x0e, 0x3e, 0x0d,
		0x3e, 0x0d, 0x3e, 0x0d, 0x3e, 0x4d, 0x2a, 0xf1, 0x70, 0x6c, 0xef, 0xb8, 0x50, 0xb5, 0xbb, 0x46,
		0xfb, 0xb6, 0x5e, 0x83, 0x47, 0xfb, 0xa7, 0x2b, 0x55, 0xbd, 0xf9, 0xe5, 0xb6, 0x72, 0x77, 0x07,
		0x9f, 0xec, 0xf6, 0x25, 0x6a, 0xde, 0x96, 0x6f, 0xee, 0xaa, 0x4d, 0x2c, 0xd1, 0xf6, 0x25, 0xaa,
		0x70, 0x0b, 0x11, 0x9c, 0xd4, 0x91, 0x21, 0xcf, 0xbe, 0x90, 0xfd, 0x9e, 0x82, 0xd6, 0x09, 0x2b,
		0xf3, 0xf0, 0x05, 0xa6, 0x94, 0x40, 0xd6, 0xd1, 0x3b, 0xe1, 0x90, 0xc9, 0x3a, 0x7a, 0x27, 0x70,
		0x48, 0x3c, 0xa2, 0xcd, 0xd5, 0x91, 0x11, 0xf8, 0xbe, 0x03, 0xcc, 0x03, 0xdf, 0x77, 0x64, 0xb7,
		0x1e, 0xa5, 0x5d, 0x95, 0x8f, 0x7a, 0x08, 0x7e, 0x6f, 0xff, 0xd9, 0xf5, 0x64, 0xa7, 0x2f, 0x0d,
		0x61, 0x5b, 0x4f, 0xd6, 0x03, 0xa7, 0x13, 0x7c, 0x7d, 0x2a, 0x3e, 0x02, 0x3f, 0x64, 0x4a, 0xe0,
		0xf0, 0x70, 0xb8, 0x1f, 0x32, 0x87, 0x87, 0xc3, 0x9d, 0x43, 0xe2, 0x1f, 0x5c, 0xd7, 0x16, 0xa6,
		0xc3, 0xe9, 0x6c, 0xcf, 0x1e, 0x82, 0xde, 0xb1, 0x9e, 0x1c, 0xd3, 0xb6, 0x9c, 0x27, 0xa3, 0xe7,
		0xb9, 0xd2, 0xed, 0xb8, 0x36, 0xa3, 0xe2, 0x59, 0x9f, 0x0b, 0xaa, 0x01, 0xaa, 0x01, 0xaa, 0x01,
		0xaa, 0x81, 0x54, 0xe2, 0x71, 0x17, 0xbb, 0xe3, 0x42, 0x35, 0xca, 0xcd, 0x5f, 0xdb, 0x77, 0x95,
		0xe6, 0xe7, 0xc6, 0x28, 0xb1, 0xa1, 0x7e, 0x59, 0xaf, 0xe1, 0x5a, 0x76, 0x8f, 0x45, 0xbb, 0xbb,
		0xc5, 0xcd, 0xe3, 0x4e, 0x0b, 0x55, 0xbb, 0x6a, 0x60, 0xa5, 0x76, 0x5a, 0xa9, 0xdb, 0xbb, 0xdf,
		0x51, 0xb6, 0xeb, 0x30, 0x2e, 0x6b, 0xdd, 0x47, 0x69, 0xf4, 0x3c, 0x21, 0x5e, 0x7a, 0xd2, 0x72,
		0x1d, 0x46, 0xda, 0xbd, 0x32, 0x11, 0x9f, 0xb7, 0xe7, 0xd1, 0xb4, 0x7d, 0xb8, 0x7b, 0x70, 0x65,
		0x7b, 0xd0, 0x9c, 0x1e, 0x57, 0xb6, 0x70, 0xf7, 0x44, 0x58, 0xe9, 0xb0, 0x9c, 0xee, 0x05, 0x5d,
		0x33, 0x1a, 0x1f, 0x2a, 0x00, 0x2a, 0x00, 0x2a, 0x00, 0x2a, 0x80, 0xd6, 0xad, 0xd3, 0x33, 0xcc,
		0x6e, 0xd7, 0x13, 0xbe, 0xcf, 0xa9, 0x05, 0xce, 0x19, 0xc6, 0x9e, 0xac, 0x4d, 0xec, 0x42, 0x77,
		0xe6, 0x2b, 0xff, 0x35, 0xcf, 0xb8, 0xf6, 0x6b, 0x7b, 0xc0, 0xd8, 0x42, 0x39, 0xd5, 0x30, 0xa5,
		0x14, 0x9e, 0xc3, 0xea, 0x89, 0x1a, 0x4d, 0x74, 0x7c, 0x7c, 0x9f, 0x31, 0xce, 0x5b, 0x6f, 0xf7,
		0x59, 0xe3, 0xbc, 0x35, 0x7e, 0x99, 0x1d, 0xfd, 0x35, 0x7e, 0x9d, 0xbb, 0xcf, 0x18, 0xf9, 0xe9,
		0xeb, 0xc2, 0x7d, 0xc6, 0x28, 0xb4, 0x4e, 0xbe, 0x7c, 0xf9, 0x70, 0xf2, 0xfd, 0x74, 0xb0, 0xff,
		0x07, 0xf9, 0x3c, 0x06, 0x2d, 0xce, 0xad, 0xa8, 0xdf, 0x55, 0xff, 0x50, 0xb6, 0x1f, 0x7f, 0xa9,
		0xdc, 0x90, 0x7f, 0x31, 0xee, 0xc8, 0xbb, 0x18, 0x39, 0xd1, 0xd4, 0x80, 0x53, 0x11, 0xe0, 0x14,
		0x08, 0x9c, 0x4c, 0xe3, 0xb1, 0x6c, 0x7c, 0x6a, 0x7d, 0xcf, 0xbe, 0xcf, 0x0f, 0x2e, 0x4e, 0xbe,
		0x97, 0x06, 0xab, 0x6f, 0xbe, 0x6d, 0xfa, 0xb5, 0xec, 0xfb, 0xd2, 0xe0, 0x62, 0xcb, 0xbf, 0x14,
		0x07, 0x17, 0x3b, 0x8e, 0x51, 0x18, 0x1c, 0xaf, 0xfd, 0xea, 0xf0, 0xfd, 0xdc, 0xb6, 0x0f, 0xe4,
		0xb7, 0x7c, 0xe0, 0x74, 0xdb, 0x07, 0x4e, 0xb7, 0x7c, 0x60, 0xeb, 0x57, 0xca, 0x6d, 0xf9, 0x40,
		0x61, 0xf0, 0xb6, 0xf6, 0xfb, 0xc7, 0x9b, 0x7f, 0xb5, 0x38, 0x38, 0x79, 0xdb, 0xf6, 0x6f, 0xa5,
		0xc1, 0xdb, 0xc5, 0x09, 0xa0, 0x7a, 0x77, 0xa8, 0x86, 0x78, 0xaa, 0x17, 0xcf, 0xf8, 0x29, 0x2e,
		0x84, 0x9b, 0x06, 0x38, 0x61, 0x92, 0xc3, 0x5a, 0x9b, 0xa9, 0xe4, 0xd1, 0xe8, 0xf0, 0x01, 0x21,
		0xb4, 0xe7, 0x80, 0x7d, 0x40, 0x08, 0xed, 0x61, 0x21, 0xfb, 0x08, 0xed, 0xd9, 0x6d, 0xa1, 0x9a,
		0x9f, 0x6f, 0x6e, 0x2a, 0x35, 0xd4, 0x0e, 0xde, 0x69, 0xb1, 0x1a, 0xb9, 0x6b, 0xc4, 0xa7, 0xfc,
		0x70, 0x7d, 0x10, 0x93, 0x12, 0xdd, 0x98, 0x94, 0x77, 0x11, 0x12, 0xd2, 0x54, 0xd9, 0x71, 0x5c,
		0x69, 0x92, 0x07, 0xb4, 0xa4, 0xfc, 0xce, 0xb3, 0x78, 0x31, 0x7b, 0xa6, 0x7c, 0x1e, 0x0a, 0x64,
		0xda, 0xed, 0x09, 0xa7, 0x33, 0xa2, 0x6e, 0x86, 0x23, 0xe4, 0x3f, 0xae, 0xf7, 0xb7, 0x61, 0x39,
		0xbe, 0x34, 0x9d, 0x8e, 0x48, 0xaf, 0xbe, 0xe1, 0xaf, 0xbd, 0x93, 0x1e, 0x2a, 0xe7, 0xb4, 0xed,
		0xf7, 0xfc, 0x74, 0xc7, 0x75, 0x7c, 0xe9, 0x99, 0x96, 0x23, 0xba, 0xc6, 0x70, 0xf4, 0xb4, 0xec,
		0x3b, 0x8e, 0xb0, 0xfd, 0xc9, 0xdf, 0x69, 0x5f, 0x9a, 0x92, 0x92, 0xcb, 0xa6, 0x7c, 0xe9, 0xf5,
		0x3b, 0x72, 0xd2, 0xd9, 0x3f, 0x55, 0x9f, 0x3d, 0xc7, 0xcd, 0xf8, 0x3b, 0x56, 0x27, 0x5f, 0xb1,
		0xbd, 0xf2, 0xb3, 0xbf, 0xfa, 0x46, 0xfb, 0xba, 0x67, 0xfb, 0xed, 0x9a, 0xdf, 0xf3, 0xdb, 0x97,
		0xf3, 0x67, 0x68, 0x98, 0xf2, 0xb9, 0xdd, 0x1c, 0x3f, 0xc2, 0xe4, 0xef, 0xf6, 0xdd, 0xe8, 0x11,
		0xde, 0x45, 0x43, 0xd6, 0xc2, 0x8d, 0x10, 0x52, 0x4a, 0x87, 0xac, 0x73, 0xb8, 0xea, 0xa3, 0xd5,
		0x0f, 0x39, 0x54, 0xcd, 0xf2, 0x65, 0x59, 0x4a, 0x9a, 0x42, 0xd0, 0xa9, 0x6b, 0xcb, 0xa9, 0xd8,
		0x62, 0x48, 0x1f, 0x7d, 0x1a, 0x5b, 0x24, 0x75, 0x6d, 0x7e, 0x5b, 0x18, 0x31, 0x7b, 0x96, 0xcf,
		0x17, 0x4b, 0xf9, 0x7c, 0xa6, 0x74, 0x5a, 0xca, 0x9c, 0x17, 0x0a, 0xd9, 0x22, 0x05, 0xc7, 0x49,
		0xd5, 0xbd, 0xae, 0xf0, 0x44, 0xf7, 0xe3, 0x70, 0x55, 0x9d, 0xbe, 0x6d, 0x6b, 0xdd, 0x5c, 0x62,
		0xe8, 0xd1, 0x05, 0x39, 0x04, 0x60, 0xa3, 0x1e, 0x64, 0xc2, 0xc1, 0x4b, 0x70, 0x50, 0x08, 0xf6,
		0xc9, 0x80, 0x92, 0x46, 0x25, 0x61, 0xca, 0x25, 0x2b, 0x84, 0x48, 0x29, 0x14, 0xa5, 0x60, 0x32,
		0xb4, 0xbf, 0x04, 0xec, 0xf7, 0x89, 0x3d, 0x65, 0x25, 0xac, 0x8c, 0x28, 0x93, 0x8d, 0x00, 0x32,
		0xa1, 0x40, 0x16, 0xf6, 0x93, 0x81, 0xdd, 0x77, 0x72, 0x8f, 0x5d, 0x4c, 0x0d, 0x29, 0x9f, 0xd5,
		0x31, 0x86, 0xab, 0xb6, 0xf7, 0x16, 0xce, 0x03, 0xe1, 0x16, 0x06, 0xd9, 0x53, 0x82, 0xa6, 0x4e,
		0x88, 0x3d, 0x3f, 0x16, 0xd4, 0x93, 0x19, 0xc6, 0x53, 0x49, 0xe0, 0x89, 0x0c, 0xeb, 0x69, 0x24,
		0xf3, 0x24, 0x92, 0x79, 0x0a, 0x69, 0x3c, 0x81, 0xbc, 0x28, 0x75, 0x65, 0x79, 0x01, 0xe1, 0x69,
		0x26, 0xd7, 0xc1, 0x77, 0x6c, 0xfd, 0x8c, 0x04, 0xdd, 0xb2, 0x60, 0x47, 0x25, 0xf4, 0x91, 0xa1,
		0x38, 0x3a, 0x6b, 0xab, 0x11, 0xd2, 0x93, 0x4f, 0xe5, 0xb1, 0x27, 0xf7, 0xcc, 0x93, 0x7b, 0xe0,
		0x97, 0xce, 0x57, 0x38, 0x37, 0xbb, 0x5a, 0xfa, 0x18, 0xf4, 0xd0, 0xcd, 0x06, 0xe8, 0x4c, 0xe5,
		0x35, 0xe4, 0x16, 0x4f, 0x45, 0x6e, 0x32, 0x5e, 0x58, 0xa3, 0x3a, 0xd4, 0x21, 0x24, 0x3b, 0x8c,
		0x94, 0x87, 0x92, 0xfa, 0x70, 0x52, 0x1f, 0x52, 0xb6, 0xc3, 0xca, 0x76, 0x68, 0x19, 0x0e, 0x6f,
		0x34, 0x5c, 0x4a, 0x61, 0x0f, 0xf5, 0x6c, 0xa0, 0x09, 0xad, 0x26, 0x12, 0x8c, 0xa9, 0xe0, 0x12,
		0xb8, 0xba, 0x56, 0x0f, 0x3a, 0xd1, 0x4d, 0x39, 0xf9, 0xd5, 0x3b, 0xc7, 0x95, 0x3b, 0x35, 0x00,
		0x70, 0x01, 0x01, 0x3b, 0x20, 0xb0, 0x03, 0x03, 0x23, 0x40, 0xd0, 0x79, 0xaf, 0x8f, 0x08, 0x6f,
		0x4a, 0xc8, 0x2f, 0xcb, 0x17, 0x78, 0xb5, 0x67, 0x39, 0x4f, 0x94, 0xd2, 0x3a, 0x8b, 0x7d, 0xc5,
		0x2d, 0x42, 0x8c, 0x1c, 0xcd, 0x0b, 0x3e, 0x88, 0x85, 0xd7, 0x69, 0x12, 0xd6, 0xc7, 0xe5, 0x0f,
		0xba, 0x1b, 0x7d, 0xcf, 0xe5, 0x97, 0xed, 0x89, 0xa6, 0xd0, 0xe5, 0x63, 0x0e, 0x61, 0x94, 0x89,
		0xa7, 0x51, 0x58, 0x3a, 0x19, 0x63, 0x9f, 0x8c, 0x07, 0xc6, 0x0e, 0xc6, 0x0e, 0xc6, 0xae, 0x9b,
		0xb1, 0x13, 0x99, 0xe3, 0x3c, 0x66, 0x39, 0xf1, 0x61, 0x07, 0x6b, 0x07, 0x6b, 0x07, 0x6b, 0xa7,
		0x03, 0x8f, 0xd9, 0x80, 0x96, 0xd3, 0x71, 0x5f, 0x2c, 0xe7, 0xc9, 0xb0, 0xcd, 0x07, 0xc1, 0x58,
		0x7c, 0x73, 0x65, 0x1e, 0x44, 0xe7, 0xb3, 0x47, 0xe7, 0x23, 0x34, 0x5f, 0x33, 0x28, 0x29, 0x00,
		0x27, 0x5a, 0x90, 0x22, 0x06, 0x2b, 0x3e, 0x57, 0xc3, 0x46, 0x59, 0x67, 0x41, 0x96, 0x23, 0xd4,
		0x66, 0xf8, 0xf1, 0xca, 0xf7, 0x2d, 0x47, 0x9e, 0xe6, 0x14, 0x24, 0x3e, 0x33, 0x36, 0xbe, 0x60,
		0x6e, 0x6e, 0xc3, 0xbf, 0x1b, 0xb3, 0x07, 0x51, 0xd1, 0xec, 0x86, 0x59, 0xe9, 0x6e, 0x9d, 0x6e,
		0xda, 0x01, 0x25, 0x5b, 0x54, 0x34, 0xa1, 0xc2, 0x56, 0x28, 0x4c, 0xc8, 0xbb, 0x59, 0x46, 0x14,
		0x74, 0xc5, 0xd1, 0x2e, 0x23, 0x99, 0xfc, 0x59, 0xa1, 0x54, 0x48, 0xb0, 0xa0, 0xbc, 0x8b, 0xe7,
		0xe8, 0xa8, 0x1e, 0xb2, 0xac, 0x3e, 0x85, 0xd3, 0x7f, 0x11, 0x9e, 0xc9, 0x50, 0x18, 0x75, 0x23,
		0x83, 0xc9, 0x33, 0xce, 0x51, 0x71, 0xfa, 0x2f, 0x43, 0x60, 0x41, 0x5b, 0xa7, 0xc8, 0x08, 0x73,
		0xca, 0x11, 0xdf, 0xa4, 0xf1, 0xec, 0xf6, 0xf8, 0xec, 0xfa, 0xd9, 0x0c, 0xb0, 0xe8, 0x61, 0xd1,
		0xc3, 0xa2, 0x87, 0x45, 0x4f, 0x24, 0xeb, 0xa8, 0xb6, 0xa8, 0x8b, 0x92, 0xa0, 0xda, 0x62, 0x80,
		0x89, 0x50, 0x6d, 0xf1, 0xa7, 0x5b, 0x81, 0x6a, 0x8b, 0xb0, 0x97, 0x28, 0xc0, 0x09, 0xd5, 0x16,
		0x83, 0x81, 0x13, 0xca, 0xd9, 0xa1, 0xda, 0x62, 0x84, 0xa1, 0x1a, 0xe2, 0x89, 0x6a, 0x8b, 0xf0,
		0x02, 0xb1, 0x78, 0x81, 0x7a, 0x7d, 0xff, 0x99, 0x3b, 0xbe, 0x63, 0x61, 0x0e, 0x78, 0x82, 0xe0,
		0x09, 0x82, 0x27, 0x08, 0x9e, 0x20, 0x42, 0x59, 0x47, 0x6c, 0x87, 0x0e, 0x63, 0x0b, 0xb1, 0x1d,
		0x11, 0xd8, 0x8d, 0xd9, 0x83, 0x20, 0xb6, 0x83, 0x70, 0x42, 0xc4, 0x76, 0xc4, 0x57, 0x46, 0x10,
		0xdb, 0x11, 0xcd, 0xd1, 0xe1, 0xab, 0x5c, 0x56, 0x9f, 0x88, 0xed, 0x80, 0x55, 0xcf, 0x32, 0xd2,
		0xa1, 0x16, 0xcb, 0xdd, 0x92, 0x50, 0x3c, 0x4e, 0x4a, 0x4d, 0x93, 0xa6, 0xad, 0x1d, 0xa9, 0xcc,
		0x2f, 0xae, 0x8c, 0x1e, 0x80, 0x24, 0xcd, 0x98, 0x4e, 0xd0, 0x06, 0x24, 0x09, 0xda, 0xa6, 0x64,
		0x28, 0x2a, 0x42, 0x59, 0x14, 0x99, 0x2d, 0x3f, 0x31, 0x87, 0xfc, 0xc4, 0xd8, 0xb8, 0x8d, 0x90,
		0x9f, 0x88, 0xfc, 0x44, 0xe4, 0x27, 0xf2, 0x82, 0x0e, 0x37, 0xf8, 0x70, 0x83, 0x90, 0x32, 0x30,
		0x52, 0x06, 0x4a, 0x0a, 0xc0, 0x89, 0x87, 0xe1, 0xc3, 0x87, 0xbd, 0x99, 0xc2, 0xc0, 0x87, 0xbd,
		0xbe, 0xf2, 0xf0, 0x61, 0x47, 0x60, 0x37, 0x66, 0x0f, 0x02, 0x1f, 0x36, 0xe1, 0x84, 0xf0, 0x61,
		0xc7, 0x57, 0x46, 0xe0, 0xc3, 0x8e, 0xe6, 0xe8, 0xf0, 0x61, 0x2f, 0xab, 0x4f, 0xf8, 0xb0, 0xb5,
		0x89, 0x24, 0xf2, 0x13, 0x29, 0x04, 0x18, 0xf9, 0x89, 0xb0, 0xe8, 0x61, 0xd1, 0xc3, 0xa2, 0xa7,
		0x96, 0x75, 0xe4, 0x27, 0xea, 0xa2, 0x24, 0xc8, 0x4f, 0x0c, 0x30, 0x11, 0xf2, 0x13, 0x7f, 0xba,
		0x15, 0xc8, 0x4f, 0x84, 0xbd, 0x44, 0x01, 0x4e, 0xc8, 0x4f, 0x0c, 0x06, 0x4e, 0x48, 0x00, 0x43,
		0x7e, 0x62, 0x84, 0xa1, 0x1a, 0xe2, 0x89, 0xfc, 0x44, 0x78, 0x81, 0x58, 0xbc, 0x40, 0xc8, 0x4f,
		0x84, 0x27, 0x08, 0x9e, 0x20, 0x78, 0x82, 0x8e, 0x10, 0xdb, 0x01, 0x4f, 0xd0, 0x1e, 0x2b, 0x8f,
		0xd8, 0x8e, 0x08, 0xec, 0xc6, 0xec, 0x41, 0x10, 0xdb, 0x41, 0x38, 0x21, 0x62, 0x3b, 0xe2, 0x2b,
		0x23, 0x88, 0xed, 0x88, 0xe6, 0xe8, 0xf0, 0x55, 0x2e, 0xab, 0x4f, 0xc4, 0x76, 0xc0, 0xaa, 0x67,
		0x19, 0x09, 0xf9, 0x89, 0x9b, 0xf2, 0x13, 0x29, 0xb3, 0xd6, 0x8e, 0x34, 0xa4, 0x27, 0xde, 0x8d,
		0xbe, 0x3f, 0x3a, 0xf0, 0xc6, 0xbf, 0x03, 0x2f, 0x49, 0x17, 0x57, 0x0d, 0x22, 0x18, 0xc7, 0x0e,
		0xbc, 0x96, 0x43, 0xdc, 0x82, 0x77, 0x3a, 0x20, 0x7a, 0xf0, 0xee, 0xe4, 0x99, 0x41, 0x0f, 0xde,
		0x68, 0x7a, 0x11, 0xd1, 0x83, 0xf7, 0x87, 0xa2, 0x8b, 0x1e, 0xbc, 0x11, 0x03, 0x01, 0x2e, 0x30,
		0x60, 0x07, 0x05, 0x76, 0x70, 0x60, 0x04, 0x89, 0x68, 0x9a, 0x25, 0xc8, 0x71, 0x57, 0xe8, 0x6e,
		0xc3, 0x3d, 0xa8, 0x42, 0x10, 0x52, 0x06, 0x46, 0xca, 0x40, 0x49, 0x01, 0x38, 0xf1, 0x78, 0x89,
		0x70, 0x0f, 0xba, 0x99, 0xc2, 0xe0, 0x1e, 0x74, 0x7d, 0xe5, 0x71, 0x0f, 0x1a, 0x81, 0xdd, 0x98,
		0x3d, 0x08, 0xee, 0x41, 0x09, 0x27, 0xc4, 0x3d, 0x68, 0x7c, 0x65, 0x04, 0xf7, 0xa0, 0xd1, 0x1c,
		0x1d, 0xf7, 0xa0, 0xcb, 0xea, 0x13, 0xf7, 0xa0, 0xda, 0x44, 0x12, 0x39, 0xee, 0x14, 0x02, 0x8c,
		0x1c, 0x77, 0x58, 0xf4, 0xb0, 0xe8, 0x61, 0xd1, 0x53, 0xcb, 0x3a, 0x72, 0xdc, 0x75, 0x51, 0x12,
		0xe4, 0xb8, 0x07, 0x98, 0x08, 0x39, 0xee, 0x3f, 0xdd, 0x0a, 0xe4, 0xb8, 0xc3, 0x5e, 0xa2, 0x00,
		0x27, 0xe4, 0xb8, 0x07, 0x03, 0x27, 0x24, 0x11, 0x23, 0xc7, 0x3d, 0xc2, 0x50, 0x0d, 0xf1, 0x44,
		0x8e, 0x3b, 0xbc, 0x40, 0x2c, 0x5e, 0x20, 0xe4, 0xb8, 0xc3, 0x13, 0x04, 0x4f, 0x10, 0x3c, 0x41,
		0x47, 0x88, 0xed, 0x80, 0x27, 0x68, 0x8f, 0x95, 0x47, 0x6c, 0x47, 0x04, 0x76, 0x63, 0xf6, 0x20,
		0x88, 0xed, 0x20, 0x9c, 0x10, 0xb1, 0x1d, 0xf1, 0x95, 0x11, 0xc4, 0x76, 0x44, 0x73, 0x74, 0xf8,
		0x2a, 0x97, 0xd5, 0x27, 0x62, 0x3b, 0x60, 0xd5, 0xb3, 0x8c, 0x84, 0x1c, 0xf7, 0xa5, 0x94, 0xe2,
		0x49, 0x56, 0x6a, 0x8c, 0x9b, 0xf0, 0x56, 0x1d, 0x74, 0xe1, 0xdd, 0x0b, 0x5a, 0xd1, 0x85, 0x37,
		0x9a, 0x8e, 0x24, 0x64, 0x28, 0x6a, 0x70, 0x14, 0x21, 0x43, 0x91, 0xe4, 0x28, 0x20, 0x43, 0x91,
		0x19, 0x74, 0xb8, 0xc1, 0x87, 0x1b, 0x84, 0x94, 0x81, 0x91, 0x32, 0x50, 0x52, 0x00, 0x4e, 0x3c,
		0x1c, 0x1f, 0x5e, 0xec, 0xcd, 0x14, 0x06, 0x5e, 0xec, 0xf5, 0x95, 0x87, 0x17, 0x3b, 0x02, 0xbb,
		0x31, 0x7b, 0x10, 0x78, 0xb1, 0x09, 0x27, 0x84, 0x17, 0x3b, 0xbe, 0x32, 0x02, 0x2f, 0x76, 0x34,
		0x47, 0x87, 0x17, 0x7b, 0x59, 0x7d, 0xc2, 0x8b, 0xad, 0x4d, 0x24, 0x91, 0xa1, 0x48, 0x21, 0xc0,
		0xc8, 0x50, 0x84, 0x45, 0x0f, 0x8b, 0x1e, 0x16, 0x3d, 0xb5, 0xac, 0x23, 0x43, 0x51, 0x17, 0x25,
		0x41, 0x86, 0x62, 0x80, 0x89, 0x90, 0xa1, 0xf8, 0xd3, 0xad, 0x40, 0x86, 0x22, 0xec, 0x25, 0x0a,
		0x70, 0x42, 0x86, 0x62, 0x30, 0x70, 0x42, 0x0a, 0x18, 0x32, 0x14, 0x23, 0x0c, 0xd5, 0x10, 0x4f,
		0x64, 0x28, 0xc2, 0x0b, 0xc4, 0xe2, 0x05, 0x42, 0x86, 0x22, 0x3c, 0x41, 0xf0, 0x04, 0xc1, 0x13,
		0x74, 0x84, 0xd8, 0x0e, 0x78, 0x82, 0xf6, 0x58, 0x79, 0xc4, 0x76, 0x44, 0x60, 0x37, 0x66, 0x0f,
		0x82, 0xd8, 0x0e, 0xc2, 0x09, 0x11, 0xdb, 0x11, 0x5f, 0x19, 0x41, 0x6c, 0x47, 0x34, 0x47, 0x87,
		0xaf, 0x72, 0x59, 0x7d, 0x22, 0xb6, 0x03, 0x56, 0x3d, 0xcb, 0x48, 0xc8, 0x50, 0xdc, 0x98, 0xa1,
		0x18, 0xdb, 0x36, 0xbc, 0xd3, 0x04, 0x45, 0xf4, 0xe1, 0xe5, 0x12, 0x4d, 0x4d, 0x22, 0x19, 0xa7,
		0x46, 0xbc, 0x13, 0x21, 0x8c, 0x63, 0x27, 0xde, 0xc9, 0xe2, 0x10, 0xb5, 0xe1, 0x1d, 0x8d, 0x46,
		0xd3, 0x83, 0x37, 0x83, 0x1e, 0xbc, 0x3f, 0x1f, 0x0f, 0x3d, 0x78, 0x93, 0xd6, 0x83, 0x97, 0xcc,
		0x27, 0x38, 0x93, 0x35, 0x5b, 0x98, 0x8f, 0x9e, 0x78, 0xa4, 0x10, 0xb7, 0x29, 0x5d, 0x26, 0xf0,
		0x39, 0xa5, 0x1a, 0x13, 0x7d, 0xf2, 0xe1, 0xc3, 0xa4, 0x3c, 0x42, 0x7a, 0x04, 0x1e, 0x31, 0x84,
		0x50, 0x9a, 0x4a, 0x02, 0xa4, 0x15, 0x04, 0xc8, 0x1b, 0x99, 0xe7, 0x00, 0xa2, 0x00, 0xd1, 0xd8,
		0x80, 0x28, 0x59, 0x23, 0x73, 0x12, 0x76, 0xc4, 0xc1, 0x92, 0x98, 0x1c, 0x89, 0x68, 0x62, 0x8e,
		0x12, 0x21, 0x6a, 0x00, 0x22, 0x9a, 0x5e, 0x1d, 0xf2, 0x1b, 0xd9, 0x05, 0xad, 0xee, 0x59, 0x0e,
		0x69, 0x09, 0xa8, 0x59, 0x98, 0x25, 0x9c, 0x1e, 0xf1, 0x77, 0x7a, 0x50, 0xf9, 0xdf, 0x94, 0xb9,
		0x3c, 0x08, 0xfc, 0x6d, 0x7a, 0xd8, 0xba, 0xf4, 0x4c, 0xc7, 0xb7, 0x24, 0x1d, 0x5f, 0x9f, 0x0e,
		0x18, 0x31, 0xc6, 0x0e, 0xb7, 0x07, 0x18, 0xfb, 0x01, 0x32, 0xf6, 0xce, 0x54, 0xfe, 0x89, 0x39,
		0x3b, 0x69, 0x09, 0x47, 0xb6, 0xc2, 0x7e, 0x60, 0xed, 0x60, 0xed, 0x87, 0xc7, 0xda, 0x51, 0xd8,
		0x4f, 0x81, 0x6b, 0x80, 0x0d, 0x6c, 0x38, 0x41, 0x87, 0x1b, 0x7c, 0xb8, 0x41, 0x48, 0x19, 0x18,
		0x29, 0x03, 0x25, 0x05, 0xe0, 0x44, 0x0b, 0x52, 0xc4, 0x60, 0xc5, 0xe7, 0x6a, 0xd8, 0x28, 0xeb,
		0x08, 0xfe, 0x5e, 0xfb, 0x83, 0xe0, 0xef, 0xdd, 0xa6, 0x40, 0xf0, 0x77, 0x74, 0x94, 0xee, 0xd6,
		0xe9, 0x10, 0xfc, 0x4d, 0x24, 0x23, 0x08, 0xfe, 0x4e, 0x80, 0xa0, 0x20, 0xf8, 0x9b, 0xff, 0xd8,
		0x20, 0xf8, 0x7b, 0x9f, 0x39, 0x10, 0xfc, 0x1d, 0x39, 0x61, 0x46, 0x61, 0x3f, 0x58, 0xf4, 0xb0,
		0xe8, 0x61, 0xd1, 0xa3, 0xb0, 0x1f, 0x2c, 0xfa, 0x3d, 0x56, 0x1e, 0x85, 0xfd, 0xf6, 0x9e, 0x08,
		0x85, 0xfd, 0x7e, 0xba, 0x15, 0x28, 0xec, 0x07, 0x7b, 0x89, 0x02, 0x9c, 0x50, 0xd8, 0x2f, 0x18,
		0x38, 0xa1, 0x72, 0x1a, 0x0a, 0xfb, 0x45, 0x18, 0xaa, 0x21, 0x9e, 0x28, 0xec, 0x07, 0x2f, 0x10,
		0x8b, 0x17, 0x08, 0x85, 0xfd, 0xe0, 0x09, 0x82, 0x27, 0x08, 0x9e, 0xa0, 0x23, 0xc4, 0x76, 0xc0,
		0x13, 0xb4, 0xc7, 0xca, 0x23, 0xb6, 0x23, 0x02, 0xbb, 0x31, 0x7b, 0x10, 0xc4, 0x76, 0x10, 0x4e,
		0x88, 0xd8, 0x8e, 0xf8, 0xca, 0x08, 0x62, 0x3b, 0xa2, 0x39, 0x3a, 0x7c, 0x95, 0xcb, 0xea, 0x13,
		0xb1, 0x1d, 0xb0, 0xea, 0x59, 0x46, 0x42, 0x61, 0xbf, 0xa5, 0x84, 0xe2, 0x49, 0x56, 0x6a, 0x9a,
		0x34, 0x6f, 0xed, 0x48, 0x65, 0x86, 0x71, 0x73, 0xfc, 0x04, 0xed, 0x89, 0x4f, 0x22, 0x2a, 0x59,
		0xee, 0x24, 0x39, 0xda, 0x14, 0x05, 0x83, 0xd6, 0xa0, 0x95, 0xb2, 0x86, 0x23, 0x5b, 0x86, 0x62,
		0x0e, 0x19, 0x8a, 0xb1, 0x71, 0x1c, 0x21, 0x43, 0x11, 0x19, 0x8a, 0xc8, 0x50, 0xe4, 0x05, 0x1d,
		0x6e, 0xf0, 0xe1, 0x06, 0x21, 0x65, 0x60, 0xa4, 0x0c, 0x94, 0x14, 0x80, 0x13, 0x0f, 0xc7, 0x87,
		0x17, 0x7b, 0x33, 0x85, 0x81, 0x17, 0x7b, 0x7d, 0xe5, 0xe1, 0xc5, 0x8e, 0xc0, 0x6e, 0xcc, 0x1e,
		0x04, 0x5e, 0x6c, 0xc2, 0x09, 0xe1, 0xc5, 0x8e, 0xaf, 0x8c, 0xc0, 0x8b, 0x1d, 0xcd, 0xd1, 0xe1,
		0xc5, 0x5e, 0x56, 0x9f, 0xf0, 0x62, 0x6b, 0x13, 0x49, 0x64, 0x28, 0x52, 0x08, 0x30, 0x32, 0x14,
		0x61, 0xd1, 0xc3, 0xa2, 0x87, 0x45, 0x4f, 0x2d, 0xeb, 0xc8, 0x50, 0xd4, 0x45, 0x49, 0x90, 0xa1,
		0x18, 0x60, 0x22, 0x64, 0x28, 0xfe, 0x74, 0x2b, 0x90, 0xa1, 0x08, 0x7b, 0x89, 0x02, 0x9c, 0x90,
		0xa1, 0x18, 0x0c, 0x9c, 0x90, 0x02, 0x86, 0x0c, 0xc5, 0x08, 0x43, 0x35, 0xc4, 0x13, 0x19, 0x8a,
		0xf0, 0x02, 0xb1, 0x78, 0x81, 0x90, 0xa1, 0x08, 0x4f, 0x10, 0x3c, 0x41, 0xf0, 0x04, 0x1d, 0x21,
		0xb6, 0x03, 0x9e, 0xa0, 0x3d, 0x56, 0x1e, 0xb1, 0x1d, 0x11, 0xd8, 0x8d, 0xd9, 0x83, 0x20, 0xb6,
		0x83, 0x70, 0x42, 0xc4, 0x76, 0xc4, 0x57, 0x46, 0x10, 0xdb, 0x11, 0xcd, 0xd1, 0xe1, 0xab, 0x5c,
		0x56, 0x9f, 0x88, 0xed, 0x80, 0x55, 0xcf, 0x32, 0x12, 0x32, 0x14, 0x37, 0x66, 0x28, 0x52, 0xa6,
		0xad, 0x1d, 0xe9, 0x48, 0x50, 0x24, 0x68, 0x85, 0x4a, 0x27, 0x68, 0xe8, 0xc2, 0x1b, 0x5e, 0x24,
		0xe3, 0xd4, 0x87, 0x77, 0x22, 0x84, 0xda, 0x3a, 0xf1, 0xbe, 0x53, 0x28, 0x66, 0xa9, 0xdf, 0xc4,
		0x6b, 0xc8, 0xfe, 0xf9, 0xa9, 0x9a, 0xe5, 0xcb, 0xb2, 0x94, 0xe1, 0xd2, 0xf1, 0x86, 0x46, 0x5d,
		0xc5, 0x16, 0x2f, 0xc2, 0x19, 0x73, 0xcb, 0x10, 0xed, 0x88, 0xaf, 0xcd, 0x6f, 0x0b, 0x23, 0x65,
		0xcf, 0xf2, 0xf9, 0x62, 0x29, 0x9f, 0xcf, 0x94, 0x4e, 0x4b, 0x99, 0xf3, 0x42, 0x21, 0x5b, 0xcc,
		0x86, 0x60, 0xcc, 0xa9, 0xba, 0xd7, 0x15, 0x9e, 0xe8, 0x7e, 0x1c, 0xae, 0x9a, 0xd3, 0xb7, 0x6d,
		0xa5, 0x9b, 0x45, 0x84, 0x05, 0x8a, 0x31, 0x20, 0xc4, 0xd9, 0x57, 0x75, 0xe6, 0x83, 0x9d, 0xf5,
		0xfd, 0x4f, 0xea, 0x7e, 0x9f, 0xd8, 0x53, 0x4c, 0xc2, 0x8a, 0x87, 0x0a, 0xb1, 0x08, 0x20, 0x0b,
		0xbc, 0x32, 0xb0, 0xdf, 0xce, 0xef, 0xbe, 0x7f, 0x7b, 0xec, 0x5d, 0xaa, 0x3f, 0x7c, 0x20, 0x5f,
		0x7a, 0xa6, 0xe5, 0x88, 0xae, 0x31, 0x59, 0xff, 0xfd, 0xf6, 0x6f, 0xee, 0xa9, 0x5c, 0x1f, 0x6b,
		0x4f, 0x29, 0x0a, 0x56, 0xa6, 0x20, 0xf0, 0x2d, 0x52, 0x98, 0x5b, 0xa2, 0xd9, 0x53, 0xbb, 0x1d,
		0x23, 0xe0, 0x45, 0x50, 0xd8, 0x8b, 0x1e, 0xb2, 0x8b, 0x1c, 0xb2, 0x8b, 0x9a, 0xa5, 0x8b, 0x98,
		0xe9, 0xc2, 0x44, 0x0c, 0xa9, 0x82, 0x26, 0xef, 0xa7, 0x86, 0x02, 0x6d, 0xf8, 0x42, 0xf6, 0x7b,
		0x46, 0xcf, 0x73, 0xa5, 0xdb, 0x71, 0x83, 0xdf, 0xe4, 0xce, 0x6f, 0x6c, 0x37, 0x0c, 0x1a, 0x94,
		0x4e, 0x85, 0xaa, 0xf1, 0x11, 0xfa, 0x2a, 0x96, 0xe2, 0xca, 0x95, 0xe0, 0x50, 0x51, 0x1d, 0x2e,
		0xf2, 0x43, 0x46, 0x7e, 0xd8, 0x68, 0x0f, 0x9d, 0x1e, 0x13, 0x20, 0x6c, 0x25, 0x8d, 0x94, 0xdd,
		0x0d, 0x9f, 0x56, 0x33, 0x93, 0xba, 0xe1, 0x60, 0x21, 0xf7, 0x82, 0xa6, 0xd0, 0x0e, 0x59, 0x5c,
		0x04, 0x65, 0x1c, 0xc4, 0xe2, 0xe1, 0x0c, 0xbf, 0x52, 0x47, 0x0c, 0x91, 0x0e, 0x6c, 0x91, 0x0d,
		0x6c, 0x91, 0x0c, 0xab, 0x67, 0x77, 0xb8, 0xae, 0x70, 0x1a, 0x29, 0xb1, 0x0c, 0xd6, 0xd9, 0x6a,
		0x7a, 0x83, 0x32, 0x4e, 0x13, 0x49, 0x3a, 0x83, 0x21, 0xf1, 0x79, 0xf1, 0x01, 0x1a, 0xa6, 0x7c,
		0x6e, 0x0f, 0xff, 0x77, 0x37, 0xfc, 0xfa, 0x8d, 0xc9, 0xb7, 0x6f, 0xd7, 0xc2, 0xca, 0x53, 0x5c,
		0x7c, 0x49, 0x51, 0x77, 0x4f, 0xec, 0x26, 0x6d, 0x11, 0x73, 0x57, 0xec, 0x20, 0x61, 0xf0, 0x5e,
		0xa8, 0x95, 0x9a, 0x88, 0x38, 0x31, 0xd6, 0x24, 0x83, 0xcd, 0x97, 0xf1, 0x8e, 0x70, 0xbf, 0x83,
		0xee, 0x33, 0xd7, 0xfe, 0xee, 0xb1, 0x99, 0x0c, 0x9b, 0xb8, 0xdb, 0x96, 0xfd, 0x7c, 0x03, 0x76,
		0x58, 0xfc, 0x94, 0x6f, 0x3d, 0x39, 0xa6, 0x6d, 0x39, 0x4f, 0x33, 0xa8, 0xf3, 0x77, 0xde, 0x81,
		0x79, 0x45, 0xcc, 0x0d, 0x83, 0xec, 0xb8, 0xf1, 0xfb, 0xd1, 0xf2, 0xbd, 0xe9, 0x77, 0x10, 0x9a,
		0x1d, 0xc2, 0xd6, 0x0d, 0xca, 0x9b, 0x43, 0xf3, 0xe3, 0xd0, 0x3c, 0x38, 0x9c, 0xad, 0x4a, 0x0b,
		0x06, 0xfb, 0xda, 0x9e, 0x81, 0x6c, 0xcd, 0x10, 0xb6, 0x65, 0x5c, 0xbd, 0xa1, 0xc1, 0x18, 0x73,
		0xf2, 0x9d, 0xa1, 0x81, 0x6c, 0xbb, 0x88, 0xfa, 0x42, 0x9f, 0x6c, 0xf7, 0xc1, 0x24, 0x70, 0x7f,
		0x4e, 0xc6, 0x81, 0xc7, 0x33, 0xbc, 0x53, 0xe5, 0x70, 0x1d, 0x9e, 0xa1, 0x9c, 0x26, 0x31, 0xf3,
		0x77, 0x9a, 0x7d, 0xf9, 0x2c, 0x1c, 0x69, 0x75, 0x68, 0x3c, 0x2c, 0x33, 0xf1, 0x5b, 0x19, 0x17,
		0x5e, 0x50, 0x78, 0x41, 0xe1, 0x05, 0x0d, 0xf1, 0x44, 0x54, 0x25, 0xc2, 0x53, 0x9d, 0xe9, 0x19,
		0x20, 0x6e, 0x2f, 0x40, 0xda, 0x49, 0x82, 0xad, 0xbf, 0x40, 0x26, 0x06, 0xfd, 0x05, 0xc8, 0x80,
		0x80, 0x0b, 0x10, 0xd8, 0x81, 0x81, 0x1d, 0x20, 0x58, 0x81, 0x82, 0x06, 0x30, 0x88, 0x80, 0x83,
		0x1c, 0x40, 0xb6, 0x30, 0x07, 0xe3, 0xef, 0x51, 0xf0, 0x25, 0x53, 0x1e, 0xfa, 0x86, 0xb9, 0x90,
		0x8f, 0xce, 0x9e, 0x8f, 0x4e, 0x0e, 0x44, 0xdc, 0x80, 0xa4, 0x0c, 0x98, 0x94, 0x01, 0x94, 0x12,
		0xa0, 0xa2, 0x05, 0x2c, 0x62, 0xe0, 0x9a, 0xad, 0x00, 0x7f, 0x4e, 0xba, 0xe7, 0xf6, 0xe5, 0xc8,
		0x1b, 0x6c, 0xfa, 0xfe, 0x48, 0x7c, 0x18, 0x33, 0xd3, 0xcf, 0x0e, 0xa0, 0x42, 0x89, 0x70, 0xcc,
		0x07, 0x5b, 0xf0, 0x69, 0x85, 0xc9, 0xf8, 0xc4, 0x72, 0x76, 0x25, 0x1e, 0xcd, 0xbe, 0x3d, 0x3a,
		0x68, 0x8f, 0xa6, 0xed, 0x0b, 0x68, 0x1a, 0x68, 0x1a, 0x68, 0x1a, 0x68, 0x1a, 0x4a, 0x79, 0x7f,
		0x70, 0x5d, 0x5b, 0x98, 0x0e, 0xa7, 0x82, 0xc9, 0x22, 0x59, 0x76, 0x17, 0x61, 0x8f, 0x4f, 0xb2,
		0xec, 0x86, 0xdb, 0xea, 0xb4, 0xdd, 0xed, 0xa5, 0xc7, 0x57, 0x1e, 0xe9, 0x65, 0x13, 0x29, 0xf2,
		0x8d, 0x3d, 0xef, 0xa6, 0x4f, 0x33, 0x0d, 0xfc, 0xf1, 0xdb, 0xb5, 0x6e, 0xaf, 0xfd, 0xcb, 0xe8,
		0x61, 0xda, 0xe5, 0xa5, 0x87, 0x41, 0x8f, 0xcf, 0x5d, 0x71, 0x05, 0x3d, 0x3e, 0xe1, 0x83, 0x83,
		0x0f, 0x0e, 0x3e, 0x38, 0xf8, 0xe0, 0x60, 0x19, 0xc1, 0x32, 0x82, 0x65, 0x04, 0x1f, 0x1c, 0x7c,
		0x70, 0xf0, 0xc1, 0x41, 0xd3, 0x40, 0xd3, 0x40, 0xd3, 0x40, 0xd3, 0xc0, 0x07, 0x07, 0x1f, 0x9c,
		0x4a, 0x1f, 0x5c, 0xc4, 0x4b, 0xd7, 0xed, 0xe5, 0x82, 0x43, 0x15, 0x3b, 0x2e, 0x79, 0xd5, 0x2e,
		0xa7, 0xd1, 0x4b, 0x47, 0xde, 0x47, 0x32, 0xb5, 0xa5, 0x23, 0x87, 0x88, 0xac, 0x27, 0x8a, 0xc1,
		0xa4, 0x8d, 0xbd, 0x44, 0x90, 0xb5, 0x4e, 0x52, 0x8b, 0x20, 0xeb, 0x08, 0x20, 0x3b, 0x59, 0x90,
		0xb5, 0xed, 0x7b, 0x86, 0xd5, 0xa5, 0xbf, 0xdf, 0x99, 0x8c, 0x4b, 0x7b, 0xc1, 0x93, 0x41, 0x90,
		0x75, 0x84, 0xad, 0x5c, 0x5c, 0xf0, 0xc4, 0xc8, 0x94, 0x21, 0xb7, 0x5a, 0x79, 0x3b, 0x27, 0x73,
		0xf4, 0xc9, 0xe1, 0xe9, 0x8f, 0xc3, 0xda, 0x93, 0x9a, 0xb5, 0x33, 0x32, 0x67, 0xd3, 0x51, 0xf6,
		0x66, 0xa3, 0x31, 0xef, 0x80, 0xdc, 0xe2, 0x58, 0x72, 0x15, 0x6d, 0x34, 0x63, 0xdf, 0xe9, 0xb8,
		0x15, 0x65, 0xe7, 0x22, 0x2f, 0x98, 0x14, 0x01, 0x26, 0x3f, 0x04, 0x13, 0xb4, 0x84, 0x4d, 0x42,
		0xc7, 0xe2, 0xd8, 0x43, 0x2b, 0xc4, 0x30, 0x11, 0x9d, 0x89, 0xa3, 0xda, 0x13, 0xa8, 0x05, 0x57,
		0x79, 0x22, 0x5c, 0xe5, 0x64, 0x71, 0xd4, 0x4a, 0x5d, 0xe4, 0x14, 0x01, 0xd3, 0x7a, 0x5c, 0xe3,
		0x4f, 0x9e, 0xd9, 0x11, 0x8f, 0x7d, 0xdb, 0xf0, 0x84, 0x2f, 0x4d, 0x4f, 0xd2, 0x39, 0xc9, 0xd7,
		0x46, 0x86, 0xbb, 0x1c, 0xee, 0x72, 0xb8, 0xcb, 0xa3, 0xe0, 0x2e, 0x47, 0x4d, 0x12, 0xb8, 0xcb,
		0xe1, 0x2e, 0x3f, 0x3c, 0x77, 0x39, 0x79, 0x3e, 0xc4, 0x38, 0x1a, 0xb5, 0xcb, 0x1d, 0xee, 0xda,
		0x45, 0xbc, 0xeb, 0x11, 0xe2, 0x5d, 0x55, 0x43, 0x9b, 0x32, 0x88, 0x53, 0x06, 0x75, 0x4a, 0x20,
		0x8f, 0xde, 0xb6, 0x3f, 0x42, 0xbc, 0xeb, 0x66, 0x66, 0x94, 0x3d, 0x80, 0x84, 0x8a, 0x47, 0xd7,
		0xfb, 0xc7, 0xf4, 0xba, 0x96, 0xf3, 0x64, 0x3c, 0xbb, 0x76, 0x57, 0x5a, 0x2f, 0x8c, 0xd9, 0x15,
		0x9b, 0x26, 0x83, 0x6a, 0x80, 0x6a, 0x80, 0x6a, 0x80, 0x6a, 0x20, 0x94, 0xf7, 0xbe, 0xe5, 0xc8,
		0x6c, 0x91, 0x51, 0x33, 0x14, 0x19, 0x86, 0xbe, 0x35, 0x9d, 0x27, 0xc1, 0x76, 0x4d, 0xc4, 0x73,
		0x3e, 0x8f, 0x26, 0xdd, 0xa1, 0xd9, 0x00, 0x80, 0x19, 0xd6, 0xd7, 0xa6, 0xf9, 0xdd, 0xb4, 0xfb,
		0x42, 0xc1, 0x3c, 0x9f, 0x3c, 0xb3, 0x23, 0x2d, 0xd7, 0xb9, 0xb2, 0x9e, 0xac, 0x71, 0x53, 0x6d,
		0xb6, 0xf9, 0x06, 0xef, 0x19, 0xb7, 0xde, 0xfc, 0x96, 0xb8, 0xad, 0x2f, 0x16, 0x0a, 0xa7, 0x85,
		0x04, 0x6d, 0xff, 0xbb, 0x78, 0x8c, 0xda, 0x3a, 0x00, 0xae, 0xfd, 0x2c, 0xec, 0x9e, 0xf0, 0x0c,
		0xee, 0x1c, 0xe6, 0xe5, 0x69, 0xc0, 0xaf, 0xc1, 0xaf, 0xc1, 0xaf, 0xc1, 0xaf, 0xe1, 0x7a, 0x89,
		0x9a, 0x3a, 0xf0, 0x44, 0xc7, 0x75, 0x1c, 0xd1, 0x91, 0x06, 0xaf, 0xd7, 0x65, 0x65, 0x1e, 0x28,
		0x04, 0x28, 0x04, 0x28, 0x04, 0x28, 0x04, 0x38, 0x5c, 0xe0, 0x70, 0x81, 0xc3, 0x05, 0x0e, 0x17,
		0x38, 0x5c, 0xe0, 0x70, 0x49, 0x30, 0xc3, 0xfe, 0x2a, 0xbc, 0x57, 0x05, 0x04, 0x7b, 0x3e, 0x0d,
		0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35, 0xf8, 0x35,
		0xf8, 0x35, 0xf8, 0x75, 0x94, 0xf8, 0x35, 0x8a, 0x65, 0xb2, 0x64, 0x56, 0xae, 0xe6, 0xe3, 0xc5,
		0xbc, 0x65, 0xcd, 0x2f, 0x93, 0xc7, 0xb9, 0x1d, 0x3f, 0x0d, 0x7a, 0xd6, 0xec, 0xca, 0xd5, 0xd0,
		0xb3, 0x26, 0xaa, 0x46, 0x1e, 0x72, 0xb4, 0xb4, 0x18, 0x71, 0xc8, 0xd1, 0x0a, 0x77, 0x0e, 0x90,
		0xa3, 0x05, 0xbf, 0x15, 0xfc, 0x56, 0xf0, 0x5b, 0x21, 0x50, 0x68, 0x13, 0x33, 0x42, 0x8e, 0x16,
		0xf1, 0x9e, 0x21, 0x47, 0x0b, 0xaa, 0x01, 0xaa, 0x01, 0xaa, 0x01, 0x57, 0x1a, 0xeb, 0x43, 0xe3,
		0x4a, 0x43, 0x3d, 0xac, 0xaf, 0x4d, 0x83, 0x2b, 0x8d, 0xfd, 0xb6, 0x1e, 0x57, 0x1a, 0x91, 0xdf,
		0x7e, 0x5c, 0x69, 0x44, 0x86, 0x6b, 0x23, 0x47, 0x0b, 0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a, 0xae,
		0x17, 0xb8, 0x5e, 0x90, 0xa3, 0x05, 0x85, 0x00, 0x85, 0x00, 0x85, 0x00, 0x87, 0x0b, 0x1c, 0x2e,
		0x70, 0xb8, 0xc0, 0xe1, 0x02, 0x87, 0x0b, 0x1c, 0x2e, 0x70, 0xb8, 0x20, 0x47, 0x0b, 0xfc, 0x1a,
		0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a, 0xfc, 0x1a,
		0xfc, 0x1a, 0x39, 0x5a, 0x7b, 0x8f, 0x1b, 0x81, 0x1c, 0x2d, 0xca, 0x64, 0x9d, 0x23, 0xdd, 0x29,
		0x5a, 0x77, 0xa3, 0x87, 0x41, 0xa3, 0xc6, 0x44, 0x34, 0x6a, 0x24, 0x6e, 0xef, 0xa7, 0x5b, 0x38,
		0xe3, 0xd8, 0xbb, 0x91, 0x26, 0x41, 0x90, 0x34, 0x31, 0x90, 0xbc, 0x4b, 0x63, 0x0e, 0x5d, 0x1a,
		0x23, 0xe0, 0x19, 0x40, 0x97, 0xc6, 0xdd, 0x9f, 0x88, 0xac, 0x4b, 0xa3, 0xed, 0x7b, 0x86, 0xd5,
		0xa5, 0x4f, 0x00, 0x9e, 0x8c, 0x4b, 0x9b, 0x01, 0x9c, 0x41, 0x97, 0xc6, 0x08, 0xbb, 0x0e, 0x91,
		0x01, 0x1c, 0x23, 0x73, 0x86, 0xdc, 0x15, 0x38, 0x93, 0x57, 0xab, 0x67, 0x98, 0xdd, 0xae, 0x27,
		0x7c, 0x9f, 0x52, 0x66, 0xa7, 0x2a, 0xff, 0x9c, 0x70, 0xcc, 0xc9, 0x1a, 0xd0, 0xba, 0xfd, 0x18,
		0x9d, 0xab, 0x56, 0xef, 0x6b, 0x9e, 0x61, 0x6d, 0xd7, 0xd6, 0xf8, 0x8c, 0x61, 0xec, 0x86, 0x29,
		0xa5, 0xf0, 0x1c, 0x36, 0x2f, 0x6b, 0xea, 0xf8, 0xf8, 0x3e, 0x63, 0x9c, 0xb7, 0xde, 0xee, 0xb3,
		0xc6, 0x79, 0x6b, 0xfc, 0x32, 0x3b, 0xfa, 0x6b, 0xfc, 0x3a, 0x77, 0x9f, 0x31, 0xf2, 0xd3, 0xd7,
		0x85, 0xfb, 0x8c, 0x51, 0x68, 0x9d, 0x7c, 0xf9, 0xf2, 0xe1, 0xe4, 0xfb, 0xe9, 0x60, 0xff, 0x0f,
		0xd2, 0xdf, 0x1b, 0xb4, 0x38, 0x96, 0xbc, 0x7e, 0x57, 0xfd, 0x83, 0x7d, 0xdd, 0xff, 0x52, 0xb9,
		0xf0, 0xff, 0x4a, 0x45, 0xdd, 0xfb, 0xf5, 0x3e, 0x46, 0x60, 0x52, 0x04, 0x98, 0xfc, 0x10, 0x4c,
		0x4c, 0xe3, 0xb1, 0x6c, 0x7c, 0x6a, 0x7d, 0xcf, 0xbe, 0xcf, 0x0f, 0x2e, 0x4e, 0xbe, 0x97, 0x06,
		0xab, 0x6f, 0xbe, 0x6d, 0xfa, 0xb5, 0xec, 0xfb, 0xd2, 0xe0, 0x62, 0xcb, 0xbf, 0x14, 0x07, 0x17,
		0x3b, 0x8e, 0x51, 0x18, 0x1c, 0xaf, 0xfd, 0xea, 0xf0, 0xfd, 0xdc, 0xb6, 0x0f, 0xe4, 0xb7, 0x7c,
		0xe0, 0x74, 0xdb, 0x07, 0x4e, 0xb7, 0x7c, 0x60, 0xeb, 0x57, 0xca, 0x6d, 0xf9, 0x40, 0x61, 0xf0,
		0xb6, 0xf6, 0xfb, 0xc7, 0x9b, 0x7f, 0xb5, 0x38, 0x38, 0x79, 0xdb, 0xf6, 0x6f, 0xa5, 0xc1, 0xdb,
		0xc5, 0x09, 0xa0, 0x75, 0x1d, 0x5a, 0x21, 0x86, 0xea, 0xc5, 0x30, 0xfa, 0x8a, 0xe6, 0x5d, 0xb4,
		0xbe, 0x17, 0x7c, 0xe5, 0xba, 0x7d, 0xe5, 0x54, 0xb7, 0x38, 0x4a, 0x1d, 0xe4, 0x04, 0xb7, 0x35,
		0x21, 0xdc, 0xe2, 0xef, 0x14, 0x4a, 0x1a, 0x95, 0x84, 0xa9, 0x97, 0xac, 0x54, 0xa8, 0xdb, 0x03,
		0x65, 0xb2, 0x14, 0x4c, 0x8a, 0xf6, 0x97, 0x81, 0x00, 0xfb, 0x9f, 0xb2, 0x1c, 0x29, 0xbc, 0x47,
		0xb3, 0x23, 0x0c, 0x53, 0x4a, 0xcf, 0x7a, 0xe8, 0x4b, 0xe1, 0x07, 0x96, 0x82, 0x39, 0x85, 0xdf,
		0x34, 0x6a, 0x40, 0xe9, 0x0c, 0x77, 0xa5, 0x12, 0xda, 0xa3, 0x4a, 0xe1, 0x41, 0xa5, 0xf3, 0x98,
		0x52, 0x79, 0x48, 0xc9, 0x3d, 0xa2, 0xe4, 0x1e, 0x50, 0x52, 0x8f, 0xa7, 0x5a, 0x3c, 0x0d, 0x7b,
		0x05, 0x92, 0xea, 0x4c, 0x65, 0x96, 0xe8, 0x6a, 0x93, 0xa4, 0xd4, 0x2d, 0xf9, 0xdd, 0x66, 0x06,
		0x77, 0x9b, 0x11, 0xb8, 0xc2, 0xc0, 0xdd, 0xa6, 0xba, 0x83, 0x3d, 0x1b, 0xe8, 0x59, 0xd8, 0xb6,
		0x4b, 0x5f, 0x2c, 0x6e, 0xb1, 0x7c, 0xc5, 0xe2, 0xf8, 0xb8, 0xeb, 0x8c, 0x0e, 0x30, 0x70, 0x01,
		0x04, 0x3b, 0x50, 0xb0, 0x03, 0x06, 0x2b, 0x70, 0xd0, 0x7a, 0x27, 0xa2, 0x7f, 0xd7, 0x49, 0x9e,
		0xee, 0xc0, 0x90, 0xe6, 0xc0, 0x94, 0xde, 0xc0, 0x70, 0x35, 0xc1, 0x99, 0xce, 0xc0, 0x1c, 0xcb,
		0xce, 0x9d, 0xbe, 0xa0, 0x22, 0x6e, 0x9d, 0x21, 0x5d, 0x81, 0x35, 0x4d, 0x41, 0xd5, 0x96, 0x32,
		0xa6, 0x25, 0x28, 0xd9, 0x56, 0xf8, 0x9d, 0xb9, 0xc5, 0x7e, 0xc2, 0x04, 0x47, 0xfe, 0x98, 0xaf,
		0xa6, 0xcd, 0xc5, 0x34, 0x67, 0xe3, 0x83, 0x69, 0x82, 0x69, 0x82, 0x69, 0x82, 0x69, 0x82, 0x69,
		0x82, 0x69, 0x82, 0x69, 0x82, 0x69, 0x82, 0x69, 0xc6, 0x83, 0x69, 0x22, 0xc2, 0x21, 0xd8, 0x3d,
		0xf4, 0xa6, 0x8b, 0x4e, 0xba, 0xce, 0x82, 0x6a, 0x2e, 0xa9, 0xab, 0xd3, 0x67, 0x28, 0xcf, 0x1e,
		0x81, 0xa4, 0x9d, 0xa0, 0x9e, 0xac, 0xc0, 0xd9, 0x8e, 0xf8, 0x74, 0xf7, 0x67, 0x0b, 0x63, 0xe2,
		0x0e, 0x4d, 0x9d, 0x01, 0x83, 0x3b, 0x34, 0xdc, 0xa1, 0xed, 0x70, 0xd0, 0xe9, 0x9d, 0x1a, 0xf3,
		0xa1, 0x23, 0xde, 0x27, 0x14, 0xfe, 0x0c, 0xf8, 0x33, 0x0e, 0xd3, 0x9f, 0x41, 0xde, 0x27, 0x74,
		0x92, 0x70, 0x62, 0x3c, 0x9a, 0x2f, 0xff, 0x3f, 0x7b, 0x6f, 0xf8, 0x9c, 0x36, 0xb2, 0xec, 0xfd,
		0xbf, 0xcf, 0x5f, 0xe1, 0xa2, 0xce, 0x8b, 0xa4, 0x2a, 0x0a, 0xc6, 0xc6, 0x76, 0x9c, 0xaa, 0xfb,
		0x22, 0xbb, 0x9b, 0xdd, 0x9b, 0x3a, 0xc9, 0x26, 0x4f, 0x92, 0x73, 0x7f, 0xf7, 0x56, 0xd6, 0xc7,
		0x25, 0xc3, 0xe0, 0xe8, 0x59, 0x59, 0x70, 0x25, 0x91, 0x4d, 0x9e, 0x8d, 0xff, 0xf7, 0x5f, 0x81,
		0x01, 0x63, 0x03, 0x09, 0xa0, 0xee, 0x1e, 0x49, 0x7c, 0x5c, 0xa7, 0xce, 0x62, 0x62, 0x66, 0xd0,
		0x4c, 0xcf, 0xb7, 0xfb, 0xdb, 0xdd, 0xd3, 0x1d, 0xc5, 0x91, 0x80, 0xf5, 0xb0, 0xf2, 0x40, 0x2c,
		0xcc, 0xa4, 0x53, 0xed, 0xb0, 0x45, 0xb5, 0x43, 0xaa, 0x1d, 0x96, 0x08, 0x9c, 0x4c, 0x40, 0x4a,
		0x89, 0xf0, 0x4b, 0xf7, 0xf6, 0x15, 0x06, 0xaf, 0xe5, 0x20, 0xf6, 0x55, 0x4f, 0x28, 0x97, 0x42,
		0xd9, 0x57, 0x2d, 0xc9, 0xd4, 0x01, 0x34, 0x75, 0x60, 0xb3, 0x00, 0x38, 0x3b, 0xa0, 0xb3, 0x02,
		0x3c, 0x73, 0xe0, 0x33, 0x07, 0x40, 0x53, 0x20, 0xd4, 0x01, 0x44, 0x25, 0x60, 0x54, 0x07, 0xc8,
		0x5b, 0xa0, 0xec, 0x45, 0xc1, 0xc4, 0xad, 0xa6, 0x2c, 0xc6, 0x33, 0xa8, 0x9c, 0xce, 0xf8, 0xb8,
		0x16, 0x95, 0x31, 0xb5, 0x41, 0xd3, 0x12, 0x3c, 0xed, 0x41, 0xd4, 0x1a, 0x4c, 0xbd, 0x81, 0xaa,
		0x37, 0x70, 0xf5, 0x02, 0xb2, 0xba, 0x60, 0xab, 0x0c, 0xba, 0xb3, 0x15, 0x53, 0xab, 0xc5, 0xbd,
		0xf2, 0xbc, 0xc5, 0x2e, 0xec, 0xa5, 0xae, 0x67, 0x71, 0xe0, 0xa6, 0xb6, 0xe4, 0x89, 0xc1, 0x5c,
		0x6f, 0x27, 0x11, 0xa8, 0x27, 0x4f, 0x26, 0x21, 0xa1, 0xe6, 0x4c, 0x09, 0x3c, 0xa8, 0xa6, 0xf8,
		0x69, 0xd6, 0x8d, 0x16, 0xba, 0xf4, 0xb4, 0xb6, 0xd0, 0x89, 0x45, 0xe9, 0x3c, 0x72, 0x17, 0xd4,
		0x31, 0xea, 0x18, 0x75, 0x5c, 0x6f, 0x75, 0xac, 0xcd, 0x85, 0xec, 0x39, 0x91, 0x2f, 0x6e, 0x64,
		0xcc, 0x91, 0xcc, 0xc1, 0xd9, 0x07, 0x48, 0xfb, 0x03, 0x6b, 0x5f, 0xa0, 0xed, 0x1d, 0xbc, 0xbd,
		0x83, 0xb8, 0x57, 0x30, 0xb7, 0x01, 0x75, 0x23, 0x70, 0xb7, 0xe7, 0x5c, 0x0b, 0xe7, 0xf5, 0x6a,
		0x10, 0x67, 0xa3, 0x9d, 0x0b, 0xc2, 0x5e, 0x64, 0x79, 0x6a, 0xa7, 0x86, 0x71, 0xdb, 0x70, 0xce,
		0x17, 0xc9, 0xf0, 0x6a, 0xb4, 0xca, 0x46, 0xb2, 0xf3, 0xa0, 0x06, 0xd2, 0xd9, 0x70, 0x49, 0x78,
		0x11, 0xbb, 0xae, 0xbd, 0x51, 0x30, 0x9d, 0xd8, 0xe8, 0x04, 0xfe, 0xe2, 0x7a, 0xe1, 0x30, 0x1e,
		0x43, 0x59, 0x2f, 0x8c, 0x33, 0x6c, 0x11, 0x6c, 0x11, 0x6c, 0x11, 0x6c, 0x11, 0x6c, 0x11, 0xc3,
		0xf3, 0x7a, 0xd1, 0xef, 0xc7, 0x2e, 0x4c, 0x7c, 0x98, 0x21, 0xad, 0xba, 0x98, 0x04, 0x95, 0xf6,
		0x75, 0x28, 0xb5, 0x32, 0x5b, 0x39, 0x9f, 0xef, 0x9b, 0x22, 0xb7, 0x17, 0x0b, 0x6e, 0x5f, 0x36,
		0xef, 0xe7, 0x07, 0xde, 0x7d, 0xe3, 0x6b, 0xd3, 0xc4, 0x71, 0xbd, 0xe7, 0xf5, 0xfa, 0xc9, 0xec,
		0xbd, 0xb9, 0x97, 0xe7, 0xcf, 0x6f, 0x96, 0xe1, 0xd7, 0xc9, 0xb2, 0xdc, 0xf9, 0xfd, 0xab, 0xc8,
		0x8d, 0x15, 0x7f, 0x87, 0x4b, 0x33, 0xb0, 0x22, 0xd3, 0x27, 0x6b, 0x6d, 0x10, 0x97, 0xee, 0xd9,
		0xf7, 0x5d, 0xd8, 0xb6, 0x0a, 0xab, 0x1c, 0x10, 0x56, 0xa9, 0x8e, 0x55, 0x4c, 0x58, 0x85, 0xb0,
		0xca, 0x8f, 0xf9, 0x3e, 0x61, 0x15, 0x5c, 0x19, 0xb8, 0x32, 0x70, 0x65, 0xe0, 0xca, 0xc0, 0x95,
		0x21, 0x7f, 0x5e, 0x09, 0xab, 0x54, 0xd8, 0x87, 0x42, 0x58, 0x45, 0xce, 0xcc, 0x22, 0xac, 0x82,
		0x2d, 0x82, 0x2d, 0x82, 0x2d, 0x82, 0x2d, 0x42, 0x58, 0xa5, 0xc2, 0x26, 0x01, 0x61, 0x95, 0x0d,
		0xe6, 0xab, 0x64, 0x58, 0xc5, 0xc2, 0x6f, 0xbd, 0x57, 0xb5, 0xa8, 0x8a, 0x40, 0x17, 0x34, 0x7f,
		0x47, 0xab, 0x5a, 0x77, 0x5e, 0xff, 0xe9, 0xbe, 0x1a, 0x38, 0xed, 0x1a, 0xaf, 0xa2, 0x2c, 0x1f,
		0xc9, 0x84, 0xee, 0xfd, 0xda, 0xd7, 0x51, 0xf2, 0x22, 0x76, 0x23, 0xc3, 0x21, 0xd3, 0x35, 0x8a,
		0x1b, 0xaf, 0xc3, 0x2f, 0x73, 0x33, 0xb5, 0x9e, 0xb6, 0xdb, 0xc7, 0x27, 0xed, 0xf6, 0xfe, 0xc9,
		0xe1, 0xc9, 0xfe, 0xe9, 0xd1, 0x51, 0xeb, 0xb8, 0x75, 0xa4, 0x38, 0xf9, 0x9b, 0xb4, 0xeb, 0x52,
		0xd7, 0xfd, 0x69, 0xb4, 0x73, 0xc9, 0x30, 0x8e, 0x2b, 0x25, 0x70, 0x46, 0x5a, 0xa1, 0x92, 0xda,
		0xa0, 0xa1, 0x1a, 0x8f, 0xad, 0x0c, 0xfe, 0xeb, 0x20, 0xff, 0xf5, 0x8e, 0x95, 0x7b, 0x51, 0x3e,
		0x68, 0xd5, 0x38, 0x60, 0x1a, 0xb5, 0x97, 0x4a, 0x7d, 0x92, 0x1a, 0x25, 0xad, 0x39, 0x2c, 0x28,
		0xdd, 0x5a, 0x77, 0x76, 0x75, 0xef, 0xe8, 0x52, 0x20, 0xcd, 0xd2, 0xa7, 0x47, 0x81, 0xb4, 0x52,
		0xfa, 0xdc, 0x76, 0xb4, 0x40, 0x9a, 0x52, 0xe3, 0xc5, 0x95, 0xc7, 0x4a, 0xa5, 0x11, 0xe3, 0x2a,
		0x40, 0xdb, 0xa7, 0x40, 0x9a, 0x47, 0xa0, 0xb3, 0x02, 0x3c, 0x73, 0xe0, 0x33, 0x07, 0x40, 0x53,
		0x20, 0xac, 0xa6, 0xb3, 0x48, 0x3d, 0x98, 0xa0, 0xd7, 0xde, 0x67, 0x15, 0x7a, 0x1d, 0x2b, 0x4e,
		0xa1, 0xd3, 0xfe, 0xe7, 0xfe, 0x8f, 0x81, 0x67, 0x5d, 0xb3, 0x3d, 0x90, 0xb1, 0x5a, 0x59, 0x98,
		0x4e, 0xb9, 0x7d, 0xd0, 0xc2, 0x7c, 0x06, 0x7d, 0x67, 0x8c, 0xe0, 0xe0, 0xbe, 0x43, 0xb4, 0xf6,
		0x22, 0xa2, 0xd8, 0x8e, 0xa8, 0x14, 0x62, 0x52, 0xd1, 0x80, 0xcb, 0x59, 0x55, 0xdc, 0x85, 0x8f,
		0xb5, 0x98, 0x85, 0x78, 0xa3, 0xcd, 0x1f, 0x30, 0x0b, 0xe1, 0xc6, 0x9b, 0x30, 0x0b, 0x98, 0x05,
		0xcc, 0x02, 0x66, 0x01, 0xb3, 0x80, 0x59, 0xc0, 0x2c, 0x60, 0x16, 0x30, 0x0b, 0x98, 0x05, 0xcc,
		0xc2, 0x33, 0xb3, 0xb8, 0x8d, 0xb9, 0x47, 0x5d, 0x7d, 0x5e, 0x71, 0x67, 0x36, 0x58, 0x05, 0xac,
		0x02, 0x56, 0x01, 0xab, 0xa8, 0x10, 0xab, 0x30, 0xc0, 0xaf, 0x79, 0x0c, 0x6b, 0x3d, 0x25, 0x45,
		0x4e, 0xe2, 0xe4, 0xec, 0x62, 0x8a, 0x9c, 0x5a, 0x21, 0xa7, 0x92, 0x25, 0xc6, 0x69, 0x94, 0x66,
		0x2a, 0x67, 0x3e, 0x9c, 0xaa, 0xa9, 0x66, 0x01, 0x71, 0x4a, 0xa6, 0x19, 0xb9, 0x71, 0x5e, 0x4c,
		0x2f, 0x72, 0xe3, 0x6a, 0xa8, 0x2a, 0xd5, 0x4c, 0x29, 0x83, 0x76, 0x4c, 0x9a, 0xed, 0x97, 0x96,
		0xb4, 0x5b, 0xba, 0x03, 0x94, 0x3b, 0xa5, 0x7e, 0x46, 0xdb, 0x67, 0xa0, 0x7f, 0xe4, 0xa5, 0x84,
		0xe4, 0xec, 0xe5, 0x0a, 0x28, 0xea, 0xa1, 0x7f, 0x4a, 0xa8, 0x7f, 0xa2, 0x1e, 0xa9, 0xd9, 0x42,
		0x03, 0x2b, 0xf7, 0x7f, 0xb3, 0xe9, 0xfb, 0x46, 0xaf, 0xea, 0x12, 0xc0, 0x9a, 0x15, 0xbc, 0x99,
		0xc3, 0x9c, 0x39, 0xdc, 0x59, 0xc2, 0x9e, 0x9e, 0xeb, 0x6b, 0xaf, 0xca, 0x9d, 0xaa, 0x67, 0xc6,
		0x96, 0x5d, 0x05, 0xe7, 0xdb, 0x29, 0xe9, 0x55, 0x5d, 0x36, 0xf0, 0x34, 0x07, 0x51, 0x6b, 0x30,
		0xf5, 0x06, 0xaa, 0xde, 0xc0, 0xd5, 0x07, 0xc8, 0xea, 0x82, 0xad, 0x32, 0xe8, 0xea, 0xbb, 0x42,
		0x3c, 0xb8, 0x46, 0x2c, 0x5d, 0x25, 0x2b, 0x5d, 0x27, 0xcd, 0xb1, 0xd8, 0x3d, 0x9b, 0x8b, 0x56,
		0xdc, 0x7b, 0x63, 0xf2, 0x3b, 0x3d, 0xac, 0x97, 0xaf, 0x63, 0x36, 0xbc, 0xf0, 0xa0, 0xaf, 0xef,
		0xcc, 0x8a, 0xca, 0x46, 0x65, 0xa3, 0xb2, 0x51, 0xd9, 0xa8, 0x6c, 0x54, 0xf6, 0xf8, 0x8d, 0x8f,
		0xb7, 0x2a, 0xfb, 0x3f, 0x3a, 0xc3, 0x34, 0x75, 0x49, 0xfe, 0xf0, 0x51, 0xf3, 0xc9, 0x93, 0xdb,
		0xe8, 0xc8, 0xd9, 0xe4, 0x23, 0xf3, 0x7a, 0x24, 0x5b, 0xf2, 0xde, 0x6c, 0xe4, 0xae, 0xfb, 0x42,
		0x4d, 0x40, 0x0b, 0xef, 0xc2, 0x8b, 0x2f, 0xe3, 0xbc, 0x60, 0xbd, 0xcb, 0x05, 0x76, 0x8e, 0xb1,
		0x7e, 0x27, 0x70, 0x5f, 0xf2, 0x67, 0xb9, 0x8b, 0xdd, 0x95, 0xcb, 0xd3, 0xaf, 0x41, 0x3f, 0x09,
		0x3a, 0x9f, 0xc6, 0xb7, 0x27, 0x4c, 0x9d, 0x65, 0xe3, 0x2a, 0xe4, 0x86, 0xde, 0xb2, 0xaa, 0x39,
		0xca, 0xce, 0xa8, 0x36, 0x28, 0x9f, 0xe9, 0x75, 0x27, 0x62, 0xaa, 0xdf, 0xc0, 0xaf, 0x64, 0xf9,
		0x5f, 0xb3, 0x57, 0xef, 0x5c, 0x4f, 0xb5, 0x4f, 0x5f, 0x35, 0xf2, 0xf9, 0x75, 0xfb, 0xf1, 0x99,
		0xf4, 0xe1, 0x33, 0x0b, 0x73, 0x1d, 0x10, 0xe6, 0x2a, 0x0d, 0xcd, 0x23, 0xcc, 0xb5, 0xbb, 0x86,
		0x28, 0x61, 0x2e, 0x7c, 0x66, 0xf8, 0xcc, 0xf0, 0x99, 0xe1, 0x33, 0xc3, 0x67, 0xb6, 0x03, 0x3e,
		0x33, 0xc2, 0x5c, 0xdf, 0x67, 0x30, 0x84, 0xb9, 0x50, 0xd9, 0xa8, 0x6c, 0x54, 0x36, 0x2a, 0x1b,
		0x95, 0x5d, 0x12, 0x95, 0x4d, 0x98, 0xab, 0xba, 0xde, 0x05, 0x62, 0x03, 0xb3, 0xd8, 0x80, 0x76,
		0x17, 0xba, 0x32, 0x87, 0x06, 0x14, 0x9b, 0xcd, 0x51, 0x4f, 0x61, 0xd7, 0x4e, 0x52, 0xfd, 0xcb,
		0x2a, 0xcc, 0x9f, 0x9d, 0x5d, 0xb8, 0xdd, 0xaa, 0x13, 0x37, 0x53, 0x8d, 0x97, 0xa9, 0xdf, 0x66,
		0x3d, 0xa0, 0x9c, 0x82, 0x1d, 0x11, 0xa4, 0x9c, 0x42, 0x0d, 0x35, 0xa5, 0xe2, 0x7d, 0xd6, 0xe1,
		0x08, 0xa0, 0x33, 0x8b, 0x1b, 0xad, 0x93, 0x99, 0x08, 0xf6, 0xfb, 0x72, 0x7e, 0x51, 0xae, 0xaf,
		0x7a, 0xde, 0x2d, 0xca, 0xf5, 0x41, 0xc8, 0x97, 0xd1, 0x88, 0xb1, 0x21, 0xd8, 0x54, 0x06, 0xd5,
		0x12, 0xf2, 0x89, 0x31, 0xfd, 0x3e, 0xff, 0x79, 0xfa, 0xdc, 0x3b, 0xdf, 0xcb, 0x83, 0x2e, 0x81,
		0xdb, 0xa9, 0x71, 0xaa, 0xee, 0xa2, 0xc6, 0x51, 0xe3, 0x65, 0x50, 0xe3, 0xf4, 0xf2, 0xd8, 0x68,
		0x0a, 0x7a, 0x79, 0x94, 0x4f, 0xad, 0x2c, 0x4c, 0x47, 0x2f, 0x0f, 0x19, 0x11, 0xa1, 0x97, 0x47,
		0xe5, 0xc5, 0x84, 0x5e, 0x1e, 0x15, 0x65, 0x16, 0x74, 0x09, 0x84, 0x59, 0xc0, 0x2c, 0x60, 0x16,
		0x30, 0x0b, 0x98, 0x05, 0xcc, 0x02, 0x66, 0x01, 0xb3, 0x80, 0x59, 0xc0, 0x2c, 0x60, 0x16, 0x45,
		0xc4, 0x84, 0x2e, 0x81, 0xb0, 0x0a, 0x58, 0x05, 0xac, 0x02, 0x56, 0x51, 0x12, 0xfc, 0xda, 0xa3,
		0x4b, 0x20, 0x59, 0xed, 0x52, 0xe9, 0x28, 0xf5, 0xcf, 0x66, 0x57, 0xb8, 0xfc, 0x21, 0x98, 0xc6,
		0xfe, 0xa0, 0x44, 0xc7, 0x61, 0xa4, 0x22, 0x95, 0x30, 0xac, 0xf1, 0x2a, 0xca, 0xf2, 0xd1, 0x4e,
		0x89, 0x9e, 0xaf, 0xc6, 0xeb, 0x28, 0x79, 0x11, 0xbb, 0x91, 0xce, 0xcb, 0x64, 0xed, 0xad, 0x11,
		0xd9, 0x9c, 0x1b, 0xb9, 0xf5, 0xb4, 0xdd, 0x3e, 0x3e, 0x69, 0xb7, 0xf7, 0x4f, 0x0e, 0x4f, 0xf6,
		0x4f, 0x8f, 0x8e, 0x5a, 0xc7, 0x2d, 0x41, 0x96, 0xd6, 0x78, 0x93, 0x76, 0x5d, 0xea, 0xba, 0x3f,
		0x8d, 0x56, 0x3f, 0x19, 0xc6, 0x71, 0xa9, 0x84, 0x42, 0x09, 0x1b, 0x4b, 0x89, 0x89, 0x0d, 0xd1,
		0x5b, 0x25, 0x25, 0x42, 0x41, 0x19, 0xfc, 0x2b, 0x8e, 0x56, 0xc5, 0x46, 0x28, 0x28, 0xd2, 0xd2,
		0xa2, 0x5c, 0x22, 0x11, 0x16, 0x10, 0xdc, 0x32, 0x08, 0x6c, 0x31, 0x31, 0xdd, 0x5e, 0xb8, 0x0a,
		0x08, 0x96, 0xd0, 0xed, 0x31, 0xd1, 0xdb, 0x62, 0x42, 0x17, 0x2b, 0xc4, 0x2e, 0x50, 0x48, 0x7a,
		0x2c, 0xe4, 0x3d, 0x13, 0xd2, 0x1e, 0x08, 0x35, 0x4f, 0x83, 0x9a, 0x47, 0x41, 0xc5, 0x73, 0xe0,
		0x17, 0xea, 0xa5, 0x6e, 0x5f, 0x69, 0xa5, 0x6c, 0xeb, 0xa6, 0x68, 0x0b, 0xbb, 0x38, 0xc5, 0x5d,
		0x9a, 0x1a, 0x2e, 0x4c, 0x3d, 0x97, 0xa5, 0x96, 0x8b, 0x52, 0xdd, 0x25, 0xa9, 0xee, 0x82, 0x54,
		0x75, 0x39, 0x96, 0x8b, 0x1b, 0x8b, 0xbb, 0x10, 0xf5, 0x12, 0x11, 0x14, 0x12, 0x0f, 0x94, 0x12,
		0x0d, 0x14, 0x5c, 0x6d, 0x9a, 0x89, 0x04, 0xda, 0x91, 0x23, 0xe5, 0x44, 0x01, 0x8b, 0x88, 0xaf,
		0x46, 0x04, 0x52, 0x33, 0xf0, 0x6f, 0xb5, 0xa5, 0x8a, 0x81, 0x7d, 0x93, 0x6d, 0x2d, 0xa9, 0xff,
		0xf4, 0xac, 0x2c, 0x7e, 0x8d, 0xc7, 0x52, 0x96, 0xa6, 0x78, 0x0a, 0xaf, 0x6e, 0xca, 0x2e, 0x96,
		0x26, 0x96, 0x26, 0x96, 0x26, 0x96, 0x26, 0x96, 0x26, 0x96, 0x26, 0x96, 0x26, 0x96, 0x26, 0x96,
		0xa6, 0xb6, 0xa5, 0x49, 0x04, 0x4d, 0x30, 0x82, 0x26, 0x95, 0x03, 0xe3, 0x2f, 0x78, 0x26, 0x90,
		0xde, 0x52, 0x20, 0x6e, 0xf6, 0xc0, 0x50, 0x08, 0xa5, 0x84, 0xcf, 0xb7, 0xd0, 0x35, 0x0a, 0x05,
		0x1b, 0xfd, 0x88, 0xd9, 0x76, 0x02, 0xb6, 0xb9, 0x78, 0x6c, 0x21, 0x1a, 0x8d, 0xc4, 0x45, 0x97,
		0x9f, 0x2e, 0xfa, 0x05, 0x0a, 0xe2, 0xcd, 0x0c, 0xe4, 0xdb, 0xa1, 0xb6, 0x14, 0xd1, 0x62, 0x81,
		0xd7, 0xc2, 0xec, 0x57, 0x82, 0xed, 0xca, 0xb1, 0x5b, 0x29, 0x36, 0x2b, 0xce, 0x5e, 0xc5, 0xd9,
		0xaa, 0x28, 0x3b, 0xb5, 0x05, 0xd5, 0xa2, 0x81, 0xd2, 0xd9, 0x99, 0x91, 0x4b, 0x81, 0x98, 0x8d,
		0x58, 0xb2, 0x2c, 0x88, 0x7d, 0xb2, 0x20, 0x4a, 0xe0, 0x72, 0x22, 0x0b, 0xc2, 0xee, 0x70, 0xcf,
		0x06, 0x0a, 0x87, 0xf9, 0x27, 0x97, 0xe4, 0x51, 0x47, 0x36, 0x11, 0x74, 0x26, 0xc6, 0xf7, 0xc6,
		0x97, 0xf5, 0x4d, 0xb7, 0xf0, 0x4d, 0x4b, 0x8c, 0x8c, 0x6f, 0xda, 0x12, 0x38, 0x64, 0x3d, 0x18,
		0x52, 0xbe, 0x69, 0xe9, 0xa2, 0xd6, 0x8d, 0xce, 0xf4, 0x4c, 0x29, 0x15, 0xdf, 0x57, 0x69, 0x89,
		0xae, 0x5e, 0x7d, 0x7f, 0x9f, 0xea, 0xfb, 0xfa, 0xc0, 0x63, 0x06, 0x40, 0x66, 0x40, 0x64, 0x02,
		0x48, 0x4a, 0x8e, 0xda, 0xaa, 0x54, 0xdf, 0xbf, 0x6b, 0xa9, 0x04, 0x7f, 0x8e, 0xaf, 0x4c, 0x29,
		0x5f, 0x8a, 0x5f, 0x32, 0x27, 0x57, 0xe3, 0xad, 0x81, 0xce, 0x0e, 0xf0, 0xac, 0x80, 0xcf, 0x1c,
		0x00, 0xcd, 0x81, 0xd0, 0x14, 0x10, 0x75, 0x80, 0x51, 0x09, 0x20, 0x67, 0x2b, 0x63, 0x77, 0x35,
		0x3e, 0xed, 0x0f, 0xf3, 0xb1, 0x87, 0x3c, 0xcc, 0xb2, 0xb1, 0xb8, 0x71, 0x3d, 0x5e, 0x73, 0x77,
		0x1b, 0x2e, 0x09, 0x2f, 0x62, 0x83, 0x22, 0xf3, 0x93, 0x79, 0x94, 0xe4, 0xf3, 0x17, 0xd7, 0x0b,
		0x87, 0xf1, 0xf8, 0xe0, 0xf6, 0xc2, 0x38, 0xa3, 0x88, 0x3d, 0x9a, 0x0f, 0xcd, 0x87, 0xe6, 0xab,
		0x94, 0xe6, 0xbb, 0xe8, 0xf7, 0x63, 0x17, 0x26, 0x16, 0x0a, 0xaf, 0x45, 0x3d, 0x18, 0x89, 0x43,
		0x53, 0x9f, 0x7a, 0x30, 0xb3, 0x90, 0xf6, 0xec, 0x55, 0xf3, 0x2e, 0x9d, 0x6c, 0xaa, 0xb8, 0xc8,
		0xf6, 0xcc, 0xb2, 0x15, 0x7e, 0x9f, 0x3e, 0xe0, 0xec, 0xd5, 0xf9, 0xf3, 0x3b, 0x0f, 0x78, 0x3e,
		0xd1, 0xbd, 0x74, 0x32, 0x2d, 0x8a, 0x63, 0x74, 0x32, 0xc5, 0x97, 0x5a, 0x12, 0x83, 0x0a, 0x5f,
		0xaa, 0x9d, 0x36, 0xc4, 0x97, 0x0a, 0xa3, 0x84, 0x51, 0xc2, 0x28, 0x61, 0x94, 0xa5, 0x61, 0x94,
		0xf8, 0x52, 0x4d, 0x77, 0x17, 0x5f, 0x2a, 0x9a, 0x0f, 0xcd, 0x87, 0xe6, 0x43, 0xf3, 0x79, 0xd7,
		0x7c, 0xf8, 0x52, 0x2b, 0xc6, 0x1e, 0x77, 0xca, 0x97, 0x5a, 0xed, 0x9a, 0xda, 0x3f, 0x76, 0xa5,
		0x52, 0x4c, 0xdb, 0xb7, 0xdc, 0x97, 0x4a, 0xde, 0x2b, 0x57, 0x2f, 0xf9, 0x87, 0x12, 0xde, 0xa8,
		0x51, 0x41, 0x21, 0xe1, 0xdc, 0x6a, 0x9d, 0x9c, 0x6a, 0x2e, 0x69, 0x70, 0x49, 0x83, 0x4b, 0x1a,
		0xa2, 0x9a, 0x47, 0xfc, 0x92, 0x46, 0x1c, 0x5e, 0xb8, 0x38, 0xc8, 0x06, 0x4a, 0x4d, 0xc0, 0x66,
		0xc7, 0xe1, 0xde, 0x3c, 0x3a, 0x81, 0xc6, 0x7d, 0x2e, 0x6d, 0x10, 0x68, 0x2c, 0xa1, 0x97, 0x81,
		0x40, 0xa3, 0x9e, 0x17, 0x41, 0xbf, 0xe9, 0xaf, 0x62, 0xb3, 0x5f, 0xe5, 0x26, 0xbf, 0x8a, 0x3e,
		0x1b, 0x8b, 0xa6, 0xbe, 0x46, 0x9d, 0x5a, 0xad, 0x9a, 0xf8, 0x5a, 0x76, 0x65, 0x55, 0x6c, 0xda,
		0x6b, 0xd2, 0xac, 0xd7, 0x7a, 0xeb, 0x0d, 0x9a, 0xf3, 0x9a, 0x6e, 0x7f, 0x45, 0xdc, 0x9b, 0x67,
		0x3b, 0x90, 0xb8, 0x17, 0x67, 0xa9, 0xae, 0x65, 0x7d, 0x33, 0x3e, 0x16, 0x35, 0x16, 0x35, 0x16,
		0x35, 0x16, 0xb5, 0xa0, 0xbc, 0x47, 0x83, 0x20, 0xec, 0x76, 0x53, 0x97, 0x65, 0x8a, 0x56, 0x75,
		0xeb, 0x54, 0x61, 0xec, 0xc9, 0xda, 0x54, 0xce, 0xaa, 0xbe, 0x5d, 0xf9, 0xcf, 0x6d, 0xc5, 0xb5,
		0x5f, 0xd8, 0x83, 0xa7, 0x8a, 0x73, 0xbc, 0x0d, 0xf3, 0xdc, 0xa5, 0x89, 0xda, 0x76, 0xcc, 0x26,
		0x7a, 0xf8, 0xf0, 0xe3, 0x7e, 0x70, 0x7a, 0xf6, 0xed, 0x63, 0x2b, 0x38, 0x3d, 0xbb, 0x79, 0xd9,
		0x1a, 0xff, 0xe7, 0xe6, 0xf5, 0xc1, 0xc7, 0xfd, 0xa0, 0x3d, 0x7d, 0x7d, 0xf4, 0x71, 0x3f, 0x38,
		0x3a, 0x7b, 0xf4, 0xc7, 0x1f, 0x4f, 0x1e, 0xfd, 0x7d, 0x78, 0xbd, 0xf9, 0x07, 0xf5, 0x92, 0x03,
		0xce, 0x34, 0xb7, 0xe2, 0xcd, 0xfb, 0x97, 0xff, 0x6d, 0xb6, 0x1f, 0xff, 0xb6, 0xdc, 0x90, 0x7f,
		0x28, 0xee, 0x48, 0x95, 0xd2, 0x35, 0x6c, 0xc0, 0xe9, 0x18, 0x70, 0xda, 0x0a, 0x9c, 0xc2, 0xa0,
		0xf7, 0x3c, 0xf8, 0xf5, 0xec, 0xef, 0xd6, 0xe3, 0xf6, 0xf5, 0xb3, 0x47, 0x7f, 0x9f, 0x5c, 0xdf,
		0x7f, 0xf3, 0xdb, 0xb2, 0x3f, 0x6b, 0x3d, 0x3e, 0xb9, 0x7e, 0xb6, 0xe2, 0x5f, 0x8e, 0xaf, 0x9f,
		0xad, 0x39, 0xc6, 0xd1, 0xf5, 0xc3, 0x85, 0x3f, 0x1d, 0xbd, 0x7f, 0xb0, 0xea, 0x03, 0xed, 0x15,
		0x1f, 0x38, 0x5c, 0xf5, 0x81, 0xc3, 0x15, 0x1f, 0x58, 0xf9, 0x95, 0x0e, 0x56, 0x7c, 0xe0, 0xe8,
		0xfa, 0xdb, 0xc2, 0xdf, 0x3f, 0x5c, 0xfe, 0xa7, 0xc7, 0xd7, 0x8f, 0xbe, 0xad, 0xfa, 0xb7, 0x93,
		0xeb, 0x6f, 0xcf, 0x1e, 0x01, 0xd5, 0xeb, 0x43, 0x35, 0xe2, 0x69, 0x2f, 0x9e, 0xd5, 0x53, 0x5c,
		0xbb, 0xe3, 0x05, 0x22, 0xe9, 0x48, 0x3d, 0xe9, 0x48, 0xfc, 0x86, 0xb2, 0xb7, 0x64, 0x23, 0xc9,
		0xab, 0xc8, 0x65, 0xea, 0x5a, 0x16, 0x76, 0xff, 0x6f, 0xd8, 0x71, 0x49, 0x27, 0x72, 0x99, 0x56,
		0xe3, 0xb2, 0xf9, 0x29, 0x4a, 0x9e, 0x7a, 0x74, 0x40, 0xea, 0x51, 0x85, 0xfc, 0x92, 0xa4, 0x1e,
		0x95, 0x38, 0xf5, 0xe8, 0xee, 0xd9, 0xff, 0xaa, 0x17, 0x21, 0xb9, 0x3f, 0x11, 0x55, 0x0e, 0x08,
		0x95, 0x78, 0x83, 0x24, 0x33, 0x68, 0x32, 0x81, 0x28, 0x1d, 0x52, 0x50, 0x99, 0x2a, 0x07, 0xf7,
		0x3a, 0xfc, 0xab, 0xdf, 0x21, 0xbd, 0x37, 0x9f, 0xee, 0x1d, 0xcf, 0x16, 0x77, 0x3c, 0x3d, 0x02,
		0x9d, 0x15, 0xe0, 0x99, 0x03, 0x9f, 0x39, 0x00, 0x9a, 0x02, 0xa1, 0x9e, 0x97, 0x64, 0x4f, 0xf1,
		0x8e, 0xa7, 0x16, 0x40, 0xce, 0x91, 0x72, 0x8d, 0xea, 0x55, 0x2b, 0x4f, 0xa5, 0xd6, 0x5d, 0x3d,
		0x43, 0x98, 0x54, 0xb7, 0x03, 0x7d, 0xc0, 0xa6, 0x3d, 0x7c, 0x5a, 0xc3, 0xa8, 0x37, 0x38, 0xf5,
		0x06, 0xab, 0x5e, 0xe0, 0x55, 0x17, 0x66, 0x95, 0xe1, 0xd6, 0x0c, 0x76, 0x67, 0x13, 0x4d, 0xb8,
		0x6f, 0x6e, 0x27, 0xfe, 0xb3, 0x9a, 0x5c, 0xd3, 0x99, 0x8d, 0x84, 0xd0, 0x26, 0x6f, 0xd8, 0xcc,
		0x96, 0xf5, 0x09, 0xd2, 0xfe, 0xc0, 0xda, 0x17, 0x68, 0x7b, 0x07, 0x6f, 0xef, 0x20, 0xee, 0x15,
		0xcc, 0x6d, 0x40, 0xdd, 0x08, 0xdc, 0x67, 0x2b, 0xa9, 0x5e, 0x3f, 0x65, 0xe5, 0x79, 0x55, 0xbb,
		0x11, 0xf5, 0x23, 0xf4, 0x3d, 0x36, 0x9c, 0x52, 0xf7, 0x06, 0xd5, 0xaa, 0x1f, 0x5b, 0x3c, 0xda,
		0xb3, 0xba, 0x71, 0x55, 0x12, 0xb5, 0xba, 0x30, 0xbd, 0xd1, 0x0d, 0xad, 0x95, 0xf3, 0x1b, 0x5e,
		0xdd, 0xf1, 0x0c, 0x57, 0x77, 0x45, 0x2e, 0xfc, 0xb2, 0xf3, 0x22, 0x67, 0x70, 0x33, 0xac, 0xd4,
		0x62, 0xf7, 0xa0, 0x9e, 0xb3, 0x9d, 0x3d, 0xa8, 0xc7, 0xf3, 0x18, 0xc0, 0xc2, 0x24, 0xea, 0xe0,
		0xbe, 0x0c, 0xa2, 0x54, 0xaf, 0xd8, 0xd7, 0x77, 0x2d, 0x99, 0x85, 0x6f, 0x00, 0x9b, 0x84, 0x4d,
		0xc2, 0x26, 0x61, 0x93, 0xb0, 0x49, 0xb3, 0xf3, 0x9a, 0x47, 0x57, 0x2e, 0x8f, 0x3a, 0x7f, 0x66,
		0xc7, 0x6d, 0x0f, 0x94, 0xf2, 0xa9, 0xe1, 0x94, 0xff, 0x4a, 0x6e, 0xac, 0xad, 0x46, 0x12, 0x26,
		0xfd, 0xcc, 0x75, 0xfa, 0x49, 0x37, 0x6b, 0x40, 0x69, 0xa1, 0xb4, 0x50, 0x5a, 0x28, 0x6d, 0x0d,
		0x44, 0xae, 0xf5, 0xb4, 0xdd, 0x3e, 0x3e, 0x69, 0xb7, 0xf7, 0x4f, 0x0e, 0x4f, 0xf6, 0x4f, 0x8f,
		0x8e, 0x5a, 0xc7, 0x2d, 0x18, 0x2e, 0x0c, 0x77, 0x87, 0x19, 0x6e, 0xe2, 0x2e, 0xfb, 0x79, 0x14,
		0xe6, 0xae, 0x6b, 0xcf, 0x6d, 0xe7, 0xe6, 0x86, 0xd5, 0xc2, 0x6a, 0x61, 0xb5, 0xb0, 0x5a, 0x58,
		0xad, 0xd9, 0x79, 0x25, 0x46, 0x0a, 0xa1, 0x84, 0x50, 0x42, 0x28, 0x21, 0x94, 0x05, 0x44, 0x8e,
		0x18, 0x29, 0x0c, 0x72, 0xe7, 0x19, 0xe4, 0x97, 0x3c, 0x18, 0x87, 0x29, 0x7d, 0x30, 0xc8, 0xd9,
		0xdc, 0x30, 0x48, 0x18, 0x24, 0x0c, 0x12, 0x06, 0x09, 0x83, 0x34, 0x3b, 0xaf, 0xc4, 0x45, 0xa1,
		0xb1, 0xd0, 0x58, 0x68, 0x2c, 0x34, 0xb6, 0xea, 0x22, 0x47, 0x5c, 0x14, 0x56, 0x5b, 0x21, 0x56,
		0x5b, 0xe9, 0xab, 0xaf, 0xca, 0xad, 0x83, 0x17, 0xe6, 0xf3, 0x5b, 0xe5, 0x70, 0xa1, 0xcc, 0xdd,
		0xbd, 0x77, 0xbe, 0x36, 0xef, 0x56, 0x76, 0x69, 0x5a, 0x14, 0x30, 0xd8, 0xf3, 0x59, 0x2d, 0xf1,
		0x3f, 0x47, 0xcf, 0xfb, 0xfc, 0x76, 0x41, 0xee, 0xbe, 0xf1, 0xf5, 0xe6, 0xd7, 0xff, 0x9c, 0x2c,
		0x87, 0x46, 0x6f, 0x62, 0xbb, 0xe3, 0x54, 0xad, 0x52, 0x20, 0x46, 0x07, 0xb3, 0x62, 0x07, 0x52,
		0xb3, 0xc0, 0x4f, 0x25, 0x8e, 0x60, 0xa3, 0x2a, 0x0d, 0xf3, 0x15, 0x4a, 0xce, 0x45, 0x49, 0xee,
		0xd2, 0x5e, 0xd8, 0x71, 0x41, 0xea, 0x7a, 0xfa, 0x45, 0xbe, 0xee, 0x4e, 0x47, 0x8d, 0xaf, 0xa5,
		0x13, 0x18, 0xd7, 0xf8, 0x8a, 0x7a, 0x94, 0xf8, 0xda, 0x62, 0x42, 0xdf, 0x25, 0xbe, 0xa2, 0x1e,
		0x15, 0xbe, 0x6e, 0x16, 0x86, 0x0a, 0x5f, 0xa5, 0x03, 0xc9, 0x45, 0xb0, 0xac, 0x69, 0x85, 0x2f,
		0x55, 0xf0, 0xb4, 0x06, 0x51, 0x6f, 0x60, 0xea, 0x0d, 0x54, 0x7d, 0x80, 0x6b, 0x3d, 0x9c, 0x1c,
		0x66, 0xf5, 0xbd, 0x66, 0x26, 0xa3, 0x7d, 0xf2, 0xc1, 0xed, 0xd4, 0xe4, 0x1e, 0x54, 0x0d, 0xa4,
		0xbd, 0x81, 0xb5, 0x2f, 0xd0, 0xf6, 0x0e, 0xde, 0xde, 0x41, 0xdc, 0x27, 0x98, 0xdb, 0x80, 0xba,
		0x11, 0xb8, 0xcf, 0x16, 0xd2, 0x5f, 0xe6, 0x41, 0xec, 0xc2, 0x9e, 0x9e, 0x8b, 0xe0, 0xbb, 0x16,
		0xf1, 0x89, 0xe1, 0x9c, 0x6f, 0x67, 0x3e, 0xc2, 0x91, 0x98, 0x3e, 0x9b, 0x29, 0x9c, 0xec, 0xfe,
		0x1b, 0x93, 0xdf, 0xc7, 0x9e, 0x34, 0x52, 0x17, 0xd7, 0x67, 0x6e, 0xc3, 0x0b, 0x8f, 0xf6, 0xc3,
		0x9d, 0xd9, 0x31, 0x21, 0x30, 0x21, 0x30, 0x21, 0x30, 0x21, 0x30, 0x21, 0x30, 0x21, 0xbc, 0x98,
		0x10, 0x1f, 0x6f, 0x4d, 0x88, 0xff, 0xe8, 0x0c, 0xd3, 0xd4, 0x25, 0xf9, 0xc3, 0x47, 0xcd, 0x27,
		0x4f, 0x9a, 0xb3, 0xbf, 0x38, 0x9b, 0x7c, 0x64, 0x5e, 0x6f, 0x65, 0x4b, 0xde, 0x9b, 0x8d, 0xdc,
		0x75, 0x5f, 0x1a, 0xa4, 0x9c, 0x94, 0xc0, 0x1b, 0x43, 0xca, 0xc9, 0xdd, 0x08, 0xf7, 0x9d, 0x38,
		0x23, 0x19, 0x27, 0x2f, 0xa7, 0xcb, 0xf1, 0xce, 0xf5, 0x48, 0x38, 0x31, 0x3b, 0x9e, 0x24, 0x9c,
		0x2c, 0x3b, 0x8e, 0xbb, 0x98, 0x6f, 0x32, 0x7f, 0x00, 0x77, 0x39, 0xdd, 0x24, 0xee, 0x77, 0xc2,
		0x38, 0x08, 0xbb, 0xdd, 0xd4, 0x65, 0x99, 0x7e, 0xba, 0xc9, 0xdd, 0xe9, 0x74, 0xd3, 0x4d, 0xf6,
		0xb5, 0xd3, 0x4d, 0x0e, 0x68, 0x29, 0x57, 0x1e, 0xca, 0x4c, 0x4b, 0xb9, 0x1d, 0x56, 0xeb, 0xea,
		0x9c, 0xd6, 0x90, 0xc3, 0x5a, 0x70, 0xd6, 0x19, 0x47, 0x7d, 0xf2, 0xe4, 0xc6, 0x16, 0x6f, 0xde,
		0x05, 0xe6, 0x1d, 0x56, 0x88, 0xa9, 0xbb, 0xea, 0xe7, 0xce, 0x4e, 0x23, 0xde, 0x9b, 0x0f, 0x95,
		0x88, 0x4a, 0x44, 0x25, 0xa2, 0x12, 0x51, 0x89, 0xde, 0x55, 0xe2, 0x3d, 0x64, 0xde, 0x61, 0x9d,
		0xa8, 0x9b, 0x6e, 0x6b, 0x92, 0x66, 0xcb, 0x1d, 0x04, 0x34, 0x20, 0x1a, 0x70, 0xa7, 0x34, 0xa0,
		0xfa, 0x2d, 0x84, 0x99, 0x3b, 0x35, 0xc8, 0x2d, 0x62, 0xaa, 0xf7, 0xdb, 0xdc, 0x4e, 0xe7, 0xb5,
		0xb9, 0x97, 0xb0, 0x6f, 0x75, 0x2f, 0x61, 0x9f, 0xce, 0xe3, 0xe5, 0x07, 0x56, 0x6f, 0x00, 0xeb,
		0x0d, 0x68, 0xbd, 0x00, 0xae, 0x2e, 0xf0, 0x2a, 0x03, 0xb0, 0x1d, 0x15, 0x59, 0x38, 0x6f, 0x57,
		0x83, 0x38, 0x1b, 0xed, 0x4c, 0x60, 0x0a, 0x95, 0x77, 0xec, 0xcc, 0xb6, 0xc1, 0x5c, 0x2f, 0x92,
		0xe1, 0xd5, 0x68, 0x61, 0xaf, 0xab, 0x1a, 0x3b, 0x56, 0xb4, 0x30, 0x6f, 0x22, 0x9e, 0xdd, 0xb4,
		0x3f, 0x18, 0x18, 0x34, 0x5a, 0xb8, 0xd7, 0x3c, 0x70, 0x3a, 0x2d, 0xaa, 0x19, 0xd5, 0x8c, 0x6a,
		0x46, 0x35, 0xa3, 0x9a, 0x67, 0xe7, 0xad, 0xd3, 0x1f, 0x26, 0xb9, 0x4b, 0x4d, 0xea, 0x57, 0x1a,
		0xd6, 0xad, 0x34, 0xae, 0x17, 0x69, 0x98, 0xbd, 0xeb, 0xa3, 0x3e, 0xa4, 0xa7, 0x22, 0x7d, 0xbe,
		0xea, 0x41, 0xfa, 0xac, 0xc0, 0x67, 0x58, 0xff, 0xd1, 0x4b, 0xdd, 0x47, 0xdf, 0xa2, 0xe4, 0xbf,
		0xce, 0xa3, 0x57, 0xe9, 0xaa, 0x49, 0x32, 0xfa, 0x19, 0x0c, 0x6b, 0x05, 0xc3, 0x4a, 0x5d, 0xc7,
		0x45, 0x9f, 0xed, 0x29, 0xd6, 0x6c, 0x5e, 0x38, 0x16, 0x1c, 0x0b, 0x8e, 0x05, 0xc7, 0x82, 0x63,
		0xc1, 0xb1, 0xe0, 0x58, 0x70, 0x2c, 0x38, 0x16, 0x1c, 0x0b, 0x8e, 0x05, 0xc7, 0xaa, 0x05, 0xc7,
		0x8a, 0xc3, 0x2c, 0x0f, 0x3a, 0xb1, 0x0b, 0x53, 0x3b, 0x7e, 0x35, 0x37, 0x27, 0xdc, 0x0a, 0x6e,
		0x05, 0xb7, 0x82, 0x5b, 0xc1, 0xad, 0x3c, 0x75, 0x60, 0xb3, 0x64, 0x57, 0x9e, 0x3a, 0xae, 0xc1,
		0xea, 0x60, 0x75, 0xb0, 0x3a, 0x58, 0x1d, 0xac, 0x0e, 0x56, 0xb7, 0x2b, 0xac, 0xce, 0xa4, 0xe8,
		0xc6, 0x22, 0xb1, 0x33, 0x28, 0xbe, 0x01, 0xb7, 0x83, 0xdb, 0xc1, 0xed, 0xe0, 0x76, 0x95, 0xe4,
		0x76, 0xd1, 0xc0, 0x08, 0x1d, 0xe7, 0x11, 0xb2, 0x75, 0x6a, 0x30, 0xd7, 0x64, 0x2d, 0x6b, 0x47,
		0xb1, 0x6e, 0x77, 0xee, 0x73, 0xdb, 0x70, 0xef, 0x16, 0xf6, 0xf0, 0xa9, 0x6d, 0x7d, 0xd1, 0xdc,
		0xa5, 0x89, 0x79, 0x6f, 0xf2, 0xc6, 0xc3, 0x87, 0x1f, 0xf7, 0x83, 0xd3, 0xb3, 0x6f, 0x1f, 0x5b,
		0xc1, 0xe9, 0xd9, 0xcd, 0xcb, 0xd6, 0xf8, 0x3f, 0x37, 0xaf, 0x0f, 0x3e, 0xee, 0x07, 0xed, 0xe9,
		0xeb, 0xa3, 0x8f, 0xfb, 0xc1, 0xd1, 0xd9, 0xa3, 0x3f, 0xfe, 0x78, 0xf2, 0xe8, 0xef, 0xc3, 0xeb,
		0xcd, 0x3f, 0x68, 0x57, 0xdd, 0xf7, 0xcc, 0x72, 0xeb, 0xde, 0xbc, 0x7f, 0xf9, 0xdf, 0xde, 0xf6,
		0xef, 0xdf, 0x96, 0x1b, 0xf8, 0x8f, 0x46, 0xdd, 0x9a, 0x2c, 0x3f, 0xae, 0x31, 0x78, 0x1e, 0x03,
		0x9e, 0x26, 0xe0, 0x19, 0x06, 0xbd, 0xe7, 0xc1, 0xaf, 0x67, 0x7f, 0xb7, 0x1e, 0xb7, 0xaf, 0x9f,
		0x3d, 0xfa, 0xfb, 0xe4, 0xfa, 0xfe, 0x9b, 0xdf, 0x96, 0xfd, 0x59, 0xeb, 0xf1, 0xc9, 0xf5, 0xb3,
		0x15, 0xff, 0x72, 0x7c, 0xfd, 0x6c, 0xcd, 0x31, 0x8e, 0xae, 0x1f, 0x2e, 0xfc, 0xe9, 0xe8, 0xfd,
		0x83, 0x55, 0x1f, 0x68, 0xaf, 0xf8, 0xc0, 0xe1, 0xaa, 0x0f, 0x1c, 0xae, 0xf8, 0xc0, 0xca, 0xaf,
		0x74, 0xb0, 0xe2, 0x03, 0x47, 0xd7, 0xdf, 0x16, 0xfe, 0xfe, 0xe1, 0xf2, 0x3f, 0x3d, 0xbe, 0x7e,
		0xf4, 0x6d, 0xd5, 0xbf, 0x9d, 0x5c, 0x7f, 0x7b, 0xf6, 0x08, 0x55, 0xa2, 0xa7, 0x4a, 0x10, 0x67,
		0x7b, 0x71, 0xae, 0x9f, 0x62, 0xc5, 0x07, 0xe9, 0xc1, 0x07, 0x69, 0x54, 0xe7, 0x70, 0xc1, 0xd8,
		0x30, 0xa9, 0x77, 0x88, 0x17, 0x12, 0x2f, 0x24, 0x5e, 0x48, 0xbc, 0x90, 0x78, 0x21, 0xf1, 0x42,
		0xe2, 0x85, 0xc4, 0x0b, 0x89, 0x17, 0x12, 0x2f, 0x24, 0x5e, 0x48, 0xbc, 0x90, 0x80, 0x27, 0x6e,
		0x1b, 0xbc, 0x90, 0x78, 0x21, 0x11, 0x67, 0xbc, 0x90, 0x78, 0x21, 0xbd, 0x8e, 0x4c, 0x87, 0x3f,
		0xdd, 0x0e, 0x7f, 0xda, 0x2d, 0x36, 0x4b, 0xdb, 0xd9, 0x4f, 0xb1, 0x9b, 0xa6, 0x42, 0xb7, 0x86,
		0x07, 0x25, 0x3e, 0x53, 0x8d, 0x7f, 0xba, 0xaf, 0x8b, 0x2e, 0xfb, 0x3d, 0xcd, 0x34, 0xe2, 0xc6,
		0xab, 0x28, 0xcb, 0x9f, 0xe7, 0xb9, 0xce, 0x75, 0xd7, 0xc6, 0xeb, 0x28, 0x79, 0x11, 0xbb, 0x2b,
		0x97, 0xdc, 0x24, 0xf3, 0x2b, 0xb4, 0xca, 0x78, 0x1d, 0x7e, 0x99, 0x9b, 0xc1, 0xe6, 0x0a, 0x43,
		0xe3, 0x4d, 0xda, 0x75, 0xa9, 0xeb, 0xfe, 0x34, 0xda, 0xad, 0x64, 0x18, 0xc7, 0xa5, 0x16, 0x2a,
		0x65, 0x80, 0x2e, 0x3b, 0x30, 0x37, 0x54, 0xfa, 0xb3, 0x94, 0x12, 0x8a, 0x65, 0x41, 0x58, 0x0e,
		0x2a, 0x65, 0x46, 0x12, 0x3a, 0x17, 0x5a, 0xe7, 0xa1, 0x6c, 0xe7, 0x40, 0x50, 0xee, 0x4b, 0x23,
		0xef, 0x32, 0x02, 0x5e, 0x5c, 0x1c, 0x05, 0x44, 0xb1, 0x11, 0x87, 0x17, 0x2e, 0x0e, 0xb2, 0x41,
		0xd8, 0x71, 0x41, 0x24, 0x57, 0xcd, 0x6f, 0xae, 0xaa, 0xc4, 0x9d, 0xf1, 0x85, 0x0e, 0x8f, 0x6c,
		0x7c, 0x5f, 0x3c, 0x8e, 0xaf, 0x11, 0xaf, 0xd7, 0x8b, 0xcb, 0x6b, 0xc5, 0xdf, 0xd5, 0xe3, 0xec,
		0xea, 0xf1, 0x74, 0xd5, 0xb8, 0x79, 0xb9, 0xd4, 0x91, 0x78, 0xbc, 0x5b, 0xb1, 0x4f, 0xa0, 0x46,
		0x5f, 0xc0, 0xf9, 0x3e, 0x80, 0x37, 0x5a, 0xa5, 0x79, 0x0f, 0xba, 0xea, 0x04, 0xfa, 0x59, 0xaa,
		0x03, 0xf6, 0x37, 0xe3, 0x02, 0xf2, 0x80, 0x3c, 0x20, 0x0f, 0xc8, 0x57, 0x02, 0xe4, 0x6f, 0x20,
		0xab, 0x46, 0xe0, 0x2e, 0xdb, 0xb5, 0x55, 0xa5, 0x4b, 0xab, 0x70, 0x57, 0x56, 0xf1, 0x3e, 0xe4,
		0x40, 0x3b, 0xd0, 0x5e, 0x31, 0x68, 0x97, 0xee, 0x7a, 0xaa, 0xe5, 0x18, 0xb0, 0x71, 0x10, 0x28,
		0xd9, 0x90, 0x6a, 0xb6, 0xa4, 0x26, 0xf0, 0xe8, 0x03, 0x90, 0x36, 0x10, 0x99, 0x01, 0x92, 0x19,
		0x30, 0x99, 0x00, 0x94, 0x2c, 0x50, 0x09, 0x03, 0x96, 0x9e, 0x4d, 0xba, 0x20, 0xef, 0xc3, 0x28,
		0xc9, 0x5b, 0xc7, 0x1a, 0xf2, 0x3e, 0x41, 0x97, 0x63, 0x85, 0xa1, 0x75, 0xab, 0x23, 0x2a, 0x26,
		0x48, 0x58, 0x54, 0x3f, 0xb4, 0xba, 0xdf, 0x65, 0x54, 0xdd, 0xd0, 0xb2, 0xde, 0x9c, 0xe6, 0xdd,
		0x42, 0x8b, 0x6a, 0x85, 0xd6, 0x5b, 0x7f, 0x7c, 0x74, 0x74, 0x78, 0x54, 0xa3, 0xed, 0xaf, 0x48,
		0x82, 0xcc, 0x59, 0x59, 0x63, 0xc8, 0x82, 0xb4, 0x4d, 0xd8, 0x0b, 0xbb, 0x68, 0x59, 0x4b, 0x7a,
		0x63, 0xb1, 0xa8, 0xb1, 0xa8, 0xb1, 0xa8, 0xb1, 0xa8, 0xf5, 0xaf, 0xaa, 0x6a, 0x5e, 0x4d, 0xd5,
		0xbd, 0x8a, 0xaa, 0x68, 0x55, 0x1b, 0x5f, 0x35, 0xb5, 0xb8, 0x1d, 0x65, 0x76, 0x1b, 0xaa, 0x26,
		0x57, 0x47, 0xcf, 0x34, 0xb7, 0xc2, 0xf2, 0x3e, 0x4f, 0x6d, 0xae, 0x82, 0x9e, 0x55, 0xe9, 0x86,
		0x84, 0x0d, 0x38, 0x1d, 0x03, 0x4e, 0x5b, 0x81, 0x13, 0x77, 0xd9, 0xea, 0x74, 0x35, 0xb3, 0x76,
		0x50, 0x8d, 0x78, 0xd6, 0xea, 0xaa, 0xe5, 0x19, 0x5e, 0xa0, 0xd2, 0x78, 0x81, 0x32, 0x97, 0x65,
		0x51, 0x3f, 0x09, 0x64, 0xd3, 0x36, 0x16, 0x74, 0xf3, 0xdd, 0x69, 0xf0, 0x09, 0xe1, 0x13, 0xc2,
		0x27, 0x84, 0x4f, 0x48, 0x50, 0xde, 0x5d, 0x32, 0xbc, 0x72, 0xe9, 0xcd, 0x85, 0x26, 0x45, 0xa7,
		0x50, 0x5b, 0x61, 0xec, 0x17, 0xc9, 0xf0, 0x6a, 0xb4, 0x38, 0xd7, 0x5c, 0x5c, 0x5b, 0xe7, 0x30,
		0xd5, 0xf2, 0xe2, 0x9a, 0xb4, 0x5e, 0xf4, 0x76, 0x59, 0x4d, 0xf0, 0x1e, 0xbc, 0x40, 0x3e, 0xeb,
		0x03, 0x8f, 0x12, 0x3b, 0xbd, 0xc7, 0x7e, 0x13, 0x07, 0xdb, 0x13, 0x4d, 0x34, 0x93, 0xbd, 0xb0,
		0x2e, 0x7f, 0x41, 0xdd, 0xe4, 0x42, 0xba, 0xec, 0x05, 0xf4, 0xa2, 0xbb, 0x2d, 0x8c, 0x4b, 0x7e,
		0xf1, 0xa8, 0x21, 0x92, 0x08, 0xee, 0x05, 0x81, 0x8a, 0x61, 0xcf, 0xf6, 0x88, 0xb1, 0xdd, 0x27,
		0xb7, 0x94, 0x3a, 0x29, 0x69, 0xf3, 0x22, 0x65, 0x05, 0x84, 0xcb, 0x58, 0xa8, 0xb6, 0x93, 0xa5,
		0xcd, 0x25, 0x61, 0x0b, 0x29, 0x68, 0xe4, 0x61, 0x7a, 0xe9, 0x72, 0xb7, 0x7d, 0x02, 0xc7, 0x6d,
		0x6f, 0xe9, 0xe9, 0x48, 0x5b, 0xca, 0x62, 0xb1, 0xdb, 0x14, 0x85, 0x69, 0xb6, 0x04, 0x9d, 0x96,
		0xa3, 0xcd, 0x52, 0xf4, 0x58, 0x9c, 0x06, 0x8b, 0xd3, 0x5d, 0x51, 0x5a, 0x6b, 0x8b, 0x9e, 0x45,
		0x6f, 0x2b, 0x34, 0x26, 0x51, 0xa6, 0xa0, 0x17, 0x5e, 0x45, 0x71, 0xe4, 0x8a, 0x37, 0x32, 0x98,
		0x09, 0xe0, 0xc2, 0xc8, 0x45, 0x8d, 0x50, 0x91, 0xab, 0x4e, 0x62, 0xbe, 0x30, 0x49, 0xdf, 0x97,
		0xbc, 0xaf, 0x4b, 0xda, 0xb7, 0xa5, 0xe6, 0xcb, 0x52, 0xf3, 0x5d, 0xa9, 0xf8, 0xaa, 0xfc, 0xd2,
		0x30, 0xa9, 0xab, 0x49, 0x77, 0x8f, 0xe6, 0x57, 0xf9, 0x2b, 0x8e, 0xf7, 0xc6, 0x2f, 0xf9, 0x5d,
		0x47, 0xae, 0xb1, 0x8b, 0xfa, 0x17, 0xb9, 0xeb, 0x58, 0x19, 0x0f, 0xa4, 0xf8, 0x5d, 0xc7, 0xb0,
		0x17, 0x05, 0x13, 0x4a, 0xa3, 0x14, 0x7e, 0x9b, 0xcd, 0x40, 0xe4, 0x8d, 0xc8, 0x9b, 0x37, 0x10,
		0x32, 0x03, 0x23, 0x13, 0x50, 0x92, 0x05, 0x27, 0x61, 0x90, 0x9a, 0xad, 0x80, 0x7e, 0xe4, 0x4d,
		0xbe, 0xf6, 0xc6, 0x82, 0xed, 0x72, 0xa2, 0x30, 0xf6, 0x62, 0x2d, 0x8e, 0x19, 0x48, 0xee, 0x40,
		0xda, 0x47, 0x67, 0x8a, 0xb0, 0x4a, 0x0a, 0x67, 0x32, 0xbe, 0x8e, 0xba, 0x69, 0xa1, 0x6e, 0x50,
		0x37, 0xa8, 0x9b, 0x32, 0xaa, 0x1b, 0x69, 0xdb, 0x58, 0xdf, 0x46, 0xb6, 0xb2, 0x95, 0x95, 0x6d,
		0x66, 0x75, 0x30, 0xb3, 0x00, 0x35, 0x3b, 0x70, 0xb3, 0x02, 0x39, 0x73, 0xb0, 0x33, 0x07, 0x3d,
		0x53, 0xf0, 0xd3, 0x01, 0x41, 0x25, 0x30, 0xd4, 0xb7, 0xc1, 0x17, 0xce, 0xcb, 0xd5, 0x20, 0xce,
		0x46, 0x2b, 0x1f, 0x84, 0xbd, 0xc8, 0xe2, 0x0a, 0x4c, 0x5b, 0x71, 0x0e, 0x9d, 0xb4, 0x38, 0x3d,
		0x09, 0xba, 0xa6, 0xff, 0x81, 0x4d, 0x22, 0xc1, 0x34, 0x5e, 0xdd, 0xbc, 0x1f, 0x2b, 0xbb, 0xfb,
		0xc6, 0xd7, 0xa6, 0x0a, 0x09, 0xd9, 0x33, 0x4b, 0x43, 0xf8, 0x30, 0x79, 0xce, 0xf3, 0xe7, 0x37,
		0x8f, 0xf5, 0xeb, 0xe4, 0x31, 0xef, 0xfc, 0xfe, 0xf5, 0x7c, 0xa2, 0xf0, 0x77, 0xe1, 0xae, 0x82,
		0xf2, 0x1d, 0x05, 0xc5, 0xbb, 0x09, 0x6a, 0x94, 0xf5, 0x00, 0xca, 0x0a, 0x65, 0x85, 0xb2, 0x42,
		0x59, 0xa1, 0xac, 0x50, 0x56, 0x28, 0x2b, 0x94, 0x15, 0xca, 0x0a, 0x65, 0x85, 0xb2, 0x56, 0x95,
		0xb2, 0x6a, 0xf5, 0x4f, 0x2d, 0x15, 0x63, 0x55, 0xe8, 0x95, 0x5a, 0x4e, 0xc2, 0x7a, 0xb3, 0xed,
		0x99, 0x1e, 0x65, 0x9d, 0x4e, 0x40, 0x9c, 0x15, 0xd2, 0x0a, 0x69, 0x85, 0xb4, 0x4a, 0x41, 0x96,
		0x3e, 0x65, 0x9d, 0xcc, 0xa3, 0x4b, 0x58, 0x5b, 0x10, 0x56, 0x08, 0x2b, 0x84, 0x75, 0x17, 0x08,
		0xab, 0x16, 0x20, 0xce, 0x26, 0x50, 0xca, 0x98, 0x5b, 0x79, 0x2c, 0xd5, 0x82, 0x57, 0x86, 0x40,
		0x69, 0x06, 0x98, 0x96, 0xc0, 0x69, 0x0f, 0xa0, 0xd6, 0x40, 0xea, 0x0d, 0x50, 0xbd, 0x01, 0xab,
		0x17, 0x80, 0xd5, 0x05, 0x5a, 0x65, 0xc0, 0x35, 0x03, 0xde, 0xd9, 0x44, 0x2e, 0x09, 0x2f, 0x62,
		0xd7, 0xb5, 0x93, 0xfe, 0xdb, 0xd2, 0x52, 0x37, 0x13, 0x1b, 0x89, 0xe0, 0x2f, 0xae, 0x17, 0x0e,
		0xe3, 0xb1, 0x04, 0xf6, 0xc2, 0x38, 0x73, 0x56, 0xf3, 0xda, 0x74, 0x36, 0x31, 0x57, 0x09, 0x3e,
		0x54, 0x83, 0x3f, 0x15, 0xe1, 0x4b, 0x55, 0x78, 0x57, 0x19, 0xde, 0x55, 0x87, 0x57, 0x15, 0x62,
		0xa3, 0x4a, 0x8c, 0x54, 0xca, 0x6c, 0x25, 0xd5, 0x83, 0x50, 0x2b, 0xcf, 0xeb, 0x45, 0xbf, 0x1f,
		0xbb, 0x30, 0xb1, 0x3c, 0xb0, 0x53, 0x4b, 0xbc, 0xf5, 0xa0, 0x1e, 0x82, 0x62, 0x20, 0x24, 0x8d,
		0x4f, 0x2e, 0x8e, 0xfb, 0xc1, 0xa7, 0x7e, 0xdc, 0xcd, 0xa3, 0x2b, 0x67, 0x6f, 0x19, 0xdc, 0x9b,
		0x1f, 0x45, 0x8d, 0xa2, 0x46, 0x51, 0xa3, 0xa8, 0x51, 0xd4, 0x66, 0xe7, 0x55, 0xad, 0xb9, 0xea,
		0x8f, 0xd0, 0xf7, 0xd8, 0x70, 0x4a, 0xdd, 0x66, 0xac, 0xab, 0x7e, 0x6c, 0xf1, 0x68, 0xcf, 0xaa,
		0x79, 0x6b, 0x49, 0xd4, 0xea, 0xc2, 0xf4, 0x46, 0xcd, 0x5e, 0x57, 0xce, 0x6f, 0xd8, 0x05, 0xd4,
		0x33, 0x5c, 0xdd, 0x15, 0xb9, 0xf0, 0xcb, 0xce, 0x8b, 0x9c, 0x41, 0x93, 0xd9, 0x52, 0x8b, 0xdd,
		0x83, 0x7a, 0xce, 0x76, 0x06, 0x93, 0xdc, 0x90, 0x49, 0x46, 0x49, 0xee, 0xd2, 0xcf, 0x61, 0xec,
		0x8b, 0x49, 0xce, 0xe6, 0x87, 0x49, 0xc2, 0x24, 0x61, 0x92, 0x30, 0x49, 0x98, 0x24, 0x4c, 0x12,
		0x26, 0x09, 0x93, 0x84, 0x49, 0xc2, 0x24, 0x61, 0x92, 0x30, 0x49, 0x98, 0x64, 0xe9, 0x99, 0x64,
		0xdc, 0xef, 0x84, 0xf1, 0xac, 0x0d, 0xb5, 0x39, 0x91, 0xbc, 0x3b, 0x3d, 0x3c, 0x12, 0x1e, 0x09,
		0x8f, 0x84, 0x47, 0xc2, 0x23, 0xcd, 0xce, 0x6b, 0x34, 0x30, 0x46, 0xdf, 0x79, 0x04, 0x6e, 0x9d,
		0x1a, 0xce, 0x39, 0x59, 0xe3, 0xda, 0x73, 0xc9, 0xdb, 0x9d, 0xfd, 0xdc, 0xf6, 0xb0, 0xb7, 0x0b,
		0x7b, 0xfc, 0xd4, 0xc3, 0xdc, 0x56, 0x1d, 0xff, 0x57, 0x7e, 0x81, 0x87, 0xe3, 0x56, 0xf8, 0x67,
		0xdf, 0x3e, 0xb6, 0x82, 0xd3, 0xb3, 0x9b, 0x97, 0xad, 0xf1, 0x7f, 0x6e, 0x5e, 0x1f, 0x7c, 0xdc,
		0x0f, 0xda, 0xd3, 0xd7, 0x47, 0x1f, 0xf7, 0x83, 0xa3, 0xb3, 0x47, 0x7f, 0xfc, 0xf1, 0xe4, 0xd1,
		0xdf, 0x87, 0xd7, 0x9b, 0x7f, 0xb0, 0x61, 0xfe, 0x88, 0x67, 0x3e, 0xb6, 0xf4, 0xcd, 0xfb, 0x97,
		0xff, 0xed, 0x7d, 0x5f, 0xff, 0x6d, 0xb9, 0xb1, 0xff, 0xf0, 0xb0, 0xb3, 0x0f, 0x6a, 0xec, 0xf7,
		0xf0, 0x0b, 0xc6, 0xc7, 0x80, 0xb1, 0x57, 0x30, 0x0e, 0x83, 0xde, 0xf3, 0xe0, 0xd7, 0xb3, 0xbf,
		0x5b, 0x8f, 0xdb, 0xd7, 0xcf, 0x1e, 0xfd, 0x7d, 0x72, 0x7d, 0xff, 0xcd, 0x6f, 0xcb, 0xfe, 0xac,
		0xf5, 0xf8, 0xe4, 0xfa, 0xd9, 0x8a, 0x7f, 0x39, 0xbe, 0x7e, 0xb6, 0xe6, 0x18, 0x47, 0xd7, 0x0f,
		0x17, 0xfe, 0x74, 0xf4, 0xfe, 0xc1, 0xaa, 0x0f, 0xb4, 0x57, 0x7c, 0xe0, 0x70, 0xd5, 0x07, 0x0e,
		0x57, 0x7c, 0x60, 0xe5, 0x57, 0x3a, 0x58, 0xf1, 0x81, 0xa3, 0xeb, 0x6f, 0x0b, 0x7f, 0xff, 0x70,
		0xf9, 0x9f, 0x1e, 0x5f, 0x3f, 0xfa, 0xb6, 0xea, 0xdf, 0x4e, 0xae, 0xbf, 0x3d, 0x7b, 0x84, 0x6a,
		0xb2, 0x57, 0x4d, 0x88, 0xb9, 0xbd, 0x98, 0xd7, 0x5f, 0x51, 0xe3, 0xbb, 0x2d, 0xa1, 0xef, 0x36,
		0x75, 0x57, 0xfd, 0xdc, 0xf9, 0x73, 0xde, 0xde, 0x9b, 0x1f, 0xef, 0x2d, 0xde, 0x5b, 0xbc, 0xb7,
		0x78, 0x6f, 0xf1, 0xde, 0xe2, 0xbd, 0xc5, 0x7b, 0x8b, 0xf7, 0x16, 0xef, 0x2d, 0xde, 0x5b, 0xbc,
		0xb7, 0x78, 0x6f, 0xf1, 0xde, 0x02, 0xc6, 0x78, 0x6f, 0xf1, 0xde, 0xa2, 0x9a, 0xf0, 0xde, 0xe2,
		0xbd, 0xc5, 0x7b, 0x5b, 0x05, 0xef, 0x6d, 0xa5, 0x6b, 0x1c, 0x2a, 0x77, 0xa2, 0x58, 0x98, 0xaf,
		0x8c, 0x9d, 0x29, 0x26, 0xad, 0x06, 0x26, 0xff, 0x6d, 0x9a, 0x94, 0xa7, 0xdd, 0x2b, 0x5b, 0xe7,
		0x8a, 0x9b, 0x3f, 0xcb, 0x26, 0xff, 0x55, 0x69, 0xbd, 0x68, 0x77, 0x72, 0x14, 0x4f, 0x8d, 0x75,
		0x24, 0xc5, 0x4f, 0x04, 0xc5, 0x28, 0x72, 0x42, 0xf5, 0x64, 0x99, 0x19, 0xa9, 0x9e, 0xac, 0x3d,
		0x31, 0xd5, 0x93, 0x37, 0x5d, 0x31, 0xb3, 0x48, 0xc7, 0xed, 0x05, 0x21, 0x17, 0xf6, 0x52, 0xd7,
		0xb3, 0x38, 0x70, 0x53, 0x2f, 0xcb, 0x89, 0xc1, 0x5c, 0x6f, 0x27, 0xc6, 0xd2, 0x93, 0x27, 0x13,
		0xd3, 0xa4, 0x79, 0x4f, 0x15, 0xa0, 0xa4, 0x97, 0x58, 0x56, 0x1a, 0xfd, 0x94, 0x57, 0x4a, 0x9e,
		0x56, 0x6f, 0xb3, 0xa5, 0x32, 0x67, 0xa5, 0x92, 0x0f, 0x50, 0xc9, 0xa8, 0x64, 0x54, 0x72, 0x8d,
		0x54, 0x32, 0x0d, 0x0d, 0xa4, 0x17, 0x94, 0x86, 0x06, 0x55, 0x57, 0x0d, 0xfe, 0x54, 0x84, 0x2f,
		0x55, 0xe1, 0x5d, 0x65, 0x78, 0x57, 0x1d, 0x5e, 0x55, 0x88, 0x8d, 0x2a, 0x31, 0x52, 0x29, 0xf6,
		0x6c, 0x6f, 0xe1, 0xbc, 0xd2, 0xd0, 0xa0, 0x0a, 0x42, 0x42, 0x43, 0x03, 0x14, 0x35, 0x8a, 0x1a,
		0x45, 0x8d, 0xa2, 0xde, 0x59, 0x45, 0x4d, 0x19, 0x4a, 0xb5, 0x1f, 0xca, 0x50, 0x9a, 0x4e, 0x4f,
		0x19, 0x4a, 0xca, 0x50, 0x7a, 0x12, 0x39, 0xca, 0x50, 0xd6, 0x72, 0x36, 0xae, 0x32, 0x6f, 0xca,
		0x24, 0x69, 0x68, 0x00, 0x93, 0x84, 0x49, 0xc2, 0x24, 0x61, 0x92, 0x30, 0x49, 0x98, 0x24, 0x4c,
		0x12, 0x26, 0x09, 0x93, 0x84, 0x49, 0xc2, 0x24, 0x61, 0x92, 0x30, 0xc9, 0x75, 0xc5, 0x90, 0x86,
		0x06, 0x76, 0x3c, 0xf2, 0x00, 0x1e, 0x09, 0x8f, 0x84, 0x47, 0xc2, 0x23, 0x4b, 0xc4, 0x23, 0x29,
		0x89, 0x55, 0x37, 0x2e, 0x49, 0x49, 0x2c, 0x4a, 0x62, 0x69, 0x1b, 0xd8, 0x94, 0xc4, 0xa2, 0x24,
		0x56, 0xf5, 0xfc, 0x1e, 0x94, 0xc4, 0xa2, 0x24, 0x16, 0xb5, 0x82, 0x28, 0x89, 0x55, 0x6b, 0xd5,
		0x84, 0x98, 0x53, 0x12, 0x0b, 0xdf, 0xed, 0x4e, 0xf8, 0x6e, 0x69, 0x68, 0x80, 0xf7, 0x16, 0xef,
		0x2d, 0xde, 0x5b, 0xbc, 0xb7, 0x78, 0x6f, 0xf1, 0xde, 0xe2, 0xbd, 0xc5, 0x61, 0x80, 0xf7, 0x16,
		0x8a, 0x8c, 0xf7, 0x16, 0xef, 0x2d, 0xde, 0x5b, 0xbc, 0xb7, 0xb8, 0xb5, 0xf0, 0xde, 0xe2, 0xbd,
		0x45, 0xcc, 0xf1, 0xde, 0xe2, 0xbd, 0x2d, 0xd7, 0x0c, 0x34, 0x34, 0x30, 0x6f, 0x68, 0x60, 0x51,
		0x9d, 0x76, 0xaf, 0xe4, 0xfd, 0x0c, 0xde, 0x8f, 0xd7, 0xa0, 0xaa, 0x95, 0x92, 0x1f, 0x54, 0xe8,
		0x24, 0x36, 0xfe, 0xe9, 0xbe, 0x9a, 0x05, 0x48, 0x1a, 0xaf, 0xa2, 0x2c, 0x7f, 0x9e, 0xe7, 0xba,
		0x75, 0x4d, 0x1b, 0xaf, 0xa3, 0xe4, 0x45, 0xec, 0xae, 0x5c, 0x72, 0x73, 0x59, 0x45, 0xb1, 0x70,
		0xf5, 0xeb, 0xf0, 0xcb, 0xdc, 0x4c, 0xad, 0xa7, 0xed, 0xf6, 0xf1, 0x49, 0xbb, 0xbd, 0x7f, 0x72,
		0x78, 0xb2, 0x7f, 0x7a, 0x74, 0xd4, 0x3a, 0x6e, 0x29, 0x5e, 0xd9, 0x69, 0xbc, 0x49, 0xbb, 0x2e,
		0x75, 0xdd, 0x9f, 0x46, 0xfb, 0x97, 0x0c, 0xe3, 0xb8, 0x52, 0x62, 0x67, 0x04, 0xfc, 0x15, 0x00,
		0xfc, 0x86, 0x6a, 0x61, 0xf5, 0xb2, 0x42, 0xbc, 0x0e, 0xb8, 0xcb, 0x43, 0xaf, 0xec, 0x88, 0xc2,
		0xa7, 0x49, 0xfb, 0x14, 0x95, 0xf9, 0xf4, 0x28, 0x1c, 0x9b, 0x32, 0x1e, 0x17, 0xd9, 0x73, 0x22,
		0x27, 0xcd, 0x32, 0x23, 0x09, 0x9d, 0x87, 0xa9, 0x11, 0x13, 0xf6, 0xa2, 0x60, 0xbc, 0x7b, 0x42,
		0xc3, 0xaa, 0x98, 0x2b, 0x7a, 0xe6, 0x89, 0xa9, 0x39, 0xa2, 0x63, 0x7e, 0x48, 0x09, 0x84, 0x12,
		0x30, 0x96, 0x11, 0x10, 0x05, 0x81, 0xb0, 0x4c, 0x00, 0x28, 0x03, 0x7c, 0xc5, 0x61, 0xaa, 0xd8,
		0x08, 0x05, 0xe5, 0x59, 0x5a, 0x8e, 0x4b, 0x21, 0xbf, 0x02, 0x02, 0xeb, 0x57, 0x50, 0x8b, 0x89,
		0xe6, 0xf6, 0x02, 0x55, 0x40, 0x98, 0x1a, 0x9d, 0x69, 0x6e, 0x60, 0x31, 0x21, 0x9a, 0xc5, 0x19,
		0x45, 0xda, 0x6e, 0x0a, 0x35, 0x49, 0x12, 0x2b, 0x7f, 0x26, 0x99, 0xd0, 0x28, 0x9f, 0xa8, 0x28,
		0x9d, 0x80, 0xa8, 0x96, 0x58, 0xa8, 0x96, 0x30, 0xa8, 0x92, 0x08, 0xe8, 0x17, 0xe0, 0xa5, 0x9a,
		0xfc, 0x4c, 0xea, 0x1c, 0x86, 0x9d, 0x8e, 0x1b, 0xe4, 0x72, 0x22, 0x72, 0xb7, 0x8a, 0xe2, 0x64,
		0x74, 0x29, 0xa3, 0x5d, 0x34, 0x3b, 0x5a, 0xbc, 0x06, 0xa2, 0x46, 0x76, 0xb3, 0x5e, 0xf6, 0xb2,
		0x56, 0x76, 0xb2, 0x7a, 0xf6, 0xb1, 0x7a, 0x76, 0xb1, 0x6a, 0xf6, 0x70, 0xb9, 0x68, 0xb0, 0x78,
		0x76, 0xaf, 0x62, 0xdb, 0x16, 0xe1, 0xb6, 0x2c, 0x02, 0x86, 0xfe, 0x63, 0x29, 0x10, 0x16, 0x6f,
		0x9b, 0xa2, 0xdb, 0x16, 0x05, 0x20, 0x06, 0x88, 0x01, 0xe2, 0x8a, 0x00, 0xb1, 0x78, 0x31, 0x55,
		0x85, 0x62, 0xa9, 0x4a, 0xc5, 0x50, 0x15, 0xe2, 0x1b, 0x9a, 0xc5, 0x4c, 0x95, 0x6f, 0xff, 0x69,
		0x17, 0x23, 0xb5, 0xa8, 0xfa, 0xa8, 0x10, 0x5c, 0x56, 0x2d, 0x16, 0x6a, 0xb5, 0xa5, 0x8a, 0xc5,
		0x3e, 0x4d, 0xb6, 0xb5, 0xa4, 0x31, 0xab, 0xb3, 0xda, 0x59, 0x9a, 0xe2, 0x6d, 0x15, 0x74, 0xdb,
		0x26, 0x60, 0x69, 0x62, 0x69, 0x62, 0x69, 0x62, 0x69, 0x62, 0x69, 0x62, 0x69, 0x62, 0x69, 0x62,
		0x69, 0x62, 0x69, 0x6a, 0x5b, 0x9a, 0x24, 0x2f, 0x14, 0x4c, 0x5e, 0x10, 0x89, 0x73, 0xef, 0xd9,
		0xa7, 0x2c, 0x4c, 0x4c, 0xe3, 0x0a, 0x66, 0x2a, 0xdc, 0xdc, 0x7f, 0x11, 0x4b, 0x54, 0x90, 0xb8,
		0x4e, 0x23, 0x9e, 0xa7, 0x70, 0x40, 0x9e, 0x42, 0x09, 0xf8, 0x08, 0x79, 0x0a, 0xeb, 0x3f, 0x11,
		0x79, 0x0a, 0x38, 0x2d, 0x70, 0x5a, 0xe0, 0xb4, 0x28, 0xb9, 0xd3, 0x82, 0x3c, 0x85, 0x0d, 0x40,
		0x98, 0x3c, 0x05, 0x80, 0x18, 0x20, 0x06, 0x88, 0xf1, 0x1e, 0xe3, 0x3d, 0xc6, 0x7b, 0xac, 0x7f,
		0xdc, 0xee, 0x6e, 0x29, 0xde, 0x63, 0xef, 0xdb, 0x8a, 0xf7, 0xd8, 0xc8, 0xd2, 0x24, 0x4f, 0x01,
		0x4b, 0x13, 0x4b, 0x13, 0x4b, 0x13, 0x4b, 0x13, 0x4b, 0x13, 0x4b, 0x13, 0x4b, 0x13, 0x4b, 0x13,
		0x4b, 0x53, 0x6e, 0x04, 0xf2, 0x14, 0xba, 0x62, 0x55, 0x23, 0x8d, 0xd3, 0x14, 0x04, 0x0a, 0x3d,
		0x16, 0xc8, 0x52, 0x78, 0x60, 0x28, 0x6d, 0x52, 0x52, 0xe6, 0x43, 0xba, 0x1a, 0x85, 0xd2, 0x39,
		0x0c, 0xe5, 0x69, 0x3b, 0x49, 0xda, 0x5c, 0x0e, 0x36, 0xfb, 0xc4, 0x86, 0x12, 0x53, 0x54, 0x52,
		0x0c, 0x25, 0x64, 0x0b, 0xc1, 0x30, 0x11, 0x88, 0xcd, 0xe4, 0x60, 0xfd, 0xdd, 0xdc, 0x60, 0x27,
		0x1b, 0x69, 0xf6, 0x79, 0x10, 0x6c, 0x91, 0xc9, 0x74, 0xdb, 0xb3, 0x6e, 0x32, 0xc0, 0x86, 0xd2,
		0xb3, 0x5d, 0xae, 0xd2, 0xd6, 0x3e, 0x8a, 0x22, 0xbe, 0x88, 0x79, 0x9f, 0xc3, 0xe8, 0x69, 0xb7,
		0x11, 0xa7, 0x82, 0xce, 0x05, 0x31, 0x27, 0x82, 0x98, 0xb3, 0xe0, 0xbe, 0x53, 0x60, 0xbc, 0x30,
		0x25, 0x43, 0xa8, 0x6d, 0xb3, 0x81, 0x1a, 0x97, 0x71, 0xff, 0xa2, 0x80, 0x1b, 0x70, 0x26, 0x30,
		0x93, 0x71, 0xb6, 0x5c, 0xe1, 0x62, 0xe9, 0x7c, 0x85, 0xdd, 0x79, 0x12, 0xee, 0x3b, 0x81, 0xa3,
		0x23, 0xed, 0x9f, 0x13, 0xf7, 0xc7, 0x89, 0xfb, 0xdf, 0x64, 0x8e, 0x96, 0x1f, 0xf3, 0xb1, 0x68,
		0x02, 0x5e, 0xe3, 0x32, 0x0d, 0x3b, 0xae, 0x37, 0x8c, 0x83, 0xd4, 0x65, 0x79, 0x98, 0xe6, 0x72,
		0x29, 0xb6, 0x0b, 0x23, 0x53, 0x15, 0xcc, 0xe0, 0xd8, 0x4a, 0x1f, 0x5f, 0xb5, 0x63, 0xac, 0x76,
		0x9c, 0x75, 0x8e, 0x75, 0x39, 0x7c, 0x12, 0x62, 0xf9, 0xb6, 0x42, 0x85, 0xff, 0x16, 0x04, 0x58,
		0xec, 0x62, 0x84, 0xe0, 0x91, 0x17, 0x3f, 0xfa, 0x1a, 0x10, 0xa0, 0x08, 0x05, 0x5a, 0x90, 0xa0,
		0x0e, 0x0d, 0xea, 0x10, 0xa1, 0x0b, 0x15, 0xb2, 0x8e, 0x59, 0xa9, 0x90, 0x9b, 0x14, 0x84, 0xcc,
		0x06, 0x74, 0x49, 0x78, 0x11, 0x2b, 0x48, 0xd5, 0xf4, 0x20, 0x4c, 0xc6, 0x17, 0xde, 0xf1, 0x5f,
		0x5c, 0x2f, 0x1c, 0xc6, 0xe3, 0x0d, 0xef, 0x85, 0x71, 0x26, 0x3e, 0xbe, 0x4e, 0x04, 0x44, 0x1c,
		0xc2, 0x34, 0xa1, 0xcc, 0x00, 0xd2, 0xb4, 0xa1, 0xcd, 0x0c, 0xe2, 0xcc, 0xa0, 0xce, 0x06, 0xf2,
		0x64, 0xa1, 0x4f, 0x18, 0x02, 0x67, 0x4b, 0xa0, 0xd6, 0xf6, 0x5c, 0xf1, 0xe2, 0xc1, 0x82, 0x6d,
		0xd4, 0x2a, 0x6b, 0x2b, 0x08, 0x41, 0xc3, 0x25, 0x75, 0x9d, 0xfe, 0x67, 0x97, 0x7e, 0x0d, 0x44,
		0xef, 0x25, 0x2c, 0xec, 0xd6, 0xdd, 0x69, 0x50, 0x08, 0x28, 0x04, 0x14, 0x02, 0x0a, 0x41, 0x54,
		0xe2, 0x87, 0x51, 0x92, 0x1f, 0x1e, 0x28, 0xea, 0x83, 0x13, 0x85, 0xa1, 0x75, 0xd2, 0xd4, 0xa6,
		0x3f, 0xba, 0x2d, 0xff, 0xd4, 0x1b, 0x88, 0x2a, 0xe7, 0x3a, 0xcd, 0xa6, 0x51, 0x4e, 0x63, 0x9b,
		0xcd, 0x63, 0x90, 0xf7, 0xa4, 0x74, 0x7c, 0xef, 0x6e, 0xbd, 0x62, 0x7a, 0x9b, 0xaf, 0xad, 0x6f,
		0x1f, 0x9c, 0xb6, 0x4f, 0x8f, 0x4f, 0x0e, 0x4e, 0x8f, 0x6a, 0x24, 0x03, 0x15, 0xe9, 0xf8, 0x77,
		0xb6, 0x13, 0x66, 0xf6, 0x38, 0x50, 0xa3, 0x6e, 0x65, 0xcf, 0xcd, 0x82, 0x91, 0x8d, 0x91, 0x8d,
		0x91, 0x8d, 0x91, 0x8d, 0x91, 0x8d, 0x91, 0x8d, 0x91, 0x8d, 0x91, 0x8d, 0x91, 0x8d, 0x91, 0x5d,
		0x42, 0x23, 0x9b, 0x2e, 0xb6, 0x72, 0x09, 0xe2, 0x93, 0x04, 0xe6, 0xe6, 0x4d, 0xb2, 0x66, 0xf3,
		0x7e, 0x9a, 0x58, 0x53, 0x34, 0x85, 0x64, 0xcf, 0x24, 0xb7, 0xfc, 0x5d, 0xf6, 0x79, 0xf0, 0xc1,
		0x9d, 0xff, 0x36, 0x7e, 0xa2, 0xf3, 0xdf, 0x26, 0x4f, 0xf4, 0xee, 0xe6, 0x81, 0x44, 0x8a, 0x6e,
		0xca, 0x49, 0xe2, 0xb5, 0xc8, 0x6d, 0x20, 0x89, 0x62, 0x9c, 0x0b, 0x76, 0x9b, 0xd4, 0x6d, 0xa5,
		0x3d, 0xcd, 0xdc, 0xa1, 0x03, 0x72, 0x87, 0xaa, 0x44, 0xf1, 0xc8, 0x1d, 0x22, 0x77, 0x88, 0xdc,
		0x21, 0xbc, 0x58, 0x78, 0xb1, 0xf0, 0x62, 0x55, 0xcb, 0x8b, 0x45, 0xee, 0x90, 0xc8, 0xb3, 0x92,
		0x3b, 0x84, 0x42, 0x40, 0x21, 0xa0, 0x10, 0xaa, 0xaf, 0x10, 0x08, 0x6b, 0x2c, 0xfc, 0x10, 0xd6,
		0x58, 0x6b, 0x1a, 0xc2, 0x1a, 0x9b, 0x6d, 0x3d, 0x61, 0x8d, 0x6a, 0xc8, 0x00, 0x61, 0x8d, 0x12,
		0x99, 0xd9, 0xe4, 0x0e, 0x61, 0x64, 0x63, 0x64, 0x63, 0x64, 0x63, 0x64, 0x63, 0x64, 0x63, 0x64,
		0x63, 0x64, 0x63, 0x64, 0x63, 0x64, 0x63, 0x64, 0x93, 0x3b, 0x64, 0x99, 0x3b, 0x24, 0x99, 0x41,
		0xb2, 0x57, 0x82, 0xd4, 0x21, 0x81, 0x42, 0xb8, 0x72, 0x72, 0x48, 0x39, 0x66, 0x79, 0x89, 0xad,
		0x44, 0x6d, 0xe6, 0xef, 0xca, 0x68, 0x15, 0x9b, 0x49, 0x8f, 0xdb, 0xc3, 0x64, 0x72, 0xa5, 0xee,
		0x26, 0xe3, 0x51, 0xe0, 0xce, 0xd0, 0xa1, 0x40, 0x81, 0x3b, 0x0a, 0xdc, 0x7d, 0x67, 0x20, 0x0a,
		0xdc, 0x95, 0xd4, 0xc7, 0x48, 0x92, 0xaa, 0x07, 0x1f, 0x22, 0x49, 0xaa, 0x05, 0x06, 0x54, 0x6a,
		0x56, 0xb7, 0xdc, 0x8a, 0x90, 0x6e, 0x5a, 0x77, 0xbb, 0x2c, 0xb7, 0x49, 0xab, 0xa7, 0xfb, 0xfb,
		0xfb, 0x44, 0x4f, 0x88, 0x9e, 0x78, 0x44, 0x3c, 0x33, 0xe4, 0xb3, 0x41, 0x40, 0x1d, 0xb7, 0x56,
		0x35, 0xa3, 0x27, 0xa2, 0x5d, 0xf7, 0xee, 0xe3, 0xcb, 0x31, 0xd1, 0x93, 0xdb, 0x2f, 0x5e, 0xc7,
		0xe8, 0x49, 0x6b, 0x7f, 0x9f, 0x00, 0xca, 0x7a, 0xbb, 0x5f, 0xc3, 0x00, 0xca, 0xf1, 0x7e, 0xbd,
		0xb6, 0x9f, 0xd8, 0x49, 0x59, 0x8e, 0x4f, 0x23, 0x75, 0xbd, 0xd4, 0x65, 0x9f, 0x82, 0xd4, 0x75,
		0x87, 0x1d, 0xf1, 0x00, 0xc8, 0xde, 0xdd, 0x2c, 0xa5, 0xfb, 0x53, 0xe9, 0xd9, 0xf2, 0x23, 0x8b,
		0x09, 0x5b, 0x1e, 0x5b, 0x1e, 0x5b, 0x1e, 0x5b, 0x5e, 0x56, 0xe2, 0x77, 0xf9, 0xfe, 0x19, 0x31,
		0x7b, 0xb5, 0x08, 0xe8, 0x4d, 0xac, 0xac, 0xfa, 0x55, 0x3e, 0xfe, 0x73, 0xfc, 0x1c, 0x14, 0xf7,
		0x58, 0x17, 0x4e, 0x28, 0xee, 0x51, 0x5a, 0x4b, 0x84, 0xb8, 0x89, 0x1f, 0x4b, 0x83, 0xb8, 0x89,
		0xc8, 0x81, 0x20, 0x6e, 0x02, 0xd7, 0x82, 0x6b, 0xc1, 0xb5, 0x2a, 0xcc, 0xb5, 0x88, 0x9b, 0x2c,
		0xfc, 0x10, 0x37, 0x59, 0x6b, 0x1a, 0xe2, 0x26, 0x1b, 0xef, 0x3e, 0x71, 0x93, 0xd2, 0x6f, 0x3f,
		0x71, 0x93, 0xb2, 0x1c, 0x1f, 0xe2, 0x26, 0xd8, 0xf2, 0xd8, 0xf2, 0xd8, 0xf2, 0xd8, 0xf2, 0xeb,
		0x4a, 0x3c, 0x71, 0x93, 0x92, 0x38, 0xb4, 0x6a, 0x19, 0x37, 0xa9, 0xfa, 0x0d, 0xc7, 0x49, 0xd8,
		0x84, 0x8b, 0x8d, 0x5a, 0x62, 0xea, 0x55, 0x3c, 0x2b, 0x78, 0x9d, 0xf1, 0x46, 0x20, 0xab, 0x78,
		0x8b, 0x31, 0xeb, 0xf7, 0xf2, 0x60, 0x90, 0x3a, 0x77, 0x35, 0x10, 0x91, 0x9e, 0xdb, 0x50, 0xdd,
		0xbd, 0x81, 0xb9, 0xd7, 0x68, 0x68, 0xe6, 0x72, 0xaf, 0x91, 0x7b, 0x8d, 0xdf, 0x19, 0x88, 0x7b,
		0x8d, 0x25, 0x65, 0xbe, 0xc4, 0xe7, 0x3d, 0x30, 0x5b, 0xe2, 0xf3, 0x05, 0x06, 0xa4, 0xf9, 0x06,
		0x4e, 0x3c, 0x9c, 0x78, 0x38, 0xf1, 0x70, 0xe2, 0xe1, 0xc4, 0xd3, 0xd9, 0xac, 0xfb, 0x4c, 0x72,
		0x5c, 0xb7, 0xb7, 0x3f, 0xcc, 0xf5, 0x74, 0xce, 0xaa, 0x09, 0xf5, 0x94, 0xd0, 0x21, 0x29, 0x61,
		0x68, 0x20, 0x34, 0x10, 0x1a, 0x48, 0x58, 0xe2, 0x49, 0x09, 0x5b, 0xf8, 0x21, 0x25, 0x6c, 0xad,
		0x69, 0x28, 0x44, 0xbc, 0xd9, 0xd6, 0x1b, 0xe6, 0x83, 0x1d, 0xb2, 0xf5, 0x7e, 0xf5, 0x80, 0xde,
		0xa8, 0xd4, 0x1f, 0x5e, 0xcb, 0x74, 0xa8, 0x55, 0x4c, 0xfe, 0x1e, 0xdb, 0xa8, 0xfe, 0xa5, 0xc6,
		0xf7, 0xfd, 0x5e, 0xfe, 0x76, 0xf6, 0x3c, 0x5c, 0x6e, 0x5c, 0x9b, 0x76, 0x72, 0xb9, 0xb1, 0xac,
		0x3c, 0x8f, 0xe0, 0x89, 0x1f, 0x1e, 0x47, 0xf0, 0xa4, 0xd0, 0x41, 0x20, 0x78, 0x82, 0xeb, 0x0a,
		0xd7, 0x15, 0xae, 0x2b, 0x82, 0x27, 0x4b, 0x6d, 0x23, 0x82, 0x27, 0x0a, 0xfb, 0x46, 0xf0, 0x04,
		0x0d, 0x84, 0x06, 0x42, 0x03, 0x55, 0x5f, 0x03, 0x11, 0x3c, 0x59, 0xf8, 0x21, 0x78, 0xb2, 0xd6,
		0x34, 0x04, 0x4f, 0x36, 0xdb, 0x7a, 0x82, 0x27, 0xa5, 0xde, 0x7a, 0x82, 0x27, 0x35, 0x72, 0x62,
		0xd5, 0x3b, 0x78, 0x52, 0xf5, 0x9b, 0x8d, 0xf7, 0x62, 0x27, 0xdc, 0x70, 0xd4, 0x92, 0xdb, 0x72,
		0xc8, 0x6b, 0x05, 0xaf, 0x3a, 0xde, 0x95, 0xd0, 0x4a, 0x5e, 0x79, 0x14, 0x09, 0xdf, 0x89, 0x86,
		0xed, 0xc4, 0xaf, 0x37, 0x1e, 0x70, 0xbd, 0xb1, 0x0c, 0x1e, 0x02, 0xae, 0x37, 0x6e, 0xe2, 0xd2,
		0x93, 0xbb, 0xde, 0x38, 0x4c, 0x72, 0x97, 0x66, 0x1a, 0x17, 0x1c, 0x27, 0x23, 0x13, 0xa5, 0x2f,
		0xa1, 0x43, 0x91, 0x28, 0xbd, 0x1f, 0x87, 0x61, 0xdd, 0xa3, 0xf4, 0x69, 0xda, 0x17, 0x04, 0x93,
		0x85, 0x83, 0x30, 0x19, 0x5f, 0x27, 0x86, 0xd1, 0x22, 0x86, 0x41, 0x0c, 0xa3, 0x4c, 0x50, 0x64,
		0x03, 0x49, 0x3a, 0x5e, 0x26, 0xe9, 0x18, 0x86, 0x34, 0x54, 0xcd, 0x06, 0x0e, 0x87, 0xf9, 0x27,
		0x97, 0xe4, 0x51, 0x67, 0x4c, 0x98, 0x83, 0x5e, 0x18, 0xc5, 0x7a, 0xa2, 0x39, 0x3d, 0x5d, 0xcb,
		0x26, 0x55, 0x92, 0x1d, 0x5d, 0x3f, 0xbe, 0x1a, 0xc8, 0x59, 0x80, 0x9d, 0x21, 0xe8, 0x59, 0x81,
		0x9f, 0x39, 0x08, 0x9a, 0x83, 0xa1, 0x2d, 0x28, 0xea, 0x80, 0xa3, 0x12, 0x48, 0xce, 0x96, 0x46,
		0x2d, 0xe0, 0xbb, 0x8a, 0xe5, 0x1d, 0xb7, 0x35, 0xcf, 0xcc, 0x04, 0xc2, 0x9e, 0x2a, 0x4e, 0xa1,
		0x1b, 0x0b, 0x9e, 0xfe, 0xe8, 0x9e, 0xf9, 0x3d, 0xab, 0xd8, 0xb0, 0x91, 0x6e, 0x59, 0x98, 0xce,
		0x28, 0x60, 0x38, 0x9b, 0xcf, 0x30, 0x70, 0xa8, 0x8c, 0x08, 0x77, 0x45, 0xc4, 0x20, 0x86, 0xec,
		0x5b, 0x44, 0x5a, 0x4f, 0xdb, 0xed, 0xe3, 0x93, 0x76, 0x7b, 0xff, 0xe4, 0xf0, 0x64, 0xff, 0xf4,
		0xe8, 0xa8, 0x75, 0xdc, 0x3a, 0xaa, 0xb1, 0xd4, 0x3c, 0xa8, 0xe6, 0xe8, 0x67, 0x15, 0x09, 0x97,
		0x2b, 0x9c, 0xca, 0xc6, 0x45, 0xd8, 0x0d, 0x3a, 0x9f, 0x5c, 0xe7, 0xcf, 0x6c, 0x78, 0xa5, 0x4f,
		0x38, 0xee, 0xcc, 0x06, 0xd3, 0x80, 0x69, 0xc0, 0x34, 0x60, 0x1a, 0x30, 0x0d, 0x98, 0x06, 0x4c,
		0x03, 0xa6, 0x01, 0xd3, 0x80, 0x69, 0xc0, 0x34, 0x6a, 0xcd, 0x34, 0x06, 0x61, 0xe7, 0x4f, 0x97,
		0x07, 0xbd, 0x7e, 0x7a, 0x15, 0xe6, 0x36, 0x74, 0xe3, 0xee, 0x94, 0x70, 0x0e, 0x38, 0x07, 0x9c,
		0x03, 0xce, 0x01, 0xe7, 0x80, 0x73, 0xc0, 0x39, 0xe0, 0x1c, 0x70, 0x0e, 0x38, 0x07, 0x9c, 0x63,
		0x17, 0x38, 0x47, 0xec, 0x92, 0xcb, 0xf1, 0xcd, 0x21, 0x3b, 0xce, 0x31, 0x99, 0x12, 0xce, 0x01,
		0xe7, 0x80, 0x73, 0xc0, 0x39, 0xe0, 0x1c, 0x70, 0x0e, 0x38, 0x07, 0x9c, 0x03, 0xce, 0x01, 0xe7,
		0x80, 0x73, 0xd4, 0x96, 0x73, 0xf4, 0x87, 0x79, 0xd0, 0xef, 0x05, 0xfd, 0xb4, 0xeb, 0x52, 0x7d,
		0xba, 0x71, 0x67, 0x36, 0x98, 0x06, 0x4c, 0x03, 0xa6, 0x01, 0xd3, 0x80, 0x69, 0xc0, 0x34, 0x60,
		0x1a, 0x30, 0x0d, 0x98, 0x06, 0x4c, 0x03, 0xa6, 0x51, 0x5b, 0xa6, 0x91, 0xba, 0x8e, 0x8b, 0x3e,
		0xbb, 0x6e, 0x90, 0x84, 0x9d, 0x3f, 0xf5, 0xa9, 0xc6, 0xdd, 0xe9, 0xe0, 0x1a, 0x70, 0x0d, 0xb8,
		0x06, 0x5c, 0x03, 0xae, 0x01, 0xd7, 0x80, 0x6b, 0xc0, 0x35, 0xe0, 0x1a, 0x70, 0x0d, 0xb8, 0x46,
		0x6d, 0xb9, 0x46, 0x9e, 0x86, 0x49, 0x76, 0x15, 0xe5, 0xe3, 0x22, 0x51, 0xc3, 0xd4, 0xe9, 0xd3,
		0x8d, 0x85, 0x19, 0x61, 0x1c, 0x30, 0x0e, 0x18, 0x07, 0x8c, 0x03, 0xc6, 0x01, 0xe3, 0x80, 0x71,
		0xc0, 0x38, 0x60, 0x1c, 0x30, 0x0e, 0x18, 0x47, 0xfd, 0x19, 0xc7, 0xff, 0x0e, 0xdd, 0xd0, 0x05,
		0xbd, 0x61, 0x1c, 0x1b, 0x92, 0x8e, 0xb9, 0x49, 0xe1, 0x1d, 0xf0, 0x0e, 0x78, 0x07, 0xbc, 0x03,
		0xde, 0x01, 0xef, 0x80, 0x77, 0xc0, 0x3b, 0xe0, 0x1d, 0xf0, 0x0e, 0x78, 0x47, 0x6d, 0x79, 0xc7,
		0x30, 0xf9, 0x33, 0xe9, 0xff, 0x95, 0x04, 0x26, 0x39, 0x55, 0xf3, 0x93, 0xc1, 0x33, 0xe0, 0x19,
		0xf0, 0x0c, 0x78, 0x06, 0x3c, 0x03, 0x9e, 0x01, 0xcf, 0x80, 0x67, 0xc0, 0x33, 0xe0, 0x19, 0xf0,
		0x8c, 0xda, 0xf3, 0x8c, 0xc4, 0x94, 0x68, 0x70, 0x77, 0x03, 0xa6, 0x01, 0xd3, 0x80, 0x69, 0xc0,
		0x34, 0x60, 0x1a, 0x30, 0x0d, 0x98, 0x06, 0x4c, 0x03, 0xa6, 0x01, 0xd3, 0x28, 0x11, 0xd3, 0x28,
		0x75, 0xfb, 0xf3, 0xe7, 0x49, 0xd2, 0xcf, 0xc7, 0xcd, 0xc2, 0x75, 0xba, 0xa0, 0x67, 0x9d, 0x4f,
		0xee, 0x2a, 0x1c, 0x84, 0xe3, 0x42, 0xbd, 0x8d, 0x66, 0x7f, 0xe0, 0x92, 0xce, 0xd8, 0xea, 0x0f,
		0x12, 0x97, 0xff, 0xd5, 0x4f, 0xff, 0x0c, 0xa2, 0x24, 0xcb, 0xc3, 0xa4, 0xe3, 0x9a, 0xf7, 0xdf,
		0xc8, 0x16, 0xde, 0x69, 0x5e, 0x0d, 0xe2, 0xac, 0x99, 0x45, 0x97, 0x49, 0x18, 0x47, 0xc9, 0x65,
		0x30, 0x48, 0xfb, 0x79, 0xbf, 0xd3, 0x8f, 0xb3, 0xe6, 0xc8, 0x80, 0x0b, 0x72, 0xd7, 0xbc, 0x8c,
		0xfb, 0x17, 0x61, 0xdc, 0xcc, 0xf2, 0x30, 0x77, 0xcd, 0x89, 0x7d, 0x91, 0x35, 0x5d, 0x9a, 0xf6,
		0xd3, 0x4c, 0xc1, 0xca, 0x68, 0x64, 0x79, 0x3a, 0xec, 0xe4, 0xc9, 0xc4, 0xa0, 0x79, 0x33, 0x7b,
		0xba, 0xdf, 0x6f, 0xbe, 0xf9, 0xcb, 0xc9, 0x17, 0x3f, 0xbf, 0xf7, 0x7b, 0x76, 0xff, 0x8d, 0xf3,
		0xd7, 0x83, 0x38, 0x3b, 0x7f, 0x3f, 0x7d, 0xb2, 0xb7, 0xd3, 0x07, 0x3b, 0x7f, 0x97, 0x7d, 0x1e,
		0x7c, 0x70, 0xe7, 0xbf, 0x8d, 0x9f, 0xeb, 0xfc, 0xfd, 0xe8, 0xb9, 0xce, 0x7f, 0x9e, 0x3c, 0xd7,
		0xf9, 0x8b, 0x9b, 0xe7, 0x7a, 0x50, 0x4e, 0x71, 0x15, 0x14, 0xd5, 0x46, 0x34, 0x0e, 0xa8, 0x05,
		0x57, 0x2e, 0xcb, 0xc2, 0x4b, 0x97, 0x89, 0xcb, 0xea, 0xcc, 0x26, 0xbd, 0x3f, 0x91, 0xf0, 0x71,
		0xd3, 0xd1, 0x68, 0x6a, 0x44, 0x5a, 0x93, 0x40, 0x1b, 0x10, 0x67, 0x6d, 0xc2, 0x6c, 0x46, 0x94,
		0xcd, 0x08, 0xb2, 0x0d, 0x31, 0x2e, 0xb7, 0x4a, 0x54, 0x23, 0xc0, 0x26, 0xc4, 0x57, 0x91, 0xf0,
		0x2a, 0x13, 0x5d, 0x45, 0x8f, 0x83, 0x05, 0xb1, 0x35, 0x62, 0x2b, 0x56, 0x44, 0xd6, 0x92, 0x8a,
		0x28, 0x12, 0x57, 0x13, 0xc2, 0x6a, 0xbd, 0xf5, 0xf6, 0x04, 0xd5, 0x54, 0x1a, 0x2a, 0x42, 0xec,
		0xce, 0x76, 0xc3, 0xee, 0xfe, 0xe4, 0xe2, 0xb8, 0x6f, 0x63, 0x79, 0xdf, 0x9b, 0x0a, 0xdb, 0x1b,
		0xdb, 0x1b, 0xdb, 0x1b, 0xdb, 0x1b, 0xdb, 0x1b, 0xdb, 0x1b, 0xdb, 0x1b, 0xdb, 0x1b, 0xdb, 0x1b,
		0xdb, 0x7b, 0xb7, 0x6c, 0xef, 0x41, 0x98, 0x7f, 0x0a, 0xc6, 0xd1, 0x0b, 0x1b, 0x03, 0x7c, 0xd9,
		0x7c, 0x58, 0xe1, 0x58, 0xe1, 0x58, 0xe1, 0x58, 0xe1, 0x58, 0xe1, 0x58, 0xe1, 0x58, 0xe1, 0x58,
		0xe1, 0x58, 0xe1, 0x58, 0xe1, 0x3b, 0x68, 0x85, 0xdb, 0xd9, 0xdf, 0x58, 0xde, 0x58, 0xde, 0x58,
		0xde, 0x58, 0xde, 0x58, 0xde, 0x58, 0xde, 0x58, 0xde, 0x58, 0xde, 0x58, 0xde, 0x58, 0xde, 0xbb,
		0x6c, 0x79, 0xe7, 0x2e, 0xb4, 0x74, 0x7f, 0xdf, 0x9d, 0x0e, 0x1b, 0x1c, 0x1b, 0x1c, 0x1b, 0x1c,
		0x1b, 0x1c, 0x1b, 0x1c, 0x1b, 0x1c, 0x1b, 0x1c, 0x1b, 0x1c, 0x1b, 0x1c, 0x1b, 0x7c, 0xb7, 0x6c,
		0xf0, 0xd4, 0x65, 0x2e, 0xfd, 0x3c, 0xbe, 0x22, 0x6c, 0x99, 0x8a, 0xf2, 0x9d, 0x69, 0xb1, 0xc9,
		0xb1, 0xc9, 0xb1, 0xc9, 0xb1, 0xc9, 0xb1, 0xc9, 0xb1, 0xc9, 0xb1, 0xc9, 0xb1, 0xc9, 0xb1, 0xc9,
		0xb1, 0xc9, 0x77, 0xd7, 0x26, 0x37, 0xb7, 0xc6, 0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3,
		0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3, 0xb1, 0xc3, 0x0d, 0xd3,
		0x54, 0x56, 0xcf, 0x8a, 0x45, 0x8e, 0x45, 0x8e, 0x45, 0x8e, 0x45, 0x8e, 0x45, 0x8e, 0x45, 0x8e,
		0x45, 0x8e, 0x45, 0x8e, 0x45, 0x8e, 0x45, 0xbe, 0x5b, 0x16, 0x79, 0x96, 0xba, 0x5e, 0xea, 0x32,
		0xa3, 0xfb, 0x9a, 0x8b, 0xb3, 0x61, 0x81, 0x63, 0x81, 0x63, 0x81, 0x63, 0x81, 0x63, 0x81, 0x63,
		0x81, 0x63, 0x81, 0x63, 0x81, 0x63, 0x81, 0x63, 0x81, 0xef, 0x90, 0x05, 0xde, 0x1f, 0xe6, 0x46,
		0x8d, 0x7a, 0x16, 0x66, 0xc2, 0xf2, 0xc6, 0xf2, 0xc6, 0xf2, 0xc6, 0xf2, 0xc6, 0xf2, 0xc6, 0xf2,
		0xc6, 0xf2, 0xc6, 0xf2, 0xc6, 0xf2, 0xc6, 0xf2, 0xde, 0x31, 0xcb, 0xdb, 0xaa, 0x55, 0xcf, 0x92,
		0xb9, 0xb0, 0xbe, 0xb1, 0xbe, 0xb1, 0xbe, 0xb1, 0xbe, 0xb1, 0xbe, 0xb1, 0xbe, 0xb1, 0xbe, 0xb1,
		0xbe, 0xb1, 0xbe, 0xb1, 0xbe, 0x77, 0xcc, 0xfa, 0x36, 0x6d, 0xd6, 0xb3, 0x6a, 0x42, 0xec, 0x70,
		0xec, 0x70, 0xec, 0x70, 0xec, 0x70, 0xec, 0x70, 0xec, 0x70, 0xec, 0x70, 0xec, 0x70, 0xec, 0x70,
		0xec, 0xf0, 0x5d, 0xb4, 0xc3, 0x0d, 0x2d, 0x70, 0x6c, 0x6f, 0x6c, 0x6f, 0x6c, 0x6f, 0x6c, 0x6f,
		0x6c, 0x6f, 0x6c, 0x6f, 0x6c, 0x6f, 0x6c, 0x6f, 0x6c, 0x6f, 0x6c, 0xef, 0x9d, 0xb6, 0xbd, 0x8d,
		0x2a, 0xa1, 0xac, 0x98, 0x0f, 0x2b, 0x1c, 0x2b, 0x1c, 0x2b, 0x1c, 0x2b, 0x1c, 0x2b, 0x1c, 0x2b,
		0x1c, 0x2b, 0x1c, 0x2b, 0x1c, 0x2b, 0x1c, 0x2b, 0x7c, 0xc7, 0xac, 0x70, 0x1f, 0x2d, 0x7b, 0x7e,
		0x30, 0x2f, 0x56, 0x39, 0x56, 0x39, 0x56, 0x39, 0x56, 0x39, 0x56, 0x39, 0x56, 0x39, 0x56, 0x39,
		0x56, 0x39, 0x56, 0x39, 0x56, 0xf9, 0x0e, 0x5b, 0xe5, 0xf6, 0xf6, 0x38, 0x96, 0x38, 0x96, 0x38,
		0x96, 0x38, 0x96, 0x38, 0x96, 0x38, 0x96, 0x38, 0x96, 0x38, 0x96, 0x38, 0x96, 0x38, 0x96, 0x38,
		0x96, 0x78, 0x62, 0x99, 0xac, 0x42, 0xdf, 0x1e, 0x6c, 0x72, 0x6c, 0x72, 0x6c, 0x72, 0x6c, 0x72,
		0x6c, 0x72, 0x6c, 0x72, 0x6c, 0x72, 0x6c, 0x72, 0x6c, 0x72, 0x6c, 0xf2, 0x89, 0x4d, 0x6e, 0xd8,
		0xb8, 0x67, 0xf9, 0x74, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0,
		0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0x3b, 0x64, 0x83, 0xdf, 0xdc, 0xa4, 0x8c, 0xae,
		0x5c, 0x7f, 0x98, 0x2b, 0xda, 0xde, 0x77, 0xa7, 0xc1, 0xe6, 0xc6, 0xe6, 0xc6, 0xe6, 0xc6, 0xe6,
		0xc6, 0xe6, 0xc6, 0xe6, 0xc6, 0xe6, 0xc6, 0xe6, 0xc6, 0xe6, 0xc6, 0xe6, 0xde, 0x21, 0x9b, 0x3b,
		0x0d, 0x73, 0x17, 0xc4, 0xd1, 0x55, 0x94, 0xbb, 0xae, 0x81, 0xdf, 0x7b, 0xf9, 0x74, 0xd8, 0xe0,
		0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0, 0xd8, 0xe0,
		0xd8, 0xe0, 0xbb, 0x64, 0x83, 0xcf, 0x27, 0x65, 0xab, 0xbb, 0xbf, 0x97, 0xce, 0x86, 0x05, 0x8e,
		0x05, 0x8e, 0x05, 0x8e, 0x05, 0x8e, 0x05, 0x8e, 0x05, 0x8e, 0x05, 0x8e, 0x05, 0x8e, 0x05, 0x8e,
		0x05, 0x5e, 0x76, 0x0b, 0xfc, 0x41, 0x89, 0xce, 0x64, 0xe3, 0x79, 0x92, 0xf4, 0xf3, 0xb1, 0x51,
		0x2d, 0x7a, 0x0c, 0x1b, 0x59, 0xe7, 0x93, 0xbb, 0x0a, 0x07, 0x61, 0xfe, 0x69, 0xa4, 0x51, 0x9b,
		0xfd, 0x81, 0x4b, 0x3a, 0x63, 0x2b, 0x38, 0x48, 0x5c, 0xfe, 0x57, 0x3f, 0xfd, 0x33, 0x88, 0x92,
		0x2c, 0x0f, 0x93, 0x8e, 0x6b, 0xde, 0x7f, 0x23, 0x5b, 0x78, 0xa7, 0x79, 0x35, 0x88, 0xb3, 0x66,
		0x16, 0x5d, 0x26, 0x61, 0x1c, 0x25, 0x97, 0xc1, 0x20, 0xed, 0xe7, 0xfd, 0x4e, 0x3f, 0xce, 0x9a,
		0x23, 0x03, 0x28, 0xc8, 0x5d, 0xf3, 0x32, 0xee, 0x5f, 0x84, 0x71, 0x33, 0xcb, 0xc3, 0xdc, 0x35,
		0x27, 0xfa, 0x5b, 0x92, 0x1d, 0x34, 0xb2, 0x3c, 0x1d, 0x76, 0xf2, 0x64, 0x62, 0x21, 0xbc, 0x99,
		0x3d, 0xce, 0xef, 0x37, 0x5f, 0xf5, 0xe5, 0xe4, 0x9b, 0x9e, 0xdf, 0xfb, 0x3d, 0xbb, 0xff, 0xc6,
		0xf9, 0xeb, 0x41, 0x9c, 0x9d, 0xbf, 0x9f, 0x3e, 0xca, 0xdb, 0xe9, 0x93, 0x9c, 0xbf, 0xcb, 0x3e,
		0x0f, 0x3e, 0xb8, 0xf3, 0xdf, 0xc6, 0x0f, 0x72, 0xfe, 0x7e, 0xf4, 0x20, 0xe7, 0x3f, 0x4f, 0x1f,
		0xe4, 0x41, 0x39, 0x04, 0xaf, 0xd8, 0x08, 0x05, 0x45, 0x56, 0x5a, 0x54, 0x7d, 0x8a, 0xa8, 0x80,
		0x64, 0x7a, 0x91, 0xc8, 0x62, 0x82, 0xb8, 0xbd, 0xf8, 0x6c, 0xf7, 0xc9, 0x2d, 0x05, 0x4e, 0x4a,
		0xd0, 0xfc, 0x08, 0x58, 0x01, 0xd1, 0x32, 0x16, 0xa9, 0xed, 0x84, 0x69, 0x73, 0x51, 0xd8, 0x42,
		0x0c, 0x1a, 0xd1, 0x08, 0x77, 0x7b, 0x61, 0xc7, 0x05, 0x61, 0x9e, 0xa7, 0xd1, 0xc5, 0x30, 0x2f,
		0x10, 0x5d, 0x9e, 0x11, 0xcb, 0xa5, 0xa3, 0x6e, 0x29, 0xa4, 0x13, 0x9b, 0xb6, 0xb5, 0xe5, 0xc7,
		0x8b, 0xba, 0xa4, 0x24, 0x5c, 0x4f, 0x82, 0x2e, 0x26, 0x29, 0x57, 0x92, 0xb8, 0xcb, 0x48, 0xdc,
		0x35, 0x24, 0xeb, 0x02, 0xb2, 0x05, 0xd6, 0x5f, 0xa2, 0xb4, 0x98, 0xc0, 0xcc, 0x0e, 0x50, 0xf1,
		0x8d, 0x5e, 0x38, 0x93, 0x45, 0x37, 0xba, 0xd8, 0x81, 0x14, 0x3b, 0x98, 0x1a, 0xbe, 0x61, 0x05,
		0x5f, 0xb0, 0xb4, 0xef, 0x57, 0xcd, 0xd7, 0xab, 0xe6, 0xdb, 0xd5, 0xf1, 0xe5, 0xfa, 0x35, 0xd1,
		0x8b, 0x1e, 0xf0, 0xd9, 0x40, 0xe1, 0x30, 0xff, 0xe4, 0x92, 0x3c, 0xea, 0xc8, 0x52, 0xd3, 0x99,
		0x20, 0xdf, 0x1b, 0x5f, 0x68, 0x47, 0x65, 0x20, 0x40, 0x1c, 0x0a, 0x34, 0x20, 0x41, 0x11, 0x1a,
		0xb4, 0x20, 0x42, 0x1d, 0x2a, 0xd4, 0x21, 0x43, 0x17, 0x3a, 0xca, 0xe9, 0xa0, 0x92, 0x82, 0x94,
		0xd9, 0x80, 0x9d, 0xe9, 0xa9, 0x52, 0x8a, 0x53, 0x4f, 0xc6, 0xd7, 0x89, 0x4c, 0xb7, 0x88, 0x4c,
		0x13, 0x99, 0x2e, 0x13, 0x14, 0xd9, 0x40, 0x92, 0x2c, 0x34, 0x09, 0x43, 0x94, 0x1a, 0x54, 0xad,
		0xb0, 0x86, 0x82, 0x3f, 0xdd, 0x57, 0x3d, 0xc9, 0x5c, 0x6e, 0x21, 0x8d, 0xe7, 0x54, 0x92, 0x1c,
		0xdd, 0xe8, 0x9c, 0x1a, 0xc4, 0x59, 0x40, 0x9d, 0x21, 0xe4, 0x59, 0x41, 0x9f, 0x39, 0x04, 0x9a,
		0x43, 0xa1, 0x2d, 0x24, 0xea, 0x40, 0xa3, 0x12, 0x44, 0xce, 0x96, 0x46, 0x2d, 0x89, 0x67, 0xe1,
		0xc4, 0x64, 0x79, 0x1a, 0x25, 0x97, 0x9a, 0x07, 0x66, 0x6a, 0x9a, 0x3d, 0x55, 0x9c, 0xe3, 0x95,
		0x4b, 0x2e, 0xc7, 0x61, 0x84, 0x8f, 0xaa, 0x22, 0xab, 0x7b, 0xe4, 0xf7, 0xac, 0x72, 0x7d, 0x8c,
		0x54, 0xcb, 0xc2, 0x74, 0xb3, 0x04, 0x10, 0xa3, 0xf9, 0x0c, 0xb3, 0x3e, 0x94, 0x01, 0xe1, 0xae,
		0x88, 0x18, 0xe4, 0x04, 0xf9, 0x16, 0x91, 0xc3, 0x83, 0x1a, 0xcb, 0xc8, 0x83, 0x6a, 0x8e, 0x7e,
		0x56, 0x91, 0xcc, 0x26, 0x85, 0x33, 0xd8, 0x70, 0x49, 0x78, 0x11, 0x3b, 0x7d, 0x5a, 0x31, 0x99,
		0x47, 0xc9, 0xac, 0xf8, 0xc5, 0xf5, 0xc2, 0x61, 0x3c, 0x36, 0xb8, 0x7a, 0x61, 0x9c, 0x39, 0x28,
		0x0b, 0x94, 0x05, 0xca, 0x02, 0x65, 0xa9, 0x16, 0x65, 0xb9, 0xe8, 0xf7, 0x63, 0x17, 0x26, 0x16,
		0x9c, 0xa5, 0x55, 0x15, 0x95, 0x57, 0x6a, 0xc7, 0x9f, 0x52, 0x12, 0xed, 0x6c, 0x7c, 0xe3, 0x44,
		0xb2, 0x65, 0x69, 0x4a, 0xb7, 0x6f, 0x36, 0xef, 0x7a, 0x06, 0x9b, 0x2a, 0xf1, 0x8e, 0x3d, 0xcb,
		0x74, 0xb4, 0x97, 0xd3, 0x47, 0x7b, 0x3e, 0x7b, 0xdc, 0xdb, 0xf7, 0xce, 0x9f, 0xdf, 0x79, 0xdc,
		0xf3, 0x89, 0x6e, 0xde, 0x81, 0xeb, 0x9d, 0x37, 0x99, 0xaa, 0x6a, 0x71, 0x32, 0xa9, 0x44, 0xd8,
		0xa5, 0xb8, 0xa6, 0x15, 0x26, 0x3b, 0x20, 0x4c, 0x66, 0x68, 0x78, 0x11, 0x26, 0xab, 0xa3, 0xb6,
		0x24, 0x4c, 0x06, 0xe7, 0x84, 0x73, 0xc2, 0x39, 0xe1, 0x9c, 0x25, 0xe2, 0x9c, 0x84, 0xc9, 0x36,
		0xf8, 0x21, 0x4c, 0x56, 0x68, 0x3a, 0xc2, 0x64, 0x32, 0x22, 0x42, 0x98, 0xac, 0xda, 0x32, 0x42,
		0x98, 0x4c, 0xf5, 0xfb, 0x12, 0x26, 0x5b, 0xc9, 0xc0, 0x08, 0x93, 0x41, 0x59, 0xa0, 0x2c, 0x50,
		0x96, 0x4a, 0x53, 0x16, 0xc2, 0x64, 0xca, 0x23, 0x12, 0x26, 0x13, 0x0c, 0x93, 0x69, 0x84, 0x3b,
		0xf6, 0x4a, 0x1b, 0x25, 0x13, 0xa8, 0x16, 0xa2, 0x27, 0xdb, 0x54, 0x60, 0xf2, 0x7d, 0x1a, 0xaa,
		0x58, 0x99, 0x69, 0x13, 0xf9, 0x2f, 0x4d, 0xc1, 0x26, 0x81, 0x8b, 0xfa, 0x17, 0x61, 0xd2, 0xfd,
		0x2b, 0xea, 0xe6, 0x9f, 0x82, 0xb9, 0x0a, 0xbc, 0x99, 0xfc, 0x95, 0xec, 0x15, 0xf3, 0x70, 0x35,
		0xbb, 0x84, 0xd4, 0x82, 0xab, 0xd9, 0x7e, 0xa8, 0x41, 0xcd, 0xaf, 0x66, 0x2f, 0x85, 0x00, 0xbd,
		0x0c, 0x94, 0xe5, 0xd3, 0x91, 0x91, 0x42, 0x46, 0x8a, 0x7f, 0xdf, 0x06, 0x19, 0x29, 0x86, 0xc4,
		0x54, 0x2d, 0x23, 0x65, 0x90, 0x46, 0xfd, 0x34, 0xca, 0x0d, 0xf2, 0x50, 0x66, 0x33, 0xe1, 0xca,
		0xb5, 0x86, 0x35, 0x43, 0x78, 0xb3, 0x82, 0x39, 0x73, 0xb8, 0x33, 0x87, 0x3d, 0x5b, 0xf8, 0xd3,
		0xf3, 0xf8, 0xed, 0xd5, 0xc2, 0x95, 0x1b, 0xbb, 0xb0, 0x97, 0xba, 0x9e, 0x85, 0x2b, 0xf7, 0x44,
		0x71, 0x8e, 0xb7, 0x13, 0x67, 0xcb, 0x93, 0x27, 0x93, 0x4a, 0xd4, 0x33, 0x54, 0xde, 0xe1, 0x90,
		0xa9, 0x4e, 0x1a, 0xf9, 0x82, 0x08, 0x69, 0xf9, 0x57, 0x15, 0x8d, 0x78, 0xb4, 0x1f, 0xda, 0x0f,
		0xed, 0x57, 0x56, 0xed, 0xa7, 0x45, 0x0a, 0x66, 0x13, 0x84, 0x9d, 0x3c, 0xfa, 0xec, 0xee, 0x78,
		0x3b, 0x83, 0x71, 0xeb, 0x02, 0x7d, 0xc1, 0x9e, 0x65, 0xaf, 0xaf, 0xfc, 0x0a, 0x8f, 0x6b, 0xd1,
		0x91, 0x45, 0x1b, 0x58, 0x2d, 0x01, 0xd6, 0x03, 0xd0, 0x5a, 0x03, 0xae, 0x37, 0xe0, 0xf5, 0x06,
		0xc0, 0x7e, 0x80, 0x58, 0x17, 0x90, 0x95, 0x81, 0xd9, 0x8e, 0x9e, 0x2c, 0x9c, 0xb8, 0xcb, 0x70,
		0x78, 0xe9, 0x54, 0xda, 0xc2, 0xad, 0x02, 0xc8, 0xa7, 0x06, 0x53, 0xe9, 0xb6, 0x8d, 0xbb, 0xff,
		0x63, 0x83, 0x20, 0x7b, 0xd6, 0x39, 0xf4, 0xc6, 0x9a, 0x6d, 0x61, 0x5a, 0xa3, 0xb6, 0x73, 0x0b,
		0xf3, 0x7a, 0xc8, 0x9b, 0x36, 0xc2, 0x97, 0xbb, 0xa2, 0x64, 0x98, 0x6b, 0x5f, 0x16, 0x51, 0xb2,
		0x6f, 0x63, 0x57, 0x2a, 0xe9, 0x7a, 0x50, 0x8f, 0x59, 0xce, 0x2a, 0x7a, 0xcb, 0x40, 0xb3, 0xe9,
		0x64, 0xf8, 0x39, 0x8c, 0xe2, 0xf0, 0x22, 0x76, 0xc1, 0x2c, 0x04, 0x6c, 0xc8, 0xb9, 0x96, 0x4c,
		0x0e, 0xdb, 0x82, 0x6d, 0xc1, 0xb6, 0x60, 0x5b, 0xb0, 0xad, 0xa5, 0xe9, 0x39, 0x57, 0x17, 0x83,
		0xac, 0x66, 0xa4, 0xeb, 0x5f, 0xc9, 0x8d, 0x41, 0xd3, 0x78, 0x6d, 0xf4, 0x6c, 0xb0, 0x3c, 0x58,
		0x1e, 0x2c, 0x0f, 0x96, 0x07, 0xcb, 0x83, 0xe5, 0xed, 0x06, 0xcb, 0xfb, 0x14, 0x5d, 0x7e, 0xfa,
		0x2b, 0xcc, 0x5d, 0x1a, 0x5c, 0x85, 0xe9, 0x9f, 0x76, 0x04, 0xef, 0xde, 0xbc, 0x70, 0x3b, 0xb8,
		0x1d, 0xdc, 0x0e, 0x6e, 0x07, 0xb7, 0x83, 0xdb, 0xc1, 0xed, 0xe0, 0x76, 0x70, 0x3b, 0xb8, 0x1d,
		0xdc, 0x0e, 0x6e, 0x07, 0xb7, 0x2b, 0x20, 0x56, 0xea, 0x17, 0xab, 0x16, 0x2c, 0x16, 0xe5, 0x0b,
		0x56, 0xf0, 0x39, 0xf8, 0x1c, 0x7c, 0x0e, 0x3e, 0x57, 0x51, 0x3e, 0x37, 0x4c, 0xe4, 0xaf, 0xce,
		0x7f, 0x0f, 0x1e, 0x5b, 0xa7, 0x06, 0x73, 0x4d, 0x96, 0xb1, 0x76, 0xac, 0x6a, 0xb6, 0x69, 0x51,
		0x92, 0x3f, 0x6d, 0x18, 0xda, 0xe0, 0x93, 0xcd, 0x33, 0xb4, 0x41, 0x8d, 0xa9, 0xb1, 0xfd, 0x66,
		0x7a, 0xa5, 0xca, 0x9e, 0x79, 0x8e, 0x6f, 0xea, 0x5c, 0x06, 0x92, 0xe3, 0x81, 0x4a, 0x7b, 0xa5,
		0xd4, 0x65, 0x13, 0xb9, 0x93, 0x1d, 0x16, 0xb9, 0x07, 0xf5, 0x9c, 0xed, 0xec, 0x41, 0x8d, 0x0e,
		0xac, 0x07, 0xb3, 0xc2, 0x25, 0xc3, 0x2b, 0x97, 0x6a, 0x14, 0x53, 0x5a, 0xcb, 0x32, 0x6c, 0x1b,
		0xce, 0xf9, 0x22, 0x19, 0x5e, 0x8d, 0x20, 0x10, 0x57, 0x93, 0xdf, 0xef, 0xaf, 0xe9, 0x6a, 0xba,
		0xb9, 0x1c, 0xeb, 0xba, 0x3e, 0x72, 0xc5, 0x97, 0xcc, 0x8d, 0xfb, 0x69, 0xa3, 0x89, 0x70, 0x3f,
		0xc9, 0x8a, 0x07, 0xee, 0x27, 0xdc, 0x4f, 0x6b, 0xfa, 0x4d, 0x48, 0x27, 0x90, 0x99, 0x8a, 0x74,
		0x82, 0x2a, 0xfb, 0x48, 0x48, 0x27, 0x20, 0x9d, 0xa0, 0x26, 0xa2, 0x44, 0x3a, 0x01, 0x1c, 0xcf,
		0x23, 0xc7, 0xab, 0x54, 0xf5, 0x28, 0xe5, 0x5e, 0x27, 0xb3, 0x79, 0xca, 0xd5, 0xe5, 0x61, 0x79,
		0x0d, 0xff, 0xe5, 0x6f, 0x37, 0x35, 0x2b, 0xf6, 0xed, 0x95, 0xa7, 0x33, 0xc4, 0x4f, 0xd3, 0x87,
		0x7f, 0x37, 0xb7, 0x24, 0x4b, 0xdf, 0xd5, 0xe8, 0x9a, 0xa2, 0x77, 0x7a, 0xca, 0x5d, 0xd2, 0xf9,
		0x9f, 0xe3, 0xe6, 0xdf, 0x5a, 0x59, 0x3b, 0x8d, 0x57, 0x51, 0x96, 0x8f, 0x76, 0x5b, 0xa7, 0x6c,
		0xf4, 0xeb, 0x28, 0x79, 0x11, 0xbb, 0x11, 0xeb, 0xcc, 0x74, 0xd4, 0xfd, 0xc8, 0x7c, 0x99, 0x9b,
		0xc1, 0x46, 0xb1, 0x37, 0xde, 0xa4, 0x5d, 0x97, 0xba, 0xee, 0x4f, 0xa3, 0x9d, 0x49, 0x86, 0x71,
		0x4c, 0xb3, 0xaa, 0x4a, 0x02, 0x77, 0x7d, 0x9b, 0x58, 0xad, 0x0f, 0xd5, 0xb4, 0xb6, 0xf2, 0x78,
		0x86, 0x2a, 0x71, 0x76, 0xea, 0xd7, 0xe2, 0x6a, 0xe9, 0xe9, 0xa8, 0x53, 0xa7, 0xab, 0xce, 0x34,
		0x28, 0x21, 0xdc, 0xd9, 0x6a, 0x32, 0x2e, 0x9d, 0xac, 0x0a, 0xaf, 0x24, 0x9d, 0xac, 0x6e, 0x27,
		0xa0, 0x93, 0x55, 0x89, 0x3b, 0x59, 0xdd, 0xaa, 0x8c, 0xa8, 0xab, 0xd7, 0xc0, 0xea, 0xce, 0x2c,
		0x3a, 0x7d, 0xab, 0xf6, 0xb5, 0xfa, 0x56, 0xed, 0xd3, 0xb7, 0xca, 0x00, 0x86, 0xcc, 0xe0, 0xc8,
		0x0c, 0x96, 0x6c, 0xe0, 0xa9, 0x1a, 0x4e, 0x0e, 0xb5, 0x40, 0xab, 0x05, 0xc2, 0xdc, 0x31, 0x66,
		0x9e, 0xc2, 0xa7, 0xe0, 0x53, 0x13, 0x3e, 0x25, 0x6a, 0x2e, 0x97, 0x88, 0x3f, 0x4d, 0x54, 0x5f,
		0x8d, 0x08, 0xd3, 0x27, 0x17, 0xc7, 0x7d, 0x85, 0x56, 0xc0, 0x93, 0x71, 0x21, 0x4c, 0x10, 0x26,
		0x08, 0xd3, 0x6e, 0x10, 0x26, 0x61, 0xdf, 0x8b, 0xae, 0x0f, 0x46, 0x09, 0x5a, 0x20, 0x49, 0x90,
		0x24, 0x48, 0x52, 0x65, 0x9a, 0xfb, 0x8e, 0xad, 0x94, 0x60, 0x6c, 0xb7, 0x7e, 0x0e, 0x63, 0xfd,
		0x0e, 0x87, 0xf7, 0xe6, 0xd3, 0x6a, 0x7b, 0xe6, 0x7a, 0xe1, 0x30, 0x1e, 0x0b, 0xcc, 0xe9, 0xfe,
		0xfe, 0x3e, 0xfd, 0x84, 0xcd, 0x91, 0xd4, 0x10, 0x51, 0xad, 0x90, 0xd5, 0x1c, 0x61, 0xcd, 0x91,
		0xd6, 0x16, 0x71, 0x75, 0x90, 0x57, 0x09, 0x81, 0xf5, 0xdd, 0x55, 0x0b, 0x27, 0x66, 0x18, 0x25,
		0x79, 0xeb, 0xd8, 0xa0, 0x9d, 0xf0, 0xb1, 0xe2, 0x14, 0x36, 0x69, 0xf8, 0x06, 0xb7, 0x34, 0x2c,
		0xd3, 0xee, 0x8d, 0x73, 0xa4, 0x6f, 0x73, 0xa3, 0xf7, 0xf7, 0xad, 0xa6, 0xf4, 0x90, 0x03, 0x6d,
		0x90, 0x59, 0x6f, 0x9a, 0x51, 0xef, 0x4b, 0x4a, 0x8e, 0xf7, 0xeb, 0x2d, 0x26, 0x15, 0x4d, 0x2d,
		0x3f, 0xdb, 0xe1, 0xf6, 0xec, 0xa9, 0xeb, 0xa5, 0x2e, 0xfb, 0x14, 0xa4, 0xae, 0x3b, 0xec, 0xa8,
		0xe6, 0xab, 0xcf, 0xdd, 0x6a, 0xbe, 0x3f, 0xa5, 0x3e, 0x97, 0x19, 0x59, 0x7e, 0x70, 0x19, 0xb8,
		0x0c, 0x5c, 0x06, 0x2e, 0x53, 0x2d, 0x2e, 0x73, 0xd1, 0xef, 0xc7, 0x2e, 0x4c, 0x0c, 0xc8, 0x4c,
		0xab, 0xc5, 0xd5, 0x13, 0x89, 0x53, 0xb3, 0x53, 0x37, 0x07, 0x6e, 0x62, 0xb5, 0x4d, 0x95, 0xf8,
		0xca, 0x5e, 0x79, 0x82, 0xf7, 0xff, 0x39, 0x7e, 0x4c, 0xd1, 0x18, 0xbe, 0xbc, 0x34, 0x5f, 0x8b,
		0xe6, 0x4c, 0x84, 0xb9, 0xd3, 0x8b, 0xc7, 0x69, 0x5c, 0xfe, 0x53, 0x0f, 0xc7, 0x1d, 0x10, 0x8e,
		0x33, 0x34, 0xb4, 0x08, 0xc7, 0xd5, 0x51, 0x3b, 0x12, 0x8e, 0xdb, 0x96, 0xc2, 0x12, 0x8e, 0x83,
		0xc2, 0x42, 0x61, 0xa1, 0xb0, 0xd5, 0xa3, 0xb0, 0x84, 0xe3, 0xd6, 0xfe, 0x21, 0x1c, 0x57, 0x68,
		0x3a, 0xc2, 0x71, 0x62, 0x52, 0x42, 0x38, 0xae, 0xf2, 0x62, 0x42, 0x38, 0x4e, 0xf5, 0xfb, 0x12,
		0x8e, 0xdb, 0x9a, 0xcb, 0x10, 0x8e, 0x83, 0xcb, 0xc0, 0x65, 0xe0, 0x32, 0xd5, 0xe3, 0x32, 0x84,
		0xe3, 0x94, 0x47, 0x24, 0x1c, 0x27, 0x10, 0x8e, 0xd3, 0xaa, 0xad, 0x58, 0xae, 0x68, 0x9c, 0x42,
		0xbd, 0x44, 0xae, 0x8e, 0x57, 0x5f, 0xfa, 0xeb, 0x77, 0x75, 0xfc, 0x46, 0xde, 0xeb, 0x74, 0x75,
		0x5c, 0xa5, 0x40, 0x8e, 0x66, 0xd9, 0x0a, 0x61, 0x5a, 0xc1, 0x35, 0x72, 0xae, 0x91, 0xfb, 0x30,
		0xf3, 0xcb, 0xa5, 0x95, 0xc4, 0xcd, 0xf6, 0x99, 0xc4, 0xc6, 0x2e, 0xec, 0xa5, 0xae, 0x27, 0x29,
		0xb1, 0x53, 0xb3, 0x5c, 0xb0, 0xe5, 0x5f, 0xe3, 0xed, 0x44, 0x71, 0x3e, 0x79, 0x32, 0xc9, 0xa0,
		0x6a, 0xde, 0x81, 0xae, 0x5a, 0x02, 0xfe, 0x68, 0x5b, 0x14, 0x11, 0x5f, 0x6e, 0xd7, 0x77, 0xbd,
		0x72, 0x48, 0xd4, 0x03, 0xf0, 0x3d, 0x00, 0x7e, 0xd4, 0xa3, 0x6a, 0xc8, 0x9a, 0x03, 0x52, 0x35,
		0x44, 0x11, 0x5e, 0x34, 0x61, 0x46, 0x1d, 0x6e, 0xb4, 0x61, 0xc7, 0x0c, 0x7e, 0xcc, 0x60, 0xc8,
		0x02, 0x8e, 0xaa, 0xe1, 0x31, 0x54, 0x4b, 0x51, 0x9c, 0x19, 0x29, 0xfa, 0x41, 0xbd, 0xdb, 0xa9,
		0x88, 0xb2, 0x59, 0x83, 0x9a, 0x19, 0xb8, 0x59, 0x81, 0x9c, 0x39, 0xd8, 0x99, 0x83, 0x9e, 0x25,
		0xf8, 0xe9, 0x80, 0xa0, 0x12, 0x18, 0xea, 0x51, 0x75, 0x43, 0xea, 0x6e, 0x41, 0xe5, 0x57, 0x52,
		0xfb, 0xe6, 0x58, 0x8c, 0x9e, 0xcd, 0x00, 0x39, 0xbb, 0xff, 0xc6, 0xe4, 0xf7, 0xb1, 0x8f, 0x79,
		0x87, 0x33, 0x5f, 0xb2, 0xe1, 0x85, 0xa1, 0x7e, 0xbc, 0x33, 0x1b, 0x2a, 0x12, 0x15, 0x89, 0x8a,
		0x44, 0x45, 0xa2, 0x22, 0x4b, 0xaa, 0x22, 0x3f, 0xde, 0xaa, 0xc8, 0xff, 0xe8, 0x0c, 0xd3, 0xd4,
		0x25, 0xf9, 0xc3, 0x47, 0xcd, 0x27, 0x4f, 0x6e, 0xbd, 0xe5, 0x67, 0x93, 0x8f, 0xcc, 0xe3, 0x7a,
		0xb6, 0xe4, 0xbd, 0xd9, 0xc8, 0x5d, 0xf7, 0x85, 0x4e, 0x8b, 0x12, 0x9b, 0xf8, 0xe2, 0xcb, 0x38,
		0x9d, 0x59, 0xfe, 0x5a, 0x84, 0xbe, 0xc3, 0xa6, 0xdf, 0x09, 0xdc, 0x97, 0xfc, 0x59, 0xee, 0x62,
		0x77, 0xe5, 0xf2, 0xf4, 0x6b, 0xd0, 0x4f, 0x82, 0xce, 0xa7, 0xf1, 0x3d, 0x0f, 0x13, 0x27, 0x4e,
		0x2f, 0x8c, 0x33, 0x0b, 0x2f, 0x4e, 0xd9, 0x1d, 0x38, 0x67, 0xa4, 0x7c, 0x15, 0x48, 0x7a, 0xb9,
		0x13, 0xfa, 0xaa, 0x7d, 0x21, 0x86, 0xd9, 0xab, 0x77, 0xae, 0x47, 0x39, 0x06, 0x31, 0x3a, 0x44,
		0x39, 0x06, 0xe2, 0x1c, 0xa5, 0xe0, 0x35, 0xc4, 0x39, 0xcc, 0x2c, 0x37, 0xe2, 0x1c, 0x38, 0x71,
		0x70, 0xe2, 0xe0, 0xc4, 0xc1, 0x89, 0x83, 0x13, 0xc7, 0xc0, 0x89, 0x43, 0x9c, 0x63, 0x8f, 0x38,
		0x07, 0x2a, 0x12, 0x15, 0x89, 0x8a, 0x44, 0x45, 0xa2, 0x22, 0x89, 0x73, 0x54, 0x8b, 0x2d, 0xef,
		0xb2, 0x53, 0xb9, 0xe6, 0xd7, 0x89, 0xef, 0xf8, 0x94, 0xb9, 0x54, 0xec, 0xfb, 0x48, 0x94, 0xf9,
		0x28, 0xd4, 0xef, 0x6e, 0xf1, 0xbc, 0xf0, 0xd7, 0xe9, 0xc2, 0xd9, 0x68, 0x9f, 0x9d, 0x6c, 0x09,
		0xa5, 0x99, 0x5d, 0x32, 0x37, 0x36, 0x57, 0xcd, 0x24, 0x38, 0x11, 0xb7, 0x8b, 0x8d, 0x58, 0x0e,
		0x4d, 0xaa, 0x0b, 0x0c, 0xc8, 0x75, 0x33, 0x03, 0xb7, 0x0c, 0x55, 0xf1, 0xcb, 0xe1, 0x78, 0xa1,
		0x2a, 0xbe, 0x21, 0xb9, 0x54, 0x0b, 0xc5, 0x5e, 0x7c, 0x1d, 0x84, 0x59, 0x16, 0xf4, 0x07, 0x79,
		0x74, 0x15, 0xfd, 0x3f, 0x67, 0x58, 0x1f, 0x7f, 0xe5, 0xcc, 0x78, 0xa1, 0xad, 0x61, 0xcf, 0x10,
		0xfe, 0xac, 0x60, 0xd0, 0x1c, 0x0e, 0xcd, 0x61, 0xd1, 0x16, 0x1e, 0xf5, 0xbc, 0x7a, 0x7b, 0x94,
		0xb0, 0xdf, 0x04, 0xbf, 0x28, 0x61, 0xbf, 0xc6, 0x83, 0xec, 0x42, 0x09, 0x7b, 0xea, 0xd7, 0x17,
		0x13, 0x91, 0x5d, 0xa8, 0x5f, 0x7f, 0x74, 0x74, 0x78, 0x44, 0xfd, 0xfa, 0xb2, 0x8d, 0xbe, 0xcb,
		0xf5, 0xeb, 0xe3, 0x28, 0xf9, 0x33, 0xb8, 0x75, 0x8f, 0x06, 0x59, 0xfe, 0x35, 0x76, 0x41, 0xea,
		0xfe, 0x77, 0xe8, 0xb2, 0xdc, 0x75, 0xf5, 0x69, 0xc7, 0x8f, 0xbe, 0x80, 0x7e, 0x6d, 0xfb, 0x7e,
		0x27, 0xb8, 0x1a, 0xc4, 0x59, 0xfe, 0xec, 0xd5, 0xcb, 0xdf, 0xff, 0x79, 0xfe, 0xfb, 0x9b, 0x5f,
		0x5e, 0x9c, 0xbf, 0x7d, 0xf7, 0xe6, 0xc3, 0x8b, 0x9f, 0x3f, 0xbc, 0x7c, 0xf3, 0xfb, 0xf9, 0xbb,
		0x17, 0xff, 0xe7, 0x5f, 0x2f, 0xde, 0x7f, 0x78, 0xf1, 0x0b, 0x3c, 0x08, 0x1e, 0x04, 0x0f, 0x82,
		0x07, 0x55, 0x8b, 0x07, 0x45, 0x5d, 0x97, 0xe4, 0x51, 0xfe, 0xd5, 0x28, 0x2b, 0x47, 0xd1, 0xba,
		0x69, 0xbc, 0x9c, 0x3c, 0xca, 0x4f, 0x61, 0x66, 0x70, 0x3e, 0xa7, 0x0b, 0x38, 0xa7, 0x0a, 0x3e,
		0xfc, 0xcf, 0xdb, 0x17, 0xda, 0xa7, 0x74, 0x6c, 0x2a, 0x66, 0xea, 0x9c, 0xcf, 0x86, 0xf7, 0xdd,
		0x59, 0xc8, 0x1f, 0x68, 0xd7, 0x3a, 0x90, 0x18, 0xe3, 0x15, 0xfd, 0xd7, 0xef, 0x93, 0x95, 0x64,
		0xf9, 0xb6, 0x16, 0xc8, 0x7b, 0xb2, 0xf8, 0xf2, 0x9d, 0xc9, 0x5a, 0xaa, 0xce, 0x70, 0x56, 0x35,
		0x25, 0x4b, 0x62, 0xa2, 0xe8, 0xf8, 0xe5, 0xca, 0xc6, 0xba, 0xa5, 0x76, 0xb5, 0xbf, 0xea, 0xfe,
		0x76, 0xf6, 0xa8, 0x5c, 0x74, 0x97, 0x02, 0x69, 0x2e, 0xba, 0x93, 0x61, 0x51, 0x16, 0x2a, 0x4d,
		0x86, 0x85, 0xa1, 0x96, 0x24, 0xc3, 0x42, 0x0a, 0xe6, 0xf0, 0x2c, 0x7a, 0x85, 0x3f, 0x2b, 0x18,
		0x34, 0x87, 0x43, 0x73, 0x58, 0xb4, 0x85, 0x47, 0x65, 0xd2, 0x43, 0x86, 0xc5, 0xba, 0xf8, 0x45,
		0x86, 0xc5, 0x1a, 0x0f, 0x42, 0x86, 0x85, 0xdc, 0x7c, 0x64, 0x58, 0x54, 0x56, 0x44, 0xc8, 0xb0,
		0x28, 0xe5, 0xe8, 0x64, 0x58, 0x90, 0x61, 0x41, 0x86, 0x05, 0x3c, 0x08, 0x1e, 0x04, 0x0f, 0xaa,
		0x1b, 0x0f, 0x22, 0xc3, 0xa2, 0xe0, 0x02, 0x92, 0x61, 0x21, 0xb4, 0x90, 0x64, 0x58, 0x48, 0xaf,
		0x28, 0x19, 0x16, 0xc5, 0x05, 0x92, 0x0c, 0x0b, 0xff, 0x4a, 0x96, 0x0c, 0x0b, 0xd1, 0xf1, 0x4b,
		0x9b, 0x61, 0x51, 0xf3, 0xba, 0x4f, 0x73, 0x09, 0x16, 0x54, 0x7d, 0xf2, 0x7d, 0x1a, 0x4a, 0x7b,
		0x0a, 0xea, 0x57, 0xf2, 0xe9, 0x56, 0xee, 0xeb, 0x54, 0xf0, 0x49, 0x36, 0x73, 0x48, 0x25, 0x63,
		0x48, 0xad, 0xcc, 0xd3, 0x01, 0x65, 0x9e, 0xaa, 0xe4, 0xea, 0xa1, 0xcc, 0x53, 0xb9, 0xcb, 0x3c,
		0x0d, 0x47, 0x50, 0x99, 0x69, 0x16, 0x7a, 0x9a, 0xcc, 0x40, 0x22, 0x22, 0x89, 0x88, 0xfe, 0x60,
		0xc8, 0x0c, 0x8e, 0x6c, 0x60, 0xa9, 0x1a, 0x64, 0x52, 0x2d, 0x11, 0xd1, 0xa5, 0x69, 0x5f, 0x01,
		0xb4, 0x16, 0x0e, 0xd4, 0x64, 0x1e, 0xdd, 0xe0, 0x5a, 0x8b, 0xe0, 0x9a, 0x4f, 0x68, 0xb3, 0x82,
		0x38, 0x73, 0xa8, 0x33, 0x87, 0x3c, 0x5b, 0xe8, 0x53, 0xf6, 0xfb, 0x69, 0x85, 0xf6, 0x95, 0x20,
		0x71, 0x36, 0x41, 0x38, 0xcc, 0x3f, 0xb9, 0x24, 0x8f, 0x3a, 0x63, 0xb7, 0x45, 0xd0, 0x0b, 0xa3,
		0xd8, 0x2e, 0x1e, 0xb5, 0x6c, 0x72, 0x65, 0x59, 0xb3, 0xc9, 0x96, 0x52, 0x07, 0x53, 0x4b, 0x50,
		0xf5, 0x00, 0xae, 0xd6, 0x20, 0xeb, 0x0d, 0x6c, 0xbd, 0x81, 0xae, 0x1f, 0xf0, 0xd5, 0x05, 0x61,
		0x65, 0x30, 0x9e, 0x2d, 0x99, 0x7a, 0xc6, 0xc3, 0x2a, 0x56, 0x7c, 0xdc, 0xb6, 0x38, 0x73, 0x13,
		0x88, 0x7c, 0x6a, 0x30, 0x95, 0x4d, 0x52, 0xf8, 0xf4, 0xc7, 0x06, 0x43, 0xf6, 0xac, 0x93, 0xc4,
		0x8d, 0x75, 0xdb, 0xc2, 0xb4, 0xc6, 0x49, 0xe3, 0xb3, 0x79, 0x3d, 0x64, 0x05, 0x1b, 0x21, 0xcc,
		0x5d, 0x51, 0x32, 0x4c, 0x26, 0x2f, 0x8b, 0x28, 0xb5, 0x9e, 0xb6, 0xdb, 0xc7, 0x27, 0xed, 0xf6,
		0xfe, 0xc9, 0xe1, 0xc9, 0xfe, 0xe9, 0xd1, 0x51, 0xeb, 0xb8, 0x75, 0xb4, 0x43, 0xd2, 0xf5, 0xa0,
		0x1e, 0xb3, 0x9c, 0x55, 0x34, 0x87, 0x5e, 0xf1, 0x74, 0x37, 0x2e, 0xc2, 0x6e, 0xd0, 0xf9, 0xe4,
		0x3a, 0x7f, 0x66, 0xc3, 0x2b, 0x3b, 0xa2, 0x75, 0x67, 0x56, 0x18, 0x16, 0x0c, 0x0b, 0x86, 0x05,
		0xc3, 0x82, 0x61, 0xc1, 0xb0, 0x60, 0x58, 0x30, 0x2c, 0x18, 0x16, 0x0c, 0x0b, 0x86, 0x05, 0xc3,
		0xaa, 0x11, 0xc3, 0x1a, 0x84, 0x9d, 0x3f, 0x5d, 0x1e, 0xf4, 0xfa, 0xe9, 0x55, 0x98, 0xdb, 0xd2,
		0xac, 0xbb, 0x53, 0xc3, 0xb5, 0xe0, 0x5a, 0x70, 0x2d, 0xb8, 0x16, 0x5c, 0x0b, 0xae, 0x05, 0xd7,
		0x82, 0x6b, 0xc1, 0xb5, 0xe0, 0x5a, 0x70, 0x2d, 0xb8, 0x56, 0xfd, 0xb8, 0x56, 0xec, 0x92, 0xcb,
		0xf1, 0xfd, 0x44, 0x7b, 0xae, 0x35, 0x99, 0x1a, 0xae, 0x05, 0xd7, 0x82, 0x6b, 0xc1, 0xb5, 0xe0,
		0x5a, 0x70, 0x2d, 0xb8, 0x16, 0x5c, 0x0b, 0xae, 0x05, 0xd7, 0x82, 0x6b, 0xc1, 0xb5, 0x6a, 0xc2,
		0xb5, 0xfa, 0xc3, 0x3c, 0xe8, 0xf7, 0x82, 0x7e, 0xda, 0x75, 0xa9, 0x1d, 0xcd, 0xba, 0x33, 0x2b,
		0x0c, 0x0b, 0x86, 0x05, 0xc3, 0x82, 0x61, 0xc1, 0xb0, 0x60, 0x58, 0x30, 0x2c, 0x18, 0x16, 0x0c,
		0x0b, 0x86, 0x05, 0xc3, 0x82, 0x61, 0xd5, 0x84, 0x61, 0xa5, 0xae, 0xe3, 0xa2, 0xcf, 0xae, 0x1b,
		0x24, 0x61, 0xe7, 0x4f, 0x3b, 0x8a, 0x75, 0x77, 0x5a, 0x38, 0x16, 0x1c, 0x0b, 0x8e, 0x05, 0xc7,
		0x82, 0x63, 0xc1, 0xb1, 0xe0, 0x58, 0x70, 0x2c, 0x38, 0x16, 0x1c, 0x0b, 0x8e, 0x05, 0xc7, 0xaa,
		0x09, 0xc7, 0xca, 0xd3, 0x30, 0xc9, 0xae, 0xa2, 0x7c, 0x5c, 0xec, 0x6f, 0x98, 0x1a, 0x36, 0xbf,
		0x5a, 0x98, 0x19, 0xa6, 0x05, 0xd3, 0x82, 0x69, 0xc1, 0xb4, 0x60, 0x5a, 0x30, 0x2d, 0x98, 0x16,
		0x4c, 0x0b, 0xa6, 0x05, 0xd3, 0x82, 0x69, 0xc1, 0xb4, 0xea, 0xc6, 0xb4, 0xfe, 0x77, 0xe8, 0x86,
		0x2e, 0xe8, 0x0d, 0xe3, 0xd8, 0x03, 0xd9, 0x9a, 0x9b, 0x1c, 0xbe, 0x05, 0xdf, 0x82, 0x6f, 0xc1,
		0xb7, 0xe0, 0x5b, 0xf0, 0x2d, 0xf8, 0x16, 0x7c, 0x0b, 0xbe, 0x05, 0xdf, 0x82, 0x6f, 0xc1, 0xb7,
		0x6a, 0xc2, 0xb7, 0x86, 0xc9, 0x9f, 0x49, 0xff, 0xaf, 0x24, 0x30, 0xcd, 0x1d, 0x9c, 0x9f, 0x14,
		0x7e, 0x05, 0xbf, 0x82, 0x5f, 0xc1, 0xaf, 0xe0, 0x57, 0xf0, 0x2b, 0xf8, 0x15, 0xfc, 0x0a, 0x7e,
		0x05, 0xbf, 0x82, 0x5f, 0xc1, 0xaf, 0x6a, 0xc6, 0xaf, 0x12, 0x2f, 0x04, 0x8b, 0xbb, 0x59, 0x30,
		0x2c, 0x18, 0x16, 0x0c, 0x0b, 0x86, 0x05, 0xc3, 0x82, 0x61, 0xc1, 0xb0, 0x60, 0x58, 0x30, 0x2c,
		0x18, 0x16, 0x0c, 0xcb, 0x9c, 0x61, 0x3d, 0xa8, 0x10, 0x66, 0x34, 0x9e, 0x27, 0x49, 0x3f, 0x0f,
		0x47, 0xa2, 0xaa, 0x0a, 0x13, 0x8d, 0xac, 0xf3, 0xc9, 0x5d, 0x85, 0x83, 0x70, 0x5c, 0x80, 0xbe,
		0xd1, 0xec, 0x0f, 0x5c, 0xd2, 0x19, 0xb3, 0x9c, 0x20, 0x71, 0xf9, 0x5f, 0xfd, 0xf4, 0xcf, 0x20,
		0x4a, 0xb2, 0x3c, 0x4c, 0x3a, 0xae, 0x79, 0xff, 0x8d, 0x6c, 0xe1, 0x9d, 0xe6, 0xd5, 0x20, 0xce,
		0x9a, 0x59, 0x74, 0x99, 0x84, 0x71, 0x94, 0x5c, 0x06, 0x83, 0xb4, 0x9f, 0xf7, 0x3b, 0xfd, 0x38,
		0x6b, 0x8e, 0x0c, 0xd0, 0x20, 0x77, 0xcd, 0x68, 0x64, 0xf0, 0xf4, 0xc2, 0x8e, 0x0b, 0xc2, 0x3c,
		0x4f, 0xa3, 0x8b, 0x61, 0xee, 0xb2, 0xdb, 0x37, 0x9b, 0x59, 0x1e, 0xe6, 0xae, 0x39, 0xb1, 0x8b,
		0xb2, 0xa6, 0x4b, 0xd3, 0x7e, 0x9a, 0x29, 0x5a, 0x47, 0x8d, 0x2c, 0x4f, 0x87, 0x9d, 0x3c, 0x99,
		0x18, 0x64, 0x6f, 0x66, 0x4f, 0xff, 0xfb, 0xcd, 0x93, 0xbd, 0x9c, 0x3c, 0xd8, 0xf9, 0xbd, 0xdf,
		0xb3, 0xfb, 0x6f, 0x9c, 0xbf, 0x1e, 0xc4, 0xd9, 0xf9, 0xfb, 0xe9, 0x93, 0xbf, 0x9d, 0x3e, 0xf8,
		0xf9, 0xbb, 0xec, 0xf3, 0xe0, 0x83, 0x3b, 0x7f, 0x39, 0x7d, 0xc4, 0xe7, 0xb3, 0xc7, 0xbe, 0x7d,
		0xef, 0xfc, 0xfd, 0xe8, 0xb1, 0xcf, 0x7f, 0x9e, 0x3c, 0xf6, 0xf9, 0x8b, 0x9b, 0xc7, 0x7e, 0x50,
		0x8d, 0x53, 0xa0, 0x70, 0x02, 0x1a, 0xd1, 0x38, 0x2e, 0x1b, 0x5c, 0xb9, 0x2c, 0x0b, 0x2f, 0x5d,
		0xa6, 0x76, 0x04, 0x66, 0xa6, 0xf8, 0xfd, 0x09, 0x95, 0x4e, 0xb5, 0xae, 0x02, 0x56, 0xf7, 0x4f,
		0x58, 0xf8, 0x25, 0x0c, 0xfd, 0x11, 0x56, 0x7e, 0x08, 0x73, 0xff, 0x83, 0xb9, 0xdf, 0xc1, 0xd6,
		0xdf, 0x50, 0x2d, 0x4d, 0xae, 0xee, 0x57, 0x30, 0xf5, 0x27, 0x18, 0xf8, 0x11, 0x8c, 0xfc, 0x07,
		0x06, 0x8e, 0x1e, 0x4b, 0x7f, 0x81, 0x31, 0xb9, 0xb3, 0xf6, 0x0f, 0xf8, 0x60, 0x6e, 0x06, 0xfe,
		0x00, 0x53, 0x3f, 0x80, 0x2f, 0x11, 0xf1, 0xc7, 0xfb, 0xbd, 0x48, 0x4d, 0x45, 0xf9, 0xf1, 0xd9,
		0x6e, 0xf3, 0x8d, 0x4f, 0x2e, 0x8e, 0xfb, 0xb6, 0x8c, 0xe3, 0xde, 0x94, 0x70, 0x0e, 0x38, 0x07,
		0x9c, 0x03, 0xce, 0x01, 0xe7, 0x80, 0x73, 0xc0, 0x39, 0xe0, 0x1c, 0x70, 0x0e, 0x38, 0x07, 0x9c,
		0xa3, 0xce, 0x9c, 0x63, 0x10, 0xe6, 0x9f, 0x82, 0x71, 0x90, 0xcb, 0x96, 0x78, 0x2c, 0x9b, 0x17,
		0xf6, 0x01, 0xfb, 0x80, 0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0xb0, 0x0f, 0xd8, 0x07, 0xec, 0x03, 0xf6,
		0x01, 0xfb, 0x80, 0x7d, 0xd4, 0x9e, 0x7d, 0xd8, 0xf3, 0x0e, 0x18, 0x07, 0x8c, 0x03, 0xc6, 0x01,
		0xe3, 0x80, 0x71, 0xc0, 0x38, 0x60, 0x1c, 0x30, 0x0e, 0x18, 0x07, 0x8c, 0x03, 0xc6, 0xb1, 0x3b,
		0x8c, 0x23, 0x77, 0xa1, 0x8f, 0x70, 0xc7, 0xdd, 0x69, 0xe1, 0x1e, 0x70, 0x0f, 0xb8, 0x07, 0xdc,
		0x03, 0xee, 0x01, 0xf7, 0x80, 0x7b, 0xc0, 0x3d, 0xe0, 0x1e, 0x70, 0x0f, 0xb8, 0x47, 0x9d, 0xb9,
		0x47, 0xea, 0x32, 0x97, 0x7e, 0x1e, 0x57, 0x54, 0xf0, 0x91, 0x72, 0xf5, 0x9d, 0xe9, 0xe1, 0x22,
		0x70, 0x11, 0xb8, 0x08, 0x5c, 0x04, 0x2e, 0x02, 0x17, 0x81, 0x8b, 0xc0, 0x45, 0xe0, 0x22, 0x70,
		0x11, 0xb8, 0xc8, 0xae, 0x70, 0x11, 0x6f, 0x2c, 0x04, 0xfe, 0x01, 0xff, 0x80, 0x7f, 0xc0, 0x3f,
		0xe0, 0x1f, 0xf0, 0x0f, 0xf8, 0x07, 0xfc, 0x03, 0xfe, 0x01, 0xff, 0x80, 0x7f, 0xec, 0x1c, 0xff,
		0xb0, 0x4f, 0xc7, 0x5a, 0x3d, 0x3b, 0x4c, 0x04, 0x26, 0x02, 0x13, 0x81, 0x89, 0xc0, 0x44, 0x60,
		0x22, 0x30, 0x11, 0x98, 0x08, 0x4c, 0x04, 0x26, 0x02, 0x13, 0xa9, 0x33, 0x13, 0xc9, 0x52, 0xd7,
		0x4b, 0x5d, 0x66, 0x7c, 0x0f, 0x7d, 0x71, 0x56, 0x98, 0x07, 0xcc, 0x03, 0xe6, 0x01, 0xf3, 0x80,
		0x79, 0xc0, 0x3c, 0x60, 0x1e, 0x30, 0x0f, 0x98, 0x07, 0xcc, 0x03, 0xe6, 0x51, 0x5b, 0xe6, 0xd1,
		0x1f, 0xe6, 0xc6, 0x0d, 0x06, 0x17, 0x66, 0x84, 0x71, 0xc0, 0x38, 0x60, 0x1c, 0x30, 0x0e, 0x18,
		0x07, 0x8c, 0x03, 0xc6, 0x01, 0xe3, 0x80, 0x71, 0xc0, 0x38, 0x60, 0x1c, 0xb5, 0x66, 0x1c, 0xd6,
		0x2d, 0x06, 0x97, 0xcc, 0x09, 0xeb, 0x80, 0x75, 0xc0, 0x3a, 0x60, 0x1d, 0xb0, 0x0e, 0x58, 0x07,
		0xac, 0x03, 0xd6, 0x01, 0xeb, 0x80, 0x75, 0xc0, 0x3a, 0x6a, 0xcd, 0x3a, 0xbc, 0x34, 0x19, 0x5c,
		0x35, 0x31, 0xfc, 0x03, 0xfe, 0x01, 0xff, 0x80, 0x7f, 0xc0, 0x3f, 0xe0, 0x1f, 0xf0, 0x0f, 0xf8,
		0x07, 0xfc, 0x03, 0xfe, 0x01, 0xff, 0xa8, 0x3f, 0xff, 0xf0, 0xc0, 0x3c, 0xe0, 0x1c, 0x70, 0x0e,
		0x38, 0x07, 0x9c, 0x03, 0xce, 0x01, 0xe7, 0x80, 0x73, 0xc0, 0x39, 0xe0, 0x1c, 0x70, 0x0e, 0x38,
		0xc7, 0x0e, 0x71, 0x0e, 0xe3, 0xca, 0x56, 0x2b, 0xe6, 0x85, 0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0xb0,
		0x0f, 0xd8, 0x07, 0xec, 0x03, 0xf6, 0x01, 0xfb, 0x80, 0x7d, 0xc0, 0x3e, 0x60, 0x1f, 0xb5, 0x66,
		0x1f, 0x3e, 0x5b, 0x0d, 0xfe, 0x60, 0x7e, 0xd8, 0x08, 0x6c, 0x04, 0x36, 0x02, 0x1b, 0x81, 0x8d,
		0xc0, 0x46, 0x60, 0x23, 0xb0, 0x11, 0xd8, 0x08, 0x6c, 0x04, 0x36, 0xb2, 0x33, 0x6c, 0xc4, 0x1f,
		0x0f, 0x81, 0x81, 0xc0, 0x40, 0x60, 0x20, 0x30, 0x10, 0x18, 0x08, 0x0c, 0x04, 0x06, 0x02, 0x03,
		0x81, 0x81, 0xc0, 0x40, 0x60, 0x20, 0xbb, 0xc7, 0x40, 0x3c, 0x24, 0x65, 0xd1, 0x6f, 0x10, 0x2e,
		0x02, 0x17, 0x81, 0x8b, 0xc0, 0x45, 0xe0, 0x22, 0x70, 0x11, 0xb8, 0x08, 0x5c, 0x04, 0x2e, 0x02,
		0x17, 0xd9, 0x51, 0x2e, 0xe2, 0xa1, 0xe1, 0xe0, 0xf2, 0x69, 0xe1, 0x1e, 0x70, 0x0f, 0xb8, 0x07,
		0xdc, 0x03, 0xee, 0x01, 0xf7, 0x80, 0x7b, 0xc0, 0x3d, 0xe0, 0x1e, 0x70, 0x0f, 0xb8, 0x47, 0x6d,
		0xb9, 0x47, 0x1a, 0xe6, 0x2e, 0x88, 0xa3, 0xab, 0x28, 0x77, 0x5d, 0x43, 0xee, 0xb1, 0x7c, 0x5a,
		0xb8, 0x07, 0xdc, 0x03, 0xee, 0x01, 0xf7, 0x80, 0x7b, 0xc0, 0x3d, 0xe0, 0x1e, 0x70, 0x0f, 0xb8,
		0x07, 0xdc, 0x03, 0xee, 0x51, 0x0e, 0xee, 0xf1, 0xa0, 0xc4, 0x67, 0xbc, 0xf1, 0x3c, 0x49, 0xfa,
		0xf9, 0x38, 0x93, 0x4a, 0xe5, 0x58, 0x37, 0xb2, 0xce, 0x27, 0x77, 0x15, 0x0e, 0xc2, 0xfc, 0xd3,
		0x48, 0xe3, 0x37, 0xfb, 0x03, 0x97, 0x74, 0xc6, 0x56, 0x7f, 0x90, 0xb8, 0xfc, 0xaf, 0x7e, 0xfa,
		0x67, 0x10, 0x25, 0x59, 0x1e, 0x26, 0x1d, 0xd7, 0xbc, 0xff, 0x46, 0xb6, 0xf0, 0x4e, 0xf3, 0x6a,
		0x10, 0x67, 0xcd, 0x2c, 0xba, 0x4c, 0xc2, 0x38, 0x4a, 0x2e, 0x83, 0x41, 0xda, 0xcf, 0xfb, 0x9d,
		0x7e, 0x9c, 0x35, 0x47, 0x06, 0x5c, 0x90, 0xbb, 0x66, 0x34, 0x32, 0x28, 0x7a, 0x61, 0xc7, 0x05,
		0x61, 0x9e, 0xa7, 0xd1, 0xc5, 0x30, 0x77, 0xd9, 0xed, 0x9b, 0xcd, 0x2c, 0x0f, 0x73, 0xd7, 0x9c,
		0xd8, 0x1d, 0x1a, 0xac, 0xa9, 0x91, 0xe5, 0xe9, 0xb0, 0x93, 0x27, 0x13, 0x0b, 0xe7, 0xcd, 0xec,
		0x71, 0x7f, 0xbf, 0x79, 0x94, 0x97, 0x93, 0x27, 0x39, 0xbf, 0xf7, 0x7b, 0x76, 0xff, 0x8d, 0xf3,
		0xd7, 0x83, 0x38, 0x3b, 0x7f, 0x3f, 0x7d, 0xd4, 0xb7, 0xd3, 0x27, 0x3d, 0x7f, 0x97, 0x7d, 0x1e,
		0x7c, 0x70, 0xe7, 0x2f, 0xa7, 0xcf, 0xf4, 0x7c, 0xf6, 0x9c, 0xb7, 0xef, 0x9d, 0xbf, 0x1f, 0x3d,
		0xe7, 0xf9, 0xcf, 0xd3, 0xe7, 0x7c, 0x50, 0x4e, 0x79, 0x16, 0x94, 0xe5, 0xc6, 0xed, 0xc6, 0x47,
		0x5d, 0x71, 0x49, 0x9e, 0x59, 0xac, 0x77, 0x66, 0x11, 0x3e, 0x89, 0x3a, 0xca, 0x4e, 0x8d, 0x63,
		0x6b, 0x72, 0x6b, 0x03, 0x4e, 0xad, 0xcd, 0xa5, 0xcd, 0x38, 0xb4, 0x19, 0x77, 0xb6, 0xe1, 0xcc,
		0xe5, 0xd6, 0x96, 0x6a, 0xdc, 0xd8, 0x02, 0x61, 0xe6, 0x51, 0xa6, 0xf5, 0x74, 0x07, 0x74, 0xc2,
		0x55, 0xf8, 0x25, 0x88, 0xa3, 0xe4, 0xcf, 0xe0, 0x22, 0x4c, 0xba, 0x7f, 0x45, 0xdd, 0xb1, 0x0d,
		0xa2, 0xa4, 0x19, 0x96, 0xcc, 0x85, 0x7e, 0x40, 0x3f, 0xa0, 0x1f, 0xd0, 0x0f, 0xa2, 0x12, 0x3f,
		0x83, 0x97, 0xe0, 0xcf, 0x8b, 0x41, 0xa6, 0xa8, 0x21, 0x14, 0x1c, 0xa6, 0x8d, 0x7f, 0x25, 0x37,
		0x4e, 0x8d, 0xc6, 0x3f, 0x95, 0xbe, 0xbb, 0xae, 0x27, 0x56, 0xd1, 0x25, 0x6e, 0xe1, 0x79, 0x35,
		0x72, 0xa7, 0x59, 0x79, 0x5a, 0x2d, 0x7d, 0x65, 0x8a, 0x9e, 0x55, 0x13, 0x8f, 0xaa, 0xf5, 0xd6,
		0xdb, 0x7b, 0x50, 0x4d, 0xa5, 0xa1, 0x22, 0x9e, 0xc7, 0xb3, 0xb2, 0xda, 0xf8, 0x0f, 0x4a, 0x74,
		0x26, 0xb5, 0x3c, 0xa0, 0x65, 0xf4, 0x7c, 0x0a, 0xaa, 0xdc, 0x32, 0x39, 0x3a, 0x65, 0xac, 0xcc,
		0xe2, 0x52, 0x29, 0x20, 0x91, 0x8d, 0x6c, 0x78, 0x91, 0x75, 0xd2, 0x68, 0x20, 0x2a, 0x8f, 0x33,
		0xeb, 0xf1, 0xce, 0xe8, 0x42, 0xe7, 0x67, 0xea, 0x51, 0x10, 0x1a, 0x4e, 0x9a, 0x8f, 0x6a, 0xf0,
		0x50, 0x45, 0xfe, 0xa9, 0xc5, 0x3b, 0xd5, 0xf9, 0xa6, 0x3a, 0xcf, 0xd4, 0xe5, 0x97, 0xe5, 0xd2,
		0x49, 0xbf, 0x44, 0xa9, 0xac, 0xc0, 0x76, 0xa6, 0xa7, 0x4a, 0xc9, 0xfd, 0x35, 0x19, 0x5f, 0xc7,
		0xe5, 0xd5, 0xc2, 0xe5, 0x85, 0xcb, 0x0b, 0x97, 0x57, 0x39, 0x5d, 0x5e, 0xd2, 0x50, 0xa5, 0x6b,
		0x09, 0x59, 0x5a, 0x46, 0xc6, 0x24, 0x9c, 0x6c, 0xea, 0x72, 0xc1, 0x9d, 0x39, 0xec, 0x99, 0xc3,
		0x9f, 0x2d, 0x0c, 0x2a, 0x7b, 0x5f, 0x2a, 0x9f, 0x4d, 0x3d, 0x70, 0x69, 0xc7, 0x25, 0x79, 0x78,
		0xe9, 0x0c, 0xd2, 0xa9, 0x8f, 0x48, 0xa7, 0xfe, 0xf1, 0x83, 0x90, 0x4e, 0x2d, 0x37, 0x1f, 0xe9,
		0xd4, 0x95, 0x15, 0x91, 0xd6, 0xfe, 0x3e, 0xd9, 0xd3, 0x65, 0x1b, 0x9d, 0xec, 0x69, 0x11, 0xc3,
		0x67, 0xb7, 0xb2, 0xa7, 0xe7, 0x38, 0x52, 0x53, 0xc5, 0xe3, 0xb3, 0x57, 0xa2, 0xc8, 0xc2, 0xdc,
		0xc3, 0x9e, 0x4f, 0xa8, 0xd5, 0x0e, 0xe4, 0xcc, 0xdd, 0xc4, 0x89, 0xd4, 0xfc, 0x84, 0xd2, 0x61,
		0xa8, 0x3d, 0x0b, 0x37, 0xe1, 0x01, 0x6e, 0x42, 0x43, 0xde, 0x8c, 0x9b, 0xb0, 0x8e, 0x9a, 0x52,
		0xcd, 0x4d, 0xd8, 0x09, 0xe3, 0xce, 0x30, 0x0e, 0x73, 0xd7, 0x0d, 0xc2, 0x8b, 0xac, 0x1f, 0x0f,
		0x73, 0x17, 0xcc, 0x2b, 0xaa, 0xe0, 0xe2, 0x2f, 0x7d, 0xef, 0xe1, 0x3a, 0x5f, 0x02, 0xa7, 0xa2,
		0x35, 0x18, 0x1a, 0x82, 0xa2, 0x15, 0x38, 0x9a, 0x83, 0xa4, 0x39, 0x58, 0xda, 0x82, 0xa6, 0x2e,
		0xd1, 0xaa, 0xbe, 0x53, 0x71, 0x18, 0x25, 0x39, 0xf5, 0x19, 0xd6, 0xfa, 0xc1, 0xa1, 0x28, 0xe2,
		0x2d, 0xc2, 0xa1, 0x58, 0x4c, 0x44, 0xa8, 0xcf, 0x50, 0x37, 0xa9, 0xc1, 0xc3, 0xa8, 0xfa, 0x7d,
		0x35, 0x6a, 0xc3, 0x91, 0xbb, 0x00, 0xcd, 0x80, 0x66, 0x40, 0x33, 0xa0, 0x19, 0xeb, 0x9d, 0x18,
		0x72, 0x17, 0xa0, 0x1a, 0x50, 0x0d, 0xa8, 0x46, 0xf9, 0xa8, 0x06, 0xb9, 0x0b, 0x30, 0x8b, 0x72,
		0x8c, 0x48, 0xee, 0x82, 0x58, 0xee, 0x82, 0x46, 0x14, 0x7a, 0xaf, 0xa4, 0xa9, 0x0b, 0x82, 0x37,
		0x24, 0xe5, 0xe5, 0x9a, 0x9b, 0xc0, 0x7e, 0x4f, 0x42, 0x0d, 0x2f, 0x04, 0xcf, 0x3f, 0x5d, 0x59,
		0xee, 0x05, 0x3f, 0xf0, 0x28, 0xdd, 0x23, 0x0a, 0x2f, 0x5c, 0x58, 0xac, 0xf1, 0x2a, 0xca, 0xf2,
		0xd1, 0xea, 0x8b, 0x1c, 0x93, 0x11, 0xd5, 0x78, 0x11, 0xbb, 0x11, 0x07, 0xcf, 0x64, 0x2c, 0xbc,
		0x91, 0x65, 0x3a, 0x37, 0xa2, 0x8e, 0xbb, 0xb8, 0xf1, 0x26, 0xed, 0xba, 0xd4, 0x75, 0x7f, 0x1a,
		0xad, 0x6e, 0x32, 0x8c, 0x63, 0xaf, 0x9b, 0x2c, 0x0c, 0x5d, 0xe5, 0x82, 0xac, 0x86, 0xc4, 0xbd,
		0xfa, 0x32, 0xa0, 0x53, 0x31, 0x40, 0xda, 0x1e, 0x46, 0xb6, 0xfb, 0xe4, 0x96, 0x32, 0x29, 0x25,
		0x8b, 0x65, 0x90, 0xc1, 0x02, 0x92, 0xe7, 0x53, 0xe2, 0xb6, 0x93, 0xb3, 0xcd, 0xa5, 0x64, 0x0b,
		0x09, 0x69, 0x24, 0x2e, 0xba, 0xfc, 0x74, 0xd1, 0x4f, 0xb7, 0x6f, 0x95, 0x33, 0xf3, 0x1a, 0xde,
		0x0e, 0xb5, 0xa5, 0xa4, 0x16, 0x4b, 0x1c, 0x2d, 0x1c, 0xb4, 0x90, 0x08, 0x4a, 0x08, 0x06, 0x1d,
		0xa4, 0x82, 0x0a, 0xe2, 0x41, 0x03, 0xf1, 0xa0, 0x80, 0xac, 0xd3, 0xdf, 0x16, 0x5d, 0x8b, 0x26,
		0x52, 0xce, 0x4e, 0x4d, 0xf1, 0x7d, 0xbe, 0x7f, 0x0e, 0x8b, 0x6e, 0xb3, 0x4c, 0x1e, 0xb7, 0x58,
		0xde, 0xb6, 0x64, 0xcc, 0x50, 0x21, 0x36, 0x28, 0x1d, 0x03, 0x54, 0x8b, 0xf5, 0xa9, 0xc5, 0xf4,
		0x74, 0x62, 0x77, 0x7e, 0xd9, 0x9a, 0x54, 0x9e, 0x74, 0x23, 0xec, 0x76, 0x53, 0x97, 0x65, 0xf2,
		0x35, 0xa4, 0xa6, 0x03, 0xcb, 0x96, 0x8f, 0xda, 0xa7, 0x7c, 0x94, 0xc8, 0xd0, 0x94, 0x8f, 0x32,
		0x05, 0x8b, 0x72, 0x3a, 0x32, 0xc5, 0x03, 0xf7, 0x33, 0x89, 0x8d, 0x5d, 0xd8, 0x4b, 0x5d, 0x4f,
		0x52, 0x62, 0xa7, 0x5a, 0xff, 0x44, 0x70, 0xcc, 0xb7, 0x13, 0xd2, 0xf8, 0xe4, 0xc9, 0xa4, 0xe5,
		0xcb, 0x14, 0xb4, 0xea, 0x54, 0x29, 0x50, 0xf4, 0xa6, 0x9e, 0xca, 0x0d, 0x3d, 0xb5, 0xda, 0x80,
		0x07, 0x80, 0x3b, 0xe0, 0xbe, 0xa3, 0xe0, 0x2e, 0x5e, 0x1b, 0x50, 0xda, 0x52, 0x54, 0xb6, 0x18,
		0x95, 0x2c, 0x47, 0x35, 0x0b, 0x52, 0x13, 0x6c, 0x0c, 0x40, 0x47, 0x1b, 0x7c, 0xcc, 0x40, 0xc8,
		0x0c, 0x8c, 0x6c, 0x40, 0x49, 0x16, 0x9c, 0x84, 0x41, 0x4a, 0xcf, 0x12, 0x5d, 0x90, 0xf8, 0x68,
		0x10, 0xe8, 0xe0, 0xcb, 0x1d, 0x03, 0xe6, 0x54, 0x61, 0xec, 0xc9, 0xda, 0x54, 0xae, 0x57, 0xc5,
		0xed, 0xca, 0x7f, 0x6e, 0x2b, 0xae, 0xfd, 0xc2, 0x1e, 0x68, 0x5e, 0x11, 0x7c, 0x1b, 0xe6, 0xb9,
		0x4b, 0x13, 0xf5, 0xcc, 0xdd, 0xc6, 0xc3, 0x87, 0x1f, 0xf7, 0x83, 0xd3, 0xb3, 0x6f, 0x1f, 0x5b,
		0xc1, 0xe9, 0xd9, 0xcd, 0xcb, 0xd6, 0xf8, 0x3f, 0x37, 0xaf, 0x0f, 0x3e, 0xee, 0x07, 0xed, 0xe9,
		0xeb, 0xa3, 0x8f, 0xfb, 0xc1, 0xd1, 0xd9, 0xa3, 0x3f, 0xfe, 0x78, 0xf2, 0xe8, 0xef, 0xc3, 0xeb,
		0xcd, 0x3f, 0xa8, 0x97, 0xc7, 0x7e, 0xa6, 0xb9, 0x15, 0x6f, 0xde, 0xbf, 0xfc, 0x6f, 0xb3, 0xfd,
		0xf8, 0xb7, 0xe5, 0x86, 0xfc, 0xa3, 0x51, 0xb5, 0x9c, 0xc8, 0xc7, 0x15, 0x06, 0xa7, 0x63, 0xc0,
		0x69, 0x2b, 0x70, 0x0a, 0x83, 0xde, 0xf3, 0xe0, 0xd7, 0xb3, 0xbf, 0x5b, 0x8f, 0xdb, 0xd7, 0xcf,
		0x1e, 0xfd, 0x7d, 0x72, 0x7d, 0xff, 0xcd, 0x6f, 0xcb, 0xfe, 0xac, 0xf5, 0xf8, 0xe4, 0xfa, 0xd9,
		0x8a, 0x7f, 0x39, 0xbe, 0x7e, 0xb6, 0xe6, 0x18, 0x47, 0xd7, 0x0f, 0x17, 0xfe, 0x74, 0xf4, 0xfe,
		0xc1, 0xaa, 0x0f, 0xb4, 0x57, 0x7c, 0xe0, 0x70, 0xd5, 0x07, 0x0e, 0x57, 0x7c, 0x60, 0xe5, 0x57,
		0x3a, 0x58, 0xf1, 0x81, 0xa3, 0xeb, 0x6f, 0x0b, 0x7f, 0xff, 0x70, 0xf9, 0x9f, 0x1e, 0x5f, 0x3f,
		0xfa, 0xb6, 0xea, 0xdf, 0x4e, 0xae, 0xbf, 0x3d, 0x7b, 0x04, 0x54, 0xaf, 0x0f, 0xd5, 0x88, 0xa7,
		0xbd, 0x78, 0x56, 0x4f, 0x71, 0xed, 0x4e, 0x33, 0x25, 0x41, 0xff, 0x62, 0xd7, 0xe5, 0xae, 0x93,
		0xbb, 0x6e, 0x70, 0x9b, 0x7a, 0xa7, 0xe6, 0x14, 0x5a, 0x32, 0x17, 0xfe, 0x21, 0xfc, 0x43, 0xf8,
		0x87, 0xf0, 0x0f, 0x89, 0x4a, 0x7c, 0x96, 0xa7, 0x51, 0x72, 0x49, 0x2b, 0xed, 0x62, 0xcf, 0x3a,
		0x4d, 0xf1, 0x0a, 0xb2, 0x3c, 0xcc, 0x87, 0x8a, 0xb1, 0x82, 0xfb, 0x13, 0xa1, 0x13, 0xd0, 0x09,
		0xe8, 0x04, 0x74, 0x82, 0xa8, 0xc4, 0xbb, 0x64, 0x78, 0xe5, 0xd2, 0x50, 0xa9, 0x5e, 0xce, 0x4c,
		0x31, 0xb4, 0x15, 0xc6, 0x7e, 0x91, 0x0c, 0xaf, 0x46, 0x8b, 0x73, 0xbd, 0x03, 0x4a, 0x27, 0x75,
		0xbd, 0xd4, 0x65, 0x9f, 0x82, 0xd4, 0x75, 0x87, 0x1d, 0x95, 0x8b, 0xca, 0x33, 0x89, 0x58, 0x9c,
		0x0a, 0xc5, 0x83, 0xe2, 0x41, 0xf1, 0xa0, 0x78, 0x44, 0x25, 0xfe, 0xa2, 0xdf, 0x8f, 0x5d, 0xa8,
		0xaa, 0x74, 0x5a, 0x5c, 0xf5, 0x5f, 0x47, 0xda, 0xeb, 0x71, 0xd5, 0x7f, 0x76, 0x03, 0x6e, 0xf6,
		0xaa, 0xba, 0x8d, 0xbe, 0x7f, 0x9f, 0x3e, 0xcb, 0xec, 0x55, 0xc9, 0xba, 0x7b, 0x97, 0xe1, 0x16,
		0xbf, 0x4c, 0x44, 0x93, 0x0b, 0xfc, 0x5c, 0xe0, 0xd7, 0x06, 0xa2, 0x2a, 0x5d, 0xda, 0x5f, 0x84,
		0x1e, 0x6e, 0xea, 0x57, 0x41, 0xd8, 0xaa, 0x70, 0x3d, 0x7f, 0x26, 0x5b, 0x65, 0xbe, 0x94, 0x9f,
		0xb9, 0x2c, 0x8b, 0xfa, 0x89, 0xc0, 0x9d, 0xfc, 0xd9, 0x48, 0x5c, 0xc9, 0xe7, 0x4a, 0xbe, 0x37,
		0xfe, 0x59, 0xb1, 0x2b, 0xf9, 0x93, 0x43, 0x23, 0x77, 0x23, 0x7f, 0x3a, 0x20, 0x17, 0xf2, 0x0d,
		0x9d, 0x50, 0x5c, 0xc8, 0xe7, 0x42, 0xfe, 0x77, 0x06, 0x72, 0x5f, 0x06, 0x71, 0xd4, 0x89, 0xf2,
		0x20, 0xed, 0x0f, 0x73, 0x17, 0xf4, 0x2f, 0xfe, 0xaf, 0xeb, 0xe4, 0x0a, 0xf7, 0xf3, 0x57, 0xcc,
		0x53, 0xf2, 0x1b, 0x9d, 0x5c, 0xd7, 0xaf, 0x94, 0x7f, 0x9a, 0x1b, 0x9d, 0x65, 0xbe, 0xd1, 0xb9,
		0x14, 0x02, 0xf4, 0x82, 0x67, 0xcb, 0xa7, 0xa3, 0xc9, 0x2b, 0x01, 0x34, 0x7f, 0x00, 0x65, 0x06,
		0x54, 0x36, 0x80, 0x25, 0x0b, 0x5c, 0xc2, 0x00, 0xa6, 0x06, 0x64, 0xb3, 0x81, 0xa3, 0xa4, 0xeb,
		0xbe, 0xe8, 0x37, 0x52, 0xba, 0x99, 0x86, 0x0e, 0x4a, 0xd6, 0x80, 0x66, 0x08, 0x6c, 0x56, 0x00,
		0x67, 0x0e, 0x74, 0xe6, 0x80, 0x67, 0x0b, 0x7c, 0x3a, 0x00, 0xa8, 0x04, 0x84, 0xb3, 0xa5, 0xb1,
		0xeb, 0xa0, 0x24, 0x5f, 0x98, 0x69, 0xa5, 0x05, 0x76, 0xa2, 0x7b, 0xd5, 0xf1, 0x6e, 0xe1, 0xa6,
		0x1b, 0x48, 0xde, 0xe5, 0x56, 0x82, 0xa2, 0x65, 0x9e, 0x56, 0xca, 0x8f, 0x56, 0x4b, 0x0c, 0x45,
		0xdb, 0x5d, 0xdd, 0x86, 0x47, 0xf5, 0xa1, 0xfa, 0x50, 0x7d, 0x25, 0xe3, 0x02, 0xb3, 0x09, 0xc2,
		0x4c, 0xbf, 0x43, 0xdd, 0x6d, 0x09, 0xab, 0x2c, 0xd1, 0x16, 0x5e, 0x9b, 0x0e, 0x67, 0xea, 0x3c,
		0xc1, 0x12, 0x34, 0x3d, 0x80, 0xa7, 0x35, 0x88, 0x7a, 0x03, 0x53, 0x6f, 0xa0, 0xea, 0x07, 0x5c,
		0x75, 0x41, 0x56, 0x19, 0x6c, 0xed, 0xf8, 0xc6, 0x12, 0x60, 0x0c, 0x92, 0xe1, 0xd5, 0x85, 0x4b,
		0x2d, 0xce, 0xdc, 0x04, 0x22, 0x4f, 0x0c, 0xa6, 0xb2, 0x69, 0xe4, 0x3a, 0xfd, 0xb1, 0xc1, 0x90,
		0x3d, 0xeb, 0xc6, 0xae, 0xc6, 0xba, 0x6d, 0x61, 0x5a, 0xe3, 0x46, 0xaf, 0xb3, 0x79, 0x3d, 0xf4,
		0xf2, 0x34, 0x42, 0x98, 0xbb, 0xa2, 0x64, 0xd8, 0x00, 0xb6, 0x2c, 0xa2, 0xd4, 0x3e, 0x38, 0x6d,
		0x9f, 0x1e, 0x9f, 0x1c, 0x9c, 0x1e, 0xed, 0x90, 0x4c, 0x3d, 0xa8, 0xc7, 0x2c, 0x67, 0x15, 0xed,
		0x77, 0xab, 0x78, 0xa6, 0x95, 0x23, 0x2b, 0x0b, 0xe6, 0x82, 0x66, 0x84, 0x05, 0x26, 0x05, 0x93,
		0x82, 0x49, 0xc1, 0xa4, 0x2a, 0xca, 0xa4, 0x86, 0x51, 0x92, 0x1f, 0xb7, 0x0d, 0x69, 0xd4, 0x53,
		0x68, 0x14, 0x34, 0x0a, 0x1a, 0x05, 0x8d, 0xf2, 0x20, 0x4a, 0x3a, 0x57, 0x3a, 0x21, 0x54, 0x10,
		0x2a, 0xff, 0x84, 0x6a, 0xae, 0xcf, 0xba, 0x21, 0xaf, 0x12, 0xeb, 0xee, 0x0e, 0xbd, 0x82, 0x5e,
		0x41, 0xaf, 0xa0, 0x57, 0x35, 0xa4, 0x57, 0x87, 0x07, 0x44, 0xa9, 0xa0, 0x57, 0xd0, 0x2b, 0xe8,
		0x55, 0xcd, 0x45, 0x89, 0x28, 0x15, 0xa4, 0xaa, 0x56, 0xa4, 0x6a, 0x10, 0x0c, 0x6c, 0xac, 0xf4,
		0xf9, 0xbe, 0x72, 0x36, 0x49, 0xab, 0xd0, 0x29, 0xe8, 0x14, 0x74, 0x0a, 0x3a, 0x55, 0x2d, 0x3a,
		0x65, 0x05, 0x8f, 0x7b, 0xca, 0x5d, 0x38, 0x57, 0x2d, 0x65, 0xed, 0x18, 0xd5, 0x9d, 0xae, 0x9d,
		0xa6, 0x48, 0xb2, 0x67, 0xd4, 0x27, 0x6f, 0x51, 0x13, 0x19, 0x75, 0x26, 0x5b, 0x98, 0xd8, 0xb2,
		0xa7, 0x64, 0x73, 0x32, 0xd9, 0xa3, 0x6f, 0x0f, 0x3f, 0xb6, 0x82, 0x83, 0xb3, 0xe9, 0x2f, 0x87,
		0x1f, 0xf7, 0x83, 0x83, 0x33, 0xcd, 0xce, 0x72, 0x0b, 0x86, 0xab, 0xe5, 0xd6, 0x5a, 0x76, 0x9e,
		0x5b, 0x98, 0xfd, 0xdf, 0x65, 0xda, 0xe0, 0x7f, 0x18, 0xee, 0xf0, 0x83, 0x1a, 0x39, 0x07, 0xfc,
		0x60, 0xef, 0x31, 0xd8, 0x6b, 0x81, 0xbd, 0x34, 0x89, 0xb4, 0x6f, 0x12, 0xd9, 0x7c, 0xd8, 0x1a,
		0xe1, 0xd7, 0xd3, 0x1b, 0x48, 0x6b, 0x9d, 0x2d, 0x20, 0xdd, 0x0d, 0x72, 0xa1, 0x90, 0xd4, 0x14,
		0x12, 0x52, 0x5f, 0x5a, 0xa9, 0xaf, 0x9f, 0x96, 0xc6, 0x11, 0xea, 0xc1, 0x11, 0x1a, 0x87, 0x17,
		0x2e, 0xb6, 0x73, 0x82, 0xde, 0x4c, 0x87, 0x03, 0x14, 0x07, 0x28, 0x0e, 0x50, 0x1c, 0xa0, 0x38,
		0x40, 0xe7, 0x4e, 0xdc, 0xd5, 0x20, 0xce, 0x02, 0x0b, 0x7c, 0xc4, 0x03, 0x2a, 0xbc, 0x73, 0x66,
		0x99, 0x40, 0xf7, 0x77, 0xef, 0xc4, 0x70, 0x4a, 0xdb, 0xcc, 0x20, 0xfb, 0xdd, 0x9c, 0x3d, 0xa8,
		0x8f, 0x4c, 0x21, 0x63, 0xd3, 0x65, 0xe5, 0xf4, 0xb3, 0x6c, 0xfa, 0x63, 0x4f, 0x5f, 0xc0, 0x63,
		0xba, 0x87, 0xb1, 0xb7, 0xf0, 0xae, 0xcc, 0x79, 0x48, 0x29, 0x2a, 0x9d, 0xcc, 0xed, 0xb7, 0x9f,
		0x1e, 0x9d, 0x1c, 0xed, 0xb0, 0xe0, 0x3d, 0xa8, 0xe7, 0x6c, 0x38, 0xf9, 0x8b, 0x99, 0x17, 0xba,
		0xcd, 0xa5, 0x7f, 0x68, 0x21, 0xb6, 0x0d, 0xe7, 0xd4, 0x69, 0x46, 0xed, 0xef, 0x08, 0xe0, 0x71,
		0x5a, 0xdc, 0xe3, 0xb8, 0xdf, 0xcf, 0x9c, 0xa1, 0xc7, 0x69, 0x3c, 0x1d, 0x1e, 0xa7, 0x8d, 0x26,
		0xc2, 0xe3, 0x24, 0x2b, 0x1e, 0x78, 0x9c, 0xf0, 0x38, 0xad, 0xe9, 0x25, 0x31, 0x3c, 0x71, 0x7a,
		0xcd, 0xc3, 0x57, 0x1a, 0x13, 0x2d, 0x14, 0xe2, 0xc2, 0xda, 0xe4, 0x16, 0x1b, 0x3f, 0xdb, 0xf4,
		0xf1, 0x6c, 0xa8, 0x43, 0xd4, 0x21, 0xea, 0x10, 0x75, 0x88, 0x3a, 0xf4, 0xc6, 0xb3, 0x2d, 0xf9,
		0xb5, 0x11, 0xaf, 0xbe, 0xa6, 0x52, 0xfd, 0x9e, 0x42, 0xeb, 0xfd, 0x95, 0xf3, 0x18, 0x77, 0x49,
		0x9f, 0x76, 0xe2, 0x9e, 0xbe, 0x68, 0x2e, 0x6f, 0x0c, 0xba, 0xfc, 0xed, 0xa6, 0x66, 0x3f, 0x90,
		0x3d, 0xcb, 0xfe, 0xeb, 0xef, 0x27, 0xcb, 0x30, 0x7d, 0x71, 0xfe, 0x62, 0xf2, 0xbc, 0xef, 0x46,
		0x8f, 0xfb, 0xe6, 0x66, 0x11, 0x96, 0xbd, 0x79, 0xfe, 0x7e, 0xbc, 0x04, 0x55, 0x69, 0x3d, 0x53,
		0xea, 0xc6, 0x70, 0xff, 0x74, 0x5f, 0xb5, 0xaa, 0x7f, 0x36, 0x5e, 0x45, 0x59, 0xfe, 0x3c, 0xcf,
		0x95, 0x3a, 0xcf, 0xbd, 0x8e, 0x92, 0x17, 0xb1, 0x1b, 0x19, 0x03, 0x99, 0x8e, 0xe5, 0xda, 0x78,
		0x1d, 0x7e, 0x99, 0x9b, 0xc1, 0xa6, 0x30, 0x56, 0xe3, 0x4d, 0xda, 0x75, 0xa9, 0xeb, 0xfe, 0x34,
		0xda, 0x96, 0x64, 0x18, 0xc7, 0xa5, 0x96, 0x1e, 0x65, 0x80, 0xae, 0x14, 0x30, 0x37, 0x54, 0x5a,
		0x4c, 0x95, 0x1c, 0x8a, 0x65, 0x41, 0xf8, 0xba, 0xa6, 0x6d, 0x84, 0x95, 0x8e, 0x49, 0x49, 0x8f,
		0x87, 0x64, 0x17, 0xee, 0x52, 0x1d, 0x00, 0x19, 0x61, 0x2f, 0x2e, 0x9a, 0x02, 0x62, 0xd9, 0x88,
		0xfb, 0x9d, 0x30, 0x0e, 0x64, 0x6b, 0x8c, 0xcf, 0x85, 0x8a, 0x6e, 0x07, 0x97, 0xed, 0x6e, 0xbf,
		0x4f, 0x77, 0xfb, 0x32, 0x7b, 0xaa, 0xe8, 0x6e, 0x5f, 0x25, 0xb5, 0x24, 0xee, 0x19, 0x52, 0xec,
		0x79, 0xaa, 0xd1, 0xe3, 0x74, 0xb1, 0xa7, 0xe9, 0x3c, 0x70, 0xd5, 0x08, 0xec, 0x53, 0xd7, 0xe9,
		0xa7, 0xdd, 0x7b, 0x5a, 0x5a, 0x1c, 0xf5, 0x97, 0xce, 0x22, 0x0b, 0xff, 0x2d, 0xe0, 0x1f, 0xf8,
		0x07, 0xfe, 0x65, 0x64, 0x56, 0xba, 0x0f, 0xe8, 0x32, 0x00, 0x90, 0x17, 0xb1, 0xef, 0xa0, 0x8d,
		0xb4, 0xb0, 0xe9, 0x34, 0x47, 0x56, 0x6b, 0x8a, 0xac, 0x19, 0x5d, 0x35, 0x88, 0xa6, 0x6a, 0x47,
		0x4f, 0xcd, 0xa2, 0xa5, 0x66, 0xd1, 0x51, 0x9b, 0x68, 0x68, 0xb9, 0xfd, 0xd7, 0x5a, 0xcd, 0x8c,
		0x95, 0xdb, 0x6f, 0x99, 0xb4, 0xdd, 0x52, 0x4e, 0x1f, 0x51, 0x4f, 0x1b, 0xa1, 0xbb, 0x7b, 0xb9,
		0x81, 0xce, 0x1c, 0xf0, 0x6c, 0x81, 0x4f, 0x07, 0x00, 0x95, 0x80, 0x50, 0x8f, 0xd4, 0x1b, 0x92,
		0x7c, 0x0b, 0xd2, 0xff, 0x63, 0x27, 0x80, 0x20, 0xfd, 0xd7, 0x17, 0xa5, 0x6b, 0x95, 0xa8, 0x53,
		0x98, 0x3b, 0x7d, 0xd5, 0xa7, 0x99, 0xc8, 0xa0, 0x64, 0xbb, 0xab, 0xdb, 0xf0, 0xa8, 0x3e, 0x54,
		0x1f, 0xaa, 0xaf, 0x64, 0x5c, 0x60, 0x36, 0x41, 0xd8, 0xed, 0xa6, 0x2e, 0xcb, 0xec, 0x72, 0xcc,
		0xa7, 0x13, 0x92, 0x66, 0x5e, 0x36, 0xf0, 0xf4, 0x00, 0xa2, 0xd6, 0x60, 0xea, 0x0d, 0x54, 0xbd,
		0x81, 0xab, 0x1f, 0x90, 0xd5, 0x05, 0x5b, 0x65, 0xd0, 0xb5, 0xe3, 0x1d, 0x8b, 0xae, 0x93, 0x41,
		0x60, 0x83, 0x8f, 0x7b, 0xd4, 0xf9, 0x91, 0xde, 0xb9, 0xcf, 0x6d, 0xc3, 0xbd, 0x5b, 0xd8, 0x43,
		0x4a, 0x9d, 0x0b, 0x57, 0xc2, 0xa6, 0x72, 0xac, 0xfc, 0xec, 0xa6, 0xa5, 0xcc, 0x29, 0x55, 0x5e,
		0x25, 0xf0, 0x3c, 0x06, 0x3c, 0x4d, 0xc0, 0x93, 0xaa, 0xcd, 0xf6, 0x55, 0x9b, 0x51, 0x25, 0x6a,
		0xaa, 0x04, 0x71, 0xb6, 0x17, 0x67, 0xaa, 0x8b, 0x97, 0xec, 0x39, 0xaa, 0xda, 0xbb, 0x5e, 0x33,
		0x1b, 0x61, 0xd1, 0xc6, 0x50, 0xcc, 0x4a, 0xc0, 0xeb, 0x88, 0xd7, 0x11, 0xaf, 0x23, 0x5e, 0xc7,
		0x8a, 0x7a, 0x1d, 0x87, 0x51, 0x92, 0x3f, 0x35, 0x74, 0x38, 0x1e, 0xd1, 0xac, 0x7e, 0xfb, 0x07,
		0xa3, 0x59, 0xbd, 0xfe, 0xbc, 0x34, 0xab, 0xaf, 0xad, 0x28, 0x1d, 0x1c, 0xd1, 0xa5, 0x1e, 0xfa,
		0x54, 0x03, 0xfa, 0x94, 0xba, 0x41, 0x3f, 0xcd, 0x5d, 0x37, 0xe8, 0xc5, 0xe1, 0xa5, 0x61, 0xfe,
		0xc6, 0xbd, 0x79, 0x21, 0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0x82, 0x50,
		0x41, 0xa8, 0x20, 0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0xaa, 0xc2, 0x84, 0xca, 0xb8, 0xed, 0xed,
		0xbd, 0x79, 0x21, 0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x45, 0xff, 0xdb, 0x0a, 0xb3,
		0x2a, 0xfa, 0xdf, 0xd6, 0x68, 0x37, 0xbd, 0x72, 0x65, 0xcf, 0x44, 0x67, 0x81, 0xf0, 0xd0, 0xff,
		0xd6, 0x58, 0xe6, 0xe8, 0x7f, 0x4b, 0xff, 0x5b, 0xfa, 0xdf, 0x56, 0xe0, 0xd8, 0xd2, 0xff, 0x56,
		0x73, 0x4e, 0xfa, 0xdf, 0x96, 0xe3, 0xfb, 0xd3, 0x6f, 0x68, 0xd9, 0x3c, 0xbe, 0xeb, 0xf6, 0x2f,
		0xab, 0xd4, 0xbb, 0xec, 0xcd, 0x1a, 0xf7, 0x1a, 0x7a, 0x37, 0x7e, 0xda, 0x3b, 0xed, 0x2d, 0x16,
		0xde, 0xa2, 0xcf, 0x90, 0xa8, 0xaf, 0x8c, 0x3e, 0x43, 0xab, 0x8d, 0x76, 0xfa, 0x0c, 0xf9, 0x04,
		0xe6, 0xca, 0x00, 0x72, 0xad, 0x7a, 0x0c, 0xad, 0x03, 0xc1, 0xf4, 0x17, 0xf2, 0x78, 0x3c, 0x4a,
		0x79, 0x2c, 0x6a, 0xd1, 0x5d, 0x68, 0x51, 0xf4, 0xeb, 0xd4, 0x6e, 0x42, 0xb6, 0x7e, 0xa4, 0x4a,
		0xbd, 0x48, 0x1a, 0x4a, 0xd0, 0x50, 0x62, 0x8f, 0x86, 0x12, 0xb2, 0x6a, 0x48, 0xbc, 0xa1, 0x44,
		0xd7, 0x65, 0x79, 0x94, 0x8c, 0x15, 0x5b, 0xa0, 0x55, 0x7b, 0x71, 0x76, 0x2a, 0x96, 0x4d, 0xa6,
		0xd3, 0x50, 0x62, 0x5f, 0xab, 0xa1, 0xc4, 0x3e, 0x0d, 0x25, 0x0c, 0x40, 0xc9, 0x0c, 0x9c, 0xcc,
		0x40, 0xca, 0x06, 0xac, 0xaa, 0xe1, 0xa8, 0x50, 0xcb, 0xd7, 0xb0, 0xa9, 0x5b, 0xa8, 0x99, 0x8f,
		0xa1, 0x9b, 0x7f, 0x61, 0x50, 0xe8, 0xda, 0xa8, 0xee, 0xa0, 0x45, 0xa9, 0x2c, 0xb3, 0xd2, 0x58,
		0x35, 0xa9, 0x23, 0x78, 0xa6, 0xb9, 0x15, 0x96, 0xc5, 0x9d, 0x6a, 0x53, 0x17, 0xf0, 0xac, 0x4a,
		0xa1, 0x21, 0x1b, 0x70, 0x3a, 0x06, 0x9c, 0xb6, 0x02, 0x27, 0x0a, 0x9b, 0xd5, 0xa9, 0x4e, 0x5f,
		0xed, 0xa0, 0x1a, 0xf1, 0xac, 0x55, 0xdd, 0xbd, 0xb3, 0x8a, 0x04, 0x84, 0xcf, 0xca, 0x1a, 0x3b,
		0x11, 0xf4, 0x3b, 0x8e, 0xd3, 0xdc, 0x03, 0x85, 0x44, 0xdb, 0xdb, 0x2e, 0x57, 0xd3, 0x19, 0xf0,
		0x05, 0xe1, 0x0b, 0xc2, 0x17, 0x84, 0x2f, 0x48, 0x54, 0xe2, 0x55, 0xef, 0xea, 0xe0, 0x0b, 0xfa,
		0xce, 0xca, 0xab, 0xdf, 0xb5, 0x31, 0xb8, 0x5b, 0x63, 0x74, 0x97, 0xc6, 0xe0, 0xee, 0x9a, 0xe5,
		0x5d, 0x19, 0xe3, 0x7b, 0x0a, 0xe6, 0x77, 0x61, 0x7c, 0x5c, 0x41, 0x30, 0x48, 0x9a, 0x37, 0xbd,
		0xdb, 0xe2, 0x4d, 0x46, 0x2c, 0xef, 0xae, 0x78, 0x11, 0x94, 0x8a, 0x26, 0xb2, 0xe3, 0xad, 0xbc,
		0xab, 0x3e, 0x6d, 0xee, 0x92, 0x58, 0xdc, 0x1d, 0x51, 0xbe, 0x2b, 0x02, 0xaf, 0xdf, 0x9e, 0xd7,
		0xf7, 0x87, 0xb9, 0x36, 0xb1, 0x1f, 0x4d, 0x01, 0xb3, 0x87, 0xd9, 0xc3, 0xec, 0x61, 0xf6, 0x30,
		0x7b, 0x98, 0x3d, 0xcc, 0x1e, 0x66, 0x0f, 0xb3, 0x87, 0xd9, 0xc3, 0xec, 0x61, 0xf6, 0x30, 0x7b,
		0x98, 0x3d, 0xcc, 0x5e, 0x9a, 0xd9, 0xf7, 0x3b, 0x61, 0x1c, 0xe8, 0xf4, 0xb3, 0xbb, 0xe5, 0xf6,
		0x73, 0x93, 0xc0, 0xee, 0x61, 0xf7, 0xb0, 0x7b, 0xd8, 0xbd, 0x38, 0xc7, 0x3c, 0x6e, 0x2b, 0x32,
		0x7b, 0x85, 0xec, 0x5c, 0x65, 0x4e, 0xa9, 0x68, 0x9a, 0x58, 0x70, 0x48, 0xab, 0x62, 0xcf, 0x46,
		0x5d, 0x05, 0x2c, 0x19, 0x80, 0x66, 0xa1, 0x71, 0x0b, 0x6a, 0x68, 0xbd, 0xf5, 0x36, 0x15, 0x5e,
		0xbc, 0x49, 0x03, 0xc6, 0x76, 0x79, 0x8c, 0xed, 0x6c, 0x10, 0x44, 0x5d, 0x45, 0x3b, 0xfb, 0x66,
		0x7c, 0x4c, 0x6c, 0x4c, 0x6c, 0x4c, 0x6c, 0x4c, 0x6c, 0x71, 0x13, 0xbb, 0x75, 0xac, 0x68, 0x62,
		0x1f, 0x63, 0x62, 0x63, 0x62, 0x63, 0x62, 0xd7, 0xd2, 0xc4, 0x3e, 0x3e, 0x3a, 0x3a, 0xc4, 0xa6,
		0xc6, 0xa6, 0x56, 0xb0, 0xa9, 0x07, 0x69, 0x3f, 0x77, 0xe3, 0x8d, 0x0f, 0x52, 0xf7, 0xbf, 0x43,
		0x97, 0xe5, 0x4e, 0xd1, 0xc2, 0x5e, 0x3a, 0x1b, 0xf6, 0x36, 0xf6, 0x36, 0xf6, 0x36, 0xf6, 0xb6,
		0xa8, 0xc4, 0x47, 0x5d, 0x97, 0xe4, 0x51, 0xfe, 0x35, 0x75, 0x3d, 0xcd, 0x8c, 0x35, 0x8d, 0x5a,
		0xc6, 0x2f, 0x27, 0x5f, 0xfd, 0xa7, 0x30, 0x53, 0x3c, 0x57, 0xd3, 0x85, 0x7a, 0xfb, 0xee, 0xcd,
		0x87, 0x17, 0x3f, 0x7f, 0x78, 0xf9, 0xe6, 0xf7, 0xf3, 0x0f, 0xff, 0xf3, 0xf6, 0x85, 0xd6, 0xe9,
		0x1a, 0x9b, 0x32, 0x99, 0x6a, 0x0a, 0x98, 0x51, 0xd3, 0xc6, 0x57, 0x2f, 0x7f, 0xff, 0xe7, 0xf9,
		0xef, 0x6f, 0x7e, 0x79, 0x71, 0x3e, 0xb7, 0x74, 0xef, 0x5e, 0xfc, 0x9f, 0x7f, 0xbd, 0x78, 0xff,
		0xe1, 0xc5, 0x2f, 0x8d, 0x2a, 0x1a, 0xcd, 0x46, 0x2b, 0xf7, 0xaf, 0xdf, 0x27, 0x2b, 0xc6, 0x32,
		0xfd, 0x50, 0xc0, 0xee, 0xc9, 0xd6, 0xcb, 0x77, 0xaa, 0x6b, 0xa6, 0x32, 0xf2, 0x59, 0xd9, 0x95,
		0x5a, 0x29, 0x0d, 0xf2, 0xcc, 0x25, 0x5d, 0x97, 0x06, 0x79, 0x36, 0x70, 0x1d, 0x3d, 0x43, 0xfc,
		0xce, 0x2c, 0x3a, 0x06, 0x78, 0x0b, 0x03, 0x1c, 0x03, 0x1c, 0x03, 0xbc, 0x9c, 0x06, 0xb8, 0x74,
		0x71, 0xe3, 0x5b, 0x7f, 0x82, 0x0b, 0xff, 0x0c, 0xba, 0x61, 0x1e, 0x06, 0xa9, 0x64, 0xd9, 0xf4,
		0xd5, 0x1e, 0x85, 0xbb, 0xf3, 0x29, 0x49, 0x8c, 0xae, 0xbf, 0x4f, 0xbd, 0x65, 0xb6, 0x45, 0xab,
		0x6c, 0xc3, 0x16, 0xd9, 0x56, 0xad, 0xb1, 0xcd, 0x5b, 0x62, 0x9b, 0xb7, 0xc2, 0xb6, 0x6d, 0x81,
		0x5d, 0xad, 0xf6, 0x69, 0xea, 0xad, 0xae, 0x6f, 0x7d, 0x15, 0xce, 0xb9, 0x5e, 0xdc, 0x0f, 0x6d,
		0xee, 0x79, 0x29, 0xb6, 0xb6, 0x6e, 0xbc, 0x72, 0xc9, 0xe5, 0xb8, 0xbd, 0x0a, 0x17, 0xbd, 0xca,
		0xa3, 0x5e, 0x96, 0xfb, 0x62, 0x1a, 0xcf, 0xf6, 0xda, 0xdc, 0xf3, 0x2a, 0x24, 0x22, 0x3b, 0x70,
		0xcf, 0xab, 0xcd, 0x0d, 0xaf, 0xb2, 0x8d, 0x5e, 0x95, 0x82, 0x9d, 0x0a, 0x47, 0xb0, 0x61, 0xc3,
		0x29, 0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24,
		0x60, 0x12, 0x88, 0x08, 0x4c, 0xa2, 0x5e, 0x4c, 0x22, 0x8b, 0xfe, 0x9f, 0x01, 0x93, 0x18, 0xcf,
		0x02, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01,
		0x93, 0x40, 0x44, 0x60, 0x12, 0x7e, 0x98, 0x44, 0xa9, 0x93, 0xb2, 0x9e, 0x27, 0x49, 0x3f, 0xbf,
		0x29, 0x55, 0xa7, 0x92, 0x9b, 0x95, 0x75, 0x3e, 0xb9, 0xab, 0x70, 0x10, 0x8e, 0xb5, 0x61, 0xa3,
		0xd9, 0x1f, 0xb8, 0xa4, 0x33, 0xb6, 0xf2, 0x83, 0xc4, 0xe5, 0x7f, 0xf5, 0xd3, 0x3f, 0x83, 0x28,
		0xc9, 0xf2, 0x30, 0xe9, 0xb8, 0xe6, 0xfd, 0x37, 0xb2, 0x85, 0x77, 0x9a, 0x57, 0x83, 0x38, 0x6b,
		0x66, 0xd1, 0x65, 0x12, 0xc6, 0x51, 0x72, 0x19, 0x0c, 0xd2, 0x7e, 0xde, 0xef, 0xf4, 0xe3, 0xac,
		0x39, 0x32, 0xd8, 0x82, 0xdc, 0x35, 0x33, 0x97, 0x65, 0x51, 0x3f, 0xc9, 0xa6, 0x2f, 0x9a, 0x59,
		0x1e, 0x8e, 0xdf, 0x56, 0x4b, 0x3d, 0xbd, 0x79, 0xca, 0x3c, 0x1d, 0x76, 0xf2, 0x64, 0x62, 0xc7,
		0xbc, 0x99, 0x3d, 0xe4, 0xef, 0x37, 0x0f, 0xf0, 0x72, 0xf2, 0xfd, 0xcf, 0xef, 0xfd, 0x9e, 0xdd,
		0x7f, 0xe3, 0xfc, 0xf5, 0x20, 0xce, 0xce, 0xdf, 0x4f, 0x1f, 0xf0, 0xed, 0xf4, 0xf9, 0xce, 0xdf,
		0x65, 0x9f, 0x07, 0x1f, 0xdc, 0xf9, 0xfb, 0xc9, 0xe3, 0x4d, 0x5f, 0x9c, 0xbf, 0x1f, 0x3d, 0xde,
		0xf9, 0xfb, 0xf1, 0xe3, 0x7d, 0x18, 0x3f, 0xdd, 0x4e, 0xa4, 0x2b, 0x8f, 0x1f, 0x3e, 0x98, 0xac,
		0xb7, 0x5a, 0xba, 0xf2, 0xdc, 0x2c, 0xdc, 0x17, 0x24, 0x5d, 0xd9, 0x3f, 0x3f, 0x26, 0x5d, 0xd9,
		0x50, 0x33, 0xea, 0xdf, 0x17, 0xcc, 0xf2, 0x34, 0x4a, 0x2e, 0x35, 0xaf, 0x0a, 0x3e, 0xdd, 0x05,
		0x6d, 0x30, 0x3e, 0xdc, 0xb3, 0xbe, 0xdf, 0x7a, 0xfa, 0xe0, 0xee, 0x3c, 0x68, 0x04, 0x34, 0x02,
		0x1a, 0x01, 0x8d, 0x20, 0x2a, 0xf1, 0xd1, 0x40, 0x09, 0x5f, 0xf6, 0x68, 0x79, 0xf2, 0xa3, 0x95,
		0xff, 0xdc, 0x56, 0x5c, 0xfb, 0x45, 0xcd, 0xac, 0xd9, 0xa2, 0xdf, 0xaa, 0x3b, 0xff, 0x4d, 0x73,
		0xfe, 0xb3, 0x6f, 0x1f, 0x5b, 0xc1, 0xe9, 0xd9, 0xcd, 0xcb, 0xd6, 0xf8, 0x3f, 0x37, 0xaf, 0x0f,
		0x3e, 0xee, 0x07, 0xed, 0xe9, 0xeb, 0xa3, 0x8f, 0xfb, 0xc1, 0xd1, 0xd9, 0xa3, 0x3f, 0xfe, 0x78,
		0xf2, 0xe8, 0xef, 0xc3, 0xeb, 0xcd, 0x3f, 0xa8, 0xd8, 0x8d, 0x5e, 0x73, 0x2b, 0xde, 0xbc, 0x7f,
		0xf9, 0xdf, 0x66, 0xfb, 0xf1, 0x6f, 0xcb, 0x0d, 0xf9, 0x47, 0x83, 0x86, 0x12, 0x76, 0xe0, 0x74,
		0x0c, 0x38, 0x6d, 0x05, 0x4e, 0x61, 0xd0, 0x7b, 0x1e, 0xfc, 0x7a, 0xf6, 0x77, 0xeb, 0x71, 0xfb,
		0xfa, 0xd9, 0xa3, 0xbf, 0x4f, 0xae, 0xef, 0xbf, 0xf9, 0x6d, 0xd9, 0x9f, 0xb5, 0x1e, 0x9f, 0x5c,
		0x3f, 0x5b, 0xf1, 0x2f, 0xc7, 0xd7, 0xcf, 0xd6, 0x1c, 0xe3, 0xe8, 0xfa, 0xe1, 0xc2, 0x9f, 0x8e,
		0xde, 0x3f, 0x58, 0xf5, 0x81, 0xf6, 0x8a, 0x0f, 0x1c, 0xae, 0xfa, 0xc0, 0xe1, 0x8a, 0x0f, 0xac,
		0xfc, 0x4a, 0x07, 0x2b, 0x3e, 0x70, 0x74, 0xfd, 0x6d, 0xe1, 0xef, 0x1f, 0x2e, 0xff, 0xd3, 0xe3,
		0xeb, 0x47, 0xdf, 0x56, 0xfd, 0xdb, 0xc9, 0xf5, 0xb7, 0x67, 0x8f, 0x80, 0xea, 0xf5, 0xa1, 0x1a,
		0xf1, 0xb4, 0x17, 0xcf, 0xea, 0x29, 0x2e, 0xaa, 0x0c, 0x6e, 0xe3, 0x17, 0xca, 0xc3, 0x7c, 0xa8,
		0xe9, 0x0f, 0xba, 0x19, 0x1f, 0x3f, 0x10, 0x7e, 0x20, 0xfc, 0x40, 0xf8, 0x81, 0x44, 0x25, 0x5e,
		0xb7, 0x83, 0x9c, 0x66, 0xe7, 0x38, 0xa5, 0x8e, 0x71, 0xe5, 0x54, 0x31, 0xf9, 0x30, 0x49, 0x5c,
		0xac, 0xda, 0x1f, 0xe2, 0x76, 0x0a, 0x14, 0x0d, 0x8a, 0x06, 0x45, 0x83, 0xa2, 0x11, 0x95, 0x78,
		0x5a, 0x44, 0x58, 0xfa, 0xf3, 0x68, 0x11, 0xb1, 0xf9, 0x3c, 0xb4, 0x88, 0x28, 0xed, 0xd6, 0xd3,
		0x22, 0x02, 0xe7, 0x8d, 0x96, 0x65, 0xad, 0xa1, 0xf9, 0x6e, 0x8d, 0xea, 0xd1, 0xe8, 0xd8, 0xd3,
		0xd8, 0xd3, 0xd8, 0xd3, 0xd8, 0xd3, 0xa2, 0x12, 0x4f, 0x0b, 0x88, 0x35, 0x17, 0xea, 0xd5, 0xfb,
		0xb7, 0xe7, 0xef, 0xde, 0xbc, 0xa2, 0xf7, 0xc3, 0x0f, 0x57, 0xea, 0xe5, 0xef, 0xbf, 0xbd, 0x7b,
		0xf1, 0xfe, 0x3d, 0xdd, 0x0b, 0x56, 0x2f, 0xd1, 0x87, 0x77, 0xcf, 0x7f, 0x7f, 0xff, 0xf2, 0x03,
		0x4b, 0xb4, 0x7a, 0x89, 0x5e, 0x68, 0x0b, 0x11, 0xed, 0x1c, 0x4a, 0x30, 0x92, 0x90, 0x9c, 0x6a,
		0xdd, 0x0a, 0x2c, 0xc7, 0x6d, 0xc0, 0x86, 0x68, 0x90, 0xd9, 0xe7, 0xc5, 0x3f, 0x99, 0xe3, 0x5c,
		0x5c, 0xf4, 0x8a, 0x8d, 0x50, 0x50, 0x68, 0x47, 0xa6, 0xfa, 0xb8, 0x93, 0x76, 0xbf, 0x13, 0xc6,
		0x41, 0x94, 0x74, 0x5d, 0x51, 0x5b, 0xbd, 0xf1, 0x2a, 0xca, 0xf2, 0xe7, 0x79, 0x2e, 0xd3, 0xae,
		0xa0, 0xf1, 0x3a, 0x4a, 0x5e, 0xc4, 0x6e, 0x64, 0x7a, 0x67, 0x32, 0x3c, 0xae, 0xf1, 0x3a, 0xfc,
		0x32, 0x37, 0xa2, 0x4e, 0x33, 0xfc, 0xc6, 0x9b, 0xb4, 0xeb, 0x52, 0xd7, 0xfd, 0x69, 0xb4, 0xb8,
		0xc9, 0x30, 0x8e, 0xbd, 0xee, 0xb1, 0x30, 0x20, 0xf9, 0x06, 0x22, 0x01, 0x08, 0xf2, 0x06, 0x3d,
		0xc5, 0x40, 0x67, 0x7b, 0xa8, 0xd8, 0xee, 0x93, 0x5b, 0x0a, 0x9e, 0x94, 0xc0, 0xf9, 0x12, 0xb4,
		0x02, 0x02, 0x66, 0x2e, 0x58, 0xdb, 0x09, 0xd4, 0xe6, 0xe2, 0xb0, 0xd9, 0x27, 0x36, 0x14, 0x9c,
		0xa2, 0x02, 0x63, 0x2c, 0x28, 0x5b, 0xc8, 0x87, 0x95, 0x5c, 0x6c, 0x26, 0x0e, 0xeb, 0x6f, 0xea,
		0x06, 0x1b, 0xda, 0xc8, 0xdc, 0xe5, 0x48, 0xbb, 0x06, 0x69, 0x7f, 0x98, 0x47, 0xc9, 0xe5, 0xc6,
		0x3b, 0x3a, 0x57, 0x44, 0xe0, 0xee, 0x40, 0x1b, 0x0a, 0xd5, 0x76, 0x6d, 0xcd, 0xb6, 0x76, 0x1a,
		0x17, 0x71, 0x0a, 0xcf, 0x3b, 0x7d, 0xb3, 0x74, 0x1b, 0xf9, 0x2a, 0xe8, 0xd2, 0x15, 0x73, 0xd9,
		0x8a, 0xb9, 0x64, 0xef, 0xbb, 0x5c, 0xb3, 0xb4, 0x51, 0x32, 0xd0, 0xda, 0xb6, 0x25, 0x57, 0x23,
		0xbc, 0xbc, 0x4c, 0xdd, 0x65, 0x98, 0xbb, 0x20, 0x8b, 0xba, 0x41, 0xa7, 0x3f, 0x4c, 0x72, 0x97,
		0x6e, 0x9f, 0x6c, 0x3b, 0x13, 0x9e, 0x15, 0xe3, 0x6e, 0xb9, 0xfe, 0xc5, 0xba, 0x02, 0x16, 0x8e,
		0xbd, 0x48, 0xc4, 0x58, 0x0a, 0x1f, 0x2b, 0xa9, 0xe3, 0x25, 0x7e, 0xcc, 0xc4, 0x8f, 0x9b, 0xe4,
		0xb1, 0xf3, 0x63, 0x74, 0x16, 0xed, 0x90, 0xb7, 0xfc, 0xf8, 0x14, 0xdf, 0xf2, 0xef, 0x9e, 0xce,
		0xa2, 0xdb, 0x2f, 0xd3, 0xba, 0xf3, 0xf6, 0xb0, 0x1e, 0x14, 0x1c, 0x48, 0x30, 0x30, 0x2a, 0x76,
		0x78, 0xa5, 0x0f, 0xb1, 0xda, 0x61, 0x56, 0x3b, 0xd4, 0x1a, 0x87, 0xbb, 0x1c, 0xee, 0x2b, 0xa9,
		0xb6, 0x98, 0x8d, 0x91, 0xcd, 0x1f, 0xc4, 0xe1, 0x85, 0x8b, 0xe5, 0xe4, 0x63, 0x2a, 0xc0, 0x73,
		0x63, 0x0b, 0xed, 0xa3, 0x6c, 0xbe, 0x84, 0x78, 0x9e, 0x84, 0x46, 0x7e, 0x84, 0x38, 0x1c, 0x68,
		0xc1, 0x82, 0x3a, 0x3c, 0xa8, 0xc3, 0x84, 0x26, 0x5c, 0xc8, 0xf9, 0xcd, 0xf7, 0x04, 0x43, 0x36,
		0xe2, 0xb9, 0x0d, 0x33, 0x69, 0x8d, 0x5d, 0xd8, 0x93, 0xcd, 0x67, 0x98, 0xe9, 0xfc, 0x13, 0xc1,
		0x31, 0xdf, 0x4e, 0x5c, 0x27, 0x4f, 0x9e, 0x4c, 0x8a, 0x3e, 0xce, 0x61, 0x56, 0x59, 0xe2, 0x24,
		0x22, 0x6e, 0x5f, 0xc9, 0x7e, 0x64, 0x77, 0x6e, 0x33, 0x3a, 0x61, 0x6c, 0x6f, 0x49, 0x63, 0xfb,
		0x01, 0xd8, 0x0e, 0xb6, 0xef, 0x20, 0xb6, 0x4b, 0x77, 0x4e, 0x6f, 0x44, 0x49, 0xd0, 0xef, 0xe4,
		0x2e, 0x57, 0xbc, 0x1e, 0x7d, 0x3b, 0x05, 0x89, 0xb6, 0x16, 0x89, 0xb6, 0xa2, 0xa0, 0xa3, 0x0d,
		0x3e, 0x66, 0x20, 0x64, 0x06, 0x46, 0x16, 0xa0, 0x24, 0x0b, 0x4e, 0xc2, 0x20, 0xa5, 0x67, 0x88,
		0x2e, 0x48, 0xfb, 0xc4, 0xf1, 0x74, 0xdc, 0x56, 0x4c, 0xb1, 0x7d, 0xca, 0xbd, 0xb5, 0xdb, 0x2f,
		0xce, 0xbd, 0xb5, 0xcd, 0xe7, 0xe1, 0xde, 0x5a, 0x69, 0xb7, 0x5e, 0x27, 0x61, 0xaa, 0x34, 0xd2,
		0xc0, 0x35, 0xb6, 0xb2, 0x9c, 0xa6, 0x91, 0x11, 0x3c, 0xf8, 0x53, 0xd9, 0xca, 0x1e, 0x4f, 0x80,
		0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d, 0x8d,
		0x8d, 0x8d, 0x8d, 0xbd, 0x23, 0x36, 0xb6, 0x42, 0xda, 0xc3, 0x82, 0x36, 0x14, 0x4f, 0x7f, 0xc0,
		0xd2, 0xc6, 0xd2, 0xc6, 0xd2, 0xc6, 0xd2, 0xd6, 0xc4, 0x96, 0x3d, 0x7a, 0xbe, 0x7c, 0x7f, 0xe5,
		0x87, 0x51, 0x62, 0xd3, 0x6a, 0xfc, 0x44, 0x71, 0x0a, 0x5d, 0xc2, 0xa3, 0xbf, 0x1b, 0xa6, 0x04,
		0xc8, 0xd8, 0x1a, 0x5e, 0xb4, 0x8a, 0x8f, 0x69, 0x35, 0x5e, 0x76, 0xa6, 0xe4, 0x5d, 0x46, 0xf6,
		0xdb, 0x4f, 0x8f, 0x4e, 0x8e, 0x68, 0x38, 0x5e, 0xb6, 0xd1, 0xe9, 0x4a, 0x74, 0x57, 0x7d, 0xea,
		0x16, 0x29, 0x5f, 0xb0, 0x60, 0x14, 0x5b, 0xf0, 0x2b, 0x15, 0x2d, 0x87, 0xd7, 0x17, 0xd9, 0x93,
		0xfe, 0x30, 0x57, 0x4f, 0x52, 0x9b, 0x9b, 0x03, 0x5e, 0x0f, 0xaf, 0x87, 0xd7, 0xc3, 0xeb, 0xc5,
		0xa4, 0x9d, 0x08, 0x9a, 0xb1, 0x5d, 0x42, 0x04, 0xad, 0xd4, 0xe6, 0x3f, 0x11, 0xb4, 0x0d, 0x79,
		0x20, 0x11, 0x34, 0x2c, 0x6d, 0x33, 0x4b, 0x5b, 0x37, 0x4d, 0x6d, 0x36, 0x03, 0x56, 0x36, 0x56,
		0x36, 0x56, 0x36, 0x56, 0x36, 0x56, 0x36, 0x56, 0x36, 0x56, 0x36, 0x56, 0x36, 0x56, 0x36, 0x56,
		0x76, 0x99, 0xad, 0x6c, 0xaa, 0xb2, 0xcb, 0x95, 0x1e, 0xbd, 0x57, 0x0b, 0xb3, 0xb9, 0xbc, 0xd6,
		0xdf, 0xf2, 0xb7, 0x2b, 0x58, 0xb9, 0xfd, 0xfd, 0xcd, 0xe3, 0xbe, 0xbb, 0x79, 0xda, 0xf3, 0xe7,
		0xd3, 0xc7, 0x7a, 0x1f, 0x75, 0x7f, 0x9e, 0x3c, 0xeb, 0xb2, 0x37, 0xa9, 0xec, 0x7e, 0x87, 0x11,
		0x88, 0x66, 0x48, 0x51, 0xd8, 0x9d, 0xc2, 0xee, 0xfe, 0xb1, 0xac, 0x12, 0xc5, 0xdf, 0xb7, 0x44,
		0x2f, 0x8a, 0xc3, 0x57, 0x56, 0x58, 0x4b, 0x5d, 0x32, 0x7e, 0x0d, 0x71, 0x34, 0x2b, 0x23, 0xbf,
		0x45, 0x69, 0xeb, 0x68, 0xf4, 0x0d, 0x7b, 0x61, 0xc7, 0x09, 0x94, 0x48, 0x9e, 0x1b, 0x8b, 0xb2,
		0xc8, 0x94, 0x45, 0xf6, 0xe2, 0x8d, 0xac, 0x58, 0x59, 0xe4, 0xd9, 0x91, 0x91, 0x2b, 0x85, 0x7c,
		0x3b, 0x64, 0xc9, 0xca, 0x1f, 0xef, 0x53, 0xfe, 0xd8, 0xdf, 0xa1, 0x55, 0x3b, 0xbc, 0x1a, 0x87,
		0xb8, 0x1c, 0x1c, 0x4f, 0xac, 0xfc, 0x71, 0x67, 0x7a, 0x02, 0x84, 0x2b, 0x63, 0x4e, 0xc6, 0x2d,
		0x79, 0x69, 0x4c, 0xca, 0x1e, 0x4b, 0xfa, 0xa0, 0x29, 0x8d, 0x59, 0x15, 0x9f, 0xa8, 0x42, 0x69,
		0xcc, 0x89, 0x62, 0x0f, 0xa2, 0xae, 0x66, 0xdd, 0x9e, 0xb9, 0x59, 0x48, 0x8a, 0x20, 0x29, 0xc2,
		0x17, 0x14, 0x99, 0x41, 0x92, 0x05, 0x34, 0xc9, 0x42, 0x94, 0x30, 0x54, 0xcd, 0x16, 0x40, 0x3f,
		0x29, 0x22, 0xcb, 0xd3, 0xcd, 0x9b, 0x8d, 0x6d, 0x64, 0xbe, 0x3c, 0x25, 0x60, 0x67, 0xe7, 0x27,
		0x2c, 0x8b, 0xdf, 0xf0, 0xd6, 0xf3, 0x74, 0xfb, 0xb2, 0x29, 0x6a, 0x1e, 0x7b, 0x71, 0x26, 0xbe,
		0x9c, 0x3d, 0xd6, 0xed, 0xcb, 0xf3, 0x89, 0xb6, 0xab, 0x51, 0xe3, 0x00, 0x15, 0xc3, 0x46, 0xd3,
		0xa0, 0xa1, 0x45, 0x0c, 0x5c, 0x09, 0xae, 0x44, 0x8b, 0x18, 0x95, 0x16, 0x31, 0x37, 0x2a, 0xa5,
		0x79, 0x07, 0xb6, 0x6a, 0x09, 0xf6, 0xa3, 0x6d, 0x51, 0x44, 0x7b, 0xb9, 0x5d, 0xdf, 0x75, 0xd7,
		0x58, 0xd4, 0x03, 0xee, 0x3d, 0xc0, 0x7d, 0xd4, 0xc3, 0x35, 0xb6, 0xe6, 0x80, 0xc2, 0x1e, 0xf6,
		0x85, 0x43, 0x20, 0x4e, 0x25, 0x14, 0x60, 0xa5, 0x36, 0xee, 0x30, 0x51, 0xb8, 0xc1, 0x1d, 0x56,
		0x46, 0x38, 0xaa, 0x86, 0x3b, 0x4c, 0x1a, 0xa6, 0x16, 0x6d, 0x20, 0x3d, 0x71, 0x94, 0xce, 0x06,
		0x30, 0xa2, 0xc2, 0x66, 0x60, 0x66, 0x01, 0x6a, 0x66, 0xe0, 0x66, 0x05, 0x72, 0xe6, 0x60, 0x67,
		0x0e, 0x7a, 0x96, 0xe0, 0xa7, 0x03, 0x82, 0x4a, 0x60, 0xa8, 0x47, 0xd5, 0x0d, 0xa9, 0xbb, 0x05,
		0x95, 0x5f, 0x49, 0xed, 0x9b, 0x63, 0x31, 0x7a, 0x36, 0xe7, 0xaa, 0xbe, 0xf7, 0xc6, 0xe4, 0xf7,
		0xb1, 0x7b, 0xb9, 0x22, 0xb7, 0xa3, 0x14, 0x84, 0xac, 0x91, 0x0d, 0x2f, 0x0c, 0xf5, 0xe3, 0x9d,
		0xd9, 0x50, 0x91, 0xa8, 0x48, 0x54, 0x24, 0x2a, 0x12, 0x15, 0x59, 0x52, 0x15, 0xf9, 0xf1, 0x56,
		0x45, 0xfe, 0x47, 0x67, 0x98, 0xa6, 0x2e, 0xc9, 0x1f, 0x3e, 0x6a, 0x3e, 0x79, 0x72, 0xeb, 0x2d,
		0x3f, 0x9b, 0x7c, 0x64, 0x1e, 0xd7, 0xb3, 0x25, 0xef, 0xcd, 0x46, 0xee, 0xba, 0x2f, 0x95, 0xd1,
		0xb6, 0xa5, 0x66, 0xcb, 0x2f, 0xbe, 0x8c, 0xaf, 0x06, 0xca, 0x97, 0x8d, 0xd0, 0x77, 0xd8, 0xf4,
		0x3b, 0x81, 0xfb, 0x92, 0x3f, 0xcb, 0x5d, 0xec, 0xae, 0x5c, 0x9e, 0x7e, 0x0d, 0xfa, 0x49, 0xd0,
		0xf9, 0x34, 0xae, 0x83, 0x61, 0xe2, 0xc4, 0xe9, 0x85, 0x71, 0x66, 0xe1, 0xc5, 0x29, 0xbb, 0x03,
		0xe7, 0x4c, 0xda, 0xa1, 0xae, 0x93, 0xe5, 0x72, 0x6b, 0xaa, 0x96, 0x28, 0xdb, 0xe5, 0x4e, 0xe0,
		0xab, 0xa9, 0xe2, 0xb0, 0xde, 0x2b, 0x4d, 0x0e, 0xcc, 0xec, 0xd5, 0x3b, 0xd7, 0x13, 0x4d, 0x88,
		0x91, 0x97, 0xeb, 0x6b, 0xd1, 0xfc, 0xa3, 0x30, 0x77, 0x7a, 0x51, 0x0e, 0xe9, 0x4a, 0x06, 0x7b,
		0x16, 0x41, 0x8e, 0x03, 0x82, 0x1c, 0x66, 0xe4, 0x86, 0x20, 0x47, 0xfd, 0xcc, 0x36, 0x82, 0x1c,
		0x78, 0x70, 0xf0, 0xe0, 0xe0, 0xc1, 0xc1, 0x83, 0x83, 0x07, 0xc7, 0xc0, 0x83, 0x43, 0x90, 0x63,
		0x8f, 0x20, 0x07, 0x2a, 0x12, 0x15, 0x89, 0x8a, 0x44, 0x45, 0xa2, 0x22, 0x09, 0x72, 0x54, 0x8b,
		0x2d, 0xef, 0xae, 0x47, 0x59, 0xc3, 0x39, 0xb8, 0x57, 0x4e, 0x87, 0xb2, 0x60, 0x9d, 0x53, 0x79,
		0xa9, 0xe6, 0x1e, 0xb1, 0xd7, 0x73, 0x50, 0xbb, 0xeb, 0xc4, 0xf3, 0x92, 0x5f, 0xa7, 0x7b, 0x66,
		0x77, 0x0a, 0x48, 0x8a, 0x5f, 0x33, 0x13, 0x2a, 0x4f, 0xb9, 0xd4, 0x08, 0xe1, 0x52, 0x71, 0x79,
		0x19, 0x10, 0x97, 0x8a, 0xab, 0xa3, 0x9b, 0xc4, 0x6f, 0x99, 0xcd, 0x57, 0x4a, 0xd6, 0x0b, 0xc2,
		0x8a, 0x96, 0x63, 0x56, 0x04, 0x98, 0x45, 0xa0, 0x39, 0xa0, 0xfc, 0x92, 0x99, 0x0b, 0x86, 0xf2,
		0x4b, 0xf5, 0x23, 0x97, 0x6a, 0xa1, 0xd8, 0x5e, 0x3f, 0xfd, 0x2b, 0x4c, 0xbb, 0x23, 0xdb, 0xb7,
		0x13, 0x87, 0x59, 0xe6, 0x32, 0x7d, 0x9f, 0xf3, 0x92, 0x39, 0x75, 0x3d, 0xcf, 0x2d, 0x3c, 0xcf,
		0xfe, 0xe0, 0xce, 0x0a, 0xf6, 0xcc, 0xe1, 0xcf, 0x1c, 0x06, 0x2d, 0xe1, 0x50, 0xcf, 0x8b, 0xb7,
		0xa7, 0xe8, 0x79, 0xd6, 0x82, 0xc9, 0x95, 0x70, 0xa9, 0x2f, 0xcd, 0xab, 0x40, 0x53, 0x5b, 0xa8,
		0x75, 0xa1, 0x53, 0xdd, 0x42, 0xf4, 0x01, 0xa5, 0xe6, 0x90, 0x6a, 0x0d, 0xad, 0xde, 0x20, 0xd6,
		0x1b, 0xd4, 0xfa, 0x80, 0x5c, 0x5d, 0xe8, 0x55, 0x86, 0x60, 0x33, 0x28, 0x9e, 0x4d, 0xe4, 0xbe,
		0x0c, 0xec, 0x04, 0x7f, 0x7a, 0xb2, 0x47, 0x93, 0x1a, 0x49, 0x9e, 0x4d, 0x6f, 0x49, 0x33, 0x9b,
		0xd6, 0x27, 0x30, 0x7b, 0x03, 0x68, 0x5f, 0x40, 0xed, 0x1d, 0xb0, 0xbd, 0x03, 0xb7, 0x4f, 0x00,
		0xb7, 0x01, 0x72, 0x23, 0x40, 0x9f, 0x2d, 0xa4, 0x7a, 0x76, 0xc7, 0xca, 0xd3, 0xaa, 0x9f, 0xed,
		0xb1, 0xd2, 0x0a, 0x3e, 0x31, 0x9c, 0x73, 0xae, 0xe0, 0xe3, 0x38, 0xb2, 0xde, 0x1c, 0x29, 0x9b,
		0x07, 0xf5, 0x10, 0x54, 0x03, 0x21, 0x55, 0xba, 0x0a, 0xf5, 0x43, 0xe9, 0xd4, 0xca, 0x82, 0xf0,
		0xc8, 0xce, 0xcc, 0x59, 0x1a, 0x46, 0x01, 0x46, 0x01, 0x46, 0x41, 0x05, 0x8d, 0x02, 0x2b, 0xb6,
		0xe7, 0x85, 0xf5, 0x79, 0x64, 0x7f, 0x9e, 0x58, 0xa0, 0x37, 0x36, 0xe8, 0x53, 0x01, 0x78, 0x57,
		0x04, 0xbe, 0x15, 0x42, 0x69, 0x14, 0x43, 0x69, 0x14, 0x44, 0x19, 0x14, 0x85, 0xad, 0xc2, 0x30,
		0x56, 0x1c, 0xfe, 0x58, 0xe5, 0xc2, 0x69, 0x1f, 0x46, 0x49, 0xfe, 0xd4, 0xc7, 0x69, 0x9f, 0x40,
		0xfb, 0x91, 0x87, 0xa9, 0xdf, 0x8d, 0x0b, 0xd9, 0x68, 0x54, 0xe6, 0x59, 0xe7, 0xc7, 0x0f, 0xba,
		0x8d, 0x1f, 0xfc, 0x75, 0x94, 0x78, 0x83, 0x57, 0xcf, 0x3a, 0x7d, 0xe1, 0x6b, 0xfc, 0x57, 0x18,
		0x0f, 0x5d, 0x09, 0xbe, 0xc7, 0xaf, 0x69, 0xd8, 0xc9, 0xa3, 0x7e, 0xf2, 0x4b, 0x74, 0x19, 0x8d,
		0xeb, 0x45, 0xed, 0x7b, 0xfb, 0x3e, 0xd7, 0x8f, 0x3d, 0x8a, 0x66, 0xf8, 0x05, 0xd1, 0xbc, 0x27,
		0x9a, 0x27, 0x88, 0xa6, 0x1f, 0x33, 0xc0, 0xdf, 0xac, 0x67, 0x0f, 0xea, 0xf9, 0x7c, 0x86, 0xd0,
		0xd2, 0x88, 0x92, 0xa0, 0xdf, 0xc9, 0x5d, 0x9e, 0xf9, 0xa3, 0xca, 0xb7, 0x5f, 0x01, 0xc2, 0x0c,
		0x61, 0x86, 0x30, 0x43, 0x98, 0x21, 0xcc, 0x35, 0x21, 0xcc, 0x93, 0xab, 0x28, 0xc7, 0x6d, 0x8f,
		0xa4, 0xf9, 0x29, 0xa4, 0x19, 0xd2, 0x0c, 0x69, 0x86, 0x34, 0x43, 0x9a, 0x17, 0x44, 0xb3, 0xf5,
		0xb4, 0xdd, 0x3e, 0x3e, 0x69, 0xb7, 0xf7, 0x4f, 0x0e, 0x4f, 0xf6, 0x4f, 0x8f, 0x8e, 0x5a, 0xc7,
		0xad, 0x23, 0xa4, 0x15, 0x1e, 0x0d, 0x8f, 0xde, 0x82, 0x47, 0x0f, 0xfe, 0xf4, 0xcc, 0xa2, 0xc7,
		0x5f, 0x00, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0, 0x70, 0x68, 0x38, 0x34, 0x1c,
		0x1a, 0x0e, 0x0d, 0x87, 0x86, 0x43, 0xc3, 0xa1, 0xe1, 0xd0, 0x70, 0xe8, 0x92, 0x73, 0xe8, 0xfe,
		0x30, 0xf7, 0x1e, 0x8c, 0x9e, 0xfb, 0x0e, 0x30, 0x69, 0x98, 0x34, 0x4c, 0x1a, 0x26, 0x0d, 0x93,
		0x86, 0x49, 0xc3, 0xa4, 0x61, 0xd2, 0x30, 0x69, 0x98, 0x34, 0x4c, 0x1a, 0x26, 0x0d, 0x93, 0x86,
		0x49, 0x57, 0x80, 0x49, 0xfb, 0x0d, 0x47, 0xcf, 0xbe, 0x01, 0x2c, 0x1a, 0x16, 0x0d, 0x8b, 0x86,
		0x45, 0xc3, 0xa2, 0x61, 0xd1, 0xb0, 0x68, 0x58, 0x34, 0x2c, 0x1a, 0x16, 0x0d, 0x8b, 0x86, 0x45,
		0xc3, 0xa2, 0x61, 0xd1, 0xa5, 0x9d, 0xc9, 0xaa, 0x26, 0x9a, 0x72, 0x43, 0xd0, 0x95, 0xf3, 0x96,
		0xa9, 0x41, 0xe2, 0x7c, 0x33, 0xbc, 0xf9, 0x5f, 0x9a, 0x8b, 0x3d, 0x60, 0x16, 0xde, 0x6a, 0x5a,
		0x56, 0xd4, 0xdc, 0x2b, 0x4d, 0xd7, 0xc5, 0xf7, 0x51, 0xf7, 0xe7, 0xc9, 0x8a, 0xcd, 0xbd, 0x3e,
		0xff, 0x75, 0xb6, 0x3a, 0x3f, 0xdf, 0xac, 0xd7, 0xfd, 0x77, 0x34, 0x7a, 0x93, 0xfa, 0x3b, 0xa8,
		0xd5, 0x2e, 0x7e, 0xff, 0x4f, 0xf7, 0xd5, 0xa6, 0x4e, 0x60, 0xe3, 0x55, 0x94, 0xe5, 0xcf, 0xf3,
		0xdc, 0xa8, 0xd6, 0xfe, 0xeb, 0x28, 0x79, 0x11, 0xbb, 0x91, 0x08, 0x67, 0x36, 0x46, 0xd1, 0xc8,
		0x08, 0x9c, 0x9b, 0xd1, 0x8f, 0xf9, 0xd3, 0x78, 0x93, 0x76, 0x5d, 0xea, 0xba, 0x3f, 0x8d, 0x36,
		0x35, 0x19, 0xc6, 0x71, 0xa5, 0x65, 0xd3, 0x58, 0x2d, 0xd5, 0x46, 0x1d, 0x35, 0x4c, 0x4a, 0x57,
		0x57, 0x58, 0x01, 0xe9, 0xaa, 0x9e, 0x6b, 0x5a, 0x5c, 0x59, 0x1e, 0xdf, 0xaa, 0x1e, 0x5b, 0xcd,
		0x06, 0x76, 0x95, 0x3a, 0x9d, 0x3a, 0xa7, 0x51, 0xfe, 0xac, 0x28, 0x9c, 0x93, 0xc6, 0x48, 0xda,
		0x82, 0x38, 0xbc, 0x70, 0xb1, 0x7e, 0x33, 0xcb, 0xb9, 0xb9, 0x74, 0x9b, 0x58, 0xee, 0xd3, 0xc4,
		0xf2, 0xc7, 0xbb, 0x41, 0x13, 0xcb, 0x6d, 0x27, 0xa4, 0x89, 0x65, 0x59, 0x34, 0xbc, 0x7a, 0x14,
		0xd0, 0xb0, 0xa1, 0x8e, 0x45, 0x03, 0x9d, 0xc5, 0x86, 0x39, 0x73, 0x98, 0xbc, 0xc3, 0x5a, 0x50,
		0xb7, 0x0f, 0x8e, 0x49, 0xdf, 0x1b, 0xb3, 0x06, 0xce, 0x07, 0xe8, 0x3e, 0x74, 0x1f, 0xba, 0xcf,
		0xbb, 0xee, 0x53, 0x6f, 0xe0, 0x6c, 0x57, 0x12, 0xd7, 0xbc, 0x04, 0xae, 0x51, 0xac, 0xda, 0x2c,
		0x1d, 0x92, 0x96, 0xcd, 0x55, 0x06, 0x55, 0x6f, 0xe0, 0xea, 0x03, 0x64, 0x75, 0xc1, 0x56, 0x19,
		0x74, 0xed, 0x88, 0xc7, 0xc2, 0x69, 0xb3, 0x4c, 0x37, 0x34, 0x4c, 0x2f, 0x34, 0x4e, 0x27, 0x34,
		0xcc, 0x2d, 0xf0, 0x91, 0x2e, 0xe8, 0x2b, 0xed, 0xdf, 0x53, 0x3a, 0xa0, 0xcf, 0x84, 0x2a, 0xcb,
		0x6b, 0x2c, 0x3e, 0xd2, 0xfb, 0x7c, 0x8b, 0x92, 0xff, 0xf4, 0x3d, 0xaf, 0xd2, 0x55, 0x93, 0xdc,
		0x94, 0xb3, 0xaa, 0x06, 0x3a, 0x1f, 0xab, 0xf2, 0x2a, 0x93, 0x3b, 0x69, 0xc6, 0x25, 0x51, 0xe1,
		0x54, 0x70, 0x2a, 0x38, 0x15, 0x9c, 0x0a, 0x4e, 0x05, 0xa7, 0x82, 0x53, 0xc1, 0xa9, 0xe0, 0x54,
		0x70, 0x2a, 0x38, 0x15, 0x9c, 0xca, 0x84, 0x53, 0x19, 0xa4, 0xb1, 0x2d, 0x58, 0x0f, 0xea, 0xe9,
		0x6c, 0x30, 0x2b, 0x98, 0x15, 0xcc, 0x0a, 0x66, 0x55, 0x41, 0x66, 0x65, 0x86, 0x8d, 0xf3, 0xf8,
		0xd8, 0x3a, 0x35, 0x98, 0x6b, 0xb2, 0x96, 0xb5, 0xa3, 0x56, 0xd3, 0x9d, 0x1b, 0x46, 0x49, 0x7e,
		0x78, 0x60, 0x79, 0x95, 0x74, 0xb2, 0x7b, 0x86, 0x8d, 0xcb, 0x3d, 0xd5, 0x30, 0xf1, 0x50, 0xac,
		0xc6, 0x67, 0xcd, 0x12, 0xcf, 0x05, 0x21, 0x6e, 0x59, 0xcf, 0xb1, 0xa7, 0x2f, 0x50, 0x82, 0x72,
		0x0f, 0x1e, 0x8a, 0x92, 0x78, 0x2d, 0x46, 0x52, 0x1a, 0x99, 0xdb, 0x6f, 0x3f, 0x3d, 0x3a, 0x39,
		0xda, 0x61, 0xc1, 0xab, 0x69, 0xdd, 0x8d, 0xb3, 0x3a, 0xd5, 0xdd, 0xf0, 0x60, 0x5e, 0xb8, 0x64,
		0x78, 0xe5, 0xd2, 0x9b, 0x4b, 0x99, 0xf6, 0x36, 0x46, 0xab, 0x6d, 0x38, 0xe7, 0x8b, 0x64, 0x78,
		0x35, 0x02, 0x42, 0xfc, 0x4e, 0x7e, 0xbf, 0xbf, 0xa6, 0xdf, 0xc9, 0xb0, 0x55, 0x8b, 0x7d, 0x6b,
		0x16, 0xfc, 0x4e, 0x12, 0xbb, 0x85, 0xdf, 0x49, 0x78, 0x62, 0xfc, 0x4e, 0x15, 0x31, 0x33, 0x88,
		0xe8, 0x57, 0xd4, 0x61, 0x41, 0x44, 0x5f, 0x95, 0x1c, 0x12, 0xd1, 0xaf, 0x8d, 0xdf, 0x81, 0x88,
		0x3e, 0x11, 0x7d, 0x98, 0x95, 0x16, 0xb3, 0xb2, 0x4d, 0x93, 0x36, 0x6a, 0xd5, 0x01, 0xab, 0x82,
		0x55, 0xc1, 0xaa, 0x60, 0x55, 0xb0, 0x2a, 0x58, 0x15, 0xac, 0x0a, 0x56, 0x05, 0xab, 0x82, 0x55,
		0xc1, 0xaa, 0x60, 0x55, 0xca, 0x23, 0x53, 0x64, 0xd7, 0xa0, 0xc8, 0xae, 0x76, 0x1b, 0x86, 0x52,
		0xd7, 0xd5, 0x55, 0x6c, 0xaa, 0xa0, 0x50, 0x45, 0xf0, 0x41, 0x89, 0x0f, 0xd7, 0xb4, 0x29, 0x82,
		0x5a, 0x16, 0xad, 0x6e, 0x2f, 0x04, 0xfd, 0xde, 0x07, 0x5e, 0x7a, 0x1d, 0xe8, 0xf6, 0x36, 0x90,
		0x16, 0x21, 0x65, 0x5c, 0xae, 0x04, 0x1e, 0x37, 0x54, 0x4a, 0x85, 0x96, 0x16, 0x81, 0x65, 0xb1,
		0x57, 0x0e, 0x21, 0x65, 0x46, 0x12, 0x3a, 0x20, 0x5a, 0x07, 0xa3, 0xb4, 0x07, 0x42, 0xf0, 0x10,
		0x94, 0x4e, 0xf8, 0x65, 0x24, 0xbe, 0xb8, 0x7c, 0x0a, 0xc8, 0xa6, 0x70, 0x0d, 0x62, 0x95, 0x9a,
		0xc3, 0xc2, 0x35, 0x86, 0xc5, 0x6b, 0x0a, 0x6b, 0x84, 0x22, 0xd4, 0x42, 0x0e, 0x5a, 0xa1, 0x05,
		0xf5, 0x10, 0x82, 0x7a, 0xa8, 0x40, 0x33, 0x24, 0x50, 0x2e, 0x5d, 0x24, 0x5d, 0xc3, 0x57, 0xb1,
		0x66, 0xaf, 0x7a, 0x8d, 0x5e, 0x25, 0xa7, 0x9f, 0x5a, 0x1c, 0x54, 0x33, 0xee, 0xa9, 0x1e, 0xe7,
		0xd4, 0x8e, 0x6b, 0x9a, 0xc5, 0x31, 0xcd, 0xe2, 0x96, 0x16, 0x71, 0xca, 0x72, 0x3b, 0x25, 0xd4,
		0xe2, 0x8e, 0x26, 0x71, 0x46, 0xc5, 0xb8, 0xa2, 0x72, 0x1c, 0x51, 0xd1, 0xa9, 0x6a, 0x11, 0x27,
		0xb4, 0xca, 0x77, 0x31, 0x8a, 0x03, 0x5a, 0x46, 0x66, 0x34, 0xf3, 0xab, 0x2c, 0xe2, 0x7a, 0xd6,
		0x5b, 0x6f, 0x1f, 0xb7, 0x33, 0x95, 0x86, 0x8a, 0xb8, 0xd6, 0xcf, 0xca, 0xea, 0x86, 0x7a, 0x2c,
		0x6a, 0x67, 0xab, 0x24, 0x27, 0x2a, 0xd7, 0x6c, 0xc5, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6,
		0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0xc6, 0x2e, 0xb1, 0x8d, 0x3d,
		0x89, 0xf8, 0x05, 0x51, 0x57, 0xd3, 0xd0, 0x9e, 0x9b, 0x05, 0x6b, 0x1b, 0x6b, 0x1b, 0x6b, 0x1b,
		0x6b, 0x5b, 0x4c, 0xda, 0xb3, 0x3c, 0x8d, 0x92, 0x4b, 0x45, 0x53, 0xbb, 0xf5, 0x74, 0x07, 0x34,
		0x81, 0x62, 0x95, 0x1d, 0xfd, 0xaa, 0x3a, 0x68, 0x01, 0xb4, 0x00, 0x5a, 0x00, 0x9f, 0x0b, 0x3e,
		0x17, 0x7c, 0x2e, 0xf8, 0x5c, 0xf0, 0xb9, 0xe0, 0x73, 0xc1, 0xe7, 0x52, 0x6a, 0x4b, 0x5b, 0x37,
		0xb0, 0xa9, 0x54, 0x65, 0x05, 0x2b, 0x1b, 0x2b, 0x1b, 0x2b, 0x1b, 0x2b, 0x1b, 0x2b, 0x1b, 0x2b,
		0x1b, 0x2b, 0x1b, 0x2b, 0x1b, 0x2b, 0x1b, 0x2b, 0x9b, 0x4b, 0xac, 0x1b, 0x8f, 0x5b, 0xaa, 0x4b,
		0xac, 0xc2, 0xc5, 0x34, 0x4a, 0x72, 0x7b, 0x55, 0xae, 0x4a, 0x86, 0xc0, 0xbd, 0xd5, 0x07, 0x1e,
		0x85, 0x79, 0x5a, 0xe5, 0x42, 0x30, 0x02, 0x2f, 0x5b, 0xd7, 0x42, 0xbe, 0x8e, 0x85, 0x49, 0xdd,
		0x0a, 0xd9, 0x3a, 0x15, 0x45, 0x37, 0x59, 0x18, 0xa9, 0xca, 0x84, 0x50, 0x0d, 0x91, 0x5b, 0xdf,
		0xfe, 0x31, 0xa9, 0x18, 0x1a, 0x6d, 0x8f, 0x21, 0xdb, 0x7d, 0x72, 0x4b, 0x81, 0x94, 0x12, 0x44,
		0xff, 0x02, 0x58, 0x40, 0xec, 0x3c, 0x8a, 0xdb, 0x76, 0x42, 0xb6, 0xb9, 0x88, 0x6c, 0xf6, 0x89,
		0x0d, 0x85, 0xa9, 0xa8, 0x10, 0x79, 0x12, 0x9e, 0x2d, 0x24, 0xc6, 0x5a, 0x52, 0x36, 0x13, 0x8f,
		0xf5, 0x37, 0x79, 0xbd, 0xbf, 0x5c, 0x53, 0x0c, 0xb6, 0xdd, 0x7e, 0xa3, 0x6d, 0xdf, 0x60, 0x9b,
		0xd5, 0xb7, 0x77, 0xbd, 0xfd, 0xfc, 0xf1, 0xee, 0xac, 0xb1, 0x33, 0x8d, 0xdc, 0x05, 0x97, 0x71,
		0xff, 0x22, 0x8c, 0x83, 0x30, 0xcf, 0xd3, 0xe8, 0x62, 0x98, 0xbb, 0xf5, 0x03, 0x18, 0x33, 0xf7,
		0xe1, 0xd2, 0x51, 0xd6, 0x94, 0x8b, 0xcd, 0xea, 0xa2, 0x6c, 0x1c, 0x54, 0xd8, 0x26, 0x58, 0x30,
		0x1f, 0x04, 0x18, 0x09, 0xcc, 0x26, 0xc2, 0xb1, 0xa5, 0x7b, 0xbf, 0xb0, 0xdb, 0xbe, 0xb0, 0x3b,
		0xfe, 0xbe, 0x9b, 0x7d, 0xfc, 0xe0, 0x9e, 0xb0, 0x62, 0xd3, 0xda, 0x1e, 0x37, 0xd5, 0xfe, 0xc2,
		0xee, 0x55, 0x94, 0x04, 0x97, 0x69, 0x7f, 0x38, 0xd8, 0x3c, 0x08, 0x77, 0xb7, 0xfd, 0xf6, 0x9d,
		0xa1, 0x36, 0x5c, 0xc7, 0xed, 0x0a, 0xfd, 0x6c, 0x1d, 0x2d, 0x2b, 0x12, 0x0d, 0x2b, 0x20, 0xe8,
		0x45, 0x05, 0x5e, 0x4c, 0xf0, 0xc5, 0x0e, 0x80, 0xcc, 0x41, 0xb0, 0xb1, 0xa5, 0xb6, 0x2d, 0x7e,
		0xd3, 0x98, 0x13, 0xec, 0xed, 0xb7, 0x6c, 0x2a, 0x35, 0xf3, 0x83, 0x6d, 0xb9, 0xd6, 0xc5, 0xaa,
		0x62, 0x15, 0x0e, 0x31, 0x4b, 0x84, 0x92, 0x05, 0x0e, 0x91, 0xd4, 0x61, 0x12, 0x3f, 0x54, 0xe2,
		0x87, 0x4b, 0xf6, 0x90, 0xf9, 0x61, 0xc3, 0x45, 0x2b, 0x4f, 0xcd, 0x9f, 0x9b, 0x60, 0x62, 0x46,
		0x16, 0xdc, 0xef, 0x25, 0x27, 0xf2, 0x66, 0xe4, 0xa2, 0x6e, 0x46, 0x91, 0x30, 0x92, 0x58, 0x26,
		0x88, 0x64, 0xe6, 0x87, 0xe0, 0xb1, 0x95, 0x3e, 0xbe, 0x6a, 0xc7, 0x58, 0xed, 0x38, 0xeb, 0x1c,
		0xeb, 0x72, 0xb8, 0xda, 0xc5, 0xb2, 0x2f, 0x66, 0x12, 0x17, 0xbb, 0xb0, 0x97, 0xba, 0x9e, 0x84,
		0xc4, 0x4d, 0xf5, 0xe7, 0x89, 0xc0, 0x58, 0x6f, 0x27, 0x1c, 0xfb, 0xc9, 0x93, 0xe6, 0x0d, 0xa1,
		0x6d, 0x2e, 0xc0, 0x89, 0x2f, 0x6f, 0x67, 0x01, 0x95, 0xda, 0x99, 0x62, 0x8f, 0x10, 0xc4, 0x4e,
		0xc6, 0x93, 0x01, 0xd6, 0x16, 0xc0, 0x0a, 0xb0, 0xee, 0x2a, 0xb0, 0x4a, 0x55, 0xf0, 0x94, 0xb7,
		0xa7, 0xb4, 0xed, 0x2a, 0x61, 0xfb, 0x4a, 0x1c, 0x0e, 0x34, 0x60, 0x41, 0x11, 0x1e, 0xb4, 0x60,
		0x42, 0x1d, 0x2e, 0xd4, 0x61, 0x43, 0x17, 0x3e, 0x64, 0x60, 0x44, 0x08, 0x4e, 0xe4, 0xed, 0xb5,
		0x05, 0x89, 0x15, 0xbf, 0x91, 0x2c, 0x7c, 0x13, 0xb9, 0x1c, 0xc5, 0xd8, 0x2f, 0xa2, 0x3c, 0x18,
		0xf4, 0xb3, 0x48, 0x34, 0xc3, 0x6a, 0xb6, 0x07, 0x77, 0x46, 0x07, 0x85, 0x41, 0x61, 0x50, 0x78,
		0xc7, 0x50, 0x78, 0x18, 0x25, 0xf9, 0xe1, 0x81, 0x02, 0x0a, 0x9f, 0x08, 0x0e, 0xa9, 0x73, 0x31,
		0x41, 0xa7, 0xdf, 0x94, 0xe2, 0x5d, 0x24, 0xd5, 0x2c, 0x74, 0xed, 0x8b, 0x07, 0x16, 0x29, 0xe6,
		0xd7, 0x3a, 0x0d, 0xbe, 0x2a, 0xbf, 0xa5, 0xed, 0x83, 0xd3, 0xf6, 0xe9, 0xf1, 0xc9, 0xc1, 0xe9,
		0x51, 0x85, 0xf7, 0xb6, 0xa4, 0xe9, 0xf8, 0x67, 0x64, 0x50, 0x57, 0x23, 0xb9, 0x76, 0x59, 0x5a,
		0x4d, 0x73, 0x21, 0x3f, 0x61, 0xde, 0x4b, 0xdb, 0x14, 0xf1, 0x4e, 0xee, 0xc9, 0x67, 0x39, 0x7d,
		0x70, 0xbf, 0x8d, 0x9f, 0xe4, 0xf9, 0xec, 0x41, 0xc6, 0xef, 0x3f, 0x1f, 0x7d, 0xf5, 0xdf, 0xc6,
		0x8f, 0x71, 0x7e, 0xfb, 0xfa, 0x7c, 0x62, 0x41, 0x57, 0xd0, 0xdb, 0x2c, 0xd3, 0x89, 0x4a, 0xb4,
		0x03, 0x95, 0xb8, 0xaf, 0xf9, 0x00, 0x5f, 0x73, 0x19, 0x68, 0x0b, 0xbe, 0xe6, 0x0d, 0x1e, 0x09,
		0x5f, 0x33, 0x5e, 0x0e, 0xbc, 0x1c, 0x78, 0x39, 0x2a, 0xe3, 0xe5, 0xc0, 0xd7, 0xbc, 0xce, 0x33,
		0xe1, 0x6b, 0x06, 0x85, 0x41, 0x61, 0x50, 0x18, 0x5f, 0x33, 0xbe, 0x66, 0x7c, 0xcd, 0x36, 0xc7,
		0xed, 0xee, 0x96, 0xe2, 0x6b, 0x2e, 0xc7, 0xde, 0xe2, 0x6b, 0x2e, 0xb1, 0xf7, 0xa1, 0x9e, 0xbe,
		0x66, 0xa9, 0x22, 0x33, 0x5e, 0x5d, 0xcd, 0x02, 0x35, 0x65, 0xaa, 0x52, 0xc5, 0x61, 0x52, 0x33,
		0x46, 0xc8, 0xbf, 0x24, 0x53, 0x2f, 0x46, 0xae, 0x4e, 0x8c, 0x6a, 0x7d, 0x18, 0x99, 0xba, 0x30,
		0x35, 0x2c, 0xbf, 0xb1, 0x39, 0x6c, 0x94, 0xa7, 0x04, 0xc7, 0x46, 0x40, 0x41, 0x0d, 0x0e, 0xaf,
		0x12, 0xe4, 0xbf, 0x0c, 0xc7, 0x8f, 0xa5, 0x45, 0xad, 0x0e, 0xc7, 0x26, 0xb5, 0x29, 0xd2, 0xf8,
		0xb2, 0xc0, 0xe5, 0xf7, 0x9b, 0x8f, 0x73, 0xe1, 0x5d, 0xd1, 0xe5, 0xc4, 0x85, 0xf7, 0x3d, 0xcb,
		0x0b, 0xef, 0x23, 0x89, 0x2e, 0x7e, 0xd3, 0x7d, 0x3c, 0x0a, 0x57, 0xdc, 0xb9, 0xe2, 0xee, 0xcd,
		0x03, 0x5b, 0xb1, 0x2b, 0xee, 0xdc, 0xba, 0x34, 0x3a, 0x9a, 0x0a, 0x47, 0x54, 0xfa, 0xa8, 0xaa,
		0x1d, 0x59, 0xb5, 0xa3, 0xab, 0x73, 0x84, 0xcb, 0xe1, 0x8b, 0x12, 0xcb, 0x84, 0xe9, 0xf4, 0xb3,
		0x5c, 0x3e, 0xe6, 0x3a, 0x1e, 0x95, 0x58, 0x6b, 0x89, 0x60, 0x40, 0x0b, 0x0e, 0xd4, 0x61, 0x41,
		0x1d, 0x1e, 0x74, 0x61, 0x42, 0xce, 0xf9, 0xbd, 0x47, 0xac, 0x55, 0x6a, 0x48, 0x62, 0xad, 0xc4,
		0x5a, 0x0d, 0x8f, 0xdb, 0xdd, 0x2d, 0x25, 0xd6, 0x5a, 0x8e, 0xbd, 0x25, 0xd6, 0xaa, 0x2d, 0xfb,
		0x8d, 0x5e, 0xdc, 0xef, 0x77, 0xa3, 0xe4, 0x32, 0xc8, 0x25, 0xf5, 0xcd, 0x4c, 0xd7, 0xdc, 0x1d,
		0x5e, 0x48, 0x35, 0xfe, 0xe2, 0x7a, 0xe1, 0x30, 0x1e, 0x1b, 0x01, 0xbf, 0xbe, 0x7a, 0xf3, 0xe6,
		0x97, 0x17, 0xbf, 0x9c, 0xbf, 0x7f, 0xf7, 0xea, 0x37, 0xac, 0x59, 0xac, 0x59, 0xac, 0xd9, 0x5d,
		0xb3, 0x66, 0xc7, 0x11, 0xac, 0x2c, 0x8d, 0x2f, 0x03, 0x0d, 0xac, 0xb9, 0xe3, 0xcd, 0x6a, 0x0b,
		0x8e, 0xf9, 0x22, 0x19, 0x5e, 0x8d, 0x16, 0xe4, 0xba, 0x46, 0xba, 0x44, 0xe7, 0x9a, 0x0e, 0x57,
		0x73, 0x80, 0x76, 0xa0, 0x7d, 0x17, 0xa1, 0x9d, 0xab, 0x39, 0xeb, 0x3c, 0xd3, 0xe7, 0x09, 0xe3,
		0x13, 0x86, 0xdd, 0x9b, 0x61, 0xc1, 0x5d, 0x70, 0x17, 0xdc, 0xdd, 0x31, 0xdc, 0xc5, 0x41, 0x2c,
		0x29, 0x92, 0x38, 0x88, 0x57, 0x8f, 0x8f, 0x83, 0xd8, 0xdb, 0x96, 0xe2, 0x20, 0xd6, 0x1b, 0x8d,
		0xcb, 0x38, 0x55, 0xbe, 0x8c, 0x33, 0xce, 0xcd, 0x1d, 0xff, 0x7f, 0x95, 0xaa, 0x3c, 0xbd, 0x1f,
		0x7d, 0xeb, 0xf1, 0xff, 0x57, 0xb8, 0xaa, 0x93, 0x6c, 0x93, 0x16, 0x1a, 0xb3, 0x58, 0x33, 0x14,
		0x32, 0xd9, 0x68, 0xcc, 0xb2, 0x8e, 0xc4, 0x55, 0xa6, 0x31, 0x4b, 0x55, 0x9b, 0xb1, 0x50, 0x1e,
		0x0f, 0x28, 0x05, 0x4a, 0xcb, 0x07, 0xa5, 0x24, 0x05, 0xfb, 0xb6, 0xa0, 0x34, 0x8e, 0xbf, 0x22,
		0x0c, 0x68, 0xc1, 0x81, 0x3a, 0x2c, 0xa8, 0xc3, 0x83, 0x2e, 0x4c, 0xc8, 0x3a, 0x05, 0xf0, 0xf9,
		0x8a, 0x0c, 0x89, 0xcf, 0x17, 0x9f, 0xaf, 0xe1, 0x71, 0xbb, 0xbb, 0xa5, 0xf8, 0x7c, 0xcb, 0xb1,
		0xb7, 0xf8, 0x7c, 0xb5, 0x65, 0x9f, 0xa4, 0x60, 0xac, 0x59, 0xac, 0x59, 0xac, 0xd9, 0xea, 0x5a,
		0xb3, 0x24, 0x05, 0x93, 0x14, 0x0c, 0xb4, 0x03, 0xed, 0x40, 0x7b, 0xed, 0xa0, 0x9d, 0xa4, 0xe0,
		0x75, 0x9e, 0x89, 0xa4, 0x60, 0x70, 0x17, 0xdc, 0x05, 0x77, 0xe5, 0x24, 0x16, 0x07, 0xb1, 0xa4,
		0x48, 0xe2, 0x20, 0x5e, 0x3d, 0x3e, 0x0e, 0x62, 0x6f, 0x5b, 0x8a, 0x83, 0x58, 0x6f, 0x34, 0x92,
		0x82, 0x6b, 0x92, 0x14, 0x5c, 0x9d, 0x72, 0xfc, 0x73, 0x39, 0xc1, 0x7e, 0xcb, 0xef, 0x17, 0xcc,
		0x64, 0x8b, 0x3a, 0x37, 0xce, 0xbc, 0x2b, 0x77, 0x75, 0xe1, 0xd2, 0x4c, 0x36, 0xaf, 0xed, 0xfe,
		0xe0, 0x94, 0xbe, 0x34, 0x64, 0x2f, 0x64, 0xb9, 0x91, 0xe5, 0xf6, 0x9d, 0x81, 0x26, 0x67, 0x32,
		0x88, 0x23, 0x8d, 0x6c, 0xb7, 0x3b, 0xa3, 0xcb, 0x3a, 0x35, 0x5a, 0x38, 0x35, 0x70, 0x6a, 0xe0,
		0xd4, 0x10, 0x0a, 0xed, 0x0b, 0xc1, 0xc9, 0x6c, 0x40, 0xa1, 0xa2, 0xd9, 0x2b, 0x0f, 0x82, 0xd8,
		0xb5, 0x31, 0x45, 0x68, 0x51, 0x83, 0x18, 0x4d, 0xa8, 0x31, 0x80, 0x1c, 0x6d, 0xe8, 0x31, 0x83,
		0x20, 0x33, 0x28, 0xb2, 0x81, 0x24, 0x25, 0x7a, 0x2f, 0x2c, 0xf3, 0xd2, 0x50, 0x35, 0x1b, 0xb8,
		0x97, 0xf6, 0xaf, 0x82, 0xb0, 0xdb, 0x4d, 0x5d, 0x96, 0xe9, 0xc9, 0xe4, 0x2c, 0x43, 0x6b, 0x7e,
		0xb6, 0xc7, 0x95, 0x74, 0x69, 0x69, 0xc1, 0x9a, 0x05, 0xbc, 0x19, 0xc2, 0x9c, 0x15, 0xdc, 0x99,
		0xc3, 0x9e, 0x39, 0xfc, 0xd9, 0xc2, 0xa0, 0x0e, 0x1c, 0x2a, 0xc1, 0xe2, 0x6c, 0x69, 0xc4, 0xc3,
		0x53, 0x2b, 0x4f, 0x4c, 0x34, 0x50, 0xc6, 0xaf, 0x3b, 0x26, 0xd9, 0xa9, 0xe2, 0x1c, 0x93, 0x35,
		0xfb, 0xa8, 0x2a, 0xb4, 0xba, 0x87, 0xfe, 0xde, 0xce, 0x7c, 0x6e, 0x1b, 0xec, 0xcd, 0xc2, 0x1e,
		0x3d, 0x35, 0x98, 0xeb, 0x6d, 0x98, 0xe7, 0x2e, 0x4d, 0xd4, 0xb7, 0x6b, 0x36, 0xe1, 0xc3, 0x87,
		0x1f, 0xf7, 0x83, 0xd3, 0xb3, 0x6f, 0x1f, 0x5b, 0xc1, 0xe9, 0xd9, 0xcd, 0xcb, 0xd6, 0xf8, 0x3f,
		0x37, 0xaf, 0x0f, 0x3e, 0xee, 0x07, 0xed, 0xe9, 0xeb, 0xa3, 0x8f, 0xfb, 0xc1, 0xd1, 0xd9, 0xa3,
		0x3f, 0xfe, 0x78, 0xf2, 0xe8, 0xef, 0xc3, 0xeb, 0xcd, 0x3f, 0xd8, 0x50, 0x7f, 0xa4, 0x33, 0x8b,
		0x2d, 0x7a, 0xf3, 0xfe, 0xe5, 0x7f, 0x9b, 0xef, 0xd3, 0xbf, 0x2d, 0x37, 0xea, 0x1f, 0x06, 0x3b,
		0xa5, 0x3a, 0xc3, 0xf5, 0xe3, 0x1a, 0x81, 0xdd, 0x31, 0x60, 0x27, 0x0a, 0x76, 0x61, 0xd0, 0x7b,
		0x1e, 0xfc, 0x7a, 0xf6, 0x77, 0xeb, 0x71, 0xfb, 0xfa, 0xd9, 0xa3, 0xbf, 0x4f, 0xae, 0xef, 0xbf,
		0xf9, 0x6d, 0xd9, 0x9f, 0xb5, 0x1e, 0x9f, 0x5c, 0x3f, 0x5b, 0xf1, 0x2f, 0xc7, 0xd7, 0xcf, 0xd6,
		0x1c, 0xe3, 0xe8, 0xfa, 0xe1, 0xc2, 0x9f, 0x8e, 0xde, 0x3f, 0x58, 0xf5, 0x81, 0xf6, 0x8a, 0x0f,
		0x1c, 0xae, 0xfa, 0xc0, 0xe1, 0x8a, 0x0f, 0xac, 0xfc, 0x4a, 0x07, 0x2b, 0x3e, 0x70, 0x74, 0xfd,
		0x6d, 0xe1, 0xef, 0x1f, 0x2e, 0xff, 0xd3, 0xe3, 0xeb, 0x47, 0xdf, 0x56, 0xfd, 0xdb, 0xc9, 0xf5,
		0xb7, 0x67, 0x8f, 0x80, 0xfe, 0xe2, 0xd0, 0x8f, 0xd8, 0xda, 0x8b, 0x6d, 0xf5, 0x15, 0xe1, 0x83,
		0x6a, 0x7d, 0xef, 0xeb, 0x4a, 0x64, 0x6a, 0xe5, 0x7d, 0x3b, 0x4f, 0xda, 0xdc, 0x5c, 0xf8, 0xd1,
		0xf0, 0xa3, 0xe1, 0x47, 0xc3, 0x8f, 0x86, 0x1f, 0x0d, 0x3f, 0x1a, 0x7e, 0x34, 0xfc, 0x68, 0x90,
		0x29, 0xfc, 0x68, 0xf8, 0xd1, 0xf0, 0xa3, 0xe1, 0x47, 0xc3, 0x8f, 0x06, 0xf4, 0xe3, 0x47, 0xc3,
		0x8f, 0x86, 0x1f, 0x4d, 0xcf, 0x8f, 0x56, 0xea, 0xb4, 0x39, 0xe1, 0x5b, 0x61, 0x0b, 0xe3, 0x7b,
		0xba, 0x25, 0x76, 0xef, 0x6a, 0x51, 0x73, 0xfe, 0xc2, 0x41, 0x53, 0x25, 0x49, 0x78, 0xcf, 0xc7,
		0xbd, 0xb2, 0xa8, 0x33, 0x7a, 0xf9, 0xfa, 0xe6, 0xe1, 0xce, 0x27, 0xff, 0x7d, 0x15, 0x65, 0xb9,
		0x48, 0x27, 0x0a, 0x3d, 0x49, 0x16, 0x94, 0x62, 0xdd, 0xfc, 0x4c, 0x8b, 0xbc, 0x4c, 0x25, 0x3f,
		0x32, 0xe9, 0xe5, 0x7e, 0xfc, 0xc4, 0xa4, 0x97, 0xd7, 0x51, 0x4f, 0xaa, 0xf9, 0x7d, 0x15, 0x3a,
		0x73, 0xac, 0xe4, 0xd4, 0x27, 0x0a, 0x63, 0x2f, 0x76, 0xee, 0xb8, 0x03, 0x95, 0x3b, 0xa0, 0x80,
		0x64, 0x3a, 0x7e, 0xac, 0x94, 0x0b, 0xa9, 0x4b, 0xef, 0x4b, 0x25, 0x42, 0x4b, 0xe5, 0x1c, 0xa0,
		0x72, 0x50, 0x39, 0xa8, 0x9c, 0x42, 0x4b, 0xc0, 0x8d, 0x26, 0xcf, 0x16, 0xb4, 0xba, 0x25, 0x6d,
		0x01, 0x6f, 0x86, 0x30, 0x67, 0x05, 0x77, 0xe6, 0xb0, 0x67, 0x0e, 0x7f, 0xb6, 0x30, 0xa8, 0xeb,
		0xab, 0x23, 0x13, 0x63, 0x33, 0x93, 0x8c, 0x4c, 0x8c, 0x4d, 0x76, 0x86, 0x4c, 0x0c, 0xb1, 0x09,
		0xc9, 0xc4, 0xd8, 0x78, 0x8b, 0xc8, 0xc4, 0x90, 0xd8, 0x29, 0x32, 0x31, 0xd6, 0x05, 0x3b, 0x32,
		0x31, 0x64, 0xc1, 0x8e, 0x90, 0x36, 0x99, 0x18, 0x15, 0x84, 0x7e, 0xc4, 0x96, 0x4c, 0x8c, 0x92,
		0xb0, 0xbb, 0x3d, 0x6e, 0x34, 0x71, 0xa3, 0x09, 0x3f, 0x1a, 0x7e, 0x34, 0xfc, 0x68, 0xf8, 0xd1,
		0xf0, 0xa3, 0xe1, 0x47, 0x83, 0x5a, 0xe2, 0x47, 0xc3, 0x8f, 0x86, 0x1f, 0x0d, 0x3f, 0x1a, 0x7e,
		0x34, 0x1c, 0x12, 0xf8, 0xd1, 0xf0, 0xa3, 0x21, 0xb6, 0xf8, 0xd1, 0xea, 0xe5, 0x47, 0xe3, 0x46,
		0x53, 0xc9, 0x6e, 0x34, 0x69, 0xe4, 0x08, 0xef, 0x95, 0xeb, 0x42, 0x93, 0x40, 0x1b, 0x2d, 0x3d,
		0x39, 0x2e, 0x57, 0xd7, 0x8e, 0x7f, 0xba, 0xaf, 0x4a, 0x89, 0x97, 0x8d, 0xd1, 0x56, 0x8c, 0x76,
		0x4f, 0xb6, 0x2b, 0xc8, 0xeb, 0x28, 0x79, 0x11, 0xbb, 0x2b, 0x97, 0xdc, 0x34, 0x26, 0x14, 0xcc,
		0xcd, 0x7f, 0x1d, 0x7e, 0x99, 0x1b, 0xb9, 0xf5, 0xb4, 0xdd, 0x3e, 0x3e, 0x69, 0xb7, 0xf7, 0x4f,
		0x0e, 0x4f, 0xf6, 0x4f, 0x8f, 0x8e, 0x5a, 0xc7, 0x2d, 0xc1, 0x76, 0x8b, 0x8d, 0x37, 0x69, 0xd7,
		0xa5, 0xae, 0xfb, 0xd3, 0x68, 0xf5, 0x93, 0x61, 0x1c, 0x97, 0x4a, 0x28, 0x94, 0x60, 0xb1, 0x8c,
		0x70, 0xd8, 0x10, 0xbd, 0xdc, 0x51, 0x12, 0x00, 0x6c, 0xd0, 0xc4, 0xb2, 0x3e, 0x4d, 0x2c, 0x65,
		0x3b, 0x1f, 0xfa, 0x17, 0x54, 0x6f, 0xed, 0x2d, 0x1f, 0x18, 0x0a, 0xe1, 0x54, 0xaf, 0x8e, 0xd7,
		0x78, 0xcb, 0x21, 0x44, 0xf4, 0xa7, 0x9c, 0xbe, 0x54, 0xd5, 0x8f, 0x32, 0xfa, 0x70, 0xdb, 0xcd,
		0x12, 0x42, 0x0a, 0x0f, 0x08, 0xd1, 0x28, 0xd4, 0xb3, 0xd5, 0x0c, 0x05, 0xb6, 0x3b, 0xf3, 0x9b,
		0x9f, 0xd8, 0xcd, 0x3e, 0xb1, 0xa1, 0xb8, 0x14, 0x15, 0x13, 0x5b, 0xf1, 0xd8, 0x42, 0x32, 0x8c,
		0x24, 0x62, 0x33, 0x61, 0x58, 0x7f, 0x4b, 0x37, 0xd8, 0xce, 0x46, 0xee, 0x82, 0x38, 0x1b, 0x04,
		0x79, 0x74, 0xb5, 0x4d, 0xa7, 0xe2, 0xdb, 0x2c, 0x9b, 0x3b, 0xc3, 0x6c, 0x28, 0x4e, 0xdb, 0xdd,
		0xab, 0xdd, 0x3a, 0x31, 0xa6, 0x48, 0xc2, 0x8b, 0x40, 0x22, 0x4b, 0xd1, 0x04, 0x15, 0xb1, 0xc4,
		0x13, 0xb1, 0x84, 0x12, 0x99, 0x44, 0x11, 0x5d, 0xc8, 0xda, 0xf6, 0x5e, 0x68, 0xd1, 0xe6, 0x9b,
		0x32, 0x4d, 0x36, 0x0b, 0x5e, 0x3d, 0x2f, 0x9c, 0x43, 0x26, 0x91, 0x23, 0x26, 0x98, 0x03, 0x26,
		0x95, 0xe3, 0x25, 0x9e, 0xc3, 0x25, 0x9e, 0xa3, 0x25, 0x9b, 0x83, 0x65, 0x6b, 0xf9, 0x17, 0xbd,
		0x8a, 0xdd, 0xe8, 0xc4, 0x2e, 0x4c, 0x86, 0x83, 0xa0, 0xeb, 0xe2, 0xf0, 0xab, 0x5c, 0x17, 0xfd,
		0xbb, 0xc3, 0xca, 0xf4, 0xcf, 0xdf, 0xa7, 0x7f, 0xbe, 0xe5, 0xc1, 0x55, 0x3b, 0xc0, 0x6a, 0x07,
		0x59, 0xe7, 0x40, 0x97, 0xc3, 0xbf, 0x24, 0x96, 0x0c, 0x39, 0x93, 0xb8, 0x61, 0x94, 0xe4, 0xad,
		0x63, 0x09, 0x81, 0x9b, 0x9c, 0xcf, 0x63, 0x81, 0xa1, 0xde, 0x85, 0xc9, 0xa5, 0x5c, 0x02, 0xa3,
		0x6c, 0x24, 0x40, 0xa1, 0xe5, 0xbc, 0x4e, 0x7d, 0xb5, 0xff, 0x0a, 0xe3, 0xa1, 0x53, 0x18, 0xf7,
		0xd7, 0x34, 0xec, 0x8c, 0x08, 0xe9, 0x2f, 0xd1, 0x65, 0x74, 0xe3, 0xe0, 0x29, 0x65, 0xd9, 0xa3,
		0xd7, 0xe1, 0x97, 0xca, 0x6d, 0xd5, 0xf1, 0xd1, 0xd1, 0xe1, 0x51, 0x85, 0xb6, 0xab, 0x24, 0x3e,
		0xff, 0x33, 0x5f, 0xee, 0xdd, 0x02, 0x76, 0xf5, 0xd8, 0xa7, 0x12, 0xc7, 0xd2, 0x16, 0xd7, 0xdd,
		0x61, 0xb1, 0xb8, 0xb0, 0xb8, 0xb0, 0xb8, 0xb0, 0xb8, 0xb0, 0xb8, 0xb0, 0xb8, 0xb0, 0xb8, 0x96,
		0x6d, 0xd5, 0xe1, 0xf1, 0xfe, 0x3e, 0x06, 0xd7, 0x2e, 0x18, 0x5c, 0xa9, 0xeb, 0x0f, 0xf2, 0xe8,
		0x2a, 0xfa, 0x7f, 0xee, 0x26, 0x76, 0x22, 0x67, 0x73, 0x2d, 0x8c, 0x8c, 0xd9, 0x85, 0xd9, 0x85,
		0xd9, 0x85, 0xd9, 0x85, 0xd9, 0x85, 0xd9, 0x85, 0xd9, 0x85, 0xa3, 0xab, 0xfa, 0x76, 0x17, 0xa9,
		0x71, 0xdf, 0xc9, 0x7d, 0xba, 0x93, 0x91, 0x53, 0xbc, 0x7b, 0x8f, 0x7e, 0x4a, 0xd4, 0x07, 0xf7,
		0x2a, 0x1b, 0x7c, 0x18, 0x7f, 0xdd, 0x42, 0x8d, 0x78, 0xb6, 0x48, 0x96, 0xdb, 0x2a, 0x43, 0xac,
		0x48, 0xff, 0x02, 0x91, 0x3e, 0x05, 0x62, 0x49, 0x21, 0x07, 0x24, 0x85, 0x68, 0x9a, 0xda, 0x24,
		0x85, 0xcc, 0x7d, 0x75, 0x92, 0x42, 0xe0, 0xca, 0x70, 0x65, 0xb8, 0x32, 0x5c, 0x19, 0xae, 0x0c,
		0x57, 0x86, 0x2b, 0xc3, 0x95, 0x6d, 0xb8, 0x32, 0x49, 0x21, 0x58, 0x5c, 0x58, 0x5c, 0x58, 0x5c,
		0x58, 0x5c, 0x58, 0x5c, 0x58, 0x5c, 0x24, 0x85, 0x60, 0x70, 0x95, 0xd7, 0xe0, 0x22, 0x29, 0x04,
		0xb3, 0x0b, 0xb3, 0x0b, 0xb3, 0x0b, 0xb3, 0x0b, 0xb3, 0x0b, 0xb3, 0x0b, 0x47, 0x17, 0x76, 0x97,
		0xf6, 0x27, 0x77, 0x33, 0x29, 0xa4, 0x68, 0x01, 0x54, 0xdb, 0x9c, 0x90, 0x02, 0xb5, 0x4c, 0xa9,
		0x9f, 0x24, 0x20, 0x2e, 0xa5, 0xac, 0xa3, 0x34, 0x27, 0x20, 0x6a, 0xd5, 0x94, 0x1e, 0x08, 0x8a,
		0xc0, 0xb6, 0x5b, 0x6f, 0xb5, 0xe5, 0x1b, 0x6c, 0xb2, 0xfa, 0xe6, 0xae, 0xb7, 0xa1, 0x3f, 0xde,
		0x9e, 0x35, 0xb6, 0xa6, 0x91, 0xbb, 0x20, 0x4a, 0x72, 0x97, 0xf6, 0xc2, 0x8e, 0x9b, 0x5f, 0x8e,
		0x75, 0xf7, 0x68, 0xbe, 0x10, 0xd6, 0xd2, 0x81, 0xd6, 0x14, 0x8f, 0xcd, 0x52, 0xba, 0x36, 0x26,
		0xce, 0xdb, 0x10, 0xe4, 0x02, 0x44, 0x78, 0x5b, 0xc2, 0x5b, 0x98, 0xd8, 0x16, 0x26, 0xb0, 0xc5,
		0x88, 0xaa, 0x2c, 0x64, 0x6c, 0x9a, 0x32, 0xd5, 0x98, 0x09, 0xe0, 0xf6, 0xf5, 0xdc, 0x6e, 0x87,
		0xa0, 0x96, 0x9b, 0xa2, 0x47, 0x87, 0x5a, 0x6e, 0x7b, 0xd4, 0x72, 0x33, 0x76, 0x96, 0x92, 0xb6,
		0xeb, 0xc9, 0x09, 0xba, 0xd3, 0x69, 0xbb, 0x61, 0xf7, 0x2a, 0x4a, 0x82, 0xcb, 0xb4, 0x3f, 0x1c,
		0xc8, 0x85, 0x33, 0xe6, 0x07, 0x25, 0x92, 0x61, 0x70, 0x58, 0xa5, 0x0f, 0xad, 0xda, 0xe1, 0x55,
		0x3b, 0xc4, 0x3a, 0x87, 0x59, 0xc6, 0xef, 0x56, 0xbe, 0x48, 0x46, 0x96, 0xa7, 0x51, 0x72, 0x29,
		0x18, 0xc9, 0x68, 0x3d, 0xf5, 0xba, 0x42, 0xa2, 0x9d, 0x5c, 0xe4, 0x3b, 0xb8, 0x98, 0x74, 0x6e,
		0x91, 0xed, 0xd8, 0xe2, 0x2b, 0xa5, 0x71, 0x4a, 0xd1, 0xa3, 0xae, 0x64, 0x46, 0xe3, 0xdc, 0xa8,
		0xe8, 0x23, 0xf4, 0x11, 0xfa, 0xa8, 0x64, 0xfa, 0x48, 0xf0, 0x84, 0x4a, 0x6a, 0x25, 0x2f, 0x18,
		0x38, 0xdf, 0x4b, 0xe7, 0x53, 0x24, 0x68, 0x95, 0xdf, 0x1f, 0x18, 0x24, 0x04, 0x09, 0x41, 0xc2,
		0x92, 0x21, 0x61, 0xec, 0xc2, 0x5e, 0xea, 0x7a, 0x92, 0x20, 0x78, 0x22, 0x30, 0xd6, 0xdb, 0x49,
		0x80, 0xeb, 0xc9, 0x93, 0xe6, 0xec, 0x7f, 0x3f, 0xea, 0x0d, 0x36, 0x8e, 0x40, 0x41, 0x0b, 0xa0,
		0x05, 0x85, 0x55, 0x62, 0xee, 0x82, 0x2b, 0x97, 0xa7, 0x51, 0x47, 0x4e, 0x19, 0xde, 0x0e, 0x89,
		0x1a, 0x44, 0x0d, 0xa2, 0x06, 0x4b, 0xa6, 0x06, 0x87, 0x51, 0x92, 0x1f, 0x1e, 0x08, 0x6a, 0xc1,
		0x13, 0x52, 0x6d, 0xbd, 0x00, 0xdb, 0xc2, 0xb0, 0xa4, 0xda, 0x56, 0x6e, 0xab, 0xda, 0x07, 0xa7,
		0xed, 0xd3, 0xe3, 0x93, 0x83, 0x53, 0xf2, 0x6d, 0x37, 0xfe, 0x21, 0xdf, 0x76, 0x23, 0xdf, 0x87,
		0x4a, 0x36, 0xdd, 0xb2, 0xc4, 0xaf, 0xe6, 0xec, 0xcd, 0x12, 0xd6, 0x60, 0x7b, 0x39, 0xfd, 0x6e,
		0x73, 0x19, 0x95, 0xb3, 0xf7, 0x2a, 0x50, 0x84, 0x2d, 0xba, 0x1c, 0x04, 0xbd, 0xb8, 0xdf, 0xef,
		0x46, 0xc9, 0x65, 0x70, 0x11, 0x26, 0xdd, 0xbf, 0xa2, 0xee, 0x78, 0x4b, 0x0b, 0xe6, 0x77, 0xac,
		0x18, 0x97, 0x7c, 0x0f, 0xf2, 0x3d, 0xbc, 0x59, 0xe0, 0x55, 0x2b, 0xd3, 0x56, 0x2c, 0xd5, 0x6a,
		0x41, 0xf0, 0x0a, 0x83, 0xa7, 0xc0, 0x51, 0x84, 0x44, 0x43, 0xa2, 0xab, 0x4f, 0xa2, 0x8b, 0x1e,
		0xed, 0xd9, 0x40, 0x5d, 0x17, 0xe7, 0x61, 0x30, 0x70, 0x69, 0xc7, 0x25, 0x79, 0x78, 0x29, 0x28,
		0x27, 0x53, 0x51, 0x5e, 0x98, 0x41, 0x68, 0x57, 0x65, 0x79, 0x8c, 0x18, 0x1c, 0x68, 0xc0, 0x82,
		0x22, 0x3c, 0x68, 0xc1, 0x84, 0x3a, 0x5c, 0xa8, 0xc3, 0x86, 0x2e, 0x7c, 0x08, 0x53, 0x4f, 0x21,
		0x99, 0x15, 0xf3, 0xcd, 0x2d, 0x48, 0xac, 0xf8, 0xf9, 0x9f, 0xc7, 0x00, 0x41, 0x57, 0x83, 0xb0,
		0xdf, 0x4e, 0xde, 0x7f, 0xa7, 0xea, 0xc7, 0x53, 0x76, 0x12, 0x69, 0xfb, 0xf5, 0x2c, 0x7c, 0x45,
		0x0a, 0x7e, 0x3e, 0x55, 0x7f, 0x9f, 0xf5, 0x96, 0xb6, 0xf6, 0xab, 0xbc, 0xa9, 0x0f, 0xca, 0x39,
		0xda, 0x59, 0x49, 0x1c, 0x94, 0x02, 0x42, 0xdf, 0xe8, 0xf6, 0xff, 0x4a, 0x82, 0xfc, 0x53, 0xea,
		0xb2, 0x4f, 0xfd, 0xb8, 0x9b, 0x29, 0x18, 0x9c, 0xf7, 0x26, 0xc0, 0xde, 0xc4, 0xde, 0xc4, 0xde,
		0xc4, 0xde, 0xc4, 0xde, 0xc4, 0xde, 0xc4, 0xde, 0xc4, 0xde, 0xc4, 0xde, 0xb4, 0xb2, 0x37, 0x85,
		0xb4, 0x84, 0x68, 0x66, 0xe6, 0x3c, 0x9e, 0xc9, 0x66, 0x68, 0xce, 0x1f, 0x2b, 0xf5, 0x4c, 0xcd,
		0xd9, 0x64, 0xa2, 0x19, 0x9b, 0xe5, 0x62, 0x0a, 0x33, 0x1b, 0x3e, 0xc8, 0x06, 0xae, 0x13, 0xf5,
		0xa2, 0x4e, 0xf1, 0xac, 0x81, 0xa5, 0xc6, 0xc2, 0xaa, 0x89, 0x60, 0x0e, 0x30, 0x07, 0x98, 0xc3,
		0x8e, 0x31, 0x07, 0x97, 0x0c, 0xaf, 0x5c, 0x2a, 0x09, 0x00, 0xf3, 0x20, 0xd0, 0x6a, 0x0b, 0x8e,
		0xf9, 0x22, 0x19, 0x5e, 0x8d, 0x16, 0xe1, 0xba, 0x96, 0xa0, 0x9f, 0x4b, 0x6e, 0xf1, 0x12, 0xac,
		0x1f, 0x8f, 0x0f, 0xc4, 0x03, 0xf1, 0x40, 0x3c, 0x10, 0x0f, 0xc4, 0xdb, 0x41, 0xfc, 0x70, 0x10,
		0xa8, 0x07, 0x01, 0x96, 0xcc, 0x01, 0xd4, 0x03, 0xf5, 0x40, 0xfd, 0x8e, 0x41, 0x3d, 0x71, 0x00,
		0xe1, 0x1f, 0xe2, 0x00, 0xdf, 0x19, 0x9f, 0x38, 0x80, 0xb7, 0x2d, 0x25, 0x0e, 0xa0, 0x30, 0x1a,
		0x71, 0x80, 0x82, 0xc7, 0x8a, 0x38, 0x80, 0x0c, 0x5f, 0x50, 0xa6, 0x0a, 0xb0, 0x04, 0x58, 0x02,
		0x2c, 0x01, 0x96, 0x00, 0x4b, 0x80, 0x25, 0xc0, 0x12, 0x60, 0x09, 0xb0, 0x04, 0x58, 0x02, 0x2c,
		0xc1, 0x90, 0x25, 0x78, 0xbd, 0x4c, 0x2b, 0x54, 0x90, 0x64, 0x36, 0x9e, 0x97, 0xc2, 0x24, 0xcb,
		0xcb, 0x5d, 0x34, 0x45, 0xae, 0xdc, 0xef, 0xd9, 0xd7, 0x2d, 0x79, 0x79, 0x39, 0xf8, 0x75, 0xf2,
		0x34, 0x3f, 0x4d, 0x1f, 0xa6, 0x50, 0x31, 0x93, 0xe2, 0xa2, 0x56, 0xa8, 0x4e, 0xef, 0xb8, 0xef,
		0xa1, 0x5c, 0x75, 0xde, 0x82, 0x4d, 0x1f, 0xf7, 0x34, 0xea, 0x28, 0x1c, 0x50, 0x47, 0xa1, 0x0c,
		0xd4, 0x93, 0x3a, 0x0a, 0x1b, 0x3c, 0x12, 0x75, 0x14, 0xf0, 0x54, 0xe1, 0xa9, 0xc2, 0x53, 0x85,
		0xa7, 0x0a, 0x4f, 0x15, 0x9e, 0x2a, 0x3c, 0x55, 0x78, 0xaa, 0xf0, 0x54, 0x59, 0xf8, 0x3b, 0xa8,
		0xa3, 0x80, 0xbd, 0x89, 0xbd, 0x89, 0xbd, 0x89, 0xbd, 0x89, 0xbd, 0x89, 0xbd, 0x89, 0xbd, 0x89,
		0xbd, 0x89, 0xbd, 0xa9, 0xae, 0x25, 0x88, 0x8c, 0x7e, 0x67, 0x32, 0xea, 0x28, 0x14, 0x37, 0x16,
		0xa8, 0xa3, 0x00, 0x73, 0x80, 0x39, 0xc0, 0x1c, 0xb8, 0x64, 0x5b, 0x26, 0xd0, 0xa7, 0x8e, 0x02,
		0x10, 0x0f, 0xc4, 0x03, 0xf1, 0x40, 0x3c, 0x75, 0x14, 0x36, 0xde, 0x62, 0xea, 0x28, 0x00, 0xf5,
		0x40, 0x3d, 0x50, 0x4f, 0x1c, 0x40, 0xf8, 0x87, 0x38, 0xc0, 0x77, 0xc6, 0x27, 0x0e, 0xe0, 0x6d,
		0x4b, 0x89, 0x03, 0x28, 0x8c, 0x46, 0x1c, 0xa0, 0xe0, 0xb1, 0x22, 0x0e, 0x40, 0x1d, 0x05, 0x58,
		0x02, 0x2c, 0x01, 0x96, 0x00, 0x4b, 0x80, 0x25, 0xc0, 0x12, 0x60, 0x09, 0xb0, 0x04, 0x58, 0x02,
		0x2c, 0x01, 0x96, 0x20, 0x38, 0x02, 0x75, 0x14, 0x56, 0xd7, 0x51, 0x90, 0xb8, 0x71, 0xbf, 0x57,
		0x92, 0x32, 0x0a, 0xef, 0xc7, 0xcf, 0xe2, 0xab, 0x8a, 0xc2, 0x03, 0x43, 0xd1, 0x94, 0x12, 0xc9,
		0x32, 0x89, 0x62, 0xa3, 0x50, 0x19, 0x0a, 0xdf, 0xc2, 0xb7, 0x9d, 0xd8, 0x6d, 0x2e, 0x34, 0x5b,
		0x08, 0x4c, 0xe3, 0x76, 0x3b, 0xa2, 0xee, 0xd6, 0xe2, 0x32, 0xe3, 0x42, 0x77, 0x46, 0xdb, 0x52,
		0x7c, 0x8b, 0x59, 0x73, 0x85, 0xbd, 0x1d, 0x12, 0xde, 0x0d, 0x41, 0x6f, 0x86, 0x94, 0xf7, 0x42,
		0xdc, 0x5b, 0x21, 0xee, 0x9d, 0x90, 0xf5, 0x46, 0xd8, 0x42, 0x6e, 0x61, 0xef, 0xc2, 0x4c, 0x62,
		0x62, 0x17, 0xf6, 0x52, 0xd7, 0x2b, 0x22, 0x31, 0xd3, 0x54, 0x92, 0x93, 0x02, 0x63, 0xbc, 0x9d,
		0xa0, 0xfe, 0x93, 0x27, 0x93, 0x6a, 0x4a, 0xcd, 0x3b, 0x47, 0xbb, 0x12, 0x80, 0x36, 0x5a, 0x46,
		0x41, 0x44, 0xdb, 0x7e, 0x57, 0x0a, 0x56, 0x1d, 0x2a, 0x1d, 0xa4, 0x45, 0x3d, 0x00, 0x6d, 0x0b,
		0x40, 0x8b, 0x7a, 0x55, 0x81, 0xb3, 0xa2, 0x15, 0x82, 0x1a, 0x9d, 0xa9, 0xc4, 0x0a, 0xd5, 0xfe,
		0x12, 0xa9, 0xe8, 0x26, 0x5e, 0xfc, 0x6b, 0xbf, 0x9c, 0xc5, 0xbf, 0x0a, 0x1d, 0x4f, 0xe9, 0x63,
		0xaa, 0x76, 0x5c, 0xd5, 0x8e, 0xad, 0xc6, 0xf1, 0x2d, 0x87, 0xaf, 0x42, 0xac, 0xf0, 0xd7, 0x4c,
		0x29, 0xca, 0x07, 0x54, 0x6f, 0x87, 0x26, 0x98, 0x5a, 0x1a, 0x30, 0xd0, 0x02, 0x05, 0x75, 0x70,
		0x50, 0x07, 0x09, 0x4d, 0xb0, 0x90, 0x73, 0x91, 0xee, 0x55, 0x22, 0x90, 0x5a, 0x9c, 0xfa, 0x68,
		0x50, 0xa1, 0x95, 0xd4, 0xa8, 0x39, 0xde, 0xe6, 0x67, 0x33, 0xc0, 0xca, 0xee, 0xbf, 0x31, 0xf9,
		0x7d, 0xec, 0x79, 0xaa, 0x51, 0x46, 0x4d, 0x36, 0xbc, 0x50, 0xc4, 0xff, 0x3b, 0xa3, 0xa3, 0x02,
		0x50, 0x01, 0xa8, 0x00, 0x54, 0x40, 0x65, 0x55, 0xc0, 0xc7, 0x5b, 0x15, 0xf0, 0x1f, 0x9d, 0x61,
		0x9a, 0xba, 0x24, 0x7f, 0xf8, 0xa8, 0xf9, 0xe4, 0xc9, 0xad, 0x37, 0xed, 0x6c, 0xf2, 0x91, 0x79,
		0xdc, 0xcb, 0x96, 0xbc, 0x37, 0x1b, 0xb9, 0xeb, 0xbe, 0x34, 0x88, 0xbc, 0xee, 0xed, 0x35, 0x5e,
		0x7c, 0x19, 0x07, 0xbd, 0x8b, 0x67, 0x33, 0xc9, 0x13, 0xdc, 0x7e, 0x27, 0x70, 0x5f, 0xf2, 0x67,
		0xb9, 0x8b, 0xdd, 0x95, 0xcb, 0xd3, 0xaf, 0x41, 0x3f, 0x09, 0x3a, 0x9f, 0xc6, 0xe9, 0x57, 0x2a,
		0xa4, 0xb7, 0x17, 0xc6, 0x99, 0x06, 0xeb, 0xf5, 0x4d, 0x78, 0xcf, 0x08, 0xce, 0xbb, 0xe6, 0x1d,
		0x0f, 0x74, 0x75, 0x7b, 0x1b, 0x4c, 0x5f, 0xbd, 0x73, 0x3d, 0x7a, 0x1a, 0xd0, 0xd3, 0x00, 0xb7,
		0x26, 0x6e, 0x4d, 0xdc, 0x9a, 0x70, 0x5a, 0x38, 0x2d, 0x9c, 0x16, 0x4e, 0x8b, 0x5b, 0x13, 0xb7,
		0x26, 0x2a, 0x00, 0x15, 0x80, 0x0a, 0x40, 0x05, 0xe0, 0xd6, 0xdc, 0x69, 0xb7, 0x66, 0x0d, 0x7d,
		0x56, 0x55, 0xbd, 0x47, 0x32, 0xef, 0xb2, 0xe2, 0xfe, 0x48, 0x05, 0x25, 0xaf, 0x42, 0xd7, 0x46,
		0xe6, 0x64, 0xad, 0xcc, 0xd9, 0xd5, 0xc5, 0xfc, 0x9f, 0x22, 0x7e, 0x4f, 0xb1, 0x6c, 0xea, 0x03,
		0x2e, 0x88, 0x68, 0x5a, 0xaa, 0x5c, 0x10, 0x11, 0xf4, 0x51, 0x36, 0xc2, 0xee, 0x55, 0x94, 0x04,
		0x97, 0x69, 0x7f, 0x38, 0x90, 0x0b, 0x3f, 0xcc, 0x0f, 0x2a, 0x13, 0x84, 0xd8, 0xaf, 0x79, 0x6e,
		0x35, 0x8d, 0x95, 0x69, 0xac, 0xac, 0x4f, 0x20, 0xe7, 0xf4, 0x64, 0x1a, 0x25, 0x22, 0xd1, 0xde,
		0xa9, 0xd2, 0x7c, 0xea, 0x75, 0x85, 0x44, 0xeb, 0x2b, 0xc8, 0xd7, 0x55, 0x30, 0xa9, 0xa7, 0x20,
		0x5b, 0x47, 0xc1, 0x4f, 0x18, 0x5c, 0xe4, 0xd6, 0xf0, 0x82, 0xb4, 0x0b, 0xdc, 0x1e, 0x46, 0x1f,
		0xa1, 0x8f, 0xd0, 0x47, 0x6a, 0xfa, 0x48, 0xf0, 0x84, 0x4a, 0x6a, 0x25, 0x3f, 0xa9, 0x40, 0x69,
		0x7c, 0x19, 0x5c, 0xb9, 0xab, 0x0b, 0x97, 0x66, 0x9f, 0x22, 0x41, 0xab, 0xfc, 0xfe, 0xc0, 0x20,
		0x21, 0x48, 0x08, 0x12, 0x96, 0x0c, 0x09, 0xe5, 0x42, 0x3a, 0x92, 0xa1, 0x9c, 0xf9, 0xba, 0x0d,
		0xb3, 0xff, 0xe5, 0x2e, 0xb8, 0x8c, 0xfb, 0x17, 0x61, 0x3c, 0xef, 0x31, 0x1d, 0x81, 0xcc, 0xcd,
		0xff, 0x37, 0x8b, 0x47, 0xf2, 0xa1, 0x05, 0xd0, 0x82, 0x71, 0xff, 0x2d, 0x17, 0x5c, 0xb9, 0x3c,
		0x8d, 0x3a, 0x72, 0xca, 0xf0, 0x76, 0x48, 0xd4, 0x20, 0x6a, 0x10, 0x35, 0x58, 0x32, 0x35, 0x38,
		0x8c, 0x92, 0xfc, 0xf0, 0x40, 0x50, 0x0b, 0x4a, 0x28, 0x41, 0xd9, 0x42, 0xc7, 0xb2, 0x85, 0x40,
		0x15, 0x32, 0x8c, 0x54, 0xaa, 0xdf, 0x6a, 0x15, 0x32, 0xd6, 0xac, 0x75, 0x7b, 0x2d, 0x5b, 0x59,
		0xb5, 0x72, 0x5b, 0xd5, 0x3e, 0x38, 0x6d, 0x9f, 0x1e, 0x9f, 0x1c, 0x9c, 0x1e, 0x55, 0x68, 0xcf,
		0x4a, 0x92, 0xf4, 0x73, 0x46, 0x6a, 0xc7, 0x26, 0xbe, 0x0f, 0x1f, 0xa9, 0x1d, 0x45, 0xd3, 0x88,
		0x8c, 0x53, 0x3a, 0x0a, 0x64, 0x0c, 0x6d, 0x91, 0xcb, 0xf1, 0x40, 0x51, 0x7c, 0x46, 0xc6, 0x5b,
		0x41, 0xef, 0x5f, 0x31, 0x8a, 0x57, 0x9c, 0xd2, 0xa9, 0x50, 0xb8, 0x62, 0x94, 0x6d, 0xd3, 0x4d,
		0x28, 0x78, 0x76, 0xbd, 0x9c, 0xd9, 0xc6, 0x56, 0x29, 0x46, 0x86, 0xa7, 0x74, 0xb3, 0xf3, 0xb9,
		0xfe, 0x29, 0x5b, 0xef, 0x2f, 0xd7, 0x14, 0x81, 0x6d, 0xb7, 0xde, 0x70, 0xcb, 0x37, 0xd8, 0x68,
		0x8b, 0x0d, 0x5e, 0x6f, 0x5b, 0x7f, 0xbc, 0x49, 0xdf, 0xff, 0x8b, 0x1f, 0x6c, 0xdf, 0xa6, 0xdb,
		0xa6, 0xb0, 0x5d, 0x6b, 0x6c, 0x8b, 0xec, 0x76, 0x7c, 0x7f, 0xe1, 0x57, 0x2f, 0xe7, 0x77, 0x96,
		0xb2, 0x31, 0xf9, 0x6a, 0xdf, 0x5f, 0xc0, 0x19, 0x23, 0x1d, 0xff, 0xf5, 0x0f, 0x36, 0x66, 0x3d,
		0x3b, 0x7c, 0x6d, 0x5f, 0xcf, 0x26, 0xbe, 0x9c, 0x79, 0x5f, 0x4d, 0xe2, 0xf2, 0xd1, 0x6e, 0xad,
		0xb3, 0x49, 0x1b, 0xba, 0x63, 0xb6, 0x76, 0xb7, 0x6c, 0xed, 0x4e, 0xb9, 0xef, 0x2e, 0x99, 0x3e,
		0x9b, 0xf2, 0x11, 0x5b, 0xdb, 0xa3, 0xb1, 0x85, 0xe3, 0x7e, 0x13, 0xc7, 0xfc, 0x92, 0x82, 0xc9,
		0x3f, 0x76, 0xab, 0x6f, 0x77, 0x1c, 0x06, 0xfd, 0x38, 0xea, 0x7c, 0x0d, 0x7a, 0xfd, 0xf4, 0xaf,
		0x30, 0xed, 0x46, 0xc9, 0xe5, 0xfa, 0x67, 0x63, 0xf1, 0xa3, 0xeb, 0x1d, 0x94, 0x96, 0xe7, 0x83,
		0x32, 0xe8, 0xd5, 0xf2, 0x8c, 0x0c, 0x7a, 0xda, 0xc7, 0x63, 0xdd, 0xb4, 0xd3, 0x5b, 0xd3, 0x7e,
		0xfd, 0x1e, 0x89, 0x8b, 0x49, 0x01, 0xeb, 0x5a, 0x01, 0x1b, 0x66, 0x70, 0x6f, 0xec, 0x73, 0xdf,
		0xc6, 0xb7, 0xbe, 0xb1, 0xb8, 0x15, 0xf5, 0x94, 0x17, 0xf6, 0x88, 0x17, 0xf6, 0x7c, 0x6f, 0x23,
		0x8e, 0x3a, 0xf6, 0xed, 0xa6, 0xd9, 0xd1, 0x05, 0x2a, 0x35, 0x14, 0xae, 0xc8, 0xb0, 0xe5, 0xf5,
		0x83, 0xad, 0x03, 0x47, 0x45, 0x02, 0x45, 0x5b, 0x0b, 0x75, 0x51, 0xe1, 0x16, 0x13, 0x72, 0x31,
		0x61, 0x97, 0x10, 0x7a, 0x1b, 0x67, 0xcb, 0xb6, 0x57, 0x05, 0x8a, 0x16, 0x5d, 0x97, 0x29, 0xb6,
		0x5e, 0xb7, 0x5e, 0x07, 0x03, 0x7a, 0x1d, 0x58, 0x1d, 0x2b, 0x3f, 0x2e, 0xf1, 0xe2, 0x37, 0x73,
		0x06, 0x83, 0x78, 0xde, 0xa6, 0x0e, 0x6e, 0xac, 0x6c, 0xc1, 0x5b, 0x3a, 0x2b, 0x26, 0x20, 0x21,
		0x42, 0xfd, 0x00, 0x4b, 0x1f, 0x64, 0xb5, 0x03, 0xad, 0x76, 0xb0, 0x35, 0x0e, 0x78, 0xb1, 0x83,
		0x5e, 0xf0, 0xc0, 0x6f, 0xee, 0x3a, 0x50, 0x70, 0x2d, 0x48, 0xba, 0x1e, 0x36, 0x71, 0x4d, 0xcc,
		0xfe, 0x37, 0x86, 0x90, 0xc8, 0x65, 0x37, 0x2f, 0xbe, 0x4e, 0x7d, 0x16, 0x13, 0x07, 0xc1, 0xb6,
		0x1d, 0x9e, 0x8a, 0x6f, 0x2c, 0x97, 0x52, 0x80, 0x5c, 0x20, 0x17, 0xc8, 0xf5, 0x70, 0x3a, 0xf7,
		0x4a, 0x71, 0x21, 0x85, 0x74, 0x90, 0xe6, 0x82, 0x97, 0xba, 0x39, 0x57, 0x42, 0xe8, 0x36, 0x1d,
		0xa4, 0x70, 0x25, 0x64, 0xb9, 0xc8, 0xd7, 0xdb, 0xf1, 0x37, 0xfe, 0x75, 0xf6, 0x85, 0x6f, 0xe3,
		0xcb, 0xf3, 0x09, 0x21, 0x45, 0xaa, 0x1e, 0xd3, 0x0c, 0x16, 0x6f, 0x02, 0xde, 0x84, 0xf2, 0x23,
		0x2a, 0x8d, 0x60, 0x4b, 0x08, 0x66, 0x34, 0x82, 0x55, 0x82, 0x33, 0x1a, 0xc1, 0x6e, 0x05, 0x67,
		0x34, 0x82, 0xdd, 0x5a, 0xe8, 0x68, 0x04, 0x6b, 0x75, 0x3c, 0xe1, 0xe1, 0x1a, 0xc7, 0xb7, 0x1c,
		0x3c, 0x9c, 0x8e, 0x09, 0xc5, 0x87, 0xa3, 0x5c, 0x36, 0xe5, 0xb2, 0x8d, 0xc0, 0x42, 0x06, 0x34,
		0x84, 0xc0, 0x43, 0xde, 0x99, 0xa7, 0x40, 0x7d, 0x34, 0xa8, 0xd0, 0x4a, 0x6a, 0x44, 0xc7, 0x04,
		0x3a, 0x26, 0xa0, 0x02, 0x50, 0x01, 0xa8, 0x00, 0x54, 0x00, 0x1d, 0x13, 0xec, 0xd9, 0x0c, 0x8d,
		0x60, 0x69, 0x04, 0xfb, 0xa3, 0x67, 0x29, 0x75, 0x53, 0x8d, 0x35, 0x03, 0x9e, 0xa5, 0x6f, 0x04,
		0xbb, 0x5e, 0x18, 0x94, 0x4e, 0xb0, 0x4b, 0xcd, 0x5d, 0x3a, 0xc1, 0xe2, 0xd7, 0xc4, 0xaf, 0x89,
		0x5f, 0x13, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0xf1, 0x6b, 0xe2, 0xd7, 0x44, 0x05, 0xa0,
		0x02, 0x50, 0x01, 0xa8, 0x00, 0xfc, 0x9a, 0xbb, 0xe8, 0xd7, 0xac, 0xa1, 0xd3, 0xaa, 0x7c, 0x9d,
		0x60, 0xb7, 0xf0, 0x59, 0xd1, 0x0a, 0xb6, 0x82, 0xa2, 0x57, 0xa1, 0x7b, 0x22, 0xf4, 0x82, 0xb5,
		0xf2, 0x78, 0x96, 0xae, 0x17, 0x2c, 0xf7, 0x43, 0xb6, 0xb2, 0x44, 0xa9, 0x36, 0x41, 0xb5, 0x09,
		0x7f, 0x94, 0x94, 0xab, 0xcf, 0x5c, 0x7d, 0xb6, 0xa3, 0x94, 0x54, 0x9b, 0x10, 0x34, 0xa6, 0xa9,
		0x36, 0x01, 0xe4, 0x02, 0xb9, 0x40, 0xae, 0xfd, 0xe9, 0xdc, 0xa3, 0xda, 0x44, 0xa5, 0x9c, 0x09,
		0xe5, 0x69, 0x3e, 0xb2, 0x9e, 0x13, 0x81, 0xee, 0x23, 0xf3, 0x43, 0xd0, 0x7d, 0xa4, 0xe8, 0x26,
		0x94, 0xab, 0xfb, 0xc8, 0x7a, 0x87, 0xd6, 0x6b, 0xf7, 0x91, 0xb5, 0x8e, 0x29, 0xed, 0x47, 0x64,
		0xf6, 0xdc, 0x4b, 0xfb, 0x91, 0xef, 0xec, 0xb0, 0x58, 0xff, 0x91, 0x35, 0xca, 0xde, 0x8f, 0xd6,
		0x37, 0xc8, 0x5c, 0xec, 0xc6, 0x2d, 0xda, 0x82, 0xcb, 0xb4, 0x3f, 0x1c, 0x6c, 0x51, 0xc5, 0x7d,
		0xf9, 0x30, 0x14, 0x74, 0xb7, 0x33, 0xf9, 0x77, 0xb9, 0xa0, 0xfb, 0x32, 0xe9, 0xdb, 0xbe, 0xb6,
		0xfb, 0xd2, 0xd1, 0x28, 0xf3, 0xae, 0xc6, 0x7e, 0x29, 0xf3, 0x4e, 0x99, 0x77, 0x5b, 0xa7, 0x12,
		0x81, 0x37, 0x2f, 0xce, 0xa2, 0x1d, 0x0e, 0xbc, 0x8d, 0x95, 0x88, 0xa8, 0xaf, 0x77, 0x36, 0x22,
		0x7e, 0x5e, 0xfc, 0xbc, 0xf8, 0x79, 0x4b, 0xe4, 0xe7, 0xcd, 0xf2, 0xf4, 0xc7, 0xcd, 0xd1, 0xaa,
		0xe1, 0xe1, 0x2d, 0xa0, 0xd5, 0xae, 0x06, 0x71, 0x16, 0xc4, 0xd9, 0x40, 0x0e, 0xf1, 0x66, 0x23,
		0x82, 0x78, 0x20, 0x1e, 0x88, 0x57, 0x22, 0xc4, 0xab, 0x50, 0x32, 0xc1, 0x93, 0x27, 0x37, 0x9d,
		0x88, 0xe3, 0x6c, 0x90, 0x35, 0x3b, 0xfd, 0x24, 0xcb, 0xd3, 0x30, 0x4a, 0x5c, 0x37, 0x18, 0xb1,
		0xfe, 0x66, 0x3e, 0x4c, 0x12, 0x17, 0x67, 0x93, 0xff, 0xae, 0xdf, 0x8b, 0x53, 0x7b, 0xcb, 0x0a,
		0x45, 0x20, 0x16, 0x46, 0x2b, 0x1c, 0x91, 0x58, 0x1c, 0x51, 0x21, 0x42, 0xb1, 0x30, 0x49, 0xa1,
		0x88, 0x85, 0xa0, 0x52, 0x24, 0xec, 0xb9, 0xc4, 0x9b, 0xbe, 0xd4, 0x01, 0xbc, 0xf4, 0xdd, 0x52,
		0x97, 0xde, 0x1f, 0x41, 0xc6, 0xfb, 0xe9, 0xf7, 0xfd, 0x6d, 0xfc, 0x10, 0x4b, 0xde, 0xab, 0x40,
		0x31, 0xfe, 0xc2, 0x84, 0x53, 0x8a, 0x68, 0x52, 0x84, 0x1f, 0x5f, 0x0f, 0x45, 0xf8, 0x3d, 0x9a,
		0x43, 0x4b, 0x8a, 0xf0, 0xcf, 0x8e, 0x34, 0xf7, 0x43, 0xd6, 0x5a, 0x7d, 0xee, 0x87, 0x00, 0x5d,
		0x55, 0x80, 0x2e, 0xdc, 0xd4, 0x38, 0x6d, 0x70, 0xda, 0xe0, 0xb4, 0x59, 0x53, 0x33, 0xe2, 0xa6,
		0xc6, 0x4d, 0x0d, 0xe2, 0x81, 0x78, 0xbb, 0x82, 0x78, 0xb8, 0xa9, 0x95, 0xb7, 0x0c, 0x37, 0x35,
		0x6e, 0xea, 0xda, 0xb8, 0xa9, 0x4b, 0x7c, 0x67, 0x67, 0x4d, 0x2f, 0x75, 0xfd, 0x6e, 0xf1, 0x6c,
		0xc9, 0x26, 0xb9, 0xc1, 0x53, 0x78, 0x03, 0xca, 0x7e, 0x83, 0x67, 0xfd, 0x83, 0x5d, 0xae, 0x7b,
		0x3d, 0xeb, 0x1d, 0x65, 0x6e, 0xfa, 0x88, 0xcb, 0x46, 0x39, 0x2e, 0xfd, 0x2c, 0xd9, 0x7e, 0xd3,
		0xdb, 0x3f, 0x93, 0xd2, 0x0a, 0x5b, 0x5c, 0xf8, 0x99, 0x7e, 0x92, 0x3b, 0x3e, 0x76, 0xac, 0x72,
		0xa7, 0xef, 0xf8, 0x6c, 0x57, 0xa9, 0xe8, 0xae, 0xc0, 0x7e, 0xe5, 0x1e, 0x8f, 0x9e, 0x13, 0x85,
		0x7b, 0x3c, 0xdc, 0xe3, 0xb1, 0xf5, 0x4d, 0x12, 0x20, 0xf5, 0xe2, 0x73, 0xdc, 0xe1, 0x00, 0xe9,
		0x6d, 0xd1, 0x29, 0xb1, 0x78, 0xc1, 0xed, 0x90, 0x04, 0x0c, 0x08, 0x18, 0x10, 0x30, 0x28, 0x51,
		0xc0, 0xa0, 0x46, 0x21, 0x52, 0xbc, 0xc1, 0xcb, 0x1c, 0x03, 0x4b, 0x2b, 0x0b, 0x96, 0xd4, 0xe7,
		0x3b, 0xf9, 0xae, 0x93, 0x7f, 0xa9, 0x40, 0x0a, 0x72, 0x71, 0x5d, 0x29, 0xa6, 0x23, 0x49, 0x42,
		0xc6, 0x50, 0x25, 0x09, 0xb9, 0xa8, 0xf2, 0x92, 0x4d, 0x42, 0x2e, 0x58, 0xbf, 0xd5, 0x06, 0xc3,
		0xd2, 0x61, 0xbc, 0x81, 0x77, 0x74, 0xe5, 0x26, 0xdc, 0x0c, 0x03, 0xc9, 0x06, 0xbb, 0x20, 0xd9,
		0xeb, 0x1d, 0x3a, 0x39, 0x7e, 0x3d, 0x1e, 0xad, 0x64, 0xad, 0x71, 0xa1, 0xd6, 0x50, 0xeb, 0x2a,
		0x51, 0x6b, 0xb1, 0xd6, 0xb8, 0x61, 0x47, 0xac, 0x23, 0xd5, 0x1d, 0xe1, 0x9d, 0x8c, 0x2b, 0xdb,
		0x11, 0xb1, 0xb5, 0xa3, 0x1d, 0x11, 0x07, 0x74, 0x44, 0xf4, 0xd1, 0x11, 0x71, 0x50, 0xdb, 0x8e,
		0x88, 0x52, 0xf0, 0x31, 0x1b, 0xb0, 0x60, 0xf4, 0xeb, 0x87, 0x87, 0xa0, 0xb0, 0x23, 0xc8, 0x00,
		0x56, 0xd4, 0xe0, 0x45, 0x13, 0x66, 0xd4, 0xe1, 0x46, 0x1b, 0x76, 0xcc, 0xe0, 0xc7, 0x0c, 0x86,
		0x2c, 0xe0, 0x48, 0x16, 0x96, 0x84, 0xe1, 0x49, 0x0d, 0xa6, 0x66, 0x03, 0x77, 0x5d, 0x27, 0x1c,
		0x64, 0xc3, 0x38, 0xcc, 0x5d, 0x70, 0x99, 0x2a, 0x0a, 0xe5, 0xf4, 0x54, 0xdd, 0x9f, 0x50, 0x49,
		0x62, 0x7e, 0x71, 0xbd, 0x70, 0x18, 0x8f, 0x05, 0xa6, 0x17, 0xc6, 0x99, 0xda, 0x3c, 0xb2, 0x1d,
		0xaa, 0xcd, 0x00, 0xd4, 0x02, 0x48, 0xcd, 0x00, 0xd5, 0x0a, 0x58, 0xcd, 0x01, 0xd6, 0x1c, 0x68,
		0x2d, 0x01, 0x57, 0x07, 0x78, 0x95, 0x00, 0x78, 0xb6, 0x30, 0xe2, 0x1d, 0xb4, 0x57, 0x9e, 0x96,
		0x8b, 0x7e, 0x3f, 0x76, 0x61, 0xa2, 0x79, 0x5e, 0xa6, 0x56, 0x5f, 0xeb, 0x41, 0x35, 0x36, 0x56,
		0x61, 0x53, 0x1b, 0xdd, 0x28, 0xeb, 0x84, 0x69, 0xd7, 0x40, 0xf1, 0x4d, 0x26, 0x42, 0xe1, 0xa1,
		0xf0, 0x50, 0x78, 0x28, 0x3c, 0x14, 0x1e, 0x0a, 0xcf, 0x87, 0xc2, 0xbb, 0x9f, 0x7c, 0xa4, 0xaf,
		0xf9, 0x16, 0x66, 0x44, 0x35, 0xa1, 0x9a, 0x50, 0x4d, 0xa8, 0xa6, 0xca, 0xa8, 0x26, 0xb9, 0xf2,
		0x1c, 0x3f, 0x54, 0x4d, 0x27, 0x8a, 0x73, 0xac, 0x28, 0xe7, 0x31, 0xfb, 0x9f, 0x58, 0xb5, 0x8e,
		0xaa, 0x6b, 0xc8, 0x2f, 0x79, 0xf0, 0xa9, 0x3f, 0xb0, 0xd0, 0x8c, 0x93, 0x99, 0xd0, 0x88, 0x68,
		0x44, 0x34, 0x22, 0x1a, 0xb1, 0x32, 0x1a, 0x31, 0x1a, 0x04, 0x61, 0xb7, 0x9b, 0xba, 0x2c, 0xb3,
		0x50, 0x8a, 0xa7, 0x8a, 0x73, 0x4c, 0xd6, 0xec, 0xa3, 0xaa, 0xc8, 0xea, 0x1e, 0xf9, 0x7b, 0x3b,
		0xf3, 0xb9, 0x6d, 0xb0, 0x37, 0x0b, 0x7b, 0xf4, 0xd4, 0x60, 0xae, 0xb7, 0x61, 0x9e, 0xbb, 0x34,
		0x51, 0xdf, 0xae, 0xd9, 0x84, 0x0f, 0x1f, 0x7e, 0xdc, 0x0f, 0x4e, 0xcf, 0xbe, 0x7d, 0x6c, 0x05,
		0xa7, 0x67, 0x37, 0x2f, 0x5b, 0xe3, 0xff, 0xdc, 0xbc, 0x3e, 0xf8, 0xb8, 0x1f, 0xb4, 0xa7, 0xaf,
		0x8f, 0x3e, 0xee, 0x07, 0x47, 0x67, 0x8f, 0xfe, 0xf8, 0xe3, 0xc9, 0xa3, 0xbf, 0x0f, 0xaf, 0x37,
		0xff, 0x60, 0x43, 0xfd, 0x91, 0xce, 0x2c, 0xb6, 0xe8, 0xcd, 0xfb, 0x97, 0xff, 0x6d, 0xbe, 0x4f,
		0xff, 0xb6, 0xdc, 0xa8, 0x7f, 0x18, 0xec, 0x94, 0xea, 0x0c, 0xd7, 0x8f, 0x6b, 0x04, 0x76, 0xc7,
		0x80, 0x9d, 0x28, 0xd8, 0x85, 0x41, 0xef, 0x79, 0xf0, 0xeb, 0xd9, 0xdf, 0xad, 0xc7, 0xed, 0xeb,
		0x67, 0x8f, 0xfe, 0x3e, 0xb9, 0xbe, 0xff, 0xe6, 0xb7, 0x65, 0x7f, 0xd6, 0x7a, 0x7c, 0x72, 0xfd,
		0x6c, 0xc5, 0xbf, 0x1c, 0x5f, 0x3f, 0x5b, 0x73, 0x8c, 0xa3, 0xeb, 0x87, 0x0b, 0x7f, 0x3a, 0x7a,
		0xff, 0x60, 0xd5, 0x07, 0xda, 0x2b, 0x3e, 0x70, 0xb8, 0xea, 0x03, 0x87, 0x2b, 0x3e, 0xb0, 0xf2,
		0x2b, 0x1d, 0xac, 0xf8, 0xc0, 0xd1, 0xf5, 0xb7, 0x85, 0xbf, 0x7f, 0xb8, 0xfc, 0x4f, 0x8f, 0xaf,
		0x1f, 0x7d, 0x5b, 0xf5, 0x6f, 0x27, 0xd7, 0xdf, 0x9e, 0x3d, 0x02, 0xfa, 0x8b, 0x43, 0x3f, 0x62,
		0x6b, 0x2f, 0xb6, 0xd5, 0x57, 0x84, 0x0f, 0xaa, 0xf5, 0xbd, 0xab, 0xe1, 0x3f, 0x13, 0xe9, 0x79,
		0xbf, 0xb1, 0x29, 0x20, 0x54, 0x50, 0x11, 0xbf, 0x1a, 0x7e, 0x35, 0xfc, 0x6a, 0xf8, 0xd5, 0x3c,
		0xf9, 0xd5, 0x76, 0x21, 0xd2, 0xb4, 0x71, 0x43, 0xc6, 0x82, 0x5d, 0xc1, 0x3c, 0x68, 0xd5, 0x52,
		0x5f, 0x26, 0x10, 0xaa, 0x81, 0xb3, 0x72, 0x7c, 0xeb, 0xda, 0x38, 0xe3, 0x12, 0x06, 0xe3, 0xff,
		0x6f, 0xde, 0x5c, 0xb6, 0x6c, 0xaa, 0x5c, 0x92, 0xda, 0xb3, 0xad, 0xa2, 0xf3, 0x6e, 0xf4, 0x54,
		0xe3, 0xff, 0x3f, 0x7f, 0x3e, 0x7e, 0xaa, 0x42, 0x75, 0x75, 0xf4, 0x25, 0x55, 0x50, 0x4a, 0x1b,
		0x2e, 0xd1, 0xbd, 0x95, 0x32, 0x83, 0xdb, 0xfb, 0x13, 0x71, 0xad, 0x8e, 0x6b, 0x75, 0xbe, 0xed,
		0x3f, 0xae, 0xd5, 0x99, 0x69, 0x42, 0xb5, 0x6b, 0x75, 0x4a, 0xb7, 0x80, 0x17, 0x0e, 0x93, 0x9a,
		0xa2, 0x53, 0x84, 0x2f, 0x68, 0x2e, 0x34, 0x17, 0x9a, 0x5b, 0x46, 0x9a, 0xab, 0x05, 0x87, 0xb3,
		0x09, 0xa2, 0xae, 0x4b, 0xf2, 0xa8, 0xf7, 0x35, 0x4a, 0x2e, 0x83, 0x81, 0xfe, 0xe1, 0xbc, 0x73,
		0x40, 0x97, 0xcc, 0xad, 0x2c, 0x67, 0xba, 0x5e, 0x42, 0x33, 0x18, 0xb5, 0x84, 0x53, 0x73, 0x58,
		0xb5, 0x86, 0x57, 0x6f, 0x30, 0xeb, 0x0d, 0x6e, 0x7d, 0xc0, 0xae, 0x2e, 0xfc, 0x2a, 0xc3, 0xf0,
		0x6c, 0xc1, 0xd4, 0xbd, 0x8e, 0x8b, 0x18, 0x39, 0x08, 0xcc, 0x84, 0xd1, 0x22, 0xb9, 0xef, 0xfe,
		0x52, 0xda, 0x84, 0xa4, 0x6d, 0x10, 0x64, 0x6f, 0x21, 0xe9, 0xcf, 0x14, 0x47, 0xf6, 0x8c, 0xd3,
		0x61, 0x6e, 0xb5, 0x90, 0x71, 0x82, 0xc1, 0x6c, 0x62, 0xcb, 0x14, 0xb3, 0xe6, 0x64, 0xb2, 0x47,
		0xdf, 0x1e, 0x7e, 0x6c, 0x05, 0x07, 0x67, 0xd3, 0x5f, 0x0e, 0x3f, 0xee, 0x07, 0x07, 0x67, 0x16,
		0x09, 0x23, 0xd3, 0x9f, 0x33, 0xcb, 0xad, 0xf5, 0x91, 0x40, 0x32, 0x9b, 0xfd, 0xdf, 0x65, 0xda,
		0xe0, 0x7f, 0x18, 0xee, 0xb0, 0xc9, 0x4c, 0xd7, 0x8f, 0x6b, 0x8c, 0xbd, 0xc7, 0x60, 0xaf, 0x05,
		0xf6, 0x92, 0xe3, 0x65, 0x9f, 0xe3, 0xd5, 0x7c, 0xd8, 0x1a, 0xe1, 0xd7, 0xd3, 0x1b, 0x48, 0x6b,
		0x9d, 0x2d, 0x20, 0xdd, 0x0d, 0x72, 0xa1, 0x90, 0xd4, 0x14, 0x12, 0x52, 0x5f, 0x5a, 0xa9, 0xaf,
		0x9f, 0x96, 0x26, 0xa1, 0xb3, 0x16, 0x9e, 0x5c, 0xe5, 0x14, 0x8f, 0xd9, 0x3c, 0xfe, 0x53, 0x3d,
		0xee, 0x45, 0xf0, 0x9b, 0xaa, 0x11, 0xb1, 0x3d, 0xdf, 0x29, 0x20, 0x2f, 0x6e, 0x9f, 0xf6, 0xb7,
		0xd4, 0xa9, 0x64, 0x84, 0xe8, 0x09, 0xfc, 0xb5, 0x4a, 0x3e, 0x4e, 0x98, 0x1b, 0x94, 0xb0, 0xb9,
		0x99, 0xa6, 0xe2, 0x61, 0xd6, 0x03, 0xc2, 0xac, 0x3f, 0x9e, 0x88, 0x30, 0xab, 0x98, 0x0e, 0x22,
		0xcc, 0xba, 0x7c, 0x61, 0x08, 0xb3, 0x6a, 0xc0, 0x27, 0x61, 0xd6, 0x12, 0xc3, 0xaa, 0x35, 0xbc,
		0x7a, 0x83, 0x59, 0x6f, 0x70, 0xeb, 0x03, 0x76, 0x6d, 0x58, 0x23, 0x61, 0x56, 0x11, 0xeb, 0x92,
		0x30, 0xab, 0xc4, 0xc6, 0x11, 0x66, 0xd5, 0x9e, 0x98, 0x30, 0xab, 0xfa, 0xd6, 0x12, 0x66, 0x25,
		0xcc, 0x5a, 0x45, 0xec, 0x25, 0xcc, 0x6a, 0x82, 0xbd, 0x04, 0x9c, 0x08, 0xb3, 0x12, 0x66, 0x45,
		0xea, 0x09, 0xb3, 0x56, 0x93, 0x30, 0xef, 0x11, 0x66, 0x35, 0xf2, 0xe4, 0xee, 0x6e, 0x98, 0x55,
		0x33, 0x20, 0xb6, 0x57, 0xb2, 0x28, 0xeb, 0xfb, 0xf1, 0xb3, 0xee, 0x70, 0x90, 0x35, 0x0f, 0xd3,
		0x4b, 0x97, 0x67, 0xfa, 0x61, 0xd6, 0xe9, 0x44, 0xdc, 0x67, 0x5d, 0x6e, 0x27, 0x11, 0x68, 0xdd,
		0x62, 0xd3, 0x09, 0xb4, 0xee, 0xaa, 0x7a, 0x56, 0x0f, 0xb4, 0xde, 0xe0, 0x95, 0x5d, 0x70, 0x75,
		0x32, 0x9f, 0x4d, 0x40, 0xb5, 0x45, 0x40, 0xb5, 0xbc, 0xf0, 0x69, 0x0d, 0xa3, 0xde, 0xe0, 0xd4,
		0x1b, 0xac, 0xfa, 0x80, 0x57, 0x1b, 0x7e, 0xa8, 0x1d, 0x50, 0xd5, 0x86, 0xdd, 0xd9, 0x44, 0xca,
		0x55, 0x56, 0x56, 0x1e, 0x6e, 0xf5, 0x1c, 0x53, 0x0f, 0x70, 0x6c, 0x0e, 0xcb, 0x3e, 0xe0, 0xd9,
		0x1b, 0x4c, 0xfb, 0x82, 0x6b, 0xef, 0xb0, 0xed, 0x1d, 0xbe, 0x7d, 0xc2, 0xb8, 0x0d, 0x9c, 0x1b,
		0xc1, 0xba, 0x39, 0xbc, 0xcf, 0x26, 0xec, 0xba, 0x2c, 0x8f, 0x12, 0x7d, 0x37, 0xdb, 0x77, 0x91,
		0x62, 0xfe, 0x4b, 0x18, 0x4b, 0xae, 0x4d, 0x82, 0xa3, 0x77, 0x45, 0xe0, 0x53, 0x21, 0x78, 0x57,
		0x0c, 0xbe, 0x15, 0x44, 0x69, 0x14, 0x45, 0x69, 0x14, 0x46, 0x19, 0x14, 0x87, 0xad, 0x02, 0x31,
		0x56, 0x24, 0xb3, 0x05, 0x36, 0x4b, 0xc0, 0x5c, 0x79, 0xda, 0x2d, 0x13, 0x32, 0x57, 0xda, 0xf7,
		0xa7, 0x1e, 0xe6, 0x36, 0x4d, 0xd8, 0xbc, 0xff, 0xe3, 0x07, 0xe1, 0xf6, 0xfc, 0x27, 0x74, 0xae,
		0x14, 0x81, 0xa7, 0x1e, 0xbf, 0x83, 0xaf, 0xfc, 0x8b, 0x85, 0x2f, 0xb2, 0x9b, 0x09, 0xa0, 0xf7,
		0x7f, 0xce, 0x7c, 0x8a, 0x82, 0xcf, 0x7c, 0x9c, 0x85, 0x6f, 0xb3, 0xab, 0x09, 0xa3, 0x0b, 0x12,
		0xe1, 0x65, 0xe6, 0xeb, 0xc7, 0x3b, 0xac, 0x1b, 0x8e, 0xd1, 0x0d, 0x65, 0xd4, 0x0d, 0xa4, 0xea,
		0x91, 0xa0, 0x8a, 0xc2, 0xfc, 0x91, 0xc2, 0xe4, 0x94, 0x90, 0xd0, 0x5a, 0x1a, 0x2b, 0xe2, 0x41,
		0xbd, 0x9f, 0xd3, 0xee, 0xf9, 0x0c, 0xed, 0xb1, 0x46, 0xd4, 0xf5, 0xe7, 0x6f, 0x8f, 0xba, 0xb8,
		0xd9, 0x95, 0x95, 0x16, 0x6e, 0x76, 0xdc, 0xec, 0xb8, 0xd9, 0xbd, 0x69, 0xa9, 0xdd, 0x73, 0xb3,
		0x67, 0x79, 0x1a, 0x25, 0x97, 0x3e, 0x7d, 0xec, 0x4f, 0xb1, 0x0a, 0x8a, 0x5b, 0x05, 0x83, 0x20,
		0xcf, 0x63, 0x8f, 0x96, 0xc1, 0xcd, 0xfc, 0x58, 0x07, 0x58, 0x07, 0x58, 0x07, 0x58, 0x07, 0x58,
		0x07, 0x35, 0xb1, 0x0e, 0x86, 0x51, 0x92, 0x3f, 0xf5, 0x68, 0x1c, 0x1c, 0x79, 0x98, 0xfa, 0x5d,
		0x98, 0x5c, 0xee, 0x64, 0x00, 0xfe, 0x75, 0x94, 0x78, 0x83, 0x57, 0xcf, 0x3a, 0x7d, 0xe1, 0x6b,
		0xfc, 0x57, 0x18, 0x0f, 0x5d, 0x09, 0xbe, 0xc7, 0xaf, 0xe9, 0xcd, 0x65, 0xdf, 0x5f, 0xa2, 0xcb,
		0x68, 0x7c, 0xdb, 0x73, 0xdf, 0xdb, 0xf7, 0xb9, 0xf6, 0xe8, 0xcc, 0x7f, 0x1d, 0x7e, 0x41, 0x34,
		0xef, 0x89, 0xe6, 0xc1, 0xd1, 0x11, 0xc2, 0xe9, 0xc7, 0x10, 0xf0, 0x37, 0x2b, 0x2e, 0xf4, 0xe2,
		0x62, 0x9b, 0x79, 0xba, 0xef, 0x31, 0x73, 0xb9, 0xdc, 0xcc, 0x0f, 0x59, 0x86, 0x2c, 0x43, 0x96,
		0x21, 0xcb, 0x90, 0xe5, 0x9a, 0x90, 0xe5, 0x68, 0x10, 0x84, 0xdd, 0x6e, 0xea, 0xb2, 0x8c, 0x94,
		0xf5, 0xdd, 0x60, 0xcc, 0x77, 0x52, 0xd6, 0xfd, 0xed, 0xfd, 0x82, 0x0c, 0x90, 0x97, 0x68, 0x9c,
		0xb3, 0x4e, 0x8a, 0xdd, 0x8e, 0xe5, 0xa4, 0x93, 0x73, 0xbe, 0x4b, 0xe0, 0x7e, 0x0c, 0xb8, 0x97,
		0x12, 0xdc, 0x49, 0xa7, 0xb5, 0x4f, 0xa7, 0x45, 0xd5, 0x91, 0x4d, 0xbe, 0xc3, 0xe2, 0x4f, 0x9a,
		0x78, 0xcd, 0x9e, 0xf3, 0x9a, 0x92, 0x33, 0xdb, 0x39, 0xb4, 0x6c, 0xea, 0x2c, 0x2f, 0xcc, 0x5b,
		0xbe, 0xba, 0xcb, 0x93, 0x0a, 0xb9, 0x93, 0xff, 0x36, 0x4d, 0x2b, 0x91, 0xed, 0x95, 0xac, 0x2e,
		0xf3, 0x87, 0x9b, 0xb5, 0x98, 0xfc, 0x57, 0xb5, 0x19, 0xae, 0xfd, 0xf1, 0x32, 0x38, 0x5a, 0x96,
		0xf7, 0x3b, 0xec, 0xef, 0x75, 0x18, 0x07, 0xa1, 0xa8, 0x9b, 0xa7, 0x3a, 0x31, 0x75, 0xf3, 0xa8,
		0x9b, 0x57, 0x71, 0x23, 0xc6, 0x3c, 0x68, 0x34, 0x3b, 0xad, 0xb1, 0x0b, 0x7b, 0xa9, 0xeb, 0xf9,
		0x68, 0x9b, 0x75, 0x62, 0xdb, 0x36, 0x6b, 0x6c, 0xa7, 0x3d, 0x79, 0x32, 0xb1, 0x8b, 0x9a, 0x51,
		0x17, 0x73, 0x60, 0x13, 0xd3, 0x4e, 0xb3, 0x97, 0xfe, 0x4a, 0xe9, 0xd4, 0x6e, 0x25, 0xb2, 0x54,
		0x2e, 0xad, 0x8d, 0x82, 0x03, 0x8c, 0x02, 0x8c, 0x02, 0x8c, 0x02, 0x8c, 0x82, 0x7b, 0x0b, 0x49,
		0x31, 0x5d, 0x52, 0x13, 0xeb, 0xa6, 0x10, 0xbc, 0x2b, 0x06, 0xdf, 0x0a, 0xa2, 0x34, 0x8a, 0xa2,
		0x34, 0x0a, 0xa3, 0x0c, 0x8a, 0xc3, 0x56, 0x81, 0x18, 0x2b, 0x12, 0x7f, 0x2c, 0x73, 0xe1, 0xb4,
		0x53, 0x4c, 0xd7, 0xc7, 0xc9, 0xa2, 0x98, 0xee, 0x7d, 0x11, 0x20, 0x77, 0x85, 0x62, 0xba, 0x93,
		0x1f, 0xb2, 0x39, 0xa6, 0xdf, 0x86, 0x62, 0xba, 0x13, 0x89, 0x20, 0xb1, 0xd1, 0x5a, 0x37, 0x50,
		0x4c, 0xb7, 0x94, 0xba, 0x81, 0xc4, 0x2e, 0x8a, 0xe9, 0xa2, 0x30, 0x7f, 0xa4, 0x30, 0x39, 0x25,
		0x14, 0xd3, 0x2d, 0x8d, 0x15, 0x41, 0x96, 0x64, 0xf5, 0xec, 0x31, 0x8a, 0xe9, 0x5a, 0x4c, 0x8b,
		0x9b, 0x1d, 0x37, 0x3b, 0x6e, 0x76, 0xdc, 0xec, 0x56, 0xbe, 0x5e, 0x8a, 0xe9, 0x62, 0x15, 0x14,
		0xb3, 0x0a, 0x28, 0xa6, 0x8b, 0x75, 0x80, 0x75, 0x80, 0x75, 0x80, 0x75, 0x80, 0x75, 0x20, 0x78,
		0xda, 0x29, 0xa6, 0x6b, 0xfd, 0x43, 0x31, 0x5d, 0x8a, 0xe9, 0xce, 0x7d, 0x0f, 0x8a, 0xe9, 0xee,
		0x51, 0x4c, 0x77, 0xb9, 0x68, 0x52, 0x4c, 0xd7, 0x9b, 0x21, 0xe0, 0x6f, 0x56, 0x5c, 0xe8, 0xc5,
		0xc5, 0x96, 0x62, 0xba, 0x90, 0x65, 0xc8, 0x32, 0x64, 0x19, 0xb2, 0x0c, 0x59, 0x96, 0x3c, 0xed,
		0x14, 0xd3, 0xa5, 0x98, 0x2e, 0xf5, 0x16, 0x29, 0xa6, 0x6b, 0x4b, 0x08, 0x48, 0xb1, 0x9b, 0x7c,
		0x1b, 0x8a, 0xe9, 0xd6, 0xd0, 0xfb, 0x43, 0x31, 0x5d, 0xc0, 0x7d, 0x35, 0xb8, 0x93, 0x4e, 0x4b,
		0x31, 0xdd, 0x1d, 0x56, 0x75, 0x88, 0x3f, 0xc5, 0x74, 0x6b, 0xe6, 0x35, 0xd8, 0xa3, 0x98, 0x6e,
		0x35, 0x0c, 0x35, 0x8a, 0xe9, 0xae, 0x2a, 0xa6, 0x6b, 0x59, 0x88, 0x6c, 0xaf, 0xdc, 0xb5, 0x74,
		0xdf, 0x8f, 0x97, 0xa2, 0x2e, 0xb5, 0xf3, 0x1e, 0x54, 0xf8, 0xd8, 0x36, 0xfe, 0xe9, 0xbe, 0x9a,
		0x5c, 0xe1, 0x68, 0xbc, 0x8a, 0xb2, 0xfc, 0x79, 0x9e, 0xdb, 0xd4, 0xa3, 0x6a, 0xbc, 0x8e, 0x92,
		0x17, 0xb1, 0xbb, 0x72, 0xc9, 0x4d, 0xfc, 0xd9, 0xa0, 0xbc, 0xe1, 0xeb, 0xf0, 0xcb, 0xdc, 0x8c,
		0xad, 0xa7, 0xed, 0xf6, 0xf1, 0x49, 0xbb, 0xbd, 0x7f, 0x72, 0x78, 0xb2, 0x7f, 0x7a, 0x74, 0xd4,
		0x3a, 0x6e, 0x19, 0x44, 0xe5, 0x1b, 0x6f, 0xd2, 0xae, 0x4b, 0x5d, 0xf7, 0xa7, 0xd1, 0x9e, 0x26,
		0xc3, 0x38, 0xae, 0xb4, 0x68, 0x1a, 0x6b, 0x92, 0xd2, 0x6b, 0x90, 0x86, 0x49, 0x91, 0xce, 0x92,
		0xea, 0x0c, 0x5d, 0x6d, 0xa1, 0x87, 0xe1, 0x3a, 0x23, 0x2b, 0x1d, 0x3d, 0xab, 0x23, 0x57, 0xde,
		0xa3, 0xa6, 0x78, 0xc6, 0x4a, 0x78, 0xb6, 0x74, 0x0e, 0x95, 0xbc, 0xc8, 0xcb, 0x8e, 0x28, 0x7c,
		0x78, 0xb4, 0x0f, 0x4d, 0xf9, 0x0e, 0x8b, 0xc2, 0x21, 0x29, 0xd1, 0xe1, 0x90, 0x3d, 0x14, 0x72,
		0xa2, 0x2b, 0x28, 0xb6, 0x4a, 0xb5, 0xb8, 0x55, 0x6b, 0x6e, 0x2b, 0xd5, 0xd6, 0x56, 0xab, 0xa1,
		0xad, 0x99, 0x68, 0xa6, 0x9e, 0x48, 0xa6, 0x9d, 0x28, 0x66, 0x96, 0x08, 0x66, 0x96, 0xe8, 0x65,
		0x91, 0xc8, 0x55, 0x6e, 0x35, 0xa8, 0x55, 0x6b, 0xba, 0xd1, 0x75, 0x77, 0xb5, 0x8f, 0x9a, 0x50,
		0xde, 0xd6, 0x8f, 0xd6, 0x56, 0x77, 0x37, 0x0b, 0xe6, 0x7a, 0xe1, 0x30, 0x1e, 0x0b, 0x4c, 0x2f,
		0x8c, 0x33, 0xb5, 0x79, 0x74, 0x33, 0x7c, 0xd5, 0x33, 0x79, 0x2d, 0x32, 0x76, 0xcd, 0x32, 0x73,
		0xad, 0x32, 0x70, 0xcd, 0x33, 0x6d, 0xcd, 0x33, 0x6a, 0x2d, 0x33, 0x67, 0xab, 0x45, 0xe2, 0xd5,
		0x33, 0x5e, 0x67, 0xa7, 0xe5, 0xa2, 0xdf, 0x8f, 0x5d, 0xa8, 0x59, 0x64, 0x7f, 0x66, 0xf5, 0xb5,
		0xaa, 0x42, 0x55, 0x15, 0x8c, 0xb1, 0x6e, 0x94, 0x75, 0xc2, 0xb4, 0x6b, 0xa0, 0xf8, 0x26, 0x13,
		0xa1, 0xf0, 0x50, 0x78, 0x28, 0x3c, 0x14, 0x1e, 0x0a, 0x0f, 0x85, 0xe7, 0x43, 0xe1, 0xdd, 0x77,
		0x5a, 0xea, 0x6b, 0xbe, 0x85, 0x19, 0x51, 0x4d, 0xa8, 0x26, 0x54, 0x13, 0xaa, 0xa9, 0x32, 0xaa,
		0x49, 0xbf, 0x0b, 0xab, 0x45, 0xd7, 0xd5, 0xf9, 0x2e, 0xab, 0x4b, 0xff, 0x37, 0x69, 0xbd, 0x3a,
		0x0e, 0x14, 0xed, 0xb4, 0x86, 0xfc, 0x92, 0x07, 0x9f, 0xfa, 0x03, 0x0b, 0xcd, 0x38, 0x99, 0x09,
		0x8d, 0x88, 0x46, 0x44, 0x23, 0xa2, 0x11, 0x2b, 0xa3, 0x11, 0x4d, 0xee, 0xdd, 0x5b, 0xdc, 0xaf,
		0xb7, 0xb9, 0x47, 0x6f, 0x90, 0x61, 0xe9, 0xe9, 0x5e, 0xbc, 0xe5, 0x15, 0x49, 0xf3, 0xab, 0x90,
		0x35, 0xbb, 0xcf, 0x7e, 0x66, 0xb1, 0x45, 0x3e, 0x2e, 0xed, 0xd5, 0xee, 0x1e, 0xfa, 0x59, 0x95,
		0x93, 0xcb, 0x6d, 0xc1, 0xee, 0x18, 0xb0, 0x13, 0x05, 0x3b, 0x2e, 0xb8, 0xd6, 0xf1, 0x7e, 0x77,
		0xed, 0xa1, 0x1f, 0xb1, 0xad, 0xe5, 0xbd, 0xec, 0xb3, 0x8a, 0x5e, 0x4d, 0x39, 0xdb, 0x61, 0xff,
		0xd9, 0x20, 0xcc, 0x3f, 0x05, 0x99, 0x8b, 0xdd, 0x38, 0x03, 0x3c, 0xb8, 0x4c, 0xfb, 0x43, 0x03,
		0x5f, 0xda, 0xd2, 0x59, 0xf1, 0xab, 0xe1, 0x57, 0xc3, 0xaf, 0x86, 0x5f, 0xad, 0x32, 0x7e, 0xb5,
		0x5d, 0x88, 0x34, 0x2d, 0x43, 0xea, 0x6c, 0xe9, 0xbb, 0xd3, 0x88, 0xd4, 0xf8, 0x97, 0x20, 0xea,
		0x72, 0xa7, 0x4e, 0xe4, 0x98, 0xd7, 0xfe, 0x4e, 0x9d, 0x56, 0x39, 0x10, 0xaf, 0x37, 0xe9, 0x14,
		0x0a, 0x7b, 0x08, 0x5e, 0xa0, 0x7b, 0x50, 0x22, 0x49, 0xd7, 0x92, 0x70, 0xff, 0x92, 0xdd, 0x10,
		0xbd, 0xa7, 0xe8, 0x4d, 0x96, 0x65, 0xa4, 0xb8, 0xb8, 0xcc, 0x09, 0xc8, 0x5b, 0xa3, 0x33, 0x35,
		0xd6, 0x65, 0xe4, 0x6c, 0x66, 0x09, 0x4c, 0xc6, 0x15, 0x3a, 0x11, 0xb2, 0x17, 0x3c, 0xc5, 0x19,
		0x8a, 0x06, 0x23, 0x51, 0x63, 0x20, 0x5a, 0x8c, 0x43, 0x9d, 0x61, 0xa8, 0x33, 0x0a, 0x4d, 0x06,
		0x51, 0x2e, 0x0d, 0x23, 0x7d, 0x21, 0xb3, 0x91, 0xb9, 0xff, 0x1d, 0xba, 0xa4, 0xe3, 0x02, 0x85,
		0x66, 0xe3, 0xb7, 0x77, 0xc7, 0xe7, 0x26, 0xd1, 0xb9, 0x41, 0xbe, 0xaf, 0x75, 0x83, 0x7c, 0x9f,
		0x1b, 0xe4, 0x66, 0x2e, 0x0f, 0x6e, 0x90, 0xd7, 0x8f, 0xf4, 0xa9, 0xb9, 0x30, 0xee, 0xf4, 0xad,
		0x3c, 0x3c, 0xd0, 0x10, 0xf7, 0x09, 0xb6, 0x28, 0x38, 0x2c, 0x94, 0x1b, 0x4f, 0x2a, 0x3a, 0x8c,
		0x2c, 0x1a, 0x47, 0x1a, 0xf5, 0xaf, 0xb2, 0x6a, 0xfc, 0x68, 0xd9, 0x3b, 0x4f, 0x31, 0xc5, 0xc2,
		0xa4, 0x31, 0xa3, 0xf5, 0xd6, 0xb7, 0x0f, 0x4e, 0xdb, 0xa7, 0xc7, 0x27, 0x07, 0xa7, 0x47, 0x35,
		0x92, 0x81, 0x8a, 0x78, 0x2b, 0xcf, 0xf0, 0x29, 0xed, 0xa6, 0x4f, 0x49, 0xd4, 0xc5, 0xe0, 0xcf,
		0xa7, 0x34, 0xe1, 0x08, 0x35, 0xf2, 0x29, 0x45, 0x83, 0xcf, 0x6d, 0x79, 0x8f, 0xd2, 0x78, 0x54,
		0xfc, 0x49, 0x22, 0xb4, 0xee, 0xcf, 0x3c, 0xb8, 0x0a, 0xf3, 0xce, 0x27, 0xdc, 0x4a, 0x3e, 0xdc,
		0x4a, 0xb3, 0xd5, 0xc7, 0xbb, 0xb4, 0xde, 0x80, 0xc2, 0x4e, 0xea, 0x85, 0x23, 0x21, 0xae, 0x49,
		0xf6, 0x2c, 0xaa, 0x12, 0x56, 0xd5, 0xa7, 0xa4, 0x00, 0x3e, 0xb8, 0x96, 0x4a, 0x0c, 0x4e, 0xd5,
		0xf0, 0x30, 0x29, 0xd6, 0x28, 0xcc, 0xf2, 0x28, 0x19, 0x9b, 0xde, 0xb3, 0x5c, 0x7f, 0x83, 0x3a,
		0x85, 0x8b, 0x93, 0x92, 0x4d, 0x68, 0x0d, 0x7b, 0xd6, 0xf0, 0x67, 0x05, 0x83, 0xe6, 0x70, 0x68,
		0x0e, 0x8b, 0x1e, 0xe0, 0x51, 0xd9, 0xef, 0x52, 0x83, 0x3b, 0xbb, 0x9f, 0xdb, 0x81, 0xba, 0x94,
		0x59, 0xdc, 0x91, 0x32, 0xbb, 0x1b, 0x65, 0x7a, 0x01, 0xb4, 0x39, 0x99, 0xec, 0xd1, 0xb7, 0x87,
		0x1f, 0x5b, 0xc1, 0xc1, 0xd9, 0xf4, 0x97, 0xc3, 0x8f, 0xfb, 0xc1, 0xc1, 0x99, 0xe6, 0x2d, 0xa1,
		0x33, 0xcd, 0xad, 0xb2, 0xbc, 0x15, 0x64, 0x7b, 0x11, 0xf4, 0x47, 0x1b, 0xa6, 0x78, 0x3f, 0x66,
		0x97, 0xef, 0x97, 0x74, 0xb3, 0x8e, 0xc1, 0x7d, 0x92, 0xf1, 0x2c, 0x58, 0x7c, 0x58, 0x7c, 0x58,
		0x7c, 0x58, 0x7c, 0x15, 0xb5, 0xf8, 0x14, 0x31, 0x6c, 0x1e, 0xc7, 0x14, 0x63, 0xb6, 0xca, 0x09,
		0x1a, 0xd3, 0x1f, 0x9b, 0xae, 0x89, 0x66, 0x4d, 0x5b, 0x8d, 0xa2, 0xf7, 0xb3, 0xe9, 0x8c, 0x12,
		0x38, 0x66, 0xf3, 0x19, 0x06, 0xf1, 0x95, 0xc1, 0xe0, 0xae, 0x88, 0x18, 0x24, 0x76, 0xf8, 0x16,
		0x91, 0xe3, 0xc3, 0x1a, 0xcb, 0x08, 0x97, 0xd5, 0x2b, 0x47, 0x26, 0x3e, 0xf5, 0x07, 0x41, 0x1c,
		0x5d, 0x45, 0xb9, 0x3e, 0xa3, 0xb8, 0x9d, 0x0a, 0x5a, 0x01, 0xad, 0x80, 0x56, 0x40, 0x2b, 0x2a,
		0x4a, 0x2b, 0x86, 0x51, 0x92, 0x3f, 0x85, 0x57, 0xc0, 0x2b, 0xe0, 0x15, 0xf0, 0x8a, 0x92, 0x88,
		0xc8, 0xc1, 0xd1, 0x11, 0xc4, 0x02, 0x62, 0x51, 0x1e, 0x62, 0x31, 0x48, 0xfb, 0x79, 0xbf, 0xd3,
		0x8f, 0x0d, 0x2a, 0x5f, 0x4d, 0x67, 0x82, 0x56, 0x40, 0x2b, 0xa0, 0x15, 0xd0, 0x8a, 0x8a, 0xd2,
		0x8a, 0x68, 0x10, 0x4c, 0xa1, 0x2c, 0xc8, 0x47, 0xb3, 0x52, 0x59, 0xbe, 0x14, 0x0c, 0xc3, 0x8a,
		0xf6, 0x19, 0xd2, 0x3f, 0x63, 0x1a, 0x68, 0xb7, 0x59, 0x5e, 0x68, 0xa1, 0x27, 0xdb, 0xdf, 0x17,
		0x4d, 0xf4, 0xc9, 0x04, 0x0c, 0x69, 0xa3, 0x17, 0xfa, 0x58, 0x16, 0x51, 0x3a, 0x38, 0x6a, 0xef,
		0x90, 0x30, 0x3d, 0xa8, 0xc7, 0x2c, 0x74, 0x4d, 0x58, 0xd3, 0xd0, 0xea, 0xba, 0x24, 0x8f, 0xf2,
		0xaf, 0xba, 0x85, 0x46, 0x17, 0x6c, 0x2d, 0x0b, 0x7d, 0xfe, 0x72, 0xf2, 0x68, 0x3f, 0x85, 0x99,
		0xb3, 0xf3, 0x79, 0x4d, 0x17, 0xf6, 0xe5, 0xdb, 0xf3, 0xb7, 0xef, 0xde, 0x7c, 0x78, 0xf3, 0xf3,
		0x9b, 0x57, 0x0d, 0x4b, 0xff, 0x57, 0x66, 0x66, 0xc1, 0xd8, 0x5a, 0x31, 0xf7, 0x17, 0xf7, 0xc3,
		0xcf, 0x6f, 0x1b, 0x75, 0x54, 0xb1, 0xfe, 0x56, 0xf4, 0xed, 0xcb, 0xd7, 0xac, 0xa8, 0xe8, 0x8a,
		0x3e, 0xff, 0xd7, 0x87, 0xff, 0x64, 0x49, 0x45, 0x97, 0xf4, 0x5f, 0xbf, 0x70, 0xec, 0x65, 0x57,
		0xf4, 0xe5, 0xcf, 0xaf, 0x59, 0x52, 0xd9, 0x25, 0x7d, 0x75, 0xf0, 0x81, 0x25, 0x15, 0x96, 0xd2,
		0xdf, 0x90, 0x52, 0xe1, 0x25, 0x7d, 0xf7, 0xfe, 0xbf, 0x58, 0x52, 0xd9, 0x25, 0xfd, 0xed, 0xdd,
		0x8b, 0x46, 0xcd, 0xa8, 0xfa, 0x19, 0x11, 0x6d, 0xd3, 0x95, 0xa9, 0x46, 0x44, 0x3b, 0x1b, 0xc7,
		0x1c, 0xed, 0x4a, 0x30, 0xdc, 0x9b, 0x8f, 0xe8, 0xf6, 0xd2, 0x09, 0x88, 0x6e, 0x17, 0xd8, 0x7b,
		0xa2, 0xdb, 0x15, 0xc1, 0x5e, 0xaa, 0x2f, 0x6c, 0x06, 0x67, 0x54, 0x5f, 0xa0, 0xfa, 0x02, 0xd5,
		0x17, 0x76, 0xde, 0x0a, 0xa4, 0x0f, 0x99, 0x9f, 0xca, 0xba, 0x23, 0xb0, 0x6f, 0xaa, 0x14, 0x45,
		0xdc, 0xf3, 0x56, 0x66, 0xf7, 0xe5, 0xe0, 0x73, 0x5b, 0xb4, 0xd6, 0xae, 0xbc, 0x94, 0x5e, 0x8b,
		0x96, 0x32, 0x0e, 0x73, 0xa7, 0xd8, 0x8a, 0x45, 0xa1, 0x45, 0x9d, 0x7a, 0xc1, 0xcc, 0x03, 0x0a,
		0x66, 0x5a, 0x73, 0x15, 0x0a, 0x66, 0xd6, 0x56, 0xff, 0x51, 0x30, 0x13, 0x97, 0x0d, 0x2e, 0x1b,
		0x5c, 0x36, 0xb8, 0x6c, 0x70, 0xd9, 0xe0, 0xb2, 0xc1, 0x65, 0x83, 0xcb, 0x06, 0x97, 0x0d, 0x05,
		0x33, 0xb1, 0xf8, 0xb0, 0xf8, 0xb0, 0xf8, 0xb0, 0xf8, 0xbc, 0x58, 0x7c, 0x14, 0xcc, 0x5c, 0xf3,
		0x87, 0xc2, 0x36, 0x85, 0xa6, 0xa3, 0xb0, 0x8d, 0x8c, 0x88, 0x50, 0x30, 0xb3, 0xda, 0x32, 0x42,
		0x16, 0x60, 0xe5, 0xc8, 0x04, 0x05, 0x33, 0xa1, 0x15, 0xd0, 0x0a, 0x68, 0x05, 0xb4, 0x62, 0xfd,
		0xb3, 0x43, 0xc1, 0x4c, 0x78, 0x05, 0xbc, 0x02, 0x5e, 0x51, 0x26, 0x11, 0xa1, 0x60, 0x26, 0xc4,
		0xa2, 0x54, 0xc4, 0x82, 0x82, 0x99, 0xd0, 0x0a, 0x68, 0x05, 0xb4, 0x02, 0x5a, 0xb1, 0xee, 0xd9,
		0xa1, 0x60, 0x66, 0x39, 0x19, 0x06, 0x05, 0x33, 0xab, 0xb3, 0x59, 0x5e, 0x68, 0xa1, 0x27, 0xdb,
		0xdf, 0x17, 0x4d, 0xf4, 0xc9, 0x04, 0x0c, 0x69, 0xa3, 0x17, 0xfa, 0x58, 0x16, 0x51, 0xa2, 0x60,
		0x66, 0x05, 0x67, 0xa1, 0x60, 0xe6, 0x9a, 0x86, 0x16, 0x05, 0x33, 0x75, 0x16, 0x96, 0x82, 0x99,
		0xba, 0x8b, 0x4b, 0xc1, 0x4c, 0x71, 0x71, 0xa5, 0x60, 0xa6, 0xf0, 0x8a, 0x52, 0x30, 0x53, 0x7c,
		0x49, 0x29, 0x98, 0x29, 0xbd, 0xa2, 0x14, 0xcc, 0x14, 0x5f, 0x52, 0x0a, 0x66, 0xca, 0x4b, 0x29,
		0x05, 0x33, 0xa5, 0x97, 0x94, 0x82, 0x99, 0xe2, 0x4b, 0x4a, 0xc1, 0xcc, 0xd2, 0x3d, 0x07, 0x11,
		0x6d, 0x0a, 0x66, 0x6e, 0xe8, 0x9d, 0x20, 0xba, 0xbd, 0xc6, 0x8e, 0x10, 0xdd, 0x2e, 0x38, 0x21,
		0xd1, 0xed, 0x72, 0x59, 0x12, 0x54, 0x5f, 0xd8, 0x0a, 0x72, 0xa8, 0xbe, 0x20, 0x6a, 0x53, 0x50,
		0x7d, 0x81, 0xea, 0x0b, 0x14, 0xcc, 0x94, 0xb7, 0x57, 0x3d, 0x17, 0xcc, 0xd4, 0xa8, 0x89, 0xb8,
		0xe7, 0xb7, 0x5e, 0xe6, 0xfb, 0xf1, 0x23, 0x95, 0xb5, 0x5c, 0xe6, 0x83, 0x12, 0x49, 0xb9, 0x96,
		0x74, 0xfb, 0x96, 0xea, 0x86, 0x68, 0x4d, 0x52, 0x4f, 0x72, 0x2c, 0x23, 0xc1, 0xc5, 0xe5, 0x4d,
		0x40, 0xd6, 0x46, 0x76, 0xe5, 0xb1, 0x98, 0x84, 0xcd, 0x5b, 0xab, 0xc7, 0x42, 0x5b, 0x2d, 0x5c,
		0xc6, 0x55, 0x9c, 0x51, 0x6b, 0x30, 0x68, 0x6d, 0xc6, 0xac, 0xc5, 0x90, 0xd5, 0x19, 0xb1, 0x3a,
		0x03, 0x36, 0x60, 0xbc, 0xe5, 0xd2, 0x33, 0xd2, 0x65, 0x57, 0x1b, 0x9d, 0xe9, 0xf9, 0x52, 0x2a,
		0x15, 0xad, 0x52, 0x47, 0x5c, 0xbd, 0x56, 0xf4, 0x3e, 0xb5, 0xa2, 0xad, 0xdd, 0x74, 0xd4, 0x8a,
		0xae, 0x2d, 0xf5, 0xa3, 0x56, 0x74, 0x31, 0x98, 0x23, 0x5a, 0xe1, 0x1f, 0xfe, 0xac, 0x60, 0xd0,
		0x1c, 0x0e, 0xcd, 0x61, 0xd1, 0x03, 0x3c, 0xea, 0xf9, 0xdc, 0xf6, 0xea, 0x12, 0xad, 0x38, 0x26,
		0x5a, 0xb1, 0xd9, 0x44, 0x37, 0xfe, 0xe8, 0x30, 0xe8, 0x3d, 0x0f, 0x7e, 0x3d, 0xfb, 0xbb, 0xf5,
		0xb8, 0x7d, 0xfd, 0xec, 0xd1, 0xdf, 0x27, 0xd7, 0xf7, 0xdf, 0xfc, 0xb6, 0xec, 0xcf, 0x5a, 0x8f,
		0x4f, 0xae, 0x9f, 0xad, 0xf8, 0x97, 0xe3, 0xeb, 0x67, 0x6b, 0x8e, 0x71, 0x74, 0xfd, 0x70, 0xe1,
		0x4f, 0x47, 0xef, 0x1f, 0xac, 0xfa, 0x40, 0x7b, 0xc5, 0x07, 0x0e, 0x57, 0x7d, 0xe0, 0x70, 0xc5,
		0x07, 0x56, 0x7e, 0xa5, 0x83, 0x15, 0x1f, 0x38, 0xba, 0xfe, 0xb6, 0xf0, 0xf7, 0x0f, 0x97, 0xff,
		0xe9, 0xf1, 0xf5, 0xa3, 0x6f, 0xab, 0xfe, 0xed, 0xe4, 0xfa, 0xdb, 0xb3, 0x47, 0x8f, 0x9a, 0x0f,
		0x5b, 0x07, 0x1f, 0xf7, 0x83, 0xa7, 0x37, 0x41, 0x83, 0xd6, 0xd9, 0x42, 0x2c, 0xe1, 0x26, 0x36,
		0x40, 0x08, 0xe7, 0xc7, 0xb3, 0xfd, 0x1b, 0x29, 0x2e, 0xb9, 0x14, 0x13, 0xd7, 0xd2, 0xa9, 0x2a,
		0x3e, 0x67, 0xc4, 0xf7, 0xe2, 0xfe, 0x5f, 0x41, 0x1c, 0x5e, 0xb8, 0xd8, 0x96, 0x3c, 0xcc, 0xcd,
		0x0b, 0x7f, 0x80, 0x3f, 0xc0, 0x1f, 0xe0, 0x0f, 0x55, 0xe6, 0x0f, 0xea, 0x70, 0x36, 0x0f, 0x69,
		0x27, 0x14, 0x0b, 0xfc, 0xf1, 0x83, 0x50, 0x2c, 0x50, 0x6e, 0x3e, 0x8a, 0x05, 0x56, 0x56, 0x44,
		0x5a, 0xfb, 0xed, 0xa7, 0x47, 0x27, 0x14, 0x0c, 0x2c, 0xdd, 0xe8, 0xb4, 0x35, 0xa2, 0xad, 0x11,
		0xe4, 0x02, 0x72, 0x01, 0xb9, 0x80, 0x5c, 0x78, 0xc1, 0xb0, 0x3d, 0xca, 0x8f, 0xc3, 0x28, 0x60,
		0x14, 0x30, 0x8a, 0x0d, 0x45, 0x84, 0xb6, 0x46, 0x90, 0x89, 0x32, 0x91, 0x09, 0xda, 0x1a, 0x41,
		0x2b, 0xa0, 0x15, 0xd0, 0x0a, 0x68, 0xc5, 0xfa, 0x67, 0x87, 0xb6, 0x46, 0xf0, 0x0a, 0x78, 0x05,
		0xbc, 0xa2, 0x4c, 0x22, 0x42, 0x5b, 0x23, 0x88, 0x45, 0xa9, 0x88, 0x05, 0x6d, 0x8d, 0xa0, 0x15,
		0xd0, 0x0a, 0x68, 0x05, 0xb4, 0x62, 0xdd, 0xb3, 0x43, 0x5b, 0xa3, 0x72, 0x32, 0x0c, 0xda, 0x1a,
		0x55, 0x67, 0xb3, 0xbc, 0xd0, 0x42, 0x4f, 0xb6, 0xbf, 0x2f, 0x9a, 0xe8, 0x93, 0x09, 0x18, 0xd2,
		0x46, 0x2f, 0xf4, 0xb1, 0x2c, 0xa2, 0x44, 0x5b, 0xa3, 0x0a, 0xce, 0x42, 0x5b, 0xa3, 0x35, 0x0d,
		0x2d, 0xda, 0x1a, 0xe9, 0x2c, 0x2c, 0x6d, 0x8d, 0x74, 0x17, 0x97, 0xb6, 0x46, 0xe2, 0xe2, 0x4a,
		0x5b, 0x23, 0xe1, 0x15, 0xa5, 0xad, 0x91, 0xf8, 0x92, 0xd2, 0xd6, 0x48, 0x7a, 0x45, 0x69, 0x6b,
		0x24, 0xbe, 0xa4, 0xb4, 0x35, 0x92, 0x97, 0x52, 0xda, 0x1a, 0x49, 0x2f, 0x29, 0x6d, 0x8d, 0xc4,
		0x97, 0x94, 0xb6, 0x46, 0xa5, 0x7b, 0x0e, 0x22, 0xda, 0xb4, 0x35, 0xda, 0xd0, 0x3b, 0x41, 0x74,
		0x7b, 0x8d, 0x1d, 0x21, 0xba, 0x5d, 0x70, 0x42, 0xa2, 0xdb, 0xe5, 0xb2, 0x24, 0x28, 0x14, 0xb8,
		0x15, 0xe4, 0x50, 0x28, 0x90, 0x12, 0x6b, 0x14, 0x0a, 0x5c, 0x73, 0x36, 0x0a, 0x05, 0x52, 0x28,
		0x70, 0x97, 0xf9, 0x82, 0x65, 0x8d, 0xc0, 0xc5, 0x29, 0x61, 0x0d, 0xb0, 0x06, 0x58, 0x03, 0xac,
		0xa1, 0xca, 0xac, 0x81, 0xf2, 0x80, 0x25, 0x73, 0x05, 0x73, 0xe9, 0x4e, 0x70, 0x3e, 0x2e, 0xdd,
		0x55, 0x56, 0x44, 0x28, 0x0f, 0x58, 0xd2, 0xd1, 0xe9, 0xbb, 0x2b, 0x62, 0x06, 0xd5, 0xba, 0xef,
		0xee, 0x71, 0x53, 0xa5, 0xc1, 0xdc, 0x9e, 0xcf, 0x86, 0xa5, 0xc7, 0xe7, 0x13, 0xe6, 0x54, 0xd6,
		0xce, 0xbb, 0xa2, 0x4d, 0x61, 0xc3, 0xdc, 0xe9, 0x75, 0x1f, 0xd4, 0x68, 0xca, 0xac, 0xde, 0x7c,
		0xf0, 0x80, 0xe6, 0x83, 0xd6, 0xb4, 0x98, 0xe6, 0x83, 0xb5, 0xd5, 0x7f, 0x34, 0x1f, 0x2c, 0xa5,
		0x39, 0x8e, 0x77, 0xb0, 0x84, 0x30, 0x68, 0x0e, 0x87, 0xe6, 0xb0, 0xe8, 0x01, 0x1e, 0x75, 0x89,
		0x12, 0x39, 0x05, 0x1b, 0x5a, 0x6d, 0xe4, 0x14, 0x10, 0x8d, 0x25, 0xa7, 0x60, 0x85, 0xfc, 0x92,
		0x53, 0x80, 0x14, 0x93, 0x53, 0xa0, 0xac, 0x5f, 0x69, 0x3e, 0x08, 0x7f, 0x80, 0x3f, 0xc0, 0x1f,
		0xe0, 0x0f, 0x72, 0xfc, 0x81, 0xec, 0x82, 0x8d, 0x7e, 0xc8, 0x2e, 0x28, 0x34, 0x1d, 0xd9, 0x05,
		0x32, 0x22, 0x42, 0x76, 0x41, 0x0d, 0x04, 0x85, 0xec, 0x82, 0xea, 0x11, 0x10, 0x9a, 0x0f, 0x42,
		0x2e, 0x20, 0x17, 0x90, 0x0b, 0xc8, 0x85, 0x3f, 0x0c, 0xdb, 0xa3, 0x49, 0x08, 0x8c, 0x02, 0x46,
		0x01, 0xa3, 0xd8, 0x50, 0x44, 0x68, 0x3e, 0x08, 0x99, 0x28, 0x13, 0x99, 0xa0, 0xf9, 0x20, 0xb4,
		0x02, 0x5a, 0x01, 0xad, 0x80, 0x56, 0xac, 0x7f, 0x76, 0x68, 0x3e, 0x08, 0xaf, 0x80, 0x57, 0xc0,
		0x2b, 0xca, 0x24, 0x22, 0x34, 0x1f, 0x84, 0x58, 0x94, 0x8a, 0x58, 0xd0, 0x7c, 0x10, 0x5a, 0x01,
		0xad, 0x80, 0x56, 0x40, 0x2b, 0xd6, 0x3d, 0x3b, 0x34, 0x1f, 0x2c, 0x27, 0xc3, 0xa0, 0xf9, 0x60,
		0x75, 0x36, 0xcb, 0x0b, 0x2d, 0xf4, 0x64, 0xfb, 0xfb, 0xa2, 0x89, 0x3e, 0x99, 0x80, 0x21, 0x6d,
		0xf4, 0x42, 0x1f, 0xcb, 0x22, 0x4a, 0x34, 0x1f, 0xac, 0xe0, 0x2c, 0x34, 0x1f, 0x5c, 0xd3, 0xd0,
		0xa2, 0xf9, 0xa0, 0xce, 0xc2, 0xd2, 0x7c, 0x50, 0x77, 0x71, 0x69, 0x3e, 0x28, 0x2e, 0xae, 0x34,
		0x1f, 0x14, 0x5e, 0x51, 0x9a, 0x0f, 0x8a, 0x2f, 0x29, 0xcd, 0x07, 0xa5, 0x57, 0x94, 0xe6, 0x83,
		0xe2, 0x4b, 0x4a, 0xf3, 0x41, 0x79, 0x29, 0xa5, 0xf9, 0xa0, 0xf4, 0x92, 0xd2, 0x7c, 0x50, 0x7c,
		0x49, 0x69, 0x3e, 0x58, 0xba, 0xe7, 0x20, 0xa2, 0x4d, 0xf3, 0xc1, 0x0d, 0xbd, 0x13, 0x44, 0xb7,
		0xd7, 0xd8, 0x11, 0xa2, 0xdb, 0x05, 0x27, 0x24, 0xba, 0x5d, 0x2e, 0x4b, 0x82, 0x42, 0x81, 0x5b,
		0x41, 0x0e, 0x85, 0x02, 0x29, 0xb1, 0x46, 0xa1, 0xc0, 0x35, 0x67, 0xa3, 0x50, 0x20, 0x85, 0x02,
		0x77, 0x99, 0x2f, 0xd0, 0x7c, 0x10, 0xd6, 0x00, 0x6b, 0x80, 0x35, 0xc0, 0x1a, 0xb6, 0x65, 0x0d,
		0x94, 0x07, 0x2c, 0x99, 0x2b, 0x98, 0x4b, 0x77, 0x82, 0xf3, 0x71, 0xe9, 0xae, 0xb2, 0x22, 0x42,
		0x79, 0xc0, 0x92, 0x8e, 0x4e, 0xf3, 0x41, 0x11, 0x33, 0xa8, 0xe6, 0xcd, 0x07, 0x35, 0xfa, 0xcb,
		0xed, 0xf9, 0xed, 0x3d, 0xf8, 0x7e, 0xfc, 0x48, 0x65, 0x6d, 0x3d, 0xf8, 0xa0, 0x44, 0x52, 0xae,
		0x25, 0xdd, 0xbe, 0xa5, 0xba, 0x21, 0xda, 0xdf, 0xd1, 0x93, 0x1c, 0xcb, 0x48, 0x70, 0x71, 0x79,
		0x13, 0x90, 0xb5, 0x46, 0x7c, 0x20, 0x26, 0x5f, 0x33, 0x5a, 0x14, 0x1f, 0x08, 0x6d, 0xb3, 0x70,
		0x3b, 0x4c, 0x71, 0xc7, 0x8d, 0x86, 0xa3, 0x46, 0xdb, 0x31, 0xa3, 0xe5, 0x88, 0x51, 0x77, 0xbc,
		0xa8, 0x3b, 0x5a, 0x0c, 0x1c, 0x2b, 0xe5, 0xd2, 0x31, 0xd2, 0xed, 0x2b, 0x1b, 0x9d, 0xe9, 0xf9,
		0x52, 0x6a, 0xb9, 0xab, 0xd2, 0x8f, 0x59, 0xbd, 0xe7, 0xee, 0x3e, 0x3d, 0x77, 0xad, 0x40, 0xc8,
		0x0c, 0x8c, 0xcc, 0x40, 0xc9, 0x10, 0x9c, 0xaa, 0x41, 0xfb, 0x4c, 0x7a, 0xee, 0x5e, 0x85, 0x1d,
		0xdb, 0x96, 0x59, 0xa3, 0x09, 0x09, 0x86, 0x59, 0xc3, 0x9d, 0x35, 0xec, 0x59, 0xc1, 0x9f, 0x39,
		0x0c, 0x9a, 0xc3, 0xa1, 0x07, 0x58, 0xd4, 0xf5, 0x0b, 0x56, 0x3f, 0x18, 0x76, 0x15, 0x76, 0x94,
		0xb3, 0x81, 0xf7, 0x6a, 0x97, 0x42, 0x37, 0x9f, 0x1c, 0x73, 0x3f, 0xe7, 0xe6, 0xe0, 0xfa, 0xd1,
		0xdf, 0x47, 0xd7, 0xe4, 0x70, 0xfd, 0x78, 0xb6, 0x7f, 0xff, 0x78, 0x19, 0x49, 0x22, 0x52, 0xef,
		0x36, 0x3a, 0x3a, 0xff, 0x57, 0x61, 0xf6, 0xa7, 0xb9, 0xe1, 0x74, 0x33, 0x2b, 0xd6, 0x13, 0xd6,
		0x13, 0xd6, 0x13, 0xd6, 0x13, 0xd6, 0x13, 0xd6, 0x13, 0xd6, 0x13, 0xd6, 0x53, 0x05, 0xac, 0x27,
		0x97, 0x7f, 0x72, 0x69, 0xae, 0x09, 0x31, 0x33, 0x78, 0xb9, 0x9d, 0x0a, 0x3b, 0x09, 0x3b, 0x09,
		0x3b, 0x09, 0x3b, 0xa9, 0xa2, 0x76, 0xd2, 0x0c, 0xc8, 0x28, 0x42, 0xbc, 0xee, 0x8f, 0x71, 0x11,
		0xe2, 0xd6, 0xb1, 0x61, 0xd9, 0xc2, 0x63, 0xaa, 0x10, 0x6f, 0xff, 0x60, 0xbb, 0x58, 0x85, 0xb8,
		0x75, 0x74, 0x78, 0x4c, 0x21, 0x62, 0x15, 0x69, 0xda, 0xc1, 0x42, 0xc4, 0xc7, 0x47, 0x47, 0x87,
		0x47, 0x94, 0x22, 0xae, 0xda, 0x2c, 0x94, 0x22, 0x5e, 0x4f, 0x9d, 0x53, 0x8a, 0x58, 0x69, 0x61,
		0x5f, 0x7c, 0xf8, 0xcf, 0x17, 0xef, 0x3e, 0xfc, 0xcf, 0xdb, 0x17, 0x14, 0x22, 0x56, 0x5b, 0xda,
		0xf3, 0x57, 0xaf, 0xa8, 0x4c, 0xaa, 0xb3, 0xb2, 0xff, 0xf5, 0xea, 0xf9, 0xef, 0xac, 0xac, 0xc6,
		0xca, 0xbe, 0x7e, 0xfb, 0xea, 0x3d, 0x2b, 0xab, 0xb1, 0xb2, 0x2f, 0xdf, 0xfe, 0x57, 0x9b, 0x95,
		0xd5, 0x58, 0xd9, 0xe7, 0xef, 0x80, 0x59, 0x2d, 0x91, 0x3d, 0x66, 0x65, 0x35, 0x56, 0xf6, 0xdd,
		0x9b, 0x9f, 0x29, 0x0b, 0x5b, 0xb2, 0xe7, 0xe0, 0xbe, 0xb5, 0x62, 0x99, 0x27, 0x93, 0x84, 0xf6,
		0xb9, 0xb9, 0x88, 0x32, 0x2e, 0x9d, 0x80, 0x28, 0x63, 0x81, 0xbd, 0x27, 0xca, 0x58, 0x11, 0xcc,
		0x25, 0x1b, 0x6b, 0x33, 0x38, 0x23, 0x1b, 0xab, 0xb0, 0x86, 0x27, 0x1b, 0x0b, 0x4b, 0x49, 0xcc,
		0x52, 0x32, 0x4a, 0x63, 0xbf, 0x3f, 0x21, 0x36, 0x13, 0x36, 0x13, 0x36, 0x13, 0x36, 0x13, 0x36,
		0x13, 0x36, 0x13, 0x36, 0x13, 0x36, 0x53, 0xa9, 0x47, 0xa4, 0x9a, 0xdf, 0xda, 0x75, 0xcf, 0xe2,
		0x83, 0xa6, 0x4a, 0xe1, 0x9a, 0x3d, 0x6f, 0x45, 0xd0, 0x5e, 0x1d, 0x9c, 0x4f, 0xcc, 0xbe, 0xb2,
		0xd6, 0xf2, 0x13, 0x2d, 0x33, 0x17, 0xe6, 0x4e, 0xaf, 0xa6, 0x91, 0x46, 0x99, 0x47, 0xf5, 0x92,
		0x46, 0x07, 0x94, 0x34, 0xb2, 0xb6, 0xe9, 0x29, 0x69, 0x54, 0x5b, 0xdd, 0x47, 0x49, 0x23, 0x5c,
		0x1a, 0xb8, 0x34, 0x70, 0x69, 0xe0, 0xd2, 0xc0, 0xa5, 0x81, 0x4b, 0x03, 0x97, 0x06, 0x2e, 0x0d,
		0x7f, 0x08, 0x43, 0x49, 0x23, 0xac, 0x27, 0xac, 0x27, 0xac, 0x27, 0xac, 0x27, 0xac, 0x27, 0xac,
		0x27, 0xac, 0x27, 0xac, 0xa7, 0x8d, 0x56, 0x9e, 0x92, 0x46, 0xd8, 0x49, 0xd8, 0x49, 0xd8, 0x49,
		0xd8, 0x49, 0x5b, 0x00, 0x19, 0x25, 0x8d, 0xd6, 0xfd, 0xa1, 0xa4, 0x51, 0xb1, 0xa9, 0x28, 0x69,
		0x54, 0x1d, 0x43, 0x61, 0xe5, 0xb4, 0x94, 0x34, 0x52, 0x97, 0x26, 0x4a, 0x1a, 0xd5, 0x5e, 0x9c,
		0x28, 0x69, 0xe4, 0xff, 0xd0, 0x51, 0xd2, 0x48, 0x62, 0x2e, 0x4a, 0x1a, 0xd5, 0xc7, 0x90, 0xd9,
		0xa3, 0xa4, 0x91, 0xed, 0xca, 0x52, 0xd2, 0x48, 0x6b, 0x65, 0x29, 0x69, 0xa4, 0xb5, 0xb2, 0x94,
		0x34, 0xd2, 0x5a, 0x59, 0x4a, 0x1a, 0xe9, 0x89, 0x2c, 0x25, 0x8d, 0x54, 0x56, 0x96, 0x92, 0x46,
		0xe5, 0x7b, 0x0e, 0x4a, 0x1a, 0x51, 0xd2, 0xc8, 0xaf, 0xbb, 0x87, 0x28, 0xe3, 0x36, 0xf3, 0x11,
		0x65, 0x94, 0x9a, 0x90, 0x28, 0xe3, 0xf7, 0xd7, 0x87, 0x6c, 0xac, 0x6d, 0x20, 0x87, 0x6c, 0xac,
		0x82, 0x0b, 0x48, 0x36, 0xd6, 0x8e, 0x59, 0x4a, 0x94, 0x34, 0xc2, 0x66, 0xc2, 0x66, 0xc2, 0x66,
		0xc2, 0x66, 0xc2, 0x66, 0xc2, 0x66, 0xc2, 0x66, 0xaa, 0x89, 0xcd, 0x44, 0x49, 0x23, 0x6f, 0x25,
		0x8d, 0x34, 0xea, 0xd6, 0xec, 0xf9, 0xac, 0x68, 0xf4, 0x7e, 0xfc, 0x40, 0x65, 0x2d, 0x68, 0xf4,
		0xa0, 0x44, 0x12, 0xae, 0x25, 0xd9, 0x7e, 0x25, 0xba, 0x21, 0x5a, 0x33, 0xca, 0x8b, 0x0c, 0xcb,
		0x48, 0x6f, 0x71, 0x59, 0x13, 0x90, 0xb3, 0x46, 0xe6, 0xfe, 0x77, 0xe8, 0x92, 0x8e, 0x0b, 0xa2,
		0xae, 0x98, 0x90, 0xdd, 0xf2, 0xd4, 0xb9, 0xc1, 0x85, 0xce, 0x84, 0x2c, 0x27, 0x15, 0xe7, 0xa0,
		0x1a, 0x9c, 0xf3, 0x0e, 0xc7, 0x94, 0x4c, 0xa7, 0xd3, 0x22, 0x93, 0xea, 0xe4, 0x51, 0x9d, 0x2c,
		0x2e, 0x90, 0xc3, 0x5e, 0xa3, 0xa6, 0x3a, 0x46, 0x9c, 0xe5, 0xcd, 0xa4, 0x35, 0x76, 0x61, 0x4f,
		0x36, 0xfd, 0x73, 0xc6, 0xe0, 0x4e, 0x04, 0xc7, 0x7c, 0x3b, 0x51, 0x83, 0x4f, 0x9e, 0x4c, 0xca,
		0x47, 0x36, 0xe7, 0x51, 0xab, 0x4e, 0x48, 0x2f, 0x5a, 0x60, 0x51, 0xa5, 0xb0, 0xa2, 0x70, 0x41,
		0x45, 0xf1, 0x42, 0x8a, 0xa0, 0x3b, 0xe8, 0x5e, 0x29, 0x74, 0x97, 0x2e, 0x79, 0xd8, 0x18, 0x7b,
		0x48, 0x5d, 0x37, 0xe8, 0x77, 0x72, 0x37, 0xbe, 0x42, 0xa2, 0x54, 0xae, 0xf5, 0xde, 0x3c, 0x3a,
		0x75, 0x5b, 0xf7, 0xb5, 0xea, 0xb6, 0xee, 0x57, 0xb4, 0x6e, 0x6b, 0x8f, 0x82, 0xad, 0x1e, 0x61,
		0xc9, 0x02, 0x9e, 0xaa, 0xe1, 0xd2, 0x53, 0x0b, 0x3d, 0xcc, 0xa4, 0xbd, 0xd3, 0x1f, 0x26, 0xb9,
		0x4b, 0x8f, 0xdb, 0x1a, 0x12, 0x3f, 0x81, 0x17, 0x85, 0x38, 0x83, 0xf2, 0x8d, 0x62, 0xc5, 0x58,
		0x8f, 0xc5, 0x8d, 0x61, 0xa3, 0x3b, 0x9d, 0xb3, 0x3b, 0x9c, 0xda, 0xf3, 0x18, 0xde, 0xd7, 0x54,
		0x4c, 0xe1, 0x36, 0xb9, 0xde, 0x6b, 0xbd, 0xf5, 0xad, 0xa7, 0xed, 0xf6, 0xf1, 0x49, 0xbb, 0xbd,
		0x7f, 0x72, 0x78, 0xb2, 0x7f, 0x7a, 0x74, 0xd4, 0x3a, 0xd6, 0xbe, 0x7b, 0x68, 0x2a, 0x0d, 0x15,
		0x09, 0x4c, 0x9d, 0xed, 0x40, 0x5f, 0x84, 0xa9, 0x25, 0x3c, 0xf8, 0xd3, 0xc2, 0xde, 0x1e, 0xcf,
		0x82, 0xb5, 0x8d, 0xb5, 0x8d, 0xb5, 0x8d, 0xb5, 0x8d, 0xb5, 0x8d, 0xb5, 0x8d, 0xb5, 0x8d, 0xb5,
		0x8d, 0xb5, 0x8d, 0xb5, 0xbd, 0x23, 0xd6, 0xb6, 0x46, 0x3a, 0xc4, 0x82, 0x3a, 0x94, 0x4f, 0x8b,
		0xc0, 0xd6, 0xc6, 0xd6, 0xc6, 0xd6, 0xc6, 0xd6, 0x9e, 0x14, 0xd2, 0x3c, 0x3c, 0x50, 0x34, 0xb4,
		0x4f, 0x30, 0xb4, 0x31, 0xb4, 0x31, 0xb4, 0x6b, 0x69, 0x68, 0xb7, 0x0f, 0x4e, 0xdb, 0xa7, 0xc7,
		0x27, 0x07, 0xa7, 0x98, 0xd7, 0x98, 0xd7, 0xa2, 0x23, 0x91, 0x13, 0xbf, 0x32, 0x27, 0x5e, 0xfa,
		0x8a, 0x87, 0x9f, 0xb4, 0x78, 0xc1, 0x7b, 0x1d, 0xe5, 0xc8, 0x97, 0xcc, 0xd3, 0x30, 0xc9, 0x06,
		0xfd, 0x34, 0x97, 0xcf, 0x99, 0xbc, 0x1d, 0xba, 0xe4, 0x79, 0x93, 0x55, 0xc9, 0x8a, 0x57, 0xb8,
		0x79, 0x4d, 0xfa, 0xe4, 0xda, 0x2c, 0x4e, 0xfe, 0xe6, 0x74, 0xcd, 0xb3, 0x28, 0x3b, 0xd3, 0xf3,
		0xa5, 0xe4, 0x60, 0x9a, 0x8c, 0x5f, 0xb1, 0x6e, 0xf7, 0xfb, 0x74, 0xbb, 0xc7, 0xc5, 0x54, 0x01,
		0x70, 0xaa, 0x86, 0xa7, 0xc9, 0xa4, 0xdb, 0xbd, 0xa8, 0x79, 0xb4, 0xf2, 0x90, 0x2d, 0xcc, 0x48,
		0xbd, 0x1b, 0x6b, 0xc0, 0xb3, 0x06, 0x3e, 0x2b, 0x00, 0x34, 0x07, 0x42, 0x73, 0x40, 0xf4, 0x00,
		0x8c, 0xca, 0x9e, 0x97, 0xca, 0xd7, 0xbb, 0x19, 0x61, 0x58, 0x90, 0x0c, 0xaf, 0x82, 0x74, 0xec,
		0xf6, 0xa6, 0x13, 0xd9, 0x8f, 0x7f, 0x0c, 0x5b, 0x97, 0x64, 0x79, 0x1a, 0x25, 0x97, 0x96, 0x5d,
		0x4b, 0x9e, 0x1a, 0xcc, 0x65, 0x55, 0x52, 0x67, 0x36, 0xe1, 0xc3, 0xe3, 0xa3, 0xa3, 0xc3, 0x8f,
		0xfb, 0xc1, 0xd1, 0xd9, 0xb7, 0xe3, 0xa3, 0xa3, 0x8f, 0xfb, 0xc1, 0xc1, 0xd9, 0xc7, 0xfd, 0xe0,
		0x74, 0xf4, 0xdb, 0xc7, 0xfd, 0xa0, 0x7d, 0xf3, 0xcb, 0xdf, 0x07, 0xd7, 0xdf, 0x8e, 0xe7, 0x7e,
		0x3d, 0xbc, 0xfe, 0x36, 0xfe, 0xc8, 0xcd, 0x6f, 0xed, 0xf1, 0x6f, 0xa7, 0x67, 0x7f, 0xb7, 0x1e,
		0xb7, 0xaf, 0x1f, 0xfd, 0xf1, 0xc7, 0x93, 0x3f, 0xfe, 0x78, 0x22, 0x3e, 0xac, 0x7e, 0x31, 0xef,
		0x33, 0x8b, 0xed, 0xb5, 0x2c, 0x9b, 0x34, 0x9b, 0xf5, 0xdf, 0x55, 0xd9, 0xe4, 0x7f, 0x34, 0xe8,
		0x0c, 0x55, 0x12, 0x78, 0x9d, 0x2a, 0xbf, 0x0b, 0x97, 0xd2, 0xed, 0xb1, 0xd4, 0x5b, 0x36, 0x7b,
		0xb0, 0x5d, 0xec, 0xf6, 0xb8, 0x4f, 0xab, 0x47, 0x15, 0x51, 0xa2, 0xd5, 0x63, 0xed, 0xc5, 0x89,
		0x56, 0x8f, 0x3b, 0xa5, 0xd0, 0x5d, 0x32, 0xbc, 0x72, 0xe9, 0x4d, 0x48, 0xde, 0x90, 0x34, 0xb5,
		0x0d, 0xe6, 0x7a, 0x91, 0x0c, 0xaf, 0x46, 0x70, 0x45, 0xfb, 0x1a, 0xdd, 0xef, 0xab, 0x58, 0x94,
		0xdd, 0xc6, 0x43, 0x3d, 0x3f, 0x19, 0xce, 0xe9, 0xe5, 0x0c, 0x15, 0xe7, 0xf4, 0xf6, 0x7b, 0x8f,
		0x73, 0xba, 0x22, 0xa8, 0x8b, 0x73, 0x7a, 0x73, 0x4d, 0x8e, 0x73, 0x7a, 0x03, 0x45, 0x83, 0x73,
		0x5a, 0x62, 0x42, 0x9c, 0xd3, 0x33, 0x13, 0x11, 0xe7, 0x34, 0xce, 0x69, 0xb8, 0x2c, 0xce, 0xe9,
		0x8a, 0x6d, 0xd9, 0xec, 0xc1, 0x70, 0x4e, 0xeb, 0xcf, 0x8b, 0x73, 0xba, 0xb6, 0xa2, 0x84, 0x73,
		0xba, 0x92, 0xb3, 0xa0, 0xd0, 0xd7, 0x53, 0xe8, 0x38, 0xa7, 0x4b, 0x2b, 0xca, 0xbb, 0xec, 0x9c,
		0xce, 0x3b, 0x83, 0xa0, 0x17, 0x87, 0x97, 0x99, 0xbe, 0x6b, 0xfa, 0x76, 0x2a, 0x1c, 0xd3, 0xcb,
		0xd9, 0x29, 0x8e, 0xe9, 0xed, 0xf7, 0x1e, 0xc7, 0x74, 0x45, 0x10, 0xb7, 0xfa, 0x8e, 0xe9, 0xa8,
		0xeb, 0x92, 0x3c, 0xca, 0xbf, 0xca, 0xf6, 0x94, 0x59, 0xa9, 0xc2, 0x15, 0x8d, 0xe2, 0xc6, 0xcb,
		0xc9, 0xa3, 0xfc, 0x14, 0x66, 0x06, 0x87, 0x74, 0xba, 0x80, 0x1f, 0x7e, 0x7e, 0x7b, 0xfe, 0xeb,
		0xab, 0xe7, 0xbf, 0xbd, 0x6f, 0x58, 0x54, 0x93, 0xc8, 0x4c, 0x9c, 0x0d, 0x36, 0x64, 0xed, 0xee,
		0x12, 0xbe, 0xfc, 0x5d, 0xdf, 0x61, 0x67, 0x40, 0x7b, 0x3d, 0x2c, 0xdd, 0xcf, 0xff, 0xdf, 0x3b,
		0x96, 0x6e, 0xbb, 0xa5, 0x7b, 0xfb, 0xfe, 0x3f, 0x59, 0xba, 0xed, 0x96, 0xee, 0xfd, 0xff, 0x70,
		0x60, 0xb7, 0x5c, 0xba, 0x17, 0x3f, 0xbf, 0x60, 0xe9, 0xb6, 0x5b, 0xba, 0xe7, 0x3f, 0xff, 0x93,
		0xa5, 0xdb, 0x6e, 0xe9, 0xde, 0xbd, 0xff, 0xc0, 0xd2, 0x6d, 0xb7, 0x74, 0xff, 0x7a, 0xf7, 0x9b,
		0xc1, 0xd2, 0xa9, 0xce, 0x70, 0x06, 0xb3, 0x1a, 0x6f, 0xeb, 0xab, 0x28, 0xcb, 0x9f, 0xe7, 0x79,
		0xaa, 0xcb, 0xae, 0x5e, 0x47, 0xc9, 0x8b, 0xd8, 0x8d, 0x18, 0x6e, 0xa6, 0x1b, 0x85, 0x68, 0xbc,
		0x0e, 0xbf, 0xcc, 0xcd, 0x64, 0x5b, 0xd2, 0xb9, 0xf1, 0x26, 0xed, 0xba, 0xd4, 0x75, 0x7f, 0xfa,
		0xda, 0x78, 0xb6, 0x97, 0x0c, 0xe3, 0x98, 0xce, 0xfb, 0x12, 0xbe, 0x91, 0xfa, 0x76, 0xde, 0x9f,
		0x55, 0xe8, 0x6a, 0xaa, 0xd4, 0xd2, 0xd9, 0xf3, 0x56, 0xa6, 0xed, 0xc3, 0xf4, 0xc1, 0xce, 0x27,
		0x8e, 0xd5, 0x5d, 0x28, 0xea, 0x2d, 0xda, 0xf9, 0x76, 0x41, 0xef, 0x4a, 0xd7, 0xef, 0xdb, 0xb3,
		0x28, 0xb6, 0x74, 0x40, 0xb1, 0xa5, 0x85, 0x79, 0x28, 0xb6, 0xb4, 0xb1, 0x06, 0xa0, 0xd8, 0xd2,
		0x1e, 0xc5, 0x96, 0x8a, 0x00, 0x1c, 0x61, 0x43, 0xff, 0xc0, 0x67, 0x05, 0x80, 0xe6, 0x40, 0x68,
		0x0e, 0x88, 0x1e, 0x80, 0xb1, 0x9a, 0xe4, 0x96, 0xfb, 0x2c, 0x85, 0xd6, 0x8d, 0xfb, 0x2c, 0x5b,
		0xef, 0x0e, 0xf7, 0x59, 0xb8, 0xcf, 0x52, 0x74, 0x7b, 0xb9, 0xcf, 0xc2, 0x7d, 0x96, 0x4a, 0xc0,
		0x2b, 0xf7, 0x59, 0xaa, 0xb2, 0x65, 0xb3, 0x07, 0xe3, 0x3e, 0x8b, 0xfe, 0xbc, 0xdc, 0x67, 0xa9,
		0xad, 0x28, 0x71, 0x9f, 0xa5, 0x92, 0xb3, 0xa0, 0xd0, 0xd7, 0x53, 0xe8, 0xdc, 0x67, 0x29, 0xad,
		0x28, 0x53, 0x6c, 0x89, 0x62, 0x4b, 0x6b, 0x0e, 0x8f, 0x73, 0x7a, 0x8b, 0xf9, 0x70, 0x4e, 0x4b,
		0x4d, 0x88, 0x73, 0xfa, 0xfb, 0xeb, 0x83, 0x73, 0xba, 0xd0, 0xba, 0xe1, 0x9c, 0xde, 0x7a, 0x77,
		0x70, 0x4e, 0xe3, 0x9c, 0x2e, 0xba, 0xbd, 0x38, 0xa7, 0x71, 0x4e, 0x57, 0x02, 0x5e, 0x71, 0x4e,
		0x57, 0x65, 0xcb, 0x66, 0x0f, 0x86, 0x73, 0x5a, 0x7f, 0x5e, 0x9c, 0xd3, 0xb5, 0x15, 0x25, 0x9c,
		0xd3, 0x95, 0x9c, 0x05, 0x85, 0xbe, 0x9e, 0x42, 0xc7, 0x39, 0x5d, 0x5a, 0x51, 0xa6, 0xd8, 0x12,
		0xc5, 0x96, 0xd6, 0x18, 0x1e, 0xc7, 0xf4, 0x16, 0xf3, 0xe1, 0x98, 0x96, 0x9a, 0x10, 0xc7, 0xf4,
		0xf7, 0xd7, 0x87, 0x62, 0x4b, 0x5b, 0xcc, 0x41, 0xb1, 0xa5, 0x6a, 0x39, 0x1a, 0x28, 0xb6, 0x24,
		0xb3, 0x74, 0x14, 0x5b, 0xda, 0x7a, 0xe9, 0x28, 0xb6, 0xb4, 0xf5, 0xd2, 0x51, 0x6c, 0x69, 0xeb,
		0xa5, 0xa3, 0xd8, 0xd2, 0xd6, 0x4b, 0x47, 0xb1, 0xa5, 0xad, 0x97, 0x8e, 0x62, 0x4b, 0x5b, 0x2f,
		0x1d, 0xc5, 0x96, 0x6a, 0xc3, 0xac, 0x28, 0xb6, 0x24, 0x38, 0x39, 0xc5, 0x96, 0x28, 0xb6, 0xb4,
		0x5d, 0xb1, 0x25, 0x8d, 0x52, 0x3a, 0x7b, 0x25, 0xa8, 0xb5, 0xf4, 0x7e, 0xfc, 0x5c, 0x65, 0x2d,
		0xb5, 0xf4, 0xa0, 0x44, 0xf2, 0xae, 0x25, 0xe7, 0xa5, 0x90, 0xef, 0x86, 0x68, 0x51, 0x2b, 0x9f,
		0x12, 0x2d, 0x23, 0xcb, 0xc5, 0x25, 0xaf, 0xd8, 0x08, 0x05, 0x65, 0xb6, 0xf1, 0x4f, 0xf7, 0x75,
		0x9c, 0x27, 0xea, 0xfe, 0x77, 0xe8, 0x92, 0x8e, 0x0b, 0xa2, 0x6e, 0xc1, 0x1d, 0x96, 0xb5, 0x43,
		0xe4, 0xed, 0x0d, 0x13, 0xbb, 0x42, 0xd6, 0x7e, 0x28, 0xba, 0xc7, 0xc2, 0x78, 0xe4, 0x11, 0x87,
		0x04, 0xd0, 0xc7, 0x0b, 0xea, 0x14, 0xc3, 0x9a, 0xed, 0x11, 0x62, 0xbb, 0x4f, 0x6e, 0x29, 0x6f,
		0x52, 0x72, 0xe6, 0x47, 0xbe, 0x0a, 0x88, 0x96, 0xb5, 0x48, 0x6d, 0x27, 0x4d, 0x9b, 0xcb, 0xc2,
		0x16, 0x72, 0x50, 0xb0, 0x50, 0xa5, 0x48, 0x41, 0xca, 0x82, 0x85, 0x27, 0x0b, 0x17, 0x98, 0x94,
		0xc8, 0x10, 0xb8, 0x93, 0x01, 0x50, 0x24, 0x7e, 0x29, 0x15, 0xda, 0x17, 0x0f, 0xdd, 0x8b, 0x87,
		0xe6, 0x17, 0x42, 0xef, 0xbd, 0x46, 0x45, 0x70, 0xb3, 0x68, 0xe9, 0xc5, 0xc6, 0x04, 0xe2, 0xa2,
		0x6e, 0xf1, 0x6d, 0xbe, 0xcd, 0x6c, 0x9f, 0x0e, 0x59, 0xd4, 0xc0, 0x14, 0x49, 0xf7, 0x11, 0x4b,
		0xeb, 0x91, 0x4c, 0xdf, 0x11, 0x3b, 0xa4, 0xd2, 0x87, 0x55, 0xed, 0xd0, 0xaa, 0x1d, 0x5e, 0x8d,
		0x43, 0x5c, 0x0e, 0x82, 0x25, 0x96, 0xf0, 0x22, 0x7f, 0xa7, 0xef, 0xf6, 0xce, 0x1e, 0xe6, 0x69,
		0x89, 0xcd, 0xd3, 0xa2, 0x1e, 0x45, 0x43, 0xf3, 0xb4, 0x80, 0x93, 0x70, 0x0b, 0xf3, 0xf4, 0x81,
		0xa2, 0xd4, 0x4c, 0x1d, 0x23, 0xdb, 0xea, 0xc1, 0x62, 0x6e, 0x90, 0xe2, 0x6e, 0x0f, 0x15, 0x37,
		0x47, 0x31, 0xb7, 0xc6, 0xa6, 0x3b, 0x50, 0xf0, 0xbc, 0x5a, 0x9f, 0xd3, 0xc6, 0x56, 0x6c, 0xc9,
		0xe8, 0x64, 0x6e, 0x76, 0x26, 0xd7, 0x3f, 0x59, 0xeb, 0xfd, 0xe5, 0x9a, 0x3b, 0xbf, 0xed, 0x8e,
		0x9b, 0xed, 0xf4, 0x06, 0x5b, 0x6c, 0xb0, 0xb5, 0xeb, 0xed, 0xe9, 0x8f, 0x77, 0xe8, 0xfb, 0x7f,
		0xf1, 0x83, 0xbd, 0xdb, 0x74, 0xcf, 0xb4, 0xf7, 0x6a, 0x8d, 0x2d, 0xd2, 0xdb, 0x9a, 0xef, 0xef,
		0xc8, 0xea, 0x75, 0xfe, 0xce, 0x1a, 0x37, 0x06, 0x69, 0x3f, 0xef, 0x77, 0xfa, 0xf1, 0x8f, 0xaf,
		0x7e, 0xdc, 0x72, 0xb7, 0xd9, 0x47, 0x7e, 0xb0, 0x77, 0xeb, 0x39, 0x4a, 0xd6, 0xe6, 0x5e, 0x9b,
		0x70, 0xab, 0x79, 0xee, 0x94, 0xb8, 0x7c, 0xb4, 0xa1, 0xeb, 0x6c, 0xdd, 0x86, 0x04, 0x69, 0x6b,
		0x02, 0xb4, 0x35, 0xc1, 0xb9, 0x4f, 0x60, 0xa6, 0xcf, 0xa6, 0x7c, 0x0a, 0xd7, 0x75, 0x21, 0xcc,
		0x64, 0x63, 0xfd, 0x25, 0xbc, 0x2f, 0x55, 0xeb, 0xae, 0xe0, 0x66, 0x5e, 0xb8, 0x8d, 0x09, 0xfe,
		0x36, 0x44, 0x7e, 0x3b, 0xa1, 0x2b, 0xca, 0xce, 0x0b, 0xb3, 0xf0, 0xc2, 0x6c, 0x7b, 0x6b, 0xa1,
		0xd4, 0x51, 0xf3, 0x9b, 0xfa, 0xbb, 0x1a, 0x17, 0x97, 0x83, 0xcd, 0x57, 0x7d, 0xba, 0xd7, 0xa3,
		0x0f, 0x6f, 0x6a, 0xfb, 0x6f, 0xe5, 0x40, 0xde, 0xda, 0x47, 0x55, 0xc4, 0x27, 0x35, 0x2f, 0xd2,
		0x9b, 0x3f, 0xa9, 0x84, 0xd3, 0x49, 0xcc, 0xc9, 0x24, 0xe6, 0x54, 0xba, 0x2f, 0xee, 0xa3, 0x75,
		0x29, 0x19, 0xbb, 0xdc, 0xd6, 0xe5, 0xdb, 0xb8, 0x8c, 0xfb, 0x17, 0x61, 0x5c, 0x3c, 0xc0, 0x32,
		0x19, 0xc7, 0x73, 0x84, 0x65, 0xbf, 0x1c, 0x11, 0x96, 0xed, 0x0e, 0x8e, 0xb4, 0xd7, 0xb6, 0x7a,
		0x21, 0x96, 0xad, 0x0e, 0x96, 0x1f, 0xe7, 0x5f, 0xe1, 0x18, 0x4b, 0xd8, 0x8b, 0x82, 0x2c, 0xec,
		0x45, 0x99, 0x5c, 0x8c, 0xe5, 0x76, 0x48, 0x99, 0x18, 0x4b, 0xab, 0xe6, 0x31, 0x96, 0x62, 0xc7,
		0x54, 0xfa, 0xb8, 0xaa, 0x1d, 0x5b, 0xb5, 0xe3, 0xab, 0x72, 0x8c, 0x8b, 0x47, 0x01, 0xf6, 0x04,
		0xa2, 0x2c, 0x52, 0xdd, 0xeb, 0x66, 0x67, 0x52, 0x4e, 0x3c, 0xee, 0x9f, 0x76, 0x29, 0xe9, 0x90,
		0x6d, 0xaf, 0x29, 0x5e, 0x37, 0x41, 0xa3, 0x4e, 0x82, 0x3c, 0x18, 0x68, 0x81, 0x82, 0x3a, 0x38,
		0xa8, 0x83, 0x84, 0x2a, 0x58, 0xc8, 0x80, 0x86, 0x10, 0x78, 0x88, 0x83, 0xc8, 0x2d, 0x98, 0x74,
		0xbb, 0xc1, 0x20, 0xcc, 0x3f, 0x65, 0x7a, 0x9d, 0x7b, 0x6f, 0xa7, 0xa8, 0x58, 0xf7, 0xde, 0xfd,
		0x6a, 0x76, 0xef, 0x95, 0x85, 0x1d, 0x6d, 0xf8, 0x31, 0x83, 0x21, 0x33, 0x38, 0x32, 0x81, 0x25,
		0x59, 0x78, 0x12, 0x86, 0x29, 0x35, 0xb8, 0x9a, 0x0d, 0xdc, 0x99, 0x9e, 0x51, 0xe5, 0x52, 0x53,
		0x6a, 0x7d, 0xe9, 0x15, 0x01, 0x4c, 0x1d, 0xc8, 0x2c, 0x00, 0xcd, 0x0e, 0xd8, 0xac, 0x00, 0xce,
		0x1c, 0xe8, 0xcc, 0x01, 0xcf, 0x14, 0xf8, 0x74, 0x00, 0x50, 0x09, 0x08, 0xd5, 0x01, 0x71, 0x36,
		0x81, 0x8b, 0xa3, 0xcb, 0xe8, 0x22, 0x76, 0xc1, 0x8d, 0x68, 0x05, 0x93, 0xc4, 0x0f, 0xb3, 0x8a,
		0x4c, 0x2b, 0xe6, 0x57, 0x16, 0x38, 0x9b, 0x8a, 0xb3, 0xea, 0x80, 0x6a, 0x09, 0xac, 0xf6, 0x00,
		0x6b, 0x0d, 0xb4, 0xde, 0x00, 0xd7, 0x1b, 0xf0, 0x7a, 0x01, 0x60, 0x5d, 0x20, 0x56, 0x06, 0xe4,
		0xd9, 0x8a, 0xa9, 0x17, 0xfd, 0x5b, 0x38, 0x6f, 0xb1, 0x0b, 0x7b, 0xba, 0x85, 0xff, 0x16, 0xec,
		0xcc, 0x13, 0x9b, 0xc6, 0x27, 0x93, 0xb4, 0xa9, 0x4e, 0x90, 0x0e, 0xfa, 0xf1, 0xb3, 0xb4, 0x3f,
		0xcc, 0xa3, 0xe4, 0x72, 0xa2, 0x09, 0x66, 0x6f, 0x4f, 0xd2, 0xa2, 0xba, 0xae, 0x17, 0x25, 0x51,
		0x1e, 0xf5, 0x93, 0x6c, 0xf5, 0x3f, 0xcd, 0xfe, 0x65, 0x9c, 0x10, 0x55, 0xd1, 0xe2, 0xc0, 0x8a,
		0x12, 0xdc, 0x48, 0x5d, 0xc7, 0x45, 0x9f, 0x0d, 0x0b, 0x2f, 0x4e, 0x27, 0x54, 0x3e, 0x95, 0xbf,
		0xb8, 0x5e, 0x38, 0x8c, 0xc7, 0x30, 0xd6, 0x0b, 0xe3, 0xcc, 0x61, 0x47, 0x60, 0x47, 0x60, 0x47,
		0x60, 0x47, 0x60, 0x47, 0xcc, 0x25, 0x8f, 0xf5, 0xfb, 0xb1, 0x0b, 0x4d, 0x7b, 0x01, 0xb4, 0x50,
		0xc1, 0x0b, 0x6b, 0x93, 0xb9, 0xa4, 0x6b, 0xa7, 0x7f, 0xc7, 0xb3, 0xa1, 0x7c, 0x51, 0xbe, 0x28,
		0x5f, 0x94, 0x2f, 0xca, 0x17, 0xe5, 0x8b, 0xf2, 0x0d, 0xae, 0x0c, 0x7a, 0x9d, 0xdd, 0x51, 0xc0,
		0xe3, 0x19, 0x51, 0x8a, 0x28, 0x45, 0x94, 0x22, 0x4a, 0x11, 0xa5, 0x38, 0x3b, 0x6f, 0xc3, 0x28,
		0xc9, 0x9f, 0x1a, 0xaa, 0xc4, 0x23, 0x9a, 0xcd, 0x6e, 0xff, 0x60, 0x34, 0x9b, 0xd5, 0x9f, 0x97,
		0x66, 0xb3, 0xb5, 0x15, 0xa5, 0x83, 0x23, 0x5a, 0xcd, 0x56, 0x6e, 0x96, 0xb3, 0xaa, 0x52, 0xa8,
		0x4a, 0xe5, 0x3a, 0x29, 0xd7, 0xd2, 0xbf, 0x25, 0x7f, 0xb2, 0xe5, 0x3a, 0xa6, 0x95, 0x29, 0x66,
		0xaf, 0x9a, 0x17, 0x97, 0x83, 0xe6, 0xcd, 0x65, 0xd4, 0xe6, 0xec, 0x3e, 0xdc, 0xec, 0x55, 0x73,
		0x96, 0xde, 0xde, 0x54, 0x4d, 0x16, 0xdd, 0x93, 0x2d, 0x0b, 0x32, 0x7d, 0xca, 0xd9, 0xab, 0xf3,
		0x9f, 0x2e, 0x07, 0xe7, 0xbf, 0x8d, 0x9f, 0xf2, 0xfc, 0x79, 0x2f, 0x7a, 0x3f, 0x7a, 0xc8, 0xe9,
		0x8b, 0xf3, 0xe7, 0xdd, 0xee, 0xdb, 0xd1, 0x23, 0x9e, 0x4f, 0x78, 0xe2, 0x0e, 0xf7, 0xb9, 0x2d,
		0x56, 0x3d, 0x76, 0x7d, 0xff, 0x82, 0x52, 0x8f, 0x86, 0x3d, 0xcb, 0xbc, 0xe3, 0x03, 0xf2, 0x8e,
		0xcb, 0xe3, 0x34, 0x20, 0xef, 0x78, 0x87, 0x75, 0x31, 0x79, 0xc7, 0x15, 0x26, 0x1f, 0x78, 0x67,
		0x2b, 0x05, 0xb4, 0xde, 0x00, 0xd7, 0x1b, 0xf0, 0x7a, 0x01, 0x60, 0x1b, 0xba, 0x48, 0xde, 0xb1,
		0x80, 0x9d, 0x49, 0xde, 0xb1, 0x4f, 0xa7, 0x01, 0x79, 0xc7, 0x9b, 0x9b, 0x4b, 0xa4, 0x3e, 0x61,
		0x47, 0x60, 0x47, 0x60, 0x47, 0x60, 0x47, 0xac, 0x3c, 0x6f, 0xa4, 0x3e, 0x95, 0x42, 0x05, 0x93,
		0x77, 0x8c, 0xf2, 0x45, 0xf9, 0xa2, 0x7c, 0x51, 0xbe, 0x28, 0x5f, 0x94, 0xaf, 0x07, 0xe5, 0x4b,
		0xde, 0x31, 0x4a, 0x11, 0xa5, 0x88, 0x52, 0x44, 0x29, 0xfa, 0x56, 0x8a, 0xe4, 0x1d, 0x17, 0xfd,
		0x21, 0xef, 0x58, 0x65, 0x5a, 0xf2, 0x8e, 0x75, 0x45, 0x89, 0xbc, 0xe3, 0x9a, 0x0b, 0x13, 0x79,
		0xc7, 0x7e, 0x29, 0x14, 0x79, 0xc7, 0xcb, 0xc8, 0x5f, 0x59, 0xf2, 0x8e, 0x35, 0x73, 0x45, 0xf7,
		0x4a, 0x91, 0x76, 0x5c, 0xa0, 0x69, 0xaf, 0xbd, 0x6c, 0x97, 0xbb, 0x24, 0xb3, 0xf2, 0xe9, 0x28,
		0xcd, 0xa9, 0x68, 0xa8, 0xe4, 0x7e, 0xfb, 0x3d, 0x07, 0xb2, 0x27, 0x40, 0x4e, 0x4e, 0x05, 0x65,
		0x74, 0xd6, 0x83, 0x24, 0x98, 0x2c, 0xb3, 0x56, 0x53, 0x82, 0x3b, 0xd3, 0xe8, 0x34, 0x26, 0xd8,
		0xa7, 0x31, 0x01, 0x8d, 0x09, 0x4a, 0xe8, 0xdc, 0xa2, 0x31, 0x81, 0x9e, 0x73, 0xca, 0x20, 0xcd,
		0x52, 0x33, 0xad, 0xf2, 0xff, 0x67, 0xef, 0x6d, 0x9b, 0xd3, 0x48, 0x96, 0xf4, 0xef, 0xf7, 0xfe,
		0x14, 0x04, 0xb1, 0x2f, 0x66, 0x22, 0xa6, 0xc7, 0x12, 0x46, 0xd2, 0x78, 0xde, 0xc9, 0x32, 0xb6,
		0xd9, 0xa3, 0x07, 0x6e, 0x81, 0x3c, 0x33, 0x7f, 0x1f, 0x2d, 0xd1, 0x86, 0xb6, 0xdc, 0xb1, 0xa8,
		0x61, 0xa1, 0xf1, 0xd8, 0x71, 0x46, 0xdf, 0xfd, 0x0e, 0x9e, 0x1a, 0x21, 0x24, 0x5b, 0x36, 0x95,
		0x99, 0xd5, 0xcd, 0x8f, 0xd8, 0xd8, 0xd1, 0xb1, 0x2d, 0x8a, 0x2e, 0x32, 0xf3, 0xca, 0x2b, 0xb3,
		0xf2, 0xaa, 0xec, 0x18, 0xe5, 0xaf, 0xbf, 0xce, 0xc7, 0xd9, 0x9e, 0xae, 0x46, 0xca, 0x2d, 0x40,
		0x20, 0xa1, 0xbb, 0x25, 0x64, 0xef, 0x94, 0xe0, 0x32, 0x1c, 0x30, 0x07, 0xcc, 0xd9, 0xce, 0xcb,
		0x70, 0x64, 0x53, 0x66, 0xd5, 0xd4, 0x59, 0x38, 0x85, 0x16, 0x0f, 0x6b, 0x1a, 0xe1, 0x4d, 0x2f,
		0xcc, 0x69, 0x85, 0x3b, 0xf5, 0xb0, 0xa7, 0x1e, 0xfe, 0x54, 0xc3, 0xa0, 0x5c, 0x69, 0xab, 0x24,
		0x58, 0xb6, 0x15, 0xef, 0x17, 0x67, 0xfe, 0x12, 0x77, 0xa3, 0x24, 0x8d, 0xd3, 0x2f, 0xb2, 0x53,
		0x50, 0x59, 0x46, 0x26, 0xd8, 0xa8, 0x29, 0xd7, 0xe7, 0x8f, 0xf2, 0x22, 0x1c, 0x29, 0x4e, 0xe1,
		0x1c, 0xbe, 0xaa, 0xb7, 0x9b, 0x93, 0xff, 0xd7, 0xfa, 0xab, 0x51, 0x93, 0x76, 0xd1, 0x69, 0xc7,
		0x6b, 0xa4, 0xd2, 0x02, 0x57, 0x3a, 0x3d, 0xb3, 0xd8, 0xc6, 0xe6, 0x79, 0xab, 0xd6, 0x6e, 0x9c,
		0x1d, 0xd7, 0x8f, 0xfe, 0x6a, 0xd7, 0x1b, 0x6f, 0xf7, 0x15, 0x4e, 0x94, 0xfc, 0x52, 0xb4, 0x3d,
		0x3c, 0x7e, 0xf6, 0xb6, 0x71, 0x3a, 0xd9, 0xbd, 0x6a, 0xfb, 0xe2, 0xb4, 0x7e, 0x74, 0xd8, 0x6c,
		0xb1, 0x8b, 0x3f, 0xb0, 0x8b, 0xf5, 0xd3, 0x7f, 0x35, 0x5b, 0x87, 0xad, 0x5a, 0xbb, 0xd9, 0x78,
		0xc5, 0x06, 0x6e, 0x64, 0x86, 0x27, 0x17, 0xc7, 0x2d, 0x0c, 0xf1, 0x07, 0xf7, 0xf1, 0x6d, 0xe3,
		0xf4, 0x6d, 0xb5, 0xfd, 0xea, 0xf8, 0xec, 0x8f, 0x66, 0xa3, 0x76, 0xc4, 0x0e, 0x6e, 0x0c, 0x2a,
		0x55, 0xf6, 0xf0, 0x07, 0xbc, 0xb9, 0x32, 0xf1, 0xe6, 0xb7, 0x8d, 0xe3, 0x26, 0xbb, 0xf7, 0xa3,
		0xbb, 0x57, 0x7b, 0xdb, 0x38, 0x65, 0xf7, 0x36, 0x80, 0x62, 0x36, 0xef, 0xfb, 0x37, 0x6f, 0x0a,
		0xc0, 0xc7, 0x87, 0x2f, 0x6a, 0xc7, 0xb5, 0x97, 0xe4, 0x83, 0x2e, 0xf2, 0x41, 0xbc, 0x78, 0xb3,
		0x7c, 0x70, 0x9f, 0x7c, 0x70, 0x63, 0x87, 0x26, 0x1d, 0xdc, 0x68, 0x03, 0xf7, 0x89, 0x88, 0x4e,
		0x1d, 0x9a, 0x5d, 0xdc, 0xcc, 0x9d, 0xd9, 0xbf, 0xcd, 0xbc, 0x59, 0x6f, 0xff, 0x44, 0x57, 0xb8,
		0xcc, 0x5b, 0xdf, 0x23, 0x17, 0xf2, 0xc4, 0x51, 0x12, 0xbe, 0xef, 0x45, 0x5d, 0xf9, 0x2e, 0xf0,
		0x62, 0x21, 0x29, 0xc1, 0x52, 0x1d, 0x11, 0x10, 0xfa, 0xcc, 0xdf, 0xf1, 0x95, 0xd3, 0x67, 0xfe,
		0xe1, 0x05, 0xe9, 0x33, 0xfb, 0x82, 0xde, 0x8a, 0x7d, 0x66, 0x79, 0x91, 0x0e, 0x61, 0x71, 0x0e,
		0x66, 0x63, 0xdc, 0x7e, 0x5b, 0xc6, 0xb3, 0x31, 0x62, 0xf7, 0x53, 0x98, 0x0d, 0xc6, 0x48, 0x5c,
		0x47, 0xe1, 0xe7, 0xa1, 0xe4, 0xab, 0x61, 0xd8, 0x89, 0x3e, 0x8c, 0x7b, 0xc1, 0x30, 0x1a, 0xa5,
		0xe1, 0x30, 0x95, 0x3b, 0x9e, 0xbc, 0xb6, 0x12, 0x07, 0x95, 0x39, 0xa8, 0x6c, 0x9e, 0x49, 0x71,
		0x50, 0x59, 0x0f, 0x06, 0xc5, 0x0e, 0x2a, 0x0b, 0x4d, 0x56, 0xac, 0xb9, 0x93, 0xe8, 0x45, 0x4c,
		0x6a, 0xb7, 0xe7, 0x40, 0x19, 0xa1, 0x8c, 0x50, 0x46, 0x1f, 0x28, 0xa3, 0xfc, 0xed, 0x39, 0xc2,
		0x55, 0x3b, 0xe5, 0xea, 0x9d, 0x76, 0x15, 0x4f, 0xa9, 0x9a, 0xa7, 0x16, 0xa2, 0x35, 0x43, 0xb5,
		0x7e, 0xc8, 0xd6, 0x0e, 0xdd, 0x66, 0x21, 0xdc, 0x2c, 0x94, 0x9b, 0x84, 0x74, 0xd9, 0xd0, 0x2e,
		0x1c, 0xe2, 0xb3, 0x1d, 0x43, 0xca, 0xd7, 0x63, 0x03, 0x40, 0x87, 0xea, 0xde, 0xe2, 0x9b, 0x6d,
		0x55, 0xf1, 0x6e, 0xbd, 0xa8, 0xc0, 0xd7, 0xe0, 0xbe, 0x9e, 0x3f, 0xea, 0xf9, 0xec, 0x49, 0xb9,
		0x0d, 0x97, 0xdb, 0x70, 0xbf, 0x23, 0x59, 0xe4, 0x36, 0x5c, 0xf8, 0x3c, 0x7c, 0x1e, 0x3e, 0x0f,
		0x9f, 0x87, 0xcf, 0xc3, 0xe7, 0xe1, 0xf3, 0xf0, 0x79, 0xf8, 0x3c, 0x7c, 0x1e, 0x3e, 0xef, 0x3b,
		0x9f, 0x2f, 0xac, 0xbc, 0xf4, 0x5d, 0x3a, 0x8f, 0xca, 0x74, 0x5e, 0x7c, 0xc5, 0x37, 0x1f, 0x29,
		0xd2, 0x99, 0xba, 0x3b, 0x5e, 0xb1, 0x0d, 0x87, 0xeb, 0xe2, 0xc1, 0xa7, 0x6a, 0xd0, 0x0b, 0xdf,
		0x47, 0xbd, 0xa8, 0x1b, 0x8c, 0x93, 0xb8, 0x13, 0x8e, 0x04, 0x0f, 0xd8, 0xdd, 0xbb, 0x1a, 0x87,
		0xec, 0x38, 0x64, 0x67, 0x4e, 0x74, 0x38, 0x64, 0xa7, 0x87, 0x90, 0x62, 0x87, 0xec, 0x66, 0x16,
		0x12, 0xf4, 0xe2, 0xeb, 0x38, 0x95, 0xaf, 0xcc, 0xaf, 0xac, 0xc6, 0x81, 0x3b, 0xab, 0xaa, 0x0f,
		0x05, 0xfa, 0xfc, 0x55, 0x75, 0x28, 0xd0, 0xab, 0x07, 0xc7, 0x6c, 0x01, 0xe1, 0x93, 0xc8, 0x6b,
		0x6e, 0x29, 0xde, 0x13, 0x57, 0x08, 0x94, 0x6a, 0x01, 0x53, 0x33, 0x70, 0xea, 0x07, 0x50, 0xed,
		0x40, 0x6a, 0x16, 0x50, 0xcd, 0x02, 0xab, 0x49, 0x80, 0x95, 0xaf, 0x96, 0x96, 0x14, 0xca, 0xe5,
		0xd2, 0x81, 0x37, 0x5b, 0xe8, 0x3a, 0xfc, 0x1c, 0xcc, 0xac, 0x70, 0xaa, 0xed, 0xab, 0xac, 0xa3,
		0xb1, 0xb2, 0xba, 0x92, 0x31, 0xea, 0x5e, 0x18, 0xaa, 0x16, 0xa4, 0x2d, 0x82, 0xb5, 0x5d, 0xd0,
		0xb6, 0x0a, 0xde, 0xe6, 0x41, 0xdc, 0x3c, 0x98, 0x9b, 0x06, 0x75, 0x9d, 0xe0, 0xae, 0x14, 0xe4,
		0xb3, 0x9d, 0x54, 0xeb, 0x8d, 0xae, 0xf9, 0xeb, 0x38, 0x4e, 0xd2, 0x67, 0x15, 0x4d, 0x7f, 0x9d,
		0x47, 0xdf, 0x03, 0xc5, 0x25, 0x75, 0xaf, 0x6e, 0x5f, 0xbc, 0x74, 0xe3, 0x51, 0xc9, 0xea, 0x2a,
		0x77, 0x23, 0x58, 0x5d, 0x5b, 0xde, 0xe8, 0x6a, 0xf7, 0x6c, 0x7d, 0xc3, 0x5b, 0xb9, 0x95, 0xc3,
		0xd5, 0xaa, 0xc9, 0x19, 0x5c, 0xf9, 0xee, 0x9b, 0xc9, 0x55, 0x2b, 0xcf, 0xab, 0xcf, 0xf7, 0x0f,
		0x2a, 0xcf, 0xf7, 0xb6, 0xd8, 0xf6, 0x9e, 0x14, 0x73, 0xb5, 0xcb, 0x82, 0xdc, 0x78, 0xaf, 0x10,
		0x1b, 0x26, 0x79, 0xf0, 0xa7, 0x28, 0x49, 0x83, 0x34, 0x0a, 0x87, 0xdd, 0xfe, 0xdf, 0x89, 0x3e,
		0x9d, 0x5c, 0xfb, 0x04, 0x4a, 0x09, 0x9c, 0xf2, 0x71, 0x5c, 0xa8, 0x2c, 0x54, 0x16, 0x2a, 0x0b,
		0x95, 0x85, 0xca, 0x9a, 0x1c, 0xf7, 0xbd, 0x1b, 0x7e, 0x85, 0x8f, 0xfd, 0x16, 0x2b, 0x49, 0x98,
		0x1f, 0xd4, 0x0b, 0xd2, 0xf8, 0x3a, 0x1a, 0xea, 0x67, 0x08, 0xab, 0xcb, 0x03, 0xd3, 0xc0, 0x34,
		0x30, 0x0d, 0x4c, 0x03, 0xd3, 0x6a, 0xfe, 0xda, 0x8d, 0x3a, 0xf1, 0x75, 0xd8, 0xdb, 0xaf, 0x5a,
		0x00, 0x75, 0x45, 0x71, 0xcd, 0xb5, 0xa2, 0x4c, 0x85, 0x92, 0xb7, 0xfb, 0x07, 0xf5, 0xa1, 0xe4,
		0x5d, 0xa1, 0xe4, 0x4d, 0xc9, 0x5b, 0xd7, 0xe4, 0x9e, 0x61, 0x72, 0x54, 0xba, 0xdd, 0xbe, 0xa8,
		0x74, 0x3f, 0xde, 0x0c, 0xff, 0x0e, 0x87, 0x49, 0x9c, 0x5c, 0x05, 0xe9, 0xc7, 0x61, 0x34, 0xfa,
		0xd8, 0xef, 0x75, 0x83, 0x41, 0x27, 0xd5, 0x27, 0xb3, 0xf7, 0x7f, 0x0c, 0x48, 0x2d, 0xa4, 0x16,
		0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xaa, 0xf9, 0xeb, 0x20, 0x1a, 0x76, 0xa2, 0x24, 0x0d, 0xaf, 0x22,
		0x03, 0x56, 0xbb, 0x07, 0xaf, 0x2c, 0x26, 0xaf, 0xe4, 0x28, 0x15, 0xbc, 0x72, 0xcb, 0x4c, 0x6e,
		0x77, 0x07, 0x66, 0x09, 0xb3, 0xf4, 0x95, 0x59, 0xe6, 0x7a, 0xa2, 0x48, 0x49, 0x35, 0x29, 0x5b,
		0xcf, 0x58, 0x19, 0xe6, 0x3e, 0x71, 0x8f, 0xa7, 0xb7, 0x87, 0xe4, 0x9f, 0xaa, 0x8c, 0x82, 0x96,
		0x2c, 0x15, 0x64, 0xea, 0x83, 0x4f, 0xd5, 0xe3, 0xd9, 0x16, 0x5c, 0xcc, 0x76, 0xa0, 0x3d, 0x63,
		0xb5, 0xc7, 0x93, 0x0d, 0x10, 0x55, 0x4d, 0x96, 0xf7, 0x99, 0x1b, 0x51, 0x21, 0x2c, 0x49, 0x35,
		0xe5, 0x35, 0xfa, 0x20, 0x2d, 0xec, 0x55, 0xb2, 0x98, 0x49, 0xae, 0x30, 0x93, 0x9c, 0x9f, 0x7a,
		0x0c, 0x33, 0xc9, 0xcc, 0x24, 0x7f, 0x73, 0xc7, 0x98, 0x49, 0x2e, 0x08, 0xfd, 0xa2, 0x98, 0x5e,
		0xa8, 0xe0, 0x6d, 0x1e, 0xc4, 0xcd, 0x83, 0xb9, 0x69, 0x50, 0xd7, 0x25, 0xd4, 0xcc, 0x24, 0x8b,
		0x45, 0x5f, 0x66, 0x92, 0x05, 0x1e, 0x94, 0x42, 0x3a, 0x85, 0x74, 0x6d, 0x93, 0xa3, 0x90, 0xce,
		0x4c, 0x32, 0xf5, 0x74, 0xef, 0x9f, 0x87, 0x99, 0x64, 0x51, 0xb6, 0xce, 0x4c, 0x32, 0x54, 0x16,
		0x2a, 0x0b, 0x95, 0x85, 0xca, 0x32, 0x93, 0x4c, 0x92, 0xf0, 0xb5, 0x3d, 0x63, 0x26, 0x19, 0x98,
		0x06, 0xa6, 0x81, 0x69, 0x60, 0x7a, 0x3b, 0x61, 0x9a, 0x99, 0x64, 0x8d, 0xc5, 0x29, 0x79, 0x2b,
		0x9a, 0x15, 0x33, 0xc9, 0x94, 0xbc, 0x95, 0x4d, 0x8e, 0x99, 0x64, 0x2a, 0xdd, 0x8e, 0x5f, 0x54,
		0xba, 0x1f, 0x6f, 0x86, 0xcc, 0x24, 0x43, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x96,
		0x99, 0x64, 0x78, 0x65, 0xae, 0xa1, 0x95, 0x24, 0x1f, 0x5e, 0xc9, 0x4c, 0x32, 0xcc, 0x12, 0x66,
		0x69, 0xba, 0x02, 0x33, 0xc9, 0xca, 0x33, 0xc9, 0x1a, 0x93, 0xa0, 0x25, 0x8f, 0x47, 0x92, 0x9b,
		0xd3, 0xe7, 0xcf, 0xeb, 0x44, 0x72, 0xae, 0xae, 0x76, 0x56, 0xf2, 0x3d, 0xef, 0x7d, 0xae, 0x2c,
		0x3a, 0x47, 0xee, 0xa3, 0x97, 0xc9, 0xf8, 0x97, 0x7b, 0xeb, 0x77, 0xfb, 0x8e, 0x8e, 0xfd, 0x48,
		0xda, 0x7f, 0x7c, 0xf4, 0x1b, 0x01, 0x57, 0xf1, 0xc8, 0x45, 0xdc, 0xba, 0x85, 0x3b, 0xe3, 0x75,
		0x68, 0xb8, 0xe5, 0xe9, 0xb7, 0xba, 0xf8, 0x36, 0x5d, 0x9b, 0x6d, 0x56, 0x7a, 0x5a, 0x59, 0xc5,
		0xb1, 0xdb, 0xc9, 0xc8, 0x58, 0x88, 0x95, 0xf2, 0x25, 0x4b, 0xf6, 0xf2, 0xa5, 0x79, 0xe9, 0x12,
		0xbc, 0x5a, 0xa9, 0x5d, 0xad, 0xa4, 0xae, 0x52, 0x3a, 0xf7, 0x1b, 0x18, 0xa5, 0x64, 0x22, 0xca,
		0x9d, 0x85, 0x8f, 0x0a, 0x19, 0xe3, 0xc2, 0x9d, 0x44, 0x85, 0xa1, 0x84, 0x75, 0x78, 0xc4, 0x7b,
		0x92, 0x1a, 0x3d, 0x48, 0xbd, 0x9e, 0xa3, 0x56, 0x8f, 0x51, 0xbd, 0xa7, 0xa8, 0xde, 0x43, 0x54,
		0xed, 0x19, 0xe6, 0x8b, 0x69, 0x4b, 0xeb, 0xe6, 0x94, 0x47, 0x51, 0xd2, 0x0d, 0xba, 0xb3, 0x79,
		0xbf, 0x60, 0xd8, 0x1f, 0xab, 0x6a, 0x97, 0xad, 0xaf, 0x2d, 0x2d, 0x43, 0xa4, 0x3b, 0xd8, 0xa8,
		0xd4, 0x86, 0x50, 0x3b, 0x4c, 0x82, 0x70, 0x5a, 0xae, 0x03, 0xbb, 0x59, 0x80, 0x37, 0x09, 0xf4,
		0xb2, 0x01, 0x5f, 0x38, 0xf0, 0x67, 0x3b, 0xa6, 0x76, 0x08, 0xc4, 0x60, 0xf0, 0x50, 0x69, 0xe0,
		0x90, 0xaa, 0xfd, 0xdc, 0xf9, 0xb6, 0xa8, 0x6a, 0xbf, 0xa8, 0xd6, 0x8b, 0x0b, 0xf5, 0x9a, 0x16,
		0x21, 0x17, 0x05, 0x7a, 0x49, 0x35, 0x5e, 0x81, 0xda, 0xbc, 0x40, 0xb1, 0x69, 0xa5, 0x2b, 0x23,
		0xce, 0xf2, 0x15, 0x7a, 0x40, 0x70, 0x7d, 0xb8, 0x3e, 0x5c, 0x1f, 0xae, 0xef, 0x72, 0x01, 0xe1,
		0x22, 0xe8, 0x9a, 0x5b, 0xaa, 0xa8, 0xe4, 0xab, 0x8b, 0x93, 0xc3, 0xb1, 0xe1, 0xd8, 0x70, 0xec,
		0x22, 0x71, 0x6c, 0xc4, 0xc9, 0xa5, 0x83, 0x33, 0x53, 0x75, 0x79, 0x0e, 0xda, 0x56, 0xc1, 0xdb,
		0x3c, 0x88, 0x9b, 0x07, 0x73, 0xd3, 0xa0, 0xae, 0x13, 0xdc, 0x95, 0x82, 0x7c, 0xb6, 0x93, 0x88,
		0x93, 0x8b, 0x2e, 0xc9, 0x44, 0x5d, 0xf1, 0x60, 0x75, 0x6d, 0x79, 0x26, 0xea, 0x98, 0xa8, 0x33,
		0x32, 0x39, 0xc4, 0xc9, 0x19, 0xac, 0xf3, 0xfd, 0x79, 0x10, 0x27, 0x17, 0x65, 0xeb, 0x88, 0x93,
		0x43, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0xa8, 0x2c, 0xe2, 0xe4, 0x24, 0x09, 0x5f, 0xdb, 0x33, 0xc4,
		0xc9, 0x81, 0x69, 0x60, 0x1a, 0x98, 0x06, 0xa6, 0xb7, 0x13, 0xa6, 0x11, 0x27, 0xd7, 0x58, 0x9c,
		0x92, 0xb7, 0xa2, 0x59, 0x21, 0x4e, 0x4e, 0xc9, 0x5b, 0xd9, 0xe4, 0x10, 0x27, 0xa7, 0xd2, 0xed,
		0xf8, 0x45, 0xa5, 0xfb, 0xf1, 0x66, 0x88, 0x38, 0x39, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x85, 0xd4,
		0x42, 0x6a, 0x11, 0x27, 0x87, 0x57, 0xe6, 0x1a, 0x5a, 0x49, 0xf2, 0xe1, 0x95, 0x88, 0x93, 0xc3,
		0x2c, 0x61, 0x96, 0xa6, 0x2b, 0x20, 0x4e, 0x2e, 0x27, 0xb9, 0xb0, 0x22, 0x4a, 0xae, 0x32, 0x02,
		0x5a, 0xf2, 0x45, 0x87, 0xe1, 0xb6, 0x1c, 0xb9, 0xa4, 0x26, 0x83, 0xbc, 0x93, 0xdc, 0x88, 0x2a,
		0x66, 0x84, 0xaa, 0x2a, 0x63, 0x0a, 0xba, 0xf8, 0xea, 0x43, 0xc8, 0x15, 0x86, 0x90, 0xf3, 0x53,
		0x80, 0x61, 0x08, 0x99, 0x21, 0xe4, 0x6f, 0xee, 0x18, 0x43, 0xc8, 0x05, 0xe1, 0x5b, 0x54, 0xcf,
		0x0b, 0x15, 0xbc, 0xcd, 0x83, 0xb8, 0x79, 0x30, 0x37, 0x0d, 0xea, 0xba, 0x0c, 0x9a, 0x21, 0x64,
		0xb1, 0xe8, 0xcb, 0x10, 0xb2, 0xc0, 0x83, 0x52, 0x39, 0xa7, 0x72, 0xae, 0x6d, 0x72, 0x54, 0xce,
		0x19, 0x42, 0xa6, 0x80, 0xee, 0xfd, 0xf3, 0x30, 0x84, 0x2c, 0xca, 0xd6, 0x19, 0x42, 0x86, 0xca,
		0x42, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0x86, 0x90, 0x49, 0x12, 0xbe, 0xb6, 0x67, 0x0c, 0x21, 0x03,
		0xd3, 0xc0, 0x34, 0x30, 0x0d, 0x4c, 0x6f, 0x27, 0x4c, 0x33, 0x84, 0xac, 0xb1, 0x38, 0x25, 0x6f,
		0x45, 0xb3, 0x62, 0x08, 0x99, 0x92, 0xb7, 0xb2, 0xc9, 0x31, 0x84, 0x4c, 0xa5, 0xdb, 0xf1, 0x8b,
		0x4a, 0xf7, 0xe3, 0xcd, 0x90, 0x21, 0x64, 0x48, 0x2d, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x85, 0xd4,
		0x32, 0x84, 0x0c, 0xaf, 0xcc, 0x35, 0xb4, 0x92, 0xe4, 0xc3, 0x2b, 0x19, 0x42, 0x86, 0x59, 0xc2,
		0x2c, 0x4d, 0x57, 0x60, 0x08, 0x59, 0x69, 0x08, 0x59, 0x63, 0x02, 0xb4, 0xe4, 0xe3, 0x0c, 0x72,
		0x73, 0xfa, 0xe0, 0x79, 0x1d, 0x41, 0xce, 0xd5, 0xe5, 0xcd, 0x4a, 0xce, 0xe6, 0xad, 0x93, 0x95,
		0x45, 0x07, 0xc6, 0xbd, 0x72, 0x2b, 0x19, 0x87, 0x72, 0x6f, 0xee, 0x02, 0xa6, 0x2e, 0x3c, 0xbb,
		0xaf, 0x32, 0xb3, 0x2f, 0x3c, 0xab, 0x2f, 0x3e, 0xa3, 0xaf, 0x51, 0xa7, 0xd4, 0xab, 0x4b, 0x6a,
		0xd5, 0x21, 0xd5, 0xeb, 0x8e, 0xea, 0x75, 0x46, 0xd5, 0xba, 0x62, 0xbe, 0xc0, 0x59, 0x7a, 0xb6,
		0xbe, 0x3c, 0x8a, 0x92, 0x6e, 0xd0, 0x9d, 0xcd, 0x04, 0x04, 0xc3, 0xfe, 0x58, 0x55, 0xdf, 0x64,
		0x7d, 0x6d, 0x69, 0xa9, 0x02, 0xdd, 0xe1, 0x07, 0xa5, 0x52, 0x85, 0x5a, 0xc3, 0x09, 0x71, 0x95,
		0x5c, 0x07, 0x76, 0xb3, 0x00, 0x6f, 0x12, 0xe8, 0x8b, 0x51, 0x0a, 0x51, 0x6b, 0x14, 0x19, 0x0c,
		0x27, 0x28, 0x0d, 0x25, 0x40, 0xf4, 0xb7, 0x97, 0xe8, 0x4b, 0x17, 0xd0, 0xbc, 0x60, 0xf8, 0x82,
		0xc5, 0x32, 0x01, 0x6e, 0xff, 0xc4, 0x63, 0x5f, 0x91, 0xf6, 0x11, 0x9f, 0x7c, 0xa3, 0x2c, 0x52,
		0x64, 0x31, 0xf7, 0x06, 0xb7, 0x7e, 0xe0, 0xce, 0x5a, 0x1d, 0x5a, 0x6a, 0x39, 0x1e, 0x7c, 0xda,
		0x0f, 0x7a, 0xe1, 0xfb, 0xa8, 0x17, 0x75, 0xb3, 0xaf, 0xd3, 0xb5, 0xbd, 0x66, 0x09, 0xc1, 0xbd,
		0xab, 0x39, 0xf6, 0x3b, 0x99, 0xca, 0x96, 0x18, 0x31, 0x92, 0x24, 0x42, 0xf2, 0xc4, 0x47, 0x9a,
		0xe8, 0xa8, 0x11, 0x1b, 0x35, 0x22, 0xa3, 0x42, 0x5c, 0xfc, 0x46, 0x46, 0xa9, 0x4a, 0x54, 0x79,
		0xa5, 0x17, 0x23, 0x5e, 0x9f, 0x57, 0xe8, 0xfc, 0xa8, 0x95, 0xe9, 0x77, 0x28, 0xd3, 0xfb, 0x53,
		0xd5, 0xa1, 0x4c, 0xbf, 0xc5, 0xd4, 0x5a, 0xbc, 0x4c, 0xdf, 0x59, 0xf8, 0xbc, 0x52, 0x69, 0x5e,
		0x45, 0xfd, 0x5e, 0x5d, 0x7b, 0x9c, 0xf2, 0x78, 0x0e, 0x02, 0xa9, 0x59, 0x40, 0x35, 0x0b, 0xac,
		0x26, 0x01, 0x56, 0xbe, 0x3a, 0x5a, 0x42, 0x7b, 0xdc, 0x95, 0x93, 0xa3, 0x3d, 0x9e, 0xeb, 0x60,
		0x6d, 0x17, 0xb4, 0xad, 0x82, 0xb7, 0x79, 0x10, 0x37, 0x0f, 0xe6, 0xa6, 0x41, 0x5d, 0x27, 0xb8,
		0x2b, 0x05, 0xf9, 0x6c, 0x27, 0xd1, 0x1e, 0x17, 0x5d, 0x92, 0x81, 0xb9, 0xe2, 0xc1, 0xea, 0xda,
		0xf2, 0x0c, 0xcc, 0x31, 0x30, 0x67, 0x64, 0x72, 0x68, 0x8f, 0x33, 0x37, 0xe7, 0xfb, 0xf3, 0xa0,
		0x3d, 0x2e, 0xca, 0xd6, 0xd1, 0x1e, 0x87, 0xca, 0x42, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0xb4, 0xc7,
		0x49, 0x12, 0xbe, 0xb6, 0x67, 0x68, 0x8f, 0x03, 0xd3, 0xc0, 0x34, 0x30, 0x0d, 0x4c, 0x6f, 0x27,
		0x4c, 0xa3, 0x3d, 0xae, 0xb1, 0x38, 0x25, 0x6f, 0x45, 0xb3, 0x42, 0x7b, 0x9c, 0x92, 0xb7, 0xb2,
		0xc9, 0xa1, 0x3d, 0x4e, 0xa5, 0xdb, 0xf1, 0x8b, 0x4a, 0xf7, 0xe3, 0xcd, 0x10, 0xed, 0x71, 0x48,
		0x2d, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0xa2, 0x3d, 0x0e, 0xaf, 0xcc, 0x35, 0xb4, 0x92,
		0xe4, 0xc3, 0x2b, 0xd1, 0x1e, 0x87, 0x59, 0xc2, 0x2c, 0x4d, 0x57, 0x40, 0x7b, 0xdc, 0xb5, 0x22,
		0xcc, 0x9a, 0xb8, 0xc7, 0xaa, 0x06, 0xb9, 0xca, 0x28, 0x68, 0xc9, 0x58, 0x3d, 0x66, 0xff, 0x78,
		0xb6, 0x05, 0xf7, 0x69, 0x91, 0xcf, 0x29, 0x75, 0x5e, 0x35, 0xca, 0x44, 0xc5, 0xaf, 0x42, 0x55,
		0xbd, 0x50, 0x05, 0x35, 0x7c, 0xf5, 0x99, 0xe4, 0x0a, 0x33, 0xc9, 0xf9, 0xa9, 0xc7, 0x30, 0x93,
		0xcc, 0x4c, 0xf2, 0x37, 0x77, 0x8c, 0x99, 0xe4, 0x82, 0xd0, 0x2f, 0x8a, 0xe9, 0x85, 0x0a, 0xde,
		0xe6, 0x41, 0xdc, 0x3c, 0x98, 0x9b, 0x06, 0x75, 0x5d, 0x42, 0xcd, 0x4c, 0xb2, 0x58, 0xf4, 0x65,
		0x26, 0x59, 0xe0, 0x41, 0x29, 0xa4, 0x53, 0x48, 0xd7, 0x36, 0x39, 0x0a, 0xe9, 0xcc, 0x24, 0x53,
		0x4f, 0xf7, 0xfe, 0x79, 0x98, 0x49, 0x16, 0x65, 0xeb, 0xcc, 0x24, 0x43, 0x65, 0xa1, 0xb2, 0x50,
		0x59, 0xa8, 0x2c, 0x33, 0xc9, 0x24, 0x09, 0x5f, 0xdb, 0x33, 0x66, 0x92, 0x81, 0x69, 0x60, 0x1a,
		0x98, 0x06, 0xa6, 0xb7, 0x13, 0xa6, 0x99, 0x49, 0xd6, 0x58, 0x9c, 0x92, 0xb7, 0xa2, 0x59, 0x31,
		0x93, 0x4c, 0xc9, 0x5b, 0xd9, 0xe4, 0x98, 0x49, 0xa6, 0xd2, 0xed, 0xf8, 0x45, 0xa5, 0xfb, 0xf1,
		0x66, 0xc8, 0x4c, 0x32, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x99, 0x49, 0x86,
		0x57, 0xe6, 0x1a, 0x5a, 0x49, 0xf2, 0xe1, 0x95, 0xcc, 0x24, 0xc3, 0x2c, 0x61, 0x96, 0xa6, 0x2b,
		0x30, 0x93, 0xac, 0x3c, 0x93, 0xac, 0x31, 0x09, 0x5a, 0xf2, 0x78, 0x24, 0xb9, 0x39, 0x7d, 0xfe,
		0xbc, 0x4e, 0x24, 0xe7, 0xea, 0x6a, 0x67, 0x25, 0xdf, 0xf3, 0xde, 0xe7, 0xca, 0xa2, 0x73, 0xe4,
		0x3e, 0x7a, 0x99, 0x8c, 0x7f, 0xb9, 0xb7, 0x7e, 0xb7, 0xef, 0xe8, 0xd8, 0x8f, 0xa4, 0xfd, 0xc7,
		0x47, 0xbf, 0x11, 0x70, 0x15, 0x8f, 0x5c, 0xc4, 0xad, 0x5b, 0xb8, 0x33, 0x5e, 0x87, 0x86, 0x5b,
		0x9e, 0x7e, 0xab, 0x8b, 0x6f, 0xd3, 0xb5, 0xd9, 0x66, 0xa5, 0xa7, 0x95, 0x55, 0x1c, 0xbb, 0x9d,
		0x8c, 0x8c, 0x85, 0x58, 0x29, 0x5f, 0xb2, 0x64, 0x2f, 0x5f, 0x9a, 0x97, 0x2e, 0xc1, 0xab, 0x95,
		0xda, 0xd5, 0x4a, 0xea, 0x2a, 0xa5, 0x73, 0xbf, 0x81, 0x51, 0x4a, 0x26, 0xa2, 0xdc, 0x59, 0xf8,
		0xa8, 0x90, 0x31, 0x2e, 0xdc, 0x49, 0x54, 0x18, 0x4a, 0x58, 0x87, 0x47, 0xbc, 0x27, 0xa9, 0xd1,
		0x83, 0xd4, 0xeb, 0x39, 0x6a, 0xf5, 0x18, 0xd5, 0x7b, 0x8a, 0xea, 0x3d, 0x44, 0xd5, 0x9e, 0x61,
		0xbe, 0x98, 0xb6, 0xb4, 0x6e, 0x4e, 0x79, 0x14, 0x25, 0xdd, 0xa0, 0x3b, 0x9b, 0xf7, 0x0b, 0x86,
		0xfd, 0xb1, 0xaa, 0x76, 0xd9, 0xfa, 0xda, 0xd2, 0x32, 0x44, 0xba, 0x83, 0x8d, 0x4a, 0x6d, 0x08,
		0xb5, 0xc3, 0x24, 0x08, 0xa7, 0xe5, 0x3a, 0xb0, 0x9b, 0x05, 0x78, 0x93, 0x40, 0x2f, 0x1b, 0xf0,
		0x85, 0x03, 0x7f, 0xb6, 0x63, 0x6a, 0x87, 0x40, 0x0c, 0x06, 0x0f, 0x95, 0x06, 0x0e, 0xa9, 0xda,
		0xcf, 0x9d, 0x6f, 0x8b, 0xaa, 0xf6, 0x8b, 0x6a, 0xbd, 0xb8, 0x50, 0xaf, 0x69, 0x11, 0x72, 0x51,
		0xa0, 0x97, 0x54, 0xe3, 0x15, 0xa8, 0xcd, 0x0b, 0x14, 0x9b, 0x56, 0xba, 0x32, 0xe2, 0x2c, 0x5f,
		0xa1, 0x07, 0x04, 0xd7, 0x87, 0xeb, 0xc3, 0xf5, 0xe1, 0xfa, 0x2e, 0x17, 0x10, 0x2e, 0x82, 0xae,
		0xb9, 0xa5, 0x8a, 0x4a, 0xbe, 0xba, 0x38, 0x39, 0x1c, 0x1b, 0x8e, 0x0d, 0xc7, 0x2e, 0x12, 0xc7,
		0x46, 0x9c, 0x5c, 0x3a, 0x38, 0x33, 0x55, 0x97, 0xe7, 0xa0, 0x6d, 0x15, 0xbc, 0xcd, 0x83, 0xb8,
		0x79, 0x30, 0x37, 0x0d, 0xea, 0x3a, 0xc1, 0x5d, 0x29, 0xc8, 0x67, 0x3b, 0x89, 0x38, 0xb9, 0xe8,
		0x92, 0x4c, 0xd4, 0x15, 0x0f, 0x56, 0xd7, 0x96, 0x67, 0xa2, 0x8e, 0x89, 0x3a, 0x23, 0x93, 0x43,
		0x9c, 0x9c, 0xc1, 0x3a, 0xdf, 0x9f, 0x07, 0x71, 0x72, 0x51, 0xb6, 0x8e, 0x38, 0x39, 0x54, 0x16,
		0x2a, 0x0b, 0x95, 0x85, 0xca, 0x22, 0x4e, 0x4e, 0x92, 0xf0, 0xb5, 0x3d, 0x43, 0x9c, 0x1c, 0x98,
		0x06, 0xa6, 0x81, 0x69, 0x60, 0x7a, 0x3b, 0x61, 0x1a, 0x71, 0x72, 0x8d, 0xc5, 0x29, 0x79, 0x2b,
		0x9a, 0x15, 0xe2, 0xe4, 0x94, 0xbc, 0x95, 0x4d, 0x0e, 0x71, 0x72, 0x2a, 0xdd, 0x8e, 0x5f, 0x54,
		0xba, 0x1f, 0x6f, 0x86, 0x88, 0x93, 0x43, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x16,
		0x71, 0x72, 0x78, 0x65, 0xae, 0xa1, 0x95, 0x24, 0x1f, 0x5e, 0x89, 0x38, 0x39, 0xcc, 0x12, 0x66,
		0x69, 0xba, 0x02, 0xe2, 0xe4, 0x72, 0x92, 0x0b, 0x2b, 0xa2, 0xe4, 0x2a, 0x23, 0xa0, 0x25, 0x5f,
		0x74, 0x18, 0x6e, 0xcb, 0x91, 0x4b, 0x6a, 0x32, 0xc8, 0x3b, 0xc9, 0x8d, 0xa8, 0x62, 0x46, 0xa8,
		0xaa, 0x32, 0xa6, 0xa0, 0x8b, 0xaf, 0x3e, 0x84, 0x5c, 0x61, 0x08, 0x39, 0x3f, 0x05, 0x18, 0x86,
		0x90, 0x19, 0x42, 0xfe, 0xe6, 0x8e, 0x31, 0x84, 0x5c, 0x10, 0xbe, 0x45, 0xf5, 0xbc, 0x50, 0xc1,
		0xdb, 0x3c, 0x88, 0x9b, 0x07, 0x73, 0xd3, 0xa0, 0xae, 0xcb, 0xa0, 0x19, 0x42, 0x16, 0x8b, 0xbe,
		0x0c, 0x21, 0x0b, 0x3c, 0x28, 0x95, 0x73, 0x2a, 0xe7, 0xda, 0x26, 0x47, 0xe5, 0x9c, 0x21, 0x64,
		0x0a, 0xe8, 0xde, 0x3f, 0x0f, 0x43, 0xc8, 0xa2, 0x6c, 0x9d, 0x21, 0x64, 0xa8, 0x2c, 0x54, 0x16,
		0x2a, 0x0b, 0x95, 0x65, 0x08, 0x99, 0x24, 0xe1, 0x6b, 0x7b, 0xc6, 0x10, 0x32, 0x30, 0x0d, 0x4c,
		0x03, 0xd3, 0xc0, 0xf4, 0x76, 0xc2, 0x34, 0x43, 0xc8, 0x1a, 0x8b, 0x53, 0xf2, 0x56, 0x34, 0x2b,
		0x86, 0x90, 0x29, 0x79, 0x2b, 0x9b, 0x1c, 0x43, 0xc8, 0x54, 0xba, 0x1d, 0xbf, 0xa8, 0x74, 0x3f,
		0xde, 0x0c, 0x19, 0x42, 0x86, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d, 0x43, 0xc8,
		0xf0, 0xca, 0x5c, 0x43, 0x2b, 0x49, 0x3e, 0xbc, 0x92, 0x21, 0x64, 0x98, 0x25, 0xcc, 0xd2, 0x74,
		0x05, 0x86, 0x90, 0x95, 0x86, 0x90, 0x35, 0x26, 0x40, 0x4b, 0x3e, 0xce, 0x20, 0x37, 0xa7, 0x0f,
		0x9e, 0xd7, 0x11, 0xe4, 0x5c, 0x5d, 0xde, 0xac, 0xe4, 0x6c, 0xde, 0x3a, 0x59, 0x59, 0x74, 0x60,
		0xdc, 0x2b, 0xb7, 0x92, 0x71, 0x28, 0xf7, 0xe6, 0x2e, 0x60, 0xea, 0xc2, 0xb3, 0xfb, 0x2a, 0x33,
		0xfb, 0xc2, 0xb3, 0xfa, 0xe2, 0x33, 0xfa, 0x1a, 0x75, 0x4a, 0xbd, 0xba, 0xa4, 0x56, 0x1d, 0x52,
		0xbd, 0xee, 0xa8, 0x5e, 0x67, 0x54, 0xad, 0x2b, 0xe6, 0x0b, 0x9c, 0xa5, 0x67, 0xeb, 0xcb, 0xa3,
		0x28, 0xe9, 0x06, 0xdd, 0xd9, 0x4c, 0x40, 0x30, 0xec, 0x8f, 0x55, 0xf5, 0x4d, 0xd6, 0xd7, 0x96,
		0x96, 0x2a, 0xd0, 0x1d, 0x7e, 0x50, 0x2a, 0x55, 0xa8, 0x35, 0x9c, 0x10, 0x57, 0xc9, 0x75, 0x60,
		0x37, 0x0b, 0xf0, 0x26, 0x81, 0xbe, 0x18, 0xa5, 0x10, 0xb5, 0x46, 0x91, 0xc1, 0x70, 0x82, 0xd2,
		0x50, 0x02, 0x44, 0x7f, 0x7b, 0x89, 0xbe, 0x74, 0x01, 0xcd, 0x0b, 0x86, 0x2f, 0x58, 0x2c, 0x13,
		0xe0, 0xf6, 0x4f, 0x3c, 0xf6, 0x15, 0x69, 0x1f, 0xf1, 0xc9, 0x37, 0xca, 0x22, 0x45, 0x16, 0x73,
		0x6f, 0x70, 0xeb, 0x07, 0xee, 0xac, 0xd5, 0xa1, 0xa5, 0x96, 0x7b, 0x95, 0x4f, 0x83, 0x24, 0x88,
		0x3e, 0x0d, 0xdc, 0x5b, 0x69, 0x96, 0x06, 0xdc, 0x5a, 0xc3, 0xb1, 0x8f, 0xc9, 0x54, 0xb1, 0xc4,
		0x48, 0x90, 0x24, 0xe9, 0x91, 0x27, 0x39, 0xd2, 0xa4, 0x46, 0x8d, 0xc4, 0xa8, 0x91, 0x16, 0x15,
		0x92, 0xe2, 0x37, 0x0a, 0x4a, 0x55, 0x9d, 0xca, 0x2b, 0x7d, 0x17, 0xf1, 0x5a, 0xbc, 0x42, 0x97,
		0x47, 0xad, 0x24, 0xbf, 0x43, 0x49, 0xde, 0x9f, 0x0a, 0x0e, 0x25, 0xf9, 0x2d, 0xa6, 0xd1, 0xe2,
		0x25, 0xf9, 0xce, 0xc2, 0xe7, 0x95, 0xca, 0xf0, 0x2a, 0x4a, 0xf7, 0xea, 0x3a, 0xe3, 0x94, 0xc2,
		0x73, 0x10, 0x48, 0xcd, 0x02, 0xaa, 0x59, 0x60, 0x35, 0x09, 0xb0, 0xf2, 0x95, 0xd0, 0x12, 0x3a,
		0xe3, 0xae, 0x9c, 0x1c, 0x9d, 0xf1, 0x5c, 0x07, 0x6b, 0xbb, 0xa0, 0x6d, 0x15, 0xbc, 0xcd, 0x83,
		0xb8, 0x79, 0x30, 0x37, 0x0d, 0xea, 0x3a, 0xc1, 0x5d, 0x29, 0xc8, 0x67, 0x3b, 0x89, 0xce, 0xb8,
		0xe8, 0x92, 0x0c, 0xc7, 0x15, 0x0f, 0x56, 0xd7, 0x96, 0x67, 0x38, 0x8e, 0xe1, 0x38, 0x23, 0x93,
		0x43, 0x67, 0x9c, 0x19, 0x39, 0xdf, 0x9f, 0x07, 0x9d, 0x71, 0x51, 0xb6, 0x8e, 0xce, 0x38, 0x54,
		0x16, 0x2a, 0x0b, 0x95, 0x85, 0xca, 0xa2, 0x33, 0x4e, 0x92, 0xf0, 0xb5, 0x3d, 0x43, 0x67, 0x1c,
		0x98, 0x06, 0xa6, 0x81, 0x69, 0x60, 0x7a, 0x3b, 0x61, 0x1a, 0x9d, 0x71, 0x8d, 0xc5, 0x29, 0x79,
		0x2b, 0x9a, 0x15, 0x3a, 0xe3, 0x94, 0xbc, 0x95, 0x4d, 0x0e, 0x9d, 0x71, 0x2a, 0xdd, 0x8e, 0x5f,
		0x54, 0xba, 0x1f, 0x6f, 0x86, 0xe8, 0x8c, 0x43, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d, 0xa4,
		0x16, 0x9d, 0x71, 0x78, 0x65, 0xae, 0xa1, 0x95, 0x24, 0x1f, 0x5e, 0x89, 0xce, 0x38, 0xcc, 0x12,
		0x66, 0x69, 0xba, 0x02, 0x3a, 0xe3, 0x4e, 0xd5, 0x5f, 0x96, 0x92, 0x1e, 0xab, 0x2a, 0xe3, 0x2a,
		0x03, 0xa0, 0x25, 0x4b, 0x7d, 0x98, 0xe3, 0xca, 0xdb, 0x41, 0x52, 0xfb, 0x34, 0x48, 0x56, 0x44,
		0xc6, 0xe7, 0xfc, 0x39, 0xaf, 0xe2, 0x63, 0xa2, 0xaa, 0x56, 0xa1, 0xaa, 0x10, 0xa8, 0x82, 0xcc,
		0xbd, 0xfa, 0x00, 0x72, 0x85, 0x01, 0xe4, 0xfc, 0x14, 0x5f, 0x18, 0x40, 0x66, 0x00, 0xf9, 0x9b,
		0x3b, 0xc6, 0x00, 0x72, 0x41, 0xb8, 0x16, 0x95, 0xf3, 0x42, 0x05, 0x6f, 0xf3, 0x20, 0x6e, 0x1e,
		0xcc, 0x4d, 0x83, 0xba, 0x2e, 0x7b, 0x66, 0x00, 0x59, 0x2c, 0xfa, 0x32, 0x80, 0x2c, 0xf0, 0xa0,
		0x54, 0xcd, 0xa9, 0x9a, 0x6b, 0x9b, 0x1c, 0x55, 0x73, 0x06, 0x90, 0x29, 0x9e, 0x7b, 0xff, 0x3c,
		0x0c, 0x20, 0x8b, 0xb2, 0x75, 0x06, 0x90, 0xa1, 0xb2, 0x50, 0x59, 0xa8, 0x2c, 0x54, 0x96, 0x01,
		0x64, 0x92, 0x84, 0xaf, 0xed, 0x19, 0x03, 0xc8, 0xc0, 0x34, 0x30, 0x0d, 0x4c, 0x03, 0xd3, 0xdb,
		0x09, 0xd3, 0x0c, 0x20, 0x6b, 0x2c, 0x4e, 0xc9, 0x5b, 0xd1, 0xac, 0x18, 0x40, 0xa6, 0xe4, 0xad,
		0x6c, 0x72, 0x0c, 0x20, 0x53, 0xe9, 0x76, 0xfc, 0xa2, 0xd2, 0xfd, 0x78, 0x33, 0x64, 0x00, 0x19,
		0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x0c, 0x20, 0xc3, 0x2b, 0x73, 0x0d, 0xad,
		0x24, 0xf9, 0xf0, 0x4a, 0x06, 0x90, 0x61, 0x96, 0x30, 0x4b, 0xd3, 0x15, 0x18, 0x40, 0x56, 0x19,
		0x40, 0xd6, 0x98, 0xff, 0x2c, 0xf9, 0x37, 0x7f, 0xdc, 0x9c, 0x3e, 0x76, 0x5e, 0xc7, 0x8f, 0x73,
		0x75, 0x69, 0xb3, 0x92, 0xa3, 0x79, 0xea, 0x60, 0x65, 0xd1, 0x51, 0x71, 0x8f, 0x5c, 0x4a, 0xc6,
		0x99, 0xdc, 0x9b, 0xba, 0xdb, 0x77, 0x74, 0xec, 0x34, 0xd2, 0xce, 0xe2, 0x8f, 0x93, 0x08, 0xf8,
		0x85, 0xbd, 0x3f, 0xb8, 0xf5, 0x01, 0x77, 0x96, 0xea, 0xd0, 0x4a, 0xcb, 0xb3, 0xaf, 0xf0, 0xd3,
		0xa0, 0xe7, 0x7e, 0x3c, 0x3a, 0xab, 0x1f, 0xdd, 0x5a, 0xc3, 0xb1, 0x7f, 0xc9, 0x28, 0x51, 0x88,
		0x55, 0xe3, 0x25, 0xab, 0xee, 0xf2, 0xd5, 0x75, 0xe9, 0x2a, 0xba, 0x5a, 0xb5, 0x5c, 0xad, 0x2a,
		0xae, 0x52, 0xfd, 0xf6, 0x1b, 0x01, 0xa5, 0x94, 0x1e, 0xca, 0x2b, 0x59, 0x99, 0x98, 0x49, 0xde,
		0x1a, 0xbd, 0x91, 0xce, 0x01, 0x85, 0x65, 0x75, 0xc4, 0x5b, 0x8c, 0x1a, 0x2d, 0x45, 0xbd, 0x16,
		0xa2, 0x56, 0xcb, 0x50, 0xbd, 0x45, 0xa8, 0xde, 0x12, 0x54, 0x6d, 0x01, 0xe6, 0x8b, 0x4b, 0x4b,
		0xcb, 0xe0, 0x94, 0x3b, 0x0b, 0x9f, 0x57, 0x92, 0x1f, 0x53, 0xd1, 0xbf, 0x53, 0xd7, 0x1f, 0xdb,
		0x41, 0x7f, 0xcc, 0xff, 0x40, 0x6a, 0x16, 0x50, 0xcd, 0x02, 0xab, 0x49, 0x80, 0x95, 0x2f, 0x87,
		0x96, 0xd0, 0x1f, 0x73, 0xe5, 0xe4, 0xe8, 0x8f, 0xe5, 0x3a, 0x58, 0xdb, 0x05, 0x6d, 0xab, 0xe0,
		0x6d, 0x1e, 0xc4, 0xcd, 0x83, 0xb9, 0x69, 0x50, 0xd7, 0x09, 0xee, 0x4a, 0x41, 0x3e, 0xdb, 0x49,
		0xf4, 0xc7, 0x44, 0x97, 0xe4, 0xd0, 0x5c, 0xf1, 0x60, 0x75, 0x6d, 0x79, 0x0e, 0xcd, 0x71, 0x68,
		0xce, 0xc8, 0xe4, 0xd0, 0x1f, 0xe3, 0xec, 0x9c, 0xef, 0xcf, 0x83, 0xfe, 0x98, 0x28, 0x5b, 0x47,
		0x7f, 0x0c, 0x2a, 0x0b, 0x95, 0x85, 0xca, 0x42, 0x65, 0xd1, 0x1f, 0x23, 0x49, 0xf8, 0xda, 0x9e,
		0xa1, 0x3f, 0x06, 0x4c, 0x03, 0xd3, 0xc0, 0x34, 0x30, 0xbd, 0x9d, 0x30, 0x8d, 0xfe, 0x98, 0xc6,
		0xe2, 0x94, 0xbc, 0x15, 0xcd, 0x0a, 0xfd, 0x31, 0x4a, 0xde, 0xca, 0x26, 0x87, 0xfe, 0x18, 0x95,
		0x6e, 0xc7, 0x2f, 0x2a, 0xdd, 0x8f, 0x37, 0x43, 0xf4, 0xc7, 0x20, 0xb5, 0x90, 0x5a, 0x48, 0x2d,
		0xa4, 0x16, 0x52, 0x8b, 0xfe, 0x18, 0xbc, 0x32, 0xd7, 0xd0, 0x4a, 0x92, 0x0f, 0xaf, 0x44, 0x7f,
		0x0c, 0x66, 0x09, 0xb3, 0x34, 0x5d, 0x01, 0xfd, 0x31, 0x01, 0xe5, 0x97, 0x4f, 0x83, 0xe9, 0x6f,
		0xdc, 0xd2, 0x1f, 0x53, 0x19, 0x00, 0x2d, 0x99, 0xab, 0xc3, 0xbc, 0x1d, 0x4c, 0xff, 0xf9, 0x52,
		0x80, 0x6c, 0xce, 0x9f, 0xf3, 0xaa, 0x40, 0x26, 0xaa, 0x6a, 0x15, 0xa6, 0x91, 0xde, 0x04, 0xb2,
		0x86, 0x00, 0x9e, 0xfa, 0x00, 0x72, 0x85, 0x01, 0xe4, 0xfc, 0x14, 0x5f, 0x18, 0x40, 0x66, 0x00,
		0xf9, 0x9b, 0x3b, 0xc6, 0x00, 0x72, 0x41, 0xb8, 0x16, 0x95, 0xf3, 0x42, 0x05, 0x6f, 0xf3, 0x20,
		0x6e, 0x1e, 0xcc, 0x4d, 0x83, 0xba, 0x2e, 0x7b, 0x66, 0x00, 0x59, 0x2c, 0xfa, 0x32, 0x80, 0x2c,
		0xf0, 0xa0, 0x54, 0xcd, 0xa9, 0x9a, 0x6b, 0x9b, 0x1c, 0x55, 0x73, 0x06, 0x90, 0x29, 0x9e, 0x7b,
		0xff, 0x3c, 0x0c, 0x20, 0x8b, 0xb2, 0x75, 0x06, 0x90, 0xa1, 0xb2, 0x50, 0x59, 0xa8, 0x2c, 0x54,
		0x96, 0x01, 0x64, 0x92, 0x84, 0xaf, 0xed, 0x19, 0x03, 0xc8, 0xc0, 0x34, 0x30, 0x0d, 0x4c, 0x03,
		0xd3, 0xdb, 0x09, 0xd3, 0x0c, 0x20, 0x6b, 0x2c, 0x4e, 0xc9, 0x5b, 0xd1, 0xac, 0x18, 0x40, 0xa6,
		0xe4, 0xad, 0x6c, 0x72, 0x0c, 0x20, 0x53, 0xe9, 0x76, 0xfc, 0xa2, 0xd2, 0xfd, 0x78, 0x33, 0x64,
		0x00, 0x19, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x0c, 0x20, 0xc3, 0x2b, 0x73,
		0x0d, 0xad, 0x24, 0xf9, 0xf0, 0x4a, 0x06, 0x90, 0x61, 0x96, 0x30, 0x4b, 0xd3, 0x15, 0x18, 0x40,
		0x56, 0x19, 0x40, 0xd6, 0x98, 0xff, 0x2c, 0xf9, 0x37, 0x7f, 0xdc, 0x9c, 0x3e, 0x76, 0x5e, 0xc7,
		0x8f, 0x73, 0x75, 0x69, 0xb3, 0x92, 0xa3, 0x79, 0xea, 0x60, 0x65, 0xd1, 0x51, 0x71, 0x8f, 0x5c,
		0x4a, 0xc6, 0x99, 0xdc, 0x9b, 0xba, 0xdb, 0x77, 0x74, 0xec, 0x34, 0xd2, 0xce, 0xe2, 0x8f, 0x93,
		0x08, 0xf8, 0x85, 0xbd, 0x3f, 0xb8, 0xf5, 0x01, 0x77, 0x96, 0xea, 0xd0, 0x4a, 0xcb, 0xbd, 0x67,
		0x93, 0xaf, 0x30, 0x1e, 0x7c, 0xaa, 0x06, 0xd7, 0xe3, 0x5e, 0x1a, 0x77, 0xc2, 0x91, 0xfb, 0x52,
		0x7f, 0x56, 0x49, 0xba, 0x77, 0x35, 0xc7, 0x3e, 0x27, 0xa3, 0x4e, 0x21, 0x56, 0xa1, 0x97, 0xac,
		0xc4, 0xcb, 0x57, 0xdc, 0xa5, 0x2b, 0xeb, 0x6a, 0x15, 0x74, 0xb5, 0x4a, 0xb9, 0x4a, 0x45, 0xdc,
		0x6f, 0x54, 0x94, 0x52, 0x7f, 0x28, 0xaf, 0x64, 0x6a, 0x62, 0x26, 0x79, 0x6b, 0x1c, 0x47, 0x3a,
		0x2f, 0x14, 0x96, 0xda, 0x11, 0x6f, 0x3b, 0x6a, 0xb4, 0x19, 0xf5, 0xda, 0x8a, 0x5a, 0x6d, 0x44,
		0xf5, 0xb6, 0xa1, 0x7a, 0x9b, 0x50, 0xb5, 0x2d, 0x98, 0x2f, 0x7e, 0x2d, 0x2d, 0x8d, 0x53, 0xee,
		0x2c, 0x7c, 0x5e, 0x49, 0x92, 0x4c, 0x45, 0x13, 0x4f, 0x5d, 0x93, 0x6c, 0x07, 0x4d, 0x32, 0xff,
		0x03, 0xa9, 0x59, 0x40, 0x35, 0x0b, 0xac, 0x26, 0x01, 0x56, 0xbe, 0x44, 0x5a, 0x42, 0x93, 0xcc,
		0x95, 0x93, 0xa3, 0x49, 0x96, 0xeb, 0x60, 0x6d, 0x17, 0xb4, 0xad, 0x82, 0xb7, 0x79, 0x10, 0x37,
		0x0f, 0xe6, 0xa6, 0x41, 0x5d, 0x27, 0xb8, 0x2b, 0x05, 0xf9, 0x6c, 0x27, 0xd1, 0x24, 0x13, 0x5d,
		0x92, 0x83, 0x74, 0xc5, 0x83, 0xd5, 0xb5, 0xe5, 0x39, 0x48, 0xc7, 0x41, 0x3a, 0x23, 0x93, 0x43,
		0x93, 0x8c, 0xf3, 0x74, 0xbe, 0x3f, 0x0f, 0x9a, 0x64, 0xa2, 0x6c, 0x1d, 0x4d, 0x32, 0xa8, 0x2c,
		0x54, 0x16, 0x2a, 0x0b, 0x95, 0x45, 0x93, 0x8c, 0x24, 0xe1, 0x6b, 0x7b, 0x86, 0x26, 0x19, 0x30,
		0x0d, 0x4c, 0x03, 0xd3, 0xc0, 0xf4, 0x76, 0xc2, 0x34, 0x9a, 0x64, 0x1a, 0x8b, 0x53, 0xf2, 0x56,
		0x34, 0x2b, 0x34, 0xc9, 0x28, 0x79, 0x2b, 0x9b, 0x1c, 0x9a, 0x64, 0x54, 0xba, 0x1d, 0xbf, 0xa8,
		0x74, 0x3f, 0xde, 0x0c, 0xd1, 0x24, 0x83, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d,
		0x9a, 0x64, 0xf0, 0xca, 0x5c, 0x43, 0x2b, 0x49, 0x3e, 0xbc, 0x12, 0x4d, 0x32, 0x98, 0x25, 0xcc,
		0xd2, 0x74, 0x05, 0x34, 0xc9, 0xdc, 0xaa, 0xc1, 0xdc, 0x23, 0xee, 0xb1, 0xaa, 0x4e, 0xa6, 0x32,
		0x0a, 0x5a, 0x32, 0xd5, 0x8e, 0x79, 0xf6, 0x76, 0x90, 0xd4, 0x07, 0x9f, 0xaa, 0x27, 0x8b, 0x1d,
		0x58, 0xd1, 0x29, 0x9b, 0x53, 0xea, 0xbc, 0x0a, 0x95, 0x89, 0x8a, 0x5f, 0x85, 0x69, 0xa4, 0x37,
		0x94, 0xac, 0xa1, 0x93, 0xa7, 0x3e, 0x93, 0x5c, 0x61, 0x26, 0x39, 0x3f, 0xf5, 0x18, 0x66, 0x92,
		0x99, 0x49, 0xfe, 0xe6, 0x8e, 0x31, 0x93, 0x5c, 0x10, 0xfa, 0x45, 0x31, 0xbd, 0x50, 0xc1, 0xdb,
		0x3c, 0x88, 0x9b, 0x07, 0x73, 0xd3, 0xa0, 0xae, 0x4b, 0xa8, 0x99, 0x49, 0x16, 0x8b, 0xbe, 0xcc,
		0x24, 0x0b, 0x3c, 0x28, 0x85, 0x74, 0x0a, 0xe9, 0xda, 0x26, 0x47, 0x21, 0x9d, 0x99, 0x64, 0xea,
		0xe9, 0xde, 0x3f, 0x0f, 0x33, 0xc9, 0xa2, 0x6c, 0x9d, 0x99, 0x64, 0xa8, 0x2c, 0x54, 0x16, 0x2a,
		0x0b, 0x95, 0x65, 0x26, 0x99, 0x24, 0xe1, 0x6b, 0x7b, 0xc6, 0x4c, 0x32, 0x30, 0x0d, 0x4c, 0x03,
		0xd3, 0xc0, 0xf4, 0x76, 0xc2, 0x34, 0x33, 0xc9, 0x1a, 0x8b, 0x53, 0xf2, 0x56, 0x34, 0x2b, 0x66,
		0x92, 0x29, 0x79, 0x2b, 0x9b, 0x1c, 0x33, 0xc9, 0x54, 0xba, 0x1d, 0xbf, 0xa8, 0x74, 0x3f, 0xde,
		0x0c, 0x99, 0x49, 0x86, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d, 0x33, 0xc9, 0xf0,
		0xca, 0x5c, 0x43, 0x2b, 0x49, 0x3e, 0xbc, 0x92, 0x99, 0x64, 0x98, 0x25, 0xcc, 0xd2, 0x74, 0x05,
		0x66, 0x92, 0x95, 0x67, 0x92, 0x35, 0x26, 0x41, 0x4b, 0x1e, 0x8f, 0x24, 0x37, 0xa7, 0xcf, 0x9f,
		0xd7, 0x89, 0xe4, 0x5c, 0x5d, 0xed, 0xac, 0xe4, 0x7b, 0xde, 0xfb, 0x5c, 0x59, 0x74, 0x8e, 0xdc,
		0x47, 0x2f, 0x93, 0xf1, 0x2f, 0xf7, 0xd6, 0xef, 0xf6, 0x1d, 0x1d, 0xfb, 0x91, 0xb4, 0xff, 0xf8,
		0xe8, 0x37, 0x02, 0xae, 0xe2, 0x91, 0x8b, 0xb8, 0x75, 0x0b, 0x77, 0xc6, 0xeb, 0xd0, 0x70, 0xcb,
		0xb7, 0xbe, 0xd5, 0x71, 0x32, 0x7b, 0x6a, 0xd7, 0xc6, 0x9b, 0x15, 0xa0, 0xee, 0x59, 0xcb, 0xb1,
		0x0b, 0xca, 0x48, 0x5a, 0x88, 0x95, 0xf5, 0x25, 0xcb, 0xf7, 0xf2, 0x65, 0x7a, 0xe9, 0x72, 0xbc,
		0x5a, 0xd9, 0x5d, 0xad, 0xbc, 0xae, 0x52, 0x46, 0xf7, 0x1b, 0x24, 0xa5, 0x24, 0x23, 0xca, 0x2b,
		0x19, 0x9c, 0x98, 0x49, 0xde, 0x9a, 0xe1, 0x91, 0xce, 0x17, 0x85, 0xf5, 0x79, 0xc4, 0x7b, 0x95,
		0x1a, 0xbd, 0x49, 0xbd, 0x5e, 0xa4, 0x56, 0xef, 0x51, 0xbd, 0xd7, 0xa8, 0xde, 0x5b, 0x54, 0xed,
		0x25, 0xe6, 0x8b, 0x81, 0x4b, 0xeb, 0xe9, 0x94, 0x3b, 0x0b, 0x9f, 0x57, 0xd2, 0x31, 0x53, 0x51,
		0xd4, 0x53, 0x17, 0x32, 0xdb, 0x41, 0xc8, 0xcc, 0xff, 0x40, 0x6a, 0x16, 0x50, 0xcd, 0x02, 0xab,
		0x49, 0x80, 0x95, 0x2f, 0xa2, 0x96, 0x10, 0x32, 0x73, 0xe5, 0xe4, 0x08, 0x99, 0xe5, 0x3a, 0x58,
		0xdb, 0x05, 0x6d, 0xab, 0xe0, 0x6d, 0x1e, 0xc4, 0xcd, 0x83, 0xb9, 0x69, 0x50, 0xd7, 0x09, 0xee,
		0x4a, 0x41, 0x3e, 0xdb, 0x49, 0x84, 0xcc, 0x44, 0x97, 0xe4, 0xf4, 0x5d, 0xf1, 0x60, 0x75, 0x6d,
		0x79, 0x4e, 0xdf, 0x71, 0xfa, 0xce, 0xc8, 0xe4, 0x10, 0x32, 0xe3, 0x10, 0x9e, 0xef, 0xcf, 0x83,
		0x90, 0x99, 0x28, 0x5b, 0x47, 0xc8, 0x0c, 0x2a, 0x0b, 0x95, 0x85, 0xca, 0x42, 0x65, 0x11, 0x32,
		0x23, 0x49, 0xf8, 0xda, 0x9e, 0x21, 0x64, 0x06, 0x4c, 0x03, 0xd3, 0xc0, 0x34, 0x30, 0xbd, 0x9d,
		0x30, 0x8d, 0x90, 0x99, 0xc6, 0xe2, 0x94, 0xbc, 0x15, 0xcd, 0x0a, 0x21, 0x33, 0x4a, 0xde, 0xca,
		0x26, 0x87, 0x90, 0x19, 0x95, 0x6e, 0xc7, 0x2f, 0x2a, 0xdd, 0x8f, 0x37, 0x43, 0x84, 0xcc, 0x20,
		0xb5, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x16, 0x52, 0x8b, 0x90, 0x19, 0xbc, 0x32, 0xd7, 0xd0, 0x4a,
		0x92, 0x0f, 0xaf, 0x44, 0xc8, 0x0c, 0x66, 0x09, 0xb3, 0x34, 0x5d, 0x01, 0x21, 0x33, 0x29, 0x71,
		0x98, 0xb9, 0xb4, 0xc7, 0xaa, 0x8c, 0x99, 0xca, 0x20, 0x68, 0xc9, 0x0b, 0xf9, 0x98, 0x8b, 0x64,
		0x5d, 0xc5, 0x6c, 0x4e, 0xa7, 0xf3, 0x2a, 0x63, 0x26, 0x2a, 0x88, 0x15, 0xa6, 0x91, 0xde, 0x40,
		0xb2, 0x86, 0x9c, 0x9e, 0xfa, 0x3c, 0x72, 0x85, 0x79, 0xe4, 0xfc, 0xd4, 0x62, 0x98, 0x47, 0x66,
		0x1e, 0xf9, 0x9b, 0x3b, 0xc6, 0x3c, 0x72, 0x41, 0xa8, 0x17, 0x85, 0xf4, 0x42, 0x05, 0x6f, 0xf3,
		0x20, 0x6e, 0x1e, 0xcc, 0x4d, 0x83, 0xba, 0x2e, 0x99, 0x66, 0x1e, 0x59, 0x2c, 0xfa, 0x32, 0x8f,
		0x2c, 0xf0, 0xa0, 0x14, 0xd1, 0x29, 0xa2, 0x6b, 0x9b, 0x1c, 0x45, 0x74, 0xe6, 0x91, 0xa9, 0xa5,
		0x7b, 0xff, 0x3c, 0xcc, 0x23, 0x8b, 0xb2, 0x75, 0xe6, 0x91, 0xa1, 0xb2, 0x50, 0x59, 0xa8, 0x2c,
		0x54, 0x96, 0x79, 0x64, 0x92, 0x84, 0xaf, 0xed, 0x19, 0xf3, 0xc8, 0xc0, 0x34, 0x30, 0x0d, 0x4c,
		0x03, 0xd3, 0xdb, 0x09, 0xd3, 0xcc, 0x23, 0x6b, 0x2c, 0x4e, 0xc9, 0x5b, 0xd1, 0xac, 0x98, 0x47,
		0xa6, 0xe4, 0xad, 0x6c, 0x72, 0xcc, 0x23, 0x53, 0xe9, 0x76, 0xfc, 0xa2, 0xd2, 0xfd, 0x78, 0x33,
		0x64, 0x1e, 0x19, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0xcc, 0x23, 0xc3, 0x2b,
		0x73, 0x0d, 0xad, 0x24, 0xf9, 0xf0, 0x4a, 0xe6, 0x91, 0x61, 0x96, 0x30, 0x4b, 0xd3, 0x15, 0x98,
		0x47, 0x56, 0x9d, 0x47, 0xd6, 0x98, 0x03, 0x2d, 0x79, 0x3b, 0x8e, 0xdc, 0x9c, 0x3e, 0x7d, 0x5e,
		0xa7, 0x91, 0x73, 0x75, 0xa5, 0xb3, 0x92, 0xdf, 0x79, 0xee, 0x6f, 0x65, 0xd1, 0x09, 0x72, 0xff,
		0x3c, 0x4c, 0xc6, 0xb7, 0xdc, 0x5b, 0xbe, 0xdb, 0x77, 0x74, 0xec, 0x43, 0xd2, 0xbe, 0xe3, 0x9f,
		0xcf, 0x08, 0xb8, 0x89, 0x37, 0xee, 0xe1, 0xd6, 0x25, 0xdc, 0x19, 0xae, 0x43, 0xa3, 0x2d, 0x67,
		0xdf, 0xe8, 0x7e, 0x70, 0x3d, 0xee, 0xa5, 0xb3, 0xe7, 0x76, 0x6d, 0xba, 0x59, 0xd9, 0xe9, 0xde,
		0xd5, 0x1c, 0xbb, 0xa0, 0x8c, 0x94, 0x85, 0x58, 0x39, 0x5f, 0xb2, 0x6c, 0x2f, 0x5f, 0x9e, 0x97,
		0x2e, 0xc3, 0xab, 0x95, 0xdb, 0xd5, 0xca, 0xea, 0x2a, 0xe5, 0x73, 0xbf, 0x41, 0x52, 0x4a, 0x2a,
		0xa2, 0xbc, 0x92, 0xbf, 0x89, 0x99, 0xe4, 0xad, 0xd9, 0x1d, 0xe9, 0x6c, 0x51, 0x58, 0x97, 0x47,
		0xbc, 0x47, 0xa9, 0xd1, 0x93, 0xd4, 0xeb, 0x41, 0x6a, 0xf5, 0x1c, 0xd5, 0x7b, 0x8c, 0xea, 0x3d,
		0x45, 0xd5, 0x1e, 0x62, 0xbe, 0xd8, 0xb7, 0xb4, 0x8e, 0x4e, 0xb9, 0xb3, 0xf0, 0x79, 0x25, 0xfd,
		0x32, 0x15, 0x1d, 0x3d, 0x75, 0x01, 0xb3, 0x1d, 0x04, 0xcc, 0xfc, 0x0f, 0xa4, 0x66, 0x01, 0xd5,
		0x2c, 0xb0, 0x9a, 0x04, 0x58, 0xf9, 0x02, 0x6a, 0x09, 0x01, 0x33, 0x57, 0x4e, 0x8e, 0x80, 0x59,
		0xae, 0x83, 0xb5, 0x5d, 0xd0, 0xb6, 0x0a, 0xde, 0xe6, 0x41, 0xdc, 0x3c, 0x98, 0x9b, 0x06, 0x75,
		0x9d, 0xe0, 0xae, 0x14, 0xe4, 0xb3, 0x9d, 0x44, 0xc0, 0x4c, 0x74, 0x49, 0x4e, 0xdd, 0x15, 0x0f,
		0x56, 0xd7, 0x96, 0xe7, 0xd4, 0x1d, 0xa7, 0xee, 0x8c, 0x4c, 0x0e, 0x01, 0x33, 0x0e, 0xdf, 0xf9,
		0xfe, 0x3c, 0x08, 0x98, 0x89, 0xb2, 0x75, 0x04, 0xcc, 0xa0, 0xb2, 0x50, 0x59, 0xa8, 0x2c, 0x54,
		0x16, 0x01, 0x33, 0x92, 0x84, 0xaf, 0xed, 0x19, 0x02, 0x66, 0xc0, 0x34, 0x30, 0x0d, 0x4c, 0x03,
		0xd3, 0xdb, 0x09, 0xd3, 0x08, 0x98, 0x69, 0x2c, 0x4e, 0xc9, 0x5b, 0xd1, 0xac, 0x10, 0x30, 0xa3,
		0xe4, 0xad, 0x6c, 0x72, 0x08, 0x98, 0x51, 0xe9, 0x76, 0xfc, 0xa2, 0xd2, 0xfd, 0x78, 0x33, 0x44,
		0xc0, 0x0c, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x08, 0x98, 0xc1, 0x2b, 0x73,
		0x0d, 0xad, 0x24, 0xf9, 0xf0, 0x4a, 0x04, 0xcc, 0x60, 0x96, 0x30, 0x4b, 0xd3, 0x15, 0x10, 0x30,
		0x93, 0x11, 0x87, 0xb9, 0x25, 0xee, 0xb1, 0x2a, 0x61, 0xa6, 0x32, 0x0a, 0x5a, 0xf2, 0x41, 0x42,
		0x66, 0xff, 0x64, 0xb1, 0x03, 0x2b, 0x2a, 0x66, 0x73, 0x4a, 0x9d, 0x57, 0x19, 0x33, 0x51, 0x49,
		0xac, 0x30, 0x8d, 0xf4, 0x86, 0x92, 0x35, 0xc4, 0xf4, 0xd4, 0x67, 0x92, 0x2b, 0xcc, 0x24, 0xe7,
		0xa7, 0x1e, 0xc3, 0x4c, 0x32, 0x33, 0xc9, 0xdf, 0xdc, 0x31, 0x66, 0x92, 0x0b, 0x42, 0xbf, 0x28,
		0xa6, 0x17, 0x2a, 0x78, 0x9b, 0x07, 0x71, 0xf3, 0x60, 0x6e, 0x1a, 0xd4, 0x75, 0x09, 0x35, 0x33,
		0xc9, 0x62, 0xd1, 0x97, 0x99, 0x64, 0x81, 0x07, 0xa5, 0x90, 0x4e, 0x21, 0x5d, 0xdb, 0xe4, 0x28,
		0xa4, 0x33, 0x93, 0x4c, 0x3d, 0xdd, 0xfb, 0xe7, 0x61, 0x26, 0x59, 0x94, 0xad, 0x33, 0x93, 0x0c,
		0x95, 0x85, 0xca, 0x42, 0x65, 0xa1, 0xb2, 0xcc, 0x24, 0x93, 0x24, 0x7c, 0x6d, 0xcf, 0x98, 0x49,
		0x06, 0xa6, 0x81, 0x69, 0x60, 0x1a, 0x98, 0xde, 0x4e, 0x98, 0x66, 0x26, 0x59, 0x63, 0x71, 0x4a,
		0xde, 0x8a, 0x66, 0xc5, 0x4c, 0x32, 0x25, 0x6f, 0x65, 0x93, 0x63, 0x26, 0x99, 0x4a, 0xb7, 0xe3,
		0x17, 0x95, 0xee, 0xc7, 0x9b, 0x21, 0x33, 0xc9, 0x90, 0x5a, 0x48, 0x2d, 0xa4, 0x16, 0x52, 0x0b,
		0xa9, 0x65, 0x26, 0x19, 0x5e, 0x99, 0x6b, 0x68, 0x25, 0xc9, 0x87, 0x57, 0x32, 0x93, 0x0c, 0xb3,
		0x84, 0x59, 0x9a, 0xae, 0xc0, 0x4c, 0xb2, 0xf2, 0x4c, 0xb2, 0xc6, 0x24, 0x68, 0xc9, 0xe3, 0x91,
		0xe4, 0xe6, 0xf4, 0xf9, 0xf3, 0x3a, 0x91, 0x9c, 0xab, 0xab, 0x9d, 0x95, 0x7c, 0xcf, 0x7b, 0x9f,
		0x2b, 0x8b, 0xce, 0x91, 0xfb, 0xe8, 0x65, 0x32, 0xfe, 0xe5, 0xde, 0xfa, 0xdd, 0xbe, 0xa3, 0x63,
		0x3f, 0x92, 0xf6, 0x1f, 0x1f, 0xfd, 0x46, 0xc0, 0x55, 0x3c, 0x72, 0x11, 0xb7, 0x6e, 0xe1, 0xce,
		0x78, 0x1d, 0x1a, 0x6e, 0xf9, 0xd6, 0xb7, 0x3a, 0x4e, 0x66, 0x4f, 0xed, 0xda, 0x78, 0xb3, 0x02,
		0xd4, 0x3d, 0x6b, 0x39, 0x76, 0x41, 0x19, 0x49, 0x0b, 0xb1, 0xb2, 0xbe, 0x64, 0xf9, 0x5e, 0xbe,
		0x4c, 0x2f, 0x5d, 0x8e, 0x57, 0x2b, 0xbb, 0xab, 0x95, 0xd7, 0x55, 0xca, 0xe8, 0x7e, 0x83, 0xa4,
		0x94, 0x64, 0x44, 0x79, 0x25, 0x83, 0x13, 0x33, 0xc9, 0x5b, 0x33, 0x3c, 0xd2, 0xf9, 0xa2, 0xb0,
		0x3e, 0x8f, 0x78, 0xaf, 0x52, 0xa3, 0x37, 0xa9, 0xd7, 0x8b, 0xd4, 0xea, 0x3d, 0xaa, 0xf7, 0x1a,
		0xd5, 0x7b, 0x8b, 0xaa, 0xbd, 0xc4, 0x7c, 0x31, 0x70, 0x69, 0x3d, 0x9d, 0x72, 0x67, 0xe1, 0xf3,
		0x4a, 0x3a, 0x66, 0x2a, 0x8a, 0x7a, 0xea, 0x42, 0x66, 0x3b, 0x08, 0x99, 0xf9, 0x1f, 0x48, 0xcd,
		0x02, 0xaa, 0x59, 0x60, 0x35, 0x09, 0xb0, 0xf2, 0x45, 0xd4, 0x12, 0x42, 0x66, 0xae, 0x9c, 0x1c,
		0x21, 0xb3, 0x5c, 0x07, 0x6b, 0xbb, 0xa0, 0x6d, 0x15, 0xbc, 0xcd, 0x83, 0xb8, 0x79, 0x30, 0x37,
		0x0d, 0xea, 0x3a, 0xc1, 0x5d, 0x29, 0xc8, 0x67, 0x3b, 0x89, 0x90, 0x99, 0xe8, 0x92, 0x9c, 0xbe,
		0x2b, 0x1e, 0xac, 0xae, 0x2d, 0xcf, 0xe9, 0x3b, 0x4e, 0xdf, 0x19, 0x99, 0x1c, 0x42, 0x66, 0x1c,
		0xc2, 0xf3, 0xfd, 0x79, 0x10, 0x32, 0x13, 0x65, 0xeb, 0x08, 0x99, 0x41, 0x65, 0xa1, 0xb2, 0x50,
		0x59, 0xa8, 0x2c, 0x42, 0x66, 0x24, 0x09, 0x5f, 0xdb, 0x33, 0x84, 0xcc, 0x80, 0x69, 0x60, 0x1a,
		0x98, 0x06, 0xa6, 0xb7, 0x13, 0xa6, 0x11, 0x32, 0xd3, 0x58, 0x9c, 0x92, 0xb7, 0xa2, 0x59, 0x21,
		0x64, 0x46, 0xc9, 0x5b, 0xd9, 0xe4, 0x10, 0x32, 0xa3, 0xd2, 0xed, 0xf8, 0x45, 0xa5, 0xfb, 0xf1,
		0x66, 0x88, 0x90, 0x19, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x11, 0x32, 0x83,
		0x57, 0xe6, 0x1a, 0x5a, 0x49, 0xf2, 0xe1, 0x95, 0x08, 0x99, 0xc1, 0x2c, 0x61, 0x96, 0xa6, 0x2b,
		0x20, 0x64, 0x26, 0x25, 0x0e, 0x33, 0x97, 0xf6, 0x58, 0x95, 0x31, 0x53, 0x19, 0x04, 0x2d, 0x79,
		0x21, 0x1f, 0x73, 0x91, 0xac, 0xab, 0x98, 0xcd, 0xe9, 0x74, 0x5e, 0x65, 0xcc, 0x44, 0x05, 0xb1,
		0xc2, 0x34, 0xd2, 0x1b, 0x48, 0xd6, 0x90, 0xd3, 0x53, 0x9f, 0x47, 0xae, 0x30, 0x8f, 0x9c, 0x9f,
		0x5a, 0x0c, 0xf3, 0xc8, 0xcc, 0x23, 0x7f, 0x73, 0xc7, 0x98, 0x47, 0x2e, 0x08, 0xf5, 0xa2, 0x90,
		0x5e, 0xa8, 0xe0, 0x6d, 0x1e, 0xc4, 0xcd, 0x83, 0xb9, 0x69, 0x50, 0xd7, 0x25, 0xd3, 0xcc, 0x23,
		0x8b, 0x45, 0x5f, 0xe6, 0x91, 0x05, 0x1e, 0x94, 0x22, 0x3a, 0x45, 0x74, 0x6d, 0x93, 0xa3, 0x88,
		0xce, 0x3c, 0x32, 0xb5, 0x74, 0xef, 0x9f, 0x87, 0x79, 0x64, 0x51, 0xb6, 0xce, 0x3c, 0x32, 0x54,
		0x16, 0x2a, 0x0b, 0x95, 0x85, 0xca, 0x32, 0x8f, 0x4c, 0x92, 0xf0, 0xb5, 0x3d, 0x63, 0x1e, 0x19,
		0x98, 0x06, 0xa6, 0x81, 0x69, 0x60, 0x7a, 0x3b, 0x61, 0x9a, 0x79, 0x64, 0x8d, 0xc5, 0x29, 0x79,
		0x2b, 0x9a, 0x15, 0xf3, 0xc8, 0x94, 0xbc, 0x95, 0x4d, 0x8e, 0x79, 0x64, 0x2a, 0xdd, 0x8e, 0x5f,
		0x54, 0xba, 0x1f, 0x6f, 0x86, 0xcc, 0x23, 0x43, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0x2d, 0xa4,
		0x96, 0x79, 0x64, 0x78, 0x65, 0xae, 0xa1, 0x95, 0x24, 0x1f, 0x5e, 0xc9, 0x3c, 0x32, 0xcc, 0x12,
		0x66, 0x69, 0xba, 0x02, 0xf3, 0xc8, 0xaa, 0xf3, 0xc8, 0x1a, 0x73, 0xa0, 0x25, 0x6f, 0xc7, 0x91,
		0x9b, 0xd3, 0xa7, 0xcf, 0xeb, 0x34, 0x72, 0xae, 0xae, 0x74, 0x56, 0xf2, 0x3b, 0xcf, 0xfd, 0xad,
		0x2c, 0x3a, 0x41, 0xee, 0x9f, 0x87, 0xc9, 0xf8, 0x96, 0x7b, 0xcb, 0x77, 0xfb, 0x8e, 0x8e, 0x7d,
		0x48, 0xda, 0x77, 0xfc, 0xf3, 0x19, 0x01, 0x37, 0xf1, 0xc6, 0x3d, 0xdc, 0xba, 0x84, 0x3b, 0xc3,
		0x75, 0x68, 0xb4, 0xe5, 0x61, 0x7f, 0x9c, 0x46, 0xc1, 0x28, 0xea, 0x45, 0x53, 0x32, 0x11, 0xf4,
		0x07, 0x93, 0xff, 0xb8, 0x1f, 0xac, 0x5e, 0x9e, 0x67, 0x7b, 0x60, 0x41, 0xc7, 0x8e, 0x28, 0x23,
		0x68, 0x21, 0x56, 0xd4, 0x97, 0x2c, 0xde, 0xcb, 0x17, 0xe9, 0xa5, 0x8b, 0xf1, 0x6a, 0x45, 0x77,
		0xb5, 0xe2, 0xba, 0x4a, 0x11, 0xdd, 0x6f, 0xa8, 0x94, 0x12, 0x8c, 0x28, 0x77, 0x16, 0x3e, 0x2a,
		0x64, 0x8c, 0x0b, 0x77, 0x12, 0x15, 0x88, 0x12, 0x56, 0xe4, 0x11, 0xef, 0x4e, 0x6a, 0x74, 0x23,
		0xf5, 0xba, 0x8f, 0x5a, 0xdd, 0x46, 0xf5, 0xee, 0xa2, 0x7a, 0x37, 0x51, 0xb5, 0x7b, 0x98, 0x2f,
		0xde, 0x2d, 0xad, 0xa0, 0x53, 0x0e, 0xbb, 0x9f, 0xa2, 0x61, 0x1a, 0x8f, 0xa2, 0x20, 0x4e, 0xc2,
		0x4e, 0x1a, 0x7f, 0x8a, 0x82, 0x69, 0x36, 0x36, 0xd2, 0x13, 0x33, 0x7b, 0xf8, 0x23, 0x48, 0xcb,
		0x13, 0xe9, 0x0e, 0x3c, 0x2a, 0xb5, 0x27, 0xd4, 0x0e, 0x99, 0x20, 0xa8, 0x96, 0xeb, 0x30, 0x6f,
		0x16, 0xee, 0x4d, 0xc2, 0xbe, 0x6c, 0xf8, 0x17, 0x86, 0x81, 0x6c, 0xc7, 0xd4, 0x0e, 0x87, 0x18,
		0x0c, 0x24, 0x2a, 0x0d, 0x22, 0xe6, 0x53, 0x5f, 0x34, 0xec, 0xfd, 0x1d, 0x7e, 0x19, 0x05, 0x9d,
		0xfe, 0xf5, 0x20, 0x1c, 0x46, 0xc1, 0x75, 0xd4, 0x55, 0xc4, 0xe7, 0xf5, 0xb5, 0x01, 0x66, 0x80,
		0x19, 0x60, 0x06, 0x98, 0x01, 0x66, 0x80, 0x79, 0xbb, 0x81, 0x39, 0x4a, 0xc2, 0xf7, 0xbd, 0x28,
		0x08, 0xe3, 0xab, 0x81, 0x1e, 0x22, 0xdf, 0x5e, 0x14, 0x28, 0x06, 0x8a, 0x81, 0x62, 0xa0, 0x18,
		0x28, 0x06, 0x8a, 0xb7, 0x1c, 0x8a, 0x3f, 0xa7, 0xd1, 0x30, 0x09, 0x7b, 0x19, 0x53, 0x9d, 0x56,
		0x91, 0x87, 0x41, 0xac, 0xc8, 0x95, 0xbf, 0xf2, 0x19, 0xf4, 0x80, 0x7a, 0x12, 0x9e, 0xc0, 0x69,
		0x70, 0x1a, 0x9c, 0x06, 0xa7, 0xc1, 0x69, 0x70, 0xda, 0x33, 0x9c, 0x8e, 0xaf, 0x92, 0xfe, 0x30,
		0x0a, 0xc2, 0x51, 0x30, 0x08, 0xd3, 0x8f, 0x41, 0x2f, 0x4a, 0xae, 0xa6, 0x47, 0x57, 0x95, 0x20,
		0xfa, 0xfe, 0xe5, 0xa1, 0xd1, 0xc0, 0x33, 0xf0, 0x0c, 0x3c, 0x03, 0xcf, 0xc0, 0x33, 0xf0, 0x3c,
		0x8c, 0x82, 0x24, 0xfa, 0x9c, 0x06, 0x1f, 0xfb, 0x83, 0x20, 0xbe, 0x1a, 0x04, 0xd7, 0x51, 0x3a,
		0x8c, 0x3b, 0xea, 0x18, 0x7d, 0xdf, 0x67, 0x00, 0xa8, 0x01, 0x6a, 0x80, 0x1a, 0xa0, 0x06, 0xa8,
		0x01, 0xea, 0x1c, 0x00, 0x35, 0x53, 0xde, 0xf7, 0xac, 0x63, 0x3c, 0xb1, 0xfa, 0xc0, 0xb8, 0xa1,
		0xfc, 0xed, 0xee, 0x66, 0x53, 0xac, 0xe7, 0x93, 0x27, 0x6e, 0x2e, 0x1e, 0xf8, 0x6c, 0xf6, 0xbc,
		0xa2, 0xd7, 0xb9, 0x0b, 0x0c, 0x79, 0x8b, 0x4c, 0x15, 0x4b, 0x5e, 0xdb, 0xae, 0x72, 0x5d, 0xbb,
		0xda, 0x50, 0x58, 0x85, 0xa1, 0x30, 0x7f, 0x32, 0x44, 0x86, 0xc2, 0xb6, 0x18, 0xa6, 0x19, 0x0a,
		0xa3, 0x00, 0x40, 0x01, 0x80, 0x02, 0x00, 0x05, 0x00, 0x0a, 0x00, 0x14, 0x00, 0x3c, 0x2f, 0x00,
		0x30, 0x14, 0x06, 0x30, 0x03, 0xcc, 0x00, 0x33, 0xc0, 0x0c, 0x30, 0x03, 0xcc, 0xdb, 0x01, 0xcc,
		0x0c, 0x85, 0x01, 0xc5, 0x40, 0x31, 0x50, 0x0c, 0x14, 0x03, 0xc5, 0x40, 0xb1, 0x2d, 0x14, 0x33,
		0x14, 0xc6, 0x50, 0x18, 0x38, 0x0d, 0x4e, 0x83, 0xd3, 0xe0, 0x34, 0x38, 0xed, 0x2d, 0x4e, 0x33,
		0x14, 0x06, 0x8d, 0x06, 0x9e, 0x81, 0x67, 0xe0, 0x19, 0x78, 0x06, 0x9e, 0x7d, 0x85, 0x67, 0x86,
		0xc2, 0x00, 0x6a, 0x80, 0x1a, 0xa0, 0x06, 0xa8, 0x01, 0x6a, 0x80, 0xda, 0xaf, 0x77, 0x66, 0x28,
		0x4c, 0x64, 0x28, 0x4c, 0xfa, 0x8a, 0x5d, 0xcf, 0x66, 0xc2, 0x04, 0xef, 0xd4, 0xe5, 0xde, 0xcf,
		0x6d, 0x70, 0x98, 0x22, 0x5d, 0xfe, 0x79, 0xaf, 0x8b, 0x6c, 0xc3, 0x0d, 0xa0, 0xa3, 0x61, 0x1a,
		0x05, 0x83, 0x7e, 0x2f, 0xee, 0x7c, 0x09, 0xe2, 0xc1, 0xa7, 0xaa, 0xdc, 0xd5, 0x9f, 0x6b, 0x2b,
		0x71, 0xe7, 0x27, 0x77, 0x7e, 0x9a, 0x53, 0x1f, 0xee, 0xfc, 0xd4, 0x83, 0x49, 0xb1, 0x3b, 0x3f,
		0x57, 0x6e, 0x6e, 0x17, 0x9f, 0xf1, 0x56, 0xb8, 0x27, 0x9e, 0xfb, 0x3f, 0x7d, 0xaa, 0xff, 0x30,
		0xea, 0x9d, 0xcb, 0xfa, 0x0e, 0xa3, 0xde, 0x2b, 0x0b, 0x08, 0x5f, 0x8c, 0xbc, 0xe6, 0x96, 0xe2,
		0x1a, 0x2b, 0x0a, 0x81, 0x52, 0x2d, 0x60, 0x6a, 0x06, 0x4e, 0xfd, 0x00, 0xaa, 0x1d, 0x48, 0xcd,
		0x02, 0xaa, 0x59, 0x60, 0x35, 0x09, 0xb0, 0xf2, 0xf5, 0xd3, 0x92, 0x42, 0x01, 0x5d, 0x3a, 0xf0,
		0x66, 0x0b, 0x5d, 0x87, 0x9f, 0x83, 0x99, 0x15, 0x2a, 0xc8, 0x6b, 0xac, 0x39, 0xf9, 0xca, 0xea,
		0x4a, 0xc6, 0xa8, 0xd3, 0xdd, 0x54, 0x0f, 0xd2, 0x16, 0xc1, 0xda, 0x2e, 0x68, 0x5b, 0x05, 0x6f,
		0xf3, 0x20, 0x6e, 0x1e, 0xcc, 0x4d, 0x83, 0xba, 0x4e, 0x70, 0x57, 0x0a, 0xf2, 0xd9, 0x4e, 0xaa,
		0x75, 0x4b, 0xd7, 0xfc, 0x75, 0x1c, 0x27, 0xe9, 0xb3, 0x8a, 0xa6, 0xbf, 0xce, 0xa3, 0xef, 0x81,
		0xe2, 0x92, 0xe7, 0x61, 0x72, 0x35, 0x79, 0xda, 0x77, 0xaa, 0xfe, 0xa1, 0x1b, 0x8f, 0xa6, 0x0f,
		0x7a, 0x12, 0x27, 0xea, 0x81, 0xd0, 0x08, 0x56, 0xd7, 0x96, 0x7f, 0x1b, 0xf6, 0xc6, 0x91, 0xe1,
		0xfa, 0xaf, 0x86, 0xe1, 0xb4, 0x4b, 0xf3, 0x32, 0xbe, 0x8a, 0xd3, 0x49, 0x26, 0xb5, 0xa3, 0xfe,
		0x39, 0x6e, 0x7e, 0x31, 0x30, 0xb9, 0xf0, 0xf3, 0xd6, 0x9b, 0x5c, 0xb5, 0xf2, 0xbc, 0xfa, 0x7c,
		0xff, 0xa0, 0xf2, 0x7c, 0x6f, 0x8b, 0x6d, 0xef, 0x49, 0x31, 0x57, 0xbb, 0x7c, 0x52, 0x8c, 0xe7,
		0x51, 0x88, 0x0d, 0x93, 0x3c, 0xf8, 0x53, 0x94, 0xa4, 0x41, 0x1a, 0x85, 0xc3, 0x6e, 0xff, 0xef,
		0x44, 0x9f, 0x4e, 0xae, 0x7d, 0x02, 0xa5, 0x04, 0x4e, 0xf9, 0x80, 0x2e, 0x54, 0x16, 0x2a, 0x0b,
		0x95, 0x85, 0xca, 0x42, 0x65, 0x4d, 0x0e, 0x00, 0xdf, 0x0d, 0xbf, 0xc2, 0x07, 0x81, 0x8b, 0x95,
		0x24, 0x0c, 0xa3, 0x51, 0x1a, 0x0e, 0xd3, 0x20, 0x8d, 0xaf, 0xa3, 0xa1, 0x7e, 0x86, 0xb0, 0xba,
		0x3c, 0x30, 0x0d, 0x4c, 0x03, 0xd3, 0xc0, 0x34, 0x30, 0xad, 0xe6, 0xaf, 0xdd, 0xa8, 0x13, 0x5f,
		0x87, 0xbd, 0xfd, 0xaa, 0x05, 0x50, 0x57, 0x14, 0xd7, 0x5c, 0x2b, 0xca, 0x54, 0x28, 0x79, 0xbb,
		0x7f, 0x50, 0x1f, 0x4a, 0xde, 0x15, 0x4a, 0xde, 0x94, 0xbc, 0x75, 0x4d, 0xee, 0x19, 0x26, 0x47,
		0xa5, 0xdb, 0xed, 0x8b, 0x4a, 0xf7, 0xe3, 0xcd, 0xf0, 0xef, 0x70, 0x98, 0xc4, 0xc9, 0x55, 0x90,
		0x7e, 0x1c, 0x46, 0xa3, 0x8f, 0xfd, 0x5e, 0x37, 0x18, 0x74, 0x52, 0x7d, 0x32, 0x7b, 0xff, 0xc7,
		0x80, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0x90, 0x5a, 0x48, 0xad, 0x9a, 0xbf, 0x0e, 0xa2, 0x61, 0x27,
		0x4a, 0xd2, 0xf0, 0x2a, 0x32, 0x60, 0xb5, 0x7b, 0xf0, 0xca, 0x62, 0xf2, 0x4a, 0x8e, 0x52, 0xc1,
		0x2b, 0xb7, 0xcc, 0xe4, 0x76, 0x77, 0x60, 0x96, 0x30, 0x4b, 0x5f, 0x99, 0x65, 0xae, 0x27, 0x8a,
		0x94, 0x74, 0x94, 0xb2, 0xf5, 0x8c, 0xe5, 0x61, 0xee, 0x0a, 0x7b, 0x3c, 0xbd, 0x3d, 0x20, 0xff,
		0x54, 0x65, 0x0c, 0xb4, 0x64, 0xa9, 0x1d, 0xd3, 0x1c, 0xa6, 0x51, 0x63, 0xfa, 0xf8, 0xf5, 0xc1,
		0xa7, 0x6a, 0x7b, 0xc6, 0x66, 0x8f, 0x27, 0x0f, 0x2f, 0x7a, 0xef, 0xbe, 0xbc, 0xaf, 0xdc, 0x88,
		0x6a, 0x61, 0x49, 0xde, 0xc7, 0xbf, 0x46, 0x1b, 0xa4, 0xb5, 0xbd, 0x4a, 0x16, 0xb3, 0xc8, 0x15,
		0x66, 0x91, 0xf3, 0x53, 0x87, 0x61, 0x16, 0x99, 0x59, 0xe4, 0x6f, 0xee, 0x18, 0xb3, 0xc8, 0x05,
		0xa1, 0x5d, 0x14, 0xd1, 0x0b, 0x15, 0xbc, 0xcd, 0x83, 0xb8, 0x79, 0x30, 0x37, 0x0d, 0xea, 0xba,
		0x44, 0x9a, 0x59, 0x64, 0xb1, 0xe8, 0xcb, 0x2c, 0xb2, 0xc0, 0x83, 0x52, 0x40, 0xa7, 0x80, 0xae,
		0x6d, 0x72, 0x14, 0xd0, 0x99, 0x45, 0xa6, 0x8e, 0xee, 0xfd, 0xf3, 0x30, 0x8b, 0x2c, 0xca, 0xd6,
		0x99, 0x45, 0x86, 0xca, 0x42, 0x65, 0xa1, 0xb2, 0x50, 0x59, 0x66, 0x91, 0x49, 0x12, 0xbe, 0xb6,
		0x67, 0xcc, 0x22, 0x03, 0xd3, 0xc0, 0x34, 0x30, 0x0d, 0x4c, 0x6f, 0x27, 0x4c, 0x33, 0x8b, 0xac,
		0xb1, 0x38, 0x25, 0x6f, 0x45, 0xb3, 0x62, 0x16, 0x99, 0x92, 0xb7, 0xb2, 0xc9, 0x31, 0x8b, 0x4c,
		0xa5, 0xdb, 0xf1, 0x8b, 0x4a, 0xf7, 0xe3, 0xcd, 0x90, 0x59, 0x64, 0x48, 0x2d, 0xa4, 0x16, 0x52,
		0x0b, 0xa9, 0x85, 0xd4, 0x32, 0x8b, 0x0c, 0xaf, 0xcc, 0x35, 0xb4, 0x92, 0xe4, 0xc3, 0x2b, 0x99,
		0x45, 0x86, 0x59, 0xc2, 0x2c, 0x4d, 0x57, 0x60, 0x16, 0x59, 0x71, 0x16, 0x59, 0x63, 0x0a, 0xb4,
		0xe4, 0xe9, 0x28, 0x72, 0x73, 0xfa, 0xec, 0x79, 0x9d, 0x44, 0xce, 0xd5, 0x55, 0xce, 0x4a, 0x3e,
		0xe7, 0xb5, 0xaf, 0x95, 0x45, 0x67, 0xc7, 0x7d, 0xf3, 0x2e, 0x19, 0xbf, 0x72, 0x6f, 0xf5, 0x6e,
		0xdf, 0xd1, 0xb1, 0xff, 0x48, 0xfb, 0x8d, 0x6f, 0xfe, 0x22, 0xe0, 0x22, 0x9e, 0xb8, 0x86, 0x5b,
		0x77, 0x70, 0x67, 0xb4, 0x0e, 0x0d, 0xb6, 0x7c, 0xe7, 0xdb, 0xdc, 0x77, 0x6e, 0xb2, 0x4b, 0xed,
		0x8a, 0xbb, 0x2b, 0x39, 0x76, 0x3b, 0x19, 0xd9, 0x0a, 0xb1, 0xd2, 0xbd, 0x64, 0x89, 0x5e, 0xbe,
		0x14, 0x2f, 0x5d, 0x72, 0x57, 0x2b, 0xad, 0xab, 0x95, 0xd0, 0x55, 0x4a, 0xe5, 0x7e, 0x03, 0xa3,
		0x94, 0x2c, 0x44, 0x79, 0x25, 0x63, 0x13, 0x33, 0xc9, 0x5b, 0x73, 0x3a, 0xd2, 0xf9, 0xa1, 0xb0,
		0x06, 0x8f, 0x78, 0x3f, 0x52, 0xa3, 0xff, 0xa8, 0xd7, 0x6f, 0xd4, 0xea, 0x2f, 0xaa, 0xf7, 0x13,
		0xd5, 0xfb, 0x87, 0xaa, 0xfd, 0xc2, 0x7c, 0xb1, 0x6d, 0x69, 0xcd, 0x9c, 0x72, 0x67, 0xe1, 0xf3,
		0x4a, 0x5a, 0x65, 0x2a, 0x8a, 0x79, 0xea, 0x62, 0x65, 0x3b, 0x88, 0x95, 0xf9, 0x1f, 0x48, 0xcd,
		0x02, 0xaa, 0x59, 0x60, 0x35, 0x09, 0xb0, 0xf2, 0x05, 0xd3, 0x12, 0x62, 0x65, 0xae, 0x9c, 0x1c,
		0xb1, 0xb2, 0x5c, 0x07, 0x6b, 0xbb, 0xa0, 0x6d, 0x15, 0xbc, 0xcd, 0x83, 0xb8, 0x79, 0x30, 0x37,
		0x0d, 0xea, 0x3a, 0xc1, 0x5d, 0x29, 0xc8, 0x67, 0x3b, 0x89, 0x58, 0x99, 0xe8, 0x92, 0x9c, 0xb0,
		0x2b, 0x1e, 0xac, 0xae, 0x2d, 0xcf, 0x09, 0x3b, 0x4e, 0xd8, 0x19, 0x99, 0x1c, 0x62, 0x65, 0x1c,
		0xb4, 0xf3, 0xfd, 0x79, 0x10, 0x2b, 0x13, 0x65, 0xeb, 0x88, 0x95, 0x41, 0x65, 0xa1, 0xb2, 0x50,
		0x59, 0xa8, 0x2c, 0x62, 0x65, 0x24, 0x09, 0x5f, 0xdb, 0x33, 0xc4, 0xca, 0x80, 0x69, 0x60, 0x1a,
		0x98, 0x06, 0xa6, 0xb7, 0x13, 0xa6, 0x11, 0x2b, 0xd3, 0x58, 0x9c, 0x92, 0xb7, 0xa2, 0x59, 0x21,
		0x56, 0x46, 0xc9, 0x5b, 0xd9, 0xe4, 0x10, 0x2b, 0xa3, 0xd2, 0xed, 0xf8, 0x45, 0xa5, 0xfb, 0xf1,
		0x66, 0x88, 0x58, 0x19, 0xa4, 0x16, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x11, 0x2b, 0x83,
		0x57, 0xe6, 0x1a, 0x5a, 0x49, 0xf2, 0xe1, 0x95, 0x88, 0x95, 0xc1, 0x2c, 0x61, 0x96, 0xa6, 0x2b,
		0x20, 0x56, 0x26, 0x29, 0x08, 0xb3, 0xbf, 0x2a, 0x56, 0xa6, 0x32, 0x06, 0x5a, 0xf2, 0x46, 0x34,
		0x66, 0x7f, 0x45, 0xad, 0x6c, 0x4e, 0xa5, 0xf3, 0x2a, 0x57, 0x26, 0x2a, 0x7e, 0x15, 0xa6, 0x91,
		0xde, 0x30, 0xb2, 0x86, 0x64, 0x9e, 0xfa, 0x2c, 0x72, 0x85, 0x59, 0xe4, 0xfc, 0xd4, 0x61, 0x98,
		0x45, 0x66, 0x16, 0xf9, 0x9b, 0x3b, 0xc6, 0x2c, 0x72, 0x41, 0x68, 0x17, 0x45, 0xf4, 0x42, 0x05,
		0x6f, 0xf3, 0x20, 0x6e, 0x1e, 0xcc, 0x4d, 0x83, 0xba, 0x2e, 0x91, 0x66, 0x16, 0x59, 0x2c, 0xfa,
		0x32, 0x8b, 0x2c, 0xf0, 0xa0, 0x14, 0xd0, 0x29, 0xa0, 0x6b, 0x9b, 0x1c, 0x05, 0x74, 0x66, 0x91,
		0xa9, 0xa3, 0x7b, 0xff, 0x3c, 0xcc, 0x22, 0x8b, 0xb2, 0x75, 0x66, 0x91, 0xa1, 0xb2, 0x50, 0x59,
		0xa8, 0x2c, 0x54, 0x96, 0x59, 0x64, 0x92, 0x84, 0xaf, 0xed, 0x19, 0xb3, 0xc8, 0xc0, 0x34, 0x30,
		0x0d, 0x4c, 0x03, 0xd3, 0xdb, 0x09, 0xd3, 0xcc, 0x22, 0x6b, 0x2c, 0x4e, 0xc9, 0x5b, 0xd1, 0xac,
		0x98, 0x45, 0xa6, 0xe4, 0xad, 0x6c, 0x72, 0xcc, 0x22, 0x53, 0xe9, 0x76, 0xfc, 0xa2, 0xd2, 0xfd,
		0x78, 0x33, 0x64, 0x16, 0x19, 0x52, 0x0b, 0xa9, 0x85, 0xd4, 0x42, 0x6a, 0x21, 0xb5, 0xcc, 0x22,
		0xc3, 0x2b, 0x73, 0x0d, 0xad, 0x24, 0xf9, 0xf0, 0x4a, 0x66, 0x91, 0x61, 0x96, 0x30, 0x4b, 0xd3,
		0x15, 0x98, 0x45, 0x56, 0x9c, 0x45, 0xd6, 0x98, 0x02, 0x2d, 0x79, 0x3a, 0x8a, 0xdc, 0x9c, 0x3e,
		0x7b, 0x5e, 0x27, 0x91, 0x73, 0x75, 0x95, 0xb3, 0x92, 0xcf, 0x79, 0xed, 0x6b, 0x65, 0xd1, 0xd9,
		0x71, 0xdf, 0xbc, 0x4b, 0xc6, 0xaf, 0xdc, 0x5b, 0xbd, 0xdb, 0x77, 0x74, 0xec, 0x3f, 0xd2, 0x7e,
		0xe3, 0x9b, 0xbf, 0x08, 0xb8, 0x88, 0x27, 0xae, 0xe1, 0xd6, 0x1d, 0xdc, 0x19, 0xad, 0x43, 0x83,
		0x15, 0x12, 0xb0, 0x10, 0x15, 0xac, 0x10, 0x12, 0xa8, 0x10, 0x13, 0xa4, 0x90, 0x2c, 0xc6, 0xcb,
		0x17, 0xdd, 0xa5, 0x8b, 0xeb, 0x6a, 0x45, 0x74, 0xb5, 0x62, 0xb9, 0x4a, 0x51, 0xdc, 0x6f, 0x08,
		0x94, 0x12, 0x80, 0x28, 0x2f, 0x50, 0x28, 0x98, 0x63, 0x83, 0x90, 0x4d, 0x2e, 0xbc, 0x6a, 0x75,
		0x39, 0x21, 0x73, 0x91, 0xad, 0x5e, 0x89, 0xf7, 0x1e, 0x35, 0x7a, 0x8d, 0x7a, 0xbd, 0x45, 0xad,
		0x5e, 0xa2, 0x7a, 0xef, 0x50, 0xbd, 0x57, 0xa8, 0xda, 0x1b, 0xcc, 0x17, 0xb3, 0x16, 0xef, 0xf5,
		0x65, 0xfe, 0x12, 0x77, 0xa3, 0x24, 0x8d, 0xd3, 0x2f, 0xc3, 0xe8, 0x83, 0xa4, 0xd3, 0x2c, 0x32,
		0x32, 0xc1, 0x6e, 0x5e, 0xb9, 0x3e, 0x7f, 0x94, 0x17, 0xe1, 0x48, 0x51, 0x71, 0xed, 0xf0, 0x55,
		0xbd, 0xdd, 0x9c, 0xfc, 0xbf, 0xd6, 0x5f, 0x8d, 0x9a, 0xb4, 0x8b, 0x4e, 0x1b, 0x09, 0x23, 0x95,
		0x0e, 0xa5, 0xf2, 0x61, 0x9f, 0xe6, 0x79, 0xab, 0xd6, 0x6e, 0x9c, 0x1d, 0xd7, 0x8f, 0xfe, 0x6a,
		0xd7, 0x1b, 0x6f, 0xf7, 0xcb, 0x45, 0x38, 0x49, 0xa5, 0xbc, 0x87, 0xc7, 0xcf, 0xde, 0x36, 0x4e,
		0x27, 0xbb, 0x57, 0x6d, 0x5f, 0x9c, 0xd6, 0x8f, 0x0e, 0x9b, 0x2d, 0x76, 0xf1, 0x07, 0x76, 0xb1,
		0x7e, 0xfa, 0xaf, 0x66, 0xeb, 0xb0, 0x55, 0x6b, 0x37, 0x1b, 0xaf, 0xd8, 0xc0, 0x8d, 0xcc, 0xf0,
		0xe4, 0xe2, 0xb8, 0x85, 0x21, 0xfe, 0xe0, 0x3e, 0xbe, 0x6d, 0x9c, 0xbe, 0xad, 0xb6, 0x5f, 0x1d,
		0x9f, 0xfd, 0xd1, 0x6c, 0xd4, 0x8e, 0xd8, 0xc1, 0x8d, 0x41, 0xa5, 0xca, 0x1e, 0xfe, 0x80, 0x37,
		0x57, 0x26, 0xde, 0xfc, 0xb6, 0x71, 0xdc, 0x64, 0xf7, 0x7e, 0x74, 0xf7, 0x6a, 0x6f, 0x1b, 0xa7,
		0xec, 0xde, 0x06, 0x50, 0xcc, 0xe6, 0x7d, 0xff, 0xe6, 0x4d, 0x01, 0xf8, 0xf8, 0xf0, 0x45, 0xed,
		0xb8, 0xf6, 0x92, 0x7c, 0xd0, 0x45, 0x3e, 0x88, 0x17, 0x6f, 0x96, 0x0f, 0xee, 0x93, 0x0f, 0x6e,
		0xec, 0xd0, 0xa4, 0x83, 0x1b, 0x6d, 0xe0, 0x3e, 0x11, 0xd1, 0xa9, 0x43, 0xb3, 0x8b, 0x9b, 0xb9,
		0x33, 0xfb, 0xb7, 0x99, 0x37, 0xeb, 0xed, 0x9f, 0xe8, 0x0a, 0x97, 0x79, 0xeb, 0x7b, 0x3c, 0xc9,
		0x81, 0x7d, 0x96, 0xa3, 0x24, 0x7c, 0xdf, 0x8b, 0xba, 0xf2, 0x5d, 0xe0, 0xc5, 0x42, 0x42, 0xdd,
		0x20, 0x25, 0xfd, 0x45, 0xfa, 0xcc, 0xdf, 0xf1, 0x95, 0xd3, 0x67, 0xfe, 0xe1, 0x05, 0xe9, 0x33,
		0xfb, 0x82, 0xde, 0x8a, 0x7d, 0x66, 0x79, 0xfd, 0x42, 0x61, 0xbd, 0xc2, 0x7c, 0x40, 0x5e, 0xda,
		0x4f, 0xc3, 0x5e, 0x30, 0x08, 0xd3, 0x8f, 0x23, 0x79, 0xd8, 0xbb, 0xbd, 0x18, 0x90, 0x04, 0x24,
		0x01, 0x49, 0x40, 0x52, 0x8e, 0x20, 0x49, 0xfc, 0x76, 0x18, 0x85, 0xdb, 0x60, 0x94, 0x24, 0x0b,
		0x14, 0x06, 0x2a, 0x35, 0x25, 0x09, 0xb4, 0xd5, 0x7d, 0x94, 0x25, 0x07, 0x2c, 0xa6, 0xbd, 0x35,
		0x74, 0xa9, 0x34, 0x25, 0x04, 0xac, 0x4c, 0x44, 0xfb, 0xb6, 0x15, 0x13, 0x5b, 0xc9, 0xe9, 0x74,
		0xee, 0x25, 0xc4, 0x42, 0xfa, 0x2a, 0xcd, 0xbb, 0xdc, 0x42, 0xf6, 0xf2, 0x4c, 0xe8, 0x05, 0xf4,
		0x02, 0x7a, 0x01, 0xbd, 0x80, 0x5e, 0x40, 0x2f, 0xa0, 0x17, 0xd0, 0x0b, 0xe8, 0x05, 0xf4, 0x02,
		0x7a, 0xa1, 0xfb, 0x8e, 0x88, 0xab, 0x7c, 0x9f, 0xb8, 0x8a, 0x90, 0xb4, 0x97, 0x9d, 0xa2, 0x8a,
		0x7b, 0xbd, 0x2e, 0x3f, 0x85, 0x54, 0xc6, 0xa3, 0x28, 0xb8, 0x1e, 0xf7, 0xd2, 0x78, 0xd0, 0x8b,
		0x84, 0x3a, 0x74, 0xcb, 0xdc, 0x73, 0x7d, 0xad, 0x9c, 0x49, 0xac, 0xec, 0x20, 0xb1, 0xa2, 0xc7,
		0x8c, 0x91, 0x58, 0x29, 0x20, 0x10, 0x8a, 0x49, 0xac, 0x74, 0x16, 0x3e, 0x2a, 0x5c, 0x02, 0x9c,
		0xaf, 0x23, 0x5b, 0xfa, 0xdb, 0xa5, 0xf4, 0x67, 0x18, 0xd8, 0xb4, 0x02, 0x9c, 0x7a, 0xa0, 0x53,
		0x0f, 0x78, 0xaa, 0x81, 0x4f, 0x96, 0x0b, 0x49, 0x95, 0xfe, 0xa4, 0x02, 0x62, 0xb6, 0x80, 0xf4,
		0x79, 0xe3, 0x35, 0xbf, 0x94, 0x3d, 0x77, 0xbc, 0xdc, 0x38, 0xdd, 0xfb, 0xdf, 0x95, 0x6a, 0x23,
		0x6a, 0x77, 0xee, 0x68, 0xde, 0xb5, 0xa3, 0x7f, 0xc7, 0x8e, 0xf6, 0xdd, 0x3a, 0x66, 0x77, 0xea,
		0x98, 0xdd, 0xa5, 0x63, 0x72, 0x87, 0x4e, 0xbe, 0xd5, 0xe0, 0xd5, 0xee, 0xca, 0x31, 0xb8, 0x9f,
		0x5d, 0xe9, 0x5e, 0x76, 0x44, 0xce, 0xe7, 0xce, 0xb7, 0x1d, 0x22, 0xe7, 0xeb, 0x15, 0xa3, 0xa7,
		0xa2, 0xfc, 0xab, 0x64, 0x59, 0x73, 0xbc, 0x18, 0x45, 0x27, 0xf3, 0x67, 0x6d, 0x4c, 0x1e, 0xb5,
		0x3d, 0x4f, 0x05, 0xb6, 0x79, 0x56, 0x6e, 0x82, 0x2a, 0xf2, 0x83, 0x72, 0x72, 0x39, 0x09, 0x84,
		0x1e, 0x42, 0x0f, 0xa1, 0x87, 0xd0, 0xbb, 0x5c, 0x40, 0xb8, 0xd2, 0xb9, 0xe6, 0x96, 0xe2, 0x88,
		0xab, 0x10, 0x28, 0xa1, 0xd7, 0xd0, 0x6b, 0xe8, 0x75, 0xb1, 0xe9, 0xb5, 0x74, 0xe0, 0xcd, 0x16,
		0x0a, 0x7b, 0xbd, 0xfe, 0xdf, 0x4b, 0x5e, 0x12, 0x8e, 0xf4, 0x6f, 0x21, 0x5f, 0xff, 0x08, 0x4a,
		0x66, 0xa9, 0x5c, 0x75, 0xbd, 0x0b, 0x0f, 0xdc, 0x7c, 0x9e, 0x67, 0xd8, 0xb0, 0x82, 0x0f, 0x73,
		0x18, 0x31, 0x87, 0x13, 0x53, 0x58, 0xd1, 0x81, 0x17, 0x25, 0x98, 0xc9, 0x76, 0xd2, 0xee, 0xe6,
		0x73, 0xbd, 0xaa, 0xee, 0x5a, 0x76, 0xbe, 0x5b, 0x94, 0x6b, 0x65, 0x15, 0x72, 0xe4, 0xeb, 0xf0,
		0x73, 0x7c, 0x3d, 0xbe, 0x16, 0xd6, 0xbd, 0x78, 0xd0, 0x4a, 0x56, 0x97, 0xd7, 0x4f, 0x0f, 0x76,
		0x49, 0x0d, 0x48, 0x0d, 0x48, 0x0d, 0x48, 0x0d, 0x48, 0x0d, 0xf4, 0xfc, 0x55, 0x7c, 0xbc, 0xef,
		0xa1, 0xe8, 0x7b, 0xa0, 0xb8, 0xa4, 0xce, 0xf8, 0xdf, 0xdd, 0x97, 0x6e, 0x3c, 0x2a, 0x69, 0x8f,
		0x07, 0x1a, 0xc3, 0xea, 0xda, 0xf2, 0xca, 0xe3, 0x83, 0x6b, 0xeb, 0x1b, 0x8c, 0x88, 0x19, 0x85,
		0xab, 0x55, 0x93, 0x0b, 0x3f, 0x6f, 0xbd, 0xc9, 0x69, 0x8f, 0x23, 0x7a, 0x69, 0x7b, 0x4f, 0x8a,
		0xb9, 0xda, 0x65, 0x51, 0x08, 0x6c, 0xae, 0x4b, 0xf5, 0x4a, 0xc7, 0x97, 0xb2, 0xf5, 0xfc, 0x3b,
		0xc6, 0x14, 0x4d, 0x7e, 0x43, 0xa5, 0xb3, 0x5a, 0xf2, 0xea, 0x4c, 0x53, 0xed, 0xfd, 0xd5, 0x40,
		0xf4, 0x60, 0x93, 0xbc, 0x83, 0xdc, 0x88, 0x9e, 0x3d, 0x93, 0xb8, 0xd7, 0xfe, 0x41, 0xba, 0x20,
		0x35, 0xb7, 0x7b, 0x1f, 0xaa, 0xab, 0x75, 0xf6, 0x2b, 0x74, 0xf6, 0xf3, 0x53, 0x7f, 0xa1, 0xb3,
		0x4f, 0x67, 0xff, 0x9b, 0x3b, 0x46, 0x67, 0x5f, 0xe1, 0x03, 0xd0, 0xd9, 0xcf, 0x3d, 0x5c, 0xd8,
		0xc1, 0x86, 0x15, 0x7c, 0x98, 0xc3, 0x88, 0x39, 0x9c, 0x98, 0xc2, 0x8a, 0x2e, 0x7f, 0xa7, 0xb3,
		0x2f, 0x98, 0x9d, 0xd3, 0xd9, 0x7f, 0xfc, 0x9e, 0xd1, 0xd9, 0x27, 0x35, 0x20, 0x35, 0x20, 0x35,
		0x20, 0x35, 0x20, 0x35, 0xd0, 0xf2, 0x57, 0x3a, 0xfb, 0x62, 0x2f, 0x3a, 0xfb, 0xaa, 0xcb, 0xd3,
		0xd9, 0xa7, 0xb3, 0x6f, 0x64, 0x72, 0x74, 0xf6, 0xe9, 0xec, 0x7b, 0x4f, 0x60, 0xe9, 0xec, 0x7f,
		0xc7, 0x7a, 0x9e, 0x76, 0xf6, 0x35, 0x1a, 0xab, 0x25, 0xff, 0x1a, 0xfb, 0x02, 0xb2, 0xc9, 0x7a,
		0xee, 0x81, 0x02, 0x50, 0x7e, 0x1c, 0x6c, 0x2b, 0xf4, 0x7f, 0x6a, 0x62, 0x44, 0x3d, 0x1f, 0xea,
		0x3f, 0xb1, 0x8a, 0xfa, 0x4f, 0x8c, 0xfa, 0xcf, 0x83, 0x0b, 0xa0, 0xfe, 0xf3, 0x43, 0xdf, 0x3a,
		0xea, 0x3f, 0x5b, 0x0b, 0xcb, 0xa8, 0xff, 0x78, 0x18, 0x28, 0xd5, 0x02, 0xa6, 0x66, 0xe0, 0xd4,
		0x0f, 0xa0, 0xda, 0x81, 0xd4, 0x2c, 0xa0, 0x9a, 0x05, 0x56, 0x93, 0x00, 0x5b, 0x8c, 0xc2, 0x83,
		0xda, 0x19, 0x41, 0x9a, 0xff, 0x34, 0xff, 0x73, 0x06, 0x11, 0x76, 0x50, 0x61, 0x05, 0x19, 0xe6,
		0xd0, 0x61, 0x0e, 0x21, 0xa6, 0x50, 0xa2, 0x03, 0x29, 0x4a, 0xd0, 0x92, 0xed, 0x24, 0xcd, 0x7f,
		0xd1, 0x25, 0x69, 0xfe, 0x17, 0x0f, 0x56, 0xd7, 0x96, 0xa7, 0xf9, 0x4f, 0xf3, 0xdf, 0xc8, 0xe4,
		0x68, 0xfe, 0xd3, 0xfc, 0xf7, 0xfd, 0x79, 0x68, 0xfe, 0x7f, 0xcf, 0x7a, 0xfe, 0xf5, 0x26, 0xe3,
		0x2d, 0x1d, 0xeb, 0xaf, 0x33, 0xd6, 0xff, 0xf5, 0xef, 0x89, 0xb1, 0xfe, 0x4d, 0xeb, 0x32, 0x8c,
		0xf5, 0xe7, 0xa8, 0xfe, 0x42, 0xc9, 0x9e, 0x92, 0xfd, 0x37, 0x77, 0x8c, 0x92, 0xbd, 0xe4, 0xe6,
		0x52, 0xb2, 0xcf, 0x33, 0x44, 0xd8, 0x41, 0x85, 0x15, 0x64, 0x98, 0x43, 0x87, 0x39, 0x84, 0x98,
		0x42, 0x89, 0x2e, 0x67, 0xa7, 0x64, 0x2f, 0x16, 0x7d, 0x29, 0xd9, 0x0b, 0x3c, 0x28, 0x25, 0x7b,
		0x4a, 0xf6, 0xda, 0x26, 0x47, 0xc9, 0x9e, 0x92, 0x3d, 0x25, 0x7b, 0xef, 0x9f, 0x87, 0x92, 0xfd,
		0xf7, 0xac, 0xe7, 0x69, 0xc9, 0x7e, 0xfb, 0xe6, 0xf5, 0xea, 0xcc, 0xeb, 0x69, 0x3a, 0xdc, 0x16,
		0xcf, 0xeb, 0xc5, 0xdb, 0x32, 0xaf, 0x57, 0xdf, 0xf2, 0x79, 0x3d, 0xd9, 0x2e, 0x97, 0x4a, 0x77,
		0x4b, 0x6d, 0x62, 0xaf, 0xc2, 0xc4, 0xde, 0x23, 0x56, 0x62, 0x62, 0x2f, 0x8f, 0x25, 0x45, 0x26,
		0xf6, 0x56, 0x16, 0x88, 0x92, 0xf0, 0x7d, 0x2f, 0xea, 0xea, 0xb5, 0xff, 0x17, 0x0b, 0x4a, 0xb7,
		0xef, 0x74, 0x05, 0xa3, 0x95, 0x6a, 0x12, 0xcc, 0x08, 0xe6, 0x2a, 0x74, 0x9b, 0x85, 0x70, 0xb3,
		0x50, 0x6e, 0x12, 0xd2, 0x8b, 0x51, 0xec, 0x50, 0xeb, 0x06, 0x19, 0x08, 0x3a, 0x2b, 0x09, 0x39,
		0x43, 0xe7, 0xb7, 0x9d, 0xce, 0x4b, 0x97, 0xca, 0xfc, 0xe1, 0xf3, 0x82, 0xd5, 0x31, 0x01, 0x42,
		0xff, 0xc4, 0x63, 0xb7, 0x91, 0x76, 0x17, 0xff, 0xdc, 0xa4, 0x2c, 0x52, 0x5f, 0xf1, 0xc3, 0x31,
		0xdc, 0xba, 0x84, 0x3b, 0xc3, 0x75, 0xf3, 0x4e, 0x8e, 0x4c, 0x7f, 0x92, 0x90, 0x4e, 0xef, 0xf3,
		0x99, 0xdb, 0x48, 0x30, 0xfd, 0xde, 0x1c, 0xbd, 0xf7, 0x71, 0x3c, 0x4a, 0x0f, 0xd3, 0xd4, 0x2d,
		0x71, 0x2d, 0x9f, 0xc4, 0x49, 0xad, 0x17, 0x4d, 0x52, 0xca, 0x91, 0x5b, 0xfa, 0x53, 0x3e, 0x09,
		0x3f, 0xdf, 0x7a, 0xe7, 0xdd, 0xdf, 0xaa, 0xd5, 0xfd, 0x83, 0x6a, 0x75, 0xe7, 0xe0, 0xd9, 0xc1,
		0xce, 0xf3, 0xbd, 0xbd, 0xdd, 0xfd, 0x5d, 0x87, 0xfd, 0xdd, 0xf2, 0xd9, 0xb0, 0x1b, 0x0d, 0xa3,
		0xee, 0x8b, 0xc9, 0xf6, 0x27, 0xe3, 0x5e, 0xcf, 0x2b, 0xab, 0x10, 0x0a, 0x84, 0xc6, 0x01, 0xd0,
		0x61, 0xb4, 0xb3, 0x8a, 0x72, 0x6e, 0x82, 0xda, 0xe6, 0x21, 0x68, 0xb3, 0x77, 0xd8, 0xd0, 0x4c,
		0x5d, 0x9b, 0xa7, 0x8d, 0x59, 0x3a, 0xb0, 0x46, 0x6d, 0x2b, 0xdc, 0xcc, 0xfa, 0x7e, 0xdc, 0x66,
		0x36, 0xb0, 0x97, 0xa9, 0x32, 0x58, 0xd4, 0x8d, 0x86, 0x6e, 0xcc, 0x65, 0x45, 0x70, 0x6c, 0xf9,
		0xb6, 0x1b, 0xda, 0xb3, 0x9b, 0x76, 0x8e, 0xb3, 0x9a, 0xa0, 0xcb, 0x9a, 0x9f, 0xfb, 0x9a, 0x9e,
		0xeb, 0x9a, 0x9d, 0x58, 0x4d, 0x4e, 0xac, 0xe6, 0x26, 0x52, 0x53, 0xb3, 0x8d, 0xe8, 0xae, 0xda,
		0x1b, 0xae, 0x85, 0x07, 0x65, 0x04, 0x06, 0x1d, 0xf7, 0x6f, 0x9d, 0x37, 0x03, 0x24, 0x8a, 0xfe,
		0x72, 0xc5, 0x7d, 0xa9, 0x22, 0xbe, 0x78, 0xb1, 0x5e, 0xbc, 0x28, 0x2f, 0x5a, 0x7c, 0xf7, 0x8b,
		0xc7, 0xba, 0xee, 0x8f, 0x96, 0xe3, 0x6e, 0x94, 0xa4, 0xf1, 0x87, 0x38, 0x72, 0xdf, 0x77, 0x5d,
		0x8a, 0x3a, 0x2f, 0xd7, 0x70, 0xfc, 0xc5, 0xcb, 0x74, 0x21, 0xc5, 0xba, 0x8e, 0x92, 0x5d, 0x46,
		0xf9, 0xae, 0xa2, 0x74, 0x17, 0x51, 0xad, 0x6b, 0xa8, 0xd6, 0x25, 0x54, 0xe9, 0x0a, 0xfa, 0x5d,
		0x6b, 0x16, 0xeb, 0xf2, 0x2d, 0xef, 0xe8, 0x1e, 0x05, 0xc9, 0xf8, 0xfa, 0xbd, 0xf3, 0xe0, 0x52,
		0x92, 0x1d, 0xe3, 0x12, 0x1e, 0xd7, 0x12, 0xec, 0x82, 0x69, 0x8c, 0x5f, 0x69, 0x9d, 0x2f, 0x51,
		0x1a, 0xa7, 0xd2, 0x1c, 0x5d, 0x91, 0x94, 0x4e, 0xd1, 0x18, 0x83, 0xd2, 0xfe, 0xea, 0xb5, 0xc6,
		0x9a, 0x54, 0x6d, 0x20, 0x27, 0x7d, 0xd2, 0x4b, 0x5f, 0x9b, 0x57, 0x0e, 0x69, 0xdb, 0x75, 0x34,
		0x01, 0xa7, 0x20, 0x1c, 0xc9, 0x25, 0xd8, 0xcb, 0x25, 0xc8, 0xaf, 0xc9, 0xaf, 0xc9, 0xaf, 0xc9,
		0xaf, 0xc9, 0xaf, 0xc9, 0xaf, 0xc9, 0xaf, 0xc9, 0xaf, 0xc9, 0xaf, 0xc9, 0xaf, 0xbd, 0xc5, 0x2e,
		0x91, 0x83, 0x53, 0xb7, 0xc3, 0xa8, 0xcc, 0x01, 0xaa, 0xdb, 0xde, 0xaa, 0x76, 0x90, 0x2a, 0x5b,
		0x54, 0xe4, 0x40, 0x95, 0x00, 0x83, 0xe2, 0xa0, 0x97, 0xe3, 0x13, 0x35, 0x2b, 0x47, 0x31, 0xdc,
		0xcb, 0x1a, 0x6b, 0x1d, 0xb2, 0x39, 0xba, 0xfd, 0x18, 0x4e, 0x55, 0x8a, 0x1d, 0x1c, 0xf7, 0x72,
		0x72, 0x56, 0xc9, 0xe5, 0xdc, 0xb5, 0xc8, 0x9c, 0xb5, 0x58, 0x5f, 0xbe, 0x42, 0x5f, 0x3e, 0x47,
		0x74, 0x9d, 0xbe, 0x3c, 0x7d, 0x79, 0xfa, 0xf2, 0x25, 0xea, 0x86, 0xd6, 0x81, 0x48, 0x2d, 0x20,
		0xa9, 0x04, 0x26, 0x19, 0x36, 0x47, 0xdd, 0xf0, 0xbe, 0x00, 0x43, 0xdd, 0x70, 0x95, 0xf0, 0x52,
		0x37, 0xf4, 0xb8, 0x66, 0x44, 0xdd, 0xf0, 0xbb, 0xbe, 0x7a, 0xea, 0x86, 0x76, 0xef, 0x4a, 0x5f,
		0xde, 0x09, 0x04, 0xd2, 0x97, 0x27, 0xbf, 0x26, 0xbf, 0x26, 0xbf, 0x26, 0xbf, 0x26, 0xbf, 0x26,
		0xbf, 0x26, 0xbf, 0x26, 0xbf, 0x26, 0xbf, 0x96, 0xc8, 0xaf, 0xe9, 0xcb, 0xdf, 0xf5, 0x56, 0xfa,
		0xf2, 0xa2, 0xef, 0x44, 0x5f, 0xfe, 0xa1, 0xbe, 0xbc, 0x6b, 0x41, 0x36, 0x9b, 0xb6, 0xbc, 0x43,
		0xb1, 0x35, 0x44, 0x58, 0x3c, 0x31, 0xcd, 0x1c, 0x09, 0xb1, 0xac, 0x18, 0x63, 0x5e, 0xd5, 0x58,
		0x1c, 0xc8, 0x33, 0xb8, 0x95, 0x65, 0x40, 0x7f, 0xc5, 0xb2, 0xea, 0x83, 0xfe, 0x8a, 0x07, 0xc1,
		0xdc, 0x99, 0xfe, 0x8a, 0xc3, 0xaa, 0xf1, 0xad, 0x82, 0x8e, 0xe3, 0xf3, 0x5d, 0x3b, 0xe8, 0xae,
		0xb8, 0x78, 0x67, 0xce, 0x77, 0x69, 0x06, 0x08, 0x3f, 0x89, 0xca, 0x49, 0x98, 0x74, 0xc3, 0xb4,
		0x3f, 0xfc, 0xe2, 0xf0, 0xd8, 0xa4, 0xf3, 0x12, 0xb1, 0x68, 0x69, 0x58, 0xa0, 0x24, 0x2c, 0x54,
		0x0a, 0x96, 0xa9, 0x59, 0x08, 0xb6, 0x7f, 0x44, 0xeb, 0x7e, 0xd2, 0xa5, 0x5e, 0x8d, 0xf2, 0xde,
		0x8d, 0x4c, 0x91, 0x28, 0xf7, 0x5f, 0xa9, 0x74, 0x09, 0x57, 0xe5, 0xbb, 0xf5, 0xb4, 0x50, 0x76,
		0x59, 0xa0, 0x99, 0x84, 0x61, 0x7f, 0x9c, 0x46, 0xc3, 0x20, 0xee, 0xba, 0x4f, 0x5a, 0x97, 0x6f,
		0x4d, 0xee, 0x4a, 0xee, 0x4a, 0xee, 0xea, 0x61, 0xee, 0x2a, 0x97, 0x67, 0x76, 0xfb, 0x69, 0x1a,
		0x75, 0x83, 0xff, 0x1b, 0x87, 0x5d, 0x81, 0x4c, 0x73, 0xf7, 0x37, 0x87, 0xef, 0xd9, 0x08, 0xd3,
		0x34, 0x1a, 0x26, 0xce, 0x93, 0xcd, 0xf2, 0x4f, 0x3f, 0xbd, 0xdb, 0x09, 0x9e, 0x5f, 0xfe, 0xf3,
		0x6e, 0x37, 0x78, 0x7e, 0x39, 0xfb, 0x71, 0x77, 0xfa, 0x9f, 0xd9, 0xcf, 0x95, 0x77, 0x3b, 0x41,
		0x75, 0xf1, 0xf3, 0xde, 0xbb, 0x9d, 0x60, 0xef, 0xf2, 0xe7, 0x7f, 0xff, 0xfb, 0xd7, 0x9f, 0xff,
		0xf3, 0xec, 0xe6, 0xfb, 0x7f, 0xd1, 0x9d, 0x85, 0x5e, 0xba, 0xdc, 0xda, 0xb3, 0x66, 0xfd, 0x4f,
		0xb1, 0xfd, 0xfd, 0x1f, 0xcd, 0x0d, 0xfe, 0xaf, 0x72, 0xf1, 0xf2, 0x07, 0xba, 0x27, 0x1b, 0x74,
		0x4f, 0x9c, 0x8c, 0xd8, 0x6a, 0xb6, 0x4d, 0x36, 0x1d, 0xa6, 0xb5, 0xe9, 0x97, 0x74, 0x67, 0xb7,
		0x57, 0x06, 0xd3, 0x6c, 0x32, 0xe8, 0xc6, 0xb3, 0xc7, 0x75, 0xd7, 0x3f, 0x79, 0xe0, 0xfd, 0xe9,
		0xa7, 0xe8, 0xa5, 0xa4, 0xf4, 0x53, 0xe8, 0xa7, 0x3c, 0xfc, 0x46, 0xe8, 0xd9, 0xc3, 0x4d, 0xe1,
		0xa6, 0xdb, 0xc7, 0x4d, 0x9d, 0xcf, 0xcd, 0x47, 0x9f, 0x27, 0x34, 0x24, 0xec, 0xb9, 0x4e, 0x25,
		0x1e, 0xf4, 0x8b, 0x87, 0x16, 0x64, 0xe2, 0x87, 0x89, 0x1f, 0xb3, 0x10, 0xa5, 0x16, 0xaa, 0x54,
		0x42, 0x96, 0xdb, 0xd0, 0xe5, 0x38, 0x84, 0xc9, 0x95, 0xd9, 0xd6, 0xec, 0x7d, 0x1c, 0x27, 0xe9,
		0x6f, 0x82, 0xd3, 0x3e, 0x7b, 0x4c, 0xfb, 0x2c, 0x3f, 0x78, 0x11, 0xa7, 0x7d, 0x76, 0x99, 0xf6,
		0x79, 0xd4, 0x57, 0x5f, 0xc0, 0x69, 0x9f, 0xca, 0x1e, 0x63, 0x3e, 0xea, 0xef, 0xba, 0x0d, 0x63,
		0xf4, 0x71, 0xa2, 0x9c, 0x70, 0x3f, 0xb4, 0x20, 0x09, 0x37, 0x09, 0x37, 0x09, 0x37, 0x09, 0x37,
		0x09, 0x37, 0x09, 0x37, 0x09, 0x37, 0x09, 0x37, 0x09, 0x37, 0x09, 0xb7, 0x37, 0x09, 0x37, 0x53,
		0xd7, 0x8e, 0x0f, 0x67, 0xdc, 0xdf, 0xd1, 0xcf, 0xaf, 0x2c, 0xfa, 0xcb, 0xd9, 0xf3, 0x9c, 0x4f,
		0x1e, 0xe7, 0xe5, 0xfc, 0x69, 0x50, 0x47, 0x7f, 0x6c, 0xa2, 0x86, 0x3a, 0xba, 0xaf, 0x0c, 0x8f,
		0x2e, 0xaf, 0x09, 0x83, 0xa3, 0xcb, 0xeb, 0xd6, 0x2f, 0xe8, 0xf2, 0x52, 0x74, 0xa2, 0xe8, 0x44,
		0xd1, 0x89, 0xa2, 0x13, 0x45, 0x27, 0x8a, 0x4e, 0x14, 0x9d, 0x28, 0x3a, 0x51, 0x74, 0xf2, 0xbe,
		0xe8, 0x44, 0x97, 0x97, 0x84, 0x9b, 0x84, 0x9b, 0x84, 0x9b, 0x84, 0x9b, 0x84, 0x9b, 0x84, 0x9b,
		0x84, 0x9b, 0x84, 0x9b, 0x84, 0x9b, 0x84, 0x5b, 0x30, 0xe1, 0xa6, 0xcb, 0xab, 0xd3, 0xe5, 0xcd,
		0xab, 0xc8, 0xf6, 0xbd, 0x4d, 0x5e, 0xb4, 0xb6, 0xa5, 0x4c, 0xd6, 0x03, 0x53, 0xcd, 0x91, 0x7a,
		0xc4, 0x7d, 0xc6, 0x99, 0x4b, 0x2d, 0x89, 0x2f, 0x49, 0x78, 0x1d, 0x77, 0x82, 0x24, 0x8a, 0xaf,
		0x3e, 0xbe, 0xef, 0x0f, 0x83, 0x19, 0x15, 0x8c, 0x46, 0x0e, 0xe5, 0x24, 0x1e, 0x5c, 0x02, 0x45,
		0x09, 0xbd, 0xf2, 0x02, 0x8a, 0x12, 0x28, 0x4a, 0x7c, 0x77, 0x18, 0x70, 0x7f, 0xf6, 0xe8, 0xa1,
		0x85, 0xd0, 0x9c, 0xf0, 0xaf, 0x12, 0xc9, 0x69, 0x24, 0x93, 0x4a, 0x63, 0xc1, 0x4f, 0x23, 0x39,
		0x16, 0xaf, 0x59, 0x73, 0x03, 0xe7, 0x87, 0x5a, 0x05, 0x02, 0x8b, 0x58, 0x80, 0x91, 0x0c, 0x34,
		0xf2, 0x01, 0x47, 0x3a, 0xf0, 0xa8, 0x05, 0x20, 0xb5, 0x40, 0xa4, 0x12, 0x90, 0x64, 0x6a, 0x53,
		0xae, 0x5b, 0x1f, 0xae, 0x03, 0x55, 0xf6, 0xc6, 0x83, 0x28, 0x1a, 0x06, 0x57, 0xc3, 0xfe, 0x78,
		0x20, 0x67, 0x90, 0x0b, 0x97, 0xba, 0xb5, 0xd6, 0x2f, 0xb9, 0x14, 0x5b, 0x97, 0x0a, 0x68, 0x1a,
		0x81, 0x4d, 0x2f, 0xc0, 0x69, 0x05, 0x3a, 0xf5, 0x80, 0xa7, 0x1e, 0xf8, 0x54, 0x03, 0xa0, 0x4c,
		0x20, 0x14, 0x0a, 0x88, 0xd9, 0xce, 0x88, 0xf5, 0x84, 0xd7, 0xfc, 0xa5, 0x17, 0x85, 0x1f, 0x86,
		0xd1, 0x07, 0x49, 0x87, 0x59, 0xe4, 0x61, 0x07, 0x82, 0x6b, 0x34, 0xe6, 0x25, 0xd0, 0x5f, 0x7f,
		0x7d, 0x7a, 0xfb, 0xff, 0x96, 0xb1, 0x79, 0x74, 0xeb, 0xe7, 0xf9, 0x10, 0xd5, 0xad, 0x3f, 0x09,
		0xa6, 0xc5, 0xc7, 0x9c, 0x74, 0x87, 0x24, 0x2e, 0x0b, 0x19, 0xc8, 0x86, 0xe8, 0x25, 0x58, 0x8a,
		0xa6, 0x6e, 0x00, 0x25, 0x40, 0x09, 0x50, 0x02, 0x94, 0x12, 0xfe, 0x12, 0x0f, 0x02, 0x71, 0xeb,
		0xca, 0xa0, 0xf2, 0xb9, 0xe0, 0x1a, 0xf3, 0x2d, 0x7b, 0x27, 0x6a, 0xb2, 0xb2, 0x2e, 0x7f, 0xe7,
		0x8b, 0xf9, 0x54, 0x0d, 0x54, 0x1c, 0xbf, 0x24, 0x74, 0x77, 0xc7, 0xd7, 0xb2, 0x1a, 0x91, 0x3b,
		0x27, 0x1e, 0x5c, 0x50, 0xf3, 0x2a, 0x8a, 0xa7, 0xf3, 0xc5, 0x7e, 0xfe, 0xe7, 0xa7, 0x77, 0xbb,
		0x41, 0xe5, 0x72, 0xf1, 0x3f, 0x9e, 0xbd, 0xdb, 0x09, 0x2a, 0x97, 0x3f, 0xff, 0x5c, 0x16, 0x7f,
		0xe4, 0x4b, 0x8d, 0xaf, 0x50, 0xf2, 0xee, 0x90, 0x07, 0x57, 0xfd, 0x1f, 0x9f, 0xbe, 0xc8, 0xff,
		0x52, 0xf8, 0x26, 0x45, 0x57, 0xb8, 0xf9, 0xa5, 0x40, 0xb1, 0x72, 0x9f, 0x58, 0xe9, 0x32, 0x56,
		0x86, 0xc1, 0x87, 0xc3, 0xe0, 0xd5, 0xe5, 0x7f, 0x76, 0x7f, 0xa9, 0xde, 0xfc, 0xfe, 0xf3, 0x7f,
		0x0e, 0x6e, 0xee, 0xfe, 0xe1, 0x3f, 0xf7, 0xfd, 0xb3, 0xdd, 0x5f, 0x0e, 0x6e, 0x7e, 0x7f, 0xe0,
		0x6f, 0xf6, 0x6f, 0x7e, 0x7f, 0xe4, 0x7b, 0xec, 0xdd, 0xfc, 0xb4, 0xf6, 0x4f, 0x27, 0x7f, 0x5e,
		0x79, 0xe8, 0x17, 0xaa, 0x0f, 0xfc, 0xc2, 0xb3, 0x87, 0x7e, 0xe1, 0xd9, 0x03, 0xbf, 0xf0, 0xe0,
		0x47, 0xaa, 0x3c, 0xf0, 0x0b, 0x7b, 0x37, 0xff, 0xac, 0xfd, 0xfb, 0x9f, 0xee, 0xff, 0xa7, 0xfb,
		0x37, 0x3f, 0xff, 0xf3, 0xd0, 0xdf, 0x1d, 0xdc, 0xfc, 0xf3, 0xfb, 0xcf, 0x3f, 0x3f, 0xfd, 0x69,
		0x77, 0x12, 0x87, 0x7e, 0x9b, 0x85, 0xa6, 0xdd, 0xcb, 0xb5, 0x88, 0x35, 0x8b, 0x40, 0x00, 0xc8,
		0xc6, 0x00, 0x82, 0x75, 0x7b, 0x6b, 0xdd, 0xf9, 0x47, 0xd5, 0x27, 0xf9, 0xfa, 0xdc, 0x37, 0x5b,
		0xd6, 0x9c, 0x13, 0x3a, 0x5e, 0x9d, 0xbd, 0xbf, 0xea, 0xd9, 0xd5, 0x87, 0xce, 0x33, 0x3e, 0xf4,
		0x37, 0x4f, 0x45, 0x8e, 0x24, 0x94, 0x34, 0x4f, 0xbb, 0xce, 0x1e, 0xec, 0x74, 0xfe, 0x5c, 0x8d,
		0xf9, 0x03, 0xdf, 0xff, 0xe7, 0x4e, 0x85, 0xb8, 0xdc, 0x9b, 0xb7, 0xcb, 0x41, 0x5f, 0xa1, 0x4a,
		0xb7, 0x6c, 0x85, 0x9b, 0x31, 0x5e, 0xcd, 0x0a, 0x36, 0x67, 0x59, 0xbc, 0xac, 0x50, 0x6f, 0xfb,
		0x18, 0xaf, 0x5c, 0xab, 0x56, 0xb2, 0x45, 0x7b, 0xbb, 0x35, 0xbb, 0xe8, 0xbb, 0xce, 0x6c, 0x7e,
		0x0b, 0xc0, 0xc6, 0xad, 0x1a, 0xe4, 0x9a, 0x45, 0xb8, 0x1e, 0x13, 0x2b, 0x69, 0x1c, 0x9b, 0xac,
		0x00, 0x35, 0x40, 0x0d, 0x50, 0xb3, 0xc1, 0x0e, 0x70, 0x6c, 0xd2, 0x30, 0x67, 0x16, 0xcf, 0x9d,
		0x35, 0x02, 0x9b, 0x5e, 0x80, 0xd3, 0x0a, 0x74, 0xea, 0x01, 0x4f, 0x3d, 0xf0, 0xa9, 0x06, 0x40,
		0xd9, 0x22, 0x1d, 0xc7, 0x26, 0x6d, 0x73, 0xf2, 0xfb, 0x72, 0x73, 0x8e, 0x4d, 0xfa, 0x53, 0x4c,
		0xd2, 0x29, 0x2a, 0x01, 0x94, 0x00, 0x25, 0x40, 0x09, 0x50, 0x8a, 0xfa, 0x0b, 0xc7, 0x26, 0xbf,
		0xe7, 0xc5, 0xb1, 0x49, 0x47, 0x59, 0x0d, 0xc7, 0x26, 0xe5, 0x5e, 0x1c, 0x9b, 0xe4, 0xd8, 0xa4,
		0x21, 0x78, 0xd9, 0xc4, 0x4a, 0x8e, 0x4d, 0x3a, 0x8d, 0x95, 0x1c, 0x2c, 0xe3, 0xd8, 0x64, 0x71,
		0x01, 0x04, 0xeb, 0xe6, 0xd8, 0x64, 0xbe, 0x88, 0x66, 0x89, 0x63, 0x93, 0xae, 0x8a, 0x0e, 0x5b,
		0x7d, 0x6c, 0x52, 0xe2, 0x44, 0x42, 0xc9, 0xdb, 0x53, 0x93, 0x0e, 0x95, 0x6d, 0xdd, 0x1b, 0xb7,
		0x5f, 0x9a, 0x64, 0xff, 0x8a, 0xbe, 0xb8, 0x97, 0x9d, 0x3c, 0x8e, 0x47, 0xe9, 0x61, 0x9a, 0x3a,
		0x56, 0x3b, 0x3b, 0x89, 0x93, 0x5a, 0x2f, 0xba, 0x8e, 0x92, 0x99, 0x1a, 0xb9, 0xc3, 0xe3, 0x40,
		0x27, 0xe1, 0xe7, 0x5b, 0xef, 0xbc, 0xfb, 0x5b, 0xb5, 0xba, 0x7f, 0x50, 0xad, 0xee, 0x1c, 0x3c,
		0x3b, 0xd8, 0x79, 0xbe, 0xb7, 0xb7, 0xbb, 0xbf, 0xeb, 0x50, 0x6b, 0xbd, 0x7c, 0x36, 0xec, 0x46,
		0xc3, 0xa8, 0xfb, 0x62, 0xb2, 0xef, 0xc9, 0xb8, 0xd7, 0x43, 0xbb, 0xdb, 0x3a, 0x3a, 0xe6, 0x51,
		0xd0, 0xfb, 0x7b, 0xe2, 0x21, 0x1a, 0xdf, 0xb9, 0xd7, 0xf8, 0x16, 0xd2, 0x7d, 0xf6, 0xc0, 0x64,
		0xf3, 0xa8, 0xf4, 0x7d, 0x35, 0x0c, 0x3b, 0xd1, 0x87, 0x71, 0x2f, 0x18, 0x46, 0xa3, 0x34, 0x1c,
		0xa6, 0xee, 0x04, 0xbe, 0xd7, 0xde, 0x19, 0x5d, 0xef, 0x6f, 0xee, 0x19, 0xba, 0xde, 0xe8, 0x7a,
		0x3f, 0xfc, 0x44, 0xce, 0x74, 0xbd, 0x1d, 0x8b, 0xed, 0xca, 0x88, 0xec, 0xa2, 0xda, 0x8d, 0x6a,
		0x37, 0xaa, 0xdd, 0x4e, 0x29, 0x91, 0x73, 0xd5, 0xee, 0x28, 0x09, 0xdf, 0xf7, 0xa2, 0xae, 0xdc,
		0xf8, 0xc9, 0x62, 0x01, 0x66, 0x1d, 0x19, 0x40, 0x31, 0x0b, 0x41, 0x6a, 0xa1, 0x48, 0x25, 0x24,
		0xe5, 0xa3, 0xc6, 0x2d, 0x3f, 0xeb, 0xf8, 0xbe, 0xdf, 0xef, 0x45, 0x61, 0x22, 0x39, 0xeb, 0xb8,
		0xbb, 0x05, 0xf3, 0x87, 0x1f, 0xa3, 0xde, 0x20, 0x1a, 0x06, 0xfd, 0xa4, 0xf7, 0x45, 0x0e, 0x06,
		0x6e, 0x2f, 0x02, 0x14, 0x00, 0x05, 0x40, 0x01, 0x50, 0x00, 0x14, 0xf8, 0x06, 0x05, 0xf3, 0x42,
		0x5f, 0x90, 0xc6, 0xd7, 0x82, 0x13, 0xe9, 0x2b, 0xab, 0x00, 0x06, 0x80, 0x01, 0x60, 0x00, 0x18,
		0x38, 0xb4, 0xf7, 0x71, 0x9c, 0xa4, 0xbb, 0xfb, 0x82, 0x58, 0xb0, 0x2f, 0xf0, 0xd6, 0xe7, 0x61,
		0x72, 0x25, 0x37, 0x3b, 0x22, 0x38, 0xc4, 0x73, 0x12, 0x27, 0x85, 0xbb, 0xd0, 0x7e, 0xa7, 0x40,
		0xd7, 0xd9, 0x0b, 0x8e, 0x3b, 0x9d, 0x84, 0x9f, 0x0b, 0xf7, 0xd5, 0x57, 0x77, 0x9e, 0xef, 0x17,
		0xe8, 0xdb, 0xcf, 0xc9, 0x71, 0xcd, 0xcb, 0xed, 0xd0, 0x79, 0xea, 0x45, 0xb3, 0x9b, 0xd1, 0x47,
		0xc2, 0x19, 0xf6, 0xfa, 0x52, 0xa4, 0xd9, 0xa4, 0xd9, 0xa4, 0xd9, 0xa4, 0xd9, 0x0e, 0xed, 0xbd,
		0x1b, 0x75, 0xe2, 0xeb, 0xb0, 0xb7, 0x5f, 0x95, 0xac, 0xba, 0x54, 0x04, 0xde, 0x7b, 0x0d, 0x7f,
		0x2b, 0xe4, 0xf3, 0x36, 0xf9, 0x7c, 0x85, 0x7c, 0x7e, 0x5b, 0xf3, 0xf9, 0x67, 0x7c, 0xf5, 0x24,
		0xf3, 0xca, 0xc9, 0x3c, 0xd3, 0x0d, 0x8e, 0x8f, 0x82, 0xdf, 0x3d, 0x21, 0xec, 0x5e, 0x11, 0x5f,
		0xeb, 0x40, 0xf8, 0xeb, 0xf9, 0x93, 0x9c, 0xcf, 0x1e, 0xc4, 0xa9, 0xd6, 0xbd, 0x83, 0x61, 0x05,
		0x27, 0x27, 0xeb, 0x5d, 0xca, 0x0c, 0x8b, 0xc8, 0x0b, 0x8b, 0x1d, 0x18, 0xad, 0x70, 0x60, 0x34,
		0x47, 0x74, 0x91, 0x03, 0xa3, 0x1c, 0x18, 0xe5, 0xc0, 0x28, 0x15, 0x2b, 0x2a, 0x56, 0x54, 0xac,
		0x9c, 0xda, 0x3b, 0xa7, 0x84, 0x9c, 0x3c, 0x2b, 0x07, 0x46, 0x81, 0x02, 0xa0, 0x00, 0x28, 0x00,
		0x0a, 0xb6, 0x1e, 0x0a, 0x38, 0x30, 0x0a, 0x18, 0x00, 0x06, 0x80, 0x41, 0xbe, 0xc1, 0x80, 0x03,
		0xa3, 0x6b, 0x2f, 0x0e, 0x8c, 0x3e, 0x6a, 0x19, 0x1a, 0xcc, 0xdf, 0xf7, 0xd5, 0x73, 0x60, 0xd4,
		0xf7, 0x6f, 0x9f, 0x1e, 0xb3, 0x37, 0xc9, 0x35, 0x07, 0x46, 0x49, 0xb3, 0x49, 0xb3, 0x49, 0xb3,
		0x8b, 0x92, 0x66, 0x73, 0x60, 0x94, 0x7c, 0x7e, 0xc3, 0xaf, 0x97, 0x03, 0xa3, 0x5b, 0x9b, 0xcf,
		0x73, 0x60, 0x94, 0x64, 0x5e, 0x3b, 0x99, 0xe7, 0xc0, 0xa8, 0xf4, 0x81, 0x51, 0xd7, 0x77, 0x01,
		0x58, 0x9d, 0x17, 0x75, 0xa8, 0xf2, 0x8f, 0xb6, 0xb5, 0x3f, 0xf6, 0x99, 0x23, 0x49, 0xeb, 0x3b,
		0x16, 0x99, 0x47, 0x29, 0xeb, 0x69, 0xfd, 0x21, 0x18, 0x45, 0xbd, 0x68, 0x8a, 0x90, 0x41, 0x7f,
		0x30, 0xf9, 0xcf, 0xc8, 0x9d, 0xa2, 0xf5, 0x43, 0x0b, 0x20, 0x6c, 0xad, 0x57, 0xac, 0x40, 0xd8,
		0x1a, 0x61, 0xeb, 0x87, 0xdf, 0x08, 0x61, 0x6b, 0x4f, 0xab, 0x97, 0xcc, 0x29, 0xe8, 0x57, 0x27,
		0x99, 0x53, 0xf8, 0xf1, 0x37, 0x0c, 0xbb, 0x9f, 0xa2, 0x61, 0x1a, 0x8f, 0xa2, 0x20, 0x4e, 0x26,
		0x84, 0xfb, 0xd3, 0xa2, 0xbd, 0x21, 0xd7, 0x44, 0x79, 0x78, 0x49, 0xc7, 0x66, 0xf1, 0x32, 0xfa,
		0x10, 0x8e, 0x7b, 0x53, 0xab, 0xf8, 0x10, 0xf6, 0x46, 0x34, 0x6b, 0x68, 0xd6, 0x18, 0x86, 0x41,
		0xb5, 0x70, 0xa8, 0x12, 0x16, 0x65, 0xaa, 0x5c, 0x1c, 0x90, 0xbd, 0x27, 0x7b, 0xda, 0x86, 0x03,
		0xb2, 0x61, 0xef, 0xef, 0xf0, 0xcb, 0x28, 0xe8, 0xf4, 0xaf, 0x07, 0xe1, 0x30, 0x0a, 0xae, 0x25,
		0x27, 0xe7, 0xee, 0x59, 0x0b, 0xe0, 0x01, 0x78, 0x00, 0x1e, 0x80, 0x07, 0xe0, 0xd9, 0x36, 0xe0,
		0x99, 0x8d, 0x51, 0x07, 0x61, 0x7c, 0x35, 0x90, 0x9e, 0xd5, 0x9e, 0x2d, 0x02, 0xd4, 0x00, 0x35,
		0x40, 0x0d, 0x50, 0x03, 0xd4, 0x6c, 0x1d, 0xd4, 0x7c, 0x4e, 0xa3, 0x61, 0x12, 0xf6, 0x32, 0xe6,
		0x31, 0xad, 0x7a, 0x0d, 0x83, 0x58, 0x52, 0x25, 0xe4, 0xe1, 0x35, 0xe5, 0x80, 0x68, 0xe2, 0xee,
		0xe0, 0x10, 0x38, 0x04, 0x0e, 0x81, 0x43, 0xe0, 0x90, 0x77, 0x38, 0x14, 0x5f, 0x25, 0xfd, 0x61,
		0x14, 0x84, 0xa3, 0x60, 0x10, 0xa6, 0x1f, 0x83, 0x5e, 0x94, 0x5c, 0x4d, 0xcf, 0x0c, 0x09, 0x41,
		0xd0, 0xfd, 0xcb, 0x41, 0x83, 0x80, 0x1f, 0xe0, 0x07, 0xf8, 0x01, 0x7e, 0xb6, 0x14, 0x7e, 0x92,
		0xe8, 0x73, 0x1a, 0x7c, 0xec, 0x0f, 0x82, 0xf8, 0x6a, 0x10, 0x5c, 0x47, 0xe9, 0x30, 0xee, 0x88,
		0x63, 0xd0, 0x7d, 0x6b, 0x02, 0x44, 0x00, 0x11, 0x40, 0x04, 0x10, 0x01, 0x44, 0xb9, 0x00, 0x22,
		0x46, 0x8d, 0x1c, 0x8f, 0x72, 0x3c, 0x70, 0xd6, 0x3f, 0xbf, 0x12, 0xf5, 0xe7, 0x93, 0x07, 0x6a,
		0x2e, 0x9e, 0xe7, 0x6c, 0xf6, 0x38, 0x08, 0xd5, 0x3f, 0x36, 0xb8, 0x20, 0x54, 0xef, 0x6b, 0x56,
		0xc2, 0x01, 0x70, 0x93, 0xac, 0x83, 0x03, 0xe0, 0xae, 0x3d, 0x83, 0x03, 0xe0, 0x90, 0x31, 0xc8,
		0x18, 0x64, 0x0c, 0x32, 0x46, 0x55, 0x30, 0x83, 0x21, 0x0e, 0x80, 0x03, 0x3c, 0x00, 0x0f, 0xc0,
		0x03, 0xf0, 0x00, 0x3c, 0x9a, 0xc0, 0xc3, 0x01, 0x70, 0xa0, 0x06, 0xa8, 0x01, 0x6a, 0x80, 0x1a,
		0xa0, 0x46, 0x1a, 0x6a, 0x38, 0x00, 0x0e, 0x0e, 0x81, 0x43, 0xe0, 0x10, 0x38, 0x04, 0x0e, 0x19,
		0xe2, 0x10, 0x07, 0xc0, 0x81, 0x1f, 0xe0, 0x07, 0xf8, 0x01, 0x7e, 0x80, 0x1f, 0x3b, 0xf8, 0xe1,
		0x00, 0x38, 0x40, 0x04, 0x10, 0x01, 0x44, 0x00, 0x11, 0x40, 0xa4, 0xfd, 0x4e, 0x1c, 0x00, 0xff,
		0xf6, 0x01, 0xf0, 0xbc, 0x5e, 0x39, 0x71, 0xff, 0xf9, 0x6f, 0x2e, 0x9e, 0x90, 0x32, 0x5a, 0x1f,
		0x8c, 0x35, 0x47, 0xf7, 0x4f, 0xdc, 0x6b, 0x9e, 0x79, 0xbc, 0x85, 0xc2, 0xcd, 0xfc, 0x81, 0xd3,
		0xb9, 0x03, 0xe7, 0x37, 0x4c, 0x54, 0xb8, 0x61, 0xc2, 0x83, 0x64, 0x96, 0x1b, 0x26, 0xbe, 0x83,
		0x7e, 0xba, 0xba, 0x61, 0x22, 0x1c, 0xb9, 0x9f, 0x2d, 0x0a, 0x47, 0x8e, 0x07, 0x8b, 0x76, 0xb8,
		0x59, 0xc2, 0x63, 0x96, 0xcb, 0x60, 0x51, 0x8e, 0xa8, 0xcc, 0x49, 0x98, 0x74, 0xc3, 0xb4, 0x3f,
		0xfc, 0xe2, 0x70, 0x5e, 0xcf, 0x39, 0x13, 0xbe, 0x15, 0x49, 0x82, 0x64, 0x7c, 0xfd, 0x3e, 0x1a,
		0xba, 0x74, 0x83, 0x79, 0x50, 0x39, 0x70, 0xf8, 0x96, 0x32, 0xb7, 0xd5, 0x0a, 0x94, 0x16, 0x24,
		0x6f, 0xa7, 0x15, 0xaa, 0x59, 0x66, 0x6f, 0x2f, 0x7c, 0x25, 0xa9, 0xc6, 0x55, 0xa4, 0x02, 0xb7,
		0xcf, 0x8a, 0xde, 0x3a, 0xab, 0xf5, 0x95, 0x56, 0x2b, 0xcf, 0xab, 0xcf, 0xf7, 0x0f, 0x2a, 0xcf,
		0xf7, 0x72, 0xfc, 0xdd, 0x7a, 0x5a, 0x4a, 0xbb, 0x2c, 0xd0, 0x30, 0xbc, 0xfb, 0x93, 0x74, 0xab,
		0x97, 0x21, 0x3a, 0x3c, 0x30, 0x47, 0xee, 0x4a, 0xee, 0x4a, 0xee, 0xea, 0x34, 0x77, 0x95, 0xcb,
		0x33, 0xbb, 0xfd, 0x34, 0x8d, 0xba, 0xc1, 0xff, 0x8d, 0xc3, 0xae, 0x40, 0xa6, 0xb9, 0xfb, 0x9b,
		0xc3, 0xf7, 0x6c, 0x84, 0x69, 0x1a, 0x0d, 0x13, 0xe7, 0xc9, 0x66, 0xf9, 0xa7, 0x9f, 0xde, 0xed,
		0x04, 0xcf, 0x2f, 0xff, 0x79, 0xb7, 0x1b, 0x3c, 0xbf, 0x9c, 0xfd, 0xb8, 0x3b, 0xfd, 0xcf, 0xec,
		0xe7, 0xca, 0xbb, 0x9d, 0xa0, 0xba, 0xf8, 0x79, 0xef, 0xdd, 0x4e, 0xb0, 0x77, 0xf9, 0xf3, 0xbf,
		0xff, 0xfd, 0xeb, 0xcf, 0xff, 0x79, 0x76, 0xf3, 0xfd, 0xbf, 0xe8, 0xce, 0x42, 0x2f, 0x5d, 0x6e,
		0xed, 0x59, 0xb3, 0xfe, 0xa7, 0xd8, 0xfe, 0xfe, 0x8f, 0xe6, 0x06, 0xff, 0x57, 0x99, 0xfc, 0xe1,
		0x9e, 0xef, 0x20, 0xed, 0xa7, 0x61, 0x6f, 0x7a, 0x3e, 0x51, 0xa0, 0xec, 0x75, 0xfb, 0xcd, 0xc9,
		0x21, 0xc8, 0x21, 0xc8, 0x21, 0xb6, 0x2a, 0x87, 0x18, 0xc7, 0x49, 0xfa, 0xac, 0x42, 0xa1, 0x8a,
		0x42, 0x15, 0x85, 0x2a, 0x0a, 0x55, 0x14, 0xaa, 0x48, 0x34, 0x83, 0x59, 0x36, 0x10, 0xc9, 0xe5,
		0x9a, 0x8b, 0xf7, 0x27, 0xdd, 0x24, 0xdd, 0x24, 0xdd, 0x24, 0xdd, 0x24, 0xdd, 0x24, 0xdd, 0x24,
		0xdd, 0x24, 0xdd, 0x24, 0xdd, 0xcc, 0x51, 0xba, 0xc9, 0x29, 0xf1, 0x1f, 0x3c, 0x25, 0xee, 0x6a,
		0x74, 0x41, 0xeb, 0x4c, 0xb8, 0x83, 0xe1, 0x04, 0x9b, 0x33, 0xe0, 0xe3, 0x51, 0x14, 0x5c, 0x8f,
		0x7b, 0x69, 0x3c, 0xe8, 0x45, 0x8e, 0xaa, 0xe7, 0xcb, 0x3c, 0x66, 0xfd, 0xbd, 0x3d, 0x3b, 0x1d,
		0xbe, 0xc3, 0xe9, 0x70, 0x0f, 0xd8, 0x09, 0xa7, 0xc3, 0x1f, 0xff, 0x44, 0xce, 0x4e, 0x87, 0x77,
		0x16, 0x3e, 0xe0, 0xb8, 0x7c, 0xe1, 0xf4, 0xd6, 0x11, 0xb1, 0xeb, 0x27, 0x28, 0x5b, 0x50, 0xb6,
		0xd8, 0xce, 0xb2, 0x85, 0xf3, 0xeb, 0x27, 0x66, 0xca, 0xa8, 0x5d, 0x69, 0xe9, 0x55, 0x14, 0xbe,
		0x65, 0x42, 0x98, 0x64, 0x28, 0x93, 0x0f, 0x69, 0xd2, 0xa1, 0x4d, 0x2d, 0xc4, 0xa9, 0x85, 0x3a,
		0x95, 0x90, 0x27, 0x54, 0x20, 0x40, 0xe6, 0x61, 0x3d, 0x33, 0x42, 0xe6, 0xc1, 0xa0, 0x16, 0x62,
		0x52, 0x13, 0x59, 0xa7, 0xd3, 0xf9, 0xbd, 0xe2, 0xef, 0x62, 0x14, 0x9d, 0xcc, 0x1f, 0xa5, 0x31,
		0x79, 0x92, 0x02, 0xde, 0xee, 0x17, 0xbd, 0x77, 0xa8, 0x47, 0xbf, 0x4c, 0x86, 0xdc, 0xe1, 0x27,
		0xe4, 0x0a, 0x72, 0x05, 0xb9, 0xf2, 0x9b, 0x5c, 0x39, 0xae, 0xd2, 0xc8, 0x56, 0x6b, 0x84, 0x02,
		0x0b, 0xd4, 0x07, 0xea, 0x03, 0xf5, 0x71, 0x5c, 0xfc, 0x70, 0x1c, 0xa8, 0xb2, 0x37, 0x0e, 0x7b,
		0xbd, 0xfe, 0xdf, 0xcb, 0x34, 0x35, 0x1c, 0xc9, 0xd9, 0xe5, 0xf2, 0x32, 0xb8, 0xbb, 0x4b, 0x0a,
		0x99, 0x8d, 0x70, 0xc5, 0x48, 0xb8, 0x72, 0x24, 0x1e, 0x46, 0x35, 0xc2, 0xa9, 0x5e, 0x58, 0xd5,
		0x0a, 0xaf, 0xea, 0x61, 0x56, 0x3d, 0xdc, 0xaa, 0x86, 0x5d, 0x99, 0xf0, 0x2b, 0x14, 0x86, 0xe5,
		0x2b, 0x51, 0x8a, 0x15, 0x29, 0xe1, 0xca, 0x94, 0xdc, 0x17, 0x2b, 0x71, 0x42, 0xed, 0x3a, 0xfc,
		0x1c, 0x5f, 0x8f, 0xaf, 0x1d, 0xcf, 0x23, 0x3e, 0xf8, 0xad, 0xae, 0x2e, 0x27, 0x0f, 0x7f, 0xbb,
		0x40, 0x1f, 0xd0, 0x07, 0xf4, 0x01, 0x7d, 0x79, 0x82, 0x3e, 0xe7, 0xc7, 0xea, 0x1f, 0x8a, 0x5e,
		0x07, 0x82, 0x4b, 0xc8, 0x1c, 0xbb, 0xbf, 0xfb, 0x92, 0xf5, 0xf7, 0x92, 0xf4, 0xb1, 0x7c, 0x65,
		0x58, 0x59, 0x5b, 0x4e, 0xf8, 0xd8, 0xfe, 0xda, 0x7a, 0x0a, 0x47, 0xbd, 0x95, 0xc2, 0xc1, 0xaa,
		0x89, 0x84, 0x9f, 0x0b, 0x6f, 0x22, 0xd2, 0x63, 0x00, 0x5e, 0xd8, 0xca, 0x93, 0x7c, 0xbe, 0xfb,
		0x65, 0x5e, 0x08, 0x8c, 0xd7, 0xa5, 0x46, 0xa1, 0xd6, 0x7b, 0xf6, 0xfe, 0xc6, 0x2d, 0xf8, 0x68,
		0xf2, 0xd7, 0x22, 0x6d, 0x94, 0x92, 0x65, 0x3f, 0xbe, 0xf6, 0xfe, 0x6a, 0xe0, 0xb4, 0x29, 0xef,
		0xde, 0x58, 0x6f, 0x9c, 0x1e, 0x7b, 0x70, 0x21, 0x85, 0xff, 0x60, 0xea, 0xe9, 0xfa, 0x26, 0x8e,
		0x92, 0x46, 0x97, 0xad, 0x42, 0x97, 0x4d, 0x8f, 0x0b, 0xd3, 0x65, 0x2b, 0x20, 0xf4, 0xd1, 0x65,
		0xfb, 0x91, 0x4d, 0xa3, 0xcb, 0x66, 0x1d, 0x4e, 0xf5, 0xc2, 0xaa, 0x56, 0x78, 0x55, 0x0f, 0xb3,
		0xea, 0xe1, 0x56, 0x35, 0xec, 0xca, 0x72, 0x2f, 0xba, 0x6c, 0xdf, 0x91, 0xfd, 0xd1, 0x65, 0xa3,
		0xcb, 0x06, 0xf4, 0x01, 0x7d, 0x40, 0x1f, 0xd0, 0xe7, 0x03, 0xf4, 0xd1, 0x65, 0x7b, 0xf4, 0x8b,
		0x2e, 0xdb, 0x46, 0xcb, 0xd1, 0x65, 0x73, 0x63, 0x22, 0x74, 0xd9, 0x8a, 0x61, 0x2b, 0x74, 0xd9,
		0x64, 0x09, 0x0c, 0x5d, 0x36, 0xe3, 0x2e, 0x9b, 0x44, 0x17, 0xa5, 0x64, 0xde, 0x64, 0x73, 0x78,
		0xaf, 0xb9, 0x7b, 0x53, 0x65, 0x8a, 0x5b, 0xc9, 0xb8, 0x8b, 0x30, 0xc3, 0x5d, 0x73, 0x46, 0xb8,
		0xfc, 0x98, 0xe0, 0x8e, 0x45, 0x26, 0xb8, 0x63, 0x26, 0xb8, 0xfd, 0x2c, 0xcc, 0x30, 0xc1, 0x6d,
		0x52, 0x58, 0x61, 0x82, 0x7b, 0x23, 0x37, 0x60, 0x82, 0x9b, 0xb3, 0x25, 0xd6, 0x01, 0x48, 0x2d,
		0x10, 0xa9, 0x04, 0xa4, 0x7c, 0x10, 0x3e, 0xb1, 0xb3, 0x25, 0x34, 0xd5, 0x7c, 0x2c, 0x6d, 0xd1,
		0x54, 0xf3, 0x2a, 0xa4, 0xaa, 0x87, 0x56, 0xf5, 0x10, 0xab, 0x1a, 0x6a, 0x65, 0xab, 0x8c, 0x34,
		0xd5, 0x1e, 0x1d, 0xbd, 0x68, 0xaa, 0x3d, 0xe2, 0x41, 0x68, 0xaa, 0xb9, 0x5b, 0x8f, 0xa6, 0x5a,
		0x6e, 0x4d, 0x84, 0xa6, 0x9a, 0xbf, 0xef, 0x4e, 0x53, 0xcd, 0x49, 0xea, 0x53, 0xec, 0xa6, 0x5a,
		0x5c, 0xcc, 0xd1, 0xb5, 0x3a, 0xa3, 0x6b, 0x0e, 0x53, 0x4f, 0x46, 0xd7, 0x28, 0x2f, 0x7a, 0xc2,
		0x81, 0x29, 0x2f, 0xea, 0x41, 0x1f, 0xe5, 0xc5, 0xef, 0xd9, 0x2c, 0xca, 0x8b, 0x96, 0x21, 0x54,
		0x2f, 0x94, 0x6a, 0x85, 0x54, 0xf5, 0xd0, 0xaa, 0x1e, 0x62, 0x55, 0x43, 0xad, 0x2c, 0xdf, 0xa2,
		0xbc, 0xf8, 0xe8, 0xe8, 0x45, 0x79, 0xf1, 0x31, 0xb5, 0x23, 0xca, 0x8b, 0xb9, 0x2e, 0x19, 0x51,
		0x5e, 0x74, 0x62, 0x22, 0x94, 0x17, 0xfd, 0x7d, 0x77, 0xca, 0x8b, 0x4e, 0x52, 0x9f, 0x2d, 0x28,
		0x2f, 0x16, 0xee, 0xcc, 0x7e, 0x9d, 0x33, 0xfb, 0x3e, 0x18, 0xb9, 0x0f, 0xc6, 0x5d, 0x84, 0x33,
		0xfb, 0xf5, 0x82, 0x9d, 0xd9, 0x77, 0x5b, 0x0d, 0x17, 0xa9, 0x82, 0x8b, 0x9d, 0xda, 0xaf, 0x70,
		0x6a, 0x3f, 0x47, 0xa5, 0x17, 0x4e, 0xed, 0x73, 0xa9, 0x35, 0x97, 0x5a, 0xdf, 0x09, 0x61, 0xcc,
		0x05, 0x28, 0x84, 0x36, 0xb5, 0x10, 0xa7, 0x16, 0xea, 0x54, 0x42, 0x5e, 0x3e, 0x48, 0x25, 0x97,
		0x5a, 0x43, 0xad, 0xf2, 0x4d, 0xad, 0x5c, 0x97, 0x0c, 0xcc, 0xb8, 0x95, 0xc3, 0x2a, 0x81, 0x03,
		0x72, 0xf5, 0xc4, 0xd0, 0x64, 0x5d, 0x9b, 0xaa, 0xb1, 0x89, 0x96, 0x9d, 0x10, 0x55, 0x13, 0xa3,
		0xdc, 0xcc, 0x1c, 0x7f, 0xdc, 0x88, 0x7e, 0xec, 0x37, 0x7f, 0xd0, 0xec, 0x5c, 0x99, 0x9b, 0xa6,
		0x99, 0x6d, 0x60, 0x53, 0x4a, 0xb6, 0xf4, 0x63, 0xa6, 0xf3, 0xfd, 0x5f, 0xfc, 0x0f, 0x7c, 0xe9,
		0xe5, 0x24, 0x8a, 0xaf, 0x3e, 0xbe, 0xef, 0x0f, 0x7f, 0xfc, 0x44, 0x51, 0x96, 0xde, 0x2c, 0xdf,
		0xea, 0x07, 0x8d, 0x6f, 0xb3, 0xf2, 0xce, 0xc6, 0x5c, 0xc8, 0x05, 0xe7, 0x71, 0xc7, 0x6d, 0x5c,
		0x71, 0x18, 0xe7, 0x5c, 0xc5, 0x39, 0x27, 0x71, 0xca, 0x3d, 0x74, 0xc3, 0xe5, 0xa6, 0xe5, 0x93,
		0xcc, 0x67, 0x36, 0xff, 0x9a, 0xef, 0x7a, 0xe1, 0xa6, 0xdf, 0xb2, 0x9b, 0x5a, 0xab, 0xb3, 0x02,
		0x85, 0xcb, 0x82, 0x84, 0xfb, 0x02, 0x84, 0xeb, 0x82, 0x83, 0x58, 0x81, 0x41, 0xac, 0xa0, 0x20,
		0x52, 0x40, 0xb0, 0x4d, 0xbd, 0x5d, 0xd5, 0x46, 0xcb, 0xe1, 0x87, 0x38, 0x18, 0x85, 0x1f, 0xe2,
		0x91, 0xfb, 0xf6, 0xca, 0xf2, 0xad, 0x11, 0x46, 0xf2, 0xaf, 0x1e, 0x49, 0x8b, 0xc5, 0xa4, 0xde,
		0x58, 0xf0, 0x16, 0xcb, 0xc2, 0xe7, 0xe5, 0x7a, 0x2c, 0xd9, 0x0a, 0x88, 0x23, 0xd1, 0x04, 0x31,
		0x0b, 0x42, 0x6a, 0xc1, 0x48, 0x25, 0x28, 0xb9, 0x0d, 0x4e, 0x8e, 0x83, 0x94, 0x58, 0xb0, 0x5a,
		0x06, 0xad, 0x6e, 0x57, 0x6b, 0x72, 0x69, 0xb9, 0x94, 0xec, 0x44, 0xd1, 0x2e, 0x13, 0x45, 0x86,
		0xe1, 0x4d, 0x2b, 0xcc, 0xa9, 0x87, 0x3b, 0xf5, 0xb0, 0xa7, 0x1a, 0xfe, 0x64, 0xc2, 0xa0, 0x50,
		0x38, 0x14, 0x0f, 0x8b, 0xd9, 0x02, 0x42, 0x62, 0x97, 0x0f, 0xba, 0xa5, 0x98, 0x78, 0x81, 0x62,
		0xa0, 0x54, 0x0b, 0x98, 0x9a, 0x81, 0x53, 0x3f, 0x80, 0x6a, 0x07, 0x52, 0xb3, 0x80, 0x6a, 0x16,
		0x58, 0x4d, 0x02, 0xac, 0x6c, 0xa0, 0x15, 0x0e, 0xb8, 0x6a, 0x81, 0x37, 0x5b, 0x28, 0xea, 0xc5,
		0x57, 0xf1, 0xfb, 0x5e, 0x14, 0xcc, 0x4c, 0x31, 0x18, 0xf4, 0x7b, 0x71, 0xe7, 0x8b, 0x9e, 0x33,
		0x64, 0xc7, 0x1b, 0xef, 0xff, 0x1c, 0xbf, 0x14, 0x72, 0x62, 0x4d, 0x2b, 0x70, 0x5b, 0x04, 0x70,
		0xbb, 0x40, 0x6e, 0x15, 0xd0, 0xcd, 0x03, 0xbb, 0x79, 0x80, 0x37, 0x0d, 0xf4, 0x3a, 0x01, 0x5f,
		0x29, 0xf0, 0x67, 0x3b, 0x29, 0x3e, 0xcb, 0xff, 0xa0, 0xbf, 0xf6, 0xa2, 0xf0, 0xc3, 0x30, 0xfa,
		0xa0, 0xe9, 0xb0, 0x8b, 0x7c, 0xf9, 0x40, 0x71, 0xcd, 0x46, 0x76, 0x46, 0xa7, 0x13, 0x0c, 0x07,
		0xfd, 0xde, 0xef, 0xc3, 0xfe, 0x38, 0x8d, 0x93, 0xab, 0x39, 0xf2, 0x64, 0x7f, 0x3c, 0xfb, 0x9f,
		0x41, 0x37, 0xfa, 0x10, 0x27, 0x71, 0x1a, 0xf7, 0x93, 0xd1, 0xc3, 0x7f, 0x95, 0xfd, 0xcd, 0xf4,
		0x64, 0xcd, 0x93, 0x62, 0x58, 0xbd, 0xc6, 0x78, 0xfa, 0x30, 0xea, 0x44, 0xf1, 0xa7, 0x48, 0x3f,
		0xed, 0x58, 0x2c, 0xac, 0xe4, 0xd5, 0x4a, 0x57, 0xd5, 0x93, 0xdf, 0x90, 0xdf, 0x90, 0xdf, 0x90,
		0xdf, 0x90, 0xdf, 0xdc, 0xe3, 0xaf, 0xf2, 0x57, 0xed, 0x3f, 0x98, 0xdf, 0xec, 0x92, 0x12, 0x3c,
		0x7a, 0xcf, 0x46, 0x51, 0xd2, 0xd5, 0xcf, 0x07, 0xa6, 0xab, 0x92, 0x0c, 0x90, 0x0c, 0x90, 0x0c,
		0x90, 0x0c, 0x90, 0x0c, 0x90, 0x0c, 0x90, 0x0c, 0xf8, 0x92, 0x0c, 0x04, 0xd7, 0x9a, 0x1a, 0x76,
		0xb7, 0x13, 0x82, 0xe9, 0xca, 0x80, 0x33, 0xe0, 0x0c, 0x38, 0x03, 0xce, 0x80, 0xb3, 0x9a, 0xbf,
		0x8e, 0xe3, 0x24, 0xfd, 0xcd, 0x00, 0x9a, 0xf7, 0x14, 0x97, 0xd4, 0x11, 0x21, 0xbe, 0xfb, 0xd2,
		0x0d, 0x47, 0x25, 0x6d, 0x91, 0x62, 0x63, 0x54, 0x5d, 0x5b, 0x5e, 0x59, 0xc4, 0x78, 0x6d, 0x7d,
		0x03, 0xa1, 0x5a, 0xa3, 0x68, 0xb5, 0x6a, 0x72, 0xe1, 0xe7, 0xad, 0x37, 0xb9, 0xca, 0xde, 0xde,
		0x16, 0x1b, 0xdd, 0x93, 0x62, 0xae, 0x76, 0x59, 0x14, 0xea, 0x98, 0xeb, 0x33, 0x7a, 0xc2, 0x6a,
		0xcc, 0xeb, 0x24, 0x58, 0x43, 0x5b, 0x24, 0x13, 0xb3, 0xc8, 0x7e, 0x7a, 0x9a, 0xcd, 0xda, 0x66,
		0x3f, 0x3d, 0xcd, 0x46, 0x4d, 0x9e, 0xaa, 0x1c, 0xa8, 0x2e, 0x69, 0x68, 0x96, 0x9c, 0x2e, 0x9e,
		0x3c, 0xfb, 0xa9, 0x7d, 0xf8, 0x21, 0x6e, 0x4e, 0x1e, 0x7c, 0xf1, 0x43, 0xfb, 0xb0, 0xdb, 0x9d,
		0x29, 0x35, 0x49, 0xdc, 0x16, 0xa7, 0xe7, 0x1d, 0x82, 0x9e, 0x21, 0x74, 0xbb, 0xdc, 0xc3, 0xf5,
		0x19, 0x21, 0xb9, 0xf0, 0xfb, 0xb0, 0x5c, 0xed, 0x3c, 0x7f, 0x85, 0xf3, 0xfc, 0xf9, 0x29, 0xba,
		0x70, 0x9e, 0x9f, 0xf3, 0xfc, 0xdf, 0xdc, 0x31, 0xce, 0xf3, 0x73, 0x9e, 0x3f, 0x9f, 0x01, 0xdc,
		0x2e, 0x90, 0x5b, 0x05, 0x74, 0xf3, 0xc0, 0x6e, 0x1e, 0xe0, 0x4d, 0x03, 0xbd, 0x2e, 0x9d, 0xe6,
		0x3c, 0xbf, 0x60, 0xbe, 0xcc, 0x79, 0x7e, 0x1f, 0x8b, 0x2e, 0x9c, 0xe7, 0x77, 0x97, 0xd6, 0x71,
		0x84, 0x8f, 0xfc, 0x86, 0xfc, 0x86, 0xfc, 0x86, 0xfc, 0x86, 0x23, 0x7c, 0xa4, 0x04, 0x5f, 0xdb,
		0x33, 0xce, 0xf3, 0x93, 0x0c, 0x90, 0x0c, 0x90, 0x0c, 0x90, 0x0c, 0x90, 0x0c, 0x90, 0x0c, 0x90,
		0x0c, 0x70, 0x9e, 0x1f, 0x70, 0x06, 0x9c, 0x01, 0x67, 0xc0, 0x79, 0x6b, 0xc0, 0x99, 0xf3, 0xfc,
		0x52, 0x2f, 0xce, 0xf3, 0xab, 0x2e, 0xcf, 0x79, 0x7e, 0xce, 0xf3, 0x1b, 0x99, 0x1c, 0xe7, 0xf9,
		0x0b, 0xb8, 0x1a, 0xe7, 0xf9, 0x3d, 0x08, 0x39, 0x9c, 0xe7, 0x97, 0xb8, 0x4b, 0xf9, 0xe1, 0xa7,
		0xf7, 0xe9, 0x38, 0xbf, 0xc3, 0x8b, 0x97, 0xf5, 0x7d, 0x23, 0x5f, 0x57, 0x0a, 0x28, 0x79, 0x99,
		0x97, 0xde, 0x55, 0x16, 0x9d, 0xbb, 0xf0, 0xc7, 0x9f, 0x64, 0x3c, 0xc9, 0xbd, 0x9d, 0x0b, 0xd8,
		0x78, 0x76, 0x87, 0x58, 0x30, 0xff, 0x2a, 0xa4, 0x2f, 0xfd, 0x59, 0x59, 0x4e, 0xf6, 0xe2, 0x9f,
		0x1d, 0x2e, 0xfe, 0xf9, 0xf6, 0x17, 0xc2, 0xc5, 0x3f, 0xb9, 0x29, 0x32, 0x72, 0xf1, 0x8f, 0x5d,
		0x91, 0x50, 0xf1, 0x78, 0xb2, 0xc6, 0x71, 0xe4, 0xec, 0xf8, 0xf1, 0xaf, 0xbf, 0xce, 0x47, 0x62,
		0x9f, 0xae, 0x46, 0xe6, 0x6d, 0x46, 0xc4, 0xc1, 0xa0, 0xf7, 0x45, 0x7a, 0x10, 0x69, 0x09, 0x88,
		0xb7, 0x57, 0xe3, 0x22, 0x3c, 0x1f, 0xf0, 0x70, 0x38, 0xe8, 0xf7, 0x00, 0xc4, 0x1c, 0x02, 0xe2,
		0xf4, 0x8b, 0x03, 0x11, 0x4b, 0x5c, 0x85, 0xe7, 0x69, 0xa8, 0x54, 0x0b, 0x99, 0x9a, 0xa1, 0xd3,
		0x20, 0x84, 0x6a, 0x87, 0x52, 0xb3, 0x90, 0x6a, 0x16, 0x5a, 0x6d, 0x42, 0xac, 0x6c, 0xa8, 0x15,
		0x0e, 0xb9, 0x6a, 0xa1, 0x37, 0x5b, 0xa8, 0x3b, 0x3b, 0xc1, 0x1d, 0x44, 0x9f, 0x07, 0xfd, 0x61,
		0x6a, 0x36, 0x3b, 0x7f, 0xff, 0xc7, 0xd0, 0x3f, 0xc5, 0x7e, 0x5e, 0xfb, 0xef, 0xda, 0x51, 0xab,
		0x7d, 0x7e, 0x76, 0xd1, 0xaa, 0x71, 0x5e, 0x2e, 0x77, 0xf8, 0x61, 0x88, 0x23, 0x56, 0x78, 0x62,
		0x8e, 0x2b, 0xe6, 0xf8, 0x62, 0x8b, 0x33, 0x3a, 0x78, 0xa3, 0x84, 0x3b, 0x7a, 0xc5, 0xb0, 0x6f,
		0x22, 0xc1, 0x7c, 0x32, 0x3d, 0x9d, 0x7c, 0x10, 0x83, 0xa3, 0xed, 0x55, 0xc5, 0x35, 0x6b, 0xc9,
		0xf8, 0x7a, 0xb2, 0xd9, 0x37, 0x1c, 0xa7, 0xff, 0xee, 0xbc, 0x25, 0xbe, 0xf6, 0x22, 0x6f, 0x59,
		0xfd, 0x18, 0xe4, 0x2d, 0xe4, 0x2d, 0xe4, 0x2d, 0xe4, 0x2d, 0xe4, 0x2d, 0xe4, 0x2d, 0xe4, 0x2d,
		0xe4, 0x2d, 0xb7, 0xf6, 0xcc, 0xb8, 0xce, 0x62, 0x52, 0x5f, 0x21, 0x51, 0x20, 0x51, 0x20, 0x51,
		0x20, 0x51, 0x20, 0x51, 0x40, 0x9c, 0x30, 0x77, 0xe2, 0x84, 0x4a, 0xf6, 0x78, 0x1c, 0x8f, 0xd2,
		0xc3, 0x34, 0x1d, 0xea, 0xda, 0xe4, 0x49, 0x9c, 0xd4, 0x7a, 0xd1, 0x24, 0xa4, 0x8c, 0x74, 0x07,
		0xbd, 0xca, 0x27, 0xe1, 0xe7, 0x5b, 0x2b, 0xef, 0xfe, 0x56, 0xad, 0xee, 0x1f, 0x54, 0xab, 0x3b,
		0x07, 0xcf, 0x0e, 0x76, 0x9e, 0xef, 0xed, 0xed, 0xee, 0xef, 0x6a, 0x4e, 0xb0, 0x9e, 0x0d, 0xbb,
		0xd1, 0x30, 0xea, 0xbe, 0xf8, 0xa2, 0x0f, 0x6a, 0xd9, 0xa0, 0xf0, 0x28, 0x1a, 0x6a, 0xe3, 0x99,
		0x11, 0x90, 0xdf, 0x05, 0xf3, 0xfe, 0x6c, 0xf7, 0x83, 0xf7, 0x5f, 0xca, 0x06, 0x13, 0x96, 0xd6,
		0xa0, 0xbe, 0x06, 0xec, 0x53, 0x4b, 0x28, 0xe8, 0xd4, 0x1f, 0x4c, 0xf1, 0xf1, 0x36, 0x61, 0x5c,
		0xd9, 0x36, 0xa9, 0x68, 0xc3, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x22, 0x4c, 0x11, 0xa6, 0x08,
		0x53, 0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x62, 0x8e, 0x99, 0x22, 0xfa, 0x30,
		0xdf, 0xb1, 0x9e, 0x4f, 0x0a, 0x16, 0xb7, 0x86, 0x2a, 0xb7, 0xed, 0xca, 0xd7, 0xc9, 0xa3, 0x37,
		0xa6, 0x4f, 0xce, 0xad, 0xaf, 0x5f, 0xf9, 0xa6, 0xb8, 0xf5, 0x75, 0xd3, 0xba, 0x4b, 0x85, 0xd1,
		0xb5, 0x1c, 0xa5, 0x65, 0x8c, 0xae, 0x31, 0xba, 0xf6, 0xed, 0x2d, 0x63, 0x74, 0x8d, 0x23, 0xe0,
		0xd2, 0xb8, 0x41, 0xbd, 0xbe, 0x48, 0x34, 0x9f, 0x7a, 0x3d, 0xf5, 0x7a, 0x77, 0x5b, 0xc9, 0x11,
		0x70, 0x8e, 0x80, 0xfb, 0x6c, 0xa4, 0x8c, 0xae, 0x91, 0xb7, 0x90, 0xb7, 0x90, 0xb7, 0x90, 0xb7,
		0x90, 0xb7, 0x90, 0xb7, 0x90, 0xb7, 0xe4, 0x26, 0x6f, 0x61, 0x74, 0x8d, 0x44, 0x81, 0x44, 0x81,
		0x44, 0x81, 0x44, 0x61, 0x5b, 0x13, 0x05, 0x0e, 0x24, 0x72, 0x20, 0x71, 0x7d, 0xbb, 0x38, 0x90,
		0xc8, 0x81, 0x44, 0x0e, 0x24, 0x72, 0x20, 0x91, 0x03, 0x89, 0x30, 0xc5, 0x99, 0x4d, 0x30, 0xba,
		0x06, 0x53, 0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x22, 0x4c, 0x11, 0xa6, 0x08,
		0x53, 0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a, 0xb9, 0x62, 0x8a, 0x8c, 0xae, 0x7d, 0xc7, 0x7a, 0xbe,
		0x8e, 0xae, 0x6d, 0xd7, 0xed, 0xe6, 0xb7, 0x26, 0xd7, 0xb8, 0xe0, 0x5c, 0xcb, 0xe7, 0xb6, 0xf2,
		0x82, 0x73, 0xf9, 0x3b, 0x37, 0x7d, 0xf4, 0xaa, 0x6d, 0xbe, 0xd4, 0x55, 0xf8, 0xb6, 0x42, 0x9d,
		0x5b, 0x0a, 0xb9, 0xc8, 0xf5, 0xfb, 0xea, 0x8e, 0x5c, 0x6c, 0x9e, 0x0f, 0xc6, 0xc1, 0xc5, 0xe6,
		0x0f, 0xee, 0x8c, 0xf8, 0x35, 0xae, 0xab, 0xd7, 0x7e, 0xab, 0x4d, 0xc4, 0xaf, 0x2e, 0xab, 0x33,
		0x19, 0xbf, 0xc3, 0xa5, 0xae, 0x1e, 0x87, 0x53, 0xab, 0xa2, 0x0f, 0x83, 0xf1, 0xa2, 0xe1, 0xb6,
		0x18, 0x05, 0x09, 0xb5, 0x66, 0xcc, 0xb2, 0x0f, 0xde, 0x8d, 0x92, 0x34, 0x4e, 0xbf, 0xe8, 0x34,
		0x62, 0xb2, 0xcc, 0x52, 0xa1, 0xa8, 0x5d, 0xae, 0xcf, 0x1f, 0xed, 0x45, 0x38, 0x8a, 0xf4, 0x0f,
		0x18, 0x1c, 0xbe, 0xaa, 0xb7, 0x9b, 0x93, 0xff, 0xd7, 0xfa, 0xab, 0xa1, 0x36, 0xb3, 0xf6, 0x36,
		0xec, 0x8d, 0xa3, 0x51, 0xf9, 0xf7, 0xd2, 0x3b, 0xb5, 0x4a, 0xa6, 0x51, 0x9b, 0xa0, 0x79, 0xde,
		0xaa, 0xb5, 0x1b, 0x67, 0xc7, 0xf5, 0xa3, 0xbf, 0xda, 0xf5, 0xc6, 0xdb, 0x7d, 0xc5, 0xf6, 0xef,
		0x2f, 0x45, 0xdf, 0xdb, 0xe3, 0x67, 0x6f, 0x1b, 0xa7, 0x93, 0x5d, 0xad, 0xb6, 0x2f, 0x4e, 0xeb,
		0x47, 0x87, 0xcd, 0x16, 0xbb, 0xeb, 0x70, 0x77, 0xeb, 0xa7, 0xff, 0x6a, 0xb6, 0x0e, 0x5b, 0xb5,
		0x76, 0xb3, 0xf1, 0x8a, 0x8d, 0x15, 0x31, 0xdb, 0x93, 0x8b, 0xe3, 0x16, 0x86, 0xeb, 0x78, 0x7f,
		0xdf, 0x36, 0x4e, 0xdf, 0x56, 0xdb, 0xaf, 0x8e, 0xcf, 0xfe, 0x68, 0x36, 0x6a, 0x47, 0xec, 0xac,
		0x18, 0x98, 0x55, 0xd9, 0x5b, 0x87, 0x51, 0xa1, 0x32, 0x89, 0x0a, 0x6f, 0x1b, 0xc7, 0x4d, 0x76,
		0xd5, 0xf5, 0xae, 0xd6, 0xde, 0x36, 0x4e, 0xd9, 0x55, 0x81, 0xd4, 0x80, 0x4d, 0x75, 0xb7, 0xa9,
		0xd3, 0x84, 0xe0, 0xf8, 0xf0, 0x45, 0xed, 0xb8, 0xf6, 0x92, 0x7c, 0x56, 0x32, 0x9f, 0x25, 0x1a,
		0xc8, 0xe4, 0xb3, 0xfb, 0xe4, 0xb3, 0x62, 0x81, 0x81, 0x74, 0x56, 0x64, 0x63, 0xf7, 0x89, 0xb8,
		0x2a, 0x81, 0x81, 0xdd, 0x95, 0x09, 0x0b, 0xec, 0xab, 0x4c, 0x54, 0xd0, 0xdf, 0x57, 0x95, 0x95,
		0x2e, 0xf3, 0xde, 0xd7, 0xca, 0xa5, 0xba, 0x7e, 0x94, 0x84, 0xef, 0x7b, 0x51, 0x57, 0xef, 0x34,
		0xc1, 0x62, 0x41, 0x69, 0x75, 0xec, 0xa5, 0xf0, 0xe1, 0x87, 0xb0, 0x37, 0xe2, 0xdc, 0xc2, 0x77,
		0x2e, 0xc4, 0xb9, 0x05, 0xa7, 0xd6, 0xc1, 0xb9, 0x05, 0xce, 0x2d, 0x7c, 0x63, 0xc7, 0xf4, 0xcf,
		0x2d, 0xbc, 0xef, 0xf7, 0x7b, 0x51, 0x98, 0x68, 0x9e, 0x59, 0xd8, 0x65, 0x4e, 0x40, 0xde, 0xa4,
		0xb6, 0x71, 0x4e, 0x40, 0xfc, 0xe6, 0x28, 0x2f, 0x26, 0x04, 0x24, 0x6f, 0x89, 0xca, 0xc7, 0x70,
		0xc0, 0xd5, 0x30, 0xec, 0x44, 0x1f, 0xc6, 0xbd, 0x60, 0x18, 0x8d, 0xd2, 0x70, 0x98, 0xca, 0x8f,
		0x09, 0xac, 0xad, 0xc8, 0xc0, 0x80, 0x55, 0xc6, 0xc8, 0xc0, 0x40, 0xfe, 0x32, 0x42, 0x06, 0x06,
		0x1e, 0xe6, 0xa8, 0xd2, 0x03, 0x03, 0xc2, 0x93, 0x54, 0x6b, 0x6e, 0xa9, 0x72, 0x7d, 0xa3, 0xfa,
		0xe5, 0x79, 0x50, 0x6d, 0xa8, 0x36, 0x54, 0xbb, 0x48, 0x54, 0x5b, 0xed, 0xea, 0x3c, 0xad, 0xea,
		0xea, 0x9a, 0x7f, 0xeb, 0x54, 0x59, 0x97, 0x1b, 0xaa, 0x5b, 0x6d, 0xbd, 0x0b, 0x05, 0x88, 0x01,
		0xe6, 0x19, 0x22, 0xac, 0xa0, 0xc2, 0x1c, 0x32, 0xcc, 0xa1, 0xc3, 0x14, 0x42, 0x74, 0xa0, 0x44,
		0x09, 0x52, 0xb2, 0x9d, 0xb4, 0x93, 0x02, 0xd4, 0xab, 0xe6, 0xae, 0x65, 0xe2, 0xbb, 0x28, 0x31,
		0x79, 0x90, 0xd5, 0x6c, 0xb1, 0x12, 0xd3, 0xdd, 0x1a, 0xdd, 0x53, 0x15, 0x26, 0x5a, 0xf2, 0xa5,
		0x2c, 0xfc, 0x7a, 0xfe, 0xf8, 0xe7, 0xb3, 0xa7, 0x17, 0x2d, 0x13, 0xcb, 0xfb, 0xca, 0x8d, 0x68,
		0x11, 0x3f, 0x4c, 0x15, 0xa5, 0x13, 0x34, 0x44, 0xc1, 0xd4, 0xeb, 0x21, 0x15, 0xea, 0x21, 0xd4,
		0x43, 0xa8, 0x87, 0x50, 0x0f, 0xf9, 0xfe, 0x85, 0xc2, 0xee, 0xa7, 0x68, 0x98, 0xc6, 0x23, 0x8b,
		0x92, 0xc8, 0xad, 0xb5, 0xa9, 0x4e, 0x50, 0x9d, 0xa0, 0x3a, 0x41, 0x75, 0x82, 0xea, 0x04, 0xd5,
		0x89, 0x1c, 0x55, 0x27, 0x7e, 0xa1, 0x61, 0xe1, 0x2c, 0xe3, 0xa1, 0x61, 0x41, 0x4a, 0x40, 0x4a,
		0x40, 0x4a, 0x40, 0x4a, 0x40, 0x4a, 0x40, 0x4a, 0xf0, 0xb5, 0x3d, 0x1b, 0x46, 0x9d, 0x28, 0xfe,
		0x64, 0x91, 0x13, 0x64, 0x2b, 0x03, 0xce, 0x80, 0x33, 0xe0, 0x0c, 0x38, 0x03, 0xce, 0x80, 0x73,
		0x8e, 0xc0, 0x99, 0xd3, 0x04, 0xdf, 0xb1, 0x9e, 0xcf, 0xa7, 0x09, 0xb6, 0xea, 0x6e, 0xa7, 0xbb,
		0x87, 0x09, 0xb8, 0xdf, 0x49, 0xcb, 0xf7, 0xb6, 0x71, 0x6e, 0x53, 0x69, 0xba, 0xce, 0x57, 0xef,
		0xda, 0xe6, 0x51, 0xce, 0x78, 0xf0, 0xa9, 0x1a, 0xf4, 0xc2, 0xf7, 0x51, 0x2f, 0xea, 0x06, 0xe3,
		0x24, 0xee, 0x84, 0x23, 0x85, 0x71, 0xce, 0x7b, 0x57, 0x65, 0xa4, 0xd3, 0x8a, 0x30, 0x32, 0xd2,
		0x99, 0x3f, 0xc2, 0xc7, 0x48, 0xe7, 0x83, 0x3b, 0x23, 0x3e, 0xd2, 0x39, 0xb3, 0xa8, 0xa0, 0x17,
		0x5f, 0xc7, 0xa9, 0xde, 0x39, 0xc6, 0x95, 0x55, 0x19, 0xef, 0xf4, 0xb5, 0xea, 0xc6, 0x71, 0xc6,
		0xe2, 0x55, 0xd5, 0x38, 0xce, 0xe8, 0x5d, 0x10, 0xce, 0x16, 0x52, 0x9a, 0xaf, 0x5f, 0x73, 0x6f,
		0xb5, 0xe9, 0x06, 0xc5, 0x80, 0xac, 0x1e, 0x98, 0x2d, 0x02, 0xb4, 0x5d, 0xa0, 0xb6, 0x0a, 0xd8,
		0xe6, 0x81, 0xdb, 0x3c, 0x80, 0x9b, 0x06, 0x72, 0x9d, 0x80, 0xae, 0x14, 0xd8, 0xd5, 0x03, 0x7c,
		0xb6, 0xe0, 0x75, 0xf8, 0x39, 0x98, 0x59, 0xed, 0xf4, 0x66, 0x38, 0x23, 0xf5, 0xdf, 0x95, 0x4f,
		0xa1, 0x6c, 0xbc, 0xba, 0xbd, 0x71, 0x33, 0x30, 0xb0, 0x04, 0x05, 0x7b, 0x70, 0xb0, 0x06, 0x09,
		0x6f, 0xc0, 0xc2, 0x1b, 0xd0, 0xf0, 0x02, 0x3c, 0x74, 0x41, 0x44, 0x19, 0x4c, 0xb2, 0x1d, 0x56,
		0xef, 0xb5, 0xaf, 0xf9, 0xfb, 0x38, 0x4e, 0xd2, 0x67, 0x15, 0x0b, 0x7f, 0x9f, 0x47, 0xf7, 0x03,
		0x83, 0xa5, 0xcf, 0xc3, 0xe4, 0x2a, 0x52, 0xbd, 0x6d, 0xf5, 0xf6, 0xcb, 0x26, 0xbe, 0x4d, 0x1f,
		0xfc, 0x24, 0x4e, 0xcc, 0x02, 0xac, 0x31, 0xac, 0xaf, 0x7d, 0x8c, 0xe9, 0x9d, 0xbb, 0x1e, 0x7c,
		0x8e, 0x57, 0xc3, 0xb0, 0x93, 0xc6, 0xfd, 0xe4, 0x65, 0x7c, 0x15, 0xa7, 0x93, 0x4c, 0x6f, 0xc7,
		0xec, 0xf3, 0xdc, 0xfc, 0x62, 0x68, 0x9a, 0xe1, 0x67, 0x4c, 0xf3, 0x8e, 0x69, 0x56, 0x2b, 0xcf,
		0xab, 0xcf, 0xf7, 0x0f, 0x2a, 0xcf, 0xf7, 0xb0, 0x51, 0x9b, 0x84, 0xc0, 0x6e, 0xd5, 0xcb, 0x27,
		0xc5, 0x7c, 0x3e, 0xc5, 0x18, 0x33, 0xc9, 0xe3, 0x3f, 0x45, 0x49, 0x1a, 0xa4, 0x51, 0x38, 0xec,
		0xf6, 0xff, 0x4e, 0xec, 0x68, 0xf4, 0xda, 0x27, 0x51, 0x4e, 0x34, 0x8d, 0x66, 0xcf, 0xa0, 0xf2,
		0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0xaf, 0xe0, 0xef, 0xfa, 0xc7, 0xe7, 0xef, 0x86, 0x77,
		0xa5, 0x63, 0xf4, 0xc5, 0x4e, 0x5a, 0xe6, 0x87, 0x52, 0x83, 0x34, 0xbe, 0x8e, 0x86, 0x76, 0x19,
		0xcb, 0xea, 0xc7, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x28, 0x4c, 0xba,
		0xd0, 0x8d, 0x3a, 0xf1, 0x75, 0xd8, 0xdb, 0xaf, 0x5a, 0x26, 0x0c, 0x15, 0x83, 0xb5, 0xd7, 0x8a,
		0x59, 0x15, 0x5a, 0x10, 0x7a, 0x0f, 0xee, 0x53, 0x0b, 0xa2, 0x42, 0x0b, 0xa2, 0x44, 0x0b, 0x62,
		0x69, 0x9a, 0x1e, 0xb5, 0x20, 0x9e, 0x61, 0x9a, 0x25, 0x3a, 0x0f, 0x74, 0x1e, 0x72, 0x4a, 0xe2,
		0xff, 0x0e, 0x87, 0x49, 0x9c, 0x5c, 0x05, 0xe9, 0xc7, 0x61, 0x34, 0xfa, 0xd8, 0xef, 0x75, 0x83,
		0x41, 0x27, 0xb5, 0x23, 0xf3, 0xf7, 0x7f, 0x1c, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87,
		0xd4, 0x17, 0x86, 0xd4, 0x0f, 0xa2, 0x61, 0x27, 0x4a, 0xd2, 0xf0, 0x2a, 0x32, 0x64, 0xf5, 0x7b,
		0xf0, 0xe9, 0xed, 0xe4, 0xd3, 0x1c, 0xe9, 0x83, 0x4f, 0x7b, 0xca, 0xa7, 0x7d, 0x31, 0xcd, 0xdd,
		0x1d, 0x8c, 0x13, 0x46, 0x5d, 0x14, 0x46, 0x5d, 0xa8, 0x09, 0x3f, 0x65, 0xf5, 0xb9, 0x6c, 0x5d,
		0x8f, 0x94, 0xb1, 0xee, 0x13, 0x2a, 0x7a, 0x7a, 0x5b, 0x88, 0xe3, 0xa9, 0xea, 0x18, 0x78, 0xc9,
		0x17, 0x05, 0xad, 0xfa, 0xe0, 0x53, 0xf5, 0x78, 0xb6, 0x2d, 0x17, 0xb3, 0x5d, 0x69, 0xcf, 0xd8,
		0xfd, 0xf1, 0x64, 0x53, 0x54, 0xee, 0xbe, 0xd3, 0xf3, 0xb9, 0x1b, 0x15, 0xd1, 0x41, 0x8d, 0x3b,
		0xf1, 0xd6, 0xe8, 0x91, 0x96, 0xa8, 0x62, 0xc9, 0x52, 0xc3, 0xa0, 0x82, 0x86, 0x41, 0x71, 0xea,
		0x59, 0x68, 0x18, 0xa0, 0x61, 0xe0, 0x6c, 0x27, 0xd1, 0x30, 0x40, 0xc3, 0xa0, 0x78, 0xa0, 0x60,
		0x0f, 0x0e, 0xd6, 0x20, 0xe1, 0x0d, 0x58, 0x78, 0x03, 0x1a, 0x5e, 0x80, 0x87, 0x4d, 0xc1, 0x01,
		0x0d, 0x03, 0xf5, 0xe8, 0x8e, 0x86, 0x81, 0xe2, 0x83, 0xd3, 0xf0, 0x58, 0x7e, 0x0c, 0x1a, 0x1e,
		0xd6, 0xe1, 0x6f, 0xd5, 0x34, 0x69, 0x78, 0xac, 0x99, 0x26, 0x1a, 0x06, 0xd6, 0x09, 0x81, 0xdd,
		0xaa, 0x9c, 0x24, 0xdc, 0xdc, 0x6c, 0xd1, 0x30, 0xc8, 0xaa, 0x17, 0x68, 0x18, 0x40, 0xe5, 0xa1,
		0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x61, 0xa9, 0x3c, 0x1a, 0x06, 0x85, 0x48, 0x5a, 0xd0, 0x30, 0x20,
		0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x90, 0xf4, 0x77, 0x34, 0x0c, 0xd0, 0x30,
		0x30, 0x08, 0x2d, 0x68, 0x18, 0x2c, 0x3f, 0x06, 0x2d, 0x08, 0xeb, 0x38, 0xbc, 0x6a, 0x9a, 0x68,
		0x18, 0x60, 0x9a, 0xbe, 0x24, 0x24, 0x76, 0xab, 0xd2, 0x79, 0xd8, 0xdc, 0x6c, 0xd1, 0x30, 0x80,
		0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa6, 0xbf, 0xa3, 0x61, 0x00, 0x9f, 0xb6,
		0x23, 0x2d, 0x1c, 0xe9, 0x83, 0x4f, 0x7b, 0xca, 0xa7, 0xd1, 0x30, 0x80, 0x51, 0xc3, 0xa8, 0x73,
		0xb9, 0x12, 0x1a, 0x06, 0x1e, 0x69, 0x18, 0x68, 0x4e, 0x81, 0x97, 0x72, 0x22, 0x61, 0xd0, 0x9c,
		0xee, 0x49, 0x51, 0x14, 0x0c, 0x9e, 0xe4, 0xd8, 0x97, 0xb5, 0x7d, 0x38, 0x57, 0xbe, 0x5b, 0x56,
		0xd1, 0xa6, 0xf0, 0xdd, 0x5b, 0x65, 0xfd, 0x54, 0xce, 0x7b, 0x64, 0xde, 0x59, 0xc8, 0x1f, 0xb5,
		0xfc, 0xd0, 0x77, 0xff, 0x13, 0x74, 0x39, 0x4f, 0x5d, 0x4d, 0xc6, 0xbd, 0xdc, 0x1b, 0xbf, 0x80,
		0xe1, 0x97, 0xa7, 0x16, 0xb0, 0xf8, 0xe6, 0xa5, 0xcc, 0x3e, 0x2b, 0xf5, 0xad, 0xac, 0x26, 0xe4,
		0xc6, 0xb2, 0x32, 0x3c, 0xe2, 0xad, 0x19, 0x8d, 0x16, 0x8c, 0x5e, 0xab, 0x45, 0xab, 0xa5, 0xa2,
		0xde, 0x3a, 0x51, 0x6f, 0x91, 0xa8, 0xb6, 0x42, 0xf2, 0x05, 0xdc, 0xd2, 0x32, 0x37, 0xe5, 0xce,
		0xc2, 0xe7, 0x85, 0x8d, 0x78, 0xe1, 0x96, 0x2a, 0xa2, 0x7b, 0x4a, 0x7a, 0x65, 0x6a, 0xbd, 0x6c,
		0xcd, 0xde, 0xb5, 0x7e, 0xaf, 0x5a, 0xbb, 0x37, 0x6d, 0xd6, 0x8b, 0x36, 0xeb, 0x3d, 0x9b, 0xf4,
		0x9a, 0xf3, 0x5d, 0xb9, 0xd0, 0xd2, 0x17, 0x2b, 0x8f, 0xa2, 0xa4, 0x1b, 0x74, 0x67, 0xf3, 0xc0,
		0xc1, 0xb0, 0x3f, 0x36, 0xd1, 0x92, 0x5c, 0xff, 0x0c, 0x5a, 0x32, 0x6e, 0x36, 0x83, 0xd0, 0xca,
		0x6d, 0x28, 0xf5, 0x43, 0x4f, 0x08, 0x5a, 0x16, 0x1a, 0x48, 0xcc, 0x01, 0xc5, 0x14, 0x58, 0x74,
		0x00, 0x46, 0x09, 0x68, 0xb2, 0x9d, 0x54, 0x3f, 0xac, 0x64, 0x38, 0xa8, 0xac, 0x3c, 0xa0, 0x4c,
		0x97, 0xe6, 0x1b, 0x4e, 0xbc, 0xe5, 0x5d, 0x9a, 0x45, 0x77, 0x46, 0x4d, 0x10, 0xde, 0x9b, 0x62,
		0xf1, 0xa2, 0x21, 0xa3, 0xa1, 0xfa, 0x2e, 0xd8, 0x8b, 0x11, 0x2c, 0xf2, 0xad, 0x74, 0xec, 0xd4,
		0xaa, 0x24, 0x8a, 0x7d, 0x42, 0x6a, 0x25, 0xd4, 0x4a, 0xa8, 0x95, 0x50, 0x2b, 0xc9, 0x43, 0xad,
		0x44, 0xa9, 0x58, 0xbd, 0xe6, 0xde, 0xaa, 0x37, 0xc5, 0x98, 0x5d, 0xb6, 0x41, 0x6d, 0x82, 0xda,
		0x04, 0xb5, 0x09, 0x6a, 0x13, 0x76, 0x01, 0x3e, 0x5b, 0x90, 0xcb, 0x36, 0x98, 0xce, 0x2d, 0x15,
		0x1f, 0x1c, 0xac, 0x41, 0xc2, 0x1b, 0xb0, 0xf0, 0x06, 0x34, 0xbc, 0x00, 0x0f, 0x5d, 0x10, 0x51,
		0x06, 0x93, 0x6c, 0x87, 0xb9, 0x6c, 0x83, 0xcb, 0x36, 0x34, 0x1f, 0x9c, 0xc9, 0xdc, 0xe5, 0xc7,
		0x60, 0x32, 0xd7, 0x3a, 0xfc, 0xad, 0x9a, 0x26, 0x93, 0xb9, 0x6b, 0xa6, 0xc9, 0x65, 0x1b, 0xd6,
		0x09, 0x81, 0xdd, 0xaa, 0x48, 0x5e, 0x6d, 0x6e, 0xb6, 0x5c, 0xb6, 0x91, 0x55, 0x2f, 0xb8, 0x6c,
		0x03, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x0b, 0x4b, 0xe5, 0xb9, 0x6c, 0xa3, 0x10, 0x49,
		0x0b, 0x97, 0x6d, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x48, 0xfa, 0x3b,
		0x97, 0x6d, 0x70, 0xd9, 0x86, 0x41, 0x68, 0xe1, 0xb2, 0x8d, 0xe5, 0xc7, 0xa0, 0x05, 0x61, 0x1d,
		0x87, 0x57, 0x4d, 0x93, 0xcb, 0x36, 0x30, 0x4d, 0x5f, 0x12, 0x12, 0xbb, 0x55, 0xe9, 0x3c, 0x6c,
		0x6e, 0xb6, 0x5c, 0xb6, 0x01, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x4d, 0x7f,
		0xe7, 0xb2, 0x0d, 0xf8, 0xb4, 0x1d, 0x69, 0xe1, 0x48, 0x1f, 0x7c, 0xda, 0x53, 0x3e, 0xcd, 0x65,
		0x1b, 0x30, 0x6a, 0x18, 0x75, 0x2e, 0x57, 0xe2, 0xb2, 0x0d, 0x1b, 0x29, 0x98, 0x95, 0x4b, 0x36,
		0x54, 0xc7, 0xbf, 0x4b, 0x3e, 0xea, 0xc3, 0xdc, 0xbe, 0x5e, 0x43, 0x43, 0x2b, 0x46, 0xcf, 0xc9,
		0x6e, 0x54, 0xd4, 0x7e, 0x42, 0x13, 0x55, 0x47, 0xc5, 0xbb, 0x61, 0xcc, 0x44, 0x0b, 0x2a, 0x88,
		0x16, 0x14, 0xa7, 0x80, 0x85, 0x68, 0x01, 0xa2, 0x05, 0xce, 0x76, 0x12, 0xd1, 0x02, 0x44, 0x0b,
		0x8a, 0x07, 0x0a, 0xf6, 0xe0, 0x60, 0x0d, 0x12, 0xde, 0x80, 0x85, 0x37, 0xa0, 0xe1, 0x05, 0x78,
		0xd8, 0x54, 0x18, 0x10, 0x2d, 0x50, 0x8f, 0xee, 0x88, 0x16, 0x28, 0x3e, 0x38, 0x1d, 0x8e, 0xe5,
		0xc7, 0xa0, 0xc3, 0x61, 0x1d, 0xfe, 0x56, 0x4d, 0x93, 0x0e, 0xc7, 0x9a, 0x69, 0x22, 0x5a, 0x60,
		0x9d, 0x10, 0xd8, 0xad, 0xca, 0xd1, 0xc1, 0xcd, 0xcd, 0x16, 0xd1, 0x82, 0xac, 0x7a, 0x81, 0x68,
		0x01, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x17, 0x96, 0xca, 0x23, 0x5a, 0x50, 0x88, 0xa4,
		0x05, 0xd1, 0x02, 0xd2, 0x05, 0xd2, 0x05, 0xd2, 0x05, 0xd2, 0x05, 0xd2, 0x05, 0x49, 0x7f, 0x47,
		0xb4, 0x00, 0xd1, 0x02, 0x83, 0xd0, 0x82, 0x68, 0xc1, 0xf2, 0x63, 0xd0, 0x82, 0xb0, 0x8e, 0xc3,
		0xab, 0xa6, 0x89, 0x68, 0x01, 0xa6, 0xe9, 0x4b, 0x42, 0x62, 0xb7, 0x2a, 0x9d, 0x87, 0xcd, 0xcd,
		0x16, 0xd1, 0x02, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x6b, 0xfa, 0x3b, 0xa2,
		0x05, 0xf0, 0x69, 0x3b, 0xd2, 0xc2, 0x91, 0x3e, 0xf8, 0xb4, 0xa7, 0x7c, 0x1a, 0xd1, 0x02, 0x18,
		0x35, 0x8c, 0x3a, 0x97, 0x2b, 0x21, 0x5a, 0xe0, 0x81, 0x68, 0x81, 0xe6, 0xf4, 0x77, 0xc9, 0x77,
		0xcd, 0x82, 0xe6, 0x74, 0x33, 0x8a, 0x22, 0x59, 0xf0, 0x24, 0xc7, 0xce, 0xab, 0xed, 0xb4, 0xb9,
		0x70, 0xd6, 0xb2, 0x8a, 0x08, 0x85, 0xb7, 0xee, 0x29, 0xeb, 0x98, 0x72, 0xee, 0x22, 0xe8, 0x2a,
		0x4a, 0x9a, 0x21, 0xaa, 0x5a, 0x21, 0x4a, 0x1a, 0x21, 0x6a, 0xda, 0x20, 0x9a, 0xf5, 0x62, 0xfd,
		0xfa, 0xb0, 0x76, 0x3d, 0xd8, 0xac, 0xfe, 0x6b, 0x56, 0xef, 0x35, 0xa9, 0xef, 0xe6, 0x3b, 0x79,
		0xd0, 0xd2, 0xf4, 0x28, 0x8f, 0xa2, 0xa4, 0x1b, 0x74, 0x67, 0x33, 0x38, 0xc1, 0xb0, 0x3f, 0x36,
		0xd1, 0x6f, 0x5a, 0xff, 0x0c, 0x5a, 0xd2, 0x29, 0x36, 0xc3, 0x47, 0xca, 0xa5, 0x1f, 0xf5, 0x46,
		0x23, 0x22, 0x52, 0x85, 0x06, 0x12, 0x73, 0x40, 0x31, 0x05, 0x96, 0x62, 0x96, 0x98, 0xd4, 0x1b,
		0x84, 0x86, 0xc3, 0x41, 0xca, 0x43, 0x41, 0x14, 0x4a, 0x28, 0x94, 0x3c, 0xa6, 0x50, 0xa2, 0x55,
		0xc8, 0xf4, 0xae, 0x42, 0xa2, 0x50, 0xb4, 0x14, 0xac, 0x8d, 0x3c, 0xc9, 0x91, 0xcf, 0x69, 0xf9,
		0x9a, 0xaf, 0x3e, 0x56, 0x16, 0x2d, 0x64, 0x79, 0xe5, 0x55, 0x32, 0xfe, 0xe4, 0xde, 0xda, 0x05,
		0x2c, 0xbd, 0x1c, 0x0f, 0x3e, 0xed, 0x07, 0xbd, 0xf0, 0x7d, 0xd4, 0x8b, 0xba, 0xd9, 0x57, 0x2f,
		0x65, 0xef, 0x59, 0x22, 0x73, 0xef, 0xaa, 0x42, 0x7e, 0x2c, 0x5b, 0x61, 0x14, 0x27, 0x8c, 0x1a,
		0x04, 0x51, 0x8f, 0x10, 0x6a, 0x11, 0x40, 0x75, 0xc2, 0xa7, 0x4e, 0xf0, 0x54, 0x09, 0x5d, 0xbe,
		0x90, 0x5b, 0xba, 0x22, 0x58, 0x5e, 0xe9, 0xd3, 0xa9, 0xf5, 0x63, 0x14, 0xbb, 0x83, 0xea, 0x6d,
		0x99, 0x1d, 0xda, 0x32, 0xf9, 0xa9, 0xaa, 0xd1, 0x96, 0xa1, 0x2d, 0x63, 0x1e, 0x84, 0xb3, 0x85,
		0x3a, 0x8b, 0x18, 0xa2, 0xdc, 0x8a, 0x51, 0xbd, 0x01, 0xc6, 0xec, 0x2e, 0x0d, 0xda, 0x20, 0x05,
		0x08, 0xd8, 0xe6, 0x81, 0xdb, 0x3c, 0x80, 0x9b, 0x06, 0x72, 0x9d, 0x80, 0xae, 0x14, 0xd8, 0xd5,
		0x03, 0x7c, 0xb6, 0x20, 0x77, 0x69, 0x30, 0x7c, 0x5b, 0x2a, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x37,
		0x60, 0xe1, 0x0d, 0x68, 0x78, 0x01, 0x1e, 0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x73, 0x97,
		0x06, 0x77, 0x69, 0x68, 0x3e, 0x38, 0x83, 0xb7, 0xcb, 0x8f, 0xc1, 0xe0, 0xad, 0x75, 0xf8, 0x5b,
		0x35, 0x4d, 0x06, 0x6f, 0xd7, 0x4c, 0x93, 0xbb, 0x34, 0xac, 0x13, 0x02, 0xbb, 0x55, 0x51, 0xb4,
		0xda, 0xdc, 0x6c, 0xb9, 0x4b, 0x23, 0xab, 0x5e, 0x70, 0x97, 0x06, 0x54, 0x1e, 0x2a, 0x0f, 0x95,
		0x87, 0xca, 0x17, 0x96, 0xca, 0x73, 0x97, 0x46, 0x21, 0x92, 0x16, 0xee, 0xd2, 0x20, 0x5d, 0x20,
		0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x90, 0xf4, 0x77, 0xee, 0xd2, 0xe0, 0x2e, 0x0d, 0x83,
		0xd0, 0xc2, 0x5d, 0x1a, 0xcb, 0x8f, 0x41, 0x0b, 0xc2, 0x3a, 0x0e, 0xaf, 0x9a, 0x26, 0x77, 0x69,
		0x60, 0x9a, 0xbe, 0x24, 0x24, 0x76, 0xab, 0xd2, 0x79, 0xd8, 0xdc, 0x6c, 0xb9, 0x4b, 0x03, 0x52,
		0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x9a, 0xfe, 0xce, 0x5d, 0x1a, 0xf0, 0x69, 0x3b,
		0xd2, 0xc2, 0x91, 0x3e, 0xf8, 0xb4, 0xa7, 0x7c, 0x9a, 0xbb, 0x34, 0x60, 0xd4, 0x30, 0xea, 0x5c,
		0xae, 0xc4, 0x5d, 0x1a, 0x9a, 0x8a, 0x58, 0x6b, 0x42, 0x45, 0xab, 0x77, 0x6a, 0xa8, 0x8e, 0x81,
		0x97, 0x3c, 0x52, 0xcf, 0xda, 0x3f, 0x9e, 0x6d, 0xcb, 0x7d, 0x77, 0x6b, 0xcc, 0x4b, 0x0c, 0x45,
		0xd1, 0x8c, 0x54, 0x11, 0x1a, 0x0c, 0x4d, 0xf4, 0xa4, 0x15, 0x6f, 0x84, 0x31, 0xd3, 0x30, 0xa8,
		0xa0, 0x61, 0x50, 0x9c, 0x7a, 0x16, 0x1a, 0x06, 0x68, 0x18, 0x38, 0xdb, 0x49, 0x34, 0x0c, 0xd0,
		0x30, 0x28, 0x1e, 0x28, 0xd8, 0x83, 0x83, 0x35, 0x48, 0x78, 0x03, 0x16, 0xde, 0x80, 0x86, 0x17,
		0xe0, 0x61, 0x53, 0x70, 0x40, 0xc3, 0x40, 0x3d, 0xba, 0xa3, 0x61, 0xa0, 0xf8, 0xe0, 0x34, 0x3c,
		0x96, 0x1f, 0x83, 0x86, 0x87, 0x75, 0xf8, 0x5b, 0x35, 0x4d, 0x1a, 0x1e, 0x6b, 0xa6, 0x89, 0x86,
		0x81, 0x75, 0x42, 0x60, 0xb7, 0x2a, 0x27, 0x09, 0x37, 0x37, 0x5b, 0x34, 0x0c, 0xb2, 0xea, 0x05,
		0x1a, 0x06, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x58, 0x2a, 0x8f, 0x86, 0x41, 0x21,
		0x92, 0x16, 0x34, 0x0c, 0x48, 0x17, 0x48, 0x17, 0x48, 0x17, 0x48, 0x17, 0x48, 0x17, 0x24, 0xfd,
		0x1d, 0x0d, 0x03, 0x34, 0x0c, 0x0c, 0x42, 0x0b, 0x1a, 0x06, 0xcb, 0x8f, 0x41, 0x0b, 0xc2, 0x3a,
		0x0e, 0xaf, 0x9a, 0x26, 0x1a, 0x06, 0x98, 0xa6, 0x2f, 0x09, 0x89, 0xdd, 0xaa, 0x74, 0x1e, 0x36,
		0x37, 0x5b, 0x34, 0x0c, 0x20, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0xaf, 0xe9, 0xef,
		0x68, 0x18, 0xc0, 0xa7, 0xed, 0x48, 0x0b, 0x47, 0xfa, 0xe0, 0xd3, 0x9e, 0xf2, 0x69, 0x34, 0x0c,
		0x60, 0xd4, 0x30, 0xea, 0x5c, 0xae, 0x84, 0x86, 0x81, 0x47, 0x1a, 0x06, 0x9a, 0x53, 0xe0, 0xa5,
		0x9c, 0x48, 0x18, 0x34, 0xa7, 0x7b, 0x52, 0x14, 0x05, 0x83, 0x27, 0x39, 0xf6, 0x65, 0x6d, 0x1f,
		0xce, 0x95, 0xef, 0x96, 0x55, 0xb4, 0x29, 0x7c, 0xf7, 0x56, 0x59, 0x3f, 0x95, 0xf3, 0x1e, 0x99,
		0x77, 0x16, 0xf2, 0x47, 0x2d, 0x3f, 0xf4, 0xdd, 0xff, 0x04, 0x5d, 0xce, 0x53, 0x57, 0x93, 0x71,
		0x2f, 0xf7, 0xc6, 0x2f, 0x60, 0xf8, 0xe5, 0xa9, 0x05, 0x2c, 0xbe, 0x79, 0x29, 0xb3, 0xcf, 0x4a,
		0x7d, 0x2b, 0xab, 0x09, 0xb9, 0xb1, 0xac, 0x0c, 0x8f, 0x78, 0x6b, 0x46, 0xa3, 0x05, 0xa3, 0xd7,
		0x6a, 0xd1, 0x6a, 0xa9, 0xa8, 0xb7, 0x4e, 0xd4, 0x5b, 0x24, 0xaa, 0xad, 0x90, 0x7c, 0x01, 0xb7,
		0xb4, 0xcc, 0x4d, 0xb9, 0xb3, 0xf0, 0x79, 0x61, 0x23, 0x5e, 0xb8, 0xa5, 0x8a, 0xe8, 0x9e, 0x92,
		0x5e, 0x99, 0x5a, 0x2f, 0x5b, 0xb3, 0x77, 0xad, 0xdf, 0xab, 0xd6, 0xee, 0x4d, 0x9b, 0xf5, 0xa2,
		0xcd, 0x7a, 0xcf, 0x26, 0xbd, 0xe6, 0x7c, 0x57, 0x2e, 0xb4, 0xf4, 0xc5, 0xca, 0xa3, 0x28, 0xe9,
		0x06, 0xdd, 0xd9, 0x3c, 0x70, 0x30, 0xec, 0x8f, 0x4d, 0xb4, 0x24, 0xd7, 0x3f, 0x83, 0x96, 0x8c,
		0x9b, 0xcd, 0x20, 0xb4, 0x72, 0x1b, 0x4a, 0xfd, 0xd0, 0x13, 0x82, 0x96, 0x85, 0x06, 0x12, 0x73,
		0x40, 0x31, 0x05, 0x16, 0x1d, 0x80, 0x51, 0x02, 0x9a, 0x6c, 0x27, 0xd5, 0x0f, 0x2b, 0x19, 0x0e,
		0x2a, 0x2b, 0x0f, 0x28, 0xd3, 0xa5, 0xf9, 0x86, 0x13, 0x6f, 0x79, 0x97, 0x66, 0xd1, 0x9d, 0x51,
		0x13, 0x84, 0xf7, 0xa6, 0x58, 0xbc, 0x68, 0xc8, 0x68, 0xa8, 0xbe, 0x0b, 0xf6, 0x62, 0x04, 0x8b,
		0x7c, 0x2b, 0x1d, 0x3b, 0xb5, 0x2a, 0x89, 0x62, 0x9f, 0x90, 0x5a, 0x09, 0xb5, 0x12, 0x6a, 0x25,
		0xd4, 0x4a, 0xf2, 0x50, 0x2b, 0x51, 0x2a, 0x56, 0xaf, 0xb9, 0xb7, 0xea, 0x4d, 0x31, 0x66, 0x97,
		0x6d, 0x50, 0x9b, 0xa0, 0x36, 0x41, 0x6d, 0x82, 0xda, 0x84, 0x5d, 0x80, 0xcf, 0x16, 0xe4, 0xb2,
		0x0d, 0xa6, 0x73, 0x4b, 0xc5, 0x07, 0x07, 0x6b, 0x90, 0xf0, 0x06, 0x2c, 0xbc, 0x01, 0x0d, 0x2f,
		0xc0, 0x43, 0x17, 0x44, 0x94, 0xc1, 0x24, 0xdb, 0x61, 0x2e, 0xdb, 0xe0, 0xb2, 0x0d, 0xcd, 0x07,
		0x67, 0x32, 0x77, 0xf9, 0x31, 0x98, 0xcc, 0xb5, 0x0e, 0x7f, 0xab, 0xa6, 0xc9, 0x64, 0xee, 0x9a,
		0x69, 0x72, 0xd9, 0x86, 0x75, 0x42, 0x60, 0xb7, 0x2a, 0x92, 0x57, 0x9b, 0x9b, 0x2d, 0x97, 0x6d,
		0x64, 0xd5, 0x0b, 0x2e, 0xdb, 0x80, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xc2, 0x52, 0x79,
		0x2e, 0xdb, 0x28, 0x44, 0xd2, 0xc2, 0x65, 0x1b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b,
		0xa4, 0x0b, 0x92, 0xfe, 0xce, 0x65, 0x1b, 0x5c, 0xb6, 0x61, 0x10, 0x5a, 0xb8, 0x6c, 0x63, 0xf9,
		0x31, 0x68, 0x41, 0x58, 0xc7, 0xe1, 0x55, 0xd3, 0xe4, 0xb2, 0x0d, 0x4c, 0xd3, 0x97, 0x84, 0xc4,
		0x6e, 0x55, 0x3a, 0x0f, 0x9b, 0x9b, 0x2d, 0x97, 0x6d, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48,
		0x3d, 0xa4, 0x5e, 0xd3, 0xdf, 0xb9, 0x6c, 0x03, 0x3e, 0x6d, 0x47, 0x5a, 0x38, 0xd2, 0x07, 0x9f,
		0xf6, 0x94, 0x4f, 0x73, 0xd9, 0x06, 0x8c, 0x1a, 0x46, 0x9d, 0xcb, 0x95, 0xb8, 0x6c, 0xc3, 0x46,
		0x0a, 0x66, 0xe5, 0x92, 0x0d, 0xd5, 0xf1, 0xef, 0x92, 0x8f, 0xfa, 0x30, 0xb7, 0xaf, 0xd7, 0xd0,
		0xd0, 0x8a, 0xd1, 0x73, 0xb2, 0x1b, 0x15, 0xb5, 0x9f, 0xd0, 0x44, 0xd5, 0x51, 0xf1, 0x6e, 0x18,
		0x33, 0xd1, 0x82, 0x0a, 0xa2, 0x05, 0xc5, 0x29, 0x60, 0x21, 0x5a, 0x80, 0x68, 0x81, 0xb3, 0x9d,
		0x44, 0xb4, 0x00, 0xd1, 0x82, 0xe2, 0x81, 0x82, 0x3d, 0x38, 0x58, 0x83, 0x84, 0x37, 0x60, 0xe1,
		0x0d, 0x68, 0x78, 0x01, 0x1e, 0x36, 0x15, 0x06, 0x44, 0x0b, 0xd4, 0xa3, 0x3b, 0xa2, 0x05, 0x8a,
		0x0f, 0x4e, 0x87, 0x63, 0xf9, 0x31, 0xe8, 0x70, 0x58, 0x87, 0xbf, 0x55, 0xd3, 0xa4, 0xc3, 0xb1,
		0x66, 0x9a, 0x88, 0x16, 0x58, 0x27, 0x04, 0x76, 0xab, 0x72, 0x74, 0x70, 0x73, 0xb3, 0x45, 0xb4,
		0x20, 0xab, 0x5e, 0x20, 0x5a, 0x00, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x85, 0xa5, 0xf2,
		0x88, 0x16, 0x14, 0x22, 0x69, 0x41, 0xb4, 0x80, 0x74, 0x81, 0x74, 0x81, 0x74, 0x81, 0x74, 0x81,
		0x74, 0x41, 0xd2, 0xdf, 0x11, 0x2d, 0x40, 0xb4, 0xc0, 0x20, 0xb4, 0x20, 0x5a, 0xb0, 0xfc, 0x18,
		0xb4, 0x20, 0xac, 0xe3, 0xf0, 0xaa, 0x69, 0x22, 0x5a, 0x80, 0x69, 0xfa, 0x92, 0x90, 0xd8, 0xad,
		0x4a, 0xe7, 0x61, 0x73, 0xb3, 0x45, 0xb4, 0x00, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21,
		0xf5, 0x9a, 0xfe, 0x8e, 0x68, 0x01, 0x7c, 0xda, 0x8e, 0xb4, 0x70, 0xa4, 0x0f, 0x3e, 0xed, 0x29,
		0x9f, 0x46, 0xb4, 0x00, 0x46, 0x0d, 0xa3, 0xce, 0xe5, 0x4a, 0x88, 0x16, 0x78, 0x20, 0x5a, 0xa0,
		0x39, 0xfd, 0x5d, 0xf2, 0x5d, 0xb3, 0xa0, 0x39, 0xdd, 0x8c, 0xa2, 0x48, 0x16, 0x3c, 0xc9, 0xb1,
		0xf3, 0x6a, 0x3b, 0x6d, 0x2e, 0x9c, 0xb5, 0xac, 0x22, 0x42, 0xe1, 0xad, 0x7b, 0xca, 0x3a, 0xa6,
		0x9c, 0xbb, 0x08, 0xba, 0x8a, 0x92, 0x66, 0x88, 0xaa, 0x56, 0x88, 0x92, 0x46, 0x88, 0x9a, 0x36,
		0x88, 0x66, 0xbd, 0x58, 0xbf, 0x3e, 0xac, 0x5d, 0x0f, 0x36, 0xab, 0xff, 0x9a, 0xd5, 0x7b, 0x4d,
		0xea, 0xbb, 0xf9, 0x4e, 0x1e, 0xb4, 0x34, 0x3d, 0xca, 0xa3, 0x28, 0xe9, 0x06, 0xdd, 0xd9, 0x0c,
		0x4e, 0x30, 0xec, 0x8f, 0x4d, 0xf4, 0x9b, 0xd6, 0x3f, 0x83, 0x96, 0x74, 0x8a, 0xcd, 0xf0, 0x91,
		0x72, 0xe9, 0x47, 0xbd, 0xd1, 0x88, 0x88, 0x54, 0xa1, 0x81, 0xc4, 0x1c, 0x50, 0x4c, 0x81, 0xa5,
		0x98, 0x25, 0x26, 0xf5, 0x06, 0xa1, 0xe1, 0x70, 0x90, 0xf2, 0x50, 0x10, 0x85, 0x12, 0x0a, 0x25,
		0x8f, 0x29, 0x94, 0x68, 0x15, 0x32, 0xbd, 0xab, 0x90, 0x28, 0x14, 0x2d, 0x05, 0x6b, 0x23, 0x4f,
		0x72, 0xe4, 0x73, 0x5a, 0xbe, 0xe6, 0xab, 0x8f, 0x95, 0x45, 0x0b, 0x59, 0x5e, 0x79, 0x95, 0x8c,
		0x3f, 0xb9, 0xb7, 0x76, 0x01, 0x4b, 0x2f, 0xf7, 0x2a, 0x9f, 0x06, 0x49, 0x10, 0x7d, 0x1a, 0xc8,
		0x59, 0x79, 0x96, 0xbe, 0xdc, 0x5a, 0x4b, 0xc8, 0x67, 0x65, 0xab, 0x89, 0xe2, 0xe4, 0x50, 0x83,
		0x0c, 0xea, 0x91, 0x3f, 0x2d, 0xb2, 0xa7, 0x4e, 0xee, 0xd4, 0xc9, 0x9c, 0x2a, 0x79, 0xcb, 0x17,
		0x4a, 0x4b, 0x57, 0xff, 0xca, 0x2b, 0x3d, 0x39, 0xb5, 0xde, 0x8b, 0x62, 0x27, 0x50, 0xbd, 0x05,
		0xb3, 0x43, 0x0b, 0x26, 0x3f, 0x15, 0x34, 0x5a, 0x30, 0xb4, 0x60, 0xcc, 0x83, 0x70, 0xb6, 0x50,
		0x67, 0x11, 0x43, 0x94, 0xdb, 0x2e, 0xaa, 0xb7, 0xbd, 0x98, 0xdd, 0x9b, 0x41, 0xcb, 0xa3, 0x00,
		0x01, 0xdb, 0x3c, 0x70, 0x9b, 0x07, 0x70, 0xd3, 0x40, 0xae, 0x13, 0xd0, 0x95, 0x02, 0xbb, 0x7a,
		0x80, 0xcf, 0x16, 0xe4, 0xde, 0x0c, 0x06, 0x6d, 0x4b, 0xc5, 0x07, 0x07, 0x6b, 0x90, 0xf0, 0x06,
		0x2c, 0xbc, 0x01, 0x0d, 0x2f, 0xc0, 0x43, 0x17, 0x44, 0x94, 0xc1, 0x24, 0xdb, 0x61, 0xee, 0xcd,
		0xe0, 0xde, 0x0c, 0xcd, 0x07, 0x67, 0xc8, 0x76, 0xf9, 0x31, 0x18, 0xb2, 0xb5, 0x0e, 0x7f, 0xab,
		0xa6, 0xc9, 0x90, 0xed, 0x9a, 0x69, 0x72, 0x6f, 0x86, 0x75, 0x42, 0x60, 0xb7, 0x2a, 0xea, 0x55,
		0x9b, 0x9b, 0x2d, 0xf7, 0x66, 0x64, 0xd5, 0x0b, 0xee, 0xcd, 0x80, 0xca, 0x43, 0xe5, 0xa1, 0xf2,
		0x50, 0xf9, 0xc2, 0x52, 0x79, 0xee, 0xcd, 0x28, 0x44, 0xd2, 0xc2, 0xbd, 0x19, 0xa4, 0x0b, 0xa4,
		0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0x92, 0xfe, 0xce, 0xbd, 0x19, 0xdc, 0x9b, 0x61, 0x10,
		0x5a, 0xb8, 0x37, 0x63, 0xf9, 0x31, 0x68, 0x41, 0x58, 0xc7, 0xe1, 0x55, 0xd3, 0xe4, 0xde, 0x0c,
		0x4c, 0xd3, 0x97, 0x84, 0xc4, 0x6e, 0x55, 0x3a, 0x0f, 0x9b, 0x9b, 0x2d, 0xf7, 0x66, 0x40, 0xea,
		0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xd3, 0xdf, 0xb9, 0x37, 0x03, 0x3e, 0x6d, 0x47,
		0x5a, 0x38, 0xd2, 0x07, 0x9f, 0xf6, 0x94, 0x4f, 0x73, 0x6f, 0x06, 0x8c, 0x1a, 0x46, 0x9d, 0xcb,
		0x95, 0xb8, 0x37, 0x43, 0x4d, 0xfd, 0x6a, 0x29, 0x4f, 0xb4, 0x7a, 0x6b, 0x86, 0xea, 0xf0, 0x77,
		0xc9, 0x17, 0x7d, 0xac, 0xe3, 0xca, 0xdb, 0x41, 0x52, 0xfb, 0x34, 0x48, 0x56, 0x2e, 0xcd, 0x98,
		0xd7, 0x13, 0x8a, 0x22, 0x06, 0xa9, 0xa2, 0x20, 0x18, 0x9a, 0x08, 0x45, 0x2b, 0x5e, 0xf5, 0x62,
		0x26, 0x58, 0x50, 0x41, 0xb0, 0xa0, 0x38, 0xc5, 0x2b, 0x04, 0x0b, 0x10, 0x2c, 0x70, 0xb6, 0x93,
		0x08, 0x16, 0x20, 0x58, 0x50, 0x3c, 0x50, 0xb0, 0x07, 0x07, 0x6b, 0x90, 0xf0, 0x06, 0x2c, 0xbc,
		0x01, 0x0d, 0x2f, 0xc0, 0xc3, 0xa6, 0xba, 0x80, 0x60, 0x81, 0x7a, 0x74, 0x47, 0xb0, 0x40, 0xf1,
		0xc1, 0xe9, 0x6e, 0x2c, 0x3f, 0x06, 0xdd, 0x0d, 0xeb, 0xf0, 0xb7, 0x6a, 0x9a, 0x74, 0x37, 0xd6,
		0x4c, 0x13, 0xc1, 0x02, 0xeb, 0x84, 0xc0, 0x6e, 0x55, 0x8e, 0x0d, 0x6e, 0x6e, 0xb6, 0x08, 0x16,
		0x64, 0xd5, 0x0b, 0x04, 0x0b, 0xa0, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb0, 0x54, 0x1e,
		0xc1, 0x82, 0x42, 0x24, 0x2d, 0x08, 0x16, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x90,
		0x2e, 0x48, 0xfa, 0x3b, 0x82, 0x05, 0x08, 0x16, 0x18, 0x84, 0x16, 0x04, 0x0b, 0x96, 0x1f, 0x83,
		0x16, 0x84, 0x75, 0x1c, 0x5e, 0x35, 0x4d, 0x04, 0x0b, 0x30, 0x4d, 0x5f, 0x12, 0x12, 0xbb, 0x55,
		0xe9, 0x3c, 0x6c, 0x6e, 0xb6, 0x08, 0x16, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4,
		0x5e, 0xd3, 0xdf, 0x11, 0x2c, 0x80, 0x4f, 0xdb, 0x91, 0x16, 0x8e, 0xf4, 0xc1, 0xa7, 0x3d, 0xe5,
		0xd3, 0x08, 0x16, 0xc0, 0xa8, 0x61, 0xd4, 0xb9, 0x5c, 0x09, 0xc1, 0x02, 0x73, 0xc1, 0x02, 0xcd,
		0xd9, 0xef, 0x92, 0xdf, 0x7a, 0x05, 0xcd, 0xe9, 0x56, 0x14, 0x45, 0xae, 0xe0, 0x49, 0x8e, 0x1d,
		0x57, 0xdb, 0x61, 0x73, 0xe0, 0xa8, 0x65, 0x15, 0xf9, 0x09, 0x4f, 0x5d, 0x53, 0xd6, 0x29, 0xe5,
		0x5c, 0x45, 0xe6, 0x9d, 0x85, 0x9c, 0x4f, 0xcb, 0xe9, 0xfc, 0x74, 0x36, 0x41, 0xff, 0xf2, 0xcb,
		0xaf, 0x64, 0x7c, 0xc9, 0xbd, 0xa5, 0x0b, 0x58, 0x79, 0x79, 0xf6, 0x75, 0x7f, 0x1a, 0xf4, 0xe4,
		0x64, 0x17, 0xb2, 0x7a, 0xdd, 0xad, 0xb5, 0x84, 0xfc, 0x55, 0x56, 0x49, 0x47, 0xbc, 0xbb, 0xa2,
		0xd1, 0x45, 0xd1, 0xeb, 0x96, 0x68, 0x75, 0x45, 0xd4, 0xbb, 0x1f, 0xea, 0x5d, 0x0e, 0xd5, 0x6e,
		0x46, 0xbe, 0x10, 0x5a, 0x5a, 0xa9, 0xa6, 0xbc, 0x92, 0x71, 0x8a, 0x9b, 0xf2, 0xad, 0x11, 0x3a,
		0xad, 0x3c, 0x57, 0x49, 0x7e, 0x4c, 0xad, 0x35, 0xad, 0xd9, 0x8a, 0xd6, 0x6f, 0x3d, 0x6b, 0xb7,
		0x9a, 0xcd, 0x5a, 0xcb, 0x66, 0xad, 0x64, 0x93, 0xd6, 0x71, 0xbe, 0x6b, 0x13, 0x5a, 0x72, 0x61,
		0xe5, 0xce, 0x22, 0x86, 0x28, 0xcb, 0x41, 0xaa, 0x6a, 0x98, 0x9a, 0xe9, 0x41, 0xee, 0xa0, 0x07,
		0x99, 0xff, 0x80, 0x6d, 0x1e, 0xb8, 0xcd, 0x03, 0xb8, 0x69, 0x20, 0xd7, 0x09, 0xe8, 0x4a, 0x81,
		0x5d, 0x3d, 0xc0, 0x67, 0x0b, 0xa2, 0x07, 0xc9, 0x01, 0xd2, 0x52, 0xf1, 0xc1, 0xc1, 0x1a, 0x24,
		0xbc, 0x01, 0x0b, 0x6f, 0x40, 0xc3, 0x0b, 0xf0, 0xd0, 0x05, 0x11, 0x65, 0x30, 0xc9, 0x76, 0x18,
		0x3d, 0x48, 0xf4, 0x20, 0x35, 0x1f, 0x9c, 0xc3, 0xa3, 0xcb, 0x8f, 0xc1, 0xe1, 0x51, 0xeb, 0xf0,
		0xb7, 0x6a, 0x9a, 0x1c, 0x1e, 0x5d, 0x33, 0x4d, 0xf4, 0x20, 0xad, 0x13, 0x02, 0xbb, 0x55, 0x99,
		0xca, 0xdc, 0xdc, 0x6c, 0xd1, 0x83, 0xcc, 0xaa, 0x17, 0xe8, 0x41, 0x42, 0xe5, 0xa1, 0xf2, 0x50,
		0x79, 0xa8, 0x7c, 0x61, 0xa9, 0x3c, 0x7a, 0x90, 0x85, 0x48, 0x5a, 0xd0, 0x83, 0x24, 0x5d, 0x20,
		0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x90, 0xf4, 0x77, 0xf4, 0x20, 0xd1, 0x83, 0x34, 0x08,
		0x2d, 0xe8, 0x41, 0x2e, 0x3f, 0x06, 0x2d, 0x08, 0xeb, 0x38, 0xbc, 0x6a, 0x9a, 0xe8, 0x41, 0x62,
		0x9a, 0xbe, 0x24, 0x24, 0x76, 0xab, 0xd2, 0x79, 0xd8, 0xdc, 0x6c, 0xd1, 0x83, 0x84, 0xd4, 0x43,
		0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa6, 0xbf, 0xa3, 0x07, 0x09, 0x9f, 0xb6, 0x23, 0x2d,
		0x1c, 0xe9, 0x83, 0x4f, 0x7b, 0xca, 0xa7, 0xd1, 0x83, 0x84, 0x51, 0xc3, 0xa8, 0x73, 0xb9, 0x12,
		0x7a, 0x90, 0xca, 0xca, 0x57, 0x9f, 0x06, 0xd3, 0xdf, 0xbe, 0xa5, 0x07, 0xa9, 0x3a, 0xfc, 0x5d,
		0xf2, 0x4a, 0x1d, 0xeb, 0xed, 0x60, 0xfa, 0xab, 0x4b, 0x41, 0xc8, 0x79, 0x3d, 0xa1, 0x28, 0x8a,
		0x90, 0x2a, 0x0a, 0x82, 0x61, 0x1a, 0xe9, 0x2b, 0x16, 0x68, 0x8a, 0x98, 0x9a, 0x09, 0x16, 0x54,
		0x10, 0x2c, 0x28, 0x4e, 0xf1, 0x0a, 0xc1, 0x02, 0x04, 0x0b, 0x9c, 0xed, 0x24, 0x82, 0x05, 0x08,
		0x16, 0x14, 0x0f, 0x14, 0xec, 0xc1, 0xc1, 0x1a, 0x24, 0xbc, 0x01, 0x0b, 0x6f, 0x40, 0xc3, 0x0b,
		0xf0, 0xb0, 0xa9, 0x2e, 0x20, 0x58, 0xa0, 0x1e, 0xdd, 0x11, 0x2c, 0x50, 0x7c, 0x70, 0xba, 0x1b,
		0xcb, 0x8f, 0x41, 0x77, 0xc3, 0x3a, 0xfc, 0xad, 0x9a, 0x26, 0xdd, 0x8d, 0x35, 0xd3, 0x44, 0xb0,
		0xc0, 0x3a, 0x21, 0xb0, 0x5b, 0x95, 0x63, 0x83, 0x9b, 0x9b, 0x2d, 0x82, 0x05, 0x59, 0xf5, 0x02,
		0xc1, 0x02, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x2f, 0x2c, 0x95, 0x47, 0xb0, 0xa0, 0x10,
		0x49, 0x0b, 0x82, 0x05, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0x92, 0xfe,
		0x8e, 0x60, 0x01, 0x82, 0x05, 0x06, 0xa1, 0x05, 0xc1, 0x82, 0xe5, 0xc7, 0xa0, 0x05, 0x61, 0x1d,
		0x87, 0x57, 0x4d, 0x13, 0xc1, 0x02, 0x4c, 0xd3, 0x97, 0x84, 0xc4, 0x6e, 0x55, 0x3a, 0x0f, 0x9b,
		0x9b, 0x2d, 0x82, 0x05, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xd7, 0xf4, 0x77,
		0x04, 0x0b, 0xe0, 0xd3, 0x76, 0xa4, 0x85, 0x23, 0x7d, 0xf0, 0x69, 0x4f, 0xf9, 0x34, 0x82, 0x05,
		0x30, 0x6a, 0x18, 0x75, 0x2e, 0x57, 0x42, 0xb0, 0xc0, 0x5c, 0xb0, 0x40, 0x73, 0xf6, 0xbb, 0xe4,
		0xb7, 0x5e, 0x41, 0x73, 0xba, 0x15, 0x45, 0x91, 0x2b, 0x78, 0x92, 0x63, 0xc7, 0xd5, 0x76, 0xd8,
		0x1c, 0x38, 0x6a, 0x59, 0x45, 0x7e, 0xc2, 0x53, 0xd7, 0x94, 0x75, 0x4a, 0x39, 0x57, 0x91, 0x79,
		0x67, 0x21, 0xe7, 0xd3, 0x72, 0x3a, 0x3f, 0x9d, 0x4d, 0xd0, 0xbf, 0xfc, 0xf2, 0x2b, 0x19, 0x5f,
		0x72, 0x6f, 0xe9, 0x02, 0x56, 0x5e, 0xee, 0x3d, 0x9b, 0x7c, 0xdd, 0xf1, 0xe0, 0x53, 0x35, 0xb8,
		0x1e, 0xf7, 0xd2, 0xb8, 0x13, 0x8e, 0xe4, 0x5a, 0x37, 0x59, 0xe5, 0xee, 0xde, 0x55, 0x85, 0x7c,
		0x58, 0x56, 0x5d, 0x47, 0xbc, 0xe3, 0xa2, 0xd1, 0x59, 0xd1, 0xeb, 0xa0, 0x68, 0x75, 0x4a, 0xd4,
		0x3b, 0x22, 0xea, 0x9d, 0x0f, 0xd5, 0x0e, 0x47, 0xbe, 0x50, 0x5b, 0x5a, 0xbd, 0xa6, 0xbc, 0x92,
		0x85, 0x8a, 0x9b, 0xf2, 0xad, 0xb1, 0x3a, 0xad, 0xdc, 0x57, 0x49, 0x92, 0x4c, 0xad, 0x5d, 0xad,
		0xd9, 0x9e, 0xd6, 0x6f, 0x47, 0x6b, 0xb7, 0x9f, 0xcd, 0xda, 0xcd, 0x66, 0xed, 0x65, 0x93, 0x76,
		0x72, 0xbe, 0xeb, 0x15, 0x5a, 0x12, 0x62, 0xe5, 0xce, 0x22, 0x86, 0x28, 0x4b, 0x44, 0xaa, 0xea,
		0x9a, 0x9a, 0x69, 0x44, 0xee, 0xa0, 0x11, 0x99, 0xff, 0x80, 0x6d, 0x1e, 0xb8, 0xcd, 0x03, 0xb8,
		0x69, 0x20, 0xd7, 0x09, 0xe8, 0x4a, 0x81, 0x5d, 0x3d, 0xc0, 0x67, 0x0b, 0xa2, 0x11, 0xc9, 0xa1,
		0xd2, 0x52, 0xf1, 0xc1, 0xc1, 0x1a, 0x24, 0xbc, 0x01, 0x0b, 0x6f, 0x40, 0xc3, 0x0b, 0xf0, 0xd0,
		0x05, 0x11, 0x65, 0x30, 0xc9, 0x76, 0x18, 0x8d, 0x48, 0x34, 0x22, 0x35, 0x1f, 0x9c, 0x03, 0xa5,
		0xcb, 0x8f, 0xc1, 0x81, 0x52, 0xeb, 0xf0, 0xb7, 0x6a, 0x9a, 0x1c, 0x28, 0x5d, 0x33, 0x4d, 0x34,
		0x22, 0xad, 0x13, 0x02, 0xbb, 0x55, 0x99, 0xd4, 0xdc, 0xdc, 0x6c, 0xd1, 0x88, 0xcc, 0xaa, 0x17,
		0x68, 0x44, 0x42, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x61, 0xa9, 0x3c, 0x1a, 0x91, 0x85,
		0x48, 0x5a, 0xd0, 0x88, 0x24, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x90, 0xf4,
		0x77, 0x34, 0x22, 0xd1, 0x88, 0x34, 0x08, 0x2d, 0x68, 0x44, 0x2e, 0x3f, 0x06, 0x2d, 0x08, 0xeb,
		0x38, 0xbc, 0x6a, 0x9a, 0x68, 0x44, 0x62, 0x9a, 0xbe, 0x24, 0x24, 0x76, 0xab, 0xd2, 0x79, 0xd8,
		0xdc, 0x6c, 0xd1, 0x88, 0x84, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa6, 0xbf,
		0xa3, 0x11, 0x09, 0x9f, 0xb6, 0x23, 0x2d, 0x1c, 0xe9, 0x83, 0x4f, 0x7b, 0xca, 0xa7, 0xd1, 0x88,
		0x84, 0x51, 0xc3, 0xa8, 0x73, 0xb9, 0x12, 0x1a, 0x91, 0x7a, 0x6a, 0x58, 0xf7, 0x08, 0x15, 0xad,
		0xaa, 0x45, 0xaa, 0x8e, 0x81, 0x97, 0xbc, 0xd1, 0xce, 0x7a, 0xf6, 0x76, 0x90, 0xd4, 0x07, 0x9f,
		0xaa, 0x27, 0x8b, 0x5d, 0x59, 0xd1, 0x8d, 0x9c, 0x97, 0x18, 0x8a, 0x22, 0x1c, 0xa9, 0x22, 0x34,
		0x18, 0xa6, 0x91, 0xbe, 0x88, 0x81, 0xa6, 0xd6, 0xa9, 0x99, 0x86, 0x41, 0x05, 0x0d, 0x83, 0xe2,
		0xd4, 0xb3, 0xd0, 0x30, 0x40, 0xc3, 0xc0, 0xd9, 0x4e, 0xa2, 0x61, 0x80, 0x86, 0x41, 0xf1, 0x40,
		0xc1, 0x1e, 0x1c, 0xac, 0x41, 0xc2, 0x1b, 0xb0, 0xf0, 0x06, 0x34, 0xbc, 0x00, 0x0f, 0x9b, 0x82,
		0x03, 0x1a, 0x06, 0xea, 0xd1, 0x1d, 0x0d, 0x03, 0xc5, 0x07, 0xa7, 0xe1, 0xb1, 0xfc, 0x18, 0x34,
		0x3c, 0xac, 0xc3, 0xdf, 0xaa, 0x69, 0xd2, 0xf0, 0x58, 0x33, 0x4d, 0x34, 0x0c, 0xac, 0x13, 0x02,
		0xbb, 0x55, 0x39, 0x49, 0xb8, 0xb9, 0xd9, 0xa2, 0x61, 0x90, 0x55, 0x2f, 0xd0, 0x30, 0x80, 0xca,
		0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xc2, 0x52, 0x79, 0x34, 0x0c, 0x0a, 0x91, 0xb4, 0xa0, 0x61,
		0x40, 0xba, 0x40, 0xba, 0x40, 0xba, 0x40, 0xba, 0x40, 0xba, 0x20, 0xe9, 0xef, 0x68, 0x18, 0xa0,
		0x61, 0x60, 0x10, 0x5a, 0xd0, 0x30, 0x58, 0x7e, 0x0c, 0x5a, 0x10, 0xd6, 0x71, 0x78, 0xd5, 0x34,
		0xd1, 0x30, 0xc0, 0x34, 0x7d, 0x49, 0x48, 0xec, 0x56, 0xa5, 0xf3, 0xb0, 0xb9, 0xd9, 0xa2, 0x61,
		0x00, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x4d, 0x7f, 0x47, 0xc3, 0x00, 0x3e,
		0x6d, 0x47, 0x5a, 0x38, 0xd2, 0x07, 0x9f, 0xf6, 0x94, 0x4f, 0xa3, 0x61, 0x00, 0xa3, 0x86, 0x51,
		0xe7, 0x72, 0x25, 0x34, 0x0c, 0x3c, 0xd2, 0x30, 0xd0, 0x9c, 0x02, 0x2f, 0xe5, 0x44, 0xc2, 0xa0,
		0x39, 0xdd, 0x93, 0xa2, 0x28, 0x18, 0x3c, 0xc9, 0xb1, 0x2f, 0x6b, 0xfb, 0x70, 0xae, 0x7c, 0xb7,
		0xac, 0xa2, 0x4d, 0xe1, 0xbb, 0xb7, 0xca, 0xfa, 0xa9, 0x9c, 0xf7, 0xc8, 0xbc, 0xb3, 0x90, 0x3f,
		0x6a, 0xf9, 0xa1, 0xef, 0xfe, 0x27, 0xe8, 0x72, 0x9e, 0xba, 0x9a, 0x8c, 0x7b, 0xb9, 0x37, 0x7e,
		0x01, 0xc3, 0x2f, 0xdf, 0xb2, 0x80, 0x71, 0x32, 0xdb, 0x0d, 0x29, 0xe3, 0xcf, 0x0a, 0x7e, 0xf7,
		0xac, 0x29, 0xe4, 0xd2, 0xb2, 0x92, 0x3c, 0xe2, 0x6d, 0x1a, 0x8d, 0x76, 0x8c, 0x5e, 0xdb, 0x45,
		0xab, 0xbd, 0xa2, 0xde, 0x46, 0x51, 0x6f, 0x97, 0xa8, 0xb6, 0x45, 0xf2, 0x05, 0xe2, 0xd2, 0x92,
		0x37, 0xe5, 0x95, 0xec, 0x54, 0xdc, 0x94, 0x6f, 0xcd, 0xe2, 0x69, 0xe5, 0xc4, 0x4a, 0x3a, 0x66,
		0x6a, 0x3d, 0x6e, 0xcd, 0x9e, 0xb6, 0x7e, 0x0f, 0x5b, 0xbb, 0x67, 0x6d, 0xd6, 0xa3, 0x36, 0xeb,
		0x49, 0x9b, 0xf4, 0xa0, 0xf3, 0x5d, 0xd1, 0xd0, 0xd2, 0x1d, 0x2b, 0x77, 0x16, 0x31, 0x44, 0x59,
		0x57, 0x52, 0x55, 0x15, 0xd5, 0x4c, 0x58, 0x72, 0x07, 0x61, 0xc9, 0xfc, 0x07, 0x6c, 0xf3, 0xc0,
		0x6d, 0x1e, 0xc0, 0x4d, 0x03, 0xb9, 0x4e, 0x40, 0x57, 0x0a, 0xec, 0xea, 0x01, 0x3e, 0x5b, 0x10,
		0x61, 0x49, 0x4e, 0xa2, 0x96, 0x8a, 0x0f, 0x0e, 0xd6, 0x20, 0xe1, 0x0d, 0x58, 0x78, 0x03, 0x1a,
		0x5e, 0x80, 0x87, 0x2e, 0x88, 0x28, 0x83, 0x49, 0xb6, 0xc3, 0x08, 0x4b, 0x22, 0x2c, 0xa9, 0xf9,
		0xe0, 0x9c, 0x42, 0x5d, 0x7e, 0x0c, 0x4e, 0xa1, 0x5a, 0x87, 0xbf, 0x55, 0xd3, 0xe4, 0x14, 0xea,
		0x9a, 0x69, 0x22, 0x2c, 0x69, 0x9d, 0x10, 0xd8, 0xad, 0xca, 0x78, 0xe7, 0xe6, 0x66, 0x8b, 0xb0,
		0x64, 0x56, 0xbd, 0x40, 0x58, 0x12, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x0b, 0x4b, 0xe5,
		0x11, 0x96, 0x2c, 0x44, 0xd2, 0x82, 0xb0, 0x24, 0xe9, 0x02, 0xe9, 0x02, 0xe9, 0x02, 0xe9, 0x02,
		0xe9, 0x82, 0xa4, 0xbf, 0x23, 0x2c, 0x89, 0xb0, 0xa4, 0x41, 0x68, 0x41, 0x58, 0x72, 0xf9, 0x31,
		0x68, 0x41, 0x58, 0xc7, 0xe1, 0x55, 0xd3, 0x44, 0x58, 0x12, 0xd3, 0xf4, 0x25, 0x21, 0xb1, 0x5b,
		0x95, 0xce, 0xc3, 0xe6, 0x66, 0x8b, 0xb0, 0x24, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43,
		0xea, 0x35, 0xfd, 0x1d, 0x61, 0x49, 0xf8, 0xb4, 0x1d, 0x69, 0xe1, 0x48, 0x1f, 0x7c, 0xda, 0x53,
		0x3e, 0x8d, 0xb0, 0x24, 0x8c, 0x1a, 0x46, 0x9d, 0xcb, 0x95, 0x10, 0x96, 0xb4, 0x10, 0xc7, 0x9a,
		0xcb, 0x14, 0xad, 0xca, 0x4a, 0xaa, 0x0e, 0x81, 0x97, 0xbc, 0x93, 0xcf, 0xba, 0x48, 0xd6, 0x55,
		0x25, 0xe7, 0xe5, 0x85, 0xa2, 0xc8, 0x4a, 0xaa, 0x88, 0x0f, 0x86, 0x69, 0xa4, 0x2f, 0x60, 0xa0,
		0x29, 0x89, 0x6a, 0xa6, 0x5f, 0x50, 0x41, 0xbf, 0xa0, 0x38, 0xb5, 0x2c, 0xf4, 0x0b, 0xd0, 0x2f,
		0x70, 0xb6, 0x93, 0xe8, 0x17, 0xa0, 0x5f, 0x50, 0x3c, 0x50, 0xb0, 0x07, 0x07, 0x6b, 0x90, 0xf0,
		0x06, 0x2c, 0xbc, 0x01, 0x0d, 0x2f, 0xc0, 0xc3, 0xa6, 0xd8, 0x80, 0x7e, 0x81, 0x7a, 0x74, 0x47,
		0xbf, 0x40, 0xf1, 0xc1, 0x69, 0x76, 0x2c, 0x3f, 0x06, 0xcd, 0x0e, 0xeb, 0xf0, 0xb7, 0x6a, 0x9a,
		0x34, 0x3b, 0xd6, 0x4c, 0x13, 0xfd, 0x02, 0xeb, 0x84, 0xc0, 0x6e, 0x55, 0x4e, 0x11, 0x6e, 0x6e,
		0xb6, 0xe8, 0x17, 0x64, 0xd5, 0x0b, 0xf4, 0x0b, 0xa0, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe,
		0xb0, 0x54, 0x1e, 0xfd, 0x82, 0x42, 0x24, 0x2d, 0xe8, 0x17, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e,
		0x90, 0x2e, 0x90, 0x2e, 0x48, 0xfa, 0x3b, 0xfa, 0x05, 0xe8, 0x17, 0x18, 0x84, 0x16, 0xf4, 0x0b,
		0x96, 0x1f, 0x83, 0x16, 0x84, 0x75, 0x1c, 0x5e, 0x35, 0x4d, 0xf4, 0x0b, 0x30, 0x4d, 0x5f, 0x12,
		0x12, 0xbb, 0x55, 0xe9, 0x3c, 0x6c, 0x6e, 0xb6, 0xe8, 0x17, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a,
		0x48, 0x3d, 0xa4, 0x5e, 0xd3, 0xdf, 0xd1, 0x2f, 0x80, 0x4f, 0xdb, 0x91, 0x16, 0x8e, 0xf4, 0xc1,
		0xa7, 0x3d, 0xe5, 0xd3, 0xe8, 0x17, 0xc0, 0xa8, 0x61, 0xd4, 0xb9, 0x5c, 0x09, 0xfd, 0x02, 0x6f,
		0xf4, 0x0b, 0x34, 0x67, 0xc0, 0x4b, 0xb9, 0x90, 0x2f, 0x68, 0x4e, 0x77, 0xa4, 0x28, 0xea, 0x05,
		0x4f, 0x72, 0xec, 0xc7, 0xda, 0xfe, 0x9b, 0x23, 0xbf, 0x2d, 0xab, 0xa8, 0x52, 0xf8, 0xed, 0xa9,
		0xb2, 0x3e, 0x2a, 0xe7, 0x39, 0x32, 0xef, 0x2c, 0xe4, 0x8b, 0x5a, 0x3e, 0xe8, 0xb7, 0xef, 0x09,
		0xba, 0x9b, 0x97, 0x6e, 0x26, 0xe3, 0x5a, 0xee, 0x0d, 0x5f, 0xc0, 0xe8, 0xcb, 0xd9, 0xb7, 0xbf,
		0x1f, 0x5c, 0x8f, 0x7b, 0xe9, 0x6c, 0x3f, 0xa4, 0x4c, 0x3f, 0x2b, 0xf3, 0xdd, 0xbb, 0xaa, 0x90,
		0x4b, 0xcb, 0x4a, 0xf1, 0x88, 0xb7, 0x67, 0x34, 0xda, 0x30, 0x7a, 0xed, 0x16, 0xad, 0xb6, 0x8a,
		0x7a, 0xfb, 0x44, 0xbd, 0x4d, 0xa2, 0xda, 0x0e, 0xc9, 0x17, 0x88, 0x4b, 0x4b, 0xdd, 0x94, 0x57,
		0x72, 0x53, 0x71, 0x53, 0xbe, 0x35, 0x83, 0xa7, 0x95, 0x11, 0x2b, 0xe9, 0x97, 0xa9, 0xf5, 0xb6,
		0x35, 0x7b, 0xd9, 0xfa, 0xbd, 0x6b, 0xed, 0x5e, 0xb5, 0x59, 0x6f, 0xda, 0xac, 0x17, 0x6d, 0xd2,
		0x7b, 0xce, 0x77, 0x35, 0x43, 0x4b, 0x6f, 0xac, 0xdc, 0x59, 0xc4, 0x10, 0x65, 0x3d, 0x49, 0x55,
		0x2d, 0x54, 0x33, 0x41, 0xc9, 0x1d, 0x04, 0x25, 0xf3, 0x1f, 0xb0, 0xcd, 0x03, 0xb7, 0x79, 0x00,
		0x37, 0x0d, 0xe4, 0x3a, 0x01, 0x5d, 0x29, 0xb0, 0xab, 0x07, 0xf8, 0x6c, 0x41, 0x04, 0x25, 0x39,
		0x81, 0x5a, 0x2a, 0x3e, 0x38, 0x58, 0x83, 0x84, 0x37, 0x60, 0xe1, 0x0d, 0x68, 0x78, 0x01, 0x1e,
		0xba, 0x20, 0xa2, 0x0c, 0x26, 0xd9, 0x0e, 0x23, 0x28, 0x89, 0xa0, 0xa4, 0xe6, 0x83, 0x73, 0xfa,
		0x74, 0xf9, 0x31, 0x38, 0x7d, 0x6a, 0x1d, 0xfe, 0x56, 0x4d, 0x93, 0xd3, 0xa7, 0x6b, 0xa6, 0x89,
		0xa0, 0xa4, 0x75, 0x42, 0x60, 0xb7, 0x2a, 0x63, 0x9d, 0x9b, 0x9b, 0x2d, 0x82, 0x92, 0x59, 0xf5,
		0x02, 0x41, 0x49, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x2f, 0x2c, 0x95, 0x47, 0x50, 0xb2,
		0x10, 0x49, 0x0b, 0x82, 0x92, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0xa4, 0x0b, 0x92,
		0xfe, 0x8e, 0xa0, 0x24, 0x82, 0x92, 0x06, 0xa1, 0x05, 0x41, 0xc9, 0xe5, 0xc7, 0xa0, 0x05, 0x61,
		0x1d, 0x87, 0x57, 0x4d, 0x13, 0x41, 0x49, 0x4c, 0xd3, 0x97, 0x84, 0xc4, 0x6e, 0x55, 0x3a, 0x0f,
		0x9b, 0x9b, 0x2d, 0x82, 0x92, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0xd7, 0xf4,
		0x77, 0x04, 0x25, 0xe1, 0xd3, 0x76, 0xa4, 0x85, 0x23, 0x7d, 0xf0, 0x69, 0x4f, 0xf9, 0x34, 0x82,
		0x92, 0x30, 0x6a, 0x18, 0x75, 0x2e, 0x57, 0x42, 0x50, 0x52, 0x5f, 0x1c, 0xeb, 0x96, 0x50, 0xd1,
		0xaa, 0xa4, 0xa4, 0xea, 0x18, 0x78, 0xc9, 0x37, 0x09, 0xad, 0xfd, 0x93, 0xc5, 0xae, 0xac, 0xa8,
		0x4a, 0xce, 0x4b, 0x0c, 0x45, 0x91, 0x95, 0x54, 0x91, 0x1f, 0x0c, 0xd3, 0x48, 0x5f, 0xc4, 0x40,
		0x53, 0x10, 0xd5, 0x4c, 0xc3, 0xa0, 0x82, 0x86, 0x41, 0x71, 0xea, 0x59, 0x68, 0x18, 0xa0, 0x61,
		0xe0, 0x6c, 0x27, 0xd1, 0x30, 0x40, 0xc3, 0xa0, 0x78, 0xa0, 0x60, 0x0f, 0x0e, 0xd6, 0x20, 0xe1,
		0x0d, 0x58, 0x78, 0x03, 0x1a, 0x5e, 0x80, 0x87, 0x4d, 0xc1, 0x01, 0x0d, 0x03, 0xf5, 0xe8, 0x8e,
		0x86, 0x81, 0xe2, 0x83, 0xd3, 0xf0, 0x58, 0x7e, 0x0c, 0x1a, 0x1e, 0xd6, 0xe1, 0x6f, 0xd5, 0x34,
		0x69, 0x78, 0xac, 0x99, 0x26, 0x1a, 0x06, 0xd6, 0x09, 0x81, 0xdd, 0xaa, 0x9c, 0x24, 0xdc, 0xdc,
		0x6c, 0xd1, 0x30, 0xc8, 0xaa, 0x17, 0x68, 0x18, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c,
		0x61, 0xa9, 0x3c, 0x1a, 0x06, 0x85, 0x48, 0x5a, 0xd0, 0x30, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d,
		0x20, 0x5d, 0x20, 0x5d, 0x90, 0xf4, 0x77, 0x34, 0x0c, 0xd0, 0x30, 0x30, 0x08, 0x2d, 0x68, 0x18,
		0x2c, 0x3f, 0x06, 0x2d, 0x08, 0xeb, 0x38, 0xbc, 0x6a, 0x9a, 0x68, 0x18, 0x60, 0x9a, 0xbe, 0x24,
		0x24, 0x76, 0xab, 0xd2, 0x79, 0xd8, 0xdc, 0x6c, 0xd1, 0x30, 0x80, 0xd4, 0x43, 0xea, 0x21, 0xf5,
		0x90, 0x7a, 0x48, 0xbd, 0xa6, 0xbf, 0xa3, 0x61, 0x00, 0x9f, 0xb6, 0x23, 0x2d, 0x1c, 0xe9, 0x83,
		0x4f, 0x7b, 0xca, 0xa7, 0xd1, 0x30, 0x80, 0x51, 0xc3, 0xa8, 0x73, 0xb9, 0x12, 0x1a, 0x06, 0x1e,
		0x69, 0x18, 0x68, 0x4e, 0x81, 0x97, 0x72, 0x22, 0x61, 0xd0, 0x9c, 0xee, 0x49, 0x51, 0x14, 0x0c,
		0x9e, 0xe4, 0xd8, 0x97, 0xb5, 0x7d, 0x38, 0x57, 0xbe, 0x5b, 0x56, 0xd1, 0xa6, 0xf0, 0xdd, 0x5b,
		0x65, 0xfd, 0x54, 0xce, 0x7b, 0x64, 0xde, 0x59, 0xc8, 0x1f, 0xb5, 0xfc, 0xd0, 0x77, 0xff, 0x13,
		0x74, 0x39, 0x4f, 0x5d, 0x4d, 0xc6, 0xbd, 0xdc, 0x1b, 0xbf, 0x80, 0xe1, 0x97, 0x6f, 0x59, 0xc0,
		0x38, 0x99, 0xed, 0x86, 0x94, 0xf1, 0x67, 0x05, 0xbf, 0x7b, 0xd6, 0x14, 0x72, 0x69, 0x59, 0x49,
		0x1e, 0xf1, 0x36, 0x8d, 0x46, 0x3b, 0x46, 0xaf, 0xed, 0xa2, 0xd5, 0x5e, 0x51, 0x6f, 0xa3, 0xa8,
		0xb7, 0x4b, 0x54, 0xdb, 0x22, 0xf9, 0x02, 0x71, 0x69, 0xc9, 0x9b, 0xf2, 0x4a, 0x76, 0x2a, 0x6e,
		0xca, 0xb7, 0x66, 0xf1, 0xb4, 0x72, 0x62, 0x25, 0x1d, 0x33, 0xb5, 0x1e, 0xb7, 0x66, 0x4f, 0x5b,
		0xbf, 0x87, 0xad, 0xdd, 0xb3, 0x36, 0xeb, 0x51, 0x9b, 0xf5, 0xa4, 0x4d, 0x7a, 0xd0, 0xf9, 0xae,
		0x68, 0x68, 0xe9, 0x8e, 0x95, 0x3b, 0x8b, 0x18, 0xa2, 0xac, 0x2b, 0xa9, 0xaa, 0x8a, 0x6a, 0x26,
		0x2c, 0xb9, 0x83, 0xb0, 0x64, 0xfe, 0x03, 0xb6, 0x79, 0xe0, 0x36, 0x0f, 0xe0, 0xa6, 0x81, 0x5c,
		0x27, 0xa0, 0x2b, 0x05, 0x76, 0xf5, 0x00, 0x9f, 0x2d, 0x88, 0xb0, 0x24, 0x27, 0x51, 0x4b, 0xc5,
		0x07, 0x07, 0x6b, 0x90, 0xf0, 0x06, 0x2c, 0xbc, 0x01, 0x0d, 0x2f, 0xc0, 0x43, 0x17, 0x44, 0x94,
		0xc1, 0x24, 0xdb, 0x61, 0x84, 0x25, 0x11, 0x96, 0xd4, 0x7c, 0x70, 0x4e, 0xa1, 0x2e, 0x3f, 0x06,
		0xa7, 0x50, 0xad, 0xc3, 0xdf, 0xaa, 0x69, 0x72, 0x0a, 0x75, 0xcd, 0x34, 0x11, 0x96, 0xb4, 0x4e,
		0x08, 0xec, 0x56, 0x65, 0xbc, 0x73, 0x73, 0xb3, 0x45, 0x58, 0x32, 0xab, 0x5e, 0x20, 0x2c, 0x09,
		0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x85, 0xa5, 0xf2, 0x08, 0x4b, 0x16, 0x22, 0x69, 0x41,
		0x58, 0x92, 0x74, 0x81, 0x74, 0x81, 0x74, 0x81, 0x74, 0x81, 0x74, 0x41, 0xd2, 0xdf, 0x11, 0x96,
		0x44, 0x58, 0xd2, 0x20, 0xb4, 0x20, 0x2c, 0xb9, 0xfc, 0x18, 0xb4, 0x20, 0xac, 0xe3, 0xf0, 0xaa,
		0x69, 0x22, 0x2c, 0x89, 0x69, 0xfa, 0x92, 0x90, 0xd8, 0xad, 0x4a, 0xe7, 0x61, 0x73, 0xb3, 0x45,
		0x58, 0x12, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x9a, 0xfe, 0x8e, 0xb0, 0x24,
		0x7c, 0xda, 0x8e, 0xb4, 0x70, 0xa4, 0x0f, 0x3e, 0xed, 0x29, 0x9f, 0x46, 0x58, 0x12, 0x46, 0x0d,
		0xa3, 0xce, 0xe5, 0x4a, 0x08, 0x4b, 0x5a, 0x88, 0x63, 0xcd, 0x65, 0x8a, 0x56, 0x65, 0x25, 0x55,
		0x87, 0xc0, 0x4b, 0xde, 0xc9, 0x67, 0x5d, 0x24, 0xeb, 0xaa, 0x92, 0xf3, 0xf2, 0x42, 0x51, 0x64,
		0x25, 0x55, 0xc4, 0x07, 0xc3, 0x34, 0xd2, 0x17, 0x30, 0xd0, 0x94, 0x44, 0x35, 0xd3, 0x2f, 0xa8,
		0xa0, 0x5f, 0x50, 0x9c, 0x5a, 0x16, 0xfa, 0x05, 0xe8, 0x17, 0x38, 0xdb, 0x49, 0xf4, 0x0b, 0xd0,
		0x2f, 0x28, 0x1e, 0x28, 0xd8, 0x83, 0x83, 0x35, 0x48, 0x78, 0x03, 0x16, 0xde, 0x80, 0x86, 0x17,
		0xe0, 0x61, 0x53, 0x6c, 0x40, 0xbf, 0x40, 0x3d, 0xba, 0xa3, 0x5f, 0xa0, 0xf8, 0xe0, 0x34, 0x3b,
		0x96, 0x1f, 0x83, 0x66, 0x87, 0x75, 0xf8, 0x5b, 0x35, 0x4d, 0x9a, 0x1d, 0x6b, 0xa6, 0x89, 0x7e,
		0x81, 0x75, 0x42, 0x60, 0xb7, 0x2a, 0xa7, 0x08, 0x37, 0x37, 0x5b, 0xf4, 0x0b, 0xb2, 0xea, 0x05,
		0xfa, 0x05, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x58, 0x2a, 0x8f, 0x7e, 0x41, 0x21,
		0x92, 0x16, 0xf4, 0x0b, 0x48, 0x17, 0x48, 0x17, 0x48, 0x17, 0x48, 0x17, 0x48, 0x17, 0x24, 0xfd,
		0x1d, 0xfd, 0x02, 0xf4, 0x0b, 0x0c, 0x42, 0x0b, 0xfa, 0x05, 0xcb, 0x8f, 0x41, 0x0b, 0xc2, 0x3a,
		0x0e, 0xaf, 0x9a, 0x26, 0xfa, 0x05, 0x98, 0xa6, 0x2f, 0x09, 0x89, 0xdd, 0xaa, 0x74, 0x1e, 0x36,
		0x37, 0x5b, 0xf4, 0x0b, 0x20, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0xaf, 0xe9, 0xef,
		0xe8, 0x17, 0xc0, 0xa7, 0xed, 0x48, 0x0b, 0x47, 0xfa, 0xe0, 0xd3, 0x9e, 0xf2, 0x69, 0xf4, 0x0b,
		0x60, 0xd4, 0x30, 0xea, 0x5c, 0xae, 0x84, 0x7e, 0x81, 0x37, 0xfa, 0x05, 0x9a, 0x33, 0xe0, 0xa5,
		0x5c, 0xc8, 0x17, 0x34, 0xa7, 0x3b, 0x52, 0x14, 0xf5, 0x82, 0x27, 0x39, 0xf6, 0x63, 0x6d, 0xff,
		0xcd, 0x91, 0xdf, 0x96, 0x55, 0x54, 0x29, 0xfc, 0xf6, 0x54, 0x59, 0x1f, 0x95, 0xf3, 0x1c, 0x99,
		0x77, 0x16, 0xf2, 0x45, 0x2d, 0x1f, 0xf4, 0xdb, 0xf7, 0x04, 0xdd, 0xcd, 0x4b, 0x37, 0x93, 0x71,
		0x2d, 0xf7, 0x86, 0x2f, 0x60, 0xf4, 0xe5, 0xd1, 0x30, 0x8d, 0x82, 0x41, 0xbf, 0x17, 0x77, 0xbe,
		0x4c, 0x6c, 0xa0, 0x2a, 0x66, 0xf6, 0x4b, 0x1d, 0x9e, 0xbb, 0x2b, 0x0a, 0xb9, 0xb2, 0xac, 0x04,
		0x8f, 0x78, 0x5b, 0x46, 0xa3, 0xfd, 0xa2, 0xd7, 0x66, 0xd1, 0x6a, 0xa7, 0xa8, 0xb7, 0x4d, 0xd4,
		0xdb, 0x23, 0xaa, 0x6d, 0x90, 0x7c, 0x81, 0xb7, 0xb4, 0xc4, 0x4d, 0x79, 0x25, 0x27, 0x15, 0x37,
		0xe5, 0x5b, 0xb3, 0x77, 0x5a, 0x99, 0xb0, 0x92, 0x6e, 0x99, 0x5a, 0x4f, 0x5b, 0xb3, 0x87, 0xad,
		0xdf, 0xb3, 0xd6, 0xee, 0x51, 0x9b, 0xf5, 0xa4, 0xcd, 0x7a, 0xd0, 0x26, 0x3d, 0xe7, 0x7c, 0x57,
		0x31, 0xb4, 0x74, 0xc6, 0xca, 0x9d, 0x45, 0x0c, 0x51, 0xd6, 0x91, 0x54, 0xd5, 0x40, 0x35, 0x13,
		0x92, 0xdc, 0x41, 0x48, 0x32, 0xff, 0x01, 0xdb, 0x3c, 0x70, 0x9b, 0x07, 0x70, 0xd3, 0x40, 0xae,
		0x13, 0xd0, 0x95, 0x02, 0xbb, 0x7a, 0x80, 0xcf, 0x16, 0x44, 0x48, 0x92, 0x93, 0xa7, 0xa5, 0xe2,
		0x83, 0x83, 0x35, 0x48, 0x78, 0x03, 0x16, 0xde, 0x80, 0x86, 0x17, 0xe0, 0xa1, 0x0b, 0x22, 0xca,
		0x60, 0x92, 0xed, 0x30, 0x42, 0x92, 0x08, 0x49, 0x6a, 0x3e, 0x38, 0xa7, 0x4e, 0x97, 0x1f, 0x83,
		0x53, 0xa7, 0xd6, 0xe1, 0x6f, 0xd5, 0x34, 0x39, 0x75, 0xba, 0x66, 0x9a, 0x08, 0x49, 0x5a, 0x27,
		0x04, 0x76, 0xab, 0x32, 0xce, 0xb9, 0xb9, 0xd9, 0x22, 0x24, 0x99, 0x55, 0x2f, 0x10, 0x92, 0x84,
		0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xc2, 0x52, 0x79, 0x84, 0x24, 0x0b, 0x91, 0xb4, 0x20,
		0x24, 0x49, 0xba, 0x40, 0xba, 0x40, 0xba, 0x40, 0xba, 0x40, 0xba, 0x20, 0xe9, 0xef, 0x08, 0x49,
		0x22, 0x24, 0x69, 0x10, 0x5a, 0x10, 0x92, 0x5c, 0x7e, 0x0c, 0x5a, 0x10, 0xd6, 0x71, 0x78, 0xd5,
		0x34, 0x11, 0x92, 0xc4, 0x34, 0x7d, 0x49, 0x48, 0xec, 0x56, 0xa5, 0xf3, 0xb0, 0xb9, 0xd9, 0x22,
		0x24, 0x09, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x4d, 0x7f, 0x47, 0x48, 0x12,
		0x3e, 0x6d, 0x47, 0x5a, 0x38, 0xd2, 0x07, 0x9f, 0xf6, 0x94, 0x4f, 0x23, 0x24, 0x09, 0xa3, 0x86,
		0x51, 0xe7, 0x72, 0x25, 0x84, 0x24, 0xd5, 0x44, 0xb1, 0xee, 0x8a, 0x14, 0xad, 0xca, 0x48, 0xaa,
		0x8e, 0x80, 0x97, 0x7c, 0x91, 0xcd, 0x6a, 0x0e, 0xd3, 0xa8, 0x31, 0xdd, 0x92, 0xfa, 0xe0, 0x53,
		0x75, 0x45, 0x45, 0x72, 0x5e, 0x5a, 0x28, 0x8a, 0x8c, 0xa4, 0x8a, 0xdc, 0x60, 0x98, 0x46, 0xfa,
		0xe2, 0x05, 0x9a, 0x02, 0xa8, 0x66, 0xda, 0x05, 0x15, 0xb4, 0x0b, 0x8a, 0x53, 0xc7, 0x42, 0xbb,
		0x00, 0xed, 0x02, 0x67, 0x3b, 0x89, 0x76, 0x01, 0xda, 0x05, 0xc5, 0x03, 0x05, 0x7b, 0x70, 0xb0,
		0x06, 0x09, 0x6f, 0xc0, 0xc2, 0x1b, 0xd0, 0xf0, 0x02, 0x3c, 0x6c, 0x0a, 0x0d, 0x68, 0x17, 0xa8,
		0x47, 0x77, 0xb4, 0x0b, 0x14, 0x1f, 0x9c, 0x46, 0xc7, 0xf2, 0x63, 0xd0, 0xe8, 0xb0, 0x0e, 0x7f,
		0xab, 0xa6, 0x49, 0xa3, 0x63, 0xcd, 0x34, 0xd1, 0x2e, 0xb0, 0x4e, 0x08, 0xec, 0x56, 0xe5, 0x04,
		0xe1, 0xe6, 0x66, 0x8b, 0x76, 0x41, 0x56, 0xbd, 0x40, 0xbb, 0x00, 0x2a, 0x0f, 0x95, 0x87, 0xca,
		0x43, 0xe5, 0x0b, 0x4b, 0xe5, 0xd1, 0x2e, 0x28, 0x44, 0xd2, 0x82, 0x76, 0x01, 0xe9, 0x02, 0xe9,
		0x02, 0xe9, 0x02, 0xe9, 0x02, 0xe9, 0x82, 0xa4, 0xbf, 0xa3, 0x5d, 0x80, 0x76, 0x81, 0x41, 0x68,
		0x41, 0xbb, 0x60, 0xf9, 0x31, 0x68, 0x41, 0x58, 0xc7, 0xe1, 0x55, 0xd3, 0x44, 0xbb, 0x00, 0xd3,
		0xf4, 0x25, 0x21, 0xb1, 0x5b, 0x95, 0xce, 0xc3, 0xe6, 0x66, 0x8b, 0x76, 0x01, 0xa4, 0x1e, 0x52,
		0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x35, 0xfd, 0x1d, 0xed, 0x02, 0xf8, 0xb4, 0x1d, 0x69, 0xe1,
		0x48, 0x1f, 0x7c, 0xda, 0x53, 0x3e, 0x8d, 0x76, 0x01, 0x8c, 0x1a, 0x46, 0x9d, 0xcb, 0x95, 0xd0,
		0x2e, 0xf0, 0x44, 0xbb, 0x40, 0x73, 0x02, 0xbc, 0x94, 0x03, 0xe9, 0x82, 0xe6, 0x74, 0x3f, 0x8a,
		0xa2, 0x5c, 0xf0, 0x24, 0xc7, 0x3e, 0xac, 0xed, 0xbb, 0xb9, 0xf1, 0xd9, 0xb2, 0x8a, 0x1e, 0x85,
		0xcf, 0x5e, 0x2a, 0xeb, 0x9f, 0x72, 0x5e, 0x23, 0xf3, 0xce, 0x42, 0x7e, 0xa8, 0xe5, 0x7f, 0x3e,
		0xfb, 0x9d, 0xa0, 0xab, 0x79, 0xe8, 0x62, 0x32, 0x6e, 0xe5, 0xde, 0xe8, 0x05, 0x0c, 0xbe, 0x7c,
		0xe7, 0x9b, 0xdf, 0x17, 0x33, 0xf9, 0xa5, 0xf6, 0xce, 0xdd, 0x15, 0x85, 0xdc, 0x58, 0x56, 0x76,
		0x47, 0xbc, 0x15, 0xa3, 0xd1, 0x72, 0xd1, 0x6b, 0xad, 0x68, 0xb5, 0x50, 0xd4, 0x5b, 0x25, 0xea,
		0x2d, 0x11, 0xd5, 0xd6, 0x47, 0xbe, 0x80, 0x5b, 0x5a, 0xd6, 0xa6, 0xbc, 0x92, 0x8d, 0x8a, 0x9b,
		0xf2, 0xad, 0x79, 0x3b, 0xad, 0x1c, 0x58, 0x49, 0xab, 0x4c, 0xad, 0x8f, 0xad, 0xd9, 0xb7, 0xd6,
		0xef, 0x53, 0x6b, 0xf7, 0xa5, 0xcd, 0xfa, 0xd0, 0x66, 0x7d, 0x67, 0x93, 0x3e, 0x73, 0xbe, 0xab,
		0x17, 0x5a, 0xda, 0x62, 0xe5, 0xce, 0x22, 0x86, 0x28, 0x6b, 0x47, 0xaa, 0xaa, 0x9e, 0x9a, 0x89,
		0x47, 0xee, 0x20, 0x1e, 0x99, 0xff, 0x80, 0x6d, 0x1e, 0xb8, 0xcd, 0x03, 0xb8, 0x69, 0x20, 0xd7,
		0x09, 0xe8, 0x4a, 0x81, 0x5d, 0x3d, 0xc0, 0x67, 0x0b, 0x22, 0x1e, 0xc9, 0x69, 0xd3, 0x52, 0xf1,
		0xc1, 0xc1, 0x1a, 0x24, 0xbc, 0x01, 0x0b, 0x6f, 0x40, 0xc3, 0x0b, 0xf0, 0xd0, 0x05, 0x11, 0x65,
		0x30, 0xc9, 0x76, 0x18, 0xf1, 0x48, 0xc4, 0x23, 0x35, 0x1f, 0x9c, 0x93, 0xa6, 0xcb, 0x8f, 0xc1,
		0x49, 0x53, 0xeb, 0xf0, 0xb7, 0x6a, 0x9a, 0x9c, 0x34, 0x5d, 0x33, 0x4d, 0xc4, 0x23, 0xad, 0x13,
		0x02, 0xbb, 0x55, 0x19, 0xe1, 0xdc, 0xdc, 0x6c, 0x11, 0x8f, 0xcc, 0xaa, 0x17, 0x88, 0x47, 0x42,
		0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x61, 0xa9, 0x3c, 0xe2, 0x91, 0x85, 0x48, 0x5a, 0x10,
		0x8f, 0x24, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x20, 0x5d, 0x90, 0xf4, 0x77, 0xc4, 0x23,
		0x11, 0x8f, 0x34, 0x08, 0x2d, 0x88, 0x47, 0x2e, 0x3f, 0x06, 0x2d, 0x08, 0xeb, 0x38, 0xbc, 0x6a,
		0x9a, 0x88, 0x47, 0x62, 0x9a, 0xbe, 0x24, 0x24, 0x76, 0xab, 0xd2, 0x79, 0xd8, 0xdc, 0x6c, 0x11,
		0x8f, 0x84, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa6, 0xbf, 0x23, 0x1e, 0x09,
		0x9f, 0xb6, 0x23, 0x2d, 0x1c, 0xe9, 0x83, 0x4f, 0x7b, 0xca, 0xa7, 0x11, 0x8f, 0x84, 0x51, 0xc3,
		0xa8, 0x73, 0xb9, 0x12, 0xe2, 0x91, 0x56, 0x82, 0x58, 0xfb, 0xab, 0xe2, 0x91, 0xaa, 0x23, 0xe0,
		0x25, 0x2f, 0x45, 0xb3, 0xf6, 0x57, 0xd4, 0x23, 0xe7, 0xa5, 0x85, 0xa2, 0xc8, 0x47, 0xaa, 0x08,
		0x0d, 0x86, 0x69, 0xa4, 0x2f, 0x5e, 0xa0, 0x29, 0x7b, 0x6a, 0xa6, 0x5d, 0x50, 0x41, 0xbb, 0xa0,
		0x38, 0x75, 0x2c, 0xb4, 0x0b, 0xd0, 0x2e, 0x70, 0xb6, 0x93, 0x68, 0x17, 0xa0, 0x5d, 0x50, 0x3c,
		0x50, 0xb0, 0x07, 0x07, 0x6b, 0x90, 0xf0, 0x06, 0x2c, 0xbc, 0x01, 0x0d, 0x2f, 0xc0, 0xc3, 0xa6,
		0xd0, 0x80, 0x76, 0x81, 0x7a, 0x74, 0x47, 0xbb, 0x40, 0xf1, 0xc1, 0x69, 0x74, 0x2c, 0x3f, 0x06,
		0x8d, 0x0e, 0xeb, 0xf0, 0xb7, 0x6a, 0x9a, 0x34, 0x3a, 0xd6, 0x4c, 0x13, 0xed, 0x02, 0xeb, 0x84,
		0xc0, 0x6e, 0x55, 0x4e, 0x10, 0x6e, 0x6e, 0xb6, 0x68, 0x17, 0x64, 0xd5, 0x0b, 0xb4, 0x0b, 0xa0,
		0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb0, 0x54, 0x1e, 0xed, 0x82, 0x42, 0x24, 0x2d, 0x68,
		0x17, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x90, 0x2e, 0x48, 0xfa, 0x3b, 0xda, 0x05,
		0x68, 0x17, 0x18, 0x84, 0x16, 0xb4, 0x0b, 0x96, 0x1f, 0x83, 0x16, 0x84, 0x75, 0x1c, 0x5e, 0x35,
		0x4d, 0xb4, 0x0b, 0x30, 0x4d, 0x5f, 0x12, 0x12, 0xbb, 0x55, 0xe9, 0x3c, 0x6c, 0x6e, 0xb6, 0x68,
		0x17, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xd3, 0xdf, 0xd1, 0x2e, 0x80,
		0x4f, 0xdb, 0x91, 0x16, 0x8e, 0xf4, 0xc1, 0xa7, 0x3d, 0xe5, 0xd3, 0x68, 0x17, 0xc0, 0xa8, 0x61,
		0xd4, 0xb9, 0x5c, 0x09, 0xed, 0x02, 0x4f, 0xb4, 0x0b, 0x34, 0x27, 0xc0, 0x4b, 0x39, 0x90, 0x2e,
		0x68, 0x4e, 0xf7, 0xa3, 0x28, 0xca, 0x05, 0x4f, 0x72, 0xec, 0xc3, 0xda, 0xbe, 0x9b, 0x1b, 0x9f,
		0x2d, 0xab, 0xe8, 0x51, 0xf8, 0xec, 0xa5, 0xb2, 0xfe, 0x29, 0xe7, 0x35, 0x32, 0xef, 0x2c, 0xe4,
		0x87, 0x5a, 0xfe, 0xe7, 0xb3, 0xdf, 0x09, 0xba, 0x9a, 0x87, 0x2e, 0x26, 0xe3, 0x56, 0xee, 0x8d,
		0x5e, 0xc0, 0xe0, 0x85, 0x05, 0x78, 0x54, 0x04, 0x77, 0x84, 0x05, 0x76, 0xc4, 0x05, 0x75, 0x34,
		0x9a, 0x2b, 0x7a, 0x4d, 0x14, 0xad, 0x66, 0x89, 0x7a, 0x53, 0x44, 0xbd, 0xf9, 0xa1, 0xda, 0xe4,
		0xc8, 0x17, 0x44, 0x4b, 0x0b, 0xd8, 0x94, 0xc3, 0x4e, 0x1a, 0x7f, 0x52, 0x30, 0xe2, 0x85, 0x5b,
		0xce, 0xd7, 0x13, 0x36, 0x28, 0x9d, 0xfa, 0xa1, 0x5a, 0x97, 0x5a, 0xb3, 0x2b, 0xad, 0xdf, 0x85,
		0xd6, 0xee, 0x3a, 0x9b, 0x75, 0x99, 0xcd, 0xba, 0xca, 0x26, 0x5d, 0xe4, 0x7c, 0xd7, 0x26, 0xd4,
		0xba, 0xc2, 0x06, 0x93, 0x60, 0x4a, 0x93, 0x5f, 0x82, 0x34, 0x5b, 0x30, 0xab, 0x5b, 0x50, 0xc5,
		0x60, 0x4e, 0xdc, 0xb4, 0x70, 0x71, 0x65, 0x59, 0xe0, 0x11, 0x78, 0x04, 0x1e, 0x81, 0x47, 0xe0,
		0x31, 0xf3, 0xb7, 0xb8, 0x1b, 0x25, 0x69, 0x9c, 0x7e, 0x19, 0x46, 0x1f, 0x34, 0x21, 0x52, 0xe1,
		0x58, 0x54, 0xb9, 0x3e, 0x7f, 0xb4, 0x17, 0xe1, 0xc8, 0x40, 0x22, 0xfa, 0xf0, 0x55, 0xbd, 0xdd,
		0x9c, 0xfc, 0xbf, 0xd6, 0x5f, 0x8d, 0x9a, 0x96, 0xab, 0x4f, 0x4f, 0x56, 0x8c, 0x54, 0x8f, 0x7e,
		0x19, 0x9d, 0xe2, 0x6e, 0x9e, 0xb7, 0x6a, 0xed, 0xc6, 0xd9, 0x71, 0xfd, 0xe8, 0xaf, 0x76, 0xbd,
		0xf1, 0x76, 0xbf, 0x5c, 0xc4, 0xa3, 0xf3, 0x46, 0x7b, 0x7b, 0xfc, 0xec, 0x6d, 0xe3, 0x74, 0xb2,
		0xab, 0xd5, 0xf6, 0xc5, 0x69, 0xfd, 0xe8, 0xb0, 0xd9, 0x62, 0x77, 0x1d, 0xee, 0x6e, 0xfd, 0xf4,
		0x5f, 0xcd, 0xd6, 0x61, 0xab, 0xd6, 0x6e, 0x36, 0x5e, 0xb1, 0xb1, 0x22, 0x66, 0x7b, 0x72, 0x71,
		0xdc, 0xc2, 0x70, 0x1d, 0xef, 0xef, 0xdb, 0xc6, 0xe9, 0xdb, 0x6a, 0xfb, 0xd5, 0xf1, 0xd9, 0x1f,
		0xcd, 0x46, 0xed, 0x88, 0x9d, 0x15, 0x03, 0xb3, 0x2a, 0x7b, 0xeb, 0x30, 0x2a, 0x54, 0x26, 0x51,
		0xe1, 0x6d, 0xe3, 0xb8, 0xc9, 0xae, 0xba, 0xde, 0xd5, 0xda, 0xdb, 0xc6, 0x29, 0xbb, 0x2a, 0x90,
		0x1a, 0xb0, 0xa9, 0xee, 0x36, 0x75, 0x9a, 0x10, 0x1c, 0x1f, 0xbe, 0xa8, 0x1d, 0xd7, 0x5e, 0x92,
		0xcf, 0x4a, 0xe6, 0xb3, 0x44, 0x03, 0x99, 0x7c, 0x76, 0x9f, 0x7c, 0x56, 0x2c, 0x30, 0x90, 0xce,
		0x8a, 0x6c, 0xec, 0x3e, 0x11, 0x57, 0x25, 0x30, 0xb0, 0xbb, 0x32, 0x61, 0x81, 0x7d, 0x95, 0x89,
		0x0a, 0xfa, 0xfb, 0xaa, 0xb2, 0xd2, 0x65, 0xde, 0xfb, 0x5a, 0xb9, 0x3c, 0x53, 0x10, 0x25, 0xe1,
		0xfb, 0x5e, 0xd4, 0xd5, 0x3b, 0x4d, 0xb0, 0x58, 0x50, 0xb8, 0x0b, 0xa8, 0x2c, 0x50, 0xcf, 0xb9,
		0x05, 0x07, 0xa6, 0xc1, 0xb9, 0x05, 0xe7, 0x0b, 0x73, 0x6e, 0x21, 0x2f, 0xd9, 0x05, 0xc7, 0xfa,
		0xb6, 0x15, 0x82, 0xd5, 0x2e, 0x65, 0xbd, 0x7d, 0x7b, 0x8c, 0xc6, 0x05, 0xac, 0x4a, 0xb7, 0x6e,
		0x03, 0x8a, 0x80, 0x22, 0xa0, 0x58, 0x4c, 0x50, 0xd4, 0xba, 0x25, 0xbb, 0x3c, 0x9d, 0xe1, 0xed,
		0x69, 0x30, 0xa1, 0x35, 0x0f, 0x5f, 0x2e, 0xad, 0x64, 0x86, 0xba, 0x12, 0x46, 0xea, 0x82, 0x99,
		0x16, 0x42, 0x99, 0x76, 0x02, 0x99, 0x56, 0xc2, 0x98, 0xe6, 0x82, 0x98, 0xe6, 0x42, 0x98, 0xa6,
		0x02, 0x98, 0xc5, 0x92, 0x4a, 0x52, 0x17, 0xba, 0xb4, 0xbb, 0xaf, 0xda, 0xe0, 0x9e, 0x6a, 0x23,
		0x31, 0x4b, 0x03, 0xd9, 0x52, 0x4b, 0xf1, 0x4a, 0x63, 0x65, 0x40, 0x6b, 0xb1, 0x4a, 0x1f, 0x74,
		0x00, 0x0d, 0xc4, 0x29, 0x4d, 0x45, 0x29, 0x7d, 0x31, 0x39, 0xeb, 0x7b, 0xa5, 0xbd, 0xb0, 0xbd,
		0x82, 0x6a, 0x32, 0x5e, 0x16, 0x45, 0x8f, 0x4e, 0xa1, 0x82, 0x32, 0x8c, 0x3a, 0x51, 0xfc, 0xc9,
		0x82, 0x43, 0x66, 0x2b, 0x43, 0x21, 0xa1, 0x90, 0x50, 0x48, 0x28, 0x24, 0x14, 0x12, 0x0a, 0x09,
		0x85, 0x84, 0x42, 0x42, 0x21, 0xa1, 0x90, 0x50, 0x48, 0x28, 0x24, 0x14, 0x32, 0x5f, 0x14, 0x32,
		0x18, 0x0c, 0x17, 0x6a, 0xc0, 0x76, 0x6c, 0xf2, 0xf6, 0x87, 0x80, 0x58, 0x42, 0x2c, 0x21, 0x96,
		0x10, 0x4b, 0x88, 0x25, 0xc4, 0x12, 0x62, 0x09, 0xb1, 0x84, 0x58, 0x42, 0x2c, 0x21, 0x96, 0x10,
		0x4b, 0x88, 0x65, 0x3e, 0x88, 0xe5, 0x68, 0x96, 0x0c, 0x2a, 0x33, 0xc9, 0xe9, 0xaa, 0x50, 0x47,
		0xa8, 0x23, 0xd4, 0x11, 0xea, 0x08, 0x75, 0x84, 0x3a, 0x42, 0x1d, 0xa1, 0x8e, 0x50, 0x47, 0xa8,
		0x23, 0xd4, 0x11, 0xea, 0x08, 0x75, 0xf4, 0x7d, 0x05, 0xae, 0x59, 0x96, 0xbb, 0xee, 0x35, 0x0d,
		0xd3, 0xe8, 0xa9, 0xd2, 0x24, 0x7e, 0xc9, 0x9b, 0x4b, 0x5f, 0x27, 0x4f, 0x3d, 0xbf, 0x4e, 0x39,
		0x1a, 0x71, 0x97, 0xb2, 0x82, 0xb3, 0x6d, 0xe5, 0x5d, 0xca, 0x82, 0x57, 0xdd, 0xfa, 0xe5, 0x4b,
		0xdb, 0x7c, 0x6f, 0xf2, 0x78, 0x14, 0x05, 0xd7, 0xe3, 0x5e, 0x1a, 0x0f, 0x7a, 0x51, 0x30, 0xb1,
		0xbb, 0x91, 0xfc, 0x25, 0xca, 0xf7, 0xac, 0x99, 0xf3, 0x1b, 0x95, 0x77, 0xb8, 0x51, 0xf9, 0x11,
		0x2b, 0x71, 0xa3, 0x72, 0x1e, 0xcb, 0x8b, 0xdc, 0xa8, 0xbc, 0xb2, 0x40, 0x67, 0xe1, 0xf3, 0x4a,
		0x3a, 0x53, 0xf3, 0xf5, 0x50, 0x99, 0xf2, 0x2d, 0x70, 0xea, 0x07, 0x50, 0xed, 0x40, 0x6a, 0x16,
		0x50, 0xcd, 0x02, 0xab, 0x49, 0x80, 0x2d, 0x46, 0x19, 0x42, 0x4d, 0x65, 0x4a, 0x4b, 0x6d, 0x77,
		0xcd, 0xbf, 0x75, 0x54, 0x77, 0x97, 0x1b, 0xaa, 0xab, 0xbe, 0x7b, 0x17, 0x0a, 0x38, 0x02, 0x90,
		0x67, 0x88, 0xb0, 0x82, 0x0a, 0x73, 0xc8, 0x30, 0x87, 0x0e, 0x53, 0x08, 0xd1, 0x81, 0x12, 0x25,
		0x48, 0xc9, 0x76, 0xd2, 0xee, 0x08, 0x80, 0x9e, 0xba, 0xef, 0x5a, 0x26, 0xbe, 0x4b, 0x73, 0xc5,
		0x83, 0xac, 0x66, 0x8b, 0x9b, 0x2b, 0xeb, 0x55, 0xba, 0xa7, 0x2a, 0x5c, 0xb4, 0xe4, 0x4b, 0x6d,
		0xf8, 0x62, 0x14, 0x9d, 0xcc, 0x9f, 0xbf, 0x31, 0x79, 0xfc, 0xf6, 0x3c, 0x55, 0x41, 0x7e, 0x7b,
		0x3d, 0x27, 0x9f, 0xa0, 0x9b, 0xde, 0xf5, 0x17, 0xf2, 0x39, 0x14, 0x05, 0x11, 0x0a, 0x22, 0x14,
		0x44, 0x28, 0x88, 0xe4, 0xa1, 0x20, 0xa2, 0x54, 0x91, 0x5e, 0x73, 0x6f, 0xb5, 0x6c, 0x40, 0x31,
		0x20, 0x53, 0x96, 0xa0, 0x2c, 0x41, 0x59, 0x82, 0xb2, 0x84, 0x4f, 0x01, 0x3e, 0x5b, 0x30, 0xec,
		0xf5, 0xfa, 0x7f, 0x2f, 0x39, 0x59, 0x38, 0xd2, 0xf7, 0x9f, 0x45, 0xc4, 0x58, 0xff, 0x28, 0xca,
		0x66, 0x6c, 0x54, 0x1d, 0xbf, 0x0b, 0x47, 0xca, 0xc7, 0xab, 0xd5, 0x61, 0xc9, 0x12, 0x9e, 0xec,
		0x61, 0xca, 0x1a, 0xae, 0xbc, 0x81, 0x2d, 0x6f, 0xe0, 0xcb, 0x0b, 0x18, 0xd3, 0x85, 0x33, 0x65,
		0x58, 0xcb, 0x76, 0x58, 0xbd, 0xea, 0xbe, 0xe6, 0xef, 0xfa, 0xd5, 0xf7, 0x35, 0xb6, 0xb1, 0x5b,
		0xd0, 0xd1, 0x8d, 0x62, 0x65, 0x62, 0xca, 0x55, 0xfa, 0x6c, 0x5d, 0xbf, 0xab, 0xf5, 0xd1, 0xe4,
		0xb7, 0x55, 0x49, 0x7a, 0xc9, 0xdb, 0xd2, 0x7d, 0xed, 0xfd, 0xd5, 0x40, 0xa5, 0x7e, 0xaf, 0xe7,
		0x60, 0x2a, 0x82, 0x17, 0xd3, 0xe3, 0xf1, 0xfa, 0x8a, 0x17, 0xc2, 0xa3, 0x07, 0x5e, 0x14, 0x96,
		0x2a, 0x14, 0x96, 0x28, 0x2c, 0x51, 0x58, 0x22, 0x9d, 0xa1, 0xb0, 0x44, 0x61, 0x89, 0xc2, 0x12,
		0x85, 0x25, 0x0a, 0x4b, 0x14, 0x96, 0x28, 0x2c, 0x51, 0x58, 0xa2, 0xb0, 0x44, 0x61, 0xc9, 0xff,
		0xc2, 0x92, 0x26, 0x47, 0xf7, 0xbc, 0xae, 0x24, 0x28, 0x22, 0x60, 0x50, 0x56, 0xe2, 0xbc, 0x76,
		0xa1, 0x1c, 0x75, 0x6b, 0x4f, 0x6b, 0xd7, 0xc4, 0x53, 0xb7, 0x7c, 0x9e, 0xd5, 0xd6, 0xa9, 0xe9,
		0xaa, 0xd6, 0x72, 0xd5, 0x4f, 0x6b, 0x57, 0x38, 0xad, 0x9d, 0x1f, 0xd2, 0xcb, 0x69, 0x6d, 0x4e,
		0x6b, 0x7f, 0xbb, 0xec, 0xc7, 0xf8, 0xba, 0xe3, 0x0d, 0x65, 0x7c, 0x3d, 0xef, 0xd0, 0x60, 0x07,
		0x11, 0x56, 0x50, 0x61, 0x0e, 0x19, 0xe6, 0xd0, 0x61, 0x0a, 0x21, 0xc5, 0x2c, 0x22, 0x31, 0xbe,
		0x4e, 0x39, 0x84, 0x72, 0x88, 0x07, 0xe5, 0x10, 0xad, 0x92, 0xa5, 0x9f, 0xf5, 0x10, 0x85, 0x2a,
		0x25, 0x6a, 0xc1, 0xaa, 0x6e, 0xe7, 0xb7, 0xbb, 0x15, 0x5d, 0x3a, 0xf8, 0xae, 0x83, 0xe5, 0x46,
		0x45, 0xf8, 0x89, 0xc7, 0x2e, 0x34, 0x49, 0xbc, 0xa7, 0xc7, 0x80, 0xe6, 0x76, 0x15, 0x4c, 0xbf,
		0x63, 0xc7, 0x6b, 0x1c, 0xc7, 0xa3, 0xf4, 0x30, 0x4d, 0x65, 0x08, 0x7f, 0xf9, 0x24, 0x4e, 0x6a,
		0xbd, 0x68, 0x92, 0x3a, 0x8f, 0x64, 0x68, 0x61, 0xf9, 0x24, 0xfc, 0x7c, 0x6b, 0x85, 0xdd, 0xdf,
		0xaa, 0xd5, 0xfd, 0x83, 0x6a, 0x75, 0xe7, 0xe0, 0xd9, 0xc1, 0xce, 0xf3, 0xbd, 0xbd, 0xdd, 0xfd,
		0x5d, 0x81, 0xbb, 0x36, 0xca, 0x67, 0xc3, 0x6e, 0x34, 0x8c, 0xba, 0x2f, 0x26, 0x5f, 0x4f, 0x32,
		0xee, 0xf5, 0xbc, 0xb6, 0x22, 0xe1, 0x00, 0xec, 0x51, 0xe0, 0x15, 0x88, 0xb2, 0x3e, 0x44, 0x57,
		0xb7, 0xc1, 0xd4, 0x5d, 0xc8, 0x73, 0xf3, 0x4e, 0x8e, 0xcc, 0x5d, 0xca, 0xcc, 0xed, 0xcd, 0xdb,
		0xa1, 0x55, 0x5b, 0x5a, 0xb3, 0x1b, 0x2b, 0xde, 0xdc, 0xe6, 0x1c, 0xd8, 0x5b, 0x39, 0x1c, 0x0c,
		0x7a, 0x5f, 0x82, 0x41, 0xbf, 0x17, 0x77, 0xbe, 0x38, 0xb3, 0xb6, 0xe5, 0xb1, 0xdf, 0xdb, 0xef,
		0xee, 0xc8, 0x3b, 0xdc, 0x36, 0x05, 0x9d, 0x57, 0x7a, 0x25, 0x2a, 0xb9, 0xb7, 0x2b, 0xb5, 0xc3,
		0x41, 0xbf, 0xe7, 0xd2, 0x8f, 0x84, 0x4a, 0xb1, 0xe2, 0xa5, 0x56, 0xf1, 0x52, 0xea, 0xdd, 0x52,
		0xe9, 0x74, 0xe3, 0x0b, 0x8a, 0x38, 0xae, 0xdb, 0x64, 0x52, 0xe2, 0x45, 0xb2, 0x22, 0x45, 0x42,
		0xe7, 0x0d, 0xc4, 0x9a, 0x49, 0x92, 0x4d, 0x23, 0xc1, 0x90, 0x23, 0x1d, 0x7a, 0xd4, 0x42, 0x90,
		0x5a, 0x28, 0xd2, 0x09, 0x49, 0xf9, 0xa8, 0x24, 0x48, 0x75, 0xf4, 0xcb, 0xdd, 0x59, 0x67, 0x3b,
		0x88, 0x3e, 0x0f, 0xfa, 0xc3, 0xd4, 0x75, 0x4a, 0xf4, 0xa0, 0x7f, 0xdd, 0xbf, 0xac, 0xd4, 0x35,
		0x2a, 0xcb, 0xee, 0xfd, 0x79, 0xed, 0xbf, 0x6b, 0x47, 0xad, 0xf6, 0xf9, 0xd9, 0x45, 0xab, 0x26,
		0x7c, 0x4f, 0xd3, 0x0e, 0xf7, 0x34, 0x59, 0xc6, 0x59, 0xad, 0x78, 0xab, 0x1e, 0x77, 0xd5, 0xe3,
		0xaf, 0x6e, 0x1c, 0x96, 0x89, 0xc7, 0x42, 0x71, 0x39, 0xdb, 0x1a, 0xf1, 0xb6, 0xf8, 0x5a, 0xe4,
		0x9c, 0x85, 0xcc, 0x20, 0x9d, 0x2c, 0x2c, 0xe8, 0x3d, 0x8b, 0xe4, 0xb0, 0x2a, 0xb8, 0x46, 0x2d,
		0x19, 0x5f, 0x4f, 0x36, 0xef, 0x66, 0x8b, 0xaf, 0x2e, 0x5c, 0x7c, 0xad, 0xf1, 0xb5, 0x09, 0x0e,
		0xaf, 0x2e, 0x0b, 0x0e, 0x83, 0xc3, 0xe0, 0x30, 0x38, 0x0c, 0x0e, 0x83, 0xc3, 0x5b, 0x86, 0xc3,
		0xca, 0x3c, 0x58, 0x85, 0xff, 0x02, 0x84, 0x00, 0x21, 0x40, 0x08, 0x10, 0xca, 0x78, 0x4c, 0x2f,
		0x0a, 0x3f, 0x0c, 0xa3, 0x0f, 0x1a, 0xe0, 0x77, 0x20, 0xb8, 0x46, 0x23, 0x3b, 0x20, 0x30, 0x33,
		0xa4, 0xdf, 0x87, 0xfd, 0x71, 0x1a, 0x27, 0x57, 0xf3, 0xd8, 0x9c, 0xfd, 0xf1, 0x1c, 0xef, 0xbb,
		0xd1, 0x87, 0x38, 0x89, 0xd3, 0xb8, 0x9f, 0x8c, 0x1e, 0xfe, 0xab, 0xec, 0x6f, 0xa6, 0x0d, 0xfb,
		0x5c, 0xd9, 0x8f, 0xe8, 0xb1, 0xb2, 0x6c, 0x15, 0xf1, 0xe3, 0x65, 0xcb, 0x95, 0x0c, 0x8e, 0x99,
		0x65, 0x8b, 0xdf, 0x3e, 0x6e, 0xa6, 0x34, 0xa9, 0x3c, 0x1e, 0x45, 0x43, 0xe9, 0x78, 0xaf, 0x38,
		0xcf, 0x74, 0x1b, 0xcc, 0xfa, 0xb3, 0xdd, 0x0c, 0xde, 0x7f, 0xd1, 0x38, 0xfe, 0x6e, 0x31, 0xbb,
		0xb4, 0x02, 0x6c, 0xd3, 0x6f, 0x92, 0x93, 0xee, 0xb9, 0x63, 0x12, 0xca, 0x95, 0x3c, 0x95, 0x0a,
		0x1e, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98, 0x04,
		0x4c, 0x02, 0x26, 0x01, 0x93, 0x90, 0x7b, 0x47, 0x46, 0xc9, 0x1e, 0x39, 0x6b, 0x73, 0x6b, 0xe2,
		0x42, 0xee, 0x96, 0x18, 0x93, 0xe9, 0x9b, 0xc9, 0x93, 0x35, 0xa6, 0x0f, 0x26, 0x72, 0xe5, 0x8b,
		0xc3, 0x69, 0x32, 0xa7, 0x63, 0x4e, 0x12, 0xb2, 0x7e, 0xa2, 0x32, 0x7e, 0xe2, 0xc7, 0xe8, 0x2b,
		0x1c, 0xa3, 0x57, 0x4c, 0x19, 0x38, 0x46, 0x5f, 0x44, 0xfc, 0xe3, 0x18, 0xfd, 0x26, 0x9b, 0xc7,
		0xf1, 0x3d, 0x6a, 0x8d, 0xd4, 0x1a, 0xa9, 0x35, 0x72, 0x7c, 0xef, 0x87, 0x93, 0x43, 0x8e, 0xef,
		0x89, 0x1a, 0x11, 0xc7, 0xe8, 0xc1, 0x61, 0x70, 0x18, 0x1c, 0x06, 0x87, 0xc1, 0x61, 0x70, 0xd8,
		0x10, 0x87, 0x39, 0x46, 0x0f, 0x10, 0x02, 0x84, 0x00, 0x21, 0x40, 0xf8, 0x58, 0x8f, 0xe1, 0xf0,
		0x0b, 0x87, 0x5f, 0x7e, 0x74, 0x15, 0x0e, 0xbf, 0x48, 0x79, 0x25, 0x87, 0x5f, 0x72, 0x0a, 0x6a,
		0x25, 0x0e, 0xbf, 0x14, 0x83, 0x49, 0x70, 0x8c, 0x1e, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24,
		0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x28, 0x3c, 0x93, 0xe0, 0x18,
		0xbd, 0xf5, 0x31, 0x7a, 0xa9, 0x0b, 0xe6, 0xac, 0x4f, 0xd1, 0x0b, 0x5c, 0x1d, 0xc7, 0x95, 0x2c,
		0xf9, 0xb3, 0xef, 0xbc, 0xdf, 0xca, 0xb2, 0xb4, 0xe8, 0x42, 0x5d, 0xcc, 0x32, 0x9a, 0xde, 0xb7,
		0x17, 0xf4, 0x07, 0xd3, 0x4c, 0x5e, 0xe0, 0x6e, 0x96, 0x3b, 0x0b, 0x70, 0x3d, 0x8b, 0x8b, 0x0a,
		0x8d, 0xdb, 0x8b, 0xb4, 0xb9, 0x9d, 0xe5, 0xb1, 0x05, 0x16, 0xa7, 0x17, 0x59, 0x73, 0x39, 0xcb,
		0x46, 0x6e, 0xc0, 0xe5, 0x2c, 0x8a, 0x53, 0x65, 0x32, 0x37, 0xf7, 0x33, 0x54, 0xe6, 0x55, 0x40,
		0xca, 0x07, 0x19, 0x14, 0x9b, 0x29, 0x0b, 0x7b, 0xbd, 0xfe, 0xdf, 0x41, 0xff, 0xef, 0x24, 0x08,
		0x47, 0xf2, 0x8d, 0xaf, 0x95, 0xd5, 0xe4, 0x4f, 0xae, 0xef, 0xd0, 0x5b, 0x53, 0x0f, 0xa0, 0x7a,
		0x81, 0x54, 0xbb, 0x22, 0xb9, 0x7d, 0xad, 0x35, 0x91, 0x40, 0x2b, 0x5c, 0x25, 0xcc, 0x7d, 0x67,
		0x6d, 0x1c, 0x27, 0xe9, 0x6f, 0x0a, 0x7d, 0x35, 0xc9, 0xd6, 0xc7, 0x79, 0x98, 0x5c, 0x4d, 0x1e,
		0xe6, 0x9d, 0xa8, 0xb9, 0x2a, 0x34, 0x20, 0x4e, 0xe2, 0x44, 0xa5, 0xd3, 0xa1, 0x80, 0x2a, 0x6b,
		0xcb, 0xbd, 0x0d, 0x7b, 0xe3, 0x48, 0x71, 0xbd, 0x57, 0xc3, 0xb0, 0x93, 0xc6, 0xfd, 0xe4, 0x65,
		0x7c, 0x15, 0xcf, 0x3a, 0x7f, 0xe2, 0xeb, 0xde, 0x28, 0x74, 0x6d, 0x4e, 0xc2, 0xcf, 0x85, 0x37,
		0x91, 0xca, 0xde, 0x5e, 0x81, 0x8d, 0x24, 0xa7, 0x6d, 0xb6, 0xcb, 0x6d, 0x1e, 0xc1, 0x8d, 0x47,
		0xe1, 0xfb, 0x5e, 0x14, 0x0c, 0xa2, 0x68, 0x18, 0x84, 0xa3, 0xe0, 0x43, 0xdc, 0x4b, 0xa3, 0xa1,
		0xc2, 0x0c, 0xee, 0xfd, 0xeb, 0xca, 0x53, 0x99, 0x0f, 0x61, 0x6f, 0x14, 0x41, 0x67, 0xa0, 0x33,
		0xd0, 0x19, 0xe8, 0x4c, 0x9e, 0xe8, 0xcc, 0xfb, 0x7e, 0xbf, 0x17, 0x85, 0x89, 0xc6, 0x41, 0xc1,
		0xdd, 0x2d, 0x06, 0xc4, 0x61, 0x34, 0xe8, 0x85, 0x9d, 0x0c, 0x98, 0xe4, 0x91, 0xf0, 0xee, 0x82,
		0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x81, 0x40, 0x20, 0x10, 0xa8, 0xfd, 0x8e, 0x1c, 0xbd, 0x7c,
		0xe4, 0xd1, 0xb4, 0xd5, 0x73, 0x49, 0x05, 0x13, 0x31, 0x1e, 0x35, 0xc2, 0xf4, 0xe3, 0xd9, 0xec,
		0xd1, 0x90, 0x31, 0x76, 0x15, 0xbc, 0x90, 0x31, 0xe6, 0xc0, 0x89, 0x27, 0x59, 0x14, 0x07, 0x4e,
		0xf4, 0x20, 0x90, 0x03, 0x27, 0x3f, 0x42, 0x51, 0x39, 0x70, 0x02, 0x3d, 0x85, 0x9e, 0x42, 0x4f,
		0x73, 0x45, 0x4f, 0x39, 0x70, 0xf2, 0xd8, 0x17, 0x07, 0x4e, 0x36, 0x5a, 0x8e, 0x03, 0x27, 0x6e,
		0x4c, 0x84, 0x03, 0x27, 0x39, 0x37, 0x12, 0x0e, 0x9c, 0x88, 0x7e, 0x5e, 0x0e, 0x9c, 0x38, 0xa0,
		0x32, 0x74, 0xdb, 0xa0, 0x33, 0xd0, 0x19, 0xe8, 0x4c, 0xee, 0xe8, 0x0c, 0xdd, 0x36, 0x15, 0x40,
		0xe4, 0xc0, 0x09, 0x10, 0x08, 0x04, 0x02, 0x81, 0x40, 0x20, 0x10, 0x98, 0x07, 0x08, 0xe4, 0xc0,
		0x89, 0x07, 0x07, 0x4e, 0x0a, 0x25, 0xf7, 0xb5, 0x72, 0xde, 0x04, 0xc1, 0x2f, 0x6b, 0x63, 0xf7,
		0xc5, 0xc8, 0xf3, 0xae, 0xf9, 0x75, 0xdb, 0xac, 0x8b, 0xa4, 0xfa, 0xe5, 0x58, 0x9a, 0x47, 0x46,
		0x92, 0x07, 0x8d, 0x2f, 0x34, 0xbe, 0xd0, 0xf8, 0x72, 0x0a, 0x37, 0xce, 0x35, 0xbe, 0xc2, 0x71,
		0xfa, 0x31, 0x18, 0x84, 0xa3, 0xd1, 0xdc, 0x04, 0x84, 0x0e, 0x5e, 0xae, 0x2e, 0x23, 0x73, 0x00,
		0x73, 0x07, 0xc5, 0x2f, 0x0e, 0x60, 0x7a, 0x58, 0x4d, 0xe0, 0x00, 0xa6, 0x5c, 0xb5, 0x60, 0x59,
		0x50, 0x5d, 0x5c, 0x75, 0x20, 0x13, 0x63, 0x56, 0xd2, 0x99, 0xdf, 0xb6, 0xe0, 0x20, 0x7e, 0x37,
		0x1a, 0x75, 0x86, 0xf1, 0x40, 0x84, 0xc5, 0xdf, 0xba, 0xca, 0x76, 0xb9, 0x08, 0x98, 0x00, 0x26,
		0x80, 0x09, 0x60, 0x82, 0x43, 0x7b, 0x1f, 0xa5, 0xc3, 0x38, 0xb9, 0x02, 0x09, 0x36, 0x7b, 0xd6,
		0x28, 0x09, 0xdf, 0xf7, 0x22, 0x41, 0x6e, 0xb0, 0x58, 0xc0, 0xf5, 0xd0, 0xc7, 0xb2, 0xf7, 0x39,
		0xf1, 0x63, 0x00, 0x06, 0x80, 0x01, 0x60, 0x00, 0x18, 0x97, 0xf6, 0x2e, 0xd7, 0x9a, 0x14, 0x6a,
		0x49, 0xfa, 0x89, 0x30, 0xbd, 0x7e, 0x27, 0xec, 0x49, 0x1c, 0xbb, 0x59, 0x5e, 0xf0, 0xb7, 0x58,
		0x01, 0x10, 0x00, 0x04, 0x00, 0x01, 0x40, 0xc0, 0xa1, 0xbd, 0x87, 0xa3, 0x20, 0x19, 0x5f, 0xbf,
		0x17, 0x39, 0xc7, 0xbe, 0x08, 0x30, 0x02, 0xb7, 0x86, 0x0a, 0x4f, 0x99, 0xc9, 0xde, 0xb8, 0xa9,
		0x70, 0xb6, 0x4d, 0x65, 0x54, 0x48, 0x6b, 0x8a, 0x4c, 0x73, 0x30, 0xe8, 0x46, 0xf6, 0x0a, 0xd4,
		0xc2, 0x7d, 0xf5, 0xd5, 0xca, 0xf3, 0xea, 0xf3, 0xfd, 0x83, 0xca, 0xf3, 0xbd, 0x02, 0xd9, 0x40,
		0x4e, 0x0e, 0xd2, 0x5d, 0x6e, 0x41, 0x76, 0xbd, 0x38, 0xda, 0x13, 0x84, 0xdd, 0xee, 0x30, 0x1a,
		0x09, 0x66, 0xd9, 0x6b, 0x2b, 0x91, 0x6d, 0x93, 0x6d, 0x93, 0x6d, 0x93, 0x6d, 0x3b, 0xb4, 0xf7,
		0x78, 0x20, 0x14, 0x5d, 0x56, 0xaa, 0x2e, 0xcf, 0x05, 0xde, 0x7b, 0xbe, 0x37, 0xb9, 0x4b, 0xb7,
		0x97, 0x3b, 0xff, 0xa9, 0x2a, 0xb8, 0xf7, 0x6b, 0xdf, 0xc1, 0x6f, 0x82, 0x6b, 0x34, 0xc2, 0x34,
		0x8d, 0x86, 0x89, 0xb8, 0xc6, 0x46, 0xf9, 0xa7, 0x9f, 0xde, 0xed, 0x04, 0xcf, 0x2f, 0xff, 0x79,
		0xb7, 0x1b, 0x3c, 0xbf, 0x9c, 0xfd, 0xb8, 0x3b, 0xfd, 0xcf, 0xec, 0xe7, 0xca, 0xbb, 0x9d, 0xa0,
		0xba, 0xf8, 0x79, 0xef, 0xdd, 0x4e, 0xb0, 0x77, 0xf9, 0xf3, 0xbf, 0xff, 0xfd, 0xeb, 0xcf, 0xff,
		0x79, 0x76, 0xf3, 0xfd, 0xbf, 0x28, 0x37, 0x9a, 0x72, 0x29, 0xf9, 0x55, 0x9c, 0x35, 0xeb, 0x7f,
		0xaa, 0x7d, 0x1f, 0xff, 0xa3, 0xf9, 0x85, 0xfc, 0x57, 0x39, 0x6f, 0xea, 0x05, 0xbf, 0xe4, 0x38,
		0x38, 0xed, 0x13, 0x9c, 0x7e, 0x28, 0x38, 0x85, 0xc1, 0x87, 0xc3, 0xe0, 0xd5, 0xe5, 0x7f, 0x76,
		0x7f, 0xa9, 0xde, 0xfc, 0xfe, 0xf3, 0x7f, 0x0e, 0x6e, 0xee, 0xfe, 0xe1, 0x3f, 0xf7, 0xfd, 0xb3,
		0xdd, 0x5f, 0x0e, 0x6e, 0x7e, 0x7f, 0xe0, 0x6f, 0xf6, 0x6f, 0x7e, 0x7f, 0xe4, 0x7b, 0xec, 0xdd,
		0xfc, 0xb4, 0xf6, 0x4f, 0x27, 0x7f, 0x5e, 0x79, 0xe8, 0x17, 0xaa, 0x0f, 0xfc, 0xc2, 0xb3, 0x87,
		0x7e, 0xe1, 0xd9, 0x03, 0xbf, 0xf0, 0xe0, 0x47, 0xaa, 0x3c, 0xf0, 0x0b, 0x7b, 0x37, 0xff, 0xac,
		0xfd, 0xfb, 0x9f, 0xee, 0xff, 0xa7, 0xfb, 0x37, 0x3f, 0xff, 0xf3, 0xd0, 0xdf, 0x1d, 0xdc, 0xfc,
		0xf3, 0xfb, 0xcf, 0x84, 0xea, 0xc7, 0x87, 0x6a, 0xcc, 0x53, 0xdf, 0x3c, 0xf3, 0x07, 0x5c, 0x54,
		0x86, 0x7e, 0xc0, 0xc3, 0xa4, 0xd4, 0x0e, 0x32, 0x54, 0x96, 0x51, 0x37, 0xa0, 0x0e, 0x44, 0x1d,
		0x88, 0x3a, 0x10, 0x5d, 0x57, 0xba, 0xae, 0x9a, 0x4c, 0x8b, 0xae, 0xeb, 0xf7, 0xaf, 0x43, 0xd7,
		0xd5, 0xdb, 0xaf, 0x9e, 0xae, 0x2b, 0xb9, 0xb5, 0x78, 0x6e, 0x7d, 0x35, 0xec, 0x8f, 0x07, 0xc2,
		0xe9, 0xf5, 0x6c, 0x0d, 0x32, 0x6c, 0x32, 0x6c, 0x32, 0x6c, 0x32, 0x6c, 0x87, 0xf6, 0xde, 0x8b,
		0xc2, 0x0f, 0xc3, 0xe8, 0x83, 0x64, 0x9b, 0x55, 0x22, 0xc1, 0x6e, 0xcc, 0x25, 0x73, 0x7e, 0xfd,
		0xf5, 0x69, 0xf6, 0x7f, 0xcb, 0x40, 0x39, 0xba, 0xf5, 0xf3, 0xad, 0x1f, 0x83, 0xa9, 0x2a, 0xcd,
		0xb6, 0xc0, 0x52, 0x2a, 0x61, 0x3b, 0xab, 0xa8, 0x34, 0x5d, 0x02, 0x50, 0x02, 0x94, 0x00, 0x25,
		0x40, 0x29, 0x07, 0xc1, 0x65, 0x05, 0x96, 0xaa, 0x02, 0xef, 0x5d, 0x4b, 0xc6, 0xd7, 0x93, 0xad,
		0xb9, 0xd9, 0x02, 0x90, 0x19, 0x46, 0xd7, 0xfd, 0x4f, 0x51, 0x30, 0x18, 0xc6, 0x9f, 0xc2, 0x34,
		0x12, 0xed, 0x30, 0xac, 0x2f, 0x05, 0xe8, 0x00, 0x3a, 0x80, 0x0e, 0xa0, 0x23, 0x19, 0x64, 0xe6,
		0xea, 0x98, 0x92, 0x18, 0x24, 0x50, 0x96, 0x2c, 0xd7, 0xbb, 0x51, 0x92, 0xc6, 0xe9, 0x97, 0x17,
		0xe1, 0x28, 0x92, 0x97, 0xb8, 0x3f, 0xaf, 0x9d, 0x9c, 0xbd, 0xad, 0xb5, 0x1b, 0xe7, 0xf5, 0xb7,
		0x87, 0xad, 0x5a, 0xfb, 0xb0, 0xd9, 0x3e, 0x6b, 0xb4, 0xea, 0x67, 0xa7, 0x52, 0x2e, 0x37, 0xad,
		0xec, 0x8e, 0x44, 0xcf, 0xa5, 0x08, 0x97, 0xc0, 0x17, 0x3b, 0x77, 0x6b, 0xcb, 0xe6, 0x9b, 0x78,
		0x78, 0x7c, 0x5c, 0xce, 0x63, 0xeb, 0xc0, 0x62, 0xc3, 0x1a, 0xc7, 0x87, 0x47, 0xd2, 0x3b, 0x26,
		0xf2, 0xce, 0x97, 0xbe, 0x07, 0x6e, 0x3f, 0x93, 0xcd, 0xfe, 0x38, 0x8d, 0x82, 0x0f, 0xbd, 0x70,
		0x10, 0x74, 0xc3, 0xeb, 0x41, 0x9c, 0x5c, 0x09, 0x66, 0x9b, 0xeb, 0x6b, 0xc9, 0x89, 0xd6, 0x48,
		0x5c, 0xd8, 0x41, 0x3a, 0x4b, 0x3a, 0x4b, 0x3a, 0x8b, 0x6a, 0x0d, 0xaa, 0x35, 0x9b, 0x3f, 0xeb,
		0x28, 0x4a, 0xba, 0x41, 0xa7, 0x7f, 0x7d, 0x3d, 0x4e, 0xe2, 0xf4, 0x8b, 0x1c, 0xe8, 0xdc, 0x59,
		0x47, 0x0e, 0x70, 0x4e, 0xcf, 0x4e, 0x6b, 0xe0, 0x0d, 0x78, 0x03, 0xde, 0x80, 0x37, 0x2e, 0xed,
		0x3d, 0x8b, 0x5d, 0x14, 0xee, 0x25, 0x20, 0x8d, 0xeb, 0x70, 0x04, 0xaf, 0xc3, 0x71, 0x7a, 0x1f,
		0x4a, 0xc9, 0xe8, 0x16, 0x9c, 0x39, 0x5a, 0x16, 0xe8, 0xfa, 0x9b, 0xe8, 0xfd, 0xd5, 0x20, 0xb8,
		0x1e, 0xf7, 0xd2, 0xf8, 0x63, 0x7f, 0xe0, 0xfe, 0x16, 0x9c, 0xd5, 0xb7, 0xe7, 0x32, 0x1c, 0xff,
		0x52, 0x1e, 0x2e, 0xc3, 0x31, 0x49, 0x69, 0x0a, 0x7e, 0x19, 0x8e, 0xe3, 0x5b, 0xb5, 0xee, 0xc9,
		0x84, 0x1c, 0xa3, 0x89, 0x40, 0x60, 0x81, 0x63, 0xc1, 0xb1, 0xe0, 0x58, 0x8e, 0x8b, 0x2c, 0x8e,
		0x03, 0xd5, 0x32, 0x0f, 0x12, 0xd2, 0xe6, 0x5f, 0xcf, 0x88, 0x44, 0x34, 0xfa, 0xef, 0xab, 0x42,
		0x71, 0x4f, 0xb9, 0x4d, 0xe8, 0xd4, 0x0b, 0xa1, 0x5a, 0xa1, 0x54, 0x3d, 0xa4, 0xaa, 0x87, 0x56,
		0xd5, 0x10, 0x2b, 0x13, 0x6a, 0x85, 0x42, 0xae, 0x7c, 0x79, 0x6b, 0xcd, 0x5f, 0xb8, 0xa7, 0x5c,
		0xe3, 0x4b, 0x2d, 0x2f, 0x68, 0x79, 0x90, 0xa6, 0x3d, 0x79, 0xdc, 0x5b, 0x59, 0x0d, 0x50, 0x02,
		0x94, 0x00, 0x25, 0x40, 0x29, 0x47, 0xa0, 0x34, 0x8e, 0x93, 0xf4, 0x37, 0x05, 0x48, 0x12, 0x9c,
		0xa2, 0x17, 0x96, 0xcc, 0x58, 0xbc, 0x64, 0xdd, 0xbd, 0xa4, 0x25, 0xa1, 0xa1, 0x84, 0x2a, 0x6b,
		0xcb, 0x29, 0x49, 0x6a, 0x64, 0xeb, 0x29, 0xca, 0x2a, 0x08, 0x47, 0x83, 0x55, 0x13, 0x51, 0x90,
		0xda, 0xb0, 0x36, 0x91, 0xca, 0xde, 0x5e, 0x81, 0x8d, 0xe4, 0x49, 0x3e, 0xdf, 0x3d, 0x2f, 0xba,
		0x7c, 0x7e, 0x17, 0xfa, 0x84, 0xda, 0xdf, 0xd9, 0xfb, 0x5b, 0xb5, 0xc1, 0x57, 0x1a, 0xa2, 0x4f,
		0x45, 0xda, 0x18, 0x25, 0xa3, 0xe6, 0x78, 0xed, 0xfd, 0xd5, 0xe0, 0x64, 0xfe, 0x64, 0x4e, 0x3b,
		0xe5, 0xee, 0x2d, 0xd6, 0xe9, 0xe9, 0xc5, 0x34, 0x4c, 0x05, 0x45, 0x00, 0x66, 0x6f, 0x9f, 0xb3,
		0x46, 0x57, 0x85, 0x46, 0x97, 0x1e, 0x11, 0xa6, 0xd1, 0x55, 0x40, 0xfc, 0xa3, 0xd1, 0xf5, 0xad,
		0x0d, 0xa2, 0xd1, 0x65, 0x1d, 0x3a, 0xf5, 0x42, 0xa8, 0x56, 0x28, 0x55, 0x0f, 0xa9, 0xea, 0xa1,
		0x55, 0x35, 0xc4, 0xca, 0x92, 0x2d, 0x1a, 0x5d, 0xdf, 0x91, 0xe9, 0xd1, 0xe8, 0xa2, 0xd1, 0x05,
		0x28, 0x01, 0x4a, 0x80, 0x12, 0xa0, 0xf4, 0x75, 0x7f, 0xa1, 0xd1, 0xf5, 0xd8, 0x17, 0x8d, 0xae,
		0x8d, 0x96, 0xa3, 0xd1, 0xe5, 0xc6, 0x44, 0x68, 0x74, 0xe5, 0xdc, 0x48, 0x68, 0x74, 0xc9, 0x52,
		0x0a, 0x1a, 0x5d, 0xe6, 0x8d, 0x2e, 0x89, 0x2e, 0x46, 0xc9, 0x87, 0x3e, 0x57, 0x73, 0xfa, 0x60,
		0x4c, 0x34, 0xdb, 0x59, 0xba, 0x1f, 0x16, 0x9e, 0xf3, 0xc1, 0xe6, 0xdb, 0x36, 0x5d, 0xa8, 0xf1,
		0xe6, 0x69, 0x13, 0x22, 0x78, 0xff, 0xa1, 0x2b, 0x30, 0xdb, 0xbc, 0x7c, 0x6f, 0x06, 0x9b, 0x9d,
		0x94, 0x69, 0x3e, 0x74, 0x19, 0x6c, 0xb6, 0x18, 0x6c, 0xfe, 0xd0, 0x65, 0xb0, 0xf9, 0x91, 0x6f,
		0xc8, 0x60, 0xb3, 0x60, 0x80, 0x91, 0x0c, 0x34, 0xf2, 0x01, 0x47, 0x3a, 0xf0, 0xa8, 0x05, 0x20,
		0xb5, 0x40, 0xa4, 0x12, 0x90, 0xf2, 0x41, 0x03, 0x39, 0xef, 0x61, 0x5a, 0x79, 0x2a, 0x5e, 0xcb,
		0xeb, 0x43, 0x97, 0x96, 0x97, 0xc7, 0x21, 0x4f, 0x35, 0xf4, 0xc9, 0xd6, 0x02, 0x39, 0x87, 0xf1,
		0x1d, 0x19, 0xd8, 0x2e, 0x45, 0x53, 0x7f, 0x4b, 0x49, 0xf6, 0x25, 0xa5, 0xac, 0xa4, 0x50, 0xb0,
		0xd1, 0x80, 0xe9, 0x73, 0xbd, 0xf8, 0xd0, 0x65, 0x2e, 0xc0, 0x55, 0xcc, 0x62, 0x2e, 0x00, 0x9e,
		0x08, 0x4f, 0x84, 0x27, 0xc2, 0x13, 0xe1, 0x89, 0xf0, 0x44, 0x78, 0x22, 0x3c, 0x11, 0x9e, 0x08,
		0x4f, 0xdc, 0x3e, 0x9e, 0x58, 0xa8, 0x93, 0x35, 0x19, 0x4d, 0xe4, 0x58, 0x8d, 0xb5, 0x8d, 0x7b,
		0x60, 0xdb, 0x79, 0x3f, 0x53, 0xb3, 0xb0, 0xe6, 0x42, 0x1d, 0xa8, 0x19, 0x0e, 0xfb, 0xc3, 0xe0,
		0x63, 0x98, 0x74, 0x7b, 0x2e, 0x2f, 0x08, 0x5c, 0xb2, 0x83, 0xd5, 0xf7, 0xe7, 0x60, 0x8d, 0x93,
		0x24, 0x9f, 0x1b, 0x03, 0x4a, 0xdc, 0x18, 0xe0, 0x14, 0x75, 0x38, 0x58, 0x53, 0xe2, 0x60, 0x8d,
		0x52, 0xc0, 0xd1, 0xaa, 0x26, 0x20, 0xa4, 0x52, 0x40, 0x0a, 0x28, 0x56, 0x30, 0x4d, 0x87, 0x51,
		0x98, 0x06, 0xe1, 0x28, 0xf8, 0x3b, 0x4e, 0x3f, 0x76, 0x87, 0xe1, 0xdf, 0xf2, 0xa5, 0xd3, 0xf5,
		0x25, 0x11, 0x57, 0xb1, 0x08, 0xa3, 0x1a, 0xe1, 0x54, 0x2f, 0xac, 0x6a, 0x85, 0x57, 0xf5, 0x30,
		0xab, 0x1e, 0x6e, 0x55, 0xc3, 0xae, 0x5c, 0x4d, 0xaf, 0x44, 0xb1, 0xf6, 0xfb, 0xb2, 0x3f, 0x8a,
		0xb5, 0x1e, 0x17, 0xb2, 0xec, 0x0b, 0x5a, 0x2b, 0x25, 0x8d, 0x82, 0x1d, 0xec, 0x99, 0x3c, 0xdb,
		0x9b, 0xf9, 0xa3, 0x71, 0xb8, 0xc7, 0x55, 0xec, 0xe2, 0x70, 0x0f, 0x5c, 0x15, 0xae, 0x0a, 0x57,
		0x75, 0xf5, 0xc6, 0x13, 0x08, 0x4a, 0xa2, 0xfe, 0x78, 0x14, 0x8c, 0x07, 0xdd, 0x30, 0x8d, 0x82,
		0xeb, 0x68, 0x34, 0x0a, 0xaf, 0xa2, 0x91, 0xc2, 0x71, 0x9f, 0x07, 0x97, 0x86, 0x53, 0xc2, 0x29,
		0xe1, 0x94, 0x70, 0xca, 0x1c, 0x71, 0xca, 0x71, 0x9c, 0xa4, 0xcf, 0x2a, 0x0a, 0x94, 0xf2, 0x00,
		0x71, 0xb4, 0x6f, 0x3f, 0x08, 0xe2, 0x68, 0xee, 0xd6, 0x43, 0x1c, 0x2d, 0xb7, 0x26, 0x52, 0xad,
		0x3c, 0xaf, 0x3e, 0xdf, 0x3f, 0xa8, 0x3c, 0x47, 0x23, 0xcd, 0xbb, 0x77, 0xbf, 0xdc, 0x62, 0xd9,
		0x65, 0x1a, 0x64, 0x90, 0x19, 0xc8, 0x0c, 0x64, 0x06, 0x32, 0xe3, 0x27, 0x99, 0xa1, 0x41, 0x26,
		0xfc, 0x8e, 0x34, 0xc8, 0x7e, 0xa8, 0x41, 0x56, 0xa8, 0x89, 0x86, 0x95, 0xfe, 0x18, 0x53, 0x0d,
		0xd6, 0xb6, 0xee, 0x89, 0x8d, 0xe7, 0x7d, 0xb2, 0xe1, 0xb6, 0x55, 0x17, 0x69, 0xba, 0xe1, 0x6a,
		0x18, 0x76, 0xa2, 0x0f, 0xe3, 0x5e, 0x30, 0x8c, 0x46, 0x69, 0x38, 0x4c, 0xdd, 0xcf, 0x37, 0xac,
		0xad, 0xc0, 0x84, 0x83, 0x7f, 0x89, 0x3f, 0x13, 0x0e, 0x26, 0x89, 0x3b, 0x13, 0x0e, 0x1b, 0xb9,
		0x01, 0x13, 0x0e, 0x9c, 0x1a, 0xf1, 0xa5, 0xb2, 0xc0, 0xa9, 0x11, 0x3d, 0x5a, 0x88, 0x24, 0xcc,
		0xe3, 0x42, 0x18, 0x45, 0x54, 0xcb, 0xd0, 0xa6, 0x15, 0xe2, 0xd4, 0x43, 0x9d, 0x7a, 0xc8, 0x53,
		0x0d, 0x7d, 0x72, 0xb5, 0xb6, 0x12, 0x45, 0xd4, 0xef, 0xcb, 0xc0, 0xb6, 0xf9, 0x0a, 0xd7, 0x8f,
		0x51, 0x6f, 0x10, 0x0d, 0x83, 0x7e, 0xd2, 0xfb, 0x22, 0x0f, 0x47, 0xb7, 0x17, 0x03, 0x92, 0x80,
		0x24, 0x20, 0x09, 0x48, 0x02, 0x92, 0x80, 0xa4, 0xd5, 0x3d, 0x98, 0x17, 0x70, 0x83, 0x34, 0xbe,
		0x8e, 0xe4, 0x31, 0x69, 0x65, 0x35, 0x40, 0x09, 0x50, 0x02, 0x94, 0x00, 0xa5, 0x1c, 0x81, 0xd2,
		0x38, 0x4e, 0xd2, 0xdd, 0x7d, 0x05, 0x4c, 0xda, 0xe7, 0xe4, 0xfc, 0xb7, 0x1f, 0x84, 0x93, 0xf3,
		0xee, 0xd6, 0xe3, 0xe4, 0x7c, 0x6e, 0x4d, 0xa4, 0xba, 0xf3, 0x7c, 0x9f, 0x33, 0xf3, 0xbe, 0xbd,
		0xfb, 0x36, 0x9f, 0x99, 0x1f, 0xa5, 0x61, 0x2f, 0x0a, 0x86, 0xfd, 0x71, 0x1a, 0x8d, 0x94, 0x98,
		0xc5, 0xfa, 0x92, 0xd0, 0x0b, 0xe8, 0x05, 0xf4, 0x02, 0x7a, 0x91, 0x23, 0x7a, 0xd1, 0x8d, 0x3a,
		0xf1, 0x75, 0xd8, 0xdb, 0xaf, 0x6a, 0x54, 0xbd, 0x2a, 0x82, 0x6b, 0xac, 0xe5, 0x09, 0x15, 0xf8,
		0x8c, 0x9f, 0x7c, 0xa6, 0x02, 0x9f, 0x81, 0xcf, 0x7c, 0xdd, 0x44, 0x9e, 0x61, 0x22, 0x90, 0x99,
		0x9c, 0x90, 0x19, 0x26, 0x9f, 0x0c, 0xa6, 0x42, 0xee, 0x4e, 0x03, 0x14, 0x4b, 0x1c, 0xf0, 0xf5,
		0xfc, 0xe9, 0xce, 0x67, 0x0f, 0x87, 0x3c, 0xa0, 0x43, 0xca, 0x8e, 0x3c, 0x20, 0x07, 0xbd, 0x7d,
		0xa0, 0xdd, 0x1c, 0xf4, 0xd6, 0x43, 0x41, 0x0e, 0x7a, 0x3f, 0x2e, 0x84, 0x51, 0x61, 0xb4, 0x0c,
		0x6d, 0x5a, 0x21, 0x4e, 0x3d, 0xd4, 0xa9, 0x87, 0x3c, 0xd5, 0xd0, 0x27, 0x4b, 0x85, 0x38, 0x55,
		0xf7, 0x1d, 0x19, 0x18, 0x07, 0xbd, 0x39, 0xe8, 0x0d, 0x24, 0x01, 0x49, 0x40, 0x12, 0x90, 0x04,
		0x24, 0x99, 0x43, 0x52, 0xaf, 0xdf, 0x09, 0xb3, 0x0a, 0x9d, 0xcb, 0x4b, 0x4f, 0x1f, 0xfc, 0x62,
		0xd7, 0x56, 0x04, 0x9c, 0x00, 0x27, 0xc0, 0x09, 0x70, 0x02, 0x9c, 0x00, 0xa7, 0xd5, 0x3d, 0xb8,
		0xee, 0x77, 0x15, 0xce, 0x08, 0x4e, 0x57, 0x01, 0x84, 0x00, 0x21, 0x40, 0x08, 0x10, 0xca, 0x11,
		0x08, 0x45, 0xc9, 0xf8, 0x3a, 0x1a, 0xce, 0x0e, 0x0e, 0x28, 0x00, 0x51, 0x55, 0x70, 0x8d, 0x5a,
		0x32, 0xbe, 0x9e, 0x6c, 0xda, 0xcd, 0x16, 0x83, 0xdd, 0x20, 0x8a, 0x86, 0x81, 0xee, 0xdc, 0xed,
		0xfa, 0x92, 0xc0, 0x20, 0x30, 0x08, 0x0c, 0x02, 0x83, 0x39, 0x82, 0x41, 0x86, 0x6f, 0x1f, 0xfd,
		0x62, 0xf8, 0x76, 0xa3, 0xe5, 0x38, 0xac, 0xee, 0xc6, 0x44, 0x18, 0xbe, 0xcd, 0xbb, 0x95, 0x70,
		0x5e, 0x3d, 0xd7, 0xf4, 0x42, 0xa5, 0xcf, 0x73, 0x77, 0x41, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01,
		0xb5, 0xc8, 0x11, 0xb5, 0xa0, 0xcd, 0xa3, 0x02, 0x4d, 0x88, 0xcd, 0x01, 0x4a, 0x80, 0x12, 0xa0,
		0x04, 0x28, 0x3d, 0xc6, 0x5f, 0xa8, 0x77, 0x3d, 0xfa, 0x45, 0xbd, 0xcb, 0x49, 0x31, 0x83, 0x7a,
		0xd7, 0x66, 0x26, 0x42, 0xbd, 0x2b, 0xef, 0x56, 0x42, 0xbd, 0x2b, 0x77, 0xa4, 0x02, 0xb1, 0x39,
		0xe8, 0x05, 0xf4, 0x02, 0x7a, 0x01, 0xbd, 0xf8, 0x3e, 0x7f, 0x41, 0x6c, 0x0e, 0x3e, 0x83, 0xd8,
		0x1c, 0x7c, 0xc6, 0x2f, 0x3e, 0x83, 0xd8, 0x1c, 0x64, 0x06, 0xb1, 0x39, 0x17, 0x29, 0xd6, 0xb6,
		0x88, 0xcd, 0x49, 0xc8, 0x88, 0x95, 0x3c, 0xd1, 0x9a, 0x6b, 0x4e, 0x9f, 0xcd, 0x57, 0xa9, 0x39,
		0xaf, 0x2e, 0x3a, 0x17, 0xb2, 0x77, 0x6f, 0xec, 0xbc, 0xec, 0x54, 0xd8, 0xcf, 0xda, 0xb2, 0xdd,
		0xd8, 0xf4, 0xe6, 0x16, 0xe8, 0xc0, 0xfa, 0xca, 0xbd, 0xfe, 0xd5, 0x55, 0x9c, 0x5c, 0x05, 0xfd,
		0xc1, 0xc4, 0xfa, 0x46, 0xce, 0xcc, 0xef, 0xd6, 0x20, 0xfd, 0xea, 0x02, 0x8e, 0x3c, 0xc6, 0xad,
		0x54, 0xa2, 0xf3, 0x62, 0x92, 0x44, 0xf1, 0x48, 0xae, 0x58, 0x24, 0x55, 0x1c, 0x12, 0x2f, 0x06,
		0x89, 0x17, 0x7f, 0x44, 0x8b, 0x3d, 0x7e, 0x61, 0x90, 0x6b, 0x69, 0xc3, 0x72, 0x67, 0xe1, 0x53,
		0x42, 0x12, 0xac, 0x22, 0x42, 0xbd, 0xe2, 0x1a, 0xac, 0x3b, 0x68, 0xb0, 0xca, 0x07, 0x1e, 0xb5,
		0x00, 0xa4, 0x16, 0x88, 0x54, 0x02, 0x52, 0x3e, 0xc8, 0xa1, 0x98, 0x06, 0x6b, 0xaf, 0x3f, 0xc9,
		0x8b, 0x67, 0x39, 0x5f, 0x30, 0x65, 0x66, 0x41, 0xe7, 0x63, 0x98, 0x5c, 0x45, 0x23, 0x0d, 0xbd,
		0xa1, 0x07, 0xd7, 0x16, 0x32, 0xa4, 0x97, 0xd1, 0x87, 0x70, 0xdc, 0x9b, 0xda, 0xd1, 0xc4, 0x5c,
		0xe9, 0x02, 0xaa, 0xc7, 0x57, 0xbd, 0x38, 0xab, 0x15, 0x6f, 0xd5, 0xe3, 0xae, 0x7a, 0xfc, 0x55,
		0x8d, 0xc3, 0xb2, 0xe5, 0x4a, 0x4e, 0xbe, 0x7f, 0x47, 0x3a, 0xb8, 0x4b, 0x5d, 0xd7, 0xdf, 0x3a,
		0x97, 0x79, 0xbd, 0xeb, 0x4e, 0x91, 0xa3, 0x58, 0x77, 0x88, 0x1c, 0xcf, 0x1e, 0xee, 0x6c, 0xf6,
		0x6c, 0x5c, 0x21, 0xe2, 0x2a, 0x7a, 0x71, 0x85, 0x08, 0xf4, 0x15, 0xfa, 0x0a, 0x7d, 0x85, 0xbe,
		0x42, 0x5f, 0xa1, 0xaf, 0xd0, 0x57, 0xe8, 0x2b, 0xf4, 0x15, 0xfa, 0x0a, 0x7d, 0xb5, 0xa7, 0xaf,
		0x45, 0x3a, 0x95, 0x74, 0x87, 0xbd, 0x72, 0x28, 0xc9, 0xda, 0xda, 0x7d, 0xb1, 0xf2, 0x9c, 0x9f,
		0x49, 0x5a, 0xb5, 0xeb, 0x22, 0x1d, 0x49, 0xca, 0x78, 0x44, 0xd8, 0xed, 0x0e, 0xa3, 0x91, 0xc0,
		0x99, 0xa4, 0xb5, 0x15, 0xdc, 0x1e, 0x4a, 0xda, 0xe1, 0x50, 0x92, 0xc7, 0xc9, 0x3e, 0x87, 0x92,
		0x72, 0x84, 0x41, 0xce, 0x93, 0xf1, 0x65, 0xc5, 0x22, 0x0a, 0x3f, 0x0c, 0xa3, 0x0f, 0x2e, 0x0d,
		0x76, 0x91, 0x6c, 0x1f, 0x38, 0x7c, 0xcf, 0xc6, 0x1c, 0x26, 0x7f, 0xfd, 0x75, 0xde, 0x54, 0x78,
		0xba, 0x16, 0xbc, 0x0a, 0x14, 0xfa, 0xa7, 0x53, 0xc9, 0xc1, 0x30, 0xfa, 0xd0, 0x8b, 0x3a, 0x69,
		0x7f, 0xe8, 0x3e, 0xf2, 0xdf, 0x5d, 0x80, 0xd3, 0xa8, 0x04, 0x7e, 0x02, 0xbf, 0x87, 0x81, 0x9f,
		0xd3, 0xa8, 0x25, 0x4e, 0xa3, 0x2a, 0x05, 0x1c, 0xe9, 0xc0, 0xa3, 0x16, 0x80, 0xd4, 0x02, 0x91,
		0x4a, 0x40, 0xca, 0x47, 0x4d, 0x50, 0xac, 0x9d, 0x77, 0x27, 0x55, 0x09, 0x3a, 0xbd, 0x78, 0xb6,
		0xd1, 0xd2, 0xca, 0x93, 0xf7, 0xaf, 0x2b, 0xdf, 0xc6, 0xfb, 0x10, 0xf6, 0x46, 0xf4, 0xf1, 0xf4,
		0x03, 0xab, 0x5e, 0x80, 0xd5, 0x0a, 0xb4, 0xea, 0x01, 0x57, 0x3d, 0xf0, 0xaa, 0x06, 0x60, 0x99,
		0x40, 0x2c, 0x14, 0x90, 0xe5, 0x4a, 0x07, 0x0f, 0xfa, 0x0b, 0x7d, 0x3c, 0x8d, 0x2f, 0xf5, 0x1e,
		0x60, 0x1a, 0x8f, 0xd2, 0x68, 0x18, 0xc4, 0x5d, 0x0b, 0x50, 0xcc, 0xd6, 0x06, 0xb0, 0x00, 0x2c,
		0x00, 0x0b, 0xc0, 0xca, 0x11, 0x60, 0x0d, 0x6f, 0x07, 0xb0, 0x20, 0x9d, 0xac, 0xab, 0x80, 0x5d,
		0xcf, 0x05, 0xd7, 0x98, 0xef, 0x5d, 0xee, 0x85, 0xcd, 0x6e, 0xcb, 0x67, 0x3f, 0xab, 0x94, 0x15,
		0x74, 0xb2, 0xe6, 0xdf, 0xce, 0x81, 0xc2, 0x52, 0x3a, 0xf2, 0x73, 0x7a, 0xdf, 0x56, 0xf6, 0x60,
		0x9a, 0x72, 0x74, 0x4a, 0x09, 0xc2, 0x83, 0xcb, 0x2a, 0x6b, 0x8f, 0x65, 0xeb, 0x1a, 0x68, 0x90,
		0x09, 0x07, 0xfc, 0xfb, 0x4d, 0x49, 0x51, 0xb6, 0xce, 0x17, 0x53, 0xaa, 0x56, 0x9e, 0x57, 0x9f,
		0xef, 0x1f, 0x54, 0x9e, 0xef, 0x6d, 0x91, 0x4d, 0x3d, 0x29, 0xc6, 0x2a, 0x97, 0x4f, 0x72, 0xec,
		0x79, 0x8a, 0x80, 0x1e, 0x0f, 0x3e, 0x55, 0x1d, 0x1f, 0x37, 0x7a, 0x54, 0xd2, 0xf5, 0x9b, 0xc2,
		0x5a, 0x8d, 0x30, 0x4d, 0xa3, 0x61, 0xa2, 0x86, 0xec, 0xe5, 0x9f, 0x7e, 0x7a, 0xb7, 0x13, 0x3c,
		0xbf, 0xfc, 0xe7, 0xdd, 0x6e, 0xf0, 0xfc, 0x72, 0xf6, 0xe3, 0xee, 0xf4, 0x3f, 0xb3, 0x9f, 0x2b,
		0xef, 0x76, 0x82, 0xea, 0xe2, 0xe7, 0xbd, 0x77, 0x3b, 0xc1, 0xde, 0xe5, 0xcf, 0xff, 0xfe, 0xf7,
		0xaf, 0x3f, 0xff, 0xe7, 0xd9, 0xcd, 0xf7, 0xff, 0x62, 0x59, 0xde, 0x85, 0x34, 0xbe, 0xa2, 0xb3,
		0x66, 0xfd, 0x4f, 0xf5, 0xef, 0xe9, 0x7f, 0x34, 0xbf, 0xa8, 0xff, 0x2a, 0xe7, 0x3d, 0xd8, 0x21,
		0x4a, 0xca, 0xe9, 0x7f, 0x83, 0x73, 0xd1, 0x77, 0x6a, 0x9b, 0xc5, 0x1a, 0x5e, 0x3f, 0x9f, 0x3c,
		0xdc, 0xf9, 0xe2, 0xd9, 0x18, 0x5e, 0x77, 0x95, 0xcf, 0x30, 0xbc, 0xce, 0x69, 0x97, 0x6f, 0x7d,
		0x9b, 0x9c, 0x76, 0x29, 0x1c, 0x06, 0x72, 0xda, 0x65, 0xb3, 0xed, 0xe3, 0xb4, 0x8b, 0x75, 0x60,
		0xd5, 0x0b, 0xb0, 0x5a, 0x81, 0x56, 0x3d, 0xe0, 0xaa, 0x07, 0x5e, 0xd5, 0x00, 0x2c, 0x4b, 0xc7,
		0x38, 0xed, 0xf2, 0x1d, 0x79, 0x20, 0xa7, 0x5d, 0x38, 0xed, 0x02, 0x60, 0x01, 0x58, 0x00, 0x16,
		0x80, 0xb5, 0x41, 0x34, 0xe3, 0xb4, 0xcb, 0x8f, 0xbc, 0x38, 0xed, 0xb2, 0xd9, 0x52, 0x9c, 0x76,
		0xc9, 0x4f, 0x82, 0xf0, 0xe0, 0xb2, 0x9c, 0x76, 0x91, 0x35, 0x25, 0x4e, 0xbb, 0x6c, 0x87, 0x4d,
		0x71, 0xda, 0xc5, 0xde, 0xf3, 0x38, 0xed, 0xe2, 0x86, 0xea, 0x71, 0xda, 0x65, 0x23, 0x17, 0xe2,
		0xb4, 0x0b, 0xa7, 0x5d, 0x38, 0xed, 0xc2, 0x69, 0x17, 0x4f, 0x4e, 0xbb, 0x14, 0x49, 0xeb, 0xf2,
		0xce, 0x61, 0x17, 0xb4, 0x2e, 0xad, 0xad, 0xdd, 0x17, 0x2b, 0xcf, 0xb9, 0xd6, 0xe5, 0xaa, 0x5d,
		0x17, 0x49, 0xf0, 0xcc, 0xed, 0x29, 0x2d, 0x91, 0xd3, 0x59, 0x62, 0xe2, 0x66, 0x15, 0xc4, 0xcd,
		0x5c, 0x52, 0x20, 0xc4, 0xcd, 0x72, 0x83, 0x36, 0xce, 0xc5, 0xcd, 0xc2, 0x71, 0xfa, 0x31, 0x18,
		0x84, 0xa3, 0xd1, 0xdc, 0x04, 0x84, 0x0e, 0x7d, 0xae, 0x2e, 0x23, 0x73, 0xf8, 0x73, 0x07, 0xa9,
		0x33, 0x0e, 0x7f, 0x7a, 0x14, 0x96, 0x54, 0xc2, 0x53, 0x3e, 0x28, 0xa1, 0x58, 0xcb, 0x76, 0xe5,
		0xe0, 0x49, 0x9c, 0x5c, 0x49, 0xc5, 0x98, 0xd5, 0x5a, 0xe1, 0x16, 0x0c, 0x01, 0x74, 0xa3, 0x51,
		0x67, 0x18, 0x0f, 0x44, 0x58, 0x7c, 0xf6, 0xa5, 0xdd, 0x5e, 0x04, 0x4c, 0x00, 0x13, 0xc0, 0x04,
		0x30, 0xc1, 0x29, 0x97, 0x1d, 0xc6, 0xc9, 0x15, 0x48, 0xb0, 0x21, 0x12, 0x7c, 0x49, 0xc2, 0xeb,
		0xb8, 0x13, 0xf6, 0x7a, 0x5f, 0x82, 0x59, 0xbd, 0x66, 0x3c, 0x8c, 0x04, 0xa9, 0xc2, 0x03, 0xeb,
		0xb9, 0x1e, 0x47, 0x91, 0x9d, 0xa7, 0x00, 0x7f, 0xc0, 0x1f, 0xf0, 0x67, 0xcb, 0xf1, 0x47, 0x6e,
		0xde, 0x41, 0x68, 0xce, 0xc1, 0x4f, 0x00, 0x8a, 0x92, 0xf0, 0x7d, 0x4f, 0x12, 0x71, 0x16, 0x0b,
		0xc8, 0x41, 0x8c, 0xc0, 0x3d, 0xb3, 0x20, 0x0c, 0x08, 0x03, 0xc2, 0x80, 0x30, 0x20, 0x8c, 0x03,
		0x84, 0x19, 0xa5, 0xe1, 0xfb, 0x5e, 0x3c, 0xfa, 0x18, 0x75, 0x83, 0x74, 0x18, 0x26, 0xa3, 0x78,
		0x76, 0x35, 0xa2, 0x1c, 0xe2, 0x3c, 0xb0, 0x20, 0x10, 0x01, 0x44, 0x00, 0x11, 0x40, 0x84, 0x43,
		0x7b, 0xef, 0xf4, 0xc7, 0x49, 0x1a, 0x0d, 0xf7, 0xab, 0x82, 0x20, 0x21, 0x70, 0x78, 0x5a, 0x78,
		0x08, 0x4a, 0x70, 0x78, 0x50, 0x63, 0xc8, 0x49, 0x69, 0x12, 0x45, 0x6b, 0x88, 0x49, 0x73, 0xc0,
		0x44, 0x70, 0x54, 0x42, 0x65, 0x28, 0x49, 0xfb, 0xab, 0xdf, 0xfd, 0xad, 0x5a, 0xdd, 0x3f, 0xa8,
		0x56, 0x77, 0x0e, 0x9e, 0x1d, 0xec, 0x3c, 0xdf, 0xdb, 0xdb, 0xdd, 0xdf, 0xdd, 0x2b, 0x90, 0x35,
		0xe4, 0xe4, 0xc4, 0xf7, 0xe5, 0x16, 0x64, 0xe1, 0xbd, 0x70, 0x94, 0x06, 0xb7, 0x32, 0x63, 0xb9,
		0xf4, 0x7b, 0x6d, 0x25, 0xf2, 0x6e, 0xf2, 0x6e, 0xf2, 0x6e, 0xf2, 0x6e, 0x87, 0xf6, 0x9e, 0xc6,
		0xd7, 0x51, 0x1a, 0x77, 0xfe, 0x77, 0x94, 0xbb, 0xcc, 0xfb, 0x22, 0x99, 0xa1, 0x6e, 0x39, 0x09,
		0x93, 0xfe, 0x28, 0xea, 0xf4, 0x93, 0xae, 0xc4, 0x28, 0x26, 0x19, 0x3e, 0x19, 0x3e, 0x19, 0x3e,
		0x19, 0x3e, 0x19, 0xfe, 0xf6, 0x64, 0xf8, 0xfd, 0x4e, 0xd8, 0x0b, 0x42, 0xc1, 0xc2, 0x7a, 0xb6,
		0x02, 0x19, 0x3d, 0x19, 0x3d, 0x19, 0x3d, 0x19, 0xbd, 0x43, 0x7b, 0x0f, 0x47, 0x41, 0x32, 0xbe,
		0x7e, 0x1f, 0x0d, 0x05, 0xf3, 0xf9, 0x03, 0xf2, 0x6c, 0xf2, 0x6c, 0xf2, 0xec, 0x42, 0xe6, 0xd9,
		0x5a, 0xf2, 0x5d, 0x64, 0xd7, 0xdb, 0x99, 0x5d, 0x5f, 0x47, 0xa3, 0x51, 0x78, 0x15, 0x09, 0x66,
		0xd7, 0xd9, 0x0a, 0x39, 0xbb, 0xbd, 0x85, 0xec, 0x9a, 0xec, 0x9a, 0xec, 0x7a, 0x93, 0x1d, 0x90,
		0xbb, 0xbd, 0x25, 0xea, 0x44, 0xf1, 0xa7, 0x48, 0x43, 0x9a, 0x7e, 0xb1, 0x92, 0xac, 0x10, 0xfd,
		0x2e, 0x42, 0xf4, 0x86, 0xc1, 0x4d, 0x2b, 0xc8, 0xa9, 0x07, 0x3b, 0xf5, 0xa0, 0xa7, 0x1a, 0xfc,
		0x84, 0xd3, 0x49, 0xa9, 0x3b, 0x99, 0x84, 0x82, 0xe2, 0xd2, 0x5d, 0xce, 0x5a, 0xf5, 0x57, 0xf5,
		0xa3, 0xc3, 0x56, 0xfd, 0xec, 0x54, 0xde, 0x94, 0x17, 0xce, 0xb9, 0xb2, 0xea, 0x2f, 0x85, 0xa0,
		0x60, 0xd2, 0xc1, 0x53, 0x33, 0x88, 0xea, 0x07, 0x53, 0xed, 0xa0, 0x6a, 0x16, 0x5c, 0xcd, 0x82,
		0xac, 0x49, 0xb0, 0x95, 0x0d, 0xba, 0x0a, 0x55, 0xa2, 0x92, 0xca, 0x6d, 0x20, 0x6b, 0xfe, 0x36,
		0x8e, 0x93, 0x54, 0xe4, 0x50, 0xc7, 0x43, 0xd1, 0xf1, 0x37, 0xee, 0x9c, 0xf8, 0xf1, 0x07, 0xe3,
		0xce, 0x09, 0xf9, 0x75, 0xb9, 0x73, 0xa2, 0xb0, 0xa6, 0xa4, 0x7f, 0x38, 0xc4, 0x2b, 0xeb, 0xe2,
		0xf6, 0x09, 0xd3, 0xcf, 0x2f, 0xd9, 0x62, 0xba, 0x68, 0xbc, 0x3c, 0x6c, 0xd5, 0xf4, 0x68, 0xd5,
		0x7c, 0x3d, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0x82, 0x50, 0x41, 0xa8, 0x20, 0x54, 0x10,
		0x2a, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x05, 0xa1, 0xca, 0x3f, 0xa1, 0x9a, 0x4e, 0xd5, 0x26, 0xfd,
		0x34, 0xfe, 0x10, 0x77, 0xa6, 0x17, 0xe2, 0x04, 0xd1, 0x70, 0xd8, 0x1f, 0x06, 0x9d, 0x7e, 0x37,
		0xd2, 0xa3, 0x59, 0x5f, 0xfd, 0x14, 0x90, 0x2f, 0xc8, 0x17, 0xe4, 0x0b, 0xf2, 0x05, 0xf9, 0x5a,
		0x5e, 0xb8, 0xda, 0x8d, 0x92, 0x34, 0x4e, 0xbf, 0x0c, 0xa3, 0x0f, 0x9a, 0xf7, 0xad, 0x2a, 0xe4,
		0x3c, 0xe5, 0xfa, 0xfc, 0xd1, 0x5e, 0x84, 0x23, 0x45, 0x37, 0x5f, 0x6c, 0xec, 0x8b, 0xd7, 0x8d,
		0x76, 0xed, 0xfc, 0xfc, 0xec, 0xbc, 0x7d, 0x74, 0xf6, 0xb2, 0xa6, 0xe5, 0xeb, 0xd3, 0x34, 0x73,
		0xa4, 0xc6, 0x3b, 0x75, 0xb9, 0xe7, 0xca, 0xfe, 0x9e, 0xd4, 0x9a, 0xcd, 0xc3, 0xd7, 0xb5, 0xf6,
		0x9b, 0xda, 0xe1, 0xcb, 0xda, 0xf9, 0x6c, 0xab, 0xcb, 0x45, 0xa4, 0x49, 0x46, 0xfb, 0x7b, 0xd6,
		0xa8, 0x9d, 0xb6, 0x17, 0x9b, 0xcc, 0xee, 0x3a, 0xde, 0xdd, 0xf3, 0xb3, 0x8b, 0x56, 0xad, 0x7d,
		0x5e, 0x7b, 0x75, 0x5e, 0x6b, 0xbe, 0x61, 0x9b, 0xa5, 0xb6, 0x79, 0xd6, 0x74, 0x61, 0x7f, 0xa5,
		0xf6, 0xf7, 0x55, 0xfd, 0xb4, 0xde, 0xaa, 0xb5, 0x9b, 0xad, 0xe9, 0x2e, 0x1f, 0x1e, 0xbd, 0xa9,
		0x9f, 0xb2, 0xcb, 0xce, 0x77, 0xf9, 0xcd, 0xd9, 0xf1, 0xcb, 0x76, 0xab, 0x7e, 0x32, 0x81, 0xb9,
		0x3f, 0x1b, 0xf5, 0xf3, 0xda, 0x4b, 0x76, 0xd7, 0xdd, 0xee, 0x1e, 0xd5, 0x0e, 0x9b, 0xb5, 0x72,
		0xc1, 0x4a, 0x60, 0x97, 0x79, 0x27, 0x5a, 0x85, 0x2a, 0x81, 0x8d, 0xc6, 0xef, 0xfd, 0xa8, 0x82,
		0x2d, 0x3e, 0x08, 0x85, 0xb0, 0xef, 0x5a, 0x88, 0x42, 0x98, 0x53, 0xeb, 0xa0, 0x10, 0x46, 0x21,
		0xec, 0x1b, 0x3b, 0x46, 0x21, 0xcc, 0xe1, 0x5a, 0xbe, 0x14, 0xc2, 0x9a, 0x17, 0x2f, 0xa8, 0x85,
		0x89, 0xd0, 0xdc, 0xd3, 0x66, 0xa3, 0x76, 0x54, 0x7f, 0x55, 0x3f, 0x82, 0x18, 0xb8, 0xdb, 0xd5,
		0x95, 0x0a, 0x98, 0xae, 0xed, 0x5a, 0xda, 0xb0, 0xcd, 0xae, 0xdf, 0x63, 0xd3, 0x87, 0x47, 0x47,
		0xb5, 0x46, 0xeb, 0xf0, 0xc5, 0x71, 0xad, 0x9d, 0x31, 0xe0, 0xb2, 0xfa, 0x87, 0xba, 0xf9, 0x65,
		0xfb, 0x76, 0xbe, 0x79, 0xd1, 0x68, 0x9c, 0x9d, 0xb7, 0x6a, 0x2f, 0xdb, 0x6f, 0x6b, 0xe7, 0xcd,
		0xfa, 0xd9, 0x69, 0xfb, 0xf4, 0xe2, 0xe4, 0x45, 0xed, 0x9c, 0xdd, 0xd7, 0xdd, 0xfd, 0xa3, 0xc3,
		0xc6, 0xe1, 0x8b, 0xfa, 0x71, 0xbd, 0xf5, 0x17, 0x3b, 0xaf, 0xbb, 0xf3, 0x67, 0x8d, 0x56, 0xfd,
		0xec, 0xf4, 0xf0, 0xb8, 0xdd, 0x38, 0x3c, 0x3f, 0x3c, 0xa9, 0xb5, 0xb0, 0x7d, 0x95, 0x54, 0xf1,
		0xf0, 0x65, 0x7b, 0x92, 0x2e, 0xd6, 0x5f, 0xd6, 0x4e, 0x5b, 0xf5, 0x57, 0x75, 0x76, 0x5d, 0x6b,
		0xd7, 0x1b, 0xb5, 0xda, 0x79, 0xfb, 0xb0, 0x69, 0xb0, 0xdd, 0xaa, 0x2b, 0x5e, 0x92, 0x1e, 0x17,
		0x26, 0x41, 0xdb, 0x86, 0x1d, 0xb6, 0x4f, 0xc4, 0xb6, 0x6b, 0x97, 0x2d, 0x12, 0xae, 0xed, 0xda,
		0x61, 0xcb, 0xc4, 0xaa, 0xf8, 0x3b, 0x6d, 0x99, 0x40, 0x6d, 0xc7, 0xee, 0xaa, 0x27, 0x4a, 0x5b,
		0x77, 0x48, 0x87, 0x4a, 0x9b, 0xf2, 0xfe, 0x9f, 0x1c, 0x1e, 0xbf, 0x3a, 0x3b, 0x3f, 0xa9, 0xbd,
		0x6c, 0x1f, 0x36, 0xdb, 0x8d, 0xc3, 0xd6, 0x1b, 0x48, 0x97, 0xfc, 0xa6, 0x1f, 0xb6, 0x5a, 0xe7,
		0xf5, 0x17, 0x17, 0xad, 0x5a, 0xfb, 0xd5, 0xf1, 0xe1, 0xeb, 0xa6, 0xf6, 0xa1, 0xa9, 0xed, 0xdd,
		0xf8, 0x2c, 0x01, 0x59, 0x7e, 0x03, 0xec, 0xbd, 0xd2, 0xde, 0xd7, 0x4f, 0xdf, 0x1e, 0x1e, 0xd7,
		0x5f, 0xb6, 0x4f, 0x6b, 0xad, 0x3f, 0xce, 0xce, 0xff, 0xd5, 0x7e, 0x55, 0xaf, 0x1d, 0xbf, 0x64,
		0xe3, 0x35, 0x32, 0xf0, 0xf3, 0xda, 0xd1, 0xd9, 0xeb, 0xd3, 0xfa, 0xff, 0xab, 0xbd, 0x6c, 0xff,
		0x51, 0x3b, 0x3e, 0x6e, 0xff, 0xeb, 0xf4, 0xec, 0x8f, 0xd3, 0xa5, 0x0f, 0xf0, 0x25, 0x28, 0xe0,
		0x6c, 0xbd, 0xd9, 0xac, 0x9f, 0xbe, 0x66, 0xff, 0xcd, 0x21, 0xf7, 0xb8, 0x76, 0xfa, 0xba, 0xf5,
		0x86, 0xb8, 0x6f, 0x90, 0x61, 0x2e, 0xbf, 0x83, 0x7a, 0xb3, 0xc5, 0xde, 0xeb, 0x61, 0xee, 0xd9,
		0x79, 0xfd, 0x75, 0x9d, 0x88, 0x63, 0x94, 0xef, 0xfc, 0xd9, 0x6a, 0xbf, 0x39, 0x6b, 0x98, 0xee,
		0x3e, 0x8d, 0x96, 0x9c, 0xd6, 0x47, 0x0c, 0xf9, 0x79, 0xf1, 0x37, 0xd7, 0x98, 0x87, 0x6f, 0xc3,
		0x29, 0x3a, 0x6b, 0xbe, 0x5d, 0xfc, 0x3d, 0x36, 0xe6, 0xd5, 0xdb, 0xd0, 0xc1, 0xf2, 0x86, 0x3f,
		0x6f, 0x01, 0xde, 0x79, 0xc1, 0x93, 0xb7, 0x09, 0xfa, 0x6c, 0xf8, 0xf0, 0x56, 0x65, 0x6e, 0x46,
		0xbc, 0x77, 0x7b, 0xb0, 0xcf, 0x8e, 0xdf, 0x6e, 0x53, 0x7e, 0x61, 0xc7, 0x63, 0xb7, 0x4d, 0x13,
		0x84, 0x36, 0xb8, 0x91, 0x91, 0x2f, 0xce, 0x21, 0xcc, 0x40, 0x91, 0x42, 0x0d, 0x0e, 0x9c, 0x17,
		0x0b, 0xda, 0x82, 0x84, 0x6a, 0x55, 0xf4, 0x8b, 0x18, 0xa9, 0xbc, 0xff, 0x2f, 0x0e, 0x97, 0xd6,
		0xdd, 0xfa, 0xab, 0x41, 0x13, 0x41, 0x61, 0xcf, 0x8f, 0xce, 0x4e, 0x4f, 0x6b, 0x47, 0xad, 0xe9,
		0xe1, 0xef, 0xb3, 0x56, 0xbb, 0xf9, 0xd7, 0xe9, 0xd1, 0x9b, 0xf3, 0xb3, 0x69, 0x29, 0x82, 0xed,
		0xd7, 0x35, 0x79, 0x52, 0x02, 0x00, 0x2b, 0x2f, 0x01, 0x73, 0x0b, 0x84, 0xbb, 0x7c, 0x08, 0x8c,
		0xdb, 0x65, 0xc2, 0x64, 0xb4, 0xae, 0x77, 0xf7, 0x5e, 0x05, 0x45, 0xf2, 0x5a, 0xed, 0xd2, 0x4b,
		0xed, 0xa8, 0x56, 0x7f, 0x5b, 0x6b, 0x5f, 0x9c, 0xd6, 0xfe, 0x6c, 0xd4, 0x8e, 0x5a, 0xb5, 0xa5,
		0xc9, 0x9f, 0x35, 0x6a, 0xa7, 0x47, 0x67, 0xa7, 0xaf, 0xea, 0xe7, 0x27, 0xa4, 0x5b, 0xa6, 0xdf,
		0x44, 0xad, 0xd9, 0x3a, 0x7c, 0x71, 0x5c, 0x6f, 0xbe, 0x21, 0xf1, 0xf5, 0xc0, 0x27, 0x9a, 0xb5,
		0xd3, 0x16, 0x99, 0x30, 0x40, 0x97, 0xd7, 0x10, 0xbb, 0xd5, 0x3b, 0x6e, 0x12, 0x4a, 0xb7, 0xde,
		0xc6, 0x75, 0x43, 0xe6, 0x96, 0x28, 0x37, 0x93, 0x2c, 0x6b, 0x6f, 0xfb, 0x59, 0xeb, 0x4d, 0xed,
		0xbc, 0x3d, 0x0d, 0xd8, 0xaf, 0xdb, 0x47, 0x6f, 0x0e, 0x4f, 0x5f, 0x53, 0x07, 0xd6, 0xd8, 0xf6,
		0x8b, 0x56, 0xfb, 0xec, 0x55, 0xfb, 0xbc, 0xd6, 0x3c, 0xbb, 0x38, 0x3f, 0xaa, 0x35, 0xd9, 0x73,
		0xf9, 0x3d, 0x9f, 0x4e, 0xfb, 0xbf, 0xac, 0xcd, 0x8d, 0xfd, 0xe2, 0x1c, 0xe6, 0xa1, 0xb1, 0xeb,
		0x27, 0x87, 0x7f, 0xb6, 0x4f, 0x2f, 0x4e, 0xda, 0x8d, 0xf3, 0xda, 0xab, 0xfa, 0x9f, 0xb5, 0x66,
		0xfb, 0xbc, 0x76, 0x78, 0x04, 0xeb, 0xd3, 0xc1, 0xd4, 0xb3, 0xd3, 0xd3, 0xf6, 0xd1, 0xd9, 0xf1,
		0x71, 0x7d, 0x2a, 0x37, 0x34, 0x89, 0x36, 0xc7, 0x17, 0xad, 0xfa, 0xd9, 0x29, 0x9b, 0x2f, 0xbf,
		0xf9, 0x87, 0x2f, 0x4f, 0xea, 0xa7, 0xf5, 0x66, 0xeb, 0xfc, 0xb0, 0x35, 0x49, 0x23, 0xcf, 0x6b,
		0xcd, 0x1a, 0x33, 0x72, 0x4a, 0x46, 0x3f, 0xef, 0x24, 0x9c, 0xd7, 0xfe, 0x7b, 0x9a, 0xb8, 0xb3,
		0xed, 0xea, 0xe6, 0xde, 0x7c, 0x73, 0xd1, 0x7a, 0x79, 0xf6, 0xc7, 0x29, 0x55, 0x25, 0x28, 0x60,
		0x2e, 0xb8, 0xc8, 0x16, 0x6c, 0xaf, 0x19, 0xe7, 0x28, 0xfe, 0xde, 0x5a, 0x72, 0x8b, 0x6d, 0x18,
		0xbd, 0xb0, 0xe6, 0x10, 0xdb, 0x71, 0x00, 0xc3, 0x98, 0x2b, 0x6c, 0xc1, 0x94, 0x96, 0x29, 0x27,
		0xd8, 0xaa, 0x53, 0x44, 0xfa, 0xb9, 0xff, 0xd6, 0x99, 0xaf, 0x7e, 0x8e, 0xcf, 0x7d, 0x8b, 0xb6,
		0xef, 0xae, 0x7b, 0xdf, 0x62, 0x1a, 0x5f, 0x9b, 0x5e, 0xb3, 0x38, 0x5d, 0x9f, 0xdb, 0x15, 0xbf,
		0x6b, 0x21, 0x6e, 0x57, 0x74, 0x6a, 0x1d, 0xdc, 0xae, 0xc8, 0xed, 0x8a, 0xdf, 0xd8, 0x31, 0xfd,
		0xdb, 0x15, 0x27, 0x71, 0x31, 0x8d, 0x3b, 0xff, 0x3b, 0xda, 0xaf, 0x2a, 0xde, 0xae, 0xf8, 0x9b,
		0xc2, 0x52, 0x17, 0x49, 0x9c, 0x8e, 0x26, 0x8f, 0x98, 0x84, 0x49, 0x7f, 0x14, 0x75, 0xfa, 0x49,
		0x77, 0xa4, 0xf1, 0x88, 0xe7, 0x61, 0x72, 0x15, 0xa9, 0x1d, 0x3f, 0xd0, 0xcb, 0x1e, 0xcb, 0x27,
		0x71, 0xa2, 0x16, 0x2d, 0x95, 0x31, 0x75, 0x6d, 0xd9, 0xe9, 0x21, 0x12, 0x83, 0x75, 0x5f, 0x0d,
		0xc3, 0xce, 0x24, 0x5f, 0x79, 0x19, 0x5f, 0xcd, 0xac, 0x77, 0xa7, 0x88, 0x94, 0xa7, 0x7c, 0x12,
		0x7e, 0xde, 0x3a, 0x53, 0xda, 0xfd, 0xad, 0x5a, 0xdd, 0x3f, 0xa8, 0x56, 0x77, 0x0e, 0x9e, 0x1d,
		0xec, 0x3c, 0xdf, 0xdb, 0xdb, 0xdd, 0xd7, 0xb8, 0x63, 0xd6, 0x1b, 0xeb, 0x7a, 0x52, 0x8c, 0x55,
		0x2e, 0xf3, 0xca, 0xf6, 0x9e, 0xe4, 0x28, 0x66, 0x94, 0x0f, 0x93, 0xa4, 0x9f, 0x4e, 0x89, 0x9b,
		0x68, 0x98, 0x28, 0x8f, 0x3a, 0x1f, 0xa3, 0xeb, 0x70, 0x10, 0xa6, 0x1f, 0x27, 0x89, 0xc2, 0xd3,
		0xfe, 0x20, 0x4a, 0x3a, 0x53, 0x76, 0x15, 0x24, 0x51, 0xfa, 0x77, 0x7f, 0xf8, 0xbf, 0x41, 0x9c,
		0x8c, 0xd2, 0x30, 0xe9, 0x44, 0x4f, 0xef, 0xfe, 0xc1, 0x68, 0xed, 0x4f, 0x9e, 0x0e, 0x86, 0xfd,
		0xb4, 0xdf, 0xe9, 0xf7, 0x46, 0xd9, 0x4f, 0x4f, 0xdf, 0x5f, 0x0d, 0x9e, 0x26, 0x51, 0x7c, 0xf5,
		0xf1, 0x7d, 0x7f, 0x38, 0xca, 0x7e, 0x7a, 0x3a, 0x4a, 0xc3, 0x34, 0x7a, 0x7a, 0x1d, 0x8d, 0x46,
		0xe1, 0x55, 0x34, 0x7a, 0x3a, 0x8c, 0x3a, 0x51, 0xfc, 0x29, 0xea, 0x0a, 0xa6, 0x27, 0xe5, 0x51,
		0x3a, 0x1c, 0x77, 0xd2, 0x64, 0xd1, 0x3f, 0xca, 0x9e, 0xf4, 0x74, 0xf6, 0x14, 0xf5, 0xf9, 0x43,
		0xb4, 0xef, 0xfc, 0xef, 0xd1, 0xdd, 0x3f, 0x68, 0x37, 0x16, 0x4f, 0x99, 0xfd, 0xd4, 0x7e, 0x71,
		0x35, 0x68, 0x9f, 0x2e, 0x9e, 0x32, 0xfb, 0xa9, 0xdd, 0x9c, 0x3c, 0x65, 0xfb, 0x64, 0xfe, 0x94,
		0xed, 0xf3, 0xc5, 0x53, 0x3e, 0xc9, 0x87, 0x81, 0x0b, 0x18, 0x77, 0x79, 0x34, 0xa3, 0x43, 0x32,
		0x26, 0x9d, 0x25, 0xf5, 0xd3, 0x55, 0x84, 0x5c, 0x73, 0x71, 0x3f, 0xba, 0xd0, 0xdb, 0x4b, 0x17,
		0x37, 0x34, 0x8a, 0x1a, 0x7a, 0xc5, 0x0c, 0xad, 0x22, 0x86, 0x7a, 0xf1, 0x42, 0xbd, 0x68, 0xa1,
		0x5a, 0xac, 0xc8, 0x17, 0x18, 0xbf, 0x8c, 0x87, 0xc2, 0xee, 0x72, 0xd6, 0xaa, 0xbf, 0xaa, 0x1f,
		0x1d, 0x4e, 0x3b, 0x94, 0x6a, 0x35, 0xe2, 0x95, 0x55, 0xa9, 0x0c, 0xfb, 0x16, 0x44, 0xf5, 0x83,
		0xa9, 0x76, 0x50, 0x35, 0x0b, 0xae, 0x66, 0x41, 0xd6, 0x24, 0xd8, 0xea, 0x70, 0xc3, 0xe2, 0x55,
		0x86, 0xc7, 0x71, 0x92, 0x16, 0xae, 0x28, 0x4c, 0x71, 0xb6, 0x40, 0x15, 0x35, 0x8a, 0xb3, 0x32,
		0xa6, 0x44, 0x71, 0x96, 0xe2, 0x6c, 0x2e, 0x57, 0xb9, 0xe4, 0x28, 0xce, 0x9a, 0x59, 0xcd, 0x2e,
		0xf1, 0xd5, 0xa3, 0x55, 0xf3, 0xf5, 0x20, 0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0x0a, 0x42, 0x05,
		0xa1, 0x82, 0x50, 0x41, 0xa8, 0x20, 0x54, 0x10, 0x2a, 0x08, 0x15, 0x84, 0x2a, 0xff, 0x84, 0x6a,
		0x7d, 0xb6, 0x20, 0x1a, 0x0e, 0xfb, 0xc3, 0xa0, 0xd3, 0xef, 0x9a, 0x4e, 0x38, 0xdc, 0xfa, 0x14,
		0x90, 0x2f, 0xc8, 0x17, 0xe4, 0x0b, 0xf2, 0x05, 0xf9, 0xca, 0xfc, 0x2d, 0xee, 0x46, 0x49, 0x1a,
		0xa7, 0x5f, 0x86, 0xd1, 0x07, 0x45, 0x06, 0xa6, 0x91, 0xf3, 0x94, 0xeb, 0xf3, 0x47, 0x7b, 0x11,
		0x8e, 0x14, 0xdd, 0x3c, 0x53, 0xa1, 0x7f, 0xdd, 0x98, 0xdd, 0x4f, 0xd9, 0x56, 0x14, 0x7b, 0xb4,
		0x10, 0x79, 0xf4, 0xe3, 0x66, 0x25, 0xae, 0x02, 0x75, 0xbc, 0xbf, 0x67, 0x8d, 0xda, 0xe9, 0x52,
		0x7e, 0x97, 0xdd, 0x75, 0xbb, 0xbb, 0xab, 0x57, 0x27, 0xb2, 0xcd, 0x42, 0xdb, 0x3c, 0x6b, 0xba,
		0xb0, 0xbf, 0x52, 0xfb, 0x7b, 0xef, 0x65, 0x20, 0xec, 0xb2, 0xe3, 0x5d, 0x7e, 0x73, 0x76, 0xfc,
		0xb2, 0xdd, 0xaa, 0x9f, 0x4c, 0x60, 0xee, 0xcf, 0x46, 0x1d, 0xe1, 0x25, 0xa7, 0xbb, 0x3b, 0x15,
		0xe5, 0x46, 0xde, 0xc3, 0x33, 0xa2, 0x55, 0xa8, 0x12, 0xd8, 0x68, 0xfc, 0xde, 0x8f, 0x2a, 0xd8,
		0xe2, 0x83, 0x50, 0x08, 0xfb, 0xae, 0x85, 0x28, 0x84, 0x39, 0xb5, 0x0e, 0x0a, 0x61, 0x14, 0xc2,
		0xbe, 0xb1, 0x63, 0x14, 0xc2, 0x1c, 0xae, 0xe5, 0x4b, 0x21, 0x4c, 0xf7, 0xe2, 0x93, 0x2d, 0xaa,
		0x85, 0x5d, 0x9c, 0x36, 0x1b, 0xb5, 0xa3, 0xfa, 0xab, 0xfa, 0x11, 0xc4, 0xc0, 0xdd, 0xae, 0xae,
		0x54, 0xc0, 0xb8, 0xb4, 0x47, 0xdd, 0xa6, 0x0f, 0x8f, 0x8e, 0x6a, 0x8d, 0xd6, 0xe1, 0x8b, 0xe3,
		0x5a, 0x3b, 0x63, 0xc0, 0xa8, 0xdc, 0xab, 0x44, 0x93, 0x8b, 0x46, 0xe3, 0xec, 0xbc, 0x55, 0x7b,
		0xd9, 0x7e, 0x5b, 0x3b, 0x9f, 0x4a, 0xe5, 0x9e, 0x5e, 0x9c, 0xbc, 0xa8, 0x9d, 0xb3, 0xfb, 0xba,
		0xbb, 0x7f, 0x74, 0xd8, 0x38, 0x7c, 0x51, 0x3f, 0xae, 0xb7, 0xfe, 0x62, 0xe7, 0x75, 0x77, 0xfe,
		0xac, 0xd1, 0xaa, 0x9f, 0x9d, 0x1e, 0x1e, 0xb7, 0x1b, 0x87, 0xe7, 0x87, 0x27, 0xb5, 0x16, 0xb6,
		0xaf, 0x92, 0x2a, 0x1e, 0xbe, 0x6c, 0x4f, 0xd2, 0xc5, 0xfa, 0xcb, 0xda, 0x69, 0xab, 0xfe, 0xaa,
		0xce, 0xae, 0x6b, 0xed, 0xfa, 0x54, 0xdb, 0xff, 0xb0, 0xc9, 0x4d, 0x26, 0xa4, 0xc7, 0x79, 0x49,
		0xd0, 0xb6, 0x61, 0x87, 0xed, 0x13, 0xb1, 0xed, 0xda, 0x65, 0x8b, 0x84, 0x6b, 0xbb, 0x76, 0xd8,
		0x32, 0xb1, 0x2a, 0xfe, 0x4e, 0x5b, 0x26, 0x50, 0xdb, 0xb1, 0xbb, 0xea, 0x89, 0xd2, 0xd6, 0x1d,
		0xd2, 0xa1, 0xd2, 0xa6, 0xbc, 0xff, 0x27, 0x87, 0xc7, 0xaf, 0xce, 0xce, 0x4f, 0x6a, 0x2f, 0xdb,
		0x87, 0xcd, 0x76, 0xe3, 0xb0, 0xf5, 0x06, 0xd2, 0x25, 0xbf, 0xe9, 0x87, 0xad, 0xd6, 0x79, 0xfd,
		0xc5, 0x45, 0xab, 0xd6, 0x7e, 0x75, 0x7c, 0xf8, 0xba, 0xa9, 0x7d, 0x68, 0x6a, 0x7b, 0x37, 0x3e,
		0x4b, 0x40, 0x96, 0xdf, 0x00, 0x7b, 0xaf, 0xb4, 0xf7, 0xf5, 0xd3, 0xb7, 0x87, 0xc7, 0xf5, 0x97,
		0xed, 0xd3, 0x5a, 0xeb, 0x8f, 0xb3, 0xf3, 0x7f, 0xb5, 0x5f, 0xd5, 0x6b, 0xc7, 0x5c, 0x5c, 0xab,
		0x92, 0x81, 0x9f, 0xd7, 0x8e, 0xce, 0x5e, 0x9f, 0xd6, 0xff, 0x5f, 0xed, 0x65, 0xfb, 0x8f, 0xda,
		0xf1, 0x71, 0xfb, 0x5f, 0xa7, 0x67, 0x7f, 0x9c, 0x2e, 0x7d, 0x80, 0x2f, 0x41, 0x01, 0x67, 0xeb,
		0xcd, 0x66, 0xfd, 0xf4, 0x35, 0xfb, 0x6f, 0x0e, 0xb9, 0xc7, 0xb5, 0xd3, 0xd7, 0xad, 0x37, 0xc4,
		0x7d, 0x83, 0x0c, 0x73, 0xf9, 0x1d, 0xd4, 0x9b, 0x5c, 0x15, 0xaf, 0x88, 0xb9, 0x67, 0xe7, 0xf5,
		0xd7, 0x75, 0x22, 0x8e, 0x51, 0xbe, 0xf3, 0x67, 0xab, 0xfd, 0xe6, 0xac, 0x61, 0xba, 0xfb, 0x34,
		0x5a, 0x72, 0x5a, 0x1f, 0x31, 0xe4, 0xe7, 0x5b, 0x70, 0xdd, 0xab, 0x2d, 0x0f, 0xdf, 0x86, 0x53,
		0x74, 0xd6, 0x7c, 0xbb, 0xf8, 0x7b, 0x6c, 0xcc, 0xab, 0xb7, 0xa1, 0x83, 0xe5, 0x0d, 0x7f, 0xde,
		0x02, 0xbc, 0xf3, 0x82, 0x27, 0x6f, 0x13, 0xf4, 0xd9, 0xf0, 0xe1, 0xad, 0xca, 0xdc, 0x8c, 0x78,
		0xef, 0xf6, 0x60, 0x9f, 0x1d, 0xbf, 0xdd, 0xa6, 0xfc, 0xc2, 0x8e, 0xc7, 0x6e, 0x9b, 0x26, 0x08,
		0x6d, 0x70, 0x23, 0x23, 0x5f, 0x9c, 0x43, 0x98, 0x81, 0x22, 0x85, 0x1a, 0x1c, 0x38, 0x2f, 0x16,
		0xb4, 0x05, 0x09, 0xd5, 0xaa, 0xe8, 0x17, 0x31, 0x52, 0x79, 0xff, 0x5f, 0x1c, 0x2e, 0xad, 0xbb,
		0xf5, 0x57, 0x83, 0x26, 0x82, 0xc2, 0x9e, 0x1f, 0x9d, 0x9d, 0x9e, 0xd6, 0x8e, 0x5a, 0xd3, 0xc3,
		0xdf, 0x67, 0xad, 0x76, 0xf3, 0xaf, 0xd3, 0xa3, 0x37, 0xe7, 0x67, 0xd3, 0x52, 0x04, 0xdb, 0xaf,
		0x6b, 0xf2, 0xa4, 0x04, 0x00, 0x56, 0x5e, 0x02, 0xe6, 0x16, 0x08, 0x77, 0xf9, 0x10, 0x18, 0xb7,
		0xcb, 0x84, 0xc9, 0x68, 0x5d, 0xef, 0xee, 0xbd, 0x0a, 0x8a, 0xe4, 0xb5, 0xda, 0xa5, 0x97, 0xda,
		0x51, 0xad, 0xfe, 0xb6, 0xd6, 0xbe, 0x38, 0xad, 0xfd, 0xd9, 0xa8, 0x1d, 0xb5, 0x6a, 0x4b, 0x93,
		0x3f, 0x6b, 0xd4, 0x4e, 0x8f, 0xce, 0x4e, 0x5f, 0xd5, 0xcf, 0x4f, 0x48, 0xb7, 0x4c, 0xbf, 0x89,
		0x5a, 0xb3, 0x75, 0xf8, 0xe2, 0xb8, 0xde, 0x7c, 0x43, 0xe2, 0xeb, 0x81, 0x4f, 0x34, 0x6b, 0xa7,
		0x2d, 0x32, 0x61, 0x80, 0x2e, 0xaf, 0x21, 0x76, 0xab, 0x77, 0xdc, 0x24, 0x94, 0x6e, 0xbd, 0x8d,
		0xeb, 0x86, 0xcc, 0x2d, 0x51, 0x6e, 0x26, 0x59, 0xd6, 0xde, 0xf6, 0xb3, 0xd6, 0x9b, 0xda, 0x79,
		0x7b, 0x1a, 0xb0, 0x5f, 0xb7, 0x8f, 0xde, 0x1c, 0x9e, 0xbe, 0xa6, 0x0e, 0xac, 0xb1, 0xed, 0x17,
		0xad, 0xf6, 0xd9, 0xab, 0xf6, 0x79, 0xad, 0x79, 0x76, 0x71, 0x7e, 0x54, 0x6b, 0xb2, 0xe7, 0xf2,
		0x7b, 0x3e, 0x9d, 0xf6, 0x7f, 0x59, 0x9b, 0x1b, 0xfb, 0xc5, 0x39, 0xcc, 0x43, 0x63, 0xd7, 0x4f,
		0x0e, 0xff, 0x6c, 0x9f, 0x5e, 0x9c, 0xb4, 0x1b, 0xe7, 0xb5, 0x57, 0xf5, 0x3f, 0x6b, 0xcd, 0xf6,
		0x79, 0xed, 0xf0, 0x08, 0xd6, 0xa7, 0x83, 0xa9, 0x67, 0xa7, 0xa7, 0xed, 0xa3, 0xb3, 0xe3, 0xe3,
		0xfa, 0x54, 0x6e, 0x68, 0x12, 0x6d, 0x8e, 0x2f, 0x5a, 0xf5, 0xb3, 0x53, 0x36, 0x5f, 0x7e, 0xf3,
		0x0f, 0x5f, 0x9e, 0xd4, 0x4f, 0xeb, 0xcd, 0xd6, 0xf9, 0x61, 0x6b, 0x92, 0x46, 0x9e, 0xd7, 0x9a,
		0x35, 0x66, 0xe4, 0x94, 0x8c, 0x7e, 0xde, 0x49, 0x38, 0xaf, 0xfd, 0xf7, 0x34, 0x71, 0x67, 0xdb,
		0xd5, 0xcd, 0xbd, 0xf9, 0xe6, 0xa2, 0xf5, 0xf2, 0xec, 0x8f, 0x53, 0xaa, 0x4a, 0x50, 0xc0, 0x5c,
		0x70, 0x91, 0x2d, 0xd8, 0x5e, 0x33, 0xce, 0x51, 0xfc, 0xbd, 0xb5, 0xe4, 0x16, 0xdb, 0x30, 0x7a,
		0x61, 0xcd, 0x21, 0xb6, 0xe3, 0x00, 0x86, 0x31, 0x57, 0xd8, 0x82, 0x29, 0x2d, 0x53, 0x4e, 0xb0,
		0x55, 0xa7, 0x88, 0xf4, 0x73, 0xff, 0xad, 0x33, 0x5f, 0xfd, 0x1c, 0x9f, 0xfb, 0x16, 0x6d, 0xdf,
		0x5d, 0xf7, 0xbe, 0xc5, 0x34, 0xbe, 0x36, 0xbd, 0x66, 0x71, 0xba, 0x3e, 0xb7, 0x2b, 0x7e, 0xd7,
		0x42, 0xdc, 0xae, 0xe8, 0xd4, 0x3a, 0xb8, 0x5d, 0x91, 0xdb, 0x15, 0xbf, 0xb1, 0x63, 0xfa, 0xb7,
		0x2b, 0x4e, 0xe2, 0x62, 0x1a, 0x77, 0xfe, 0x77, 0xb4, 0x5f, 0x55, 0xbc, 0x5d, 0xf1, 0x37, 0x85,
		0xa5, 0x2e, 0x92, 0x38, 0x1d, 0x4d, 0x1e, 0x31, 0x09, 0x93, 0xfe, 0x28, 0xea, 0xf4, 0x93, 0xee,
		0x48, 0xe3, 0x11, 0xcf, 0xc3, 0xe4, 0x2a, 0x52, 0x3b, 0x7e, 0xa0, 0x97, 0x3d, 0x96, 0x4f, 0xe2,
		0x44, 0x2d, 0x5a, 0x2a, 0x63, 0xea, 0xda, 0xb2, 0xd3, 0x43, 0x24, 0x06, 0xeb, 0xbe, 0x1a, 0x86,
		0x9d, 0x49, 0xbe, 0xf2, 0x32, 0xbe, 0x9a, 0x59, 0xef, 0x4e, 0x11, 0x29, 0x4f, 0xf9, 0x24, 0xfc,
		0xbc, 0x75, 0xa6, 0xb4, 0xfb, 0x5b, 0xb5, 0xba, 0x7f, 0x50, 0xad, 0xee, 0x1c, 0x3c, 0x3b, 0xd8,
		0x79, 0xbe, 0xb7, 0xb7, 0xbb, 0xaf, 0x71, 0xc7, 0xac, 0x37, 0xd6, 0xf5, 0xa4, 0x18, 0xab, 0x5c,
		0xe6, 0x95, 0xed, 0x3d, 0xc9, 0x51, 0xcc, 0x28, 0x1f, 0x26, 0x49, 0x3f, 0x9d, 0x12, 0x37, 0xd1,
		0x30, 0x51, 0x1e, 0x75, 0x3e, 0x46, 0xd7, 0xe1, 0x20, 0x4c, 0x3f, 0x4e, 0x12, 0x85, 0xa7, 0xfd,
		0x41, 0x94, 0x74, 0xa6, 0xec, 0x2a, 0x48, 0xa2, 0xf4, 0xef, 0xfe, 0xf0, 0x7f, 0x83, 0x38, 0x19,
		0xa5, 0x61, 0xd2, 0x89, 0x9e, 0xde, 0xfd, 0x83, 0xd1, 0xda, 0x9f, 0x3c, 0x1d, 0x0c, 0xfb, 0x69,
		0xbf, 0xd3, 0xef, 0x8d, 0xb2, 0x9f, 0x9e, 0xbe, 0xbf, 0x1a, 0x3c, 0x4d, 0xa2, 0xf8, 0xea, 0xe3,
		0xfb, 0xfe, 0x70, 0x94, 0xfd, 0xf4, 0x74, 0x94, 0x86, 0x69, 0xf4, 0xf4, 0x3a, 0x1a, 0x8d, 0xc2,
		0xab, 0x68, 0xf4, 0x74, 0x34, 0x49, 0x92, 0x05, 0xe9, 0xf8, 0x28, 0x1d, 0x8e, 0x3b, 0x69, 0xb2,
		0xe8, 0x1d, 0x65, 0x4f, 0x79, 0x3a, 0x7b, 0x82, 0xfa, 0xfc, 0x01, 0xda, 0x77, 0xfe, 0xf7, 0xe8,
		0xee, 0x1f, 0xb4, 0x1b, 0x8b, 0x27, 0xcc, 0x7e, 0x6a, 0xbf, 0xb8, 0x1a, 0xb4, 0x4f, 0x17, 0x4f,
		0x98, 0xfd, 0xd4, 0x6e, 0x4e, 0x9e, 0xb0, 0x7d, 0x32, 0x7f, 0xc2, 0x76, 0x73, 0xf2, 0x84, 0x4f,
		0xf2, 0x61, 0xd8, 0x6e, 0xdf, 0xd1, 0xb1, 0x8b, 0x48, 0xbb, 0x86, 0x27, 0x2e, 0x21, 0xe0, 0x0d,
		0xf6, 0x5e, 0xe0, 0xd6, 0x01, 0xdc, 0x99, 0xa9, 0x43, 0x13, 0x2d, 0x2f, 0xbe, 0xcf, 0x20, 0xec,
		0x76, 0x87, 0xd1, 0x68, 0xe4, 0xdc, 0x48, 0x33, 0xe6, 0xba, 0xb6, 0x92, 0x63, 0x47, 0x93, 0x49,
		0x17, 0xc5, 0xaa, 0x77, 0x92, 0xd5, 0x3a, 0xf9, 0xea, 0x9c, 0x74, 0x35, 0x4e, 0xad, 0xfa, 0xa6,
		0x56, 0x6d, 0x53, 0xa9, 0xae, 0xf9, 0x0d, 0x85, 0x62, 0xd5, 0xb2, 0xcc, 0xde, 0xe3, 0x81, 0x50,
		0x74, 0xb9, 0x1d, 0x61, 0x76, 0x9f, 0x0b, 0xbc, 0xf7, 0x7c, 0x6f, 0x64, 0x8a, 0x50, 0x82, 0x19,
		0xf9, 0x72, 0xe7, 0x3f, 0x55, 0x05, 0xf7, 0x7e, 0xed, 0x3b, 0x10, 0xac, 0x48, 0x96, 0x1b, 0x61,
		0x9a, 0x46, 0xc3, 0x44, 0xbc, 0x26, 0x58, 0xfe, 0xe9, 0xa7, 0x77, 0x3b, 0xc1, 0xf3, 0xcb, 0x7f,
		0xde, 0xed, 0x06, 0xcf, 0x2f, 0x67, 0x3f, 0xee, 0x4e, 0xff, 0x33, 0xfb, 0xb9, 0xf2, 0x6e, 0x27,
		0xa8, 0x2e, 0x7e, 0xde, 0x7b, 0xb7, 0x13, 0xec, 0x5d, 0xfe, 0xfc, 0xef, 0x7f, 0xff, 0xfa, 0xf3,
		0x7f, 0x9e, 0xdd, 0x7c, 0xff, 0x2f, 0xca, 0x95, 0xf2, 0x2f, 0x25, 0xbf, 0x8a, 0xb3, 0x66, 0xfd,
		0x4f, 0xb5, 0xef, 0xe3, 0x7f, 0x34, 0xbf, 0x90, 0xff, 0x12, 0xfc, 0x46, 0xf2, 0x54, 0x3c, 0xd0,
		0x09, 0x4e, 0xfb, 0x04, 0xa7, 0x1f, 0x0a, 0x4e, 0x61, 0xf0, 0xe1, 0x30, 0x78, 0x75, 0xf9, 0x9f,
		0xdd, 0x5f, 0xaa, 0x37, 0xbf, 0xff, 0xfc, 0x9f, 0x83, 0x9b, 0xbb, 0x7f, 0xf8, 0xcf, 0x7d, 0xff,
		0x6c, 0xf7, 0x97, 0x83, 0x9b, 0xdf, 0x1f, 0xf8, 0x9b, 0xfd, 0x9b, 0xdf, 0x1f, 0xf9, 0x1e, 0x7b,
		0x37, 0x3f, 0xad, 0xfd, 0xd3, 0xc9, 0x9f, 0x57, 0x1e, 0xfa, 0x85, 0xea, 0x03, 0xbf, 0xf0, 0xec,
		0xa1, 0x5f, 0x78, 0xf6, 0xc0, 0x2f, 0x3c, 0xf8, 0x91, 0x2a, 0x0f, 0xfc, 0xc2, 0xde, 0xcd, 0x3f,
		0x6b, 0xff, 0xfe, 0xa7, 0xfb, 0xff, 0xe9, 0xfe, 0xcd, 0xcf, 0xff, 0x3c, 0xf4, 0x77, 0x07, 0x37,
		0xff, 0xfc, 0xfe, 0x33, 0xa1, 0xfa, 0xf1, 0xa1, 0x1a, 0xf3, 0xd4, 0x37, 0xcf, 0xfc, 0x01, 0xd7,
		0x13, 0xbf, 0x3f, 0xa7, 0x9f, 0x95, 0xa1, 0x41, 0x14, 0x0d, 0x83, 0x50, 0xb0, 0x20, 0xb4, 0x58,
		0x80, 0x3a, 0x10, 0x75, 0x20, 0xea, 0x40, 0xd4, 0x81, 0x1c, 0xda, 0x7b, 0x38, 0x0a, 0x92, 0xf1,
		0xf5, 0xfb, 0x68, 0x28, 0x58, 0x06, 0x3a, 0x10, 0x78, 0x6b, 0xd9, 0xb3, 0x48, 0x82, 0x4c, 0x4b,
		0xe3, 0xac, 0x91, 0xd6, 0x79, 0x5d, 0xa5, 0xb3, 0x44, 0x9a, 0xa7, 0x3b, 0x24, 0xcf, 0x8e, 0x6b,
		0x9c, 0x0d, 0xd2, 0xfe, 0xea, 0xab, 0x95, 0xe7, 0xd5, 0xe7, 0xfb, 0x07, 0x95, 0xe7, 0x7b, 0x05,
		0xb2, 0x01, 0x72, 0x6b, 0xbf, 0x72, 0xeb, 0xab, 0x61, 0x7f, 0x3c, 0x10, 0x4e, 0xaf, 0x67, 0x6b,
		0x90, 0x61, 0x93, 0x61, 0x93, 0x61, 0x93, 0x61, 0x3b, 0xb4, 0xf7, 0x5e, 0x14, 0x7e, 0x18, 0x46,
		0x1f, 0x24, 0xdb, 0xac, 0x12, 0x09, 0x76, 0x63, 0x7e, 0x4e, 0xea, 0xd7, 0x5f, 0x9f, 0x66, 0xff,
		0xb7, 0x0c, 0x94, 0xa3, 0x5b, 0x3f, 0xdf, 0xfa, 0x31, 0x98, 0x9e, 0x41, 0xda, 0x16, 0x58, 0x4a,
		0x25, 0x6c, 0x67, 0x15, 0x95, 0xa6, 0x4b, 0x00, 0x4a, 0x80, 0x12, 0xa0, 0x04, 0x28, 0xe5, 0x20,
		0xb8, 0xac, 0xc0, 0x52, 0x55, 0xe0, 0xbd, 0x6b, 0xc9, 0xf8, 0x7a, 0xb2, 0x35, 0x37, 0x5b, 0x00,
		0x32, 0xff, 0x37, 0x8e, 0x66, 0x7a, 0xbf, 0x42, 0x08, 0x33, 0x7f, 0x7f, 0x19, 0x78, 0xd9, 0x05,
		0x5e, 0x80, 0x17, 0xe0, 0xc5, 0x47, 0x78, 0x79, 0x19, 0x0f, 0x65, 0xcc, 0x3d, 0x4e, 0x06, 0xe3,
		0x54, 0xce, 0x16, 0xb3, 0x43, 0x4a, 0xd3, 0x65, 0x84, 0xcc, 0x43, 0xb6, 0x7e, 0x2a, 0x2e, 0x71,
		0xa1, 0x21, 0x6d, 0xa1, 0x27, 0x69, 0xa1, 0x25, 0x65, 0xa1, 0x2e, 0x61, 0xa1, 0x2e, 0x5d, 0xa1,
		0x2a, 0x59, 0x91, 0xaf, 0x91, 0x4c, 0x71, 0x69, 0x8a, 0xcc, 0x5f, 0xc6, 0x71, 0x92, 0x3e, 0xab,
		0x28, 0x9c, 0xab, 0x3c, 0x10, 0x5c, 0x42, 0x47, 0x05, 0x42, 0x41, 0x28, 0x44, 0x53, 0xf5, 0x41,
		0x79, 0x44, 0x5f, 0x5b, 0xe5, 0xc1, 0x62, 0xfe, 0x5e, 0x41, 0xd5, 0x41, 0x55, 0xcd, 0xc1, 0xca,
		0x44, 0xb4, 0x3a, 0xb8, 0xa6, 0xb6, 0x92, 0x53, 0x6d, 0x83, 0xbc, 0x9c, 0xf2, 0x14, 0xf0, 0xc5,
		0x72, 0x7f, 0x9c, 0xaa, 0xb0, 0x89, 0xf9, 0x3a, 0xd0, 0x09, 0xe8, 0x04, 0x74, 0x02, 0x3a, 0x01,
		0x9d, 0x80, 0x4e, 0x40, 0x27, 0xa0, 0x13, 0xd0, 0x09, 0xe8, 0x04, 0x74, 0xc2, 0x88, 0x4e, 0xa0,
		0x53, 0x65, 0xa6, 0x53, 0x25, 0xd2, 0x14, 0x2e, 0x99, 0xaa, 0x54, 0xfd, 0x7f, 0xb3, 0x47, 0xda,
		0x82, 0x13, 0x03, 0xc3, 0xe8, 0xba, 0xff, 0x29, 0x0a, 0x06, 0xc3, 0xf8, 0x53, 0x98, 0x46, 0xa2,
		0x33, 0x89, 0xeb, 0x4b, 0x71, 0x4c, 0x8d, 0x73, 0x04, 0xe6, 0x8c, 0x98, 0x73, 0x04, 0x7a, 0x40,
		0x28, 0x7f, 0x4c, 0x6d, 0x2d, 0xc8, 0x04, 0xfd, 0xc1, 0x14, 0x78, 0x05, 0x4f, 0xad, 0x09, 0xe4,
		0xad, 0xe5, 0x7a, 0x37, 0x4a, 0xd2, 0x38, 0xfd, 0xf2, 0x22, 0x1c, 0x45, 0xf2, 0x15, 0xcd, 0xf3,
		0xda, 0xc9, 0xd9, 0xdb, 0x5a, 0xbb, 0x71, 0x5e, 0x7f, 0x7b, 0xd8, 0xaa, 0xb5, 0x0f, 0x9b, 0xed,
		0xb3, 0xc6, 0xf4, 0x8e, 0x2c, 0x21, 0x4f, 0x50, 0xb8, 0x97, 0x5e, 0xe9, 0x76, 0x95, 0x5b, 0x5b,
		0x36, 0xdf, 0xc4, 0xc3, 0xe3, 0xe3, 0x72, 0x1e, 0x87, 0x0d, 0x2d, 0x36, 0xac, 0x71, 0x7c, 0x78,
		0x24, 0xbd, 0x63, 0x4f, 0xf2, 0xc1, 0x8b, 0xb6, 0xe1, 0x78, 0xea, 0xb0, 0x3f, 0x4e, 0xa3, 0xe0,
		0x43, 0x2f, 0x1c, 0x04, 0xdd, 0xf0, 0x7a, 0x10, 0x27, 0x57, 0x82, 0xd9, 0xe6, 0xfa, 0x5a, 0xae,
		0x0f, 0xc5, 0x45, 0x1f, 0xc2, 0x71, 0x6f, 0x8a, 0xe6, 0x1f, 0xc2, 0xde, 0x88, 0xa9, 0x0b, 0xd2,
		0x59, 0xd2, 0x59, 0xd2, 0x59, 0xa7, 0xf6, 0xfe, 0xbe, 0xdf, 0xef, 0x45, 0xa1, 0x68, 0xf6, 0xba,
		0xbb, 0x05, 0xc0, 0x33, 0x8a, 0x92, 0x6e, 0xd0, 0xe9, 0x5f, 0x5f, 0x8f, 0x93, 0x38, 0xfd, 0x22,
		0x07, 0x3a, 0x77, 0xd6, 0x91, 0x03, 0x9c, 0xd3, 0xb3, 0xd3, 0x1a, 0x78, 0x03, 0xde, 0x80, 0x37,
		0xe0, 0x8d, 0x4b, 0x7b, 0xcf, 0x62, 0x17, 0xa3, 0x7e, 0xde, 0x43, 0xda, 0x68, 0x14, 0xf7, 0x93,
		0x60, 0xda, 0x83, 0x91, 0x44, 0xb4, 0xdb, 0xcb, 0x80, 0x38, 0x20, 0x0e, 0x88, 0x03, 0xe2, 0x38,
		0xb4, 0xf7, 0x28, 0x19, 0x5f, 0x47, 0xc3, 0x50, 0xba, 0x46, 0x0f, 0xdc, 0x6c, 0x08, 0x37, 0xe3,
		0xc1, 0xa0, 0x3f, 0x4c, 0xa3, 0x6e, 0xd0, 0x09, 0x07, 0xe1, 0xfb, 0xb8, 0x17, 0xa7, 0xb1, 0xe4,
		0xa4, 0xf9, 0x03, 0xeb, 0x01, 0x40, 0x00, 0x10, 0x00, 0x04, 0x00, 0x39, 0xb4, 0xf7, 0x78, 0xde,
		0x69, 0x15, 0x56, 0xdc, 0xca, 0x7f, 0x93, 0xf8, 0xc5, 0xeb, 0x46, 0xfb, 0xe8, 0xb0, 0x71, 0xf8,
		0xa2, 0x7e, 0x5c, 0x6f, 0xfd, 0x45, 0x6b, 0xf8, 0x5b, 0xfb, 0x75, 0xf8, 0xf2, 0x65, 0xbb, 0x71,
		0xd8, 0x7a, 0xd3, 0xa4, 0x1d, 0xfc, 0xf0, 0x26, 0xbd, 0x3e, 0x3f, 0x3c, 0xaa, 0xbd, 0xba, 0x38,
		0x6e, 0x9f, 0xd7, 0x9a, 0xad, 0xc3, 0xf3, 0x16, 0x7b, 0xf5, 0x15, 0x83, 0x6a, 0x9e, 0x3e, 0xab,
		0xb0, 0x41, 0x0f, 0x6f, 0xd0, 0x49, 0xe3, 0xc5, 0xeb, 0x06, 0x1b, 0xf4, 0xf0, 0x06, 0xd5, 0xfe,
		0x6c, 0xd5, 0x4e, 0x5f, 0xd6, 0x5e, 0xb6, 0x4f, 0x6b, 0x7f, 0xb6, 0xde, 0x9c, 0x35, 0xda, 0xb5,
		0xd3, 0xa3, 0xb3, 0x97, 0xf5, 0xd3, 0xd7, 0x6c, 0xda, 0xc3, 0x9b, 0x76, 0x7e, 0x76, 0xd1, 0xaa,
		0xb5, 0xcf, 0x6b, 0xaf, 0xce, 0x6b, 0xcd, 0x37, 0x1c, 0x54, 0xf1, 0x3b, 0x5f, 0x3c, 0x8e, 0x47,
		0xe9, 0x61, 0x9a, 0x0a, 0xc9, 0x15, 0x9d, 0xc4, 0x49, 0xad, 0x17, 0x4d, 0x32, 0xf2, 0x91, 0xcc,
		0xa0, 0x4c, 0xf9, 0x24, 0xfc, 0x7c, 0x6b, 0x85, 0xdd, 0xdf, 0xaa, 0xd5, 0xfd, 0x83, 0x6a, 0x75,
		0xe7, 0xe0, 0xd9, 0xc1, 0xce, 0xf3, 0xbd, 0xbd, 0xdd, 0x7d, 0x91, 0x3c, 0xf2, 0x6c, 0xd8, 0x8d,
		0x86, 0x51, 0xf7, 0xc5, 0x97, 0xf2, 0xef, 0xa5, 0x64, 0xdc, 0xeb, 0xf9, 0x5a, 0xcf, 0x78, 0xe2,
		0x91, 0xc5, 0x49, 0x0d, 0x75, 0xd8, 0x0e, 0x73, 0x94, 0x5d, 0x96, 0x8c, 0x8c, 0xa6, 0x37, 0xdc,
		0x84, 0xe8, 0xcd, 0x8d, 0xcd, 0x81, 0xa1, 0x95, 0xd3, 0xf8, 0x3a, 0x1a, 0xba, 0x2b, 0xb3, 0x65,
		0x98, 0x36, 0x7f, 0x5f, 0x47, 0xae, 0xe0, 0x56, 0xc0, 0xd1, 0x79, 0xf9, 0x4c, 0xa2, 0x6c, 0x26,
		0x57, 0x2e, 0x93, 0x2a, 0x93, 0x89, 0x97, 0xc7, 0xc4, 0xcb, 0x62, 0xa2, 0xe5, 0x30, 0xbf, 0xc0,
		0xc5, 0xb5, 0xe0, 0x62, 0xb9, 0xb3, 0xf0, 0x29, 0xa1, 0x7a, 0xfd, 0xfc, 0xfd, 0x51, 0x86, 0xa5,
		0x3e, 0x6f, 0x16, 0x80, 0xd4, 0x02, 0x91, 0x4a, 0x40, 0xca, 0x07, 0xdf, 0x12, 0x53, 0x86, 0xed,
		0xf4, 0x93, 0x24, 0xea, 0xa4, 0xc1, 0x30, 0x4a, 0x87, 0x5f, 0xe4, 0x8b, 0xdb, 0xab, 0xcb, 0x09,
		0x99, 0xcb, 0xad, 0x03, 0x9c, 0xcf, 0x76, 0xd0, 0x8f, 0x52, 0x8f, 0xa1, 0xff, 0x3f, 0x7b, 0x6f,
		0xd7, 0xd4, 0x36, 0xb2, 0xb5, 0x7f, 0x9f, 0xe7, 0x53, 0x50, 0xaa, 0x7d, 0x90, 0x54, 0x45, 0x63,
		0x0c, 0x06, 0x42, 0xce, 0xc8, 0x84, 0xd9, 0x0f, 0xff, 0x9b, 0x04, 0x0a, 0x92, 0xdc, 0xfb, 0xae,
		0x0c, 0xdb, 0x25, 0x6c, 0x41, 0x34, 0x63, 0x24, 0x97, 0x24, 0x33, 0x49, 0x4d, 0xf8, 0xee, 0x4f,
		0xf9, 0x4d, 0xc6, 0x18, 0x26, 0x10, 0xab, 0xd7, 0x5a, 0x92, 0x7f, 0xd4, 0xae, 0x8d, 0x87, 0x80,
		0xbb, 0xdd, 0x5a, 0x2f, 0xd7, 0xb5, 0x56, 0xf7, 0xd5, 0x72, 0xb1, 0x54, 0x2a, 0xa6, 0x8a, 0xc7,
		0x56, 0xf1, 0x18, 0x2b, 0x1a, 0x6b, 0xdd, 0xd6, 0xe2, 0xaa, 0xaf, 0x1f, 0xd5, 0x0d, 0x3b, 0xd1,
		0x55, 0xd0, 0xdb, 0x6e, 0x49, 0xdc, 0xf4, 0xbf, 0xe1, 0x70, 0x8c, 0x05, 0x09, 0x98, 0x0d, 0x04,
		0xab, 0x7e, 0xfc, 0x41, 0x34, 0x04, 0xab, 0x36, 0x10, 0xac, 0x32, 0x1e, 0x7f, 0xe6, 0x4d, 0x44,
		0x41, 0xb0, 0x6a, 0x13, 0x13, 0xb1, 0x9d, 0xf8, 0xdc, 0xbf, 0xfb, 0x2a, 0xcb, 0xde, 0x7e, 0x49,
		0x7a, 0x5d, 0x3f, 0x8f, 0xae, 0x04, 0xb6, 0x00, 0xcd, 0x86, 0x72, 0xcf, 0x90, 0x76, 0x61, 0x48,
		0x30, 0x24, 0x18, 0x12, 0x0c, 0x09, 0x86, 0x04, 0x43, 0x82, 0x21, 0xc1, 0x90, 0x60, 0x48, 0x30,
		0x24, 0x18, 0x12, 0x0c, 0xe9, 0xe9, 0x66, 0xf2, 0x67, 0x18, 0xf6, 0x83, 0x5e, 0x74, 0x1d, 0xfa,
		0x51, 0x9c, 0x87, 0xe9, 0x75, 0xd0, 0x73, 0x4f, 0x95, 0xee, 0x19, 0x93, 0xae, 0x12, 0x9c, 0x09,
		0xce, 0x04, 0x67, 0x82, 0x33, 0xc1, 0x99, 0xe0, 0x4c, 0x70, 0x26, 0x38, 0x13, 0x9c, 0x09, 0xce,
		0x04, 0x67, 0x32, 0xc9, 0x99, 0xae, 0xa2, 0x38, 0xba, 0x1a, 0x5c, 0xf9, 0x41, 0xf7, 0x3a, 0x4c,
		0xf3, 0x28, 0x1b, 0x9d, 0x49, 0x12, 0xe4, 0x4f, 0x3f, 0x18, 0x1f, 0x2e, 0x05, 0x97, 0x82, 0x4b,
		0xc1, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0x05, 0x97, 0x82, 0x4b, 0xc1,
		0xa5, 0x8c, 0xbd, 0x23, 0x37, 0x49, 0x3e, 0x4e, 0x7c, 0x60, 0x7c, 0x1e, 0xbd, 0xe1, 0xe4, 0x14,
		0xe9, 0x9a, 0x92, 0x18, 0xc1, 0x87, 0xd1, 0x67, 0x6a, 0x4f, 0xe8, 0xd8, 0x2a, 0x68, 0x84, 0x3a,
		0x96, 0xa2, 0x76, 0x28, 0x41, 0xed, 0xec, 0x84, 0xf1, 0x06, 0x27, 0x8c, 0xe5, 0xb8, 0x36, 0x27,
		0x8c, 0x6b, 0x98, 0xf2, 0x38, 0x61, 0xfc, 0x94, 0xc5, 0xa2, 0x7e, 0xa9, 0x1a, 0x43, 0xe5, 0x62,
		0xa9, 0x54, 0x4c, 0x15, 0x8f, 0xad, 0xe2, 0x31, 0x56, 0x34, 0xd6, 0xba, 0x25, 0x5a, 0xd4, 0x2f,
		0x9f, 0x04, 0xfa, 0xa8, 0x5f, 0x3e, 0xe9, 0x8b, 0xfa, 0x25, 0xc5, 0x29, 0x95, 0xf8, 0x33, 0x6f,
		0x22, 0xd4, 0x2f, 0x2b, 0x6d, 0x22, 0xd4, 0x2f, 0x9d, 0xce, 0x97, 0x13, 0xc6, 0x8f, 0x66, 0x48,
		0x9c, 0x30, 0x86, 0x21, 0xc1, 0x90, 0x60, 0x48, 0x30, 0x24, 0x18, 0x12, 0x0c, 0x09, 0x86, 0x04,
		0x43, 0x82, 0x21, 0xc1, 0x90, 0x60, 0x48, 0x3f, 0x61, 0x26, 0x9c, 0x30, 0x86, 0x33, 0xc1, 0x99,
		0xe0, 0x4c, 0x70, 0x26, 0x38, 0x13, 0x9c, 0x09, 0xce, 0x04, 0x67, 0x82, 0x33, 0xc1, 0x99, 0xe0,
		0x4c, 0x70, 0xa6, 0x87, 0xcd, 0x84, 0x13, 0xc6, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0x05,
		0x97, 0x82, 0x4b, 0xc1, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0xf5, 0x74,
		0x33, 0x89, 0xc3, 0xcb, 0x24, 0x8f, 0x82, 0x3c, 0xec, 0xfa, 0x82, 0x9b, 0xf5, 0xee, 0x1d, 0x15,
		0x4a, 0x03, 0xa5, 0x81, 0xd2, 0x40, 0x69, 0xa0, 0x34, 0x50, 0x1a, 0x28, 0x0d, 0x94, 0x06, 0x4a,
		0x03, 0xa5, 0x81, 0xd2, 0xd4, 0x9c, 0xd2, 0x20, 0x9a, 0xa4, 0x27, 0x9a, 0xe4, 0x42, 0x17, 0x67,
		0x4d, 0x57, 0x33, 0xe9, 0x74, 0xf4, 0x91, 0xac, 0x4a, 0x26, 0x3d, 0x33, 0x64, 0xe4, 0xae, 0x8c,
		0x5b, 0xd9, 0xa8, 0xbd, 0x52, 0x65, 0xa9, 0x94, 0xcc, 0xb8, 0x1c, 0x03, 0x5e, 0xde, 0xdc, 0x4a,
		0x30, 0x35, 0x2f, 0x4f, 0x83, 0x38, 0xeb, 0x27, 0x69, 0x5e, 0x9a, 0x95, 0x15, 0xec, 0x6b, 0xf6,
		0xd6, 0x25, 0xb9, 0x44, 0xb9, 0x9a, 0x5e, 0xa5, 0x97, 0x86, 0x5c, 0x94, 0x82, 0xdc, 0x95, 0x7e,
		0x5c, 0x95, 0x7a, 0x9c, 0x97, 0x76, 0x9c, 0x97, 0x72, 0x9c, 0x96, 0x6e, 0x6c, 0x25, 0x99, 0xb2,
		0x35, 0xb8, 0xbc, 0xce, 0xd4, 0xa7, 0x1c, 0x69, 0x05, 0x3a, 0x11, 0x92, 0x74, 0x2e, 0x16, 0xb8,
		0x8e, 0x58, 0xa0, 0xfb, 0xc0, 0x23, 0x16, 0x80, 0xc4, 0x02, 0x91, 0x48, 0x40, 0xaa, 0x06, 0xd5,
		0x73, 0x26, 0x16, 0xd8, 0x4b, 0x3a, 0x41, 0xcf, 0x0f, 0xba, 0xdd, 0x34, 0xcc, 0x32, 0xf7, 0x9d,
		0xb5, 0xf9, 0xe1, 0x68, 0xa9, 0x49, 0x87, 0x37, 0xb9, 0x30, 0x27, 0x15, 0xee, 0xc4, 0xc3, 0x9e,
		0x78, 0xf8, 0x13, 0x0d, 0x83, 0x6e, 0x6b, 0x7f, 0xd5, 0x6f, 0xa9, 0x0d, 0xe2, 0x28, 0x89, 0x25,
		0xda, 0x69, 0xbb, 0x0e, 0xc7, 0x98, 0x2c, 0x57, 0xe5, 0x1b, 0x5c, 0xd3, 0x87, 0x12, 0xf5, 0x1d,
		0xa7, 0x14, 0xe9, 0x27, 0x24, 0xfb, 0xa4, 0xe4, 0x9e, 0xd8, 0x3d, 0x4f, 0xee, 0xba, 0x25, 0xf8,
		0xec, 0x16, 0x9e, 0xe1, 0x2b, 0xc1, 0x31, 0x8f, 0x83, 0x3c, 0x0f, 0xd3, 0x58, 0xec, 0x71, 0x16,
		0x03, 0x3f, 0x7f, 0xfe, 0x79, 0xdd, 0xdf, 0x3d, 0xfb, 0xfe, 0xb9, 0xe9, 0xef, 0x9e, 0x8d, 0x5f,
		0x36, 0x47, 0xdf, 0xc6, 0xaf, 0x37, 0x3e, 0xaf, 0xfb, 0xad, 0xe9, 0xeb, 0xad, 0xcf, 0xeb, 0xfe,
		0xd6, 0xd9, 0x8b, 0xdf, 0x7f, 0xff, 0xe5, 0xc5, 0xdf, 0x9b, 0x37, 0x4f, 0xff, 0x43, 0x4f, 0xec,
		0xa3, 0x9d, 0x49, 0x3e, 0xba, 0xa3, 0xd3, 0x83, 0xff, 0xa8, 0x3d, 0xbf, 0xff, 0x4a, 0x3e, 0xc0,
		0x7f, 0x09, 0x3e, 0x41, 0x91, 0x91, 0x6e, 0x5e, 0xd6, 0x38, 0x78, 0x6e, 0x13, 0x3c, 0x45, 0x82,
		0x67, 0xe0, 0x5f, 0xec, 0xf9, 0xbf, 0x9d, 0xfd, 0xdd, 0x7c, 0xd9, 0xba, 0x79, 0xfd, 0xe2, 0xef,
		0x9d, 0x9b, 0xbb, 0x3f, 0xfc, 0x7e, 0xdf, 0xaf, 0x35, 0x5f, 0xee, 0xdc, 0xbc, 0x7e, 0xe0, 0x5f,
		0xb6, 0x6f, 0x5e, 0x3f, 0xf2, 0x3d, 0xb6, 0x6e, 0x9e, 0x2f, 0xfc, 0xea, 0xf0, 0xe7, 0x1b, 0x0f,
		0xfd, 0x41, 0xeb, 0x81, 0x3f, 0xd8, 0x7c, 0xe8, 0x0f, 0x36, 0x1f, 0xf8, 0x83, 0x07, 0xa7, 0xb4,
		0xf1, 0xc0, 0x1f, 0x6c, 0xdd, 0x7c, 0x5f, 0xf8, 0xfd, 0xe7, 0xf7, 0xff, 0xea, 0xf6, 0xcd, 0x8b,
		0xef, 0x0f, 0xfd, 0xdb, 0xce, 0xcd, 0xf7, 0xd7, 0x2f, 0x48, 0x25, 0xee, 0x52, 0x09, 0xe6, 0x2c,
		0x6f, 0xce, 0xf5, 0x4b, 0xac, 0xcf, 0xaa, 0xfd, 0x39, 0x1c, 0x03, 0x03, 0x41, 0xfe, 0x9b, 0xe5,
		0x69, 0x14, 0x5f, 0x4a, 0x72, 0xdf, 0x57, 0x6c, 0x3c, 0x73, 0x3a, 0x5f, 0x27, 0xba, 0x04, 0xf9,
		0xc0, 0xef, 0x46, 0x59, 0x27, 0xb9, 0x0e, 0x25, 0xee, 0x05, 0x9a, 0x1f, 0xce, 0xbd, 0xea, 0xc0,
		0x45, 0xd0, 0xcb, 0x38, 0xa5, 0xf3, 0x10, 0xea, 0xa0, 0xa5, 0xf0, 0x33, 0x4f, 0x9d, 0x96, 0x82,
		0xf9, 0xa8, 0x5e, 0xfd, 0x96, 0xc2, 0x79, 0x92, 0xf4, 0xc2, 0x40, 0xa4, 0xa9, 0xd0, 0x5c, 0xe1,
		0xf4, 0xd7, 0x0f, 0xb2, 0x2c, 0xba, 0x0e, 0xfd, 0xab, 0xa4, 0x2b, 0x70, 0x84, 0x74, 0x6e, 0x34,
		0x92, 0x1f, 0xc9, 0x8f, 0xe4, 0x47, 0xf2, 0x23, 0xf9, 0x91, 0xfc, 0x74, 0x92, 0x5f, 0xde, 0xe9,
		0xfb, 0x57, 0x12, 0x1b, 0xbc, 0xa6, 0x03, 0x91, 0x8a, 0x48, 0x45, 0xa4, 0x22, 0x52, 0x51, 0x85,
		0x52, 0xd1, 0x20, 0x8a, 0xf3, 0xe6, 0xb6, 0x40, 0x26, 0xda, 0x46, 0xbc, 0xe0, 0xc7, 0x1f, 0x44,
		0x43, 0xbc, 0x60, 0x9d, 0x93, 0xe9, 0xc6, 0xc3, 0xc1, 0xbc, 0x89, 0x28, 0x88, 0x17, 0x48, 0x9b,
		0xc8, 0xf6, 0xd6, 0xd6, 0xe6, 0x16, 0x02, 0x06, 0xd6, 0xde, 0x1d, 0x01, 0x83, 0x52, 0x50, 0x4f,
		0x5d, 0x05, 0x0c, 0xa6, 0x27, 0x7f, 0x1b, 0x4e, 0xce, 0xeb, 0xad, 0x69, 0x9d, 0xfe, 0x9e, 0x7e,
		0xac, 0xf6, 0x84, 0x27, 0x59, 0x15, 0x32, 0x28, 0xf5, 0x90, 0x7d, 0x90, 0x87, 0xee, 0xce, 0x73,
		0xba, 0xd0, 0xb8, 0x70, 0x7e, 0x9c, 0x73, 0x83, 0xe3, 0x9c, 0x72, 0x24, 0x98, 0xe3, 0x9c, 0x35,
		0x4c, 0x7c, 0x1c, 0xe7, 0x34, 0x83, 0xbc, 0xa9, 0xf9, 0x99, 0x0a, 0x77, 0xe2, 0x61, 0x4f, 0x3c,
		0xfc, 0x89, 0x86, 0x41, 0xb7, 0x4c, 0x88, 0xe3, 0x9c, 0x8f, 0xc6, 0x62, 0x1c, 0xe7, 0x7c, 0xfc,
		0x43, 0xe1, 0x38, 0x67, 0x45, 0x9e, 0xd8, 0x3d, 0x4f, 0x8e, 0xe3, 0x9c, 0xce, 0x07, 0xe6, 0x38,
		0xe7, 0xd2, 0x8f, 0x8e, 0xe3, 0x9c, 0x2e, 0x9e, 0x20, 0xc7, 0x39, 0x97, 0x0d, 0x9e, 0x1c, 0xe7,
		0x94, 0x09, 0x9e, 0x9c, 0x7f, 0xe3, 0x38, 0x67, 0x8d, 0x52, 0x09, 0xe6, 0xcc, 0x71, 0x4e, 0xa3,
		0x25, 0x02, 0xb9, 0xcf, 0xc1, 0x71, 0xce, 0x25, 0x52, 0x3f, 0x6d, 0x78, 0xa7, 0xf3, 0x75, 0xb1,
		0xa5, 0x77, 0x5c, 0x7b, 0x2f, 0x55, 0xba, 0xfa, 0x41, 0x8b, 0xbc, 0x35, 0x16, 0x45, 0xfe, 0xfb,
		0x71, 0x00, 0x45, 0xfe, 0x9f, 0x79, 0xea, 0x14, 0xf9, 0xcd, 0xc7, 0xd9, 0xea, 0x17, 0xf9, 0x87,
		0x71, 0xcb, 0x8f, 0x07, 0x57, 0xe7, 0x61, 0xca, 0xee, 0x5e, 0x1b, 0x50, 0x87, 0xdd, 0xbd, 0xe5,
		0x8d, 0xc7, 0xee, 0xde, 0xca, 0x9a, 0x08, 0xbb, 0x7b, 0xa1, 0x15, 0xc6, 0x68, 0x05, 0x2a, 0x31,
		0x90, 0x18, 0x48, 0x0c, 0x24, 0x06, 0x12, 0x63, 0x8b, 0xc4, 0x70, 0x50, 0x5e, 0x24, 0xfd, 0xa1,
		0x12, 0x43, 0xf2, 0x23, 0xf9, 0x91, 0xfc, 0x48, 0x7e, 0x24, 0xbf, 0x95, 0x4b, 0x7e, 0x69, 0x78,
		0x95, 0xe4, 0xa1, 0xdc, 0xf1, 0x91, 0x3b, 0xe3, 0x91, 0x98, 0x48, 0x4c, 0x24, 0x26, 0x12, 0x53,
		0x85, 0x12, 0x93, 0xc8, 0x51, 0x05, 0x0e, 0x91, 0xfc, 0xd4, 0x93, 0x11, 0x3d, 0x8a, 0x20, 0xb9,
		0x8b, 0x56, 0x7c, 0xf7, 0x6c, 0xcd, 0x8e, 0x1c, 0x9c, 0x49, 0x3c, 0x22, 0x8d, 0x7d, 0xa1, 0xb5,
		0x3b, 0x5a, 0xc0, 0x8e, 0xc1, 0x47, 0x07, 0xbb, 0x6d, 0x82, 0x5d, 0xa9, 0xc1, 0x8e, 0x3d, 0xd5,
		0x75, 0x3c, 0x22, 0x50, 0xfb, 0xd0, 0x8f, 0xd9, 0xd6, 0xf2, 0x28, 0xc0, 0x19, 0x3b, 0x29, 0xaa,
		0x5a, 0x4d, 0x93, 0xd9, 0xa1, 0x7d, 0x7b, 0x30, 0xea, 0x68, 0xd4, 0xd1, 0xa8, 0xa3, 0x51, 0x47,
		0xab, 0x50, 0x1d, 0x8d, 0x2d, 0xda, 0xe6, 0xb8, 0x25, 0x5b, 0xb4, 0xcb, 0x1b, 0x8f, 0x2d, 0xda,
		0x95, 0x35, 0x11, 0xb6, 0x68, 0x43, 0x2c, 0x8c, 0x11, 0x0b, 0x2e, 0x73, 0x81, 0x50, 0x40, 0x28,
		0x20, 0x14, 0x10, 0x8a, 0x87, 0xfd, 0x85, 0xcb, 0x5c, 0xe0, 0x12, 0x70, 0x09, 0xb8, 0x04, 0x5c,
		0x02, 0x2e, 0x51, 0x1b, 0x2e, 0xc1, 0x65, 0x2e, 0xaa, 0x97, 0xb9, 0xb8, 0xb8, 0xac, 0x63, 0x4d,
		0xfd, 0x2e, 0x97, 0xd3, 0xd1, 0xa7, 0xb2, 0x7a, 0x95, 0xcb, 0x33, 0x43, 0xa6, 0xee, 0xca, 0xc4,
		0xf5, 0x4d, 0xdb, 0x2b, 0xf5, 0xc6, 0x1c, 0x3d, 0x63, 0x2e, 0xc7, 0x8c, 0x97, 0x37, 0xba, 0x12,
		0x0c, 0xce, 0x1b, 0x64, 0xa1, 0x7f, 0x35, 0xe8, 0xe5, 0x51, 0xbf, 0x17, 0xfa, 0x43, 0xdb, 0x28,
		0xaf, 0xe0, 0x33, 0x63, 0x49, 0x8b, 0x63, 0x94, 0xe4, 0x2a, 0xe5, 0xde, 0x41, 0x54, 0x7a, 0x2d,
		0xc7, 0x45, 0xed, 0xc6, 0x5d, 0xad, 0xc6, 0x55, 0x6d, 0xc6, 0x79, 0x2d, 0xc6, 0x79, 0xed, 0xc5,
		0x69, 0xad, 0xc5, 0x56, 0xf2, 0x29, 0xfb, 0xce, 0x20, 0xaf, 0x33, 0xf5, 0x29, 0x47, 0x77, 0x9b,
		0x39, 0xb9, 0xfb, 0xce, 0xf9, 0xe5, 0x66, 0xeb, 0x5c, 0x6e, 0xe6, 0x3e, 0xf0, 0x88, 0x05, 0x20,
		0xb1, 0x40, 0x24, 0x12, 0x90, 0xaa, 0x41, 0x04, 0x9d, 0x5d, 0x6e, 0x16, 0xc6, 0xc1, 0x79, 0x2f,
		0xec, 0xba, 0xef, 0x7b, 0x4d, 0x07, 0x42, 0x91, 0x41, 0x23, 0x64, 0x4a, 0x84, 0x4e, 0xb9, 0x10,
		0x2a, 0x15, 0x4a, 0xc5, 0x43, 0xaa, 0x78, 0x68, 0x15, 0x0d, 0xb1, 0x6e, 0xab, 0x8e, 0x28, 0x32,
		0x3c, 0x01, 0xe9, 0x35, 0x29, 0xcf, 0xda, 0xad, 0x5d, 0xa9, 0xd7, 0xb0, 0x16, 0x4b, 0x18, 0xf5,
		0xba, 0x74, 0xfb, 0x63, 0x16, 0xbe, 0x9b, 0x7c, 0xbc, 0xe3, 0xe1, 0xa7, 0x5b, 0xa1, 0xbb, 0xb7,
		0xc3, 0x61, 0x64, 0x77, 0x46, 0x4f, 0xc3, 0xf2, 0xf3, 0x3d, 0xe4, 0x14, 0x72, 0x0a, 0x39, 0x5d,
		0x4d, 0x72, 0xea, 0xa8, 0x9a, 0x26, 0x53, 0x55, 0x73, 0x1c, 0xc0, 0xa0, 0x8c, 0x50, 0x46, 0x28,
		0xa3, 0x4d, 0xca, 0xe8, 0x2a, 0x20, 0x16, 0x03, 0x04, 0xbd, 0x5e, 0xf2, 0xd7, 0x0c, 0xa2, 0x07,
		0x99, 0x7b, 0x7b, 0x9e, 0x7a, 0xe8, 0xe2, 0xd0, 0x8e, 0xcd, 0x4c, 0xa8, 0xb2, 0x27, 0x54, 0xe1,
		0x13, 0x0b, 0xdb, 0x92, 0xe1, 0x5b, 0x3e, 0x8c, 0x4b, 0x87, 0x73, 0xb5, 0xb0, 0xae, 0x16, 0xde,
		0x55, 0xc2, 0xbc, 0xdb, 0x70, 0xef, 0x38, 0xec, 0x17, 0x2b, 0xe6, 0xbc, 0x62, 0xb8, 0xe0, 0x6f,
		0xee, 0x2b, 0x87, 0x0b, 0x68, 0xb6, 0x59, 0xd1, 0x8d, 0xa9, 0xd5, 0x42, 0x12, 0x8e, 0x2b, 0x8c,
		0xb3, 0x22, 0x9c, 0x9d, 0x4a, 0x63, 0x38, 0xfc, 0x55, 0xa7, 0x8c, 0x6c, 0xcd, 0x4a, 0xd9, 0x71,
		0xff, 0xfc, 0xb2, 0xef, 0xa4, 0xf6, 0xe8, 0xce, 0xd8, 0x6f, 0x9c, 0x54, 0x80, 0x83, 0x5c, 0xe0,
		0x62, 0x00, 0x57, 0x5b, 0x8d, 0x45, 0x49, 0xfe, 0x06, 0x24, 0x1f, 0x92, 0x0f, 0xc9, 0x87, 0xe4,
		0x43, 0xf2, 0x21, 0xf9, 0x90, 0x7c, 0x48, 0x3e, 0x24, 0x1f, 0x92, 0x0f, 0xc9, 0x87, 0xe4, 0x57,
		0x90, 0xe4, 0xbb, 0x24, 0x64, 0xb6, 0x38, 0xbe, 0x83, 0xf3, 0xa0, 0x0e, 0x29, 0x3e, 0x7b, 0xee,
		0xec, 0x38, 0x49, 0x5d, 0x77, 0xdc, 0xed, 0x97, 0x0e, 0x31, 0x6c, 0xee, 0xb7, 0x73, 0x53, 0xdb,
		0x72, 0x5a, 0xd3, 0x72, 0xbe, 0xe3, 0x6e, 0x83, 0x1d, 0x77, 0x72, 0xe4, 0x86, 0x1d, 0x77, 0x35,
		0x4c, 0x82, 0x1c, 0x07, 0xb3, 0x51, 0x4f, 0xe2, 0x38, 0x98, 0xa5, 0x7a, 0x11, 0x65, 0xff, 0x4a,
		0xd6, 0x83, 0x38, 0x0e, 0xa6, 0x55, 0xef, 0xe1, 0x38, 0x18, 0xd4, 0xf4, 0xe7, 0xa8, 0x69, 0x9d,
		0x64, 0xbb, 0x16, 0xb8, 0x29, 0xea, 0x5d, 0xda, 0x26, 0x6f, 0xc8, 0xd4, 0x2b, 0x2e, 0xe3, 0x75,
		0xd7, 0xb8, 0xcd, 0xa8, 0x79, 0x3d, 0x53, 0x34, 0xdf, 0x21, 0x80, 0x1b, 0x3e, 0x81, 0xe9, 0x63,
		0x2f, 0xe9, 0x9a, 0x47, 0xef, 0x30, 0xca, 0xf2, 0xbd, 0x3c, 0x2f, 0x87, 0x9b, 0x79, 0xef, 0xa2,
		0x78, 0xbf, 0x17, 0x0e, 0x51, 0x58, 0x56, 0x0e, 0x03, 0xf0, 0xde, 0x05, 0x5f, 0x6f, 0xbd, 0x63,
		0xf3, 0x55, 0xab, 0xb5, 0xbd, 0xd3, 0x6a, 0xad, 0xef, 0x6c, 0xee, 0xac, 0xef, 0x6e, 0x6d, 0x35,
		0xb7, 0x9b, 0x25, 0x08, 0xa9, 0x7a, 0x47, 0x69, 0x37, 0x4c, 0xc3, 0xee, 0x9b, 0xe1, 0x0a, 0xc7,
		0x83, 0x5e, 0x4f, 0xf5, 0x41, 0x97, 0x1c, 0x9f, 0xb4, 0xe2, 0x52, 0x09, 0x41, 0x48, 0x21, 0xf8,
		0x2c, 0x17, 0x6b, 0x7e, 0x3e, 0x42, 0xfc, 0xdc, 0x5f, 0xfe, 0xa4, 0xa9, 0x95, 0x65, 0x62, 0xc2,
		0xa6, 0xb5, 0x84, 0x45, 0xc9, 0x59, 0xd2, 0xcf, 0x19, 0xd0, 0xd3, 0x1f, 0xff, 0x4f, 0x3c, 0x7a,
		0xaf, 0x1f, 0x86, 0xa9, 0x7f, 0x99, 0x26, 0x83, 0xfe, 0xcf, 0xef, 0xcb, 0x9a, 0x5d, 0xd5, 0x75,
		0xeb, 0xcd, 0x7e, 0xd2, 0x0c, 0x97, 0x2b, 0xda, 0x2f, 0x5d, 0x69, 0x2a, 0xa3, 0x92, 0x54, 0x5e,
		0xa5, 0xa8, 0xac, 0x4a, 0x50, 0xe9, 0x95, 0x9e, 0xd2, 0x2b, 0x39, 0xa5, 0x56, 0x6a, 0x64, 0x03,
		0xe7, 0xb2, 0x45, 0xec, 0x5b, 0x5e, 0xb3, 0xfc, 0x83, 0x5e, 0xf4, 0xc4, 0x65, 0x9f, 0x74, 0x39,
		0x5d, 0xb4, 0xd2, 0x4a, 0xc0, 0x65, 0x96, 0x7a, 0xcb, 0x2f, 0xe9, 0x96, 0x5d, 0xba, 0x75, 0x56,
		0xa2, 0x75, 0x56, 0x8a, 0x75, 0x52, 0x72, 0xd5, 0x65, 0x59, 0x65, 0x75, 0xa9, 0xbc, 0xe0, 0x22,
		0xf2, 0xb3, 0xe0, 0x22, 0x72, 0xa0, 0xd6, 0x3c, 0x7b, 0x6b, 0x44, 0x9a, 0xed, 0x84, 0x03, 0x57,
		0x61, 0xc1, 0x79, 0x78, 0x70, 0x1e, 0x26, 0x9c, 0x86, 0x0b, 0x9b, 0x35, 0xc6, 0xd2, 0x45, 0x9a,
		0xa7, 0x3e, 0xef, 0x6e, 0x5b, 0x4e, 0x31, 0x02, 0x5a, 0x58, 0xec, 0xcc, 0x51, 0x0b, 0x42, 0x62,
		0xc1, 0x48, 0x24, 0x28, 0x95, 0x1b, 0x9c, 0x4a, 0x0e, 0x52, 0xce, 0x82, 0xd5, 0x2c, 0x68, 0x75,
		0xbb, 0x25, 0xdf, 0x58, 0xf1, 0x70, 0xf4, 0x2a, 0x86, 0x42, 0x11, 0x4b, 0x3a, 0xac, 0xc9, 0x85,
		0x37, 0xa9, 0x30, 0x27, 0x1e, 0xee, 0xc4, 0xc3, 0x9e, 0x68, 0xf8, 0x73, 0x13, 0x06, 0x1d, 0x85,
		0x43, 0xe7, 0x61, 0xb1, 0x18, 0xc0, 0xb1, 0x54, 0xe0, 0x82, 0x5b, 0x3a, 0x17, 0xa8, 0x10, 0x08,
		0x94, 0x62, 0x01, 0x53, 0x32, 0x70, 0xca, 0x07, 0x50, 0xe9, 0x40, 0xaa, 0x16, 0x50, 0xd5, 0x02,
		0xab, 0x4a, 0x80, 0x75, 0x1b, 0x68, 0x1d, 0x07, 0x5c, 0xb1, 0xc0, 0x5b, 0x0c, 0x14, 0xf6, 0xa2,
		0xcb, 0xe8, 0xbc, 0x17, 0xfa, 0x63, 0x53, 0xf4, 0xfb, 0x49, 0x2f, 0xea, 0x7c, 0x93, 0x73, 0x86,
		0x62, 0x63, 0xf9, 0xfd, 0xf3, 0x78, 0x59, 0xcb, 0x4b, 0x70, 0xa5, 0x02, 0xb7, 0x46, 0x00, 0xd7,
		0x0b, 0xe4, 0x5a, 0x01, 0x5d, 0x3d, 0xb0, 0xab, 0x07, 0x78, 0xd5, 0x40, 0x2f, 0x13, 0xf0, 0x85,
		0x02, 0x7f, 0xb1, 0x92, 0x62, 0x3a, 0x05, 0x0b, 0xfe, 0xda, 0x0b, 0x83, 0x8b, 0x34, 0xbc, 0x90,
		0x74, 0xd8, 0x29, 0x5e, 0xde, 0x11, 0x1c, 0xf3, 0xb8, 0xd8, 0xb1, 0xd3, 0xf1, 0xd3, 0x7e, 0xd2,
		0x7b, 0x9d, 0x26, 0x83, 0x3c, 0x8a, 0x2f, 0x27, 0x99, 0xa7, 0xf8, 0xf1, 0xf8, 0x3f, 0xfd, 0x6e,
		0x78, 0x11, 0xc5, 0x51, 0x1e, 0x25, 0x71, 0xf6, 0xf0, 0x3f, 0x15, 0xff, 0x32, 0xda, 0x64, 0xf3,
		0xac, 0x1e, 0x56, 0x2f, 0x71, 0xe3, 0x7d, 0x1a, 0x76, 0xc2, 0xe8, 0x3a, 0x94, 0x87, 0x1d, 0xd3,
		0x81, 0x85, 0xbc, 0x5a, 0x58, 0x2f, 0x09, 0x7c, 0x03, 0xbe, 0x01, 0xdf, 0x80, 0x6f, 0xc0, 0x37,
		0x2a, 0x7a, 0x4c, 0x0b, 0xf8, 0xa6, 0x09, 0x24, 0x78, 0xf4, 0x9a, 0x65, 0x61, 0xdc, 0x95, 0xc7,
		0x03, 0xa3, 0x51, 0x01, 0x03, 0x80, 0x01, 0xc0, 0x00, 0x60, 0x00, 0x30, 0x00, 0x18, 0x00, 0x0c,
		0x58, 0x01, 0x03, 0xfe, 0x55, 0xf0, 0x55, 0x07, 0x10, 0x8c, 0x46, 0x26, 0x39, 0x93, 0x9c, 0x49,
		0xce, 0x24, 0x67, 0x92, 0xb3, 0x98, 0xbf, 0x0e, 0xa2, 0x38, 0x7f, 0xa5, 0x90, 0x9a, 0xb7, 0x04,
		0x87, 0x3c, 0x09, 0xe2, 0xcb, 0xe1, 0x87, 0xfd, 0x2c, 0xea, 0x1e, 0xb2, 0xe1, 0x68, 0x6d, 0x22,
		0x8b, 0x20, 0x1e, 0x07, 0x95, 0xb2, 0xea, 0xc2, 0xf0, 0x9f, 0x82, 0xde, 0x20, 0x54, 0x1c, 0xff,
		0xb7, 0x34, 0xe8, 0xe4, 0x51, 0x12, 0xbf, 0x8d, 0x2e, 0xa3, 0xb1, 0x2a, 0x85, 0xf8, 0x3c, 0x6e,
		0x5e, 0x2a, 0x98, 0x5c, 0xf0, 0x75, 0xe5, 0x4d, 0x6e, 0x63, 0x6b, 0x6b, 0x85, 0x8d, 0xee, 0x59,
		0x3d, 0x47, 0x3b, 0xab, 0x0b, 0x75, 0xac, 0xf4, 0x1e, 0x3d, 0x21, 0xfd, 0xff, 0x19, 0x09, 0x96,
		0x50, 0x1a, 0xb9, 0x25, 0x69, 0x71, 0xeb, 0x75, 0xa3, 0x38, 0x6f, 0x5b, 0xbc, 0x6a, 0x14, 0xc7,
		0x4d, 0x1a, 0x22, 0x9b, 0xaa, 0xd7, 0x24, 0x24, 0x4c, 0x8e, 0xc3, 0x30, 0xfd, 0xf7, 0xe8, 0xc3,
		0xcf, 0x5e, 0xb6, 0xf7, 0x2e, 0xa2, 0xd3, 0xe1, 0x47, 0x9f, 0xbe, 0x68, 0xef, 0x75, 0xbb, 0x63,
		0xc5, 0x39, 0x97, 0x77, 0x00, 0xba, 0xf7, 0x91, 0x1b, 0xa7, 0x57, 0x38, 0xb8, 0xbc, 0x1b, 0x70,
		0xb1, 0x4a, 0xe3, 0xf8, 0x4a, 0x8a, 0x35, 0x8d, 0x5d, 0xfd, 0x1b, 0xec, 0xea, 0xaf, 0x4e, 0xe9,
		0x85, 0x5d, 0xfd, 0xec, 0xea, 0xff, 0xe1, 0x8a, 0xb1, 0xab, 0x9f, 0x5d, 0xfd, 0xd5, 0x0c, 0xe0,
		0x7a, 0x81, 0x5c, 0x2b, 0xa0, 0xab, 0x07, 0x76, 0xf5, 0x00, 0xaf, 0x1a, 0xe8, 0x65, 0x49, 0x35,
		0xbb, 0xfa, 0x1d, 0xe2, 0x65, 0x76, 0xf5, 0x5b, 0x2c, 0xbd, 0xb0, 0xab, 0xbf, 0x3c, 0x58, 0xc7,
		0x46, 0x3e, 0xf0, 0x0d, 0xf8, 0x06, 0x7c, 0x03, 0xbe, 0x61, 0x23, 0x1f, 0x90, 0xe0, 0x9f, 0xd6,
		0x8c, 0x5d, 0xfd, 0x80, 0x01, 0xc0, 0x00, 0x60, 0x00, 0x30, 0x00, 0x18, 0x00, 0x0c, 0x00, 0x06,
		0xd8, 0xd5, 0x4f, 0x72, 0x26, 0x39, 0x93, 0x9c, 0x49, 0xce, 0x2b, 0x93, 0x9c, 0xd9, 0xd5, 0xef,
		0xea, 0x8b, 0x5d, 0xfd, 0xa2, 0xc3, 0xb3, 0xab, 0x9f, 0x5d, 0xfd, 0x4a, 0x26, 0xc7, 0xae, 0xfe,
		0x1a, 0x8e, 0xc6, 0xae, 0x7e, 0x03, 0x21, 0x87, 0x5d, 0xfd, 0x5d, 0xc7, 0x77, 0xc5, 0x2f, 0xae,
		0x80, 0xad, 0x4d, 0xfd, 0x0e, 0xae, 0x91, 0x97, 0xf3, 0x90, 0x6a, 0x5d, 0x2f, 0x20, 0xe4, 0x6b,
		0x66, 0x7d, 0xcc, 0x73, 0x7a, 0x02, 0xc3, 0x92, 0x57, 0xb9, 0xf1, 0xa7, 0xf2, 0xad, 0xdd, 0x81,
		0xa5, 0x17, 0xb7, 0x8a, 0xf9, 0x93, 0x87, 0xe1, 0xfa, 0x1a, 0xa0, 0xb9, 0xe1, 0xdc, 0x5e, 0x05,
		0xb4, 0xce, 0x55, 0x40, 0x3f, 0x7e, 0x20, 0x5c, 0x05, 0x54, 0x99, 0x82, 0x23, 0x57, 0x01, 0xe9,
		0x15, 0x0c, 0x05, 0xb7, 0x2a, 0x4b, 0x6c, 0x4d, 0x2e, 0xb6, 0x22, 0xff, 0xf2, 0xcb, 0xe4, 0x80,
		0x6c, 0x63, 0x3e, 0x32, 0xaf, 0x72, 0x46, 0xec, 0xf7, 0x7b, 0xdf, 0x5c, 0x1f, 0x4a, 0x9a, 0x25,
		0xc4, 0xdb, 0xa3, 0x71, 0x35, 0x9e, 0x85, 0x7c, 0x98, 0xf6, 0x93, 0x1e, 0x09, 0xb1, 0x82, 0x09,
		0x71, 0xf4, 0xe0, 0xc8, 0x88, 0x6b, 0x5c, 0x8e, 0x67, 0x34, 0x54, 0x8a, 0x85, 0x4c, 0xc9, 0xd0,
		0xa9, 0x10, 0x42, 0xa5, 0x43, 0xa9, 0x5a, 0x48, 0x55, 0x0b, 0xad, 0x3a, 0x21, 0xd6, 0x6d, 0xa8,
		0x75, 0x1c, 0x72, 0xc5, 0x42, 0x6f, 0x31, 0x50, 0x77, 0xbc, 0x9b, 0xdb, 0x0f, 0xbf, 0xf6, 0x93,
		0x34, 0x57, 0x3b, 0x47, 0x7f, 0xff, 0x34, 0xe4, 0x77, 0xb4, 0x9f, 0xec, 0xff, 0xbf, 0xfd, 0x5f,
		0x3f, 0xb4, 0x4f, 0x8e, 0x3e, 0x7e, 0xd8, 0x67, 0xef, 0x5c, 0xe5, 0xf2, 0x87, 0x62, 0x1e, 0xd1,
		0xca, 0x27, 0xea, 0x79, 0x45, 0x3d, 0xbf, 0xe8, 0xe6, 0x19, 0x99, 0x7c, 0x23, 0x94, 0x77, 0xe4,
		0x8a, 0x61, 0x3f, 0xcc, 0x04, 0x93, 0x53, 0xea, 0xf9, 0x70, 0x22, 0x0a, 0xdb, 0xdc, 0x5b, 0x82,
		0x63, 0xee, 0xc7, 0x83, 0xab, 0xe1, 0x62, 0xdf, 0xb0, 0xb5, 0xfe, 0xc9, 0xb8, 0x25, 0xba, 0x32,
		0x81, 0x5b, 0xe6, 0xa7, 0x01, 0x6e, 0x01, 0xb7, 0x80, 0x5b, 0xc0, 0x2d, 0xe0, 0x16, 0x70, 0x0b,
		0xb8, 0x05, 0xdc, 0x72, 0x6b, 0xcd, 0x94, 0xeb, 0x2c, 0x2a, 0xf5, 0x15, 0x80, 0x02, 0x40, 0x01,
		0xa0, 0x00, 0x50, 0x00, 0x28, 0x20, 0x54, 0x58, 0x39, 0xa1, 0x42, 0x21, 0x7b, 0x3c, 0x8c, 0xb2,
		0x7c, 0x2f, 0xcf, 0x53, 0x59, 0x9b, 0x7c, 0x17, 0xc5, 0xfb, 0xbd, 0x70, 0x18, 0x52, 0x32, 0xd9,
		0x43, 0x5f, 0xde, 0xbb, 0xe0, 0xeb, 0xad, 0x91, 0x9b, 0xaf, 0x5a, 0xad, 0xed, 0x9d, 0x56, 0x6b,
		0x7d, 0x67, 0x73, 0x67, 0x7d, 0x77, 0x6b, 0xab, 0xb9, 0xdd, 0x94, 0x3c, 0xcd, 0x7a, 0x94, 0x76,
		0xc3, 0x34, 0xec, 0xbe, 0xf9, 0x26, 0x9f, 0xd4, 0x8a, 0x43, 0xc3, 0x59, 0x98, 0x4a, 0xe7, 0x33,
		0xa5, 0x44, 0x7e, 0x37, 0x99, 0x27, 0xe3, 0xd5, 0xf7, 0xcf, 0xbf, 0x79, 0x0a, 0xa7, 0x2d, 0xb5,
		0x93, 0xfa, 0x42, 0x62, 0x1f, 0x59, 0x42, 0x4d, 0x4f, 0x00, 0xc2, 0x14, 0x1f, 0x6f, 0x13, 0xca,
		0x95, 0x6d, 0x95, 0x8a, 0x36, 0x4c, 0x11, 0xa6, 0x08, 0x53, 0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a,
		0x30, 0x45, 0x98, 0x22, 0x4c, 0x11, 0xa6, 0x08, 0x53, 0x84, 0x29, 0x56, 0x98, 0x29, 0xa2, 0x15,
		0xf3, 0x84, 0xf1, 0xac, 0xe9, 0x58, 0xdc, 0x3a, 0x58, 0xb9, 0x7a, 0x97, 0xc0, 0x0e, 0x3f, 0xfc,
		0xf1, 0xe8, 0xb3, 0x73, 0x0f, 0xec, 0x3f, 0x3c, 0x2b, 0xee, 0x81, 0x5d, 0xb6, 0xfa, 0xb2, 0xc1,
		0x01, 0xb6, 0x0a, 0x81, 0x33, 0x0e, 0xb0, 0x71, 0x80, 0xed, 0xc7, 0x4b, 0xc6, 0x01, 0x36, 0x36,
		0x82, 0xbb, 0xce, 0x1b, 0x54, 0xed, 0xeb, 0x44, 0xf6, 0xa9, 0xda, 0x53, 0xb5, 0x2f, 0x6f, 0x29,
		0xd9, 0x08, 0xce, 0x46, 0x70, 0xcb, 0x46, 0xca, 0x01, 0x36, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0x02,
		0x6e, 0x01, 0xb7, 0x80, 0x5b, 0xc0, 0x2d, 0x95, 0xc1, 0x2d, 0x1c, 0x60, 0x03, 0x28, 0x00, 0x14,
		0x00, 0x0a, 0x00, 0x85, 0x55, 0x05, 0x0a, 0x6c, 0x4b, 0x64, 0x5b, 0xe2, 0xe2, 0x72, 0xb1, 0x2d,
		0x91, 0x6d, 0x89, 0x6c, 0x4b, 0x64, 0x5b, 0x22, 0xdb, 0x12, 0x61, 0x8a, 0x63, 0x9b, 0xe0, 0x00,
		0x1b, 0x4c, 0x11, 0xa6, 0x08, 0x53, 0x84, 0x29, 0xc2, 0x14, 0x61, 0x8a, 0x30, 0x45, 0x98, 0x22,
		0x4c, 0x11, 0xa6, 0x08, 0x53, 0x84, 0x29, 0x56, 0x8a, 0x29, 0x72, 0x80, 0xed, 0x09, 0xe3, 0x59,
		0x3e, 0xc0, 0xb6, 0x6a, 0xf7, 0x9d, 0xdf, 0x3a, 0xbf, 0xc6, 0x95, 0xe7, 0x52, 0x9e, 0xb7, 0xb2,
		0x57, 0x9e, 0xbb, 0xbf, 0x83, 0xd3, 0xa6, 0x6f, 0xad, 0xf2, 0x35, 0xaf, 0x8e, 0xef, 0x2f, 0x94,
		0xb9, 0xb7, 0x90, 0xab, 0x5d, 0x9f, 0x56, 0x83, 0xe4, 0xaa, 0xf3, 0x6a, 0xb0, 0x0f, 0xae, 0x3a,
		0x7f, 0x70, 0x65, 0x9c, 0x5f, 0xec, 0x3a, 0x7f, 0x11, 0xb8, 0xd8, 0xe9, 0xf8, 0xf9, 0x61, 0x65,
		0x4e, 0xc9, 0xaf, 0x73, 0xcd, 0xab, 0xe1, 0x70, 0xaa, 0x55, 0x00, 0xe2, 0x90, 0xbc, 0xd3, 0x70,
		0x5b, 0x8f, 0xe2, 0x84, 0x58, 0x63, 0x66, 0xd6, 0x13, 0xef, 0x86, 0x71, 0x1e, 0xe5, 0xdf, 0x64,
		0x9a, 0x32, 0x05, 0xb2, 0x14, 0x28, 0x70, 0x7b, 0x07, 0x93, 0x8f, 0xf6, 0x26, 0xc8, 0x42, 0xf9,
		0xcd, 0x06, 0x7b, 0xbf, 0x1d, 0xb4, 0x4f, 0x87, 0xff, 0xf7, 0xe1, 0xff, 0x8e, 0xc5, 0xce, 0xaf,
		0x7d, 0x0a, 0x7a, 0x83, 0x30, 0xf3, 0x5e, 0xaf, 0x7d, 0x16, 0xab, 0x6a, 0x2a, 0xb5, 0x0c, 0x4e,
		0x4f, 0x3e, 0xec, 0xb7, 0x8f, 0x8f, 0x0e, 0x0f, 0x7e, 0xfd, 0xbf, 0xf6, 0xc1, 0xf1, 0xa7, 0x6d,
		0xc1, 0x56, 0xf0, 0xcb, 0xba, 0xaf, 0xed, 0xe1, 0xe6, 0xa7, 0xe3, 0xf7, 0xc3, 0x55, 0x6d, 0xb5,
		0x3f, 0xbe, 0x3f, 0xf8, 0x75, 0xef, 0xf4, 0x03, 0xab, 0x5b, 0xe2, 0xea, 0x1e, 0xbc, 0xff, 0x9f,
		0xd3, 0x0f, 0x7b, 0x1f, 0xf6, 0xdb, 0xa7, 0xc7, 0xbf, 0xb1, 0xb0, 0x4e, 0xcc, 0xf6, 0xdd, 0xc7,
		0xc3, 0x0f, 0x18, 0x6e, 0xc9, 0xeb, 0xfb, 0xe9, 0xf8, 0xfd, 0xa7, 0x56, 0xfb, 0xb7, 0xc3, 0xa3,
		0xff, 0x3d, 0x3d, 0xde, 0xff, 0x95, 0x95, 0x75, 0x96, 0xcc, 0x5a, 0xac, 0x6d, 0x89, 0x51, 0x61,
		0x63, 0x18, 0x15, 0x3e, 0x1d, 0x1f, 0x9e, 0xb2, 0xaa, 0x65, 0xaf, 0xea, 0xfe, 0xa7, 0xe3, 0xf7,
		0xac, 0xaa, 0x03, 0x68, 0xc0, 0xa2, 0x96, 0xb7, 0xa8, 0x23, 0x40, 0x70, 0xb8, 0xf7, 0x66, 0xff,
		0x70, 0xff, 0x2d, 0x78, 0xd6, 0x25, 0x9e, 0x25, 0x1a, 0xb8, 0xc1, 0xb3, 0xdb, 0xe0, 0x59, 0x67,
		0x81, 0x01, 0x38, 0xeb, 0x64, 0x61, 0xb7, 0x89, 0xb8, 0x22, 0x81, 0x81, 0xd5, 0x75, 0x13, 0x16,
		0x58, 0x57, 0x37, 0x51, 0x41, 0x7e, 0x5d, 0x45, 0x46, 0x3a, 0xab, 0x7a, 0x5f, 0xab, 0x92, 0x4a,
		0xfb, 0x61, 0x1c, 0x9c, 0xf7, 0xc2, 0xae, 0xdc, 0x6e, 0x82, 0xe9, 0x80, 0xae, 0x95, 0xb2, 0x67,
		0x22, 0x88, 0x17, 0x41, 0x2f, 0x63, 0xdf, 0xc2, 0x13, 0x07, 0x62, 0xdf, 0x42, 0xa9, 0xd6, 0xc1,
		0xbe, 0x05, 0xf6, 0x2d, 0xfc, 0x60, 0xc5, 0xe4, 0xf7, 0x2d, 0x9c, 0x27, 0x49, 0x2f, 0x0c, 0x62,
		0xc9, 0x3d, 0x0b, 0x4d, 0x4e, 0x0b, 0xb8, 0x37, 0xa9, 0x55, 0x3d, 0x2d, 0xe0, 0xfc, 0x2e, 0x29,
		0x23, 0xe7, 0x04, 0x5c, 0xde, 0x1b, 0x55, 0x8d, 0x23, 0x02, 0x97, 0x69, 0xd0, 0x09, 0x2f, 0x06,
		0x3d, 0x3f, 0x0d, 0xb3, 0x3c, 0x48, 0x73, 0xf7, 0x87, 0x05, 0x16, 0x46, 0xe4, 0xd8, 0x80, 0x16,
		0x6e, 0xe4, 0xd8, 0x40, 0xf5, 0x70, 0x21, 0xc7, 0x06, 0x1e, 0x66, 0xaa, 0xae, 0x8f, 0x0d, 0x38,
		0x3e, 0x4f, 0xb5, 0xe0, 0x96, 0x22, 0x57, 0x3a, 0x8a, 0x5f, 0xa7, 0x07, 0xe1, 0x86, 0x70, 0x43,
		0xb8, 0xeb, 0x44, 0xb8, 0xc5, 0x2e, 0xd3, 0x93, 0xaa, 0xb1, 0x2e, 0xf8, 0xb7, 0x4c, 0xad, 0x75,
		0xb6, 0xa0, 0xb2, 0x35, 0xd7, 0xbb, 0xa9, 0x00, 0x79, 0xc0, 0x2a, 0xa7, 0x08, 0xad, 0x54, 0xa1,
		0x9e, 0x32, 0xd4, 0x53, 0x87, 0x6a, 0x0a, 0x91, 0x49, 0x25, 0x42, 0x29, 0xa5, 0x58, 0x49, 0x3d,
		0x71, 0x40, 0xb9, 0x9a, 0xee, 0x02, 0x12, 0x6f, 0xa2, 0xcd, 0x64, 0x00, 0xd5, 0xac, 0xb8, 0x36,
		0xd3, 0xdd, 0x3a, 0x5d, 0x43, 0x84, 0x8d, 0xae, 0xd9, 0x29, 0x0e, 0xff, 0x7b, 0xb2, 0x00, 0x27,
		0xe3, 0xcf, 0xef, 0xb4, 0x58, 0xec, 0xde, 0x63, 0x6e, 0x9c, 0x16, 0xf3, 0x83, 0x5c, 0x50, 0x46,
		0x41, 0x42, 0x28, 0x4c, 0xbc, 0x2a, 0xb2, 0x41, 0x55, 0x84, 0xaa, 0x08, 0x55, 0x11, 0xaa, 0x22,
		0x54, 0x45, 0xa8, 0x8a, 0x50, 0x15, 0xa1, 0x2a, 0x42, 0x55, 0x84, 0xaa, 0x08, 0x55, 0x11, 0xaa,
		0x22, 0x54, 0x45, 0x4c, 0x57, 0x45, 0x56, 0x4c, 0xb5, 0xfa, 0x6e, 0x51, 0x04, 0xe5, 0x6a, 0x29,
		0x0f, 0x5c, 0xd5, 0xbd, 0xa8, 0x42, 0xfb, 0x05, 0xed, 0xfa, 0xd8, 0x2a, 0x6f, 0x4f, 0x8d, 0xfa,
		0xd7, 0x2d, 0xbf, 0x17, 0x9c, 0x87, 0xbd, 0xb0, 0xeb, 0x0f, 0xe2, 0xa8, 0x13, 0x64, 0x02, 0x5b,
		0x54, 0xef, 0x1d, 0x95, 0x6d, 0xaa, 0x5a, 0xe4, 0x91, 0x6d, 0xaa, 0xd5, 0x23, 0x7f, 0x6c, 0x53,
		0x55, 0xab, 0x0b, 0x4e, 0x2c, 0xca, 0xef, 0x45, 0x57, 0x51, 0x2e, 0xd7, 0x95, 0x99, 0x1b, 0x95,
		0x2d, 0xab, 0x56, 0x2b, 0x70, 0x34, 0x67, 0xea, 0x57, 0x61, 0xa3, 0x39, 0x63, 0x2e, 0x08, 0x17,
		0x03, 0x09, 0x9d, 0x19, 0x58, 0x70, 0x6f, 0xb1, 0xdd, 0x1a, 0x82, 0x01, 0x59, 0x3c, 0x30, 0x6b,
		0x04, 0x68, 0xbd, 0x40, 0xad, 0x15, 0xb0, 0xd5, 0x03, 0xb7, 0x7a, 0x00, 0x57, 0x0d, 0xe4, 0x32,
		0x01, 0x5d, 0x28, 0xb0, 0x8b, 0x07, 0xf8, 0x62, 0xc0, 0xab, 0xe0, 0xab, 0x3f, 0xb6, 0xda, 0x91,
		0xe6, 0xbd, 0x92, 0xae, 0xd1, 0xdc, 0x2c, 0x84, 0x8d, 0x57, 0xb6, 0x4f, 0xae, 0x96, 0x0c, 0x34,
		0x93, 0x82, 0x7e, 0x72, 0xd0, 0x4e, 0x12, 0x66, 0x92, 0x85, 0x99, 0xa4, 0x61, 0x22, 0x79, 0xc8,
		0x26, 0x11, 0xe1, 0x64, 0x52, 0xac, 0xb0, 0x78, 0xdf, 0x7d, 0xc1, 0xdf, 0x07, 0x51, 0x9c, 0x6f,
		0x6e, 0x68, 0xf8, 0xfb, 0x24, 0xba, 0xef, 0x28, 0x0c, 0x7d, 0x12, 0xc4, 0x97, 0xa1, 0xe8, 0x3d,
		0x32, 0xb7, 0xbf, 0x74, 0xe2, 0xdb, 0xe8, 0x83, 0xbf, 0x8b, 0x62, 0xb5, 0x00, 0xab, 0x9c, 0xd6,
		0x17, 0xa6, 0x31, 0xba, 0x4d, 0xc8, 0xc0, 0x3c, 0x7e, 0x4b, 0x83, 0x4e, 0x1e, 0x25, 0xf1, 0xdb,
		0xe8, 0x32, 0xca, 0x87, 0x48, 0x6f, 0x5d, 0x6d, 0x3e, 0x37, 0x2f, 0x15, 0x4d, 0x33, 0xf8, 0x8a,
		0x69, 0xde, 0x31, 0xcd, 0xd6, 0xc6, 0x6e, 0x6b, 0x77, 0x7b, 0x67, 0x63, 0x77, 0x0b, 0x1b, 0xd5,
		0x01, 0x04, 0x7a, 0xa3, 0x9e, 0x3d, 0xab, 0xe7, 0xe7, 0x13, 0x8c, 0x31, 0x43, 0x1c, 0x7f, 0x1d,
		0xc6, 0xb9, 0x9f, 0x87, 0x41, 0xda, 0x4d, 0xfe, 0x8a, 0xf5, 0x68, 0xf4, 0xc2, 0x4c, 0x84, 0x81,
		0xa6, 0xd2, 0x56, 0x77, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x0b, 0xf8, 0xbb,
		0xfc, 0x56, 0xfa, 0xbb, 0xe1, 0x5d, 0x68, 0x4b, 0x7d, 0xbd, 0x41, 0xcb, 0x64, 0x5b, 0xaa, 0x9f,
		0x47, 0x57, 0x61, 0xaa, 0x87, 0x58, 0xe6, 0xa7, 0x01, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b,
		0xc0, 0x85, 0xda, 0xc0, 0x85, 0x6e, 0xd8, 0x89, 0xae, 0x82, 0xde, 0x76, 0x4b, 0x13, 0x30, 0x6c,
		0x28, 0x8c, 0xbd, 0x50, 0xcc, 0xda, 0xa0, 0x05, 0x21, 0xf7, 0xc1, 0x2d, 0xb5, 0x20, 0x36, 0x68,
		0x41, 0xac, 0xd1, 0x82, 0x98, 0x99, 0xa6, 0xa1, 0x16, 0xc4, 0x26, 0xa6, 0xb9, 0x46, 0xe7, 0x81,
		0xce, 0x43, 0x45, 0x49, 0xfc, 0x5f, 0x41, 0x1a, 0x47, 0xf1, 0xa5, 0x9f, 0x7f, 0x49, 0xc3, 0xec,
		0x4b, 0xd2, 0xeb, 0xfa, 0xfd, 0x4e, 0xae, 0x47, 0xe6, 0xef, 0x9f, 0x0e, 0xa4, 0x1e, 0x52, 0x0f,
		0xa9, 0x87, 0xd4, 0x43, 0xea, 0x6b, 0x43, 0xea, 0xfb, 0x61, 0xda, 0x09, 0xe3, 0x3c, 0xb8, 0x0c,
		0x15, 0x59, 0xfd, 0x16, 0x7c, 0x7a, 0x35, 0xf9, 0x34, 0x5b, 0xfa, 0xe0, 0xd3, 0x46, 0xf9, 0xb4,
		0x15, 0xd3, 0x6c, 0xae, 0x63, 0x9c, 0x30, 0xea, 0xba, 0x30, 0xea, 0x5a, 0x9d, 0xf0, 0x13, 0x56,
		0xa2, 0x2b, 0xc6, 0x35, 0xa6, 0x8f, 0x75, 0x9f, 0x58, 0x51, 0xe3, 0xb6, 0x18, 0x47, 0x43, 0xf4,
		0x28, 0xf8, 0x9a, 0x1d, 0x1d, 0xad, 0x83, 0xfe, 0x75, 0xeb, 0x70, 0xbc, 0x30, 0x1f, 0xc7, 0xeb,
		0xd2, 0x1e, 0x73, 0xfc, 0xc3, 0xe1, 0xb2, 0x88, 0xe8, 0xf9, 0xcb, 0x79, 0xde, 0x8d, 0x88, 0x04,
		0xa1, 0x84, 0xce, 0xff, 0x02, 0x49, 0x92, 0x92, 0x58, 0x5c, 0xd3, 0x54, 0x32, 0xd8, 0x40, 0xc9,
		0xa0, 0x3e, 0x55, 0x2d, 0x94, 0x0c, 0x50, 0x32, 0x28, 0x6d, 0x25, 0x51, 0x32, 0x40, 0xc9, 0xa0,
		0x7e, 0x49, 0x41, 0x3f, 0x39, 0x68, 0x27, 0x09, 0x33, 0xc9, 0xc2, 0x4c, 0xd2, 0x30, 0x91, 0x3c,
		0x74, 0xca, 0x0e, 0x28, 0x19, 0x88, 0x47, 0x77, 0x94, 0x0c, 0x04, 0x3f, 0x38, 0x6d, 0x8f, 0xd9,
		0x34, 0x68, 0x7b, 0x68, 0x87, 0xbf, 0x79, 0xd3, 0xa4, 0xed, 0xb1, 0x60, 0x9a, 0x28, 0x19, 0x68,
		0x03, 0x02, 0xbd, 0x51, 0xd9, 0x4f, 0xb8, 0xbc, 0xd9, 0xa2, 0x64, 0x50, 0x54, 0x2f, 0x50, 0x32,
		0x80, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xda, 0x52, 0x79, 0x94, 0x0c, 0x6a, 0x01, 0x5a,
		0x50, 0x32, 0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x82, 0x4b, 0x7f, 0x47, 0xc9,
		0x00, 0x25, 0x03, 0x85, 0xd0, 0x82, 0x92, 0xc1, 0x6c, 0x1a, 0xb4, 0x20, 0xb4, 0xe3, 0xf0, 0xbc,
		0x69, 0xa2, 0x64, 0x80, 0x69, 0x5a, 0x01, 0x24, 0x7a, 0xa3, 0xd2, 0x79, 0x58, 0xde, 0x6c, 0x51,
		0x32, 0x80, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa4, 0xbf, 0xa3, 0x64, 0x00,
		0x9f, 0xd6, 0x23, 0x2d, 0x6c, 0xe9, 0x83, 0x4f, 0x1b, 0xe5, 0xd3, 0x28, 0x19, 0xc0, 0xa8, 0x61,
		0xd4, 0x95, 0x1c, 0x09, 0x25, 0x03, 0x63, 0x4a, 0x06, 0x92, 0x27, 0xc1, 0xd7, 0x2a, 0x23, 0x64,
		0x70, 0x3a, 0x5a, 0x95, 0xba, 0xe8, 0x18, 0x3c, 0xab, 0xb0, 0x47, 0x4b, 0x7b, 0x72, 0xe5, 0x3c,
		0xd8, 0x13, 0x51, 0xa9, 0xb0, 0xef, 0xb3, 0x6e, 0xbd, 0xd5, 0x9d, 0x0f, 0xb9, 0x79, 0x67, 0x47,
		0x5e, 0x29, 0xe5, 0x8d, 0x55, 0xf0, 0x42, 0x87, 0x8e, 0x67, 0xd6, 0xe1, 0xdc, 0x38, 0x59, 0xf9,
		0x2e, 0xe0, 0xc0, 0xfc, 0xbd, 0x91, 0x0d, 0x4c, 0x9f, 0xbd, 0x2b, 0xe3, 0x2f, 0x8a, 0x7f, 0x73,
		0xa3, 0x39, 0x72, 0x66, 0xb7, 0xc2, 0x3c, 0xce, 0x9b, 0x35, 0x12, 0x4d, 0x19, 0xb9, 0xe6, 0x8b,
		0x54, 0x93, 0x45, 0xbc, 0x99, 0x22, 0xde, 0x34, 0x11, 0x6d, 0x8e, 0x54, 0x2b, 0x7d, 0xbb, 0x16,
		0xbe, 0xf1, 0x3a, 0x53, 0x9f, 0x77, 0x6c, 0xc4, 0x53, 0xb7, 0x14, 0x11, 0xe2, 0x13, 0x52, 0x30,
		0x13, 0xeb, 0x6e, 0x4b, 0x76, 0xb3, 0xe5, 0xbb, 0xd7, 0xd2, 0xdd, 0x6a, 0xb5, 0xee, 0xb4, 0x5a,
		0x37, 0x5a, 0xa5, 0xfb, 0x5c, 0xed, 0x2a, 0x86, 0x94, 0xe2, 0x98, 0x97, 0x85, 0x71, 0xd7, 0xef,
		0x8e, 0x4f, 0x08, 0xfb, 0x69, 0x32, 0x50, 0x51, 0x97, 0x5c, 0x9c, 0x83, 0x94, 0xb0, 0x9b, 0xce,
		0xd1, 0x68, 0xe1, 0xc6, 0x94, 0xf8, 0x36, 0x28, 0x24, 0x2e, 0x6b, 0x9d, 0x48, 0xd4, 0x13, 0x8a,
		0x6a, 0x62, 0x91, 0x49, 0x30, 0x42, 0x89, 0xa6, 0x58, 0x49, 0xf1, 0xed, 0x4b, 0x8a, 0x47, 0x97,
		0x85, 0x8f, 0x2c, 0xd3, 0xb1, 0xf9, 0x81, 0x13, 0xd3, 0xb1, 0x29, 0x3a, 0x35, 0x62, 0x42, 0xf1,
		0x86, 0x4a, 0xc6, 0xd3, 0xe6, 0x8c, 0x84, 0x1a, 0xbc, 0xc3, 0xbe, 0x8c, 0xc3, 0x52, 0xdf, 0x5c,
		0xff, 0x4e, 0xac, 0x56, 0x22, 0xd8, 0x35, 0xa4, 0x62, 0x42, 0xc5, 0x84, 0x8a, 0x09, 0x15, 0x93,
		0x2a, 0x54, 0x4c, 0x84, 0x4a, 0xd6, 0x0b, 0xee, 0x2d, 0x7a, 0x87, 0x8c, 0xda, 0x25, 0x1c, 0x54,
		0x28, 0xa8, 0x50, 0x50, 0xa1, 0xa0, 0x42, 0xa1, 0x17, 0xe0, 0x8b, 0x01, 0xb9, 0x84, 0x83, 0x53,
		0xbb, 0x6b, 0xf5, 0x4f, 0x0e, 0xda, 0x49, 0xc2, 0x4c, 0xb2, 0x30, 0x93, 0x34, 0x4c, 0x24, 0x0f,
		0xd9, 0x24, 0x22, 0x9c, 0x4c, 0x8a, 0x15, 0xe6, 0x12, 0x0e, 0x2e, 0xe1, 0x90, 0xfc, 0xe0, 0x9c,
		0xd8, 0x9d, 0x4d, 0x83, 0x13, 0xbb, 0xda, 0xe1, 0x6f, 0xde, 0x34, 0x39, 0xb1, 0xbb, 0x60, 0x9a,
		0x5c, 0xc2, 0xa1, 0x0d, 0x08, 0xf4, 0x46, 0x45, 0x0a, 0x6b, 0x79, 0xb3, 0xe5, 0x12, 0x8e, 0xa2,
		0x7a, 0xc1, 0x25, 0x1c, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x5b, 0x2a, 0xcf, 0x25,
		0x1c, 0xb5, 0x00, 0x2d, 0x5c, 0xc2, 0x01, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05,
		0x97, 0xfe, 0xce, 0x25, 0x1c, 0x5c, 0xc2, 0xa1, 0x10, 0x5a, 0xb8, 0x84, 0x63, 0x36, 0x0d, 0x5a,
		0x10, 0xda, 0x71, 0x78, 0xde, 0x34, 0xb9, 0x84, 0x03, 0xd3, 0xb4, 0x02, 0x48, 0xf4, 0x46, 0xa5,
		0xf3, 0xb0, 0xbc, 0xd9, 0x72, 0x09, 0x07, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea,
		0x25, 0xfd, 0x9d, 0x4b, 0x38, 0xe0, 0xd3, 0x7a, 0xa4, 0x85, 0x2d, 0x7d, 0xf0, 0x69, 0xa3, 0x7c,
		0x9a, 0x4b, 0x38, 0x60, 0xd4, 0x30, 0xea, 0x4a, 0x8e, 0xc4, 0x25, 0x1c, 0x7a, 0x82, 0x30, 0x73,
		0x97, 0x6f, 0x88, 0x1e, 0x01, 0x5f, 0xb3, 0xa9, 0x12, 0x73, 0xfb, 0xda, 0x0d, 0x09, 0xc5, 0x18,
		0x39, 0x57, 0xbb, 0x11, 0x51, 0xfd, 0x09, 0x54, 0x14, 0x1e, 0x05, 0x6f, 0x8d, 0x51, 0x93, 0x2e,
		0xd8, 0x40, 0xba, 0xa0, 0x3e, 0x65, 0x2c, 0xa4, 0x0b, 0x90, 0x2e, 0x28, 0x6d, 0x25, 0x91, 0x2e,
		0x40, 0xba, 0xa0, 0x7e, 0x49, 0x41, 0x3f, 0x39, 0x68, 0x27, 0x09, 0x33, 0xc9, 0xc2, 0x4c, 0xd2,
		0x30, 0x91, 0x3c, 0x74, 0xea, 0x0c, 0x48, 0x17, 0x88, 0x47, 0x77, 0xa4, 0x0b, 0x04, 0x3f, 0x38,
		0x7d, 0x8e, 0xd9, 0x34, 0xe8, 0x73, 0x68, 0x87, 0xbf, 0x79, 0xd3, 0xa4, 0xcf, 0xb1, 0x60, 0x9a,
		0x48, 0x17, 0x68, 0x03, 0x02, 0xbd, 0x51, 0xd9, 0x40, 0xb8, 0xbc, 0xd9, 0x22, 0x5d, 0x50, 0x54,
		0x2f, 0x90, 0x2e, 0x80, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xda, 0x52, 0x79, 0xa4, 0x0b,
		0x6a, 0x01, 0x5a, 0x90, 0x2e, 0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x82, 0x4b,
		0x7f, 0x47, 0xba, 0x00, 0xe9, 0x02, 0x85, 0xd0, 0x82, 0x74, 0xc1, 0x6c, 0x1a, 0xb4, 0x20, 0xb4,
		0xe3, 0xf0, 0xbc, 0x69, 0x22, 0x5d, 0x80, 0x69, 0x5a, 0x01, 0x24, 0x7a, 0xa3, 0xd2, 0x79, 0x58,
		0xde, 0x6c, 0x91, 0x2e, 0x80, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa4, 0xbf,
		0x23, 0x5d, 0x00, 0x9f, 0xd6, 0x23, 0x2d, 0x6c, 0xe9, 0x83, 0x4f, 0x1b, 0xe5, 0xd3, 0x48, 0x17,
		0xc0, 0xa8, 0x61, 0xd4, 0x95, 0x1c, 0x09, 0xe9, 0x02, 0x23, 0xd2, 0x05, 0x92, 0x27, 0xc0, 0xd7,
		0xec, 0x2b, 0x17, 0x9c, 0x8e, 0x96, 0xa3, 0x2e, 0xc2, 0x05, 0xcf, 0x2a, 0xec, 0xc2, 0xd2, 0xae,
		0x5b, 0x19, 0x97, 0xf5, 0x44, 0xe4, 0x28, 0x0c, 0x3b, 0xa9, 0x5b, 0xf7, 0x74, 0xe7, 0x34, 0x0e,
		0x1d, 0x46, 0x48, 0x3f, 0x44, 0x54, 0x37, 0x44, 0x48, 0x2f, 0x44, 0x4c, 0x27, 0x44, 0xb2, 0x76,
		0x2c, 0x5f, 0x2b, 0x96, 0xae, 0x0d, 0xab, 0xd5, 0x82, 0xd5, 0x6a, 0xbf, 0x2a, 0xb5, 0xde, 0x6a,
		0x43, 0x08, 0x29, 0x7d, 0x0f, 0x2f, 0x0b, 0xe3, 0xae, 0xdf, 0x1d, 0x9f, 0xc7, 0xf1, 0xd3, 0x64,
		0xa0, 0xa2, 0xe5, 0xb4, 0x38, 0x07, 0x29, 0x19, 0x15, 0x9d, 0x83, 0x48, 0xc2, 0x65, 0x20, 0xf1,
		0xa6, 0x23, 0x82, 0x52, 0xb5, 0x4e, 0x24, 0xea, 0x09, 0x45, 0x35, 0xb1, 0xd4, 0xb3, 0xdc, 0x24,
		0xde, 0x2c, 0x54, 0x3c, 0x28, 0x24, 0x7c, 0x40, 0x88, 0x72, 0x09, 0xe5, 0x92, 0xc7, 0x96, 0x4b,
		0xa4, 0x8a, 0x9a, 0x06, 0xeb, 0x24, 0x02, 0x05, 0x4c, 0x87, 0x15, 0x92, 0x67, 0x15, 0xf2, 0x3c,
		0x29, 0x8f, 0xb3, 0xec, 0x69, 0x9e, 0xd3, 0x92, 0x96, 0x31, 0xdf, 0x72, 0xe3, 0x55, 0xe5, 0xdb,
		0xbc, 0x03, 0x7b, 0xf7, 0xa2, 0xfe, 0xf5, 0xb6, 0xdf, 0x0b, 0xce, 0xc3, 0x5e, 0xd8, 0x2d, 0x1e,
		0xbe, 0x2b, 0xab, 0x2f, 0x40, 0xcd, 0xbd, 0xa3, 0x3a, 0xf2, 0x66, 0xb7, 0xd5, 0x46, 0xe7, 0xe4,
		0x51, 0x82, 0x2c, 0xca, 0x91, 0x43, 0x29, 0x32, 0x28, 0x4e, 0xfe, 0xc4, 0xc9, 0x9e, 0x28, 0xb9,
		0xab, 0x56, 0xfe, 0x76, 0x5d, 0x1d, 0xf4, 0xe6, 0xba, 0x76, 0x62, 0xbd, 0x19, 0xc1, 0x5e, 0xa1,
		0x78, 0x8b, 0x66, 0x9d, 0x16, 0x4d, 0x75, 0x2a, 0x6c, 0xb4, 0x68, 0x68, 0xd1, 0xa8, 0x07, 0xe1,
		0x62, 0xa0, 0xce, 0x34, 0x86, 0x08, 0xb7, 0x65, 0x44, 0xef, 0x86, 0x51, 0xbb, 0x63, 0x83, 0x96,
		0x48, 0x0d, 0x02, 0xb6, 0x7a, 0xe0, 0x56, 0x0f, 0xe0, 0xaa, 0x81, 0x5c, 0x26, 0xa0, 0x0b, 0x05,
		0x76, 0xf1, 0x00, 0x5f, 0x0c, 0xc8, 0x1d, 0x1b, 0x1c, 0xca, 0x5d, 0xab, 0x7f, 0x72, 0xd0, 0x4e,
		0x12, 0x66, 0x92, 0x85, 0x99, 0xa4, 0x61, 0x22, 0x79, 0xc8, 0x26, 0x11, 0xe1, 0x64, 0x52, 0xac,
		0x30, 0x77, 0x6c, 0x70, 0xc7, 0x86, 0xe4, 0x07, 0xe7, 0x40, 0xee, 0x6c, 0x1a, 0x1c, 0xc8, 0xd5,
		0x0e, 0x7f, 0xf3, 0xa6, 0xc9, 0x81, 0xdc, 0x05, 0xd3, 0xe4, 0x8e, 0x0d, 0x6d, 0x40, 0xa0, 0x37,
		0x2a, 0x4a, 0x57, 0xcb, 0x9b, 0x2d, 0x77, 0x6c, 0x14, 0xd5, 0x0b, 0xee, 0xd8, 0x80, 0xca, 0x43,
		0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xda, 0x52, 0x79, 0xee, 0xd8, 0xa8, 0x05, 0x68, 0xe1, 0x8e, 0x0d,
		0xe0, 0x02, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x00, 0x2e, 0xb8, 0xf4, 0x77, 0xee, 0xd8, 0xe0, 0x8e,
		0x0d, 0x85, 0xd0, 0xc2, 0x1d, 0x1b, 0xb3, 0x69, 0xd0, 0x82, 0xd0, 0x8e, 0xc3, 0xf3, 0xa6, 0xc9,
		0x1d, 0x1b, 0x98, 0xa6, 0x15, 0x40, 0xa2, 0x37, 0x2a, 0x9d, 0x87, 0xe5, 0xcd, 0x96, 0x3b, 0x36,
		0x20, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x2f, 0xe9, 0xef, 0xdc, 0xb1, 0x01, 0x9f,
		0xd6, 0x23, 0x2d, 0x6c, 0xe9, 0x83, 0x4f, 0x1b, 0xe5, 0xd3, 0xdc, 0xb1, 0x01, 0xa3, 0x86, 0x51,
		0x57, 0x72, 0x24, 0xee, 0xd8, 0x90, 0xd6, 0xc5, 0x5a, 0x10, 0x2b, 0x9a, 0xbf, 0x6b, 0x43, 0xf4,
		0x28, 0xf8, 0x9a, 0x29, 0x0d, 0xad, 0xed, 0xc3, 0xf1, 0xc2, 0xdc, 0x77, 0xe7, 0xc6, 0xa4, 0xd0,
		0x50, 0x17, 0x15, 0x49, 0x11, 0xd9, 0xc1, 0x40, 0x45, 0x61, 0x5a, 0xf0, 0xae, 0x18, 0x35, 0x25,
		0x83, 0x0d, 0x94, 0x0c, 0xea, 0x53, 0xd5, 0x42, 0xc9, 0x00, 0x25, 0x83, 0xd2, 0x56, 0x12, 0x25,
		0x03, 0x94, 0x0c, 0xea, 0x97, 0x14, 0xf4, 0x93, 0x83, 0x76, 0x92, 0x30, 0x93, 0x2c, 0xcc, 0x24,
		0x0d, 0x13, 0xc9, 0x43, 0xa7, 0xec, 0x80, 0x92, 0x81, 0x78, 0x74, 0x47, 0xc9, 0x40, 0xf0, 0x83,
		0xd3, 0xf6, 0x98, 0x4d, 0x83, 0xb6, 0x87, 0x76, 0xf8, 0x9b, 0x37, 0x4d, 0xda, 0x1e, 0x0b, 0xa6,
		0x89, 0x92, 0x81, 0x36, 0x20, 0xd0, 0x1b, 0x95, 0xfd, 0x84, 0xcb, 0x9b, 0x2d, 0x4a, 0x06, 0x45,
		0xf5, 0x02, 0x25, 0x03, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0xaf, 0x2d, 0x95, 0x47, 0xc9,
		0xa0, 0x16, 0xa0, 0x05, 0x25, 0x03, 0xe0, 0x02, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x00, 0x2e, 0xb8,
		0xf4, 0x77, 0x94, 0x0c, 0x50, 0x32, 0x50, 0x08, 0x2d, 0x28, 0x19, 0xcc, 0xa6, 0x41, 0x0b, 0x42,
		0x3b, 0x0e, 0xcf, 0x9b, 0x26, 0x4a, 0x06, 0x98, 0xa6, 0x15, 0x40, 0xa2, 0x37, 0x2a, 0x9d, 0x87,
		0xe5, 0xcd, 0x16, 0x25, 0x03, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x4b, 0xfa,
		0x3b, 0x4a, 0x06, 0xf0, 0x69, 0x3d, 0xd2, 0xc2, 0x96, 0x3e, 0xf8, 0xb4, 0x51, 0x3e, 0x8d, 0x92,
		0x01, 0x8c, 0x1a, 0x46, 0x5d, 0xc9, 0x91, 0x50, 0x32, 0x30, 0xa6, 0x64, 0x20, 0x79, 0x12, 0x7c,
		0xad, 0x32, 0x42, 0x06, 0xa7, 0xa3, 0x55, 0xa9, 0x8b, 0x8e, 0xc1, 0xb3, 0x0a, 0x7b, 0xb4, 0xb4,
		0x27, 0x57, 0xce, 0x83, 0x3d, 0x11, 0x95, 0x0a, 0xfb, 0x3e, 0xeb, 0xd6, 0x5b, 0xdd, 0xf9, 0x90,
		0x9b, 0x77, 0x76, 0xe4, 0x95, 0x52, 0xde, 0x58, 0x05, 0x2f, 0x74, 0xe8, 0x78, 0x66, 0x1d, 0xce,
		0x8d, 0x93, 0x95, 0xef, 0x02, 0x0e, 0xcc, 0xdf, 0x1b, 0xd9, 0xc0, 0xf4, 0xd9, 0xbb, 0x32, 0xfe,
		0xa2, 0xf8, 0x37, 0x37, 0x9a, 0x23, 0x67, 0x76, 0x2b, 0xcc, 0xe3, 0xbc, 0x59, 0x23, 0xd1, 0x94,
		0x91, 0x6b, 0xbe, 0x48, 0x35, 0x59, 0xc4, 0x9b, 0x29, 0xe2, 0x4d, 0x13, 0xd1, 0xe6, 0x48, 0xb5,
		0xd2, 0xb7, 0x6b, 0xe1, 0x1b, 0xaf, 0x33, 0xf5, 0x79, 0xc7, 0x46, 0x3c, 0x75, 0x4b, 0x11, 0x21,
		0x3e, 0x21, 0x05, 0x33, 0xb1, 0xee, 0xb6, 0x64, 0x37, 0x5b, 0xbe, 0x7b, 0x2d, 0xdd, 0xad, 0x56,
		0xeb, 0x4e, 0xab, 0x75, 0xa3, 0x55, 0xba, 0xcf, 0xd5, 0xae, 0x62, 0x48, 0x29, 0x8e, 0x79, 0x59,
		0x18, 0x77, 0xfd, 0xee, 0xf8, 0x84, 0xb0, 0x9f, 0x26, 0x03, 0x15, 0x75, 0xc9, 0xc5, 0x39, 0x48,
		0x09, 0xbb, 0xe9, 0x1c, 0x8d, 0x16, 0x6e, 0x4c, 0x89, 0x6f, 0x83, 0x42, 0xe2, 0xb2, 0xd6, 0x89,
		0x44, 0x3d, 0xa1, 0xa8, 0x26, 0x16, 0x99, 0x04, 0x23, 0x94, 0x68, 0x8a, 0x95, 0x14, 0xdf, 0xbe,
		0xa4, 0x78, 0x74, 0x59, 0xf8, 0xc8, 0x32, 0x1d, 0x9b, 0x1f, 0x38, 0x31, 0x1d, 0x9b, 0xa2, 0x53,
		0x23, 0x26, 0x14, 0x6f, 0xa8, 0x64, 0x3c, 0x6d, 0xce, 0x48, 0xa8, 0xc1, 0x3b, 0xec, 0xcb, 0x38,
		0x2c, 0xf5, 0xcd, 0xf5, 0xef, 0xc4, 0x6a, 0x25, 0x82, 0x5d, 0x43, 0x2a, 0x26, 0x54, 0x4c, 0xa8,
		0x98, 0x50, 0x31, 0xa9, 0x42, 0xc5, 0x44, 0xa8, 0x64, 0xbd, 0xe0, 0xde, 0xa2, 0x77, 0xc8, 0xa8,
		0x5d, 0xc2, 0x41, 0x85, 0x82, 0x0a, 0x05, 0x15, 0x0a, 0x2a, 0x14, 0x7a, 0x01, 0xbe, 0x18, 0x90,
		0x4b, 0x38, 0x38, 0xb5, 0xbb, 0x56, 0xff, 0xe4, 0xa0, 0x9d, 0x24, 0xcc, 0x24, 0x0b, 0x33, 0x49,
		0xc3, 0x44, 0xf2, 0x90, 0x4d, 0x22, 0xc2, 0xc9, 0xa4, 0x58, 0x61, 0x2e, 0xe1, 0xe0, 0x12, 0x0e,
		0xc9, 0x0f, 0xce, 0x89, 0xdd, 0xd9, 0x34, 0x38, 0xb1, 0xab, 0x1d, 0xfe, 0xe6, 0x4d, 0x93, 0x13,
		0xbb, 0x0b, 0xa6, 0xc9, 0x25, 0x1c, 0xda, 0x80, 0x40, 0x6f, 0x54, 0xa4, 0xb0, 0x96, 0x37, 0x5b,
		0x2e, 0xe1, 0x28, 0xaa, 0x17, 0x5c, 0xc2, 0x01, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0xb5,
		0xa5, 0xf2, 0x5c, 0xc2, 0x51, 0x0b, 0xd0, 0xc2, 0x25, 0x1c, 0xc0, 0x05, 0xe0, 0x02, 0x70, 0x01,
		0xb8, 0x00, 0x5c, 0x70, 0xe9, 0xef, 0x5c, 0xc2, 0xc1, 0x25, 0x1c, 0x0a, 0xa1, 0x85, 0x4b, 0x38,
		0x66, 0xd3, 0xa0, 0x05, 0xa1, 0x1d, 0x87, 0xe7, 0x4d, 0x93, 0x4b, 0x38, 0x30, 0x4d, 0x2b, 0x80,
		0x44, 0x6f, 0x54, 0x3a, 0x0f, 0xcb, 0x9b, 0x2d, 0x97, 0x70, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a,
		0x48, 0x3d, 0xa4, 0x5e, 0xd2, 0xdf, 0xb9, 0x84, 0x03, 0x3e, 0xad, 0x47, 0x5a, 0xd8, 0xd2, 0x07,
		0x9f, 0x36, 0xca, 0xa7, 0xb9, 0x84, 0x03, 0x46, 0x0d, 0xa3, 0xae, 0xe4, 0x48, 0x5c, 0xc2, 0xa1,
		0x27, 0x08, 0x33, 0x77, 0xf9, 0x86, 0xe8, 0x11, 0xf0, 0x35, 0x9b, 0x2a, 0x31, 0xb7, 0xaf, 0xdd,
		0x90, 0x50, 0x8c, 0x91, 0x73, 0xb5, 0x1b, 0x11, 0xd5, 0x9f, 0x40, 0x45, 0xe1, 0x51, 0xf0, 0xd6,
		0x18, 0x35, 0xe9, 0x82, 0x0d, 0xa4, 0x0b, 0xea, 0x53, 0xc6, 0x42, 0xba, 0x00, 0xe9, 0x82, 0xd2,
		0x56, 0x12, 0xe9, 0x02, 0xa4, 0x0b, 0xea, 0x97, 0x14, 0xf4, 0x93, 0x83, 0x76, 0x92, 0x30, 0x93,
		0x2c, 0xcc, 0x24, 0x0d, 0x13, 0xc9, 0x43, 0xa7, 0xce, 0x80, 0x74, 0x81, 0x78, 0x74, 0x47, 0xba,
		0x40, 0xf0, 0x83, 0xd3, 0xe7, 0x98, 0x4d, 0x83, 0x3e, 0x87, 0x76, 0xf8, 0x9b, 0x37, 0x4d, 0xfa,
		0x1c, 0x0b, 0xa6, 0x89, 0x74, 0x81, 0x36, 0x20, 0xd0, 0x1b, 0x95, 0x0d, 0x84, 0xcb, 0x9b, 0x2d,
		0xd2, 0x05, 0x45, 0xf5, 0x02, 0xe9, 0x02, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0xaf, 0x2d,
		0x95, 0x47, 0xba, 0xa0, 0x16, 0xa0, 0x05, 0xe9, 0x02, 0xe0, 0x02, 0x70, 0x01, 0xb8, 0x00, 0x5c,
		0x00, 0x2e, 0xb8, 0xf4, 0x77, 0xa4, 0x0b, 0x90, 0x2e, 0x50, 0x08, 0x2d, 0x48, 0x17, 0xcc, 0xa6,
		0x41, 0x0b, 0x42, 0x3b, 0x0e, 0xcf, 0x9b, 0x26, 0xd2, 0x05, 0x98, 0xa6, 0x15, 0x40, 0xa2, 0x37,
		0x2a, 0x9d, 0x87, 0xe5, 0xcd, 0x16, 0xe9, 0x02, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87,
		0xd4, 0x4b, 0xfa, 0x3b, 0xd2, 0x05, 0xf0, 0x69, 0x3d, 0xd2, 0xc2, 0x96, 0x3e, 0xf8, 0xb4, 0x51,
		0x3e, 0x8d, 0x74, 0x01, 0x8c, 0x1a, 0x46, 0x5d, 0xc9, 0x91, 0x90, 0x2e, 0x30, 0x22, 0x5d, 0x20,
		0x79, 0x02, 0x7c, 0xcd, 0xbe, 0x72, 0xc1, 0xe9, 0x68, 0x39, 0xea, 0x22, 0x5c, 0xf0, 0xac, 0xc2,
		0x2e, 0x2c, 0xed, 0xba, 0x95, 0x71, 0x59, 0x4f, 0x44, 0x8e, 0xc2, 0xb0, 0x93, 0xba, 0x75, 0x4f,
		0x77, 0x4e, 0xe3, 0xd0, 0x61, 0x84, 0xf4, 0x43, 0x44, 0x75, 0x43, 0x84, 0xf4, 0x42, 0xc4, 0x74,
		0x42, 0x24, 0x6b, 0xc7, 0xf2, 0xb5, 0x62, 0xe9, 0xda, 0xb0, 0x5a, 0x2d, 0x58, 0xad, 0xf6, 0xab,
		0x52, 0xeb, 0xad, 0x36, 0x84, 0x90, 0xd2, 0xf7, 0xf0, 0xb2, 0x30, 0xee, 0xfa, 0xdd, 0xf1, 0x79,
		0x1c, 0x3f, 0x4d, 0x06, 0x2a, 0x5a, 0x4e, 0x8b, 0x73, 0x90, 0x92, 0x51, 0xd1, 0x39, 0x88, 0x24,
		0x5c, 0x06, 0x12, 0x6f, 0x3a, 0x22, 0x28, 0x55, 0xeb, 0x44, 0xa2, 0x9e, 0x50, 0x54, 0x13, 0x4b,
		0x3d, 0xcb, 0x4d, 0xe2, 0xcd, 0x42, 0xc5, 0x83, 0x42, 0xc2, 0x07, 0x84, 0x28, 0x97, 0x50, 0x2e,
		0x79, 0x6c, 0xb9, 0x44, 0xaa, 0xa8, 0x69, 0xb0, 0x4e, 0x22, 0x50, 0xc0, 0x74, 0x58, 0x21, 0x79,
		0x56, 0x21, 0xcf, 0x93, 0xf2, 0x38, 0xcb, 0x9e, 0xe6, 0x39, 0x2d, 0x69, 0x19, 0xf3, 0x2d, 0x37,
		0x5e, 0x55, 0xbe, 0xcd, 0x3b, 0xb0, 0x77, 0xaf, 0xb7, 0x71, 0xdd, 0x8f, 0xfd, 0xf0, 0xba, 0xef,
		0xce, 0xd6, 0x0b, 0x28, 0x73, 0x6b, 0x2c, 0x47, 0x9e, 0xeb, 0xb6, 0xb2, 0xe8, 0x9c, 0x28, 0x4a,
		0x10, 0x43, 0x39, 0x22, 0x28, 0x45, 0xfc, 0xc4, 0x89, 0x9e, 0x38, 0xb1, 0x13, 0x25, 0x72, 0xd5,
		0xca, 0xd5, 0xae, 0x2b, 0x81, 0xde, 0x5c, 0x87, 0x4e, 0xac, 0x0f, 0x23, 0xd8, 0x17, 0x14, 0x6f,
		0xc7, 0xac, 0xd3, 0x8e, 0xa9, 0x4e, 0x35, 0x8d, 0x76, 0x0c, 0xed, 0x18, 0xf5, 0x20, 0x5c, 0x0c,
		0xd4, 0x99, 0xc6, 0x10, 0xe1, 0x16, 0x8c, 0xe8, 0x3d, 0x30, 0x6a, 0xf7, 0x69, 0xd0, 0xfe, 0xa8,
		0x41, 0xc0, 0x56, 0x0f, 0xdc, 0xea, 0x01, 0x5c, 0x35, 0x90, 0xcb, 0x04, 0x74, 0xa1, 0xc0, 0x2e,
		0x1e, 0xe0, 0x8b, 0x01, 0xb9, 0x4f, 0x83, 0x03, 0xb8, 0x6b, 0xf5, 0x4f, 0x0e, 0xda, 0x49, 0xc2,
		0x4c, 0xb2, 0x30, 0x93, 0x34, 0x4c, 0x24, 0x0f, 0xd9, 0x24, 0x22, 0x9c, 0x4c, 0x8a, 0x15, 0xe6,
		0x3e, 0x0d, 0xee, 0xd3, 0x90, 0xfc, 0xe0, 0x1c, 0xbe, 0x9d, 0x4d, 0x83, 0xc3, 0xb7, 0xda, 0xe1,
		0x6f, 0xde, 0x34, 0x39, 0x7c, 0xbb, 0x60, 0x9a, 0xdc, 0xa7, 0xa1, 0x0d, 0x08, 0xf4, 0x46, 0x45,
		0xd5, 0x6a, 0x79, 0xb3, 0xe5, 0x3e, 0x8d, 0xa2, 0x7a, 0xc1, 0x7d, 0x1a, 0x50, 0x79, 0xa8, 0x3c,
		0x54, 0x1e, 0x2a, 0x5f, 0x5b, 0x2a, 0xcf, 0x7d, 0x1a, 0xb5, 0x00, 0x2d, 0xdc, 0xa7, 0x01, 0x5c,
		0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0x97, 0xfe, 0xce, 0x7d, 0x1a, 0xdc, 0xa7, 0xa1,
		0x10, 0x5a, 0xb8, 0x4f, 0x63, 0x36, 0x0d, 0x5a, 0x10, 0xda, 0x71, 0x78, 0xde, 0x34, 0xb9, 0x4f,
		0x03, 0xd3, 0xb4, 0x02, 0x48, 0xf4, 0x46, 0xa5, 0xf3, 0xb0, 0xbc, 0xd9, 0x72, 0x9f, 0x06, 0xa4,
		0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x25, 0xfd, 0x9d, 0xfb, 0x34, 0xe0, 0xd3, 0x7a,
		0xa4, 0x85, 0x2d, 0x7d, 0xf0, 0x69, 0xa3, 0x7c, 0x9a, 0xfb, 0x34, 0x60, 0xd4, 0x30, 0xea, 0x4a,
		0x8e, 0xc4, 0x7d, 0x1a, 0xa2, 0x1a, 0x58, 0x33, 0x89, 0xa2, 0xf9, 0xdb, 0x34, 0x44, 0x0f, 0x80,
		0xaf, 0xd9, 0x51, 0xc9, 0x3a, 0xdc, 0xf8, 0xd4, 0x8f, 0xf7, 0xaf, 0xfb, 0xf1, 0xdc, 0x65, 0x1a,
		0x93, 0xaa, 0x42, 0x5d, 0xe4, 0x21, 0x45, 0xf4, 0x04, 0x03, 0x15, 0xe9, 0x68, 0xc1, 0x4b, 0x60,
		0xd4, 0x64, 0x0b, 0x36, 0x90, 0x2d, 0xa8, 0x4f, 0x09, 0x0b, 0xd9, 0x02, 0x64, 0x0b, 0x4a, 0x5b,
		0x49, 0x64, 0x0b, 0x90, 0x2d, 0xa8, 0x5f, 0x52, 0xd0, 0x4f, 0x0e, 0xda, 0x49, 0xc2, 0x4c, 0xb2,
		0x30, 0x93, 0x34, 0x4c, 0x24, 0x0f, 0x9d, 0x1a, 0x03, 0xb2, 0x05, 0xe2, 0xd1, 0x1d, 0xd9, 0x02,
		0xc1, 0x0f, 0x4e, 0x8f, 0x63, 0x36, 0x0d, 0x7a, 0x1c, 0xda, 0xe1, 0x6f, 0xde, 0x34, 0xe9, 0x71,
		0x2c, 0x98, 0x26, 0xb2, 0x05, 0xda, 0x80, 0x40, 0x6f, 0x54, 0x36, 0x0f, 0x2e, 0x6f, 0xb6, 0xc8,
		0x16, 0x14, 0xd5, 0x0b, 0x64, 0x0b, 0xa0, 0xf2, 0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb6, 0x54,
		0x1e, 0xd9, 0x82, 0x5a, 0x80, 0x16, 0x64, 0x0b, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x02, 0x70, 0x01,
		0xb8, 0xe0, 0xd2, 0xdf, 0x91, 0x2d, 0x40, 0xb6, 0x40, 0x21, 0xb4, 0x20, 0x5b, 0x30, 0x9b, 0x06,
		0x2d, 0x08, 0xed, 0x38, 0x3c, 0x6f, 0x9a, 0xc8, 0x16, 0x60, 0x9a, 0x56, 0x00, 0x89, 0xde, 0xa8,
		0x74, 0x1e, 0x96, 0x37, 0x5b, 0x64, 0x0b, 0x20, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52,
		0x2f, 0xe9, 0xef, 0xc8, 0x16, 0xc0, 0xa7, 0xf5, 0x48, 0x0b, 0x5b, 0xfa, 0xe0, 0xd3, 0x46, 0xf9,
		0x34, 0xb2, 0x05, 0x30, 0x6a, 0x18, 0x75, 0x25, 0x47, 0x42, 0xb6, 0xc0, 0x84, 0x6c, 0x81, 0xe4,
		0xf9, 0xef, 0x35, 0xeb, 0xaa, 0x05, 0xa7, 0xa3, 0xc5, 0xa8, 0x8b, 0x68, 0xc1, 0xb3, 0x0a, 0xbb,
		0xaf, 0xb4, 0xdb, 0x56, 0xc4, 0x5d, 0x3d, 0x11, 0x21, 0x0a, 0xb3, 0x0e, 0xea, 0xd6, 0x35, 0xdd,
		0x39, 0x8c, 0x9b, 0x77, 0x76, 0xe4, 0x82, 0x52, 0xae, 0x67, 0xd7, 0xe5, 0x1c, 0x7a, 0x99, 0x35,
		0xef, 0x72, 0xe3, 0x51, 0xe5, 0xdb, 0xbb, 0x03, 0x5b, 0xf7, 0xc6, 0x0f, 0xfc, 0xba, 0xdf, 0x73,
		0x27, 0xc4, 0x50, 0x54, 0xf0, 0x6e, 0x8d, 0xe5, 0xc8, 0x6b, 0xdd, 0x6a, 0xeb, 0x38, 0xef, 0xb7,
		0x48, 0xf4, 0x55, 0xe4, 0xfa, 0x27, 0x52, 0x7d, 0x12, 0xf1, 0x7e, 0x88, 0x78, 0xdf, 0x43, 0xb4,
		0xbf, 0x51, 0xad, 0x3c, 0xed, 0x5a, 0xbb, 0xc6, 0x9b, 0x43, 0x9e, 0xce, 0x4d, 0xf9, 0xd6, 0xa1,
		0x3a, 0x29, 0xbc, 0x2b, 0x24, 0x48, 0x26, 0xd6, 0xac, 0x96, 0x6c, 0x4e, 0xcb, 0x37, 0xa3, 0xa5,
		0x9b, 0xcf, 0x6a, 0xcd, 0x66, 0xb5, 0xe6, 0xb2, 0x4a, 0x33, 0xb9, 0xda, 0x75, 0x0a, 0x29, 0x01,
		0x31, 0xaf, 0x33, 0x8d, 0x21, 0xc2, 0x02, 0x91, 0xa2, 0xba, 0xa6, 0x6a, 0x0a, 0x91, 0xeb, 0x28,
		0x44, 0x56, 0x3f, 0x60, 0xab, 0x07, 0x6e, 0xf5, 0x00, 0xae, 0x1a, 0xc8, 0x65, 0x02, 0xba, 0x50,
		0x60, 0x17, 0x0f, 0xf0, 0xc5, 0x80, 0x28, 0x44, 0xb2, 0xa5, 0x74, 0xad, 0xfe, 0xc9, 0x41, 0x3b,
		0x49, 0x98, 0x49, 0x16, 0x66, 0x92, 0x86, 0x89, 0xe4, 0x21, 0x9b, 0x44, 0x84, 0x93, 0x49, 0xb1,
		0xc2, 0x28, 0x44, 0xa2, 0x10, 0x29, 0xf9, 0xc1, 0xd9, 0x4e, 0x3a, 0x9b, 0x06, 0xdb, 0x49, 0xb5,
		0xc3, 0xdf, 0xbc, 0x69, 0xb2, 0x9d, 0x74, 0xc1, 0x34, 0x51, 0x88, 0xd4, 0x06, 0x04, 0x7a, 0xa3,
		0x72, 0x4e, 0x73, 0x79, 0xb3, 0x45, 0x21, 0xb2, 0xa8, 0x5e, 0xa0, 0x10, 0x09, 0x95, 0x87, 0xca,
		0x43, 0xe5, 0xa1, 0xf2, 0xb5, 0xa5, 0xf2, 0x28, 0x44, 0xd6, 0x02, 0xb4, 0xa0, 0x10, 0x09, 0x5c,
		0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0x97, 0xfe, 0x8e, 0x42, 0x24, 0x0a, 0x91, 0x0a,
		0xa1, 0x05, 0x85, 0xc8, 0xd9, 0x34, 0x68, 0x41, 0x68, 0xc7, 0xe1, 0x79, 0xd3, 0x44, 0x21, 0x12,
		0xd3, 0xb4, 0x02, 0x48, 0xf4, 0x46, 0xa5, 0xf3, 0xb0, 0xbc, 0xd9, 0xa2, 0x10, 0x09, 0xa9, 0x87,
		0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x49, 0x7f, 0x47, 0x21, 0x12, 0x3e, 0xad, 0x47, 0x5a,
		0xd8, 0xd2, 0x07, 0x9f, 0x36, 0xca, 0xa7, 0x51, 0x88, 0x84, 0x51, 0xc3, 0xa8, 0x2b, 0x39, 0x12,
		0x0a, 0x91, 0x0a, 0xfa, 0x57, 0xd7, 0xfd, 0xd1, 0x3b, 0xdc, 0x52, 0x88, 0x14, 0x3d, 0x00, 0xbe,
		0x66, 0x4c, 0x23, 0xeb, 0x53, 0x7f, 0xf4, 0xc7, 0x33, 0x89, 0xc8, 0x49, 0x55, 0xa1, 0x2e, 0x1a,
		0x91, 0x22, 0x7a, 0x82, 0x41, 0x1e, 0xca, 0xeb, 0x16, 0x48, 0x0a, 0x9b, 0xaa, 0xc9, 0x16, 0x6c,
		0x20, 0x5b, 0x50, 0x9f, 0x12, 0x16, 0xb2, 0x05, 0xc8, 0x16, 0x94, 0xb6, 0x92, 0xc8, 0x16, 0x20,
		0x5b, 0x50, 0xbf, 0xa4, 0xa0, 0x9f, 0x1c, 0xb4, 0x93, 0x84, 0x99, 0x64, 0x61, 0x26, 0x69, 0x98,
		0x48, 0x1e, 0x3a, 0x35, 0x06, 0x64, 0x0b, 0xc4, 0xa3, 0x3b, 0xb2, 0x05, 0x82, 0x1f, 0x9c, 0x1e,
		0xc7, 0x6c, 0x1a, 0xf4, 0x38, 0xb4, 0xc3, 0xdf, 0xbc, 0x69, 0xd2, 0xe3, 0x58, 0x30, 0x4d, 0x64,
		0x0b, 0xb4, 0x01, 0x81, 0xde, 0xa8, 0x6c, 0x1e, 0x5c, 0xde, 0x6c, 0x91, 0x2d, 0x28, 0xaa, 0x17,
		0xc8, 0x16, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x6d, 0xa9, 0x3c, 0xb2, 0x05, 0xb5,
		0x00, 0x2d, 0xc8, 0x16, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x02, 0x70, 0xc1, 0xa5, 0xbf,
		0x23, 0x5b, 0x80, 0x6c, 0x81, 0x42, 0x68, 0x41, 0xb6, 0x60, 0x36, 0x0d, 0x5a, 0x10, 0xda, 0x71,
		0x78, 0xde, 0x34, 0x91, 0x2d, 0xc0, 0x34, 0xad, 0x00, 0x12, 0xbd, 0x51, 0xe9, 0x3c, 0x2c, 0x6f,
		0xb6, 0xc8, 0x16, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xd2, 0xdf, 0x91,
		0x2d, 0x80, 0x4f, 0xeb, 0x91, 0x16, 0xb6, 0xf4, 0xc1, 0xa7, 0x8d, 0xf2, 0x69, 0x64, 0x0b, 0x60,
		0xd4, 0x30, 0xea, 0x4a, 0x8e, 0x84, 0x6c, 0x81, 0x09, 0xd9, 0x02, 0xc9, 0xf3, 0xdf, 0x6b, 0xd6,
		0x55, 0x0b, 0x4e, 0x47, 0x8b, 0x51, 0x17, 0xd1, 0x82, 0x67, 0x15, 0x76, 0x5f, 0x69, 0xb7, 0xad,
		0x88, 0xbb, 0x7a, 0x22, 0x42, 0x14, 0x66, 0x1d, 0xd4, 0xad, 0x6b, 0xba, 0x73, 0x18, 0x37, 0xef,
		0xec, 0xc8, 0x05, 0xa5, 0x5c, 0xcf, 0xae, 0xcb, 0x39, 0xf4, 0x32, 0x6b, 0xde, 0xe5, 0xc6, 0xa3,
		0xca, 0xb7, 0x77, 0x07, 0xb6, 0xee, 0xf5, 0x36, 0x87, 0x0f, 0x3c, 0xea, 0x5f, 0xb7, 0xfc, 0xab,
		0x41, 0x2f, 0x8f, 0x3a, 0x41, 0xe6, 0xae, 0x99, 0x53, 0xd4, 0xf2, 0xee, 0x1d, 0xd5, 0x91, 0x27,
		0xbb, 0xd5, 0xdb, 0x71, 0xde, 0x83, 0x91, 0xe8, 0xb5, 0xc8, 0xf5, 0x54, 0xa4, 0x7a, 0x27, 0xe2,
		0x3d, 0x12, 0xf1, 0x5e, 0x88, 0x68, 0xcf, 0xa3, 0x5a, 0xb9, 0xdb, 0xb5, 0x9e, 0x8d, 0x37, 0x87,
		0x46, 0x9d, 0x9b, 0xf2, 0xad, 0x83, 0x76, 0x52, 0x18, 0x58, 0x48, 0xa4, 0x4c, 0xac, 0x81, 0x2d,
		0xd9, 0xb0, 0x96, 0x6f, 0x50, 0x4b, 0x37, 0xa4, 0xd5, 0x1a, 0xd0, 0x6a, 0x0d, 0x67, 0x95, 0x06,
		0x73, 0xb5, 0x6b, 0x17, 0x52, 0xa2, 0x62, 0x5e, 0x67, 0x1a, 0x43, 0x84, 0x45, 0x23, 0x45, 0xb5,
		0x4e, 0xd5, 0x54, 0x23, 0xd7, 0x51, 0x8d, 0xac, 0x7e, 0xc0, 0x56, 0x0f, 0xdc, 0xea, 0x01, 0x5c,
		0x35, 0x90, 0xcb, 0x04, 0x74, 0xa1, 0xc0, 0x2e, 0x1e, 0xe0, 0x8b, 0x01, 0x51, 0x8d, 0x64, 0x9b,
		0xe9, 0x5a, 0xfd, 0x93, 0x83, 0x76, 0x92, 0x30, 0x93, 0x2c, 0xcc, 0x24, 0x0d, 0x13, 0xc9, 0x43,
		0x36, 0x89, 0x08, 0x27, 0x93, 0x62, 0x85, 0x51, 0x8d, 0x44, 0x35, 0x52, 0xf2, 0x83, 0xb3, 0xc5,
		0x74, 0x36, 0x0d, 0xb6, 0x98, 0x6a, 0x87, 0xbf, 0x79, 0xd3, 0x64, 0x8b, 0xe9, 0x82, 0x69, 0xa2,
		0x1a, 0xa9, 0x0d, 0x08, 0xf4, 0x46, 0xe5, 0xec, 0xe6, 0xf2, 0x66, 0x8b, 0x6a, 0x64, 0x51, 0xbd,
		0x40, 0x35, 0x12, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x6b, 0x4b, 0xe5, 0x51, 0x8d, 0xac,
		0x05, 0x68, 0x41, 0x35, 0x12, 0xb8, 0x00, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0x2e, 0xfd,
		0x1d, 0xd5, 0x48, 0x54, 0x23, 0x15, 0x42, 0x0b, 0xaa, 0x91, 0xb3, 0x69, 0xd0, 0x82, 0xd0, 0x8e,
		0xc3, 0xf3, 0xa6, 0x89, 0x6a, 0x24, 0xa6, 0x69, 0x05, 0x90, 0xe8, 0x8d, 0x4a, 0xe7, 0x61, 0x79,
		0xb3, 0x45, 0x35, 0x12, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x92, 0xfe, 0x8e,
		0x6a, 0x24, 0x7c, 0x5a, 0x8f, 0xb4, 0xb0, 0xa5, 0x0f, 0x3e, 0x6d, 0x94, 0x4f, 0xa3, 0x1a, 0x09,
		0xa3, 0x86, 0x51, 0x57, 0x72, 0x24, 0x54, 0x23, 0x65, 0x35, 0xb1, 0xee, 0x11, 0x2b, 0x9a, 0xd7,
		0x8f, 0x14, 0x3d, 0x0a, 0xbe, 0x66, 0x48, 0x41, 0x6b, 0xf3, 0x53, 0x3f, 0x3e, 0xe8, 0x5f, 0xb7,
		0xde, 0x4d, 0xd7, 0x65, 0x4e, 0x49, 0x72, 0x52, 0x68, 0xa8, 0x8b, 0x94, 0xa4, 0x88, 0xec, 0x60,
		0x90, 0x87, 0xf2, 0x52, 0x06, 0x92, 0xfa, 0xa7, 0x6a, 0x4a, 0x06, 0x1b, 0x28, 0x19, 0xd4, 0xa7,
		0xaa, 0x85, 0x92, 0x01, 0x4a, 0x06, 0xa5, 0xad, 0x24, 0x4a, 0x06, 0x28, 0x19, 0xd4, 0x2f, 0x29,
		0xe8, 0x27, 0x07, 0xed, 0x24, 0x61, 0x26, 0x59, 0x98, 0x49, 0x1a, 0x26, 0x92, 0x87, 0x4e, 0xd9,
		0x01, 0x25, 0x03, 0xf1, 0xe8, 0x8e, 0x92, 0x81, 0xe0, 0x07, 0xa7, 0xed, 0x31, 0x9b, 0x06, 0x6d,
		0x0f, 0xed, 0xf0, 0x37, 0x6f, 0x9a, 0xb4, 0x3d, 0x16, 0x4c, 0x13, 0x25, 0x03, 0x6d, 0x40, 0xa0,
		0x37, 0x2a, 0xfb, 0x09, 0x97, 0x37, 0x5b, 0x94, 0x0c, 0x8a, 0xea, 0x05, 0x4a, 0x06, 0x50, 0x79,
		0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x5f, 0x5b, 0x2a, 0x8f, 0x92, 0x41, 0x2d, 0x40, 0x0b, 0x4a, 0x06,
		0xc0, 0x05, 0xe0, 0x02, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x70, 0xe9, 0xef, 0x28, 0x19, 0xa0, 0x64,
		0xa0, 0x10, 0x5a, 0x50, 0x32, 0x98, 0x4d, 0x83, 0x16, 0x84, 0x76, 0x1c, 0x9e, 0x37, 0x4d, 0x94,
		0x0c, 0x30, 0x4d, 0x2b, 0x80, 0x44, 0x6f, 0x54, 0x3a, 0x0f, 0xcb, 0x9b, 0x2d, 0x4a, 0x06, 0x90,
		0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x97, 0xf4, 0x77, 0x94, 0x0c, 0xe0, 0xd3, 0x7a,
		0xa4, 0x85, 0x2d, 0x7d, 0xf0, 0x69, 0xa3, 0x7c, 0x1a, 0x25, 0x03, 0x18, 0x35, 0x8c, 0xba, 0x92,
		0x23, 0xa1, 0x64, 0x60, 0x4c, 0xc9, 0x40, 0xf2, 0x24, 0xf8, 0x5a, 0x65, 0x84, 0x0c, 0x4e, 0x47,
		0xab, 0x52, 0x17, 0x1d, 0x83, 0x67, 0x15, 0xf6, 0x68, 0x69, 0x4f, 0xae, 0x9c, 0x07, 0x7b, 0x22,
		0x2a, 0x15, 0xf6, 0x7d, 0xd6, 0xad, 0xb7, 0xba, 0xf3, 0x21, 0x37, 0xef, 0xec, 0xc8, 0x2b, 0xa5,
		0xbc, 0xb1, 0x0a, 0x5e, 0xe8, 0xd0, 0xf1, 0xcc, 0x3a, 0x9c, 0x1b, 0x27, 0x2b, 0xdf, 0x05, 0x1c,
		0x98, 0xbf, 0x77, 0xcb, 0x06, 0x06, 0xf1, 0x78, 0x35, 0x5c, 0xb9, 0x40, 0x51, 0x02, 0xbc, 0x67,
		0x4c, 0x47, 0x8e, 0xed, 0x56, 0xa4, 0xc7, 0x79, 0xe3, 0x46, 0xa2, 0x41, 0x23, 0xd7, 0x88, 0x91,
		0x6a, 0xb8, 0x88, 0x37, 0x56, 0xc4, 0x1b, 0x28, 0xa2, 0x8d, 0x92, 0x6a, 0xa5, 0x72, 0xd7, 0x22,
		0x38, 0xde, 0x1c, 0x4a, 0x75, 0x6e, 0xca, 0xb7, 0x4e, 0xe7, 0x49, 0x61, 0x63, 0x21, 0x65, 0x33,
		0xb1, 0xae, 0xb7, 0x64, 0x97, 0x5b, 0xbe, 0xab, 0x2d, 0xdd, 0xc5, 0x56, 0xeb, 0x5a, 0xab, 0x75,
		0xa9, 0x55, 0xba, 0xd2, 0xd5, 0xae, 0x6e, 0x48, 0x29, 0x91, 0x79, 0x9d, 0x69, 0x0c, 0x11, 0x56,
		0x9a, 0x14, 0x55, 0x4a, 0x55, 0x93, 0x9a, 0x5c, 0x47, 0x6a, 0xb2, 0xfa, 0x01, 0x5b, 0x3d, 0x70,
		0xab, 0x07, 0x70, 0xd5, 0x40, 0x2e, 0x13, 0xd0, 0x85, 0x02, 0xbb, 0x78, 0x80, 0x2f, 0x06, 0x44,
		0x6a, 0x92, 0xbd, 0xa9, 0x6b, 0xf5, 0x4f, 0x0e, 0xda, 0x49, 0xc2, 0x4c, 0xb2, 0x30, 0x93, 0x34,
		0x4c, 0x24, 0x0f, 0xd9, 0x24, 0x22, 0x9c, 0x4c, 0x8a, 0x15, 0x46, 0x6a, 0x12, 0xa9, 0x49, 0xc9,
		0x0f, 0xce, 0xbe, 0xd4, 0xd9, 0x34, 0xd8, 0x97, 0xaa, 0x1d, 0xfe, 0xe6, 0x4d, 0x93, 0x7d, 0xa9,
		0x0b, 0xa6, 0x89, 0xd4, 0xa4, 0x36, 0x20, 0xd0, 0x1b, 0x95, 0x03, 0x9f, 0xcb, 0x9b, 0x2d, 0x52,
		0x93, 0x45, 0xf5, 0x02, 0xa9, 0x49, 0xa8, 0x3c, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0xaf, 0x2d, 0x95,
		0x47, 0x6a, 0xb2, 0x16, 0xa0, 0x05, 0xa9, 0x49, 0xe0, 0x02, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x00,
		0x2e, 0xb8, 0xf4, 0x77, 0xa4, 0x26, 0x91, 0x9a, 0x54, 0x08, 0x2d, 0x48, 0x4d, 0xce, 0xa6, 0x41,
		0x0b, 0x42, 0x3b, 0x0e, 0xcf, 0x9b, 0x26, 0x52, 0x93, 0x98, 0xa6, 0x15, 0x40, 0xa2, 0x37, 0x2a,
		0x9d, 0x87, 0xe5, 0xcd, 0x16, 0xa9, 0x49, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4,
		0x4b, 0xfa, 0x3b, 0x52, 0x93, 0xf0, 0x69, 0x3d, 0xd2, 0xc2, 0x96, 0x3e, 0xf8, 0xb4, 0x51, 0x3e,
		0x8d, 0xd4, 0x24, 0x8c, 0x1a, 0x46, 0x5d, 0xc9, 0x91, 0x90, 0x9a, 0xd4, 0x92, 0xc8, 0x9a, 0x48,
		0x15, 0xcd, 0x0b, 0x4d, 0x8a, 0x1e, 0x04, 0x5f, 0x33, 0x28, 0xa2, 0xf5, 0x31, 0x5e, 0xd4, 0x99,
		0x9c, 0x14, 0x19, 0xea, 0x22, 0x34, 0x29, 0x22, 0x45, 0x18, 0xe4, 0xa1, 0xbc, 0x8c, 0x81, 0xa4,
		0x4c, 0xaa, 0x9a, 0x8a, 0xc1, 0x06, 0x2a, 0x06, 0xf5, 0xa9, 0x68, 0xa1, 0x62, 0x80, 0x8a, 0x41,
		0x69, 0x2b, 0x89, 0x8a, 0x01, 0x2a, 0x06, 0xf5, 0x4b, 0x0a, 0xfa, 0xc9, 0x41, 0x3b, 0x49, 0x98,
		0x49, 0x16, 0x66, 0x92, 0x86, 0x89, 0xe4, 0xa1, 0x53, 0x72, 0x40, 0xc5, 0x40, 0x3c, 0xba, 0xa3,
		0x62, 0x20, 0xf8, 0xc1, 0x69, 0x79, 0xcc, 0xa6, 0x41, 0xcb, 0x43, 0x3b, 0xfc, 0xcd, 0x9b, 0x26,
		0x2d, 0x8f, 0x05, 0xd3, 0x44, 0xc5, 0x40, 0x1b, 0x10, 0xe8, 0x8d, 0xca, 0x5e, 0xc2, 0xe5, 0xcd,
		0x16, 0x15, 0x83, 0xa2, 0x7a, 0x81, 0x8a, 0x01, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0xd7,
		0x96, 0xca, 0xa3, 0x62, 0x50, 0x0b, 0xd0, 0x82, 0x8a, 0x01, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x00,
		0x2e, 0x00, 0x17, 0x5c, 0xfa, 0x3b, 0x2a, 0x06, 0xa8, 0x18, 0x28, 0x84, 0x16, 0x54, 0x0c, 0x66,
		0xd3, 0xa0, 0x05, 0xa1, 0x1d, 0x87, 0xe7, 0x4d, 0x13, 0x15, 0x03, 0x4c, 0xd3, 0x0a, 0x20, 0xd1,
		0x1b, 0x95, 0xce, 0xc3, 0xf2, 0x66, 0x8b, 0x8a, 0x01, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4,
		0x43, 0xea, 0x25, 0xfd, 0x1d, 0x15, 0x03, 0xf8, 0xb4, 0x1e, 0x69, 0x61, 0x4b, 0x1f, 0x7c, 0xda,
		0x28, 0x9f, 0x46, 0xc5, 0x00, 0x46, 0x0d, 0xa3, 0xae, 0xe4, 0x48, 0xa8, 0x18, 0x98, 0x52, 0x31,
		0x90, 0x3c, 0x07, 0xbe, 0x56, 0x11, 0x11, 0x83, 0xd3, 0xd1, 0x9a, 0xd4, 0x45, 0xc3, 0xe0, 0x59,
		0x85, 0xbd, 0x59, 0xda, 0x8b, 0x2b, 0xe6, 0xbd, 0x9e, 0x88, 0x3e, 0x85, 0x75, 0x7f, 0x75, 0xeb,
		0xa9, 0xee, 0xfc, 0xc7, 0xcd, 0x3b, 0x3b, 0xf2, 0x48, 0x29, 0x4f, 0xb4, 0xef, 0x81, 0x0e, 0x9d,
		0xce, 0xa8, 0xb3, 0xb9, 0x71, 0xb0, 0xf2, 0xcd, 0xdf, 0x81, 0xe9, 0x7b, 0xc5, 0xf3, 0xdf, 0xf6,
		0xaf, 0x06, 0xbd, 0x7c, 0xbc, 0x1e, 0xae, 0x1c, 0xa0, 0x28, 0xfc, 0xdd, 0x3b, 0xaa, 0x23, 0xc7,
		0x76, 0x2b, 0xce, 0xe3, 0xbc, 0x61, 0x23, 0xd1, 0x98, 0x91, 0x6b, 0xc0, 0x48, 0x35, 0x5a, 0xc4,
		0x1b, 0x2a, 0xe2, 0x8d, 0x13, 0xd1, 0x06, 0x49, 0xb5, 0x52, 0xb9, 0x6b, 0xf1, 0x1b, 0x6f, 0x0e,
		0xa3, 0x3a, 0x37, 0xe5, 0x5b, 0xa7, 0xf2, 0xa4, 0x90, 0xb1, 0x90, 0xa2, 0x99, 0x58, 0xb7, 0x5b,
		0xb2, 0xbb, 0x2d, 0xdf, 0xcd, 0x96, 0xee, 0x5e, 0xab, 0x75, 0xab, 0xd5, 0xba, 0xd3, 0x2a, 0xdd,
		0xe8, 0x6a, 0x57, 0x36, 0xa4, 0x14, 0xc8, 0xbc, 0xce, 0x34, 0x86, 0x08, 0x2b, 0x4c, 0x8a, 0xea,
		0xa3, 0xaa, 0x49, 0x4c, 0xae, 0x23, 0x31, 0x59, 0xfd, 0x80, 0xad, 0x1e, 0xb8, 0xd5, 0x03, 0xb8,
		0x6a, 0x20, 0x97, 0x09, 0xe8, 0x42, 0x81, 0x5d, 0x3c, 0xc0, 0x17, 0x03, 0x22, 0x31, 0xc9, 0x9e,
		0xd4, 0xb5, 0xfa, 0x27, 0x07, 0xed, 0x24, 0x61, 0x26, 0x59, 0x98, 0x49, 0x1a, 0x26, 0x92, 0x87,
		0x6c, 0x12, 0x11, 0x4e, 0x26, 0xc5, 0x0a, 0x23, 0x31, 0x89, 0xc4, 0xa4, 0xe4, 0x07, 0x67, 0x3f,
		0xea, 0x6c, 0x1a, 0xec, 0x47, 0xd5, 0x0e, 0x7f, 0xf3, 0xa6, 0xc9, 0x7e, 0xd4, 0x05, 0xd3, 0x44,
		0x62, 0x52, 0x1b, 0x10, 0xe8, 0x8d, 0xca, 0x41, 0xcf, 0xe5, 0xcd, 0x16, 0x89, 0xc9, 0xa2, 0x7a,
		0x81, 0xc4, 0x24, 0x54, 0x1e, 0x2a, 0x0f, 0x95, 0x87, 0xca, 0xd7, 0x96, 0xca, 0x23, 0x31, 0x59,
		0x0b, 0xd0, 0x82, 0xc4, 0x24, 0x70, 0x01, 0xb8, 0x00, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x5c, 0xfa,
		0x3b, 0x12, 0x93, 0x48, 0x4c, 0x2a, 0x84, 0x16, 0x24, 0x26, 0x67, 0xd3, 0xa0, 0x05, 0xa1, 0x1d,
		0x87, 0xe7, 0x4d, 0x13, 0x89, 0x49, 0x4c, 0xd3, 0x0a, 0x20, 0xd1, 0x1b, 0x95, 0xce, 0xc3, 0xf2,
		0x66, 0x8b, 0xc4, 0x24, 0xa4, 0x1e, 0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x25, 0xfd, 0x1d,
		0x89, 0x49, 0xf8, 0xb4, 0x1e, 0x69, 0x61, 0x4b, 0x1f, 0x7c, 0xda, 0x28, 0x9f, 0x46, 0x62, 0x12,
		0x46, 0x0d, 0xa3, 0xae, 0xe4, 0x48, 0x48, 0x4c, 0xea, 0x48, 0x64, 0xdd, 0x12, 0x2b, 0x9a, 0x17,
		0x99, 0x14, 0x3d, 0x0a, 0xbe, 0x66, 0x4f, 0x48, 0x6b, 0xfb, 0xdd, 0x74, 0x5d, 0xe6, 0x74, 0x26,
		0x27, 0x85, 0x86, 0xba, 0x08, 0x4d, 0x8a, 0x88, 0x11, 0x06, 0x79, 0x28, 0x2f, 0x65, 0x20, 0x29,
		0x92, 0xaa, 0xa6, 0x64, 0xb0, 0x81, 0x92, 0x41, 0x7d, 0xaa, 0x5a, 0x28, 0x19, 0xa0, 0x64, 0x50,
		0xda, 0x4a, 0xa2, 0x64, 0x80, 0x92, 0x41, 0xfd, 0x92, 0x82, 0x7e, 0x72, 0xd0, 0x4e, 0x12, 0x66,
		0x92, 0x85, 0x99, 0xa4, 0x61, 0x22, 0x79, 0xe8, 0x94, 0x1d, 0x50, 0x32, 0x10, 0x8f, 0xee, 0x28,
		0x19, 0x08, 0x7e, 0x70, 0xda, 0x1e, 0xb3, 0x69, 0xd0, 0xf6, 0xd0, 0x0e, 0x7f, 0xf3, 0xa6, 0x49,
		0xdb, 0x63, 0xc1, 0x34, 0x51, 0x32, 0xd0, 0x06, 0x04, 0x7a, 0xa3, 0xb2, 0x9f, 0x70, 0x79, 0xb3,
		0x45, 0xc9, 0xa0, 0xa8, 0x5e, 0xa0, 0x64, 0x00, 0x95, 0x87, 0xca, 0x43, 0xe5, 0xa1, 0xf2, 0xb5,
		0xa5, 0xf2, 0x28, 0x19, 0xd4, 0x02, 0xb4, 0xa0, 0x64, 0x00, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x80,
		0x0b, 0xc0, 0x05, 0x97, 0xfe, 0x8e, 0x92, 0x01, 0x4a, 0x06, 0x0a, 0xa1, 0x05, 0x25, 0x83, 0xd9,
		0x34, 0x68, 0x41, 0x68, 0xc7, 0xe1, 0x79, 0xd3, 0x44, 0xc9, 0x00, 0xd3, 0xb4, 0x02, 0x48, 0xf4,
		0x46, 0xa5, 0xf3, 0xb0, 0xbc, 0xd9, 0xa2, 0x64, 0x00, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5,
		0x90, 0x7a, 0x49, 0x7f, 0x47, 0xc9, 0x00, 0x3e, 0xad, 0x47, 0x5a, 0xd8, 0xd2, 0x07, 0x9f, 0x36,
		0xca, 0xa7, 0x51, 0x32, 0x80, 0x51, 0xc3, 0xa8, 0x2b, 0x39, 0x12, 0x4a, 0x06, 0xc6, 0x94, 0x0c,
		0x24, 0x4f, 0x82, 0xaf, 0x55, 0x46, 0xc8, 0xe0, 0x74, 0xb4, 0x2a, 0x75, 0xd1, 0x31, 0x78, 0x56,
		0x61, 0x8f, 0x96, 0xf6, 0xe4, 0xca, 0x79, 0xb0, 0x27, 0xa2, 0x52, 0x61, 0xdf, 0x67, 0xdd, 0x7a,
		0xab, 0x3b, 0x1f, 0x72, 0xf3, 0xce, 0x8e, 0xbc, 0x52, 0xca, 0x1b, 0xab, 0xe0, 0x85, 0x0e, 0x1d,
		0xcf, 0xac, 0xc3, 0xb9, 0x71, 0xb2, 0xf2, 0x5d, 0xc0, 0x81, 0xf9, 0x7b, 0xb7, 0x6c, 0x60, 0x10,
		0x8f, 0x57, 0xc3, 0x95, 0x0b, 0x14, 0x25, 0xc0, 0x7b, 0xc6, 0x74, 0xe4, 0xd8, 0x6e, 0x45, 0x7a,
		0x9c, 0x37, 0x6e, 0x24, 0x1a, 0x34, 0x72, 0x8d, 0x18, 0xa9, 0x86, 0x8b, 0x78, 0x63, 0x45, 0xbc,
		0x81, 0x22, 0xda, 0x28, 0xa9, 0x56, 0x2a, 0x77, 0x2d, 0x82, 0xe3, 0xcd, 0xa1, 0x54, 0xe7, 0xa6,
		0x7c, 0xeb, 0x74, 0x9e, 0x14, 0x36, 0x16, 0x52, 0x36, 0x13, 0xeb, 0x7a, 0x4b, 0x76, 0xb9, 0xe5,
		0xbb, 0xda, 0xd2, 0x5d, 0x6c, 0xb5, 0xae, 0xb5, 0x5a, 0x97, 0x5a, 0xa5, 0x2b, 0x5d, 0xed, 0xea,
		0x86, 0x94, 0x12, 0x99, 0xd7, 0x99, 0xc6, 0x10, 0x61, 0xa5, 0x49, 0x51, 0xa5, 0x54, 0x35, 0xa9,
		0xc9, 0x75, 0xa4, 0x26, 0xab, 0x1f, 0xb0, 0xd5, 0x03, 0xb7, 0x7a, 0x00, 0x57, 0x0d, 0xe4, 0x32,
		0x01, 0x5d, 0x28, 0xb0, 0x8b, 0x07, 0xf8, 0x62, 0x40, 0xa4, 0x26, 0xd9, 0x9b, 0xba, 0x56, 0xff,
		0xe4, 0xa0, 0x9d, 0x24, 0xcc, 0x24, 0x0b, 0x33, 0x49, 0xc3, 0x44, 0xf2, 0x90, 0x4d, 0x22, 0xc2,
		0xc9, 0xa4, 0x58, 0x61, 0xa4, 0x26, 0x91, 0x9a, 0x94, 0xfc, 0xe0, 0xec, 0x4b, 0x9d, 0x4d, 0x83,
		0x7d, 0xa9, 0xda, 0xe1, 0x6f, 0xde, 0x34, 0xd9, 0x97, 0xba, 0x60, 0x9a, 0x48, 0x4d, 0x6a, 0x03,
		0x02, 0xbd, 0x51, 0x39, 0xf0, 0xb9, 0xbc, 0xd9, 0x22, 0x35, 0x59, 0x54, 0x2f, 0x90, 0x9a, 0x84,
		0xca, 0x43, 0xe5, 0xa1, 0xf2, 0x50, 0xf9, 0xda, 0x52, 0x79, 0xa4, 0x26, 0x6b, 0x01, 0x5a, 0x90,
		0x9a, 0x04, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x82, 0x4b, 0x7f, 0x47, 0x6a, 0x12,
		0xa9, 0x49, 0x85, 0xd0, 0x82, 0xd4, 0xe4, 0x6c, 0x1a, 0xb4, 0x20, 0xb4, 0xe3, 0xf0, 0xbc, 0x69,
		0x22, 0x35, 0x89, 0x69, 0x5a, 0x01, 0x24, 0x7a, 0xa3, 0xd2, 0x79, 0x58, 0xde, 0x6c, 0x91, 0x9a,
		0x84, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0xbd, 0xa4, 0xbf, 0x23, 0x35, 0x09, 0x9f,
		0xd6, 0x23, 0x2d, 0x6c, 0xe9, 0x83, 0x4f, 0x1b, 0xe5, 0xd3, 0x48, 0x4d, 0xc2, 0xa8, 0x61, 0xd4,
		0x95, 0x1c, 0x09, 0xa9, 0x49, 0x2d, 0x89, 0xac, 0x89, 0x54, 0xd1, 0xbc, 0xd0, 0xa4, 0xe8, 0x41,
		0xf0, 0x35, 0x83, 0x22, 0x5a, 0x1f, 0xe3, 0x45, 0x9d, 0xc9, 0x49, 0x91, 0xa1, 0x2e, 0x42, 0x93,
		0x22, 0x52, 0x84, 0x41, 0x1e, 0xca, 0xcb, 0x18, 0x48, 0xca, 0xa4, 0xaa, 0xa9, 0x18, 0x6c, 0xa0,
		0x62, 0x50, 0x9f, 0x8a, 0x16, 0x2a, 0x06, 0xa8, 0x18, 0x94, 0xb6, 0x92, 0xa8, 0x18, 0xa0, 0x62,
		0x50, 0xbf, 0xa4, 0xa0, 0x9f, 0x1c, 0xb4, 0x93, 0x84, 0x99, 0x64, 0x61, 0x26, 0x69, 0x98, 0x48,
		0x1e, 0x3a, 0x25, 0x07, 0x54, 0x0c, 0xc4, 0xa3, 0x3b, 0x2a, 0x06, 0x82, 0x1f, 0x9c, 0x96, 0xc7,
		0x6c, 0x1a, 0xb4, 0x3c, 0xb4, 0xc3, 0xdf, 0xbc, 0x69, 0xd2, 0xf2, 0x58, 0x30, 0x4d, 0x54, 0x0c,
		0xb4, 0x01, 0x81, 0xde, 0xa8, 0xec, 0x25, 0x5c, 0xde, 0x6c, 0x51, 0x31, 0x28, 0xaa, 0x17, 0xa8,
		0x18, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x6d, 0xa9, 0x3c, 0x2a, 0x06, 0xb5, 0x00,
		0x2d, 0xa8, 0x18, 0x00, 0x17, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x02, 0x70, 0xc1, 0xa5, 0xbf, 0xa3,
		0x62, 0x80, 0x8a, 0x81, 0x42, 0x68, 0x41, 0xc5, 0x60, 0x36, 0x0d, 0x5a, 0x10, 0xda, 0x71, 0x78,
		0xde, 0x34, 0x51, 0x31, 0xc0, 0x34, 0xad, 0x00, 0x12, 0xbd, 0x51, 0xe9, 0x3c, 0x2c, 0x6f, 0xb6,
		0xa8, 0x18, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xd2, 0xdf, 0x51, 0x31,
		0x80, 0x4f, 0xeb, 0x91, 0x16, 0xb6, 0xf4, 0xc1, 0xa7, 0x8d, 0xf2, 0x69, 0x54, 0x0c, 0x60, 0xd4,
		0x30, 0xea, 0x4a, 0x8e, 0x84, 0x8a, 0x81, 0x29, 0x15, 0x03, 0xc9, 0x73, 0xe0, 0x6b, 0x15, 0x11,
		0x31, 0x38, 0x1d, 0xad, 0x49, 0x5d, 0x34, 0x0c, 0x9e, 0x55, 0xd8, 0x9b, 0xa5, 0xbd, 0xb8, 0x62,
		0xde, 0xeb, 0x89, 0xe8, 0x53, 0x58, 0xf7, 0x57, 0xb7, 0x9e, 0xea, 0xce, 0x7f, 0xdc, 0xbc, 0xb3,
		0x23, 0x8f, 0x94, 0xf2, 0x44, 0xfb, 0x1e, 0xe8, 0xd0, 0xe9, 0x8c, 0x3a, 0x9b, 0x1b, 0x07, 0x2b,
		0xdf, 0xfc, 0x1d, 0x98, 0xbe, 0x97, 0xa5, 0x79, 0xe8, 0xf7, 0x93, 0x5e, 0xd4, 0xf9, 0x36, 0xb4,
		0x82, 0x96, 0x33, 0xe3, 0x9f, 0x29, 0xf3, 0xdc, 0x1d, 0xd1, 0x91, 0x43, 0xbb, 0x15, 0xe5, 0x71,
		0xde, 0xa8, 0x91, 0x68, 0xc8, 0xc8, 0x35, 0x5e, 0xa4, 0x1a, 0x2c, 0xe2, 0x8d, 0x14, 0xf1, 0x86,
		0x89, 0x68, 0x63, 0xa4, 0x5a, 0x29, 0xdc, 0xb5, 0xe8, 0x8d, 0x37, 0x87, 0x4d, 0x9d, 0x9b, 0xf2,
		0xad, 0xd3, 0x78, 0x52, 0x88, 0x58, 0x48, 0xc9, 0x4c, 0xac, 0xcb, 0x2d, 0xd9, 0xd5, 0x96, 0xef,
		0x62, 0x4b, 0x77, 0xad, 0xd5, 0xba, 0xd4, 0x6a, 0x5d, 0x69, 0x95, 0x2e, 0x74, 0xb5, 0x2b, 0x1a,
		0x52, 0xca, 0x63, 0x5e, 0x67, 0x1a, 0x43, 0x84, 0x95, 0x25, 0x45, 0x75, 0x51, 0xd5, 0xa4, 0x25,
		0xd7, 0x91, 0x96, 0xac, 0x7e, 0xc0, 0x56, 0x0f, 0xdc, 0xea, 0x01, 0x5c, 0x35, 0x90, 0xcb, 0x04,
		0x74, 0xa1, 0xc0, 0x2e, 0x1e, 0xe0, 0x8b, 0x01, 0x91, 0x96, 0x64, 0x2f, 0xea, 0x5a, 0xfd, 0x93,
		0x83, 0x76, 0x92, 0x30, 0x93, 0x2c, 0xcc, 0x24, 0x0d, 0x13, 0xc9, 0x43, 0x36, 0x89, 0x08, 0x27,
		0x93, 0x62, 0x85, 0x91, 0x96, 0x44, 0x5a, 0x52, 0xf2, 0x83, 0xb3, 0x0f, 0x75, 0x36, 0x0d, 0xf6,
		0xa1, 0x6a, 0x87, 0xbf, 0x79, 0xd3, 0x64, 0x1f, 0xea, 0x82, 0x69, 0x22, 0x2d, 0xa9, 0x0d, 0x08,
		0xf4, 0x46, 0xe5, 0x80, 0xe7, 0xf2, 0x66, 0x8b, 0xb4, 0x64, 0x51, 0xbd, 0x40, 0x5a, 0x12, 0x2a,
		0x0f, 0x95, 0x87, 0xca, 0x43, 0xe5, 0x6b, 0x4b, 0xe5, 0x91, 0x96, 0xac, 0x05, 0x68, 0x41, 0x5a,
		0x12, 0xb8, 0x00, 0x5c, 0x00, 0x2e, 0x00, 0x17, 0x80, 0x0b, 0x2e, 0xfd, 0x1d, 0x69, 0x49, 0xa4,
		0x25, 0x15, 0x42, 0x0b, 0xd2, 0x92, 0xb3, 0x69, 0xd0, 0x82, 0xd0, 0x8e, 0xc3, 0xf3, 0xa6, 0x89,
		0xb4, 0x24, 0xa6, 0x69, 0x05, 0x90, 0xe8, 0x8d, 0x4a, 0xe7, 0x61, 0x79, 0xb3, 0x45, 0x5a, 0x12,
		0x52, 0x0f, 0xa9, 0x87, 0xd4, 0x43, 0xea, 0x21, 0xf5, 0x92, 0xfe, 0x8e, 0xb4, 0x24, 0x7c, 0x5a,
		0x8f, 0xb4, 0xb0, 0xa5, 0x0f, 0x3e, 0x6d, 0x94, 0x4f, 0x23, 0x2d, 0x09, 0xa3, 0x86, 0x51, 0x57,
		0x72, 0x24, 0xa4, 0x25, 0x45, 0xa5, 0xb1, 0xee, 0x0a, 0x15, 0xcd, 0x0b, 0x4b, 0x8a, 0x1e, 0x03,
		0x5f, 0xb3, 0x23, 0x9e, 0x75, 0x9a, 0xe6, 0xe1, 0xf1, 0x68, 0x51, 0x0e, 0xfa, 0xd7, 0xad, 0x39,
		0x5d, 0xc9, 0x49, 0x81, 0xa1, 0x2e, 0xc2, 0x92, 0x22, 0xe2, 0x83, 0x41, 0x1e, 0xca, 0x4b, 0x18,
		0x48, 0x8a, 0xa2, 0xaa, 0x29, 0x18, 0x6c, 0xa0, 0x60, 0x50, 0x9f, 0x6a, 0x16, 0x0a, 0x06, 0x28,
		0x18, 0x94, 0xb6, 0x92, 0x28, 0x18, 0xa0, 0x60, 0x50, 0xbf, 0xa4, 0xa0, 0x9f, 0x1c, 0xb4, 0x93,
		0x84, 0x99, 0x64, 0x61, 0x26, 0x69, 0x98, 0x48, 0x1e, 0x3a, 0xe5, 0x06, 0x14, 0x0c, 0xc4, 0xa3,
		0x3b, 0x0a, 0x06, 0x82, 0x1f, 0x9c, 0x76, 0xc7, 0x6c, 0x1a, 0xb4, 0x3b, 0xb4, 0xc3, 0xdf, 0xbc,
		0x69, 0xd2, 0xee, 0x58, 0x30, 0x4d, 0x14, 0x0c, 0xb4, 0x01, 0x81, 0xde, 0xa8, 0xec, 0x23, 0x5c,
		0xde, 0x6c, 0x51, 0x30, 0x28, 0xaa, 0x17, 0x28, 0x18, 0x40, 0xe5, 0xa1, 0xf2, 0x50, 0x79, 0xa8,
		0x7c, 0x6d, 0xa9, 0x3c, 0x0a, 0x06, 0xb5, 0x00, 0x2d, 0x28, 0x18, 0x00, 0x17, 0x80, 0x0b, 0xc0,
		0x05, 0xe0, 0x02, 0x70, 0xc1, 0xa5, 0xbf, 0xa3, 0x60, 0x80, 0x82, 0x81, 0x42, 0x68, 0x41, 0xc1,
		0x60, 0x36, 0x0d, 0x5a, 0x10, 0xda, 0x71, 0x78, 0xde, 0x34, 0x51, 0x30, 0xc0, 0x34, 0xad, 0x00,
		0x12, 0xbd, 0x51, 0xe9, 0x3c, 0x2c, 0x6f, 0xb6, 0x28, 0x18, 0x40, 0xea, 0x21, 0xf5, 0x90, 0x7a,
		0x48, 0x3d, 0xa4, 0x5e, 0xd2, 0xdf, 0x51, 0x30, 0x80, 0x4f, 0xeb, 0x91, 0x16, 0xb6, 0xf4, 0xc1,
		0xa7, 0x8d, 0xf2, 0x69, 0x14, 0x0c, 0x60, 0xd4, 0x30, 0xea, 0x4a, 0x8e, 0x84, 0x82, 0x81, 0x21,
		0x05, 0x03, 0xc9, 0x53, 0xe0, 0x6b, 0x95, 0x10, 0x30, 0x38, 0x1d, 0xad, 0x48, 0x5d, 0xf4, 0x0b,
		0x9e, 0x55, 0xd8, 0x93, 0xa5, 0x3d, 0xb8, 0x52, 0x9e, 0xeb, 0x89, 0x28, 0x53, 0xd8, 0xf6, 0x55,
		0xb7, 0x5e, 0xea, 0xce, 0x77, 0xdc, 0xbc, 0xb3, 0x23, 0x6f, 0x94, 0xf2, 0x42, 0xeb, 0xde, 0xe7,
		0xd0, 0xe1, 0x4c, 0x3a, 0x9a, 0x1b, 0xe7, 0x2a, 0xdf, 0xf4, 0x1d, 0x98, 0xbd, 0x77, 0xe7, 0xd9,
		0x6f, 0x3b, 0x33, 0xfc, 0x99, 0x1a, 0xcf, 0xdd, 0x11, 0x1d, 0x39, 0xb3, 0x5b, 0x21, 0x1e, 0xe7,
		0xcd, 0x19, 0x89, 0x26, 0x8c, 0x5c, 0xb3, 0x45, 0xaa, 0xa9, 0x22, 0xde, 0x3c, 0x11, 0x6f, 0x92,
		0x88, 0x36, 0x43, 0xaa, 0x95, 0xbe, 0x5d, 0x0b, 0xdd, 0x78, 0x73, 0xa8, 0xd4, 0xb9, 0x29, 0xdf,
		0x3a, 0x81, 0x27, 0x85, 0x85, 0x85, 0xd4, 0xcb, 0xc4, 0x3a, 0xdb, 0x92, 0x9d, 0x6c, 0xf9, 0xce,
		0xb5, 0x74, 0xa7, 0x5a, 0xad, 0x33, 0xad, 0xd6, 0x89, 0x56, 0xe9, 0x3c, 0x57, 0xbb, 0x92, 0x21,
		0xa5, 0x36, 0xe6, 0x75, 0xa6, 0x31, 0x44, 0x58, 0x4d, 0x52, 0x54, 0x09, 0x55, 0x4d, 0x4e, 0x72,
		0x1d, 0x39, 0xc9, 0xea, 0x07, 0x6c, 0xf5, 0xc0, 0xad, 0x1e, 0xc0, 0x55, 0x03, 0xb9, 0x4c, 0x40,
		0x17, 0x0a, 0xec, 0xe2, 0x01, 0xbe, 0x18, 0x10, 0x39, 0x49, 0xf6, 0x9f, 0xae, 0xd5, 0x3f, 0x39,
		0x68, 0x27, 0x09, 0x33, 0xc9, 0xc2, 0x4c, 0xd2, 0x30, 0x91, 0x3c, 0x64, 0x93, 0x88, 0x70, 0x32,
		0x29, 0x56, 0x18, 0x39, 0x49, 0xe4, 0x24, 0x25, 0x3f, 0x38, 0x7b, 0x4f, 0x67, 0xd3, 0x60, 0xef,
		0xa9, 0x76, 0xf8, 0x9b, 0x37, 0x4d, 0xf6, 0x9e, 0x2e, 0x98, 0x26, 0x72, 0x92, 0xda, 0x80, 0x40,
		0x6f, 0x54, 0x0e, 0x75, 0x2e, 0x6f, 0xb6, 0xc8, 0x49, 0x16, 0xd5, 0x0b, 0xe4, 0x24, 0xa1, 0xf2,
		0x50, 0x79, 0xa8, 0x3c, 0x54, 0xbe, 0xb6, 0x54, 0x1e, 0x39, 0xc9, 0x5a, 0x80, 0x16, 0xe4, 0x24,
		0x81, 0x0b, 0xc0, 0x05, 0xe0, 0x02, 0x70, 0x01, 0xb8, 0xe0, 0xd2, 0xdf, 0x91, 0x93, 0x44, 0x4e,
		0x52, 0x21, 0xb4, 0x20, 0x27, 0x39, 0x9b, 0x06, 0x2d, 0x08, 0xed, 0x38, 0x3c, 0x6f, 0x9a, 0xc8,
		0x49, 0x62, 0x9a, 0x56, 0x00, 0x89, 0xde, 0xa8, 0x74, 0x1e, 0x96, 0x37, 0x5b, 0xe4, 0x24, 0x21,
		0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x1e, 0x52, 0x2f, 0xe9, 0xef, 0xc8, 0x49, 0xc2, 0xa7, 0xf5,
		0x48, 0x0b, 0x5b, 0xfa, 0xe0, 0xd3, 0x46, 0xf9, 0x34, 0x72, 0x92, 0x30, 0x6a, 0x18, 0x75, 0x25,
		0x47, 0x42, 0x4e, 0x52, 0x53, 0x16, 0x6b, 0x7b, 0x5e, 0x4e, 0x52, 0xf4, 0x18, 0xf8, 0x9a, 0x51,
		0xe9, 0xac, 0xed, 0x39, 0x3d, 0xc9, 0x49, 0x81, 0xa1, 0x2e, 0x82, 0x92, 0x22, 0xb2, 0x83, 0x41,
		0x1e, 0xca, 0x4b, 0x18, 0x48, 0x4a, 0xa1, 0xaa, 0x29, 0x18, 0x6c, 0xa0, 0x60, 0x50, 0x9f, 0x6a,
		0x16, 0x0a, 0x06, 0x28, 0x18, 0x94, 0xb6, 0x92, 0x28, 0x18, 0xa0, 0x60, 0x50, 0xbf, 0xa4, 0xa0,
		0x9f, 0x1c, 0xb4, 0x93, 0x84, 0x99, 0x64, 0x61, 0x26, 0x69, 0x98, 0x48, 0x1e, 0x3a, 0xe5, 0x06,
		0x14, 0x0c, 0xc4, 0xa3, 0x3b, 0x0a, 0x06, 0x82, 0x1f, 0x9c, 0x76, 0xc7, 0x6c, 0x1a, 0xb4, 0x3b,
		0xb4, 0xc3, 0xdf, 0xbc, 0x69, 0xd2, 0xee, 0x58, 0x30, 0x4d, 0x14, 0x0c, 0xb4, 0x01, 0x81, 0xde,
		0xa8, 0xec, 0x23, 0x5c, 0xde, 0x6c, 0x51, 0x30, 0x28, 0xaa, 0x17, 0x28, 0x18, 0x40, 0xe5, 0xa1,
		0xf2, 0x50, 0x79, 0xa8, 0x7c, 0x6d, 0xa9, 0x3c, 0x0a, 0x06, 0xb5, 0x00, 0x2d, 0x28, 0x18, 0x00,
		0x17, 0x80, 0x0b, 0xc0, 0x05, 0xe0, 0x02, 0x70, 0xc1, 0xa5, 0xbf, 0xa3, 0x60, 0x80, 0x82, 0x81,
		0x42, 0x68, 0x41, 0xc1, 0x60, 0x36, 0x0d, 0x5a, 0x10, 0xda, 0x71, 0x78, 0xde, 0x34, 0x51, 0x30,
		0xc0, 0x34, 0xad, 0x00, 0x12, 0xbd, 0x51, 0xe9, 0x3c, 0x2c, 0x6f, 0xb6, 0x28, 0x18, 0x40, 0xea,
		0x21, 0xf5, 0x90, 0x7a, 0x48, 0x3d, 0xa4, 0x5e, 0xd2, 0xdf, 0x51, 0x30, 0x80, 0x4f, 0xeb, 0x91,
		0x16, 0xb6, 0xf4, 0xc1, 0xa7, 0x8d, 0xf2, 0x69, 0x14, 0x0c, 0x60, 0xd4, 0x30, 0xea, 0x4a, 0x8e,
		0x84, 0x82, 0x81, 0x21, 0x05, 0x03, 0xc9, 0x53, 0xe0, 0x6b, 0x95, 0x10, 0x30, 0x38, 0x1d, 0xad,
		0x48, 0x5d, 0xf4, 0x0b, 0x9e, 0x55, 0xd8, 0x93, 0xa5, 0x3d, 0xb8, 0x52, 0x9e, 0xeb, 0x89, 0x28,
		0x53, 0xd8, 0xf6, 0x55, 0xb7, 0x5e, 0xea, 0xce, 0x77, 0xdc, 0xbc, 0xb3, 0x23, 0x6f, 0x94, 0xf2,
		0x42, 0xeb, 0xde, 0xe7, 0xd0, 0xe1, 0x4c, 0x3a, 0x9a, 0x1b, 0xe7, 0x2a, 0xdf, 0xf4, 0x1d, 0x98,
		0xbd, 0x63, 0x49, 0x1e, 0x11, 0x09, 0x1e, 0xc7, 0x92, 0x3b, 0xce, 0x25, 0x76, 0x24, 0xda, 0x2d,
		0x72, 0x6d, 0x15, 0xa9, 0xf6, 0x89, 0x78, 0x9b, 0x44, 0xbc, 0x1d, 0x22, 0xda, 0xf6, 0xa8, 0x56,
		0xa2, 0x76, 0x2d, 0x69, 0xe3, 0x4d, 0x73, 0xa3, 0x3f, 0xc9, 0x54, 0x8e, 0x6d, 0x79, 0xea, 0x9d,
		0xf3, 0xc3, 0x3a, 0x36, 0x2f, 0x99, 0xfa, 0xa2, 0x58, 0x17, 0x5b, 0xb2, 0x6b, 0x2d, 0xdf, 0xa5,
		0x96, 0xee, 0x4a, 0xab, 0x75, 0xa1, 0xd5, 0xba, 0xce, 0x2a, 0x5d, 0xe6, 0x6a, 0x57, 0x2d, 0xc4,
		0xba, 0xc6, 0x85, 0xbf, 0x45, 0xdd, 0x30, 0xce, 0xa3, 0xfc, 0x5b, 0x1a, 0x5e, 0x48, 0x38, 0xdd,
		0x14, 0x59, 0x0a, 0xf4, 0x85, 0xbd, 0x83, 0xc9, 0x47, 0x7b, 0x13, 0x64, 0x0a, 0x1a, 0x99, 0x7b,
		0xbf, 0x1d, 0xb4, 0x4f, 0x87, 0xff, 0xf7, 0xe1, 0xff, 0x8e, 0xf7, 0xa5, 0x5c, 0x7d, 0xd4, 0x5a,
		0xca, 0x44, 0x7b, 0xdf, 0x4a, 0xdb, 0xd8, 0x4e, 0x4f, 0x3e, 0xec, 0xb7, 0x8f, 0x8f, 0x0e, 0x0f,
		0x7e, 0xfd, 0xbf, 0xf6, 0xc1, 0xf1, 0xa7, 0x6d, 0xaf, 0x8e, 0x7b, 0x07, 0x95, 0xd6, 0xf6, 0x70,
		0xf3, 0xd3, 0xf1, 0xfb, 0xe1, 0xaa, 0xb6, 0xda, 0x1f, 0xdf, 0x1f, 0xfc, 0xba, 0x77, 0xfa, 0x81,
		0xd5, 0x2d, 0x71, 0x75, 0x0f, 0xde, 0xff, 0xcf, 0xe9, 0x87, 0xbd, 0x0f, 0xfb, 0xed, 0xd3, 0xe3,
		0xdf, 0x58, 0x58, 0x27, 0x66, 0xfb, 0xee, 0xe3, 0xe1, 0x07, 0x0c, 0xb7, 0xe4, 0xf5, 0xfd, 0x74,
		0xfc, 0xfe, 0x53, 0xab, 0xfd, 0xdb, 0xe1, 0xd1, 0xff, 0x9e, 0x1e, 0xef, 0xff, 0xca, 0xca, 0x3a,
		0x4b, 0x66, 0x2d, 0xd6, 0xb6, 0xc4, 0xa8, 0xb0, 0x31, 0x8c, 0x0a, 0x9f, 0x8e, 0x0f, 0x4f, 0x59,
		0xd5, 0xb2, 0x57, 0x75, 0xff, 0xd3, 0xf1, 0x7b, 0x56, 0xd5, 0x01, 0x34, 0x60, 0x51, 0xcb, 0x5b,
		0xd4, 0x11, 0x20, 0x38, 0xdc, 0x7b, 0xb3, 0x7f, 0xb8, 0xff, 0x16, 0x3c, 0xeb, 0x12, 0xcf, 0x12,
		0x0d, 0xdc, 0xe0, 0xd9, 0x6d, 0xf0, 0xac, 0xb3, 0xc0, 0x00, 0x9c, 0x75, 0xb2, 0xb0, 0xdb, 0x44,
		0x5c, 0x91, 0xc0, 0xc0, 0xea, 0xba, 0x09, 0x0b, 0xac, 0xab, 0x9b, 0xa8, 0x20, 0xbf, 0xae, 0x22,
		0x23, 0x9d, 0x55, 0xbd, 0xaf, 0xf5, 0xac, 0x82, 0x76, 0xed, 0x85, 0x71, 0x70, 0xde, 0x0b, 0xbb,
		0x72, 0xbb, 0x09, 0xa6, 0x03, 0x3a, 0xee, 0x02, 0x0a, 0x2b, 0xf4, 0xb2, 0x6f, 0xa1, 0x04, 0xd3,
		0x60, 0xdf, 0x42, 0xe9, 0x03, 0xb3, 0x6f, 0xa1, 0x2a, 0xe8, 0x42, 0x61, 0xdf, 0x82, 0x9c, 0xc2,
		0xad, 0x90, 0xa2, 0x2d, 0x47, 0x06, 0x26, 0xce, 0xb7, 0xa2, 0x47, 0x06, 0x1c, 0x1f, 0xa6, 0xb3,
		0x72, 0x4e, 0xc0, 0xdd, 0x09, 0xb9, 0x6a, 0x1c, 0x0f, 0x18, 0x64, 0xa1, 0x7f, 0x35, 0xe8, 0xe5,
		0x51, 0xbf, 0x17, 0xfa, 0x43, 0xeb, 0xcb, 0xdc, 0x9f, 0x15, 0xb8, 0x67, 0xcc, 0x8a, 0x1f, 0x1c,
		0x58, 0xe7, 0xe0, 0x80, 0x1d, 0xa4, 0xc8, 0xc1, 0x81, 0x15, 0x4e, 0xd7, 0xce, 0x0f, 0x0e, 0x74,
		0xa6, 0x3e, 0x2f, 0xc4, 0xf1, 0x45, 0xee, 0xe5, 0x17, 0xba, 0xd4, 0x1c, 0xca, 0x0d, 0xe5, 0x86,
		0x72, 0xd7, 0x93, 0x72, 0x4b, 0x5d, 0x42, 0x2e, 0x56, 0x65, 0x5d, 0xf0, 0x6f, 0x99, 0x6a, 0xeb,
		0x6c, 0x41, 0x75, 0xee, 0x45, 0x13, 0x56, 0xa5, 0x12, 0xd7, 0x40, 0xd5, 0xd0, 0x3e, 0xd5, 0xd3,
		0x3c, 0xd5, 0xd2, 0x3a, 0x55, 0xd7, 0x38, 0x55, 0xd7, 0x36, 0x55, 0xd5, 0x34, 0xad, 0x97, 0xfa,
		0x95, 0xb8, 0x76, 0xa9, 0xe2, 0xbd, 0x65, 0xc2, 0xf7, 0x95, 0x21, 0xdb, 0xf4, 0x03, 0x27, 0x5e,
		0x6d, 0xd9, 0xa6, 0xc5, 0x4a, 0x5d, 0x43, 0x84, 0x8f, 0xae, 0xd9, 0xa9, 0x10, 0x7f, 0xcc, 0xc2,
		0x77, 0x93, 0x15, 0x38, 0x1e, 0x2e, 0x40, 0x7b, 0x02, 0x58, 0xd8, 0xff, 0xb0, 0x88, 0xcc, 0x87,
		0x39, 0x4e, 0x6e, 0xf3, 0x83, 0x7b, 0x24, 0x45, 0x59, 0x84, 0xb2, 0x08, 0x65, 0x11, 0xca, 0x22,
		0x55, 0x28, 0x8b, 0x08, 0xd5, 0xa5, 0x17, 0xdc, 0x5b, 0x0c, 0x0f, 0x08, 0x06, 0x64, 0x8a, 0x13,
		0x14, 0x27, 0x28, 0x4e, 0x50, 0x9c, 0xb0, 0x14, 0xe0, 0x8b, 0x01, 0x83, 0x5e, 0x2f, 0xf9, 0x6b,
		0xc6, 0xca, 0x82, 0x4c, 0xef, 0xee, 0xae, 0xc5, 0xa9, 0x08, 0x9b, 0xb1, 0x52, 0x8d, 0xfc, 0x6e,
		0x3a, 0xe2, 0xde, 0xb0, 0x3a, 0xa7, 0x29, 0xed, 0x74, 0x65, 0x26, 0x6d, 0x99, 0x49, 0x5f, 0x26,
		0xd2, 0x98, 0x6c, 0x3a, 0x13, 0x4e, 0x6b, 0xc5, 0x0a, 0xeb, 0xdf, 0x1b, 0x26, 0x5f, 0x83, 0x5f,
		0x60, 0x1b, 0x4d, 0xae, 0x1d, 0x5d, 0x7a, 0x2d, 0xaf, 0x82, 0xaf, 0xd1, 0xd5, 0xe0, 0xca, 0xf1,
		0x1e, 0xd3, 0x1f, 0x5a, 0xd3, 0xfc, 0x34, 0xf4, 0xe0, 0x4a, 0x13, 0xa8, 0x02, 0x54, 0x01, 0xaa,
		0x00, 0x55, 0x80, 0x2a, 0xf5, 0x81, 0x2a, 0x83, 0x28, 0xce, 0x37, 0x37, 0x14, 0x91, 0xca, 0x0e,
		0xd7, 0x9b, 0xca, 0x7d, 0x70, 0xae, 0x37, 0x9d, 0x4d, 0x83, 0xeb, 0x4d, 0xb5, 0xc3, 0xdf, 0xbc,
		0x69, 0x72, 0xbd, 0xe9, 0x82, 0x69, 0xb6, 0x36, 0x76, 0x5b, 0xbb, 0xdb, 0x3b, 0x1b, 0xbb, 0x5b,
		0xd8, 0xa8, 0x0e, 0x20, 0xd0, 0x1b, 0x95, 0x5b, 0x4e, 0x2b, 0x10, 0xc9, 0xb8, 0xe5, 0xf4, 0xc1,
		0x4d, 0x77, 0xe1, 0xf0, 0x1d, 0x44, 0x3b, 0xed, 0x6b, 0x86, 0x77, 0xe0, 0xed, 0x9f, 0x5f, 0xf6,
		0x45, 0xb6, 0xe1, 0xc9, 0xb9, 0xd9, 0x8d, 0xc8, 0x7e, 0x4a, 0x97, 0x37, 0xc1, 0x3d, 0x48, 0x8a,
		0x24, 0xaf, 0xe5, 0x55, 0xdb, 0x1f, 0xb2, 0xc1, 0xfe, 0x90, 0xfa, 0x54, 0xb1, 0xd8, 0x1f, 0xc2,
		0xfe, 0x90, 0xd2, 0x56, 0x92, 0xfd, 0x21, 0xec, 0x0f, 0xa1, 0xe9, 0x52, 0xe7, 0x34, 0xa5, 0x9d,
		0xae, 0xcc, 0xa4, 0x2d, 0x33, 0xe9, 0xcb, 0x44, 0x1a, 0xd3, 0xa9, 0x76, 0xb0, 0x3f, 0x44, 0x3e,
		0xbc, 0xb3, 0x3f, 0xa4, 0x84, 0xb5, 0x64, 0x7f, 0x08, 0xfb, 0x43, 0x80, 0x2a, 0x40, 0x15, 0xa0,
		0x0a, 0x50, 0xa5, 0xae, 0x50, 0x85, 0xfd, 0x21, 0xe2, 0x5f, 0xec, 0x0f, 0x61, 0x7f, 0xc8, 0xad,
		0x79, 0xb0, 0x3f, 0x64, 0x8d, 0xfd, 0x21, 0xf7, 0x9b, 0x26, 0xfb, 0x43, 0xb4, 0x01, 0x81, 0xde,
		0xa8, 0xec, 0x0f, 0xa9, 0x40, 0x24, 0x63, 0x7f, 0xc8, 0x3f, 0xef, 0x0f, 0x91, 0x6c, 0xb4, 0xaf,
		0x59, 0xdf, 0x1e, 0xe2, 0x50, 0xd8, 0x5f, 0xde, 0xc9, 0xd0, 0x50, 0xab, 0x9f, 0xbb, 0xae, 0xb0,
		0x82, 0xda, 0xbe, 0xf3, 0xe2, 0x46, 0x35, 0xf5, 0xd3, 0x22, 0x51, 0xfd, 0xb4, 0x08, 0xfd, 0xb4,
		0x27, 0x0f, 0x84, 0x7e, 0x5a, 0xa9, 0xd6, 0x81, 0x7e, 0x1a, 0xfa, 0x69, 0x3f, 0x58, 0x31, 0xf4,
		0xd3, 0x2a, 0x18, 0x90, 0xc5, 0x03, 0xb3, 0x46, 0x80, 0xd6, 0x0b, 0xd4, 0x5a, 0x01, 0x5b, 0x3d,
		0x70, 0xab, 0x07, 0x70, 0xd5, 0x40, 0x5e, 0xcf, 0xa2, 0x8e, 0xf8, 0xfe, 0x58, 0x36, 0x9a, 0xb0,
		0xd1, 0x44, 0x72, 0x60, 0x36, 0x9a, 0xb0, 0xd1, 0x84, 0x8d, 0x26, 0x1a, 0x29, 0x4c, 0x38, 0x95,
		0x15, 0x2b, 0xcc, 0x46, 0x13, 0x36, 0x9a, 0x48, 0x7e, 0x70, 0x36, 0x9a, 0xcc, 0xa6, 0xc1, 0x46,
		0x13, 0xed, 0xf0, 0x37, 0x6f, 0x9a, 0x6c, 0x34, 0x59, 0x30, 0x4d, 0x36, 0x9a, 0x68, 0x03, 0x02,
		0xbd, 0x51, 0xd9, 0x68, 0x52, 0x85, 0x9a, 0x04, 0x1b, 0x4d, 0x1e, 0xea, 0x5c, 0x47, 0x08, 0x91,
		0xdc, 0x6a, 0x64, 0x1f, 0x20, 0x44, 0xf2, 0x73, 0x4f, 0x13, 0x21, 0x12, 0x57, 0xd5, 0x2d, 0x84,
		0x48, 0x6a, 0x54, 0xc5, 0xa2, 0xd1, 0x42, 0xa3, 0xa5, 0xb4, 0x95, 0xa4, 0xd1, 0x42, 0xa3, 0x45,
		0x34, 0x15, 0xd1, 0x68, 0x91, 0x9c, 0x01, 0x8d, 0x16, 0x23, 0x29, 0xcb, 0x44, 0xea, 0xd2, 0xa9,
		0x70, 0xd0, 0x68, 0x11, 0x8f, 0xee, 0x34, 0x5a, 0x04, 0x3f, 0x38, 0x8d, 0x96, 0xd9, 0x34, 0x68,
		0xb4, 0x68, 0x87, 0xbf, 0x79, 0xd3, 0xa4, 0xd1, 0xb2, 0x60, 0x9a, 0x34, 0x5a, 0xb4, 0x01, 0x81,
		0xde, 0xa8, 0x34, 0x5a, 0xaa, 0x50, 0x93, 0xa0, 0xd1, 0xf2, 0x8f, 0x8d, 0x16, 0x4e, 0xf4, 0xde,
		0xea, 0xb3, 0x70, 0xa2, 0xd7, 0x8a, 0xfb, 0x72, 0xa2, 0xf7, 0x5e, 0x77, 0x5d, 0xe1, 0x13, 0xbd,
		0x07, 0x9c, 0xe8, 0x7d, 0xe0, 0x71, 0x49, 0x74, 0x3a, 0x45, 0x3b, 0x9c, 0xe2, 0x67, 0x7a, 0x37,
		0x38, 0xd3, 0xbb, 0xc4, 0x88, 0x9c, 0xe9, 0x75, 0x8e, 0x61, 0x39, 0xd3, 0xfb, 0xc4, 0x15, 0x13,
		0x3b, 0xd3, 0x1b, 0xc6, 0xc1, 0x79, 0x2f, 0xec, 0xca, 0x6f, 0x35, 0x99, 0x0e, 0x2c, 0xd5, 0xda,
		0xd5, 0xb9, 0xe6, 0x40, 0xb8, 0xde, 0xc3, 0x69, 0xe2, 0x5a, 0xa5, 0x0a, 0xf5, 0x94, 0xa1, 0x9e,
		0x3a, 0x54, 0x53, 0x48, 0x3d, 0x0b, 0x4a, 0xe2, 0x1d, 0x41, 0xc5, 0x6b, 0x08, 0x84, 0xaf, 0x1f,
		0xa0, 0x28, 0x42, 0x51, 0xe4, 0x69, 0x45, 0x11, 0xa9, 0xf2, 0xa5, 0xd5, 0xaa, 0x88, 0x40, 0xc5,
		0xd2, 0x61, 0x59, 0xe4, 0x59, 0x85, 0x9c, 0x50, 0xca, 0xf9, 0xec, 0x3b, 0x9d, 0xe7, 0xb4, 0x9a,
		0x65, 0xd1, 0xcd, 0xdc, 0x38, 0x58, 0xf9, 0xe6, 0x5f, 0xee, 0x3b, 0x96, 0xec, 0x48, 0x43, 0x10,
		0x3e, 0xba, 0xb1, 0x6f, 0x62, 0x59, 0xfe, 0xe8, 0x29, 0x97, 0x3c, 0xc6, 0x61, 0x94, 0xe5, 0x7b,
		0x79, 0xee, 0x86, 0xfc, 0x7b, 0xef, 0xa2, 0x78, 0xbf, 0x17, 0x0e, 0x61, 0x74, 0xe6, 0x86, 0x22,
		0x7a, 0xef, 0x82, 0xaf, 0xb7, 0x46, 0x68, 0xbe, 0x6a, 0xb5, 0xb6, 0x77, 0x5a, 0xad, 0xf5, 0x9d,
		0xcd, 0x9d, 0xf5, 0xdd, 0xad, 0xad, 0xe6, 0x76, 0xd3, 0xc1, 0x3e, 0x03, 0xef, 0x28, 0xed, 0x86,
		0x69, 0xd8, 0x7d, 0x33, 0x7c, 0x3c, 0xf1, 0xa0, 0xd7, 0x33, 0x6d, 0x45, 0x8e, 0xc3, 0xb0, 0xb1,
		0xf0, 0xeb, 0x20, 0xd6, 0xda, 0x88, 0xb1, 0xe5, 0x86, 0xd4, 0xf2, 0x02, 0x5f, 0x39, 0xef, 0x54,
		0x92, 0xd1, 0xbb, 0x32, 0x76, 0x1b, 0x46, 0x5e, 0xa2, 0x6d, 0xeb, 0xda, 0x74, 0x39, 0xb6, 0xbc,
		0xbc, 0xe5, 0x95, 0x60, 0x75, 0x5e, 0xd0, 0xef, 0xf7, 0xbe, 0xf9, 0xfd, 0xa4, 0x17, 0x75, 0xbe,
		0x95, 0x66, 0x73, 0xb3, 0xdb, 0x7a, 0x6f, 0xbf, 0x7b, 0x49, 0x3e, 0x52, 0x6e, 0xb3, 0xb0, 0xf4,
		0x0a, 0xb0, 0x8b, 0x0a, 0xef, 0xed, 0x0a, 0x6e, 0xda, 0x4f, 0x7a, 0x65, 0x7a, 0x92, 0xa3, 0x12,
		0xad, 0xf3, 0x12, 0xac, 0xf3, 0x12, 0xeb, 0xdd, 0x12, 0xea, 0x68, 0xe1, 0x6b, 0x9a, 0x77, 0xca,
		0x6e, 0x9f, 0xb9, 0x92, 0xbe, 0x75, 0x2b, 0x71, 0xeb, 0x68, 0x1f, 0x82, 0xb3, 0x26, 0x93, 0xcb,
		0x66, 0x92, 0xc3, 0x90, 0xe3, 0x3a, 0xf4, 0x88, 0x85, 0x20, 0xb1, 0x50, 0x24, 0x13, 0x92, 0xaa,
		0x51, 0x55, 0x70, 0xd5, 0xe9, 0xf7, 0xba, 0xe3, 0x8e, 0xb7, 0x1f, 0x7e, 0xed, 0x27, 0x69, 0x5e,
		0x36, 0x24, 0x7a, 0xd0, 0xbf, 0xee, 0x1f, 0xd6, 0x91, 0xfd, 0xdc, 0xea, 0xea, 0x9f, 0xec, 0xff,
		0xbf, 0xfd, 0x5f, 0x3f, 0xb4, 0x4f, 0x8e, 0x3e, 0x7e, 0xd8, 0x77, 0x35, 0x9c, 0xdb, 0x66, 0xbe,
		0xf3, 0xe6, 0xbd, 0x44, 0xb3, 0x5e, 0x20, 0xce, 0x4a, 0xc5, 0x5b, 0xf1, 0xb8, 0x2b, 0x1e, 0x7f,
		0x65, 0xe3, 0xb0, 0x9b, 0x78, 0xec, 0x28, 0x2e, 0x17, 0x4b, 0xe3, 0xbc, 0x5d, 0xbe, 0x10, 0x39,
		0xc7, 0x21, 0xd3, 0xcf, 0x87, 0x03, 0x3b, 0xf4, 0x9e, 0x29, 0x38, 0x6c, 0x39, 0x1c, 0x63, 0x3f,
		0x1e, 0x5c, 0x0d, 0x17, 0xef, 0xa6, 0x2a, 0x0d, 0x88, 0x97, 0xee, 0xf2, 0x70, 0x74, 0xa5, 0x92,
		0x87, 0xe7, 0x87, 0x25, 0x0f, 0x93, 0x87, 0xc9, 0xc3, 0xe4, 0x61, 0xf2, 0x30, 0x79, 0x78, 0xc5,
		0xf2, 0xb0, 0x30, 0x0f, 0x16, 0xe1, 0xbf, 0x24, 0x42, 0x12, 0x21, 0x89, 0x90, 0x44, 0xe8, 0xc6,
		0x63, 0x7a, 0x61, 0x70, 0x91, 0x86, 0x17, 0x12, 0xc9, 0xcf, 0xa1, 0x46, 0x93, 0x77, 0x5c, 0x6c,
		0x13, 0x18, 0x1b, 0xd2, 0xeb, 0x34, 0x19, 0xe4, 0x51, 0x7c, 0x39, 0x89, 0xcd, 0xc5, 0x8f, 0x27,
		0xf9, 0xbe, 0x1b, 0x5e, 0x44, 0x71, 0x94, 0x47, 0x49, 0x9c, 0x3d, 0xfc, 0x4f, 0xc5, 0xbf, 0x8c,
		0x5a, 0xf6, 0x95, 0xb2, 0x1f, 0xa7, 0x5b, 0xcc, 0x8a, 0x51, 0x9c, 0x6f, 0x35, 0x9b, 0x8d, 0xa4,
		0xb0, 0xe5, 0xac, 0x18, 0xfc, 0xf6, 0xd6, 0x33, 0xa1, 0x13, 0xcc, 0x83, 0x2c, 0x4c, 0x5d, 0xc7,
		0x7b, 0xc1, 0x73, 0x4e, 0xb7, 0x93, 0x59, 0x32, 0x5e, 0x4d, 0xff, 0xfc, 0x9b, 0xc4, 0x96, 0x78,
		0x8d, 0x33, 0x4d, 0x73, 0x89, 0x6d, 0xf4, 0x24, 0xd9, 0xfb, 0x5e, 0x39, 0x26, 0x21, 0x5c, 0xc9,
		0x13, 0xa9, 0xe0, 0xc1, 0x24, 0x60, 0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93,
		0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0x09, 0x77, 0xef, 0xc8, 0xb1, 0xb2, 0x27, 0x9c, 0xb8,
		0xb9, 0x75, 0xea, 0xc2, 0xdd, 0xcd, 0x6a, 0x4a, 0x67, 0x70, 0x86, 0x9f, 0xed, 0x78, 0xf4, 0xd1,
		0x9c, 0x5c, 0x93, 0x56, 0xe2, 0xc9, 0xb2, 0x52, 0x8f, 0x3b, 0xb9, 0x10, 0xfd, 0x73, 0x2a, 0xf2,
		0xe7, 0x7c, 0x33, 0xfd, 0x06, 0x9b, 0xe9, 0x05, 0x81, 0x03, 0x9b, 0xe9, 0xeb, 0x98, 0x05, 0xd9,
		0x4c, 0xbf, 0xcc, 0xe2, 0xb1, 0x89, 0x8f, 0x8a, 0x23, 0x15, 0x47, 0x2a, 0x8e, 0x6c, 0xe2, 0xfb,
		0x69, 0x70, 0xc8, 0x26, 0x3e, 0xa7, 0x46, 0xc4, 0x66, 0x7a, 0xf2, 0x30, 0x79, 0x98, 0x3c, 0x4c,
		0x1e, 0x26, 0x0f, 0x93, 0x87, 0x15, 0xf3, 0x30, 0x9b, 0xe9, 0x49, 0x84, 0x24, 0x42, 0x12, 0x21,
		0x89, 0xf0, 0xb1, 0x1e, 0xc3, 0x16, 0x18, 0xb6, 0xc0, 0xfc, 0xec, 0x28, 0x6c, 0x81, 0x71, 0xe5,
		0x95, 0x6c, 0x81, 0xa9, 0x68, 0x52, 0x5b, 0x63, 0x0b, 0x4c, 0x3d, 0x98, 0x04, 0x9b, 0xe9, 0x61,
		0x12, 0x30, 0x09, 0x98, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12,
		0x30, 0x89, 0xda, 0x33, 0x09, 0x36, 0xd3, 0x5b, 0xd8, 0x4c, 0xef, 0xea, 0xfa, 0x39, 0xfd, 0xbd,
		0xf4, 0x0e, 0x2e, 0x96, 0xe3, 0x92, 0x96, 0x6a, 0x5a, 0x79, 0xf5, 0xef, 0x69, 0x99, 0xd9, 0x75,
		0xad, 0xae, 0x6a, 0xc9, 0x46, 0xf7, 0xf1, 0xf9, 0x49, 0x7f, 0x84, 0xea, 0x1d, 0xdc, 0xd6, 0x72,
		0x67, 0x00, 0x2e, 0x6c, 0x29, 0xa3, 0x5a, 0x53, 0xee, 0x95, 0xdb, 0xdc, 0xd7, 0xf2, 0xd8, 0x62,
		0x4b, 0xa9, 0x57, 0x5e, 0x73, 0x5d, 0xcb, 0x52, 0x6e, 0xc0, 0x75, 0x2d, 0x82, 0x27, 0xcc, 0xdc,
		0xdc, 0xf1, 0xcf, 0x01, 0x33, 0x53, 0x01, 0xa9, 0x1a, 0xc4, 0xd0, 0xd9, 0xf9, 0xb2, 0xa0, 0xd7,
		0x4b, 0xfe, 0xf2, 0x93, 0xbf, 0x62, 0x3f, 0xc8, 0xdc, 0x37, 0xc1, 0xe6, 0x46, 0x73, 0xbf, 0x8b,
		0x7d, 0x9d, 0x3e, 0x9b, 0x78, 0x00, 0x95, 0x0b, 0xa4, 0xd2, 0xd5, 0xc9, 0xd5, 0x6b, 0xb3, 0x39,
		0x09, 0xb4, 0x8e, 0x2b, 0x86, 0x95, 0xef, 0xb2, 0x0d, 0xa2, 0x38, 0x7f, 0x25, 0xd0, 0x63, 0x73,
		0xd9, 0x06, 0x39, 0x09, 0xe2, 0xcb, 0xe1, 0x87, 0xf9, 0xec, 0xd4, 0x5c, 0x05, 0x9a, 0x11, 0xef,
		0xa2, 0x58, 0xa4, 0xeb, 0x21, 0x90, 0x55, 0x16, 0x86, 0xfb, 0x14, 0xf4, 0x06, 0xa1, 0xe0, 0x78,
		0xbf, 0xa5, 0x41, 0x27, 0x8f, 0x92, 0xf8, 0x6d, 0x74, 0x19, 0x8d, 0xbb, 0x80, 0xce, 0xc7, 0xbd,
		0x11, 0xe8, 0xe0, 0xbc, 0x0b, 0xbe, 0xd6, 0xde, 0x44, 0x36, 0xb6, 0xb6, 0x6a, 0x6c, 0x24, 0x15,
		0x6d, 0xb9, 0x9d, 0xad, 0xf2, 0x71, 0xdc, 0x28, 0x0b, 0xce, 0x7b, 0xa1, 0x3f, 0xaa, 0xbc, 0x07,
		0x99, 0x7f, 0x11, 0xf5, 0xf2, 0x30, 0x15, 0x38, 0x8f, 0x7b, 0xff, 0xb8, 0xee, 0xa9, 0xcc, 0x45,
		0xd0, 0xcb, 0x42, 0xe8, 0x0c, 0x74, 0x06, 0x3a, 0x03, 0x9d, 0xa9, 0x12, 0x9d, 0x39, 0x4f, 0x92,
		0x5e, 0x18, 0xc4, 0x12, 0x9b, 0x06, 0x9b, 0x2b, 0x9c, 0x10, 0xd3, 0xb0, 0xdf, 0x0b, 0x3a, 0x45,
		0x62, 0x72, 0x9f, 0x09, 0xef, 0x0e, 0x48, 0x0a, 0x24, 0x05, 0x92, 0x02, 0x49, 0x81, 0xa4, 0x40,
		0x52, 0xa0, 0xf4, 0x3b, 0xb2, 0x0d, 0xf3, 0x09, 0x1b, 0xd4, 0xe6, 0xf7, 0x26, 0xd5, 0x4e, 0xd6,
		0x38, 0x3b, 0x0e, 0xf2, 0x2f, 0x47, 0xe3, 0x0f, 0x87, 0xb0, 0x71, 0x59, 0x21, 0x0c, 0x61, 0x63,
		0xb6, 0x9d, 0x18, 0xc1, 0x52, 0x6c, 0x3b, 0x91, 0x4b, 0x84, 0x6c, 0x3b, 0xf9, 0x19, 0xa2, 0xca,
		0xb6, 0x13, 0x48, 0x2a, 0x24, 0x15, 0x92, 0x5a, 0x29, 0x92, 0xca, 0xb6, 0x93, 0xc7, 0x7e, 0xb1,
		0xed, 0x64, 0xa9, 0xe1, 0xd8, 0x76, 0x52, 0x8e, 0x89, 0xb0, 0xed, 0xa4, 0xe2, 0x46, 0xc2, 0xb6,
		0x13, 0xa7, 0xf3, 0x65, 0xdb, 0x49, 0x09, 0x54, 0x86, 0x9e, 0x1b, 0x74, 0x06, 0x3a, 0x03, 0x9d,
		0xa9, 0x1c, 0x9d, 0xa1, 0xe7, 0x26, 0x92, 0x10, 0xd9, 0x76, 0x42, 0x0a, 0x24, 0x05, 0x92, 0x02,
		0x49, 0x81, 0xa4, 0xc0, 0x2a, 0xa4, 0x40, 0xb6, 0x9d, 0x18, 0xd9, 0x76, 0x52, 0x33, 0x01, 0xb0,
		0xb9, 0x5d, 0x27, 0x48, 0x80, 0x69, 0x9b, 0xbc, 0x25, 0x53, 0xaf, 0xbe, 0x0a, 0xd8, 0x6d, 0xe3,
		0xae, 0x93, 0x0e, 0x58, 0xc9, 0x62, 0x3d, 0x6e, 0x44, 0x7a, 0x50, 0xfd, 0x42, 0xf5, 0x0b, 0xd5,
		0xaf, 0x52, 0x93, 0x4e, 0xe9, 0xaa, 0x5f, 0xc1, 0x20, 0xff, 0xe2, 0xf7, 0x83, 0x2c, 0x9b, 0x98,
		0x80, 0xa3, 0x4d, 0x98, 0xf3, 0xc3, 0xb8, 0xd9, 0x8c, 0xb9, 0x8e, 0x06, 0x18, 0x9b, 0x31, 0x0d,
		0x56, 0x16, 0xd8, 0x8c, 0xe9, 0xae, 0x72, 0x30, 0x2b, 0xae, 0x4e, 0x2f, 0x42, 0x70, 0x13, 0x63,
		0xe6, 0xe0, 0xcc, 0xab, 0x15, 0xd8, 0x94, 0xdf, 0x0d, 0xb3, 0x4e, 0x1a, 0xf5, 0x9d, 0x30, 0xfa,
		0x5b, 0x17, 0xdd, 0xce, 0x06, 0x21, 0x27, 0x90, 0x13, 0xc8, 0x09, 0xe4, 0x84, 0x12, 0xed, 0x3d,
		0xcb, 0xd3, 0x28, 0xbe, 0x24, 0x13, 0x2c, 0xf7, 0x59, 0x7b, 0x49, 0x27, 0xe8, 0xb9, 0x68, 0x90,
		0xce, 0x2e, 0x67, 0x9a, 0x8e, 0x40, 0x0e, 0x20, 0x07, 0x90, 0x03, 0xc8, 0x01, 0x65, 0x16, 0x1e,
		0x32, 0x3f, 0x1e, 0x5c, 0x9d, 0x3b, 0xd9, 0x71, 0x38, 0x0d, 0x30, 0x0e, 0x6e, 0x7c, 0x73, 0x7c,
		0x1e, 0xc0, 0xed, 0x6d, 0x69, 0x02, 0xbb, 0x10, 0x44, 0x36, 0x75, 0x4b, 0xed, 0xf7, 0x97, 0xdc,
		0xc2, 0x7d, 0xe3, 0xf6, 0xfa, 0xba, 0xda, 0x3d, 0xfa, 0xd6, 0xc6, 0x6e, 0x6b, 0x77, 0x7b, 0x67,
		0x63, 0x77, 0xab, 0x46, 0x36, 0x50, 0x91, 0x2d, 0x0f, 0x67, 0x2b, 0x80, 0xae, 0x5d, 0xed, 0x3e,
		0x2c, 0x12, 0xa0, 0x9b, 0xdd, 0x86, 0x60, 0x6b, 0xb0, 0x35, 0xd8, 0x1a, 0x6c, 0x0d, 0xb6, 0x06,
		0x5b, 0x83, 0xad, 0xc1, 0xd6, 0x60, 0x6b, 0xb0, 0xb5, 0x4d, 0x6c, 0x3d, 0xda, 0xd8, 0xe8, 0x4f,
		0xf6, 0x1d, 0xba, 0xc4, 0xd8, 0xb7, 0x06, 0x02, 0x6b, 0x83, 0xb5, 0xc1, 0xda, 0x60, 0xed, 0x12,
		0xed, 0x9d, 0x5e, 0x66, 0x69, 0x19, 0x21, 0x77, 0xf1, 0xb0, 0xe6, 0x73, 0xc1, 0x68, 0x08, 0xb2,
		0x00, 0x59, 0x80, 0x2c, 0x40, 0x16, 0xa8, 0x40, 0x70, 0x99, 0x4b, 0x04, 0x2d, 0x07, 0xef, 0xbd,
		0x1f, 0x0f, 0xae, 0x86, 0x4b, 0x73, 0xb3, 0x02, 0x49, 0x26, 0x0d, 0xaf, 0x92, 0xeb, 0xd0, 0xef,
		0xa7, 0xd1, 0x75, 0x90, 0x87, 0x4e, 0x8b, 0xfb, 0x8b, 0x43, 0x91, 0x74, 0x48, 0x3a, 0x24, 0x1d,
		0x92, 0x8e, 0xcb, 0x20, 0x33, 0x39, 0x1e, 0xea, 0x32, 0x07, 0x39, 0xa8, 0x08, 0x7a, 0x07, 0xdd,
		0x30, 0xce, 0xa3, 0xfc, 0xdb, 0x9b, 0x20, 0x0b, 0xdd, 0xab, 0xbd, 0x9c, 0xec, 0xbf, 0x3b, 0xfa,
		0xb4, 0xdf, 0x3e, 0x3e, 0x39, 0xf8, 0xb4, 0xf7, 0x61, 0xbf, 0xbd, 0x77, 0xda, 0x3e, 0x3a, 0xfe,
		0x70, 0x70, 0xf4, 0xde, 0x95, 0xcb, 0x8d, 0x8a, 0xaa, 0x99, 0x53, 0x05, 0x51, 0xc7, 0xd5, 0xe7,
		0xe9, 0xca, 0xdd, 0x5a, 0xb2, 0xc9, 0x22, 0xee, 0x1d, 0x1e, 0x7a, 0x55, 0xac, 0xda, 0x6b, 0x2c,
		0xd8, 0xf1, 0xe1, 0xde, 0xaf, 0xae, 0x57, 0xcc, 0xc9, 0x3b, 0x9f, 0x59, 0x0f, 0xdc, 0x36, 0xc1,
		0x66, 0x32, 0xc8, 0x43, 0xff, 0xa2, 0x17, 0xf4, 0xfd, 0x6e, 0x70, 0xd5, 0x8f, 0xe2, 0x4b, 0x87,
		0x68, 0x73, 0x71, 0xac, 0xb2, 0x45, 0xfb, 0xdd, 0x6a, 0x57, 0x01, 0x67, 0x81, 0xb3, 0xc0, 0xd9,
		0x15, 0x87, 0xb3, 0xee, 0xb4, 0xa5, 0x1c, 0x69, 0x4a, 0x19, 0xbd, 0xb5, 0x29, 0x8c, 0xbb, 0x7e,
		0x27, 0xb9, 0xba, 0x1a, 0xc4, 0x51, 0xfe, 0xcd, 0xe1, 0xf5, 0x4d, 0xf3, 0xe3, 0xb8, 0x4b, 0x38,
		0xef, 0x8f, 0xde, 0xef, 0x93, 0x6f, 0xc8, 0x37, 0xe4, 0x1b, 0xf2, 0x4d, 0x99, 0xf6, 0x5e, 0xc4,
		0x2e, 0x0a, 0xf7, 0x2e, 0x52, 0x1a, 0x9a, 0x70, 0x8e, 0x35, 0xe1, 0x4a, 0xbf, 0x65, 0x53, 0x47,
		0x0a, 0xae, 0xcc, 0xfb, 0x34, 0x6d, 0x68, 0xc0, 0x85, 0xe7, 0x97, 0x7d, 0xff, 0x6a, 0xd0, 0xcb,
		0xa3, 0x2f, 0x49, 0xbf, 0x7c, 0x29, 0xb8, 0xf9, 0xb7, 0x47, 0x11, 0xce, 0x1e, 0xf0, 0x41, 0x11,
		0x4e, 0x05, 0xd8, 0xd4, 0x5c, 0x11, 0xae, 0x64, 0x69, 0xc9, 0x7b, 0xf0, 0x90, 0x83, 0x5b, 0x9b,
		0x9d, 0x5f, 0xc8, 0x0b, 0xd3, 0x82, 0x69, 0xc1, 0xb4, 0x2c, 0x05, 0xaa, 0x19, 0x0e, 0x8a, 0x83,
		0xf3, 0x5e, 0xd8, 0x75, 0xdf, 0xd2, 0x9d, 0x0e, 0xc4, 0xc5, 0x1d, 0x1a, 0x21, 0x53, 0x22, 0x74,
		0xca, 0x85, 0x50, 0xa9, 0x50, 0x2a, 0x1e, 0x52, 0xc5, 0x43, 0xab, 0x68, 0x88, 0x75, 0x13, 0x6a,
		0x1d, 0x85, 0x5c, 0xf7, 0x45, 0xae, 0x05, 0x7f, 0xe1, 0xe2, 0x0e, 0x89, 0x87, 0xea, 0x4d, 0x69,
		0xb9, 0x9f, 0xe7, 0x3d, 0xf7, 0x79, 0x6f, 0x6e, 0x34, 0x92, 0x12, 0x49, 0x89, 0xa4, 0x44, 0x52,
		0xaa, 0x50, 0x52, 0xe2, 0x7e, 0xf8, 0xc7, 0x7e, 0x71, 0x3f, 0xfc, 0x52, 0xc3, 0x71, 0x3f, 0x7c,
		0x39, 0x26, 0xc2, 0xfd, 0xf0, 0x15, 0x37, 0x12, 0xee, 0x87, 0x77, 0x4b, 0x29, 0xb8, 0x0b, 0x50,
		0xa9, 0x19, 0x3e, 0xd7, 0x14, 0x6d, 0x38, 0x69, 0x65, 0xac, 0xa9, 0xb5, 0xc8, 0xf7, 0xcf, 0x2f,
		0xfb, 0xef, 0x26, 0x9f, 0xad, 0xd4, 0x7e, 0x79, 0xf9, 0x76, 0x5b, 0xea, 0x4e, 0xc6, 0xd1, 0x9d,
		0x87, 0xee, 0x36, 0x30, 0x3a, 0xb8, 0x2e, 0xd2, 0x79, 0xbb, 0x6b, 0x83, 0x76, 0x97, 0x1c, 0x1d,
		0xa6, 0xdd, 0x55, 0xc3, 0x2c, 0x48, 0xbb, 0xeb, 0x47, 0x0b, 0x44, 0xbb, 0x4b, 0x3b, 0x74, 0xca,
		0x85, 0x50, 0xa9, 0x50, 0x2a, 0x1e, 0x52, 0xc5, 0x43, 0xab, 0x68, 0x88, 0x75, 0x4b, 0xb9, 0x68,
		0x77, 0x3d, 0x01, 0xe9, 0xd1, 0xee, 0xa2, 0xdd, 0x45, 0x52, 0x22, 0x29, 0x91, 0x94, 0x48, 0x4a,
		0xff, 0xec, 0x2f, 0xb4, 0xbb, 0x1e, 0xfb, 0x45, 0xbb, 0x6b, 0xa9, 0xe1, 0x68, 0x77, 0x95, 0x63,
		0x22, 0xb4, 0xbb, 0x2a, 0x6e, 0x24, 0xb4, 0xbb, 0xdc, 0x52, 0x0a, 0xda, 0x5d, 0x26, 0xda, 0x5d,
		0x2e, 0x3a, 0x19, 0x6b, 0x36, 0xba, 0x5d, 0xa7, 0xa3, 0x8f, 0xc6, 0x19, 0x67, 0x3d, 0x7b, 0xb7,
		0x63, 0xe7, 0x95, 0x3f, 0xea, 0x7c, 0xdb, 0xb2, 0x6b, 0x75, 0xe0, 0x79, 0xd4, 0x90, 0xf0, 0xcf,
		0x2f, 0xba, 0x0e, 0x4e, 0x3b, 0xcf, 0xde, 0x9b, 0xa3, 0xce, 0xa5, 0x94, 0x6c, 0x2e, 0xba, 0x1c,
		0x75, 0xd6, 0x38, 0xea, 0x7c, 0xd1, 0xe5, 0xa8, 0xf3, 0x23, 0xdf, 0x90, 0xa3, 0xce, 0x0e, 0x03,
		0x8c, 0xcb, 0x40, 0xe3, 0x3e, 0xe0, 0xb8, 0x0e, 0x3c, 0x62, 0x01, 0x48, 0x2c, 0x10, 0x89, 0x04,
		0xa4, 0x6a, 0x50, 0x42, 0xf6, 0x7e, 0xa8, 0x56, 0xa1, 0xea, 0xd7, 0xfe, 0xba, 0xe8, 0xd2, 0xfe,
		0x32, 0x1c, 0xf2, 0x44, 0x43, 0x9f, 0xdb, 0xba, 0x20, 0x7b, 0x32, 0x9e, 0x80, 0xc0, 0x9a, 0x14,
		0x50, 0xed, 0x16, 0x94, 0x6c, 0x14, 0x96, 0x8a, 0xb2, 0x42, 0xed, 0x0e, 0x0b, 0x8c, 0x3e, 0xd9,
		0x9b, 0x8b, 0x2e, 0x27, 0x05, 0xca, 0x8a, 0x5c, 0x9c, 0x14, 0x80, 0x2d, 0xc2, 0x16, 0x61, 0x8b,
		0xb0, 0x45, 0xd8, 0x22, 0x6c, 0x11, 0xb6, 0x08, 0x5b, 0x84, 0x2d, 0xc2, 0x16, 0x57, 0x93, 0x2d,
		0xd6, 0x6c, 0xaf, 0x4d, 0x41, 0x16, 0xd9, 0x68, 0xa3, 0x6d, 0xe9, 0x46, 0x2c, 0xbc, 0xfa, 0xbb,
		0x6c, 0xa6, 0x36, 0x5d, 0xab, 0x2d, 0x36, 0x69, 0x9a, 0xa4, 0xfe, 0x97, 0x20, 0xee, 0xf6, 0xca,
		0xbc, 0x4a, 0x70, 0xc6, 0x14, 0xe6, 0xdf, 0x9f, 0xad, 0x36, 0xa5, 0x00, 0x7e, 0x6e, 0x15, 0x58,
		0xe3, 0x56, 0x81, 0x52, 0x73, 0x0f, 0x5b, 0x6d, 0xd6, 0xd8, 0x6a, 0x23, 0x14, 0x70, 0xa4, 0x2a,
		0x0b, 0xc8, 0xac, 0xd4, 0x90, 0x0e, 0x3a, 0x2b, 0x9e, 0xe6, 0x69, 0x18, 0xe4, 0x7e, 0x90, 0xf9,
		0x7f, 0x45, 0xf9, 0x97, 0x6e, 0x1a, 0xfc, 0xe5, 0xbe, 0x8c, 0xba, 0x38, 0x24, 0xd2, 0x2b, 0x1a,
		0x61, 0x54, 0x22, 0x9c, 0xca, 0x85, 0x55, 0xa9, 0xf0, 0x2a, 0x1e, 0x66, 0xc5, 0xc3, 0xad, 0x68,
		0xd8, 0x75, 0x57, 0xdf, 0x5b, 0xa3, 0x70, 0xfb, 0x34, 0xf4, 0x47, 0xe1, 0xd6, 0x70, 0x39, 0xcb,
		0x46, 0x59, 0x6b, 0xae, 0xac, 0x51, 0xbb, 0xad, 0x3e, 0xc3, 0x4f, 0xf7, 0xff, 0x4d, 0x3e, 0x1c,
		0xdb, 0x7d, 0xca, 0x8a, 0x60, 0x6c, 0xf7, 0x81, 0xb1, 0xc2, 0x58, 0x61, 0xac, 0x30, 0x56, 0x18,
		0x2b, 0x8c, 0x15, 0xc6, 0x0a, 0x63, 0x85, 0xb1, 0xc2, 0x58, 0x61, 0xac, 0x1a, 0x8c, 0xb5, 0x66,
		0xdb, 0x8d, 0xe6, 0x08, 0x2b, 0x5b, 0x8e, 0xb4, 0x2d, 0xde, 0x90, 0xa5, 0x57, 0x7f, 0xdb, 0xd1,
		0x6d, 0xdb, 0xae, 0xd3, 0xd6, 0xa3, 0xcb, 0x34, 0xe8, 0x84, 0x17, 0x83, 0x9e, 0x9f, 0x86, 0x59,
		0x1e, 0xa4, 0x79, 0xf9, 0x9b, 0x8f, 0x16, 0x46, 0x60, 0xfb, 0x91, 0x3d, 0x12, 0xc0, 0xf6, 0x23,
		0x15, 0x10, 0xcf, 0xf6, 0xa3, 0xa5, 0xdc, 0x80, 0xed, 0x47, 0x14, 0x73, 0xad, 0x54, 0x19, 0x28,
		0xe6, 0xca, 0x51, 0x44, 0xce, 0x6e, 0x3e, 0x2e, 0x84, 0x51, 0x50, 0xd5, 0x0c, 0x6d, 0x52, 0x21,
		0x4e, 0x3c, 0xd4, 0x89, 0x87, 0x3c, 0xd1, 0xd0, 0xe7, 0xae, 0xee, 0xb6, 0x46, 0x41, 0xf5, 0x69,
		0x08, 0x6c, 0x95, 0x6f, 0x5f, 0xfa, 0x12, 0xf6, 0xfa, 0x61, 0xea, 0x27, 0x71, 0xef, 0x9b, 0xfb,
		0x74, 0x74, 0x7b, 0x30, 0x52, 0x12, 0x29, 0x89, 0x94, 0x44, 0x4a, 0x22, 0x25, 0x91, 0x92, 0xe6,
		0xd7, 0x60, 0x52, 0xc0, 0xf5, 0xf3, 0xe8, 0x2a, 0x74, 0x9f, 0x93, 0xe6, 0x46, 0x23, 0x29, 0x91,
		0x94, 0x48, 0x4a, 0x24, 0xa5, 0x0a, 0x25, 0xa5, 0x41, 0x14, 0xe7, 0xcd, 0x6d, 0x81, 0x9c, 0xb4,
		0xcd, 0x8d, 0x80, 0x3f, 0xfe, 0x20, 0xdc, 0x08, 0x58, 0xde, 0x78, 0xdc, 0x08, 0x58, 0x59, 0x13,
		0x69, 0xad, 0xef, 0x6e, 0x73, 0x25, 0xa0, 0xb5, 0x77, 0x3f, 0x5b, 0x61, 0x52, 0x91, 0xe5, 0x41,
		0x2f, 0xf4, 0xd3, 0x64, 0x90, 0x87, 0x99, 0x10, 0xb3, 0x58, 0x1c, 0x12, 0x7a, 0x01, 0xbd, 0x80,
		0x5e, 0x40, 0x2f, 0x2a, 0x44, 0x2f, 0xba, 0x61, 0x27, 0xba, 0x0a, 0x7a, 0xdb, 0x2d, 0x89, 0xaa,
		0xd7, 0x86, 0xc3, 0x31, 0x16, 0x70, 0xc2, 0x06, 0x7c, 0xc6, 0x26, 0x9f, 0xd9, 0x80, 0xcf, 0xc0,
		0x67, 0xfe, 0xd9, 0x44, 0x36, 0x31, 0x11, 0xc8, 0x4c, 0x45, 0xc8, 0x0c, 0xa7, 0xa0, 0x94, 0xce,
		0x86, 0xdc, 0x3d, 0x11, 0x50, 0x37, 0xe5, 0x8e, 0x7f, 0x4f, 0x3e, 0xdf, 0xc9, 0xf8, 0xe3, 0xa1,
		0xdd, 0x51, 0x22, 0x71, 0x47, 0xbb, 0x83, 0xed, 0xde, 0x16, 0xc8, 0x37, 0xdb, 0xbd, 0xe5, 0x72,
		0x21, 0xdb, 0xbd, 0x1f, 0x17, 0xc2, 0xa8, 0x33, 0x6a, 0x86, 0x36, 0xa9, 0x10, 0x27, 0x1e, 0xea,
		0xc4, 0x43, 0x9e, 0x68, 0xe8, 0x73, 0x4b, 0x88, 0xd8, 0x5b, 0xf7, 0x04, 0x04, 0xc6, 0x76, 0x6f,
		0xb6, 0x7b, 0x93, 0x92, 0x48, 0x49, 0xa4, 0x24, 0x52, 0x12, 0x29, 0x49, 0x3d, 0x25, 0xb1, 0xdd,
		0x9b, 0xa4, 0x44, 0x52, 0x22, 0x29, 0x91, 0x94, 0x1e, 0xe3, 0x2f, 0x6c, 0xf7, 0x7e, 0xf4, 0x17,
		0xdb, 0xbd, 0x97, 0x1a, 0x8e, 0xed, 0x11, 0xe5, 0x98, 0x08, 0xdb, 0xbd, 0xab, 0x6e, 0x25, 0xec,
		0x90, 0xa8, 0x1c, 0xa9, 0x60, 0xbb, 0x37, 0xf4, 0x02, 0x7a, 0x01, 0xbd, 0x80, 0x5e, 0x3c, 0xcd,
		0x5f, 0xd8, 0xee, 0x0d, 0x9f, 0x61, 0xbb, 0x37, 0x7c, 0xc6, 0x16, 0x9f, 0x61, 0xbb, 0x37, 0x64,
		0x86, 0xed, 0xde, 0x65, 0x40, 0xac, 0x55, 0xda, 0xee, 0x5d, 0xaf, 0x6b, 0x2f, 0xee, 0xee, 0xf6,
		0xe6, 0xe2, 0x0b, 0x6d, 0xab, 0x37, 0x65, 0xed, 0x95, 0xbf, 0xfa, 0xe2, 0x8e, 0x7d, 0xd7, 0xe9,
		0xf2, 0x8b, 0x5e, 0x72, 0x79, 0x19, 0xc5, 0x97, 0x7e, 0xd2, 0x1f, 0xda, 0x60, 0x56, 0xfe, 0xdd,
		0x17, 0x77, 0x07, 0xe0, 0xea, 0x0b, 0x7b, 0x85, 0x23, 0xae, 0xbe, 0x50, 0x29, 0xfc, 0x70, 0xf5,
		0xc5, 0x52, 0x6e, 0xc0, 0xd5, 0x17, 0x9c, 0x85, 0xd2, 0x0e, 0x40, 0x62, 0x81, 0x48, 0x24, 0x20,
		0x55, 0x83, 0x28, 0x3a, 0x3b, 0x0b, 0xd5, 0x4b, 0x86, 0xe8, 0x38, 0xba, 0xfc, 0x72, 0x9e, 0xa4,
		0xfe, 0x88, 0xa1, 0xf9, 0x9d, 0x2f, 0x41, 0x7c, 0x19, 0x66, 0xee, 0x3b, 0x74, 0xff, 0x30, 0xb6,
		0xfb, 0x9b, 0x8d, 0x87, 0xe6, 0x4a, 0x47, 0x50, 0x3c, 0xbe, 0xca, 0xc5, 0x59, 0xa9, 0x78, 0x2b,
		0x1e, 0x77, 0xc5, 0xe3, 0xaf, 0x68, 0x1c, 0x76, 0x5b, 0xba, 0x64, 0x17, 0xfc, 0x13, 0xe0, 0x20,
		0x17, 0x1b, 0x1b, 0xae, 0x76, 0x99, 0xa8, 0x7a, 0xdd, 0x29, 0x74, 0xd4, 0x4d, 0xd1, 0xe3, 0x70,
		0xfc, 0xf1, 0x8e, 0xc6, 0x9f, 0x0e, 0x41, 0x8f, 0xb2, 0x62, 0x18, 0x82, 0x1e, 0x90, 0x58, 0x48,
		0x2c, 0x24, 0x16, 0x12, 0x0b, 0x89, 0x85, 0xc4, 0x42, 0x62, 0x21, 0xb1, 0x90, 0x58, 0x48, 0x2c,
		0x24, 0xd6, 0x06, 0x89, 0xad, 0xd7, 0x3e, 0xa5, 0x3b, 0x1c, 0x96, 0x6d, 0x4a, 0xda, 0x36, 0x6f,
		0xc9, 0xd6, 0x2b, 0xbf, 0x4b, 0x69, 0xde, 0xba, 0xeb, 0xb4, 0x49, 0x69, 0xf6, 0xd0, 0xfc, 0xc9,
		0x9a, 0x96, 0xbc, 0x49, 0xe9, 0xee, 0x00, 0xe5, 0x6e, 0x52, 0x5a, 0x67, 0x93, 0x92, 0x61, 0xd8,
		0xcf, 0x26, 0xa5, 0x0a, 0xe5, 0xa1, 0xd2, 0x61, 0xf9, 0xac, 0x76, 0x11, 0x06, 0x17, 0x69, 0x78,
		0x51, 0xa6, 0xc1, 0x4e, 0x61, 0xf7, 0x4e, 0x89, 0xef, 0x79, 0x3c, 0x49, 0x95, 0xbf, 0xfc, 0x32,
		0x69, 0x30, 0x34, 0xee, 0xc6, 0xae, 0x1a, 0xc5, 0xfd, 0xd1, 0x81, 0x65, 0x3f, 0x0d, 0x2f, 0x7a,
		0x61, 0x27, 0x4f, 0xd2, 0xf2, 0xe3, 0xfe, 0xdd, 0x01, 0xd8, 0x9c, 0x4a, 0xdc, 0x27, 0xee, 0x1b,
		0x8c, 0xfb, 0x6c, 0x4e, 0x5d, 0x63, 0x73, 0xaa, 0x50, 0xc0, 0x71, 0x1d, 0x78, 0xc4, 0x02, 0x90,
		0x58, 0x20, 0x12, 0x09, 0x48, 0xd5, 0x28, 0x0e, 0x3a, 0xeb, 0xeb, 0xdd, 0x81, 0x2a, 0x7e, 0xa7,
		0x17, 0x8d, 0x17, 0xda, 0xb5, 0x28, 0xe5, 0xfd, 0xe3, 0xba, 0xef, 0xe7, 0x5d, 0x04, 0xbd, 0x8c,
		0x86, 0x9e, 0x7c, 0x60, 0x95, 0x0b, 0xb0, 0x52, 0x81, 0x56, 0x3c, 0xe0, 0x8a, 0x07, 0x5e, 0xd1,
		0x00, 0xec, 0x26, 0x10, 0x3b, 0x0a, 0xc8, 0xee, 0x2a, 0x07, 0x0f, 0xfa, 0x0b, 0x0d, 0x3d, 0x89,
		0x87, 0x7a, 0x4f, 0x62, 0x1a, 0x64, 0x79, 0x98, 0xfa, 0x51, 0x57, 0x23, 0x29, 0x16, 0x63, 0x93,
		0xb0, 0x48, 0x58, 0x24, 0x2c, 0x12, 0x56, 0x85, 0x12, 0x56, 0x7a, 0x3b, 0x80, 0xf9, 0xf9, 0x70,
		0x5c, 0x81, 0xdc, 0xb5, 0xeb, 0x70, 0x8c, 0xc9, 0xda, 0x55, 0x5e, 0xf3, 0xec, 0xb6, 0xb2, 0xf6,
		0xe6, 0x86, 0x27, 0x20, 0xa1, 0x35, 0x79, 0x3a, 0x3b, 0x02, 0x43, 0xc9, 0x28, 0xd3, 0xc9, 0x3d,
		0xad, 0xe2, 0x83, 0x49, 0x2a, 0xd5, 0x09, 0x01, 0x84, 0x07, 0x87, 0x15, 0x96, 0x25, 0x2b, 0xc6,
		0x55, 0x90, 0x27, 0x73, 0x1c, 0xf0, 0xef, 0x37, 0x25, 0x41, 0x45, 0x3b, 0x2b, 0xa6, 0xd4, 0xda,
		0xd8, 0x6d, 0xed, 0x6e, 0xef, 0x6c, 0xec, 0x6e, 0xad, 0x90, 0x4d, 0x3d, 0xab, 0xc7, 0x28, 0x67,
		0xcf, 0x2a, 0xec, 0x79, 0x82, 0x09, 0x3d, 0xea, 0x5f, 0xb7, 0xfc, 0xa0, 0xdb, 0x4d, 0xc3, 0x2c,
		0x13, 0x4c, 0xeb, 0xcd, 0x57, 0x02, 0x63, 0x1d, 0x07, 0x79, 0x1e, 0xa6, 0xb1, 0x58, 0x66, 0xf7,
		0x9e, 0x3f, 0xff, 0xbc, 0xee, 0xef, 0x9e, 0x7d, 0xff, 0xdc, 0xf4, 0x77, 0xcf, 0xc6, 0x2f, 0x9b,
		0xa3, 0x6f, 0xe3, 0xd7, 0x1b, 0x9f, 0xd7, 0xfd, 0xd6, 0xf4, 0xf5, 0xd6, 0xe7, 0x75, 0x7f, 0xeb,
		0xec, 0xc5, 0xef, 0xbf, 0xff, 0xf2, 0xe2, 0xef, 0xcd, 0x9b, 0xa7, 0xff, 0xa1, 0xe7, 0xde, 0x85,
		0x24, 0x1e, 0xd1, 0xd1, 0xe9, 0xc1, 0x7f, 0xc4, 0x9f, 0xd3, 0x7f, 0x25, 0x1f, 0xd4, 0xbf, 0xbc,
		0xaa, 0x07, 0x3b, 0xf4, 0x4a, 0x39, 0x06, 0xa0, 0xb4, 0x35, 0xfa, 0x4e, 0x7d, 0xb3, 0x6e, 0x67,
		0xd9, 0x4f, 0x86, 0x1f, 0xef, 0x64, 0xfa, 0xe9, 0x38, 0xcb, 0x5e, 0x16, 0xaa, 0xe1, 0x2c, 0x3b,
		0x7b, 0x5e, 0x7e, 0xf4, 0x34, 0xd9, 0xf3, 0x52, 0xbb, 0x4c, 0xc8, 0x9e, 0x97, 0xe5, 0x96, 0x8f,
		0x3d, 0x2f, 0xda, 0x81, 0x55, 0x2e, 0xc0, 0x4a, 0x05, 0x5a, 0xf1, 0x80, 0x2b, 0x1e, 0x78, 0x45,
		0x03, 0xb0, 0x5b, 0x52, 0xc6, 0x9e, 0x97, 0x27, 0xe0, 0x40, 0xf6, 0xbc, 0xb0, 0xe7, 0x85, 0x84,
		0x45, 0xc2, 0x22, 0x61, 0x91, 0xb0, 0x96, 0x88, 0x66, 0xec, 0x79, 0xf9, 0x99, 0x2f, 0xf6, 0xbc,
		0x2c, 0x37, 0x14, 0x7b, 0x5e, 0xaa, 0x03, 0x10, 0x1e, 0x1c, 0x96, 0x3d, 0x2f, 0x6e, 0x4d, 0x89,
		0x3d, 0x2f, 0xab, 0x61, 0x53, 0xec, 0x79, 0xd1, 0xf7, 0x3c, 0xf6, 0xbc, 0x94, 0x43, 0xf5, 0xd8,
		0xf3, 0xb2, 0x94, 0x0b, 0xb1, 0xe7, 0x85, 0x3d, 0x2f, 0xec, 0x79, 0x61, 0xcf, 0x8b, 0xa1, 0x3d,
		0x2f, 0xf5, 0x92, 0xbe, 0xbc, 0xb3, 0xe5, 0x05, 0xe9, 0x4b, 0x6d, 0x9b, 0xb7, 0x64, 0xeb, 0x95,
		0x97, 0xbe, 0x9c, 0xb7, 0xee, 0x3a, 0x49, 0xa0, 0x95, 0xbb, 0x63, 0xcb, 0xc9, 0x4e, 0x2d, 0x67,
		0x72, 0x67, 0x1b, 0xc8, 0x9d, 0x95, 0x49, 0x87, 0x90, 0x3b, 0xab, 0x4c, 0xce, 0x29, 0x5d, 0xee,
		0x2c, 0x18, 0xe4, 0x5f, 0xfc, 0x7e, 0x90, 0x65, 0x13, 0x13, 0x70, 0xb4, 0x01, 0x74, 0x7e, 0x18,
		0x37, 0x1b, 0x41, 0xd7, 0x11, 0x3f, 0x63, 0x23, 0xa8, 0xa1, 0xb0, 0x24, 0x12, 0x9e, 0xaa, 0x41,
		0x0f, 0x9d, 0xb5, 0x6f, 0xe7, 0x36, 0xa1, 0x44, 0xf1, 0xa5, 0xab, 0x18, 0x33, 0x5f, 0x37, 0x5c,
		0x81, 0x03, 0x01, 0xdd, 0x30, 0xeb, 0xa4, 0x51, 0xdf, 0x09, 0xa3, 0x2f, 0x1e, 0xda, 0xed, 0x41,
		0xc8, 0x09, 0xe4, 0x04, 0x72, 0x02, 0x39, 0xa1, 0x54, 0x2e, 0x9b, 0x46, 0xf1, 0x25, 0x99, 0x60,
		0xb9, 0xcf, 0xda, 0x4b, 0x3a, 0x41, 0xcf, 0x0f, 0x32, 0x77, 0x69, 0xa0, 0x18, 0x81, 0x1c, 0x40,
		0x0e, 0x20, 0x07, 0x90, 0x03, 0xca, 0x2c, 0x3c, 0x64, 0x7e, 0x3c, 0xb8, 0x3a, 0x0f, 0x53, 0x87,
		0x69, 0xc0, 0xc1, 0xfe, 0x40, 0xc7, 0xfb, 0x01, 0x1d, 0xee, 0xa3, 0x95, 0xd8, 0xef, 0x27, 0xb4,
		0x29, 0x4b, 0x6a, 0x3f, 0x9f, 0xe4, 0x5e, 0x2b, 0x87, 0xbb, 0x86, 0x44, 0xf6, 0xe7, 0x49, 0x3f,
		0x7a, 0xa9, 0xfd, 0x77, 0xa2, 0x36, 0x50, 0x91, 0x2d, 0x0f, 0x67, 0x2b, 0x80, 0xae, 0x47, 0xbd,
		0x57, 0x97, 0xe0, 0x7a, 0x3a, 0x00, 0xd8, 0x1a, 0x6c, 0x0d, 0xb6, 0x06, 0x5b, 0x83, 0xad, 0xc1,
		0xd6, 0x60, 0x6b, 0xb0, 0x35, 0xd8, 0x1a, 0x6c, 0xbd, 0x0a, 0xd8, 0xda, 0xc1, 0xed, 0xd0, 0xf7,
		0x63, 0xec, 0xd2, 0x6f, 0x89, 0x06, 0x6b, 0x83, 0xb5, 0xc1, 0xda, 0x60, 0x6d, 0x7a, 0x99, 0xe5,
		0x66, 0x84, 0xdc, 0xc5, 0xc3, 0x9a, 0xcf, 0x05, 0x0e, 0x64, 0x23, 0xc8, 0x02, 0x64, 0x01, 0xb2,
		0xc0, 0x8a, 0x67, 0x01, 0x57, 0xc1, 0x65, 0x2e, 0x11, 0xb4, 0x1c, 0xbc, 0xf7, 0x7e, 0x3c, 0xb8,
		0x1a, 0x2e, 0xcd, 0xcd, 0x0a, 0x24, 0x99, 0x34, 0xbc, 0x4a, 0xae, 0x43, 0xbf, 0x9f, 0x46, 0xd7,
		0x41, 0x1e, 0x3a, 0x2d, 0xee, 0x2f, 0x0e, 0x45, 0xd2, 0x21, 0xe9, 0x90, 0x74, 0x48, 0x3a, 0x2e,
		0x83, 0x8c, 0x9f, 0xb8, 0xd8, 0xb2, 0x3d, 0x97, 0x83, 0x1c, 0x54, 0x04, 0xbd, 0x83, 0x6e, 0x18,
		0xe7, 0x51, 0xfe, 0xed, 0x4d, 0x90, 0x85, 0xee, 0x55, 0x31, 0x4f, 0xf6, 0xdf, 0x1d, 0x7d, 0xda,
		0x6f, 0x1f, 0x9f, 0x1c, 0x7c, 0xda, 0xfb, 0xb0, 0xdf, 0xde, 0x3b, 0x6d, 0x1f, 0x1d, 0x7f, 0x38,
		0x38, 0x7a, 0xef, 0xca, 0xe5, 0x46, 0x45, 0xd5, 0xcc, 0xa9, 0x7e, 0x85, 0xe3, 0xea, 0xf3, 0x74,
		0xe5, 0x6e, 0x2d, 0xd9, 0x64, 0x11, 0xf7, 0x0e, 0x0f, 0xbd, 0x2a, 0x56, 0xed, 0x35, 0x16, 0xec,
		0xf8, 0x70, 0xef, 0x57, 0xd7, 0x2b, 0xe6, 0xe4, 0x9d, 0xcf, 0xac, 0x07, 0x6e, 0x9b, 0x60, 0x73,
		0x74, 0x60, 0xff, 0xa2, 0x17, 0xf4, 0xfd, 0x6e, 0x70, 0xd5, 0x8f, 0xe2, 0x4b, 0x87, 0x68, 0x73,
		0x71, 0xac, 0xb2, 0x2f, 0x0c, 0x70, 0xab, 0x78, 0x0f, 0x9c, 0x05, 0xce, 0x02, 0x67, 0x57, 0x1c,
		0xce, 0xba, 0x53, 0xa4, 0x77, 0xa4, 0x44, 0x6f, 0xf4, 0xc6, 0xa8, 0x30, 0xee, 0xfa, 0x9d, 0xe4,
		0xea, 0x6a, 0x10, 0x47, 0xf9, 0x37, 0x87, 0x57, 0x47, 0xcd, 0x8f, 0xe3, 0x2e, 0xe1, 0xbc, 0x3f,
		0x7a, 0xbf, 0x4f, 0xbe, 0x21, 0xdf, 0x90, 0x6f, 0xc8, 0x37, 0x65, 0xda, 0x7b, 0x11, 0xbb, 0x28,
		0xdc, 0x1b, 0x4f, 0x69, 0x79, 0x92, 0x07, 0x3d, 0xbf, 0x1f, 0xe4, 0x5f, 0x1c, 0x96, 0xec, 0x6f,
		0x0f, 0x42, 0xb6, 0x21, 0xdb, 0x90, 0x6d, 0xc8, 0x36, 0x25, 0xda, 0xbb, 0xb3, 0xcb, 0x31, 0xd8,
		0x90, 0x7f, 0xcf, 0xc4, 0xd9, 0x90, 0xff, 0xf4, 0x71, 0xd8, 0x90, 0x6f, 0xf6, 0xd1, 0xb3, 0x21,
		0x5f, 0xef, 0x5d, 0xcf, 0x56, 0x07, 0x60, 0x8f, 0xd0, 0x4c, 0xe8, 0x1e, 0x63, 0x4f, 0xc7, 0x01,
		0x66, 0x03, 0xb3, 0x81, 0xd9, 0xc0, 0x6c, 0x60, 0x36, 0x30, 0x1b, 0x98, 0x0d, 0xcc, 0x06, 0x66,
		0x03, 0xb3, 0xcd, 0xc1, 0x6c, 0xae, 0x36, 0x71, 0x7c, 0xb5, 0x49, 0xd9, 0xd7, 0xf6, 0xe8, 0x5c,
		0x68, 0x52, 0xe2, 0xfd, 0x3c, 0x36, 0xee, 0x31, 0xc9, 0xa3, 0xab, 0x30, 0xcd, 0xca, 0xbf, 0xc8,
		0x64, 0xf2, 0xbe, 0xc6, 0x6f, 0x32, 0x59, 0xe7, 0x26, 0x93, 0x0a, 0x71, 0x39, 0x6e, 0x32, 0x31,
		0x7c, 0x93, 0x49, 0x67, 0xea, 0x53, 0x8e, 0x8a, 0x4a, 0x93, 0xf7, 0x77, 0x53, 0x4c, 0x6a, 0x52,
		0x4c, 0xa2, 0x98, 0x44, 0x31, 0xc9, 0x62, 0x31, 0xa9, 0xec, 0x40, 0x75, 0x3b, 0x60, 0xc5, 0x61,
		0x27, 0xf7, 0xd3, 0x30, 0x4f, 0xbf, 0xb9, 0x3f, 0x90, 0x34, 0x3f, 0x9c, 0x23, 0x73, 0xb9, 0xb5,
		0x9f, 0x72, 0x73, 0xdd, 0xd5, 0x20, 0x6e, 0xe9, 0xba, 0xb3, 0xd8, 0x29, 0x11, 0x43, 0xe5, 0x62,
		0xa9, 0x54, 0x4c, 0x15, 0x8f, 0xad, 0xe2, 0x31, 0x56, 0x34, 0xd6, 0x3a, 0xae, 0xd7, 0x38, 0xf2,
		0x18, 0x67, 0x05, 0xfd, 0x05, 0x7f, 0xe9, 0x86, 0x9d, 0xe8, 0x2a, 0xe8, 0x6d, 0xb7, 0x5c, 0xba,
		0xcc, 0x14, 0xf4, 0x6d, 0x38, 0x1c, 0x63, 0xa1, 0xf6, 0xe7, 0x72, 0x30, 0xb7, 0x9d, 0x85, 0xe9,
		0xd7, 0xdf, 0xee, 0xef, 0x82, 0x97, 0xe8, 0x34, 0xdc, 0x35, 0x83, 0x8d, 0x97, 0x32, 0xc3, 0x09,
		0x75, 0x1e, 0x1e, 0xb6, 0xc0, 0x75, 0xe7, 0xe3, 0xde, 0xbc, 0x14, 0x30, 0x11, 0x81, 0x8e, 0xc4,
		0x5d, 0x13, 0xd9, 0xc4, 0x44, 0x6c, 0x27, 0x3e, 0xf7, 0xef, 0x7e, 0x56, 0x91, 0x06, 0x8b, 0x03,
		0x17, 0xf4, 0xbe, 0x24, 0xbd, 0xae, 0x9f, 0x47, 0x57, 0x02, 0xb2, 0x0d, 0xb3, 0xa1, 0xdc, 0x33,
		0xa4, 0x5d, 0x18, 0x12, 0x0c, 0x09, 0x86, 0x04, 0x43, 0x82, 0x21, 0xc1, 0x90, 0x60, 0x48, 0x30,
		0x24, 0x18, 0x12, 0x0c, 0x09, 0x86, 0x04, 0x43, 0x7a, 0xba, 0x99, 0xfc, 0x19, 0x86, 0xfd, 0xa0,
		0x17, 0x5d, 0x87, 0x7e, 0x14, 0xe7, 0x61, 0x7a, 0x1d, 0xf4, 0xdc, 0x53, 0xa5, 0x7b, 0xc6, 0xa4,
		0xab, 0x04, 0x67, 0x82, 0x33, 0xc1, 0x99, 0xe0, 0x4c, 0x70, 0x26, 0x38, 0x13, 0x9c, 0x09, 0xce,
		0x04, 0x67, 0x82, 0x33, 0xc1, 0x99, 0x4c, 0x72, 0xa6, 0xab, 0x28, 0x8e, 0xae, 0x06, 0x57, 0x7e,
		0xd0, 0xbd, 0x0e, 0xd3, 0x3c, 0xca, 0xc2, 0x21, 0x4a, 0x12, 0xe4, 0x4f, 0x3f, 0x18, 0x1f, 0x2e,
		0x05, 0x97, 0x82, 0x4b, 0xc1, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0x05,
		0x97, 0x82, 0x4b, 0xc1, 0xa5, 0x8c, 0xbd, 0x63, 0xd9, 0xc7, 0xad, 0x1c, 0x49, 0x0f, 0x14, 0xef,
		0xaf, 0x29, 0x41, 0x30, 0x3e, 0x93, 0xde, 0x70, 0x72, 0x92, 0x74, 0x4d, 0x4d, 0x92, 0xe0, 0xc3,
		0xe8, 0x53, 0xb5, 0x27, 0xa4, 0x6c, 0x15, 0xae, 0x3e, 0x18, 0x69, 0x30, 0xb8, 0xbb, 0xf1, 0xa0,
		0x64, 0xa1, 0x8a, 0x35, 0x89, 0x73, 0xc6, 0x1b, 0x9c, 0x33, 0x96, 0x63, 0xdc, 0x9c, 0x33, 0xae,
		0x61, 0xe2, 0xe3, 0x9c, 0xf1, 0x53, 0x16, 0x8b, 0x2a, 0xa6, 0x6a, 0x0c, 0x95, 0x8b, 0xa5, 0x52,
		0x31, 0x55, 0x3c, 0xb6, 0x8a, 0xc7, 0x58, 0xd1, 0x58, 0xeb, 0x96, 0x6e, 0x51, 0xc5, 0x7c, 0x12,
		0xe8, 0xa3, 0x8a, 0xf9, 0xa4, 0x2f, 0xaa, 0x98, 0x94, 0xa8, 0x54, 0xe2, 0xcf, 0xbc, 0x89, 0x50,
		0xc5, 0xac, 0xb4, 0x89, 0x50, 0xc5, 0x74, 0x3a, 0x5f, 0xce, 0x19, 0x3f, 0x9a, 0x21, 0x71, 0xce,
		0x18, 0x86, 0x04, 0x43, 0x82, 0x21, 0xc1, 0x90, 0x60, 0x48, 0x30, 0x24, 0x18, 0x12, 0x0c, 0x09,
		0x86, 0x04, 0x43, 0x82, 0x21, 0xfd, 0x84, 0x99, 0x70, 0xce, 0x18, 0xce, 0x04, 0x67, 0x82, 0x33,
		0xc1, 0x99, 0xe0, 0x4c, 0x70, 0x26, 0x38, 0x13, 0x9c, 0x09, 0xce, 0x04, 0x67, 0x82, 0x33, 0xc1,
		0x99, 0x1e, 0x36, 0x13, 0xce, 0x19, 0xc3, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a,
		0x2e, 0x05, 0x97, 0x82, 0x4b, 0xc1, 0xa5, 0xe0, 0x52, 0x70, 0xa9, 0xda, 0x73, 0x29, 0xce, 0x19,
		0xeb, 0x9e, 0x33, 0x76, 0x71, 0x90, 0x74, 0x4d, 0xfb, 0x98, 0x71, 0x89, 0x17, 0xa0, 0x97, 0x6f,
		0xa8, 0xdc, 0xe2, 0x2f, 0x63, 0xda, 0x95, 0xbf, 0xc6, 0x7f, 0x6c, 0xcc, 0xb5, 0xba, 0xc7, 0x3f,
		0x0d, 0xe2, 0xac, 0x9f, 0xa4, 0xb9, 0x83, 0xab, 0xfc, 0x8b, 0xb7, 0xe6, 0x36, 0x7f, 0x7b, 0x65,
		0x20, 0x6e, 0xf3, 0x57, 0x29, 0xe3, 0x70, 0x9b, 0xff, 0x52, 0x6e, 0xc0, 0x6d, 0xfe, 0xa8, 0x6c,
		0x68, 0x07, 0x20, 0xb1, 0x40, 0x24, 0x12, 0x90, 0xaa, 0x41, 0xfb, 0x9c, 0xa9, 0x6c, 0xf4, 0x92,
		0x4e, 0xd0, 0xf3, 0x83, 0x6e, 0x37, 0x0d, 0xb3, 0xcc, 0x7d, 0x53, 0x6f, 0x7e, 0x38, 0xda, 0x6b,
		0xd2, 0xe1, 0x4d, 0x2e, 0xcc, 0x49, 0x85, 0x3b, 0xf1, 0xb0, 0x27, 0x1e, 0xfe, 0x44, 0xc3, 0xa0,
		0xdb, 0x3a, 0x60, 0xf5, 0xdb, 0x6b, 0x83, 0x38, 0x4a, 0x62, 0x89, 0xd6, 0xda, 0xae, 0xc3, 0x31,
		0x26, 0xcb, 0x55, 0xf9, 0x66, 0xd7, 0xf4, 0xa1, 0x44, 0x7d, 0xc7, 0x29, 0x45, 0xfa, 0x09, 0xc9,
		0x3e, 0x29, 0xb9, 0x27, 0x76, 0xcf, 0x93, 0xbb, 0x6e, 0x09, 0x3e, 0xbb, 0x85, 0x67, 0xf8, 0x4a,
		0x70, 0xcc, 0xe3, 0x20, 0xcf, 0xc3, 0x34, 0x16, 0x7b, 0x9c, 0xc5, 0xc0, 0xcf, 0x9f, 0x7f, 0x5e,
		0xf7, 0x77, 0xcf, 0xbe, 0x7f, 0x6e, 0xfa, 0xbb, 0x67, 0xe3, 0x97, 0xcd, 0xd1, 0xb7, 0xf1, 0xeb,
		0x8d, 0xcf, 0xeb, 0x7e, 0x6b, 0xfa, 0x7a, 0xeb, 0xf3, 0xba, 0xbf, 0x75, 0xf6, 0xe2, 0xf7, 0xdf,
		0x7f, 0x79, 0xf1, 0xf7, 0xe6, 0xcd, 0xd3, 0xff, 0xd0, 0x13, 0xfb, 0x68, 0x67, 0x92, 0x8f, 0xee,
		0xe8, 0xf4, 0xe0, 0x3f, 0x6a, 0xcf, 0xef, 0xbf, 0x92, 0x0f, 0xf0, 0x5f, 0x82, 0x4f, 0x50, 0x64,
		0xa4, 0x9b, 0x97, 0x35, 0x0e, 0x9e, 0xdb, 0x04, 0x4f, 0x91, 0xe0, 0x19, 0xf8, 0x17, 0x7b, 0xfe,
		0x6f, 0x67, 0x7f, 0x37, 0x5f, 0xb6, 0x6e, 0x5e, 0xbf, 0xf8, 0x7b, 0xe7, 0xe6, 0xee, 0x0f, 0xbf,
		0xdf, 0xf7, 0x6b, 0xcd, 0x97, 0x3b, 0x37, 0xaf, 0x1f, 0xf8, 0x97, 0xed, 0x9b, 0xd7, 0x8f, 0x7c,
		0x8f, 0xad, 0x9b, 0xe7, 0x0b, 0xbf, 0x3a, 0xfc, 0xf9, 0xc6, 0x43, 0x7f, 0xd0, 0x7a, 0xe0, 0x0f,
		0x36, 0x1f, 0xfa, 0x83, 0xcd, 0x07, 0xfe, 0xe0, 0xc1, 0x29, 0x6d, 0x3c, 0xf0, 0x07, 0x5b, 0x37,
		0xdf, 0x17, 0x7e, 0xff, 0xf9, 0xfd, 0xbf, 0xba, 0x7d, 0xf3, 0xe2, 0xfb, 0x43, 0xff, 0xb6, 0x73,
		0xf3, 0xfd, 0xf5, 0x0b, 0x52, 0x89, 0xbb, 0x54, 0x82, 0x39, 0xcb, 0x9b, 0x73, 0xfd, 0x12, 0xeb,
		0xb3, 0x6a, 0x7f, 0x0e, 0xc7, 0xc0, 0x40, 0x90, 0xff, 0x66, 0x79, 0x1a, 0xc5, 0x97, 0x92, 0xdc,
		0xf7, 0x15, 0x9b, 0xd0, 0x9c, 0xce, 0xd7, 0xc9, 0x81, 0x9e, 0x7c, 0xe0, 0x77, 0xa3, 0xac, 0x93,
		0x5c, 0x87, 0x12, 0x82, 0xda, 0xf3, 0xc3, 0xb9, 0x3f, 0xae, 0x73, 0x11, 0xf4, 0xb2, 0x90, 0x96,
		0xc2, 0x03, 0xa8, 0x83, 0x96, 0xc2, 0xcf, 0x3c, 0x75, 0x5a, 0x0a, 0xe6, 0xa3, 0x7a, 0xf5, 0x5b,
		0x0a, 0xe7, 0x49, 0xd2, 0x0b, 0x03, 0x91, 0xa6, 0x42, 0x73, 0x85, 0xd3, 0x5f, 0x3f, 0xc8, 0xb2,
		0xe8, 0x3a, 0xf4, 0xaf, 0x92, 0xae, 0x80, 0x50, 0xea, 0xdc, 0x68, 0x24, 0x3f, 0x92, 0x1f, 0xc9,
		0x8f, 0xe4, 0x47, 0xf2, 0x23, 0xf9, 0xe9, 0x24, 0xbf, 0xbc, 0xd3, 0xf7, 0xaf, 0x24, 0x36, 0x78,
		0x4d, 0x07, 0x22, 0x15, 0x91, 0x8a, 0x48, 0x45, 0xa4, 0xa2, 0x0a, 0xa5, 0xa2, 0x41, 0x14, 0xe7,
		0xcd, 0x6d, 0x81, 0x4c, 0xb4, 0x8d, 0x90, 0xc1, 0x8f, 0x3f, 0x88, 0x86, 0x90, 0xc1, 0x3a, 0xa7,
		0xd4, 0x8d, 0x87, 0x83, 0x79, 0x13, 0x51, 0x10, 0x32, 0x90, 0x36, 0x91, 0xed, 0xad, 0xad, 0xcd,
		0x2d, 0xc4, 0x0c, 0xac, 0xbd, 0x3b, 0x62, 0x06, 0xa5, 0xa0, 0x9e, 0x3a, 0x8b, 0x19, 0x4c, 0x4f,
		0xff, 0xd6, 0xee, 0xde, 0xf4, 0xe9, 0x07, 0xe3, 0xea, 0xf4, 0xb2, 0x90, 0x27, 0x57, 0xa7, 0x73,
		0xa8, 0xd3, 0x08, 0x05, 0xe6, 0x50, 0xa7, 0x5c, 0xfa, 0xe3, 0x50, 0xa7, 0x19, 0xfc, 0x4d, 0xe5,
		0xcf, 0x54, 0xb8, 0x13, 0x0f, 0x7b, 0xe2, 0xe1, 0x4f, 0x34, 0x0c, 0xba, 0xe5, 0x43, 0x1c, 0xea,
		0x7c, 0x34, 0x16, 0xe3, 0x50, 0xe7, 0xe3, 0x1f, 0x0a, 0x87, 0x3a, 0x2b, 0xf2, 0xc4, 0xee, 0x79,
		0x72, 0x1c, 0xea, 0x74, 0x3e, 0x30, 0x87, 0x3a, 0x97, 0x7e, 0x74, 0x1c, 0xea, 0x74, 0xf1, 0x04,
		0x39, 0xd4, 0xb9, 0x6c, 0xf0, 0xe4, 0x50, 0xa7, 0x4c, 0xf0, 0xe4, 0x14, 0x1c, 0x87, 0x3a, 0x6b,
		0x94, 0x4a, 0x30, 0x67, 0x0e, 0x75, 0x1a, 0x2d, 0x11, 0xc8, 0x7d, 0x0e, 0x0e, 0x75, 0x2e, 0x91,
		0xfa, 0x69, 0xc6, 0x3b, 0x9d, 0x2f, 0x87, 0x3a, 0x1f, 0x37, 0x18, 0xe7, 0x5a, 0x1e, 0x89, 0x3a,
		0x68, 0x29, 0xfc, 0xcc, 0x53, 0xa7, 0xa5, 0x60, 0x3e, 0xaa, 0x73, 0xae, 0xe5, 0x09, 0x69, 0x9b,
		0x43, 0x9d, 0x1c, 0xea, 0x24, 0xf9, 0x91, 0xfc, 0x48, 0x7e, 0x24, 0x3f, 0x92, 0xdf, 0x0a, 0x25,
		0x3f, 0x0e, 0x75, 0x92, 0x8a, 0x48, 0x45, 0xa4, 0x22, 0x52, 0xd1, 0xc3, 0xfe, 0xc2, 0xa1, 0xce,
		0x47, 0x7f, 0x71, 0xa8, 0x73, 0xa9, 0xe1, 0x38, 0xd4, 0x59, 0x8e, 0x89, 0x70, 0xa8, 0xb3, 0xf2,
		0x66, 0x42, 0x1f, 0xc9, 0x2d, 0x97, 0xe0, 0x50, 0xa7, 0xfa, 0xa1, 0xce, 0x9a, 0x5d, 0x52, 0x5d,
		0x9c, 0xe9, 0xe4, 0x9e, 0x6a, 0x6d, 0x43, 0xb7, 0x61, 0xe0, 0xd5, 0xbf, 0xaa, 0xba, 0xf8, 0x24,
		0x35, 0xba, 0xad, 0x7a, 0x90, 0x85, 0xfe, 0xd5, 0xa0, 0x97, 0x47, 0xfd, 0x5e, 0xe8, 0x0f, 0x2d,
		0x24, 0x2b, 0xff, 0xda, 0xea, 0x7b, 0xc6, 0xe0, 0xfe, 0x6a, 0x7b, 0x75, 0x1b, 0xee, 0xaf, 0x56,
		0xa9, 0xbb, 0x70, 0x7f, 0xf5, 0x52, 0x6e, 0xc0, 0xfd, 0xd5, 0x48, 0x1d, 0x68, 0x07, 0x20, 0xb1,
		0x40, 0x24, 0x12, 0x90, 0xaa, 0x41, 0x0a, 0x9d, 0x49, 0x1d, 0x84, 0x71, 0x70, 0xde, 0x0b, 0xbb,
		0xee, 0x7b, 0x60, 0xd3, 0x81, 0xd8, 0xf6, 0xa1, 0x11, 0x32, 0x25, 0x42, 0xa7, 0x5c, 0x08, 0x95,
		0x0a, 0xa5, 0xe2, 0x21, 0x55, 0x3c, 0xb4, 0x8a, 0x86, 0x58, 0xb7, 0x15, 0x48, 0xb6, 0x7d, 0x3c,
		0x01, 0xe9, 0x35, 0x29, 0xd5, 0xda, 0xad, 0x60, 0x99, 0xa8, 0x64, 0x2d, 0x96, 0x31, 0xea, 0x26,
		0xc4, 0xf7, 0x31, 0x0b, 0xdf, 0x4d, 0x3e, 0xe0, 0xf1, 0xf0, 0xf3, 0xad, 0x90, 0x1e, 0x5f, 0x38,
		0x8c, 0xef, 0xce, 0x48, 0x6a, 0x58, 0x7e, 0xd6, 0x87, 0xa2, 0x42, 0x51, 0xa1, 0xa8, 0xab, 0x49,
		0x51, 0x1d, 0xd5, 0xd4, 0x64, 0x6a, 0x6b, 0x8e, 0x03, 0x18, 0xc4, 0x11, 0xe2, 0x08, 0x71, 0xb4,
		0x49, 0x1c, 0x5d, 0x05, 0xc4, 0x62, 0x80, 0xa0, 0xd7, 0x4b, 0xfe, 0x9a, 0x81, 0xf4, 0x20, 0x73,
		0x6f, 0xcf, 0x53, 0x0f, 0x5d, 0x1c, 0xda, 0xb1, 0x99, 0x09, 0xd5, 0xf7, 0x84, 0xea, 0x7c, 0x62,
		0x61, 0x5b, 0x32, 0x7c, 0xcb, 0x87, 0x71, 0xe9, 0x70, 0xae, 0x16, 0xd6, 0xd5, 0xc2, 0xbb, 0x4a,
		0x98, 0x77, 0x1b, 0xee, 0x1d, 0x87, 0xfd, 0x62, 0xc5, 0x9c, 0xd7, 0x0d, 0x17, 0xfc, 0xcd, 0x7d,
		0xfd, 0x70, 0x01, 0xcd, 0x36, 0x2b, 0xba, 0x55, 0xd5, 0xe1, 0xc3, 0xf7, 0xae, 0x82, 0xaf, 0xd1,
		0xd5, 0xe0, 0xaa, 0xe4, 0xfd, 0x45, 0x3f, 0x7c, 0xfa, 0xf3, 0xc3, 0xca, 0xa5, 0xe3, 0x26, 0xa9,
		0x98, 0x54, 0x4c, 0x2a, 0x26, 0x15, 0x93, 0x8a, 0xe7, 0x8f, 0xcd, 0x6d, 0x6e, 0x08, 0x66, 0xe2,
		0x1d, 0x81, 0xa1, 0x64, 0x8e, 0xd1, 0x4d, 0xbf, 0x04, 0xb5, 0x63, 0x25, 0x8f, 0xd5, 0x09, 0xa7,
		0xb5, 0x85, 0x61, 0x85, 0x8f, 0xd9, 0x15, 0xe3, 0x2a, 0x9c, 0xa3, 0x12, 0x0a, 0x2f, 0xf3, 0xa6,
		0x24, 0x78, 0xfc, 0xce, 0x8a, 0x29, 0xb5, 0x36, 0x76, 0x5b, 0xbb, 0xdb, 0x3b, 0x1b, 0xbb, 0x5b,
		0x2b, 0x64, 0x53, 0xa8, 0x89, 0xea, 0x12, 0xb8, 0x4a, 0x95, 0x82, 0x1d, 0x6f, 0x14, 0x29, 0xc6,
		0x31, 0xb6, 0x61, 0x24, 0x1c, 0xfe, 0xba, 0xd3, 0xb6, 0xda, 0x9a, 0x9d, 0xdd, 0x23, 0xfb, 0xe7,
		0x97, 0x7d, 0x27, 0x5b, 0x48, 0xdc, 0x99, 0xfc, 0x8d, 0x93, 0xad, 0x3c, 0x2e, 0xae, 0x7a, 0x5c,
		0x00, 0xd8, 0xae, 0xce, 0x8f, 0xae, 0x49, 0xf6, 0x6a, 0x37, 0xe8, 0xd5, 0xda, 0xa9, 0x28, 0xd0,
		0xab, 0x5d, 0xe1, 0x04, 0x4d, 0xaf, 0xb6, 0xcc, 0xc5, 0xa4, 0x57, 0x6b, 0x3d, 0x7c, 0xcb, 0x87,
		0x71, 0xe9, 0x70, 0xae, 0x16, 0xd6, 0xd5, 0xc2, 0xbb, 0x4a, 0x98, 0x97, 0x61, 0xaa, 0xf4, 0x6a,
		0x4b, 0x40, 0xb3, 0xf4, 0x6a, 0x17, 0xd7, 0x86, 0x5e, 0x2d, 0xa9, 0x98, 0x54, 0x4c, 0x2a, 0x26,
		0x15, 0xaf, 0x6e, 0x2a, 0xa6, 0x57, 0xbb, 0xf4, 0x17, 0xbd, 0x5a, 0x27, 0xc3, 0xd2, 0xab, 0x75,
		0x6b, 0x4a, 0xf4, 0x6a, 0x57, 0xc3, 0xa6, 0xe8, 0xd5, 0xea, 0x12, 0x38, 0x7a, 0xb5, 0xf7, 0x8c,
		0x63, 0xb1, 0x57, 0xeb, 0xb2, 0xab, 0xb6, 0x66, 0xac, 0x55, 0xeb, 0x40, 0xa9, 0xd5, 0x9d, 0xc1,
		0xa3, 0x83, 0x61, 0xcc, 0x55, 0xea, 0xab, 0x82, 0xb1, 0x5f, 0x3a, 0x49, 0xb5, 0xa9, 0x81, 0x11,
		0x39, 0xd5, 0xc0, 0x88, 0xd0, 0xc0, 0x40, 0x03, 0xc3, 0x44, 0x31, 0x0c, 0x0d, 0x0c, 0xb9, 0x44,
		0x88, 0x06, 0x86, 0x42, 0x00, 0x73, 0x1e, 0xc8, 0x24, 0x02, 0x9a, 0x5c, 0x60, 0x93, 0x0a, 0x70,
		0xe2, 0x81, 0x4e, 0x3c, 0xe0, 0x89, 0x06, 0xbe, 0x6a, 0x92, 0x69, 0xe7, 0xfb, 0xaa, 0x68, 0xe0,
		0x56, 0xb1, 0x3c, 0x49, 0x03, 0xb7, 0x52, 0x21, 0x5c, 0x2d, 0x94, 0xab, 0x85, 0x74, 0x95, 0xd0,
		0xee, 0x36, 0xc4, 0x3b, 0x0e, 0xf5, 0xc5, 0x8a, 0xd1, 0xc0, 0x2d, 0x65, 0x28, 0x1a, 0xb8, 0xd5,
		0x4b, 0x6b, 0x0b, 0xc3, 0xd2, 0xc0, 0x75, 0x6b, 0x4a, 0x34, 0x70, 0x57, 0xc3, 0xa6, 0x68, 0xe0,
		0xaa, 0xce, 0x9f, 0x06, 0xee, 0x7d, 0xe3, 0x18, 0xeb, 0x4a, 0x45, 0xab, 0x74, 0xd8, 0xf6, 0x80,
		0xc3, 0xb6, 0x1c, 0xb6, 0x7d, 0x5a, 0xa5, 0x81, 0xc3, 0xb6, 0x86, 0x2a, 0x0a, 0x14, 0x85, 0x57,
		0x38, 0x41, 0x53, 0x14, 0x2e, 0x63, 0x11, 0x29, 0x0a, 0x5b, 0x0e, 0xd9, 0xf2, 0xa1, 0x5b, 0x3a,
		0x84, 0xab, 0x85, 0x72, 0xb5, 0x90, 0xae, 0x12, 0xda, 0x65, 0xd8, 0x29, 0x45, 0xe1, 0xa5, 0xa3,
		0x23, 0x45, 0xe1, 0x25, 0x3e, 0x18, 0x45, 0x61, 0xf7, 0xe3, 0x52, 0x14, 0xae, 0xad, 0x29, 0x51,
		0x14, 0xae, 0xee, 0x28, 0x14, 0x85, 0x25, 0x38, 0xe7, 0x2a, 0x17, 0x85, 0x57, 0xe4, 0x54, 0xcf,
		0x01, 0xa7, 0x7a, 0xaa, 0xe4, 0x32, 0x16, 0x5d, 0xa5, 0xbe, 0xa7, 0x7a, 0x0e, 0x56, 0xe4, 0x54,
		0x8f, 0x9b, 0x8e, 0x88, 0xd3, 0x4e, 0x88, 0xf3, 0x73, 0x3d, 0x1b, 0x9c, 0xeb, 0x91, 0x2b, 0x8f,
		0x71, 0xae, 0xa7, 0x86, 0xa9, 0xd0, 0xd9, 0xb9, 0x9e, 0x30, 0x0e, 0xce, 0x7b, 0x61, 0xd7, 0x7d,
		0x0b, 0x77, 0x3a, 0x90, 0xab, 0x96, 0x8e, 0x8c, 0xe4, 0xa7, 0x63, 0x9e, 0xcd, 0x09, 0x22, 0x53,
		0xa1, 0x54, 0x3c, 0xa4, 0x8a, 0x87, 0x56, 0xd1, 0x10, 0x5b, 0x4d, 0xe2, 0xee, 0xbc, 0x73, 0x20,
		0x28, 0xc9, 0xe9, 0x58, 0x8a, 0x13, 0x82, 0x5a, 0x6b, 0x82, 0xea, 0xaa, 0x8c, 0x63, 0x84, 0xa1,
		0x3a, 0xa8, 0xdc, 0x94, 0x48, 0x51, 0x9f, 0x19, 0x72, 0x00, 0x57, 0x86, 0x6f, 0xcc, 0xe0, 0xbd,
		0x52, 0xcb, 0x02, 0x06, 0x4c, 0xbc, 0x1c, 0xe3, 0x5e, 0xde, 0x14, 0x97, 0x7b, 0x87, 0x25, 0x8d,
		0x78, 0x08, 0xe6, 0x46, 0x40, 0xae, 0x78, 0xf4, 0xfe, 0xe8, 0xb1, 0x2c, 0xf9, 0xae, 0x87, 0x51,
		0x96, 0xef, 0xe5, 0x79, 0x39, 0x34, 0xcd, 0x7b, 0x17, 0xc5, 0xfb, 0xbd, 0x70, 0x08, 0xc8, 0xb2,
		0x72, 0xc8, 0x80, 0xf7, 0x2e, 0xf8, 0x7a, 0xeb, 0x1d, 0x9b, 0xaf, 0x5a, 0xad, 0xed, 0x9d, 0x56,
		0x6b, 0x7d, 0x67, 0x73, 0x67, 0x7d, 0x77, 0x6b, 0xab, 0xb9, 0xdd, 0x2c, 0xa1, 0x73, 0xe7, 0x1d,
		0xa5, 0xdd, 0x30, 0x0d, 0xbb, 0x6f, 0x86, 0x0b, 0x1c, 0x0f, 0x7a, 0x3d, 0xd5, 0xe7, 0x5c, 0x72,
		0x90, 0xd2, 0x0c, 0x4e, 0x25, 0x44, 0x22, 0x95, 0x08, 0xb4, 0x5c, 0xc0, 0xf9, 0xf9, 0x30, 0xf1,
		0x73, 0x7f, 0xf9, 0x93, 0x06, 0x57, 0x96, 0xa1, 0x89, 0x1b, 0xd8, 0x12, 0x56, 0x25, 0x68, 0x4d,
		0x3f, 0x67, 0x43, 0x4f, 0xb7, 0x80, 0x9f, 0x78, 0xfa, 0x5e, 0x1a, 0x9d, 0xff, 0xf4, 0x23, 0x2f,
		0x68, 0xdf, 0xf0, 0x4d, 0x7e, 0xd2, 0xf2, 0x96, 0x2b, 0xdc, 0x2f, 0x5d, 0xa0, 0x2f, 0xa3, 0x9a,
		0x74, 0xbb, 0x5a, 0x94, 0x46, 0xe7, 0x4b, 0x56, 0x8c, 0xca, 0xaa, 0x08, 0x95, 0x5e, 0xf1, 0x29,
		0xbd, 0xa2, 0x73, 0xb7, 0x62, 0x33, 0x5d, 0xbb, 0x8a, 0xc4, 0xcc, 0x65, 0x0b, 0xda, 0x5e, 0x70,
		0x11, 0xf9, 0x59, 0x70, 0x11, 0x2d, 0xbf, 0xbd, 0x7e, 0x76, 0x4f, 0x55, 0xf1, 0x96, 0xcb, 0x22,
		0xcc, 0x52, 0xfa, 0x69, 0xa5, 0xf5, 0xcf, 0xca, 0x2c, 0xfa, 0x96, 0xeb, 0xae, 0xae, 0x0a, 0xb9,
		0xce, 0x0a, 0xb6, 0xce, 0x0a, 0xb3, 0xa5, 0xbb, 0xb3, 0x0d, 0xae, 0x55, 0x56, 0xdf, 0xaa, 0xf0,
		0xcd, 0xf2, 0x4c, 0xe4, 0xae, 0xd7, 0x97, 0x65, 0x21, 0xe5, 0x36, 0xd3, 0x4b, 0xef, 0x08, 0xb9,
		0xe8, 0x00, 0xb9, 0x09, 0x0a, 0xae, 0x82, 0x83, 0xf3, 0x20, 0xe1, 0x3c, 0x58, 0x38, 0x0f, 0x1a,
		0x36, 0xab, 0x8e, 0x65, 0x37, 0xc1, 0x0b, 0xd7, 0xf7, 0x27, 0x3c, 0xc6, 0xd1, 0x9e, 0x9d, 0xf9,
		0x61, 0xdc, 0xec, 0xdd, 0x59, 0x47, 0x93, 0xd7, 0x71, 0x18, 0x72, 0x1d, 0x8e, 0xc4, 0xc2, 0x92,
		0x58, 0x78, 0x12, 0x0b, 0x53, 0xe5, 0x86, 0xab, 0x92, 0xc3, 0x56, 0xb1, 0x0a, 0xce, 0x1a, 0xc9,
		0x85, 0xdd, 0xf7, 0xc2, 0xe0, 0x22, 0x0d, 0x2f, 0x5c, 0x18, 0xfd, 0x14, 0xd5, 0x38, 0x38, 0x64,
		0xe6, 0x1d, 0x4f, 0x2a, 0x5e, 0xbf, 0xfc, 0x32, 0x6e, 0x31, 0x36, 0xe6, 0x03, 0xe6, 0x2a, 0x48,
		0xc1, 0xf7, 0xaf, 0x5b, 0x7e, 0x96, 0xe6, 0xa1, 0xdf, 0x4f, 0x7a, 0x51, 0xe7, 0x9b, 0x43, 0x59,
		0xf8, 0xbb, 0x23, 0x21, 0x11, 0x4f, 0x3a, 0x22, 0x1d, 0xb1, 0xa5, 0xb4, 0xbc, 0x37, 0xee, 0x8d,
		0xd7, 0xd4, 0xfd, 0x96, 0xd2, 0xe9, 0x40, 0x88, 0xc5, 0x4b, 0x87, 0x36, 0xd9, 0x10, 0x27, 0x15,
		0xea, 0xc4, 0x43, 0x9e, 0x78, 0xe8, 0x13, 0x0f, 0x81, 0x6e, 0x42, 0xa1, 0xa3, 0x90, 0xe8, 0x3c,
		0x34, 0x16, 0x03, 0xa4, 0xc9, 0x20, 0x0f, 0x05, 0x85, 0x81, 0x26, 0xe3, 0xc9, 0xa8, 0xf4, 0x34,
		0x51, 0xe9, 0x31, 0x1e, 0x48, 0xa5, 0x03, 0xaa, 0x5a, 0x60, 0x55, 0x0b, 0xb0, 0x6a, 0x81, 0xd6,
		0x6d, 0xc0, 0x75, 0x1c, 0x78, 0xc5, 0x02, 0xf0, 0x7c, 0x20, 0x96, 0xb3, 0xff, 0xb9, 0x78, 0x2c,
		0x65, 0xfb, 0x32, 0x61, 0x59, 0x3c, 0x3c, 0x6b, 0x84, 0x69, 0xdd, 0x70, 0xad, 0x15, 0xb6, 0xd5,
		0xc3, 0xb7, 0x7a, 0x18, 0x57, 0x0f, 0xe7, 0x32, 0x61, 0x5d, 0x28, 0xbc, 0x8b, 0x87, 0xf9, 0x62,
		0xc0, 0x4e, 0xd2, 0x4b, 0x52, 0x79, 0xbf, 0x99, 0x5d, 0x6e, 0x37, 0x1c, 0xfe, 0xe5, 0x4a, 0x28,
		0x43, 0x49, 0xa7, 0x01, 0xcd, 0x74, 0x60, 0x23, 0x2d, 0x68, 0xa7, 0x07, 0x33, 0x69, 0xc2, 0x4c,
		0xba, 0x30, 0x93, 0x36, 0x64, 0xd3, 0x87, 0x70, 0x1a, 0x29, 0x56, 0x59, 0x4c, 0xe3, 0xf3, 0x41,
		0xbf, 0x77, 0xd7, 0x80, 0x7d, 0x34, 0xca, 0xdf, 0x51, 0x18, 0x7b, 0xa1, 0x81, 0x3b, 0x4e, 0x74,
		0xcf, 0xea, 0x69, 0xda, 0x92, 0x5a, 0x92, 0x61, 0xdc, 0xed, 0x27, 0xd1, 0x28, 0x70, 0x28, 0x61,
		0x96, 0x62, 0x06, 0xc0, 0x16, 0x60, 0x0b, 0xb0, 0x05, 0xd8, 0x02, 0x6c, 0x01, 0xb6, 0xd4, 0x14,
		0xb6, 0x14, 0xb9, 0x0e, 0xe4, 0xb2, 0xf4, 0xe2, 0xf6, 0x83, 0xfc, 0x8b, 0x1f, 0x75, 0xf5, 0x80,
		0xcb, 0x74, 0x02, 0xe0, 0x16, 0x70, 0x0b, 0xb8, 0x05, 0xdc, 0x02, 0x6e, 0x01, 0xb7, 0xd4, 0x14,
		0xb7, 0x4c, 0x53, 0x1d, 0xb0, 0x65, 0xe9, 0xb5, 0x75, 0x7b, 0xa1, 0xe5, 0x0f, 0x2d, 0xda, 0xb5,
		0x52, 0xfe, 0x3f, 0xda, 0x32, 0x90, 0x05, 0xc8, 0x02, 0x64, 0x01, 0xb2, 0xd4, 0x17, 0xb2, 0x48,
		0x6f, 0x38, 0x28, 0x06, 0x0e, 0xf2, 0x3c, 0xf5, 0xa3, 0xb8, 0x1b, 0x7e, 0xd5, 0x73, 0xba, 0xe2,
		0x38, 0xf2, 0x6c, 0x2e, 0x4a, 0xc6, 0xae, 0xc3, 0x91, 0xd5, 0x13, 0x8f, 0x85, 0x04, 0x64, 0x2b,
		0x11, 0x59, 0x49, 0x48, 0xe6, 0x12, 0x93, 0xb9, 0x04, 0x65, 0x2e, 0x51, 0xe9, 0x24, 0x2c, 0xa5,
		0xc4, 0xa5, 0xcf, 0xb9, 0x0d, 0x71, 0x6f, 0x0b, 0x1c, 0xfc, 0x3e, 0x2e, 0x7e, 0xef, 0xff, 0x46,
		0xc9, 0x36, 0x0b, 0xf3, 0xac, 0x78, 0x35, 0xe1, 0xec, 0xe3, 0x04, 0xfc, 0x6c, 0x35, 0x5c, 0x46,
		0xc1, 0x5d, 0x94, 0xf6, 0x7a, 0x2e, 0xf8, 0x89, 0xc6, 0x9e, 0x4f, 0x80, 0x16, 0x40, 0x0b, 0xa0,
		0x05, 0xd0, 0x02, 0x68, 0xd5, 0x00, 0x68, 0x89, 0xdd, 0x23, 0xff, 0xa3, 0x2c, 0xa2, 0x09, 0xb3,
		0x64, 0xef, 0x9d, 0x7f, 0xe8, 0x4b, 0x37, 0x66, 0xae, 0x69, 0xdd, 0x53, 0x6f, 0x14, 0x5e, 0x2c,
		0x4c, 0x47, 0xe9, 0x5e, 0xfb, 0x07, 0xe7, 0xa3, 0x78, 0x37, 0xb9, 0xb1, 0x70, 0x3a, 0x6f, 0xc2,
		0xc1, 0x57, 0x4c, 0xf8, 0x07, 0x26, 0xac, 0x75, 0x9f, 0x7e, 0xa5, 0x6c, 0xf9, 0xd9, 0x6a, 0x8e,
		0x7e, 0x46, 0xd1, 0xc0, 0x61, 0xd1, 0xe0, 0xea, 0x6a, 0x10, 0x47, 0xf9, 0x37, 0x2b, 0xcd, 0x9a,
		0xbb, 0x13, 0xa2, 0x90, 0x40, 0x21, 0x81, 0x42, 0x02, 0x85, 0x04, 0x0a, 0x09, 0x14, 0x12, 0x9e,
		0x18, 0x37, 0xe8, 0xd8, 0xac, 0x3d, 0xa6, 0x63, 0x33, 0xcd, 0xb8, 0x51, 0x98, 0x15, 0xaf, 0xbf,
		0xd1, 0xb4, 0x91, 0x79, 0x38, 0x6a, 0xe7, 0x5d, 0x17, 0xbc, 0x45, 0xe9, 0xdc, 0x2b, 0x88, 0x0b,
		0xc4, 0x05, 0xe2, 0x02, 0x71, 0x81, 0xb8, 0x6a, 0x80, 0xb8, 0xa2, 0xbe, 0x1f, 0x74, 0xbb, 0x69,
		0x98, 0x65, 0x16, 0x40, 0xd7, 0xae, 0xe2, 0x1c, 0x26, 0xcf, 0x64, 0xe5, 0xdb, 0x37, 0x73, 0xd7,
		0x30, 0xe8, 0xdb, 0xc6, 0x82, 0x8d, 0xbc, 0x32, 0x30, 0x97, 0xe3, 0x20, 0xcf, 0xc3, 0x34, 0x56,
		0x37, 0x97, 0x62, 0x42, 0xcf, 0x9f, 0x7f, 0x5e, 0xf7, 0x77, 0xcf, 0xbe, 0x7f, 0x6e, 0xfa, 0xbb,
		0x67, 0xe3, 0x97, 0xcd, 0xd1, 0xb7, 0xf1, 0xeb, 0x8d, 0xcf, 0xeb, 0x7e, 0x6b, 0xfa, 0x7a, 0xeb,
		0xf3, 0xba, 0xbf, 0x75, 0xf6, 0xe2, 0xf7, 0xdf, 0x7f, 0x79, 0xf1, 0xf7, 0xe6, 0xcd, 0xd3, 0xff,
		0xd0, 0x53, 0xff, 0xc8, 0x67, 0x16, 0x4c, 0xe0, 0xe8, 0xf4, 0xe0, 0x3f, 0xe6, 0xec, 0xe0, 0xbf,
		0x92, 0x86, 0xf0, 0x2f, 0x03, 0x96, 0xa0, 0xdb, 0x60, 0x79, 0x49, 0xb2, 0x28, 0x92, 0xc5, 0x36,
		0xc9, 0xa2, 0x52, 0xc9, 0x22, 0xf0, 0x2f, 0xf6, 0xfc, 0xdf, 0xce, 0xfe, 0x6e, 0xbe, 0x6c, 0xdd,
		0xbc, 0x7e, 0xf1, 0xf7, 0xce, 0xcd, 0xdd, 0x1f, 0x7e, 0xbf, 0xef, 0xd7, 0x9a, 0x2f, 0x77, 0x6e,
		0x5e, 0x3f, 0xf0, 0x2f, 0xdb, 0x37, 0xaf, 0x1f, 0xf9, 0x1e, 0x5b, 0x37, 0xcf, 0x17, 0x7e, 0x75,
		0xf8, 0xf3, 0x8d, 0x87, 0xfe, 0xa0, 0xf5, 0xc0, 0x1f, 0x6c, 0x3e, 0xf4, 0x07, 0x9b, 0x0f, 0xfc,
		0xc1, 0x83, 0x53, 0xda, 0x78, 0xe0, 0x0f, 0xb6, 0x6e, 0xbe, 0x2f, 0xfc, 0xfe, 0xf3, 0xfb, 0x7f,
		0x75, 0xfb, 0xe6, 0xc5, 0xf7, 0x87, 0xfe, 0x6d, 0xe7, 0xe6, 0xfb, 0xeb, 0x17, 0xa4, 0x4e, 0xfb,
		0xa9, 0x13, 0xb7, 0x90, 0x77, 0x0b, 0x80, 0x04, 0x3b, 0x35, 0xea, 0x07, 0xd5, 0xbc, 0xf0, 0x6b,
		0xee, 0x9b, 0xdb, 0xad, 0x71, 0xdf, 0xa4, 0xe8, 0x1f, 0xe8, 0xe4, 0x41, 0xfa, 0x07, 0x77, 0x66,
		0x43, 0xff, 0xe0, 0x81, 0x09, 0xd1, 0x3f, 0x30, 0x99, 0x41, 0xe9, 0x1f, 0xb0, 0x63, 0x63, 0xed,
		0x31, 0x3b, 0x36, 0x6e, 0x67, 0xdd, 0x28, 0xcc, 0xe6, 0xfe, 0x9b, 0x9d, 0x1b, 0x42, 0x0f, 0x29,
		0x8a, 0xaf, 0x83, 0x5e, 0xd4, 0xf5, 0xd3, 0x30, 0xc8, 0x92, 0x58, 0x1f, 0x8a, 0xdd, 0x99, 0x0f,
		0x28, 0x0c, 0x14, 0x06, 0x0a, 0x03, 0x85, 0x81, 0xc2, 0x40, 0x61, 0x4f, 0xcd, 0x24, 0xdd, 0x30,
		0xce, 0xa3, 0xfc, 0x9b, 0x11, 0x24, 0xa6, 0x78, 0x22, 0xcc, 0x3b, 0x98, 0x2c, 0xc5, 0x9b, 0x20,
		0x33, 0x10, 0xc2, 0xa6, 0x0f, 0xe8, 0xe0, 0xfd, 0xa7, 0xbd, 0xc3, 0x83, 0xb7, 0xed, 0x93, 0xa3,
		0x8f, 0x1f, 0xf6, 0xdb, 0x27, 0xfb, 0x7b, 0xa7, 0x47, 0xef, 0xb5, 0xa3, 0xd9, 0xe8, 0x20, 0x5f,
		0x66, 0xa2, 0x00, 0x6f, 0xe4, 0xa4, 0xe5, 0xdd, 0xa7, 0xf5, 0xeb, 0xe1, 0xc7, 0xd3, 0x0f, 0xfb,
		0x27, 0xed, 0xc3, 0xa3, 0xa3, 0x63, 0x8f, 0x83, 0xb1, 0x66, 0x9f, 0xd3, 0xd1, 0xc9, 0xc1, 0xbf,
		0x0f, 0xde, 0xef, 0x7d, 0x38, 0x3a, 0xe1, 0x29, 0xd9, 0x7d, 0x4a, 0x7b, 0xa7, 0x38, 0x92, 0xf5,
		0x80, 0x77, 0xf4, 0xfe, 0xb7, 0xfd, 0xb7, 0xde, 0x8a, 0x9f, 0x9b, 0x3e, 0x5b, 0x35, 0xfc, 0xbc,
		0x12, 0xd5, 0x9f, 0x5e, 0x90, 0xe5, 0xfe, 0x55, 0xd2, 0x8d, 0x2e, 0xa2, 0xb0, 0xab, 0x5f, 0xfc,
		0x99, 0x9f, 0x0e, 0xb5, 0x1f, 0x6a, 0x3f, 0xd4, 0x7e, 0xa8, 0xfd, 0x50, 0xfb, 0xa1, 0xf6, 0xf3,
		0xc4, 0xb8, 0x91, 0x47, 0x57, 0x61, 0x1e, 0x75, 0xfe, 0xcc, 0xb6, 0x5b, 0x06, 0x6a, 0x3f, 0x8a,
		0x1b, 0x6e, 0xbd, 0x8f, 0xf1, 0x58, 0xf7, 0xc7, 0x8b, 0x83, 0x38, 0xc9, 0xc2, 0x4e, 0x12, 0x77,
		0x55, 0x4f, 0x35, 0xa1, 0x08, 0x37, 0x59, 0x08, 0x14, 0xe1, 0x1e, 0x9e, 0x0e, 0x8a, 0x70, 0x55,
		0xe0, 0xeb, 0x28, 0xc2, 0x3d, 0xc2, 0x84, 0x9b, 0xaf, 0x5a, 0xad, 0xed, 0x9d, 0x56, 0x6b, 0x7d,
		0x67, 0x73, 0x67, 0x7d, 0x77, 0x6b, 0xab, 0xb9, 0xdd, 0x44, 0x1b, 0xce, 0x68, 0x8d, 0x83, 0x1d,
		0xc7, 0x75, 0xac, 0x71, 0x68, 0xdd, 0x68, 0xbb, 0x00, 0x4a, 0x75, 0x6e, 0xb6, 0x2d, 0xa6, 0xf1,
		0x36, 0xbc, 0x08, 0x06, 0xbd, 0x11, 0x35, 0x5a, 0xa7, 0xb6, 0x42, 0x6d, 0x85, 0xda, 0x0a, 0xb5,
		0x15, 0x6a, 0x2b, 0xd4, 0x56, 0x9e, 0x1a, 0x37, 0x10, 0xb6, 0xa7, 0x8c, 0x41, 0x19, 0x83, 0x32,
		0x06, 0x65, 0x8c, 0x15, 0x32, 0x61, 0x84, 0xed, 0x29, 0x5e, 0x50, 0xbc, 0x90, 0x2f, 0x5e, 0x4c,
		0x0e, 0xc3, 0x24, 0x83, 0x3c, 0xd4, 0x2f, 0x60, 0xdc, 0x9e, 0x0c, 0x05, 0x04, 0x0a, 0x08, 0x14,
		0x10, 0x28, 0x20, 0x50, 0x40, 0xa0, 0x80, 0xf0, 0xc4, 0xb8, 0x71, 0x9e, 0x24, 0xbd, 0x30, 0x88,
		0x2d, 0x1c, 0xca, 0x69, 0xae, 0x0a, 0x74, 0x79, 0x56, 0x63, 0x13, 0xf7, 0xf6, 0xe2, 0x38, 0xc9,
		0x83, 0x21, 0x1b, 0x50, 0x31, 0x70, 0x2f, 0xeb, 0x7c, 0x09, 0xaf, 0x82, 0xfe, 0xe4, 0xb8, 0x7b,
		0x23, 0xe9, 0x87, 0x71, 0x67, 0x04, 0x14, 0xfc, 0x38, 0xcc, 0xff, 0x4a, 0xd2, 0x3f, 0xfd, 0x28,
		0xce, 0xf2, 0x20, 0xee, 0x84, 0x8d, 0xbb, 0x3f, 0xc8, 0x16, 0x7e, 0xd2, 0xe8, 0xa7, 0x49, 0x9e,
		0x74, 0x92, 0x5e, 0x56, 0xbc, 0x6a, 0x9c, 0x5f, 0xf6, 0x1b, 0x69, 0x74, 0xde, 0x08, 0x2e, 0x22,
		0x3f, 0x0b, 0x2e, 0xa2, 0xac, 0x78, 0xd5, 0x18, 0x29, 0xd2, 0x66, 0x69, 0x1e, 0xfa, 0xfd, 0xa4,
		0x17, 0x75, 0xbe, 0x35, 0x7a, 0xe3, 0xd0, 0xda, 0x18, 0xc1, 0xb4, 0x6c, 0xfc, 0x6d, 0x7c, 0x98,
		0x5e, 0xc1, 0xe1, 0xbc, 0x2c, 0x4f, 0x07, 0x9d, 0x3c, 0x9e, 0x78, 0xfe, 0x51, 0xb1, 0x32, 0xef,
		0xc7, 0x9f, 0xfa, 0x60, 0xf2, 0xa1, 0xdb, 0x77, 0xfe, 0x3b, 0xbb, 0xfb, 0x83, 0xf6, 0xf1, 0x74,
		0x55, 0x8a, 0x57, 0xed, 0x37, 0x97, 0xfd, 0xf6, 0x49, 0x74, 0xde, 0xde, 0xbb, 0x88, 0x4e, 0x87,
		0x8b, 0x32, 0x7d, 0xd1, 0x3e, 0xe8, 0x5f, 0xb7, 0x4e, 0xd3, 0x3c, 0x3c, 0x1e, 0xad, 0x48, 0xfb,
		0x30, 0xe9, 0x0c, 0x7f, 0xed, 0x64, 0xb4, 0x20, 0xe3, 0x6f, 0xed, 0xd3, 0xd1, 0x82, 0x3c, 0xab,
		0xa7, 0x0f, 0x0a, 0xfa, 0x9f, 0x37, 0x88, 0xff, 0x8c, 0x93, 0xbf, 0x62, 0x3f, 0xc8, 0xf3, 0x34,
		0x3a, 0x1f, 0xae, 0xb0, 0xb8, 0x0f, 0xce, 0x2a, 0xd3, 0x8b, 0x73, 0x11, 0x8e, 0x44, 0xd3, 0xbc,
		0x22, 0x3c, 0xac, 0x16, 0x2d, 0xd1, 0xa4, 0x23, 0x36, 0x68, 0x88, 0x36, 0xfd, 0x30, 0x43, 0x3b,
		0xcc, 0xd0, 0x0d, 0x33, 0x34, 0xa3, 0xde, 0x98, 0xeb, 0x6d, 0x94, 0xea, 0xb8, 0xfd, 0x42, 0x90,
		0xd7, 0xaf, 0x8b, 0x2d, 0x4e, 0x49, 0xb7, 0x3a, 0xd6, 0xa4, 0x3a, 0x46, 0x75, 0x8c, 0xea, 0x18,
		0xd5, 0x31, 0xaa, 0x63, 0xd6, 0xd3, 0x59, 0x31, 0x81, 0x61, 0xee, 0xf0, 0x73, 0xed, 0x1a, 0xdd,
		0x5c, 0x04, 0x9b, 0x4d, 0x49, 0xd9, 0x35, 0x6c, 0xf4, 0xc4, 0xd5, 0xd3, 0x9b, 0xa5, 0x34, 0x67,
		0x33, 0xdd, 0x59, 0x4b, 0x7b, 0x66, 0xd3, 0x9f, 0xd9, 0x34, 0x68, 0x36, 0x1d, 0xea, 0xa6, 0x45,
		0xe5, 0xf4, 0x58, 0x3c, 0x95, 0x0f, 0x16, 0x12, 0xd4, 0x9a, 0x2d, 0xad, 0xdd, 0x05, 0xf6, 0xb5,
		0x63, 0xe3, 0x7e, 0x9d, 0xa9, 0xf6, 0xee, 0x58, 0x48, 0x77, 0x96, 0xcc, 0x57, 0x74, 0x97, 0x92,
		0xa2, 0xeb, 0x78, 0xe3, 0xf6, 0x8b, 0x19, 0x60, 0xa7, 0xd5, 0x0d, 0x32, 0x54, 0xab, 0x00, 0xd4,
		0x01, 0xea, 0x00, 0x75, 0x80, 0x3a, 0x40, 0x9d, 0x7e, 0xed, 0x63, 0xbe, 0x06, 0xd2, 0x0b, 0x0d,
		0x1d, 0x28, 0x99, 0x2b, 0x85, 0x0c, 0x67, 0xf6, 0x92, 0x53, 0x02, 0x86, 0x93, 0xa8, 0xc5, 0x64,
		0x6a, 0x3b, 0xa9, 0x5a, 0x4d, 0xae, 0xe6, 0x93, 0xac, 0xf9, 0x64, 0x6b, 0x3e, 0xe9, 0xda, 0x48,
		0xbe, 0x46, 0x92, 0xb0, 0xbd, 0x0a, 0xcb, 0x42, 0xdc, 0x1a, 0x44, 0x71, 0xde, 0xdc, 0xb6, 0x14,
		0xb3, 0x26, 0x59, 0x70, 0xdb, 0xd0, 0x94, 0x6c, 0x9c, 0x0b, 0xbe, 0xfb, 0x65, 0x2b, 0xa6, 0xaf,
		0x59, 0x3b, 0x37, 0x6c, 0x1c, 0x5e, 0x2d, 0x4c, 0xcf, 0xd8, 0xb9, 0xe2, 0x85, 0xf9, 0x19, 0x3c,
		0x9b, 0x69, 0x34, 0xdc, 0xcf, 0xbb, 0x44, 0xf0, 0x15, 0x97, 0x58, 0xd2, 0x25, 0xb6, 0xb7, 0xb6,
		0x36, 0xb7, 0x70, 0x8b, 0x6a, 0x63, 0x31, 0x7b, 0xb3, 0x39, 0x7b, 0xc6, 0x7a, 0x18, 0x09, 0x9b,
		0x86, 0x76, 0xca, 0x2c, 0x40, 0x64, 0x2b, 0x3b, 0x66, 0x8c, 0x46, 0x6d, 0xea, 0x44, 0x4f, 0x31,
		0x26, 0xea, 0x44, 0x4f, 0xb2, 0x74, 0xea, 0x44, 0x4b, 0x4e, 0x90, 0x3a, 0x51, 0x85, 0x88, 0x83,
		0xf1, 0x3a, 0xd1, 0x2b, 0x83, 0x65, 0xa2, 0x2d, 0xca, 0x44, 0x3f, 0xf8, 0xa2, 0x4c, 0x54, 0x4b,
		0x4e, 0x4c, 0x99, 0xa8, 0xea, 0xd1, 0x7e, 0xde, 0x25, 0x28, 0x13, 0x2d, 0xed, 0x12, 0x1b, 0x5b,
		0x14, 0x89, 0x6a, 0x50, 0x96, 0x59, 0xa3, 0x48, 0x64, 0x70, 0x3d, 0xcc, 0x14, 0x89, 0xae, 0x27,
		0xde, 0x6e, 0xb1, 0x4a, 0x34, 0x9e, 0x1b, 0x65, 0xa2, 0xfb, 0xa6, 0x43, 0x99, 0xe8, 0x09, 0xd6,
		0x44, 0x99, 0xe8, 0x49, 0x96, 0x4e, 0x99, 0x68, 0xc9, 0x09, 0x52, 0x26, 0xaa, 0x10, 0x71, 0x30,
		0x5c, 0x26, 0x3a, 0x8f, 0xe2, 0x20, 0xfd, 0x66, 0xb0, 0x4e, 0xb4, 0x6b, 0x68, 0x4a, 0x87, 0x61,
		0x7c, 0x39, 0x3a, 0xc8, 0x45, 0xa1, 0xe8, 0x47, 0xac, 0x98, 0x42, 0xd1, 0xd2, 0xac, 0xb8, 0x09,
		0x27, 0xae, 0x78, 0xbc, 0x9f, 0x77, 0x09, 0x0a, 0x45, 0x4b, 0xbb, 0x04, 0xfb, 0x89, 0x6a, 0x52,
		0x9c, 0x59, 0xa3, 0x54, 0x64, 0x70, 0x3d, 0x2c, 0x94, 0x8a, 0xc2, 0xaf, 0x79, 0x18, 0x77, 0xc3,
		0xae, 0xbd, 0x42, 0x51, 0x31, 0x33, 0xca, 0x44, 0xf7, 0x4d, 0x87, 0x32, 0xd1, 0x13, 0x6c, 0x89,
		0x32, 0xd1, 0x93, 0x2c, 0x9d, 0x32, 0xd1, 0x92, 0x13, 0xa4, 0x4c, 0x54, 0x21, 0xda, 0x60, 0xb9,
		0x4c, 0xa4, 0x7e, 0x59, 0xc4, 0x43, 0x69, 0x50, 0xe9, 0xf2, 0x08, 0x40, 0xdc, 0x7d, 0xcf, 0x24,
		0xe9, 0x0f, 0x99, 0x50, 0xd0, 0xb3, 0x07, 0xe2, 0x8a, 0x99, 0x01, 0xe2, 0x00, 0x71, 0x80, 0x38,
		0x40, 0x1c, 0x20, 0x0e, 0x10, 0x07, 0x88, 0x03, 0xc4, 0x01, 0xe2, 0xee, 0x3e, 0x93, 0x7e, 0x90,
		0xe6, 0x91, 0x45, 0x0c, 0x37, 0x9d, 0x18, 0x10, 0x0e, 0x08, 0x07, 0x84, 0x03, 0xc2, 0x01, 0xe1,
		0x80, 0x70, 0x40, 0x38, 0x20, 0x1c, 0x10, 0xee, 0xee, 0x33, 0xc9, 0xd3, 0x20, 0xce, 0xa2, 0x3c,
		0xba, 0x36, 0xb8, 0xef, 0xfe, 0xd6, 0xdc, 0x00, 0x72, 0x00, 0x39, 0x80, 0x1c, 0x40, 0x0e, 0x20,
		0x07, 0x90, 0x03, 0xc8, 0x01, 0xe4, 0x8c, 0x01, 0xb9, 0x95, 0x96, 0xa3, 0x57, 0xbe, 0xcd, 0x7f,
		0x61, 0x3e, 0xf6, 0x6f, 0xf7, 0x5f, 0xbc, 0xf7, 0x7c, 0xf1, 0x47, 0x0d, 0x0b, 0x97, 0xbe, 0x8c,
		0xd7, 0x33, 0x4f, 0x07, 0x9d, 0x3c, 0x9e, 0x84, 0xa3, 0xa3, 0x62, 0x39, 0xef, 0xde, 0xf8, 0x7f,
		0xe7, 0xbf, 0xb3, 0xbb, 0x3f, 0x68, 0x1f, 0x4f, 0x97, 0xb2, 0x78, 0xd5, 0x7e, 0x73, 0xd9, 0x6f,
		0x9f, 0x44, 0xe7, 0xed, 0xbd, 0x8b, 0xe8, 0x74, 0xb8, 0x92, 0xd3, 0x17, 0xed, 0x83, 0xfe, 0x75,
		0xeb, 0x34, 0xcd, 0xc3, 0xe3, 0xd1, 0x32, 0xb6, 0x0f, 0x93, 0xce, 0xf0, 0xd7, 0x4e, 0x46, 0xab,
		0x38, 0xfe, 0xd6, 0xfe, 0x38, 0x5e, 0xb2, 0xbd, 0x62, 0x11, 0x17, 0x7e, 0xd2, 0x3e, 0x1d, 0xad,
		0xe1, 0xaa, 0x5e, 0xa0, 0xb4, 0x52, 0x17, 0x82, 0xfe, 0x4f, 0xf8, 0xcd, 0x82, 0xa2, 0x9f, 0x77,
		0x18, 0x65, 0xf9, 0xd0, 0x00, 0x75, 0x6f, 0x27, 0x7d, 0x17, 0xc5, 0xfb, 0xbd, 0x70, 0x08, 0x3f,
		0x33, 0x5d, 0x7a, 0xe8, 0xbd, 0x0b, 0xbe, 0xde, 0x9a, 0x49, 0xf3, 0x55, 0xab, 0xb5, 0xbd, 0xd3,
		0x6a, 0xad, 0xef, 0x6c, 0xee, 0xac, 0xef, 0x6e, 0x6d, 0x35, 0xb7, 0x9b, 0x8a, 0xa7, 0x35, 0xbc,
		0xa3, 0xb4, 0x1b, 0xa6, 0x61, 0xf7, 0xcd, 0xd0, 0x74, 0xe2, 0x41, 0xaf, 0xb7, 0x52, 0x1e, 0x63,
		0x24, 0x6f, 0xd7, 0x24, 0x5f, 0x7b, 0xaa, 0xd7, 0xd5, 0x55, 0x35, 0x43, 0xeb, 0xe4, 0x66, 0xf9,
		0xcc, 0x28, 0x3b, 0xa2, 0x70, 0x44, 0xd1, 0x8e, 0x24, 0x95, 0x8c, 0x20, 0x0a, 0xf1, 0xa2, 0x3a,
		0x71, 0x42, 0x36, 0x2c, 0xc8, 0x39, 0xa7, 0xcc, 0x48, 0x42, 0xee, 0x3f, 0x85, 0xdc, 0x43, 0xbf,
		0xf3, 0xa3, 0xee, 0x5a, 0x18, 0x77, 0xfb, 0x49, 0x14, 0xe7, 0x6b, 0x9d, 0xa4, 0x97, 0xa4, 0x42,
		0xf6, 0xad, 0x83, 0xb7, 0xf5, 0xf0, 0xb5, 0x29, 0x3c, 0xad, 0x83, 0x9f, 0xa5, 0xcc, 0x5b, 0x29,
		0xab, 0xd9, 0xcf, 0x66, 0x82, 0xa9, 0xcb, 0x6a, 0xca, 0x92, 0x49, 0x50, 0xee, 0xd3, 0x85, 0xdb,
		0x11, 0x1c, 0x7b, 0xaa, 0xb4, 0x87, 0x5a, 0xf6, 0x4c, 0x01, 0x9f, 0xb4, 0xe7, 0x8b, 0x6e, 0xbd,
		0xd0, 0x9d, 0x6f, 0xb8, 0x79, 0x67, 0x47, 0xde, 0x26, 0xe5, 0x65, 0x26, 0xbd, 0xcb, 0xa1, 0x5b,
		0x19, 0x72, 0x27, 0x37, 0x7e, 0x54, 0xbe, 0x95, 0x3b, 0xb0, 0x70, 0x2f, 0x0e, 0xa3, 0xcb, 0x2f,
		0xe7, 0x49, 0x9a, 0x39, 0x33, 0xee, 0xa2, 0x93, 0x3f, 0x1b, 0xca, 0x91, 0xa7, 0x4e, 0xfb, 0xf2,
		0x8e, 0xde, 0xde, 0xf5, 0x76, 0x33, 0x89, 0xed, 0x63, 0xb2, 0xdb, 0xc1, 0xa4, 0xb6, 0x77, 0x89,
		0x6f, 0xd7, 0x12, 0xdf, 0x7e, 0x25, 0xbe, 0x9d, 0xaa, 0x5a, 0x39, 0xfa, 0x6d, 0xe4, 0xb6, 0x00,
		0x52, 0xc4, 0x2e, 0xf7, 0xa6, 0x7c, 0x37, 0x5a, 0xba, 0xb6, 0x64, 0xb7, 0x41, 0x53, 0x2c, 0x78,
		0x4a, 0x06, 0x51, 0x9d, 0x60, 0x2a, 0x1d, 0x54, 0xd5, 0x82, 0xab, 0x5a, 0x90, 0x55, 0x0b, 0xb6,
		0xf5, 0x28, 0x47, 0xb8, 0x0e, 0xc2, 0xc5, 0x40, 0x41, 0xf7, 0x8f, 0xd1, 0x33, 0x89, 0x62, 0xbf,
		0x9f, 0x64, 0xb9, 0x9c, 0x27, 0x14, 0x37, 0x22, 0xdc, 0x99, 0x80, 0x54, 0xc3, 0x41, 0x24, 0x54,
		0x8b, 0x87, 0x6c, 0x8d, 0xd0, 0xad, 0x1b, 0xc2, 0xb5, 0x42, 0xb9, 0x7a, 0x48, 0x57, 0x0f, 0xed,
		0xea, 0x21, 0x5e, 0x26, 0xd4, 0x0b, 0x85, 0x7c, 0xf1, 0xd0, 0x5f, 0x0c, 0x38, 0xa9, 0xfa, 0x8a,
		0x3b, 0xce, 0x34, 0x5c, 0x88, 0x55, 0x9d, 0x15, 0x13, 0x80, 0x5a, 0x22, 0xd0, 0x4c, 0x08, 0x36,
		0x12, 0x83, 0x76, 0x82, 0x30, 0x93, 0x28, 0xcc, 0x24, 0x0c, 0x33, 0x89, 0x43, 0x36, 0x81, 0x08,
		0x27, 0x12, 0xb5, 0x84, 0x32, 0x9f, 0x58, 0xf4, 0xfc, 0x6d, 0x2e, 0xbf, 0x68, 0xf9, 0x9a, 0x4e,
		0x9a, 0x51, 0x4f, 0x37, 0x16, 0xd2, 0x8e, 0xad, 0xf4, 0x63, 0x25, 0x0d, 0x99, 0x4b, 0x47, 0xe6,
		0xd2, 0x92, 0xb9, 0xf4, 0xa4, 0x93, 0xa6, 0x94, 0xd2, 0x95, 0x7a, 0xda, 0x2a, 0x26, 0x30, 0xde,
		0x7b, 0xaa, 0xee, 0xa7, 0xd3, 0xe8, 0x25, 0xb9, 0x15, 0xf6, 0x47, 0xe9, 0x4c, 0x59, 0x24, 0xc4,
		0x8c, 0x5a, 0x89, 0x25, 0x95, 0x12, 0x9b, 0xea, 0x24, 0xd6, 0x54, 0x49, 0xcc, 0xaa, 0x91, 0x98,
		0x55, 0x21, 0x31, 0xab, 0x3e, 0xb2, 0xda, 0x52, 0x09, 0x66, 0x54, 0x46, 0x8a, 0xb8, 0xd3, 0x0b,
		0x83, 0x8b, 0x34, 0xbc, 0xb0, 0x10, 0x74, 0xa6, 0xac, 0x6b, 0xc7, 0xc0, 0x5c, 0x8e, 0x27, 0xbb,
		0x10, 0x7f, 0xf9, 0x65, 0xac, 0xc3, 0xd0, 0x18, 0x27, 0xf2, 0x55, 0x55, 0x12, 0x50, 0x64, 0x5e,
		0xd3, 0x53, 0x45, 0x76, 0x30, 0x5d, 0x31, 0x23, 0x60, 0x1d, 0xb0, 0x0e, 0x58, 0x07, 0xac, 0x03,
		0xd6, 0x01, 0xeb, 0x80, 0x75, 0x95, 0x84, 0x75, 0x45, 0x2e, 0x07, 0xd9, 0x89, 0x3f, 0x8c, 0xc9,
		0xb9, 0x71, 0x3b, 0xc0, 0x6e, 0x3a, 0x21, 0x70, 0x1d, 0xb8, 0x0e, 0x5c, 0x07, 0xae, 0x03, 0xd7,
		0x81, 0xeb, 0xc0, 0x75, 0x95, 0xc4, 0x75, 0xd3, 0x54, 0x0e, 0xac, 0x13, 0x7f, 0x16, 0x63, 0xdd,
		0x5a, 0x33, 0xa0, 0xce, 0x82, 0x8c, 0xae, 0xf2, 0x86, 0x22, 0x20, 0x1d, 0x90, 0x0e, 0x48, 0x07,
		0xa4, 0x03, 0xd2, 0xe9, 0x6f, 0x50, 0x2a, 0x26, 0x32, 0x12, 0xaa, 0x8e, 0xe2, 0x6e, 0xf8, 0xd5,
		0xde, 0xc5, 0x4b, 0xb7, 0xe6, 0xc6, 0xc5, 0x4b, 0x96, 0x13, 0xa9, 0xc5, 0x84, 0x6a, 0x3b, 0xb1,
		0x5a, 0x4d, 0xb0, 0xe6, 0x13, 0xad, 0xf9, 0x84, 0x6b, 0x3e, 0xf1, 0xda, 0x48, 0xc0, 0x46, 0x12,
		0xb1, 0xbd, 0x1a, 0x8b, 0xe1, 0x5a, 0x8b, 0xc5, 0x9a, 0xcb, 0x7d, 0xb5, 0x97, 0x7f, 0xf8, 0xdf,
		0x08, 0x52, 0x64, 0x61, 0x9e, 0x15, 0xaf, 0x26, 0x95, 0x9a, 0x31, 0xcc, 0xe0, 0x22, 0x29, 0x2b,
		0x4e, 0xe9, 0x9d, 0x87, 0x59, 0xee, 0x4f, 0x54, 0xf8, 0x8c, 0xe1, 0xd2, 0xd9, 0xd4, 0x80, 0xa5,
		0xc0, 0x52, 0x60, 0x29, 0xb0, 0x14, 0x58, 0x0a, 0x2c, 0x5d, 0x31, 0x58, 0xca, 0x7d, 0xa0, 0xc0,
		0xb8, 0x47, 0x3c, 0x13, 0x1b, 0x07, 0x21, 0x17, 0xac, 0xd7, 0xc2, 0x81, 0x48, 0xe0, 0x1b, 0xf0,
		0x0d, 0xf8, 0x06, 0x7c, 0x03, 0xbe, 0x01, 0xdf, 0xc4, 0xe3, 0xd6, 0x20, 0x8a, 0xf3, 0xcd, 0x0d,
		0x83, 0xe8, 0xcd, 0x52, 0x4d, 0xf1, 0x24, 0x88, 0x2f, 0x87, 0xab, 0xf5, 0xd9, 0x54, 0x0c, 0xb0,
		0x15, 0xd3, 0xd7, 0x26, 0xf7, 0x90, 0x99, 0x4b, 0x36, 0x46, 0xe1, 0xd5, 0xc2, 0xf4, 0x3e, 0x05,
		0xbd, 0x41, 0x68, 0x78, 0x7e, 0xbf, 0xa5, 0x41, 0x27, 0x8f, 0x92, 0xf8, 0x6d, 0x74, 0x19, 0x8d,
		0xaf, 0x99, 0x33, 0x37, 0xcf, 0x9b, 0x97, 0x06, 0x5d, 0x22, 0xf8, 0x8a, 0x4b, 0x2c, 0xe9, 0x12,
		0xad, 0x8d, 0xdd, 0xd6, 0xee, 0xf6, 0xce, 0xc6, 0xee, 0x16, 0xbe, 0x51, 0x6d, 0x40, 0x66, 0x6f,
		0x36, 0x67, 0x14, 0x89, 0xac, 0xc4, 0x4e, 0xaf, 0x93, 0x5c, 0x5d, 0x0d, 0xe2, 0x28, 0xff, 0x66,
		0x75, 0x27, 0xda, 0xdd, 0x09, 0x52, 0x38, 0xba, 0x6f, 0x3a, 0x14, 0x8e, 0x9e, 0x60, 0x52, 0x14,
		0x8e, 0x9e, 0x64, 0xe9, 0x14, 0x8e, 0x96, 0x9c, 0x20, 0x85, 0xa3, 0x0a, 0x31, 0x09, 0xb6, 0xa3,
		0xfd, 0x44, 0x1a, 0xac, 0xe0, 0x76, 0xb4, 0x29, 0xae, 0x88, 0xc2, 0xac, 0x78, 0xfd, 0x8d, 0x1d,
		0x69, 0x36, 0x51, 0xaa, 0x19, 0x09, 0xb0, 0x05, 0x9f, 0x34, 0x22, 0x05, 0x06, 0x2e, 0x05, 0x97,
		0x82, 0x4b, 0xc1, 0xa5, 0xe0, 0x52, 0x70, 0xa9, 0x78, 0xdc, 0x8a, 0xfa, 0x7e, 0xd0, 0xed, 0xa6,
		0x61, 0x96, 0x59, 0x84, 0xa6, 0xbb, 0x86, 0xe6, 0x34, 0x79, 0x86, 0x34, 0x35, 0x1f, 0x6d, 0x59,
		0xd7, 0x2d, 0x83, 0xb6, 0xb5, 0x60, 0x63, 0xaf, 0x0c, 0xce, 0xed, 0x38, 0xc8, 0xf3, 0x30, 0x8d,
		0xcd, 0x99, 0x5b, 0x31, 0xc1, 0xe7, 0xcf, 0x3f, 0xaf, 0xfb, 0xbb, 0x67, 0xdf, 0x3f, 0x37, 0xfd,
		0xdd, 0xb3, 0xf1, 0xcb, 0xe6, 0xe8, 0xdb, 0xf8, 0xf5, 0xc6, 0xe7, 0x75, 0xbf, 0x35, 0x7d, 0xbd,
		0xf5, 0x79, 0xdd, 0xdf, 0x3a, 0x7b, 0xf1, 0xfb, 0xef, 0xbf, 0xbc, 0xf8, 0x7b, 0xf3, 0xe6, 0xe9,
		0x7f, 0xe8, 0x99, 0x5b, 0x82, 0x33, 0x8b, 0x26, 0x73, 0x74, 0x7a, 0xf0, 0x1f, 0xf3, 0x76, 0xf3,
		0x5f, 0x49, 0xc3, 0xf9, 0x97, 0x41, 0xcb, 0xb1, 0xd5, 0x56, 0x7c, 0x49, 0x32, 0x7b, 0x74, 0x32,
		0xdb, 0x26, 0x99, 0xd5, 0x3a, 0x99, 0x05, 0xfe, 0xc5, 0x9e, 0xff, 0xdb, 0xd9, 0xdf, 0xcd, 0x97,
		0xad, 0x9b, 0xd7, 0x2f, 0xfe, 0xde, 0xb9, 0xb9, 0xfb, 0xc3, 0xef, 0xf7, 0xfd, 0x5a, 0xf3, 0xe5,
		0xce, 0xcd, 0xeb, 0x07, 0xfe, 0x65, 0xfb, 0xe6, 0xf5, 0x23, 0xdf, 0x63, 0xeb, 0xe6, 0xf9, 0xc2,
		0xaf, 0x0e, 0x7f, 0xbe, 0xf1, 0xd0, 0x1f, 0xb4, 0x1e, 0xf8, 0x83, 0xcd, 0x87, 0xfe, 0x60, 0xf3,
		0x81, 0x3f, 0x78, 0x70, 0x4a, 0x1b, 0x0f, 0xfc, 0xc1, 0xd6, 0xcd, 0xf7, 0x85, 0xdf, 0x7f, 0x7e,
		0xff, 0xaf, 0x6e, 0xdf, 0xbc, 0xf8, 0xfe, 0xd0, 0xbf, 0xed, 0xdc, 0x7c, 0x7f, 0xfd, 0x82, 0xd4,
		0x5e, 0xbf, 0xd4, 0x8e, 0x1b, 0xc9, 0xbb, 0x11, 0x40, 0xa7, 0x12, 0xd5, 0xa8, 0x35, 0xf6, 0x4f,
		0x59, 0x82, 0x9e, 0x5e, 0xf8, 0x35, 0xf7, 0xcd, 0xef, 0xa1, 0xba, 0x6f, 0x92, 0xf4, 0xab, 0xee,
		0x9b, 0x0e, 0xfd, 0xaa, 0x27, 0x98, 0x15, 0xfd, 0xaa, 0x27, 0x59, 0x3a, 0xfd, 0xaa, 0x25, 0x27,
		0x48, 0xbf, 0xaa, 0x42, 0x05, 0x19, 0xf6, 0x51, 0xfd, 0x4c, 0xed, 0xa5, 0x7a, 0xfb, 0xa8, 0x6e,
		0x63, 0x8b, 0x28, 0xcc, 0xe6, 0xfe, 0x9b, 0xfd, 0x54, 0x46, 0x51, 0x6b, 0x14, 0x5f, 0x07, 0xbd,
		0xa8, 0xeb, 0xa7, 0x61, 0x90, 0x25, 0xb1, 0x3d, 0xc0, 0x7a, 0x67, 0x7e, 0x60, 0x55, 0xb0, 0x2a,
		0x58, 0x15, 0xac, 0x0a, 0x56, 0x05, 0xab, 0xae, 0x18, 0x56, 0x8d, 0xba, 0x61, 0x9c, 0x47, 0xf9,
		0x37, 0xa3, 0x78, 0xd5, 0xd0, 0xe9, 0x60, 0xef, 0x60, 0xb2, 0x54, 0x6f, 0x82, 0xcc, 0x60, 0x48,
		0x9d, 0x3e, 0xd0, 0x83, 0xf7, 0x9f, 0xf6, 0x0e, 0x0f, 0xde, 0xb6, 0x4f, 0x8e, 0x3e, 0x7e, 0xd8,
		0x6f, 0x9f, 0xec, 0xef, 0x9d, 0x1e, 0xbd, 0xb7, 0x16, 0x5d, 0x47, 0x87, 0xc0, 0x33, 0x93, 0x6d,
		0x22, 0xa3, 0xa7, 0xfa, 0xef, 0x3e, 0xdd, 0x5f, 0x0f, 0x3f, 0x9e, 0x7e, 0xd8, 0x3f, 0x69, 0x1f,
		0x1e, 0x1d, 0x1d, 0x7b, 0x88, 0x36, 0xd4, 0xe6, 0xb9, 0x1e, 0x9d, 0x1c, 0xfc, 0xfb, 0xe0, 0xfd,
		0xde, 0x87, 0xa3, 0x13, 0x9e, 0x6a, 0x7d, 0x9e, 0xea, 0xde, 0x29, 0x8e, 0x5a, 0xb7, 0x00, 0x7c,
		0xf4, 0xfe, 0xb7, 0xfd, 0xb7, 0x1e, 0x9a, 0x20, 0xff, 0xf8, 0x75, 0x06, 0x1f, 0x31, 0x36, 0x0b,
		0x0b, 0xd5, 0xc1, 0x5e, 0x90, 0xe5, 0xfe, 0x55, 0xd2, 0x8d, 0x2e, 0xa2, 0xb0, 0x6b, 0xaf, 0x38,
		0x38, 0x3f, 0x3d, 0x6a, 0x83, 0xf7, 0x4d, 0x87, 0xda, 0xe0, 0x13, 0x0c, 0x8a, 0xda, 0xe0, 0x93,
		0x2c, 0x9d, 0xda, 0xe0, 0x92, 0x13, 0xa4, 0x36, 0x58, 0x21, 0xec, 0x6b, 0xb8, 0x36, 0x98, 0x47,
		0x57, 0x61, 0x1e, 0x75, 0xfe, 0xcc, 0xb6, 0x5b, 0x06, 0x6b, 0x83, 0x86, 0x8e, 0x11, 0x78, 0x1f,
		0xe3, 0xb1, 0x46, 0xa0, 0x17, 0x07, 0x71, 0x92, 0x85, 0x9d, 0x24, 0xee, 0x9a, 0x3a, 0xab, 0x8a,
		0xda, 0xed, 0x23, 0x17, 0x0a, 0xb5, 0xdb, 0x9f, 0x9f, 0x1e, 0x6a, 0xb7, 0x75, 0xac, 0xc7, 0xa0,
		0x76, 0x5b, 0x82, 0x4b, 0x34, 0x5f, 0xb5, 0x5a, 0xdb, 0x3b, 0xad, 0xd6, 0xfa, 0xce, 0xe6, 0xce,
		0xfa, 0xee, 0xd6, 0x56, 0x73, 0xbb, 0x89, 0xee, 0x6d, 0xc5, 0xf1, 0xa3, 0xbd, 0xd9, 0x70, 0x6e,
		0xc3, 0x4c, 0x14, 0xf5, 0xfa, 0x41, 0xfe, 0xc5, 0x8f, 0x0c, 0x56, 0xb7, 0xa6, 0x13, 0x33, 0xc2,
		0x7e, 0xde, 0x86, 0x17, 0xc1, 0xa0, 0x37, 0xa2, 0xaa, 0xeb, 0xd4, 0xda, 0xee, 0x9d, 0x0e, 0xb5,
		0xb6, 0x27, 0x98, 0x37, 0xb5, 0xb6, 0x27, 0x59, 0x3a, 0xb5, 0xb6, 0x25, 0x27, 0x48, 0xad, 0xad,
		0x42, 0xbc, 0x86, 0x4b, 0x9b, 0x9e, 0x9e, 0x05, 0xb9, 0xb4, 0xe9, 0x47, 0x5f, 0x94, 0xb1, 0x6a,
		0xc9, 0xd9, 0x29, 0x63, 0x55, 0x3d, 0xdc, 0xcf, 0xbb, 0x04, 0x65, 0xac, 0xa5, 0x5d, 0x82, 0x4b,
		0x9b, 0xea, 0x02, 0xc8, 0xec, 0xcd, 0x86, 0xe2, 0x95, 0x99, 0xd8, 0xe9, 0x4d, 0x0e, 0x47, 0x26,
		0x83, 0x3c, 0xb4, 0x57, 0xc0, 0xba, 0x3d, 0x39, 0x0a, 0x46, 0xf7, 0x4d, 0x87, 0x82, 0xd1, 0x13,
		0xcc, 0x89, 0x82, 0xd1, 0x93, 0x2c, 0x9d, 0x82, 0xd1, 0x92, 0x13, 0xa4, 0x60, 0x54, 0x21, 0x06,
		0x61, 0xb8, 0x60, 0x74, 0x9e, 0x24, 0xbd, 0x30, 0x88, 0x2d, 0x1e, 0xda, 0x6c, 0x02, 0xe5, 0x0c,
		0xcc, 0x40, 0xd9, 0x85, 0xbc, 0xbd, 0x38, 0x4e, 0xf2, 0x60, 0xc8, 0xc6, 0x4c, 0x38, 0x90, 0x97,
		0x75, 0xbe, 0x84, 0x57, 0x41, 0x7f, 0x22, 0x3a, 0xd3, 0x48, 0xfa, 0x61, 0xdc, 0x19, 0x01, 0x25,
		0x3f, 0x0e, 0xf3, 0xbf, 0x92, 0xf4, 0x4f, 0x3f, 0x8a, 0xb3, 0x3c, 0x88, 0x3b, 0x61, 0xe3, 0xee,
		0x0f, 0xb2, 0x85, 0x9f, 0x34, 0xfa, 0x69, 0x92, 0x27, 0x9d, 0xa4, 0x97, 0x15, 0xaf, 0x1a, 0xe7,
		0x97, 0xfd, 0x46, 0x1a, 0x9d, 0x37, 0x82, 0x8b, 0xc8, 0xcf, 0x82, 0x8b, 0x28, 0x2b, 0x5e, 0x35,
		0x46, 0xf7, 0x0c, 0x64, 0x69, 0x1e, 0xfa, 0xfd, 0xa4, 0x17, 0x75, 0xbe, 0x35, 0xe2, 0x30, 0xba,
		0xfc, 0x72, 0x9e, 0xa4, 0x59, 0xf1, 0xaa, 0x11, 0x74, 0xff, 0x18, 0x65, 0x83, 0x28, 0xf6, 0xfb,
		0x49, 0x96, 0x37, 0x46, 0x08, 0x37, 0x1b, 0x7f, 0x1b, 0xeb, 0xdc, 0x18, 0xf0, 0x75, 0x2f, 0xcb,
		0xd3, 0x41, 0x27, 0x8f, 0x27, 0x41, 0xe8, 0xa8, 0x58, 0xc4, 0xf7, 0xe3, 0x05, 0x3a, 0x98, 0xac,
		0x4f, 0xfb, 0xce, 0x7f, 0x67, 0x77, 0x7f, 0xd0, 0x3e, 0x9e, 0x2e, 0x60, 0xf1, 0xaa, 0xfd, 0xe6,
		0xb2, 0xdf, 0x3e, 0x89, 0xce, 0xdb, 0x7b, 0x17, 0xd1, 0xe9, 0x70, 0xfd, 0xa6, 0x2f, 0xda, 0x07,
		0xfd, 0xeb, 0xd6, 0x69, 0x9a, 0x87, 0xc7, 0xa3, 0xc5, 0x6b, 0xbf, 0x9f, 0x2e, 0x5e, 0xf1, 0xaa,
		0xbd, 0xd7, 0xfd, 0xe3, 0x24, 0x3a, 0x3f, 0x88, 0x8f, 0x93, 0x2c, 0x6f, 0x9f, 0x8c, 0x56, 0x6e,
		0xfc, 0xad, 0x7d, 0x3a, 0x5a, 0xb9, 0x67, 0xab, 0x19, 0x07, 0x14, 0x63, 0x80, 0x37, 0x88, 0xff,
		0x8c, 0x93, 0xbf, 0x62, 0x3f, 0xc8, 0xf3, 0x34, 0x3a, 0x1f, 0x3e, 0x11, 0xf5, 0x38, 0x30, 0xeb,
		0xb6, 0x2c, 0xce, 0x4d, 0x39, 0x5a, 0x4e, 0x73, 0xa7, 0xf2, 0x34, 0xac, 0x50, 0x47, 0x4b, 0x94,
		0xd1, 0x26, 0x55, 0xb4, 0x46, 0x11, 0xcd, 0x52, 0x43, 0xb3, 0x94, 0xd0, 0x2c, 0x15, 0x5c, 0x6d,
		0xdc, 0xfa, 0x36, 0x4a, 0x6d, 0x84, 0x9d, 0x85, 0x24, 0x65, 0xaf, 0x16, 0xbb, 0x38, 0x45, 0x5b,
		0x15, 0xd9, 0x26, 0x15, 0x59, 0xf3, 0xe9, 0xd5, 0x76, 0x9a, 0xb5, 0x9a, 0x6e, 0xcd, 0xa7, 0x5d,
		0xf3, 0xe9, 0xd7, 0x7c, 0x1a, 0xb6, 0x53, 0xc8, 0x5a, 0x33, 0x54, 0x91, 0xb5, 0x92, 0x9e, 0x8b,
		0x09, 0x0d, 0x73, 0x9f, 0x9f, 0x5b, 0xab, 0x13, 0xcf, 0x45, 0xd4, 0xd9, 0x14, 0x8d, 0xb9, 0x9e,
		0xcd, 0x7d, 0x2f, 0xe6, 0xd2, 0xb5, 0xe5, 0xb4, 0x5d, 0x8d, 0xf4, 0x6d, 0x3d, 0x8d, 0x57, 0x26,
		0x9d, 0x57, 0x26, 0xad, 0x57, 0x26, 0xbd, 0xdb, 0x4a, 0xf3, 0xc6, 0xd2, 0x7d, 0xf1, 0x14, 0x3f,
		0x58, 0x4c, 0xb0, 0x6b, 0xb6, 0x6f, 0x7d, 0x58, 0x60, 0xc3, 0x3b, 0x36, 0x6f, 0xde, 0x9c, 0xde,
		0x02, 0x31, 0xbe, 0xcc, 0x61, 0x06, 0x56, 0xd8, 0x29, 0x69, 0xdd, 0x35, 0xbd, 0x71, 0x5f, 0xd2,
		0x2c, 0xf0, 0xb5, 0xd2, 0x36, 0xbd, 0xd7, 0x1b, 0x01, 0xbd, 0x80, 0x5e, 0x40, 0x2f, 0xa0, 0x17,
		0xd0, 0x4b, 0x66, 0xbd, 0xff, 0x29, 0x5a, 0xab, 0x75, 0x15, 0x13, 0x1b, 0x61, 0xb4, 0x5e, 0x68,
		0xf8, 0x90, 0xe1, 0x5c, 0xe9, 0x6b, 0x38, 0xd3, 0x97, 0x9c, 0xfc, 0xaa, 0x11, 0x28, 0xa8, 0x02,
		0x38, 0xa8, 0x16, 0x48, 0xa8, 0x0a, 0x58, 0xa8, 0x1c, 0x68, 0xa8, 0x1c, 0x78, 0xa8, 0x1c, 0x88,
		0xb0, 0x09, 0x26, 0x8c, 0x82, 0x8a, 0xe2, 0xe9, 0x9a, 0xad, 0xa8, 0x2d, 0xc4, 0xcd, 0x41, 0x14,
		0xe7, 0xcd, 0x6d, 0xcb, 0x31, 0x73, 0x92, 0xc5, 0xb7, 0x0d, 0x4f, 0xd1, 0xa6, 0x76, 0xc6, 0xdd,
		0x2f, 0xdb, 0x39, 0x67, 0xcd, 0xba, 0xb6, 0x46, 0xc5, 0xe0, 0xe5, 0xc2, 0x74, 0x8d, 0x6b, 0x6f,
		0x2c, 0xcc, 0xb7, 0x02, 0x7a, 0x03, 0x15, 0x49, 0x47, 0xf3, 0x2e, 0x16, 0x7c, 0xc5, 0xc5, 0x1c,
		0xbb, 0xd8, 0xf6, 0xd6, 0xd6, 0xe6, 0x16, 0x6e, 0xb6, 0x5a, 0x58, 0xd4, 0xfe, 0xec, 0xce, 0x9e,
		0xb1, 0x5e, 0x15, 0x0d, 0xe3, 0x86, 0x77, 0xc2, 0x2d, 0x50, 0x0a, 0xab, 0x3b, 0xe2, 0x2a, 0x92,
		0x55, 0xa8, 0x0b, 0x96, 0x69, 0x8c, 0xd4, 0x05, 0x4b, 0xf5, 0x1c, 0xea, 0x82, 0x8e, 0x27, 0x4c,
		0x5d, 0xb0, 0xc6, 0x44, 0xac, 0x62, 0x75, 0xc1, 0x57, 0x15, 0x28, 0x0b, 0x6e, 0x51, 0x16, 0x5c,
		0xf2, 0x8b, 0xb2, 0x20, 0x35, 0x0b, 0xca, 0x82, 0x2b, 0x98, 0x8d, 0xe6, 0x5d, 0x8c, 0xb2, 0xa0,
		0x73, 0x17, 0xdb, 0xd8, 0xa2, 0x28, 0xb8, 0x62, 0x40, 0xd4, 0xfe, 0xec, 0x28, 0x0a, 0x56, 0x36,
		0x88, 0x8f, 0x2b, 0x6d, 0xd7, 0x93, 0xe8, 0x52, 0x85, 0xaa, 0xe0, 0x78, 0xae, 0x94, 0x05, 0x7f,
		0x66, 0x7a, 0x94, 0x05, 0x4b, 0xb4, 0x46, 0xca, 0x82, 0xa5, 0x7a, 0x0e, 0x65, 0x41, 0xc7, 0x13,
		0xa6, 0x2c, 0x58, 0x63, 0x22, 0x56, 0xa1, 0xb2, 0xe0, 0x79, 0x14, 0x07, 0xe9, 0xb7, 0x0a, 0xd4,
		0x05, 0x77, 0x0d, 0x4f, 0xf1, 0x30, 0x8c, 0x2f, 0x47, 0x07, 0x73, 0x29, 0x0c, 0x2e, 0x5b, 0xb5,
		0xa0, 0x30, 0xe8, 0xbc, 0x6a, 0xd1, 0xa4, 0x66, 0xb1, 0x62, 0xf9, 0x68, 0xde, 0xc5, 0x28, 0x0c,
		0x3a, 0x77, 0x31, 0xf6, 0x0b, 0xae, 0x20, 0x18, 0xb5, 0x3f, 0x3b, 0x4a, 0x83, 0x95, 0x0d, 0xe3,
		0x5e, 0xf8, 0x35, 0x0f, 0xe3, 0x6e, 0xd8, 0xb5, 0x5f, 0x18, 0x2c, 0x66, 0x4a, 0x59, 0xf0, 0x67,
		0xa6, 0x47, 0x59, 0xb0, 0x44, 0x5b, 0xa4, 0x2c, 0x58, 0xaa, 0xe7, 0x50, 0x16, 0x74, 0x3c, 0x61,
		0xca, 0x82, 0x35, 0xa6, 0x61, 0x55, 0x2a, 0x0b, 0x9a, 0xbb, 0x30, 0xed, 0xa1, 0x34, 0x6e, 0xe4,
		0x02, 0x35, 0x40, 0xed, 0xcf, 0x3c, 0xc3, 0xa4, 0x3f, 0x64, 0x9e, 0x41, 0xcf, 0x3e, 0xa8, 0x2d,
		0x66, 0x0a, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50,
		0x0b, 0xa8, 0xc5, 0x29, 0xe6, 0x9f, 0x61, 0x3f, 0x48, 0xf3, 0xa8, 0x0a, 0x98, 0x76, 0x3a, 0x51,
		0x20, 0x2d, 0x90, 0x16, 0x48, 0x0b, 0xa4, 0x05, 0xd2, 0x02, 0x69, 0x81, 0xb4, 0x40, 0x5a, 0x20,
		0x2d, 0x4e, 0x31, 0xff, 0x0c, 0xf3, 0x34, 0x88, 0xb3, 0x28, 0x8f, 0xae, 0x2b, 0x70, 0x2e, 0xe9,
		0xd6, 0x5c, 0x01, 0xb6, 0x00, 0x5b, 0x80, 0x2d, 0xc0, 0x16, 0x60, 0x0b, 0xb0, 0x05, 0xd8, 0x02,
		0x6c, 0x01, 0xb6, 0xcc, 0xc8, 0xa8, 0x8b, 0x7a, 0x7b, 0x71, 0x9c, 0xe4, 0x41, 0x1e, 0x25, 0x36,
		0x0f, 0x40, 0x79, 0x59, 0xe7, 0x4b, 0x78, 0x15, 0xf4, 0x27, 0x17, 0x50, 0x36, 0x92, 0x7e, 0x18,
		0x77, 0x46, 0x40, 0xd1, 0x8f, 0xc3, 0xfc, 0xaf, 0x24, 0xfd, 0xd3, 0x8f, 0xe2, 0x2c, 0x0f, 0xe2,
		0x4e, 0xd8, 0xb8, 0xfb, 0x83, 0x6c, 0xe1, 0x27, 0x8d, 0x7e, 0x9a, 0xe4, 0x49, 0x27, 0xe9, 0x65,
		0xc5, 0xab, 0xc6, 0xf9, 0x65, 0xbf, 0x91, 0x46, 0xe7, 0x8d, 0xe0, 0x22, 0xf2, 0xb3, 0xe0, 0x22,
		0xca, 0x8a, 0x57, 0x8d, 0xa8, 0x7f, 0xdd, 0xf2, 0xb3, 0x34, 0x0f, 0xfd, 0x7e, 0xd2, 0x8b, 0x3a,
		0xdf, 0x1a, 0x71, 0x18, 0x5d, 0x7e, 0x39, 0x4f, 0xd2, 0xac, 0x78, 0xd5, 0x08, 0xba, 0x7f, 0x8c,
		0xb2, 0x55, 0x14, 0xfb, 0xfd, 0x24, 0xcb, 0x1b, 0x69, 0x32, 0xc8, 0xc3, 0x6c, 0xfc, 0xad, 0x31,
		0x88, 0xff, 0x8c, 0x93, 0xbf, 0x62, 0x3f, 0xc8, 0xf3, 0x34, 0x3a, 0x1f, 0xfd, 0xc3, 0xc2, 0x8f,
		0x1a, 0x16, 0xef, 0x3f, 0x1c, 0x2f, 0x7d, 0x9e, 0x0e, 0x3a, 0x79, 0x3c, 0x89, 0x8c, 0x47, 0xc5,
		0xca, 0xbf, 0x1f, 0xaf, 0xea, 0xc1, 0x64, 0x51, 0xdb, 0x77, 0xfe, 0x3b, 0xbb, 0xfb, 0x83, 0xf6,
		0xf1, 0x74, 0xd5, 0x8b, 0x57, 0xed, 0x37, 0x97, 0xfd, 0xf6, 0x49, 0x74, 0xde, 0xde, 0xbb, 0x88,
		0x4e, 0x87, 0x8b, 0x3e, 0x7d, 0xd1, 0x3e, 0xe8, 0x5f, 0xb7, 0x4e, 0xd3, 0x3c, 0x3c, 0x1e, 0xad,
		0x78, 0xfb, 0xfd, 0x74, 0xc5, 0x8b, 0x57, 0xed, 0xbd, 0xee, 0x1f, 0x27, 0xd1, 0xf9, 0x41, 0x7c,
		0x9c, 0x64, 0x79, 0xfb, 0x64, 0xb4, 0xdc, 0xe3, 0x6f, 0xed, 0x8f, 0xe3, 0xb5, 0xdd, 0x2b, 0x56,
		0x7b, 0xe1, 0x27, 0xed, 0xd3, 0xd1, 0x62, 0x73, 0x69, 0xa9, 0xe1, 0x99, 0x18, 0x89, 0x90, 0x43,
		0xd0, 0x6f, 0x51, 0x85, 0xd8, 0x3b, 0x8c, 0xb2, 0x7c, 0x68, 0xd0, 0xa6, 0xe2, 0xb5, 0xf7, 0x2e,
		0x8a, 0xf7, 0x7b, 0xe1, 0x10, 0xc2, 0x67, 0xb6, 0x28, 0xbc, 0xf7, 0x2e, 0xf8, 0x7a, 0x6b, 0x66,
		0xcd, 0x57, 0xad, 0xd6, 0xf6, 0x4e, 0xab, 0xb5, 0xbe, 0xb3, 0xb9, 0xb3, 0xbe, 0xbb, 0xb5, 0xd5,
		0xdc, 0x6e, 0x1a, 0x3a, 0x31, 0xe7, 0x1d, 0xa5, 0xdd, 0x30, 0x0d, 0xbb, 0x6f, 0x86, 0xa6, 0x17,
		0x0f, 0x7a, 0x3d, 0x3c, 0xd2, 0x3e, 0x56, 0xa9, 0x3f, 0x46, 0xf1, 0x4c, 0xdd, 0x66, 0x5d, 0x3b,
		0x54, 0x62, 0x03, 0x8f, 0xe8, 0x67, 0x7f, 0xdd, 0x19, 0x28, 0x47, 0x39, 0x6b, 0xd1, 0xad, 0x6e,
		0x51, 0xcd, 0x40, 0x0c, 0xab, 0x41, 0xec, 0xd2, 0x0d, 0x55, 0x7a, 0x01, 0x42, 0x67, 0x64, 0xa5,
		0x90, 0x34, 0xa5, 0x3e, 0x43, 0xdf, 0xf7, 0xa3, 0xee, 0x5a, 0x18, 0x77, 0xfb, 0x49, 0x14, 0xe7,
		0x6b, 0x9d, 0xa4, 0x97, 0xa4, 0x4a, 0x8e, 0x64, 0x83, 0xf7, 0xd8, 0xe1, 0x39, 0xa6, 0x79, 0x8d,
		0x0d, 0x1e, 0xa3, 0xe5, 0x3e, 0x46, 0x32, 0x79, 0xa5, 0x33, 0xb8, 0x62, 0xba, 0xae, 0x5c, 0x9a,
		0xd6, 0x49, 0xca, 0xf2, 0x29, 0x51, 0x76, 0x44, 0xe1, 0xe8, 0xa1, 0x1d, 0x35, 0x2a, 0x1a, 0x2d,
		0x14, 0xe2, 0x44, 0x85, 0xe2, 0x83, 0x6c, 0x64, 0x90, 0xf3, 0x4f, 0x99, 0x91, 0x84, 0x22, 0x80,
		0x96, 0xe7, 0x57, 0xcd, 0xe3, 0x05, 0x5d, 0xbd, 0x0a, 0x2e, 0x2e, 0xe3, 0xdb, 0xee, 0x3d, 0x4d,
		0xc0, 0xcb, 0xbc, 0xdb, 0x96, 0x94, 0xca, 0x6d, 0x45, 0x9a, 0x5d, 0x5a, 0x30, 0x3f, 0xbe, 0x50,
		0x5c, 0x99, 0xee, 0x14, 0x12, 0x1a, 0x4e, 0x7a, 0x03, 0xaf, 0xc6, 0x86, 0x5c, 0xdd, 0x0d, 0xb6,
		0x5a, 0x1b, 0x66, 0xd5, 0x37, 0xc0, 0xaa, 0x6f, 0x68, 0x55, 0xdf, 0xa0, 0x5a, 0x2f, 0xc4, 0xf3,
		0x36, 0x92, 0x2d, 0xe3, 0x79, 0x13, 0xb2, 0x20, 0xee, 0x38, 0xd3, 0x70, 0xa1, 0x42, 0x56, 0x84,
		0x13, 0x80, 0x5a, 0x22, 0xd0, 0x4c, 0x08, 0x36, 0x12, 0x83, 0x76, 0x82, 0x30, 0x93, 0x28, 0xcc,
		0x24, 0x0c, 0x33, 0x89, 0x63, 0x35, 0x8a, 0x67, 0xd2, 0x09, 0x65, 0x3e, 0xb1, 0xe8, 0xf9, 0xdb,
		0x5c, 0x7e, 0xd1, 0xf2, 0x35, 0x9d, 0x34, 0xa3, 0x9e, 0x6e, 0x2c, 0xa4, 0x1d, 0x5b, 0xe9, 0xc7,
		0x4a, 0x1a, 0x32, 0x97, 0x8e, 0xcc, 0xa5, 0x25, 0x73, 0xe9, 0x49, 0x27, 0x4d, 0x29, 0xa5, 0x2b,
		0xf5, 0xb4, 0x55, 0x4c, 0x60, 0xbc, 0xa3, 0x43, 0xdd, 0x4f, 0xa7, 0xd1, 0x4b, 0x73, 0x83, 0xc9,
		0xdd, 0x74, 0xa6, 0xbc, 0x87, 0xdd, 0xcc, 0x79, 0x78, 0x4b, 0xe7, 0xde, 0x6d, 0x9e, 0x6f, 0xb7,
		0x76, 0x8e, 0xdd, 0xec, 0x79, 0x75, 0xb3, 0xe7, 0xd2, 0xcd, 0x9e, 0x3f, 0x5f, 0xed, 0x2d, 0xd1,
		0x66, 0xce, 0x8d, 0x17, 0x71, 0xa7, 0x17, 0x06, 0x17, 0x69, 0x78, 0x61, 0x21, 0xe8, 0x4c, 0x59,
		0xd7, 0x8e, 0x81, 0xb9, 0x1c, 0x4f, 0x7a, 0xc8, 0xbf, 0xfc, 0x32, 0x3e, 0xce, 0xda, 0x18, 0x27,
		0xf2, 0x55, 0xdd, 0x2c, 0xac, 0xc8, 0xbc, 0xa6, 0x7b, 0x75, 0xed, 0x60, 0xba, 0x62, 0x46, 0xc0,
		0x3a, 0x60, 0x1d, 0xb0, 0x0e, 0x58, 0x07, 0xac, 0x03, 0xd6, 0x01, 0xeb, 0x2a, 0x09, 0xeb, 0x8a,
		0x5c, 0x0e, 0xb2, 0x13, 0x7f, 0x18, 0x93, 0xd3, 0x58, 0x76, 0x80, 0xdd, 0x74, 0x42, 0xe0, 0x3a,
		0x70, 0x1d, 0xb8, 0x0e, 0x5c, 0x07, 0xae, 0x03, 0xd7, 0x81, 0xeb, 0x2a, 0x89, 0xeb, 0xa6, 0xa9,
		0x1c, 0x58, 0x27, 0xfe, 0x2c, 0xc6, 0xf2, 0x7f, 0x66, 0x40, 0x9d, 0x05, 0x35, 0x42, 0xe5, 0x0d,
		0x45, 0x40, 0x3a, 0x20, 0x1d, 0x90, 0x0e, 0x48, 0x07, 0xa4, 0xd3, 0xdf, 0xa0, 0x54, 0x4c, 0x64,
		0x24, 0xc3, 0x19, 0xc5, 0xdd, 0xd0, 0xce, 0x05, 0x0c, 0xb3, 0xd3, 0x7d, 0xb3, 0xb9, 0x59, 0xd1,
		0x2e, 0x35, 0x75, 0xd5, 0x87, 0xb9, 0xab, 0x3d, 0x2c, 0x5e, 0xe5, 0x61, 0xfb, 0xea, 0x0e, 0xab,
		0x57, 0x75, 0x98, 0xbf, 0x9a, 0xc3, 0xfc, 0x55, 0x1c, 0xe6, 0xaf, 0xde, 0x40, 0x95, 0xda, 0x64,
		0x8d, 0xc5, 0x70, 0xad, 0xc5, 0x62, 0xcd, 0xe5, 0xbe, 0xda, 0xcb, 0x3f, 0xfc, 0x6f, 0x04, 0x29,
		0xb2, 0x30, 0xcf, 0x8a, 0x57, 0x93, 0x4a, 0xcd, 0x18, 0x66, 0x20, 0x18, 0x6b, 0xc5, 0x29, 0x8d,
		0xec, 0xa0, 0x5f, 0xf0, 0x46, 0x0b, 0x3b, 0xe9, 0x81, 0xa3, 0xc0, 0x51, 0xe0, 0x28, 0x70, 0x14,
		0x38, 0x0a, 0x1c, 0x15, 0x8f, 0x5b, 0x83, 0x28, 0xce, 0x37, 0x37, 0x0c, 0xa2, 0x51, 0x4b, 0x60,
		0xf4, 0x24, 0x88, 0x2f, 0x87, 0xab, 0xf5, 0xd9, 0x54, 0x0c, 0x30, 0x78, 0x0d, 0xd9, 0xbb, 0x28,
		0xb6, 0x7b, 0x05, 0xb1, 0xf1, 0x8b, 0x7d, 0x3f, 0x05, 0xbd, 0x41, 0x68, 0x78, 0x7e, 0xbf, 0xa5,
		0x41, 0x27, 0x8f, 0x92, 0xf8, 0x6d, 0x74, 0x19, 0x8d, 0x55, 0xbd, 0xb9, 0x9c, 0xfb, 0x31, 0x2e,
		0x11, 0x7c, 0xc5, 0x25, 0x96, 0x74, 0x89, 0xd6, 0xc6, 0x6e, 0x6b, 0x77, 0x7b, 0x67, 0x63, 0x77,
		0x0b, 0xdf, 0xa8, 0x36, 0x20, 0xb3, 0x37, 0x9b, 0x33, 0x8a, 0x44, 0x56, 0x62, 0xa7, 0xd7, 0x49,
		0xae, 0xae, 0x06, 0x71, 0x94, 0x7f, 0xb3, 0xda, 0xc2, 0xbc, 0x3b, 0x41, 0x0a, 0x47, 0xf7, 0x4d,
		0x87, 0xc2, 0xd1, 0x13, 0x4c, 0x8a, 0xc2, 0xd1, 0x93, 0x2c, 0x9d, 0xc2, 0xd1, 0x92, 0x13, 0xa4,
		0x70, 0x54, 0x21, 0x26, 0x41, 0x1f, 0xf3, 0x27, 0xd2, 0x60, 0x05, 0xfb, 0x98, 0x53, 0x5c, 0x11,
		0x85, 0x59, 0xf1, 0xfa, 0x1b, 0xad, 0x4c, 0x9b, 0x28, 0xd5, 0x8c, 0x76, 0xc4, 0x82, 0x4f, 0x1a,
		0xd1, 0x90, 0x00, 0x97, 0x82, 0x4b, 0xc1, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x54, 0x3c, 0x6e,
		0x45, 0x7d, 0x3f, 0xe8, 0x76, 0xd3, 0x30, 0xcb, 0x2c, 0x42, 0xd3, 0x5d, 0x43, 0x73, 0x9a, 0x3c,
		0x43, 0x9a, 0x9a, 0x8f, 0xb6, 0xac, 0xeb, 0x96, 0x41, 0xdb, 0x5a, 0xb0, 0xb1, 0x57, 0x06, 0xe7,
		0x76, 0x1c, 0xe4, 0x79, 0x98, 0xc6, 0xe6, 0xcc, 0xad, 0x98, 0xe0, 0xf3, 0xe7, 0x9f, 0xd7, 0xfd,
		0xdd, 0xb3, 0xef, 0x9f, 0x9b, 0xfe, 0xee, 0xd9, 0xf8, 0x65, 0x73, 0xf4, 0x6d, 0xfc, 0x7a, 0xe3,
		0xf3, 0xba, 0xdf, 0x9a, 0xbe, 0xde, 0xfa, 0xbc, 0xee, 0x6f, 0x9d, 0xbd, 0xf8, 0xfd, 0xf7, 0x5f,
		0x5e, 0xfc, 0xbd, 0x79, 0xf3, 0xf4, 0x3f, 0xf4, 0xcc, 0x2d, 0xc1, 0x99, 0x45, 0x93, 0x39, 0x3a,
		0x3d, 0xf8, 0x8f, 0x79, 0xbb, 0xf9, 0xaf, 0xa4, 0xe1, 0xfc, 0xcb, 0xa0, 0xe5, 0xd8, 0x6a, 0x2b,
		0xbe, 0x24, 0x99, 0x3d, 0x3a, 0x99, 0x6d, 0x93, 0xcc, 0x6a, 0x9d, 0xcc, 0x02, 0xff, 0x62, 0xcf,
		0xff, 0xed, 0xec, 0xef, 0xe6, 0xcb, 0xd6, 0xcd, 0xeb, 0x17, 0x7f, 0xef, 0xdc, 0xdc, 0xfd, 0xe1,
		0xf7, 0xfb, 0x7e, 0xad, 0xf9, 0x72, 0xe7, 0xe6, 0xf5, 0x03, 0xff, 0xb2, 0x7d, 0xf3, 0xfa, 0x91,
		0xef, 0xb1, 0x75, 0xf3, 0x7c, 0xe1, 0x57, 0x87, 0x3f, 0xdf, 0x78, 0xe8, 0x0f, 0x5a, 0x0f, 0xfc,
		0xc1, 0xe6, 0x43, 0x7f, 0xb0, 0xf9, 0xc0, 0x1f, 0x3c, 0x38, 0xa5, 0x8d, 0x07, 0xfe, 0x60, 0xeb,
		0xe6, 0xfb, 0xc2, 0xef, 0x3f, 0xbf, 0xff, 0x57, 0xb7, 0x6f, 0x5e, 0x7c, 0x7f, 0xe8, 0xdf, 0x76,
		0x6e, 0xbe, 0xbf, 0x7e, 0x41, 0x6a, 0xaf, 0x5f, 0x6a, 0xc7, 0x8d, 0xe4, 0xdd, 0x08, 0xa0, 0x53,
		0x89, 0x6a, 0xd4, 0x1a, 0xfb, 0xa7, 0x2c, 0x41, 0x4f, 0x2f, 0xfc, 0x9a, 0xfb, 0xe6, 0xf7, 0x50,
		0xdd, 0x37, 0x49, 0xfa, 0x55, 0xf7, 0x4d, 0x87, 0x7e, 0xd5, 0x13, 0xcc, 0x8a, 0x7e, 0xd5, 0x93,
		0x2c, 0x9d, 0x7e, 0xd5, 0x92, 0x13, 0xa4, 0x5f, 0x55, 0xa1, 0x82, 0x0c, 0xfb, 0xa8, 0x7e, 0xa6,
		0xf6, 0x52, 0xbd, 0x7d, 0x54, 0xb7, 0xb1, 0x45, 0x14, 0x66, 0x73, 0xff, 0xcd, 0x7e, 0x2a, 0xa3,
		0xa8, 0x35, 0x8a, 0xaf, 0x83, 0x5e, 0xd4, 0xf5, 0xd3, 0x30, 0xc8, 0x92, 0xd8, 0x1e, 0x60, 0xbd,
		0x33, 0x3f, 0xb0, 0x2a, 0x58, 0x15, 0xac, 0x0a, 0x56, 0x05, 0xab, 0x82, 0x55, 0x57, 0x0c, 0xab,
		0x46, 0xdd, 0x30, 0xce, 0xa3, 0xfc, 0x9b, 0x51, 0xbc, 0x6a, 0xe8, 0x74, 0xb0, 0x77, 0x30, 0x59,
		0xaa, 0x37, 0x41, 0x66, 0x30, 0xa4, 0x4e, 0x1f, 0xe8, 0xc1, 0xfb, 0x4f, 0x7b, 0x87, 0x07, 0x6f,
		0xdb, 0x27, 0x47, 0x1f, 0x3f, 0xec, 0xb7, 0x4f, 0xf6, 0xf7, 0x4e, 0x8f, 0xde, 0x5b, 0x8b, 0xae,
		0xa3, 0x43, 0xe0, 0x99, 0xc9, 0x36, 0x91, 0xd1, 0x53, 0xfd, 0x77, 0x9f, 0xee, 0xaf, 0x87, 0x1f,
		0x4f, 0x3f, 0xec, 0x9f, 0xb4, 0x0f, 0x8f, 0x8e, 0x8e, 0x3d, 0x44, 0x1b, 0x6a, 0xf3, 0x5c, 0x8f,
		0x4e, 0x0e, 0xfe, 0x7d, 0xf0, 0x7e, 0xef, 0xc3, 0xd1, 0x09, 0x4f, 0xb5, 0x3e, 0x4f, 0x75, 0xef,
		0x14, 0x47, 0xad, 0x5b, 0x00, 0x3e, 0x7a, 0xff, 0xdb, 0xfe, 0x5b, 0x0f, 0x4d, 0x90, 0x7f, 0xfc,
		0x3a, 0x83, 0x8f, 0x18, 0x9b, 0x85, 0x85, 0xea, 0x60, 0x2f, 0xc8, 0x72, 0xff, 0x2a, 0xe9, 0x46,
		0x17, 0x51, 0xd8, 0xb5, 0x57, 0x1c, 0x9c, 0x9f, 0x1e, 0xb5, 0xc1, 0xfb, 0xa6, 0x43, 0x6d, 0xf0,
		0x09, 0x06, 0x45, 0x6d, 0xf0, 0x49, 0x96, 0x4e, 0x6d, 0x70, 0xc9, 0x09, 0x52, 0x1b, 0xac, 0x10,
		0xf6, 0x35, 0x5c, 0x1b, 0xcc, 0xa3, 0xab, 0x30, 0x8f, 0x3a, 0x7f, 0x66, 0xdb, 0x2d, 0x83, 0xb5,
		0x41, 0x43, 0xc7, 0x08, 0xbc, 0x8f, 0xf1, 0x58, 0x23, 0xd0, 0x8b, 0x83, 0x38, 0xc9, 0xc2, 0x4e,
		0x12, 0x77, 0x4d, 0x9d, 0x55, 0x45, 0xed, 0xf6, 0x91, 0x0b, 0x85, 0xda, 0xed, 0xcf, 0x4f, 0x0f,
		0xb5, 0xdb, 0x3a, 0xd6, 0x63, 0x50, 0xbb, 0x2d, 0xc1, 0x25, 0x9a, 0xaf, 0x5a, 0xad, 0xed, 0x9d,
		0x56, 0x6b, 0x7d, 0x67, 0x73, 0x67, 0x7d, 0x77, 0x6b, 0xab, 0xb9, 0xdd, 0x44, 0xf7, 0xb6, 0xe2,
		0xf8, 0xd1, 0xde, 0x6c, 0x38, 0xb7, 0x61, 0x26, 0x8a, 0x7a, 0xd3, 0x7b, 0xc5, 0xcd, 0x55, 0xb7,
		0xa6, 0x13, 0x33, 0xc2, 0x7e, 0xde, 0x86, 0x17, 0xc1, 0xa0, 0x37, 0xa2, 0xaa, 0xeb, 0xd4, 0xda,
		0xee, 0x9d, 0x0e, 0xb5, 0xb6, 0x27, 0x98, 0x37, 0xb5, 0xb6, 0x27, 0x59, 0x3a, 0xb5, 0xb6, 0x25,
		0x27, 0x48, 0xad, 0xad, 0x42, 0xbc, 0x86, 0x4b, 0x9b, 0x9e, 0x9e, 0x05, 0xb9, 0xb4, 0xe9, 0x47,
		0x5f, 0x94, 0xb1, 0x6a, 0xc9, 0xd9, 0x29, 0x63, 0x55, 0x3d, 0xdc, 0xcf, 0xbb, 0x04, 0x65, 0xac,
		0xa5, 0x5d, 0x82, 0x4b, 0x9b, 0xea, 0x02, 0xc8, 0xec, 0xcd, 0x86, 0xe2, 0x95, 0x99, 0xd8, 0xe9,
		0x4d, 0x0e, 0x47, 0x26, 0x83, 0x3c, 0xb4, 0x57, 0xc0, 0xba, 0x3d, 0x39, 0x0a, 0x46, 0xf7, 0x4d,
		0x87, 0x82, 0xd1, 0x13, 0xcc, 0x89, 0x82, 0xd1, 0x93, 0x2c, 0x9d, 0x82, 0xd1, 0x92, 0x13, 0xa4,
		0x60, 0x54, 0x21, 0x06, 0x61, 0xb8, 0x60, 0x74, 0x9e, 0x24, 0xbd, 0x30, 0x88, 0x2d, 0x1e, 0xda,
		0x6c, 0x02, 0xe5, 0x0c, 0xcc, 0x40, 0xd9, 0x85, 0xbc, 0xbd, 0x38, 0x4e, 0xf2, 0x60, 0xc8, 0xc6,
		0x4c, 0x38, 0x90, 0x97, 0x75, 0xbe, 0x84, 0x57, 0x41, 0x7f, 0x22, 0x3a, 0xd3, 0x48, 0xfa, 0x61,
		0xdc, 0x19, 0x01, 0x25, 0x3f, 0x0e, 0xf3, 0xbf, 0x92, 0xf4, 0x4f, 0x3f, 0x8a, 0xb3, 0x3c, 0x88,
		0x3b, 0x61, 0xe3, 0xee, 0x0f, 0xb2, 0x85, 0x9f, 0x34, 0xfa, 0x69, 0x92, 0x27, 0x9d, 0xa4, 0x97,
		0x15, 0xaf, 0x1a, 0xe7, 0x97, 0xfd, 0x46, 0x1a, 0x9d, 0x37, 0x82, 0x8b, 0xc8, 0xcf, 0x82, 0x8b,
		0x28, 0x2b, 0x5e, 0x35, 0x46, 0xf7, 0x0c, 0x64, 0x69, 0x1e, 0xfa, 0xfd, 0xa4, 0x17, 0x75, 0xbe,
		0x35, 0xe2, 0x30, 0xba, 0xfc, 0x72, 0x9e, 0xa4, 0x59, 0xf1, 0xaa, 0x11, 0x74, 0xff, 0x18, 0x65,
		0x83, 0x28, 0xf6, 0xfb, 0x69, 0xd8, 0x18, 0x01, 0xdc, 0x6c, 0xfc, 0x6d, 0x2c, 0x73, 0x63, 0xc0,
		0xd5, 0xbd, 0x2c, 0x4f, 0x07, 0x9d, 0x3c, 0x9e, 0xc4, 0xa0, 0xa3, 0x62, 0x0d, 0xdf, 0x8f, 0xd7,
		0xe7, 0x60, 0xb2, 0x3c, 0xed, 0x3b, 0xff, 0x9d, 0xdd, 0xfd, 0x41, 0xfb, 0x78, 0xba, 0x7e, 0xc5,
		0xab, 0xf6, 0x9b, 0xcb, 0x7e, 0xfb, 0x24, 0x3a, 0x6f, 0xef, 0x5d, 0x44, 0xa7, 0xc3, 0xe5, 0x9b,
		0xbe, 0x68, 0x1f, 0xf4, 0xaf, 0x5b, 0xa7, 0x69, 0x1e, 0x1e, 0x8f, 0xd6, 0xae, 0xfd, 0x7e, 0xba,
		0x76, 0xc5, 0xab, 0xf6, 0x5e, 0xf7, 0x8f, 0x93, 0xe8, 0xfc, 0x20, 0x3e, 0x4e, 0xc3, 0xf6, 0xc9,
		0x68, 0xe1, 0xc6, 0xdf, 0xda, 0xa7, 0xa3, 0x85, 0x7b, 0xb6, 0x9a, 0x51, 0x40, 0x31, 0x02, 0x78,
		0x83, 0xf8, 0xcf, 0x38, 0xf9, 0x2b, 0xf6, 0x83, 0x3c, 0x4f, 0xa3, 0xf3, 0xe1, 0x13, 0x51, 0x8f,
		0x02, 0xb3, 0x5e, 0xcb, 0xe2, 0xdc, 0x94, 0x63, 0xe5, 0x34, 0x73, 0x2a, 0x4f, 0xc3, 0x0a, 0x71,
		0xb4, 0x44, 0x18, 0x6d, 0x12, 0x45, 0x6b, 0x04, 0xd1, 0x2c, 0x31, 0x34, 0x4b, 0x08, 0xcd, 0x12,
		0xc1, 0xd5, 0x46, 0xad, 0x6f, 0xa3, 0xd4, 0x46, 0xd8, 0x59, 0x48, 0x52, 0xf6, 0x2a, 0xb1, 0x8b,
		0x53, 0xb4, 0x55, 0x8f, 0x6d, 0x52, 0x8f, 0x35, 0x9f, 0x5e, 0x6d, 0xa7, 0x59, 0xab, 0xe9, 0xd6,
		0x7c, 0xda, 0x35, 0x9f, 0x7e, 0xcd, 0xa7, 0x61, 0x3b, 0x65, 0xac, 0x35, 0x43, 0xf5, 0x58, 0x2b,
		0xe9, 0xb9, 0x98, 0xd0, 0x30, 0xf7, 0xf9, 0xb9, 0xb5, 0x2a, 0xf1, 0x5c, 0x44, 0x9d, 0x4d, 0xd1,
		0x98, 0xeb, 0xd9, 0xdc, 0xf5, 0x62, 0x2e, 0x5d, 0x5b, 0x4e, 0xdb, 0xd5, 0x48, 0xdf, 0xd6, 0xd3,
		0x78, 0x65, 0xd2, 0x79, 0x65, 0xd2, 0x7a, 0x65, 0xd2, 0xbb, 0xad, 0x34, 0x6f, 0x2c, 0xdd, 0x17,
		0x4f, 0xf1, 0x83, 0xc5, 0x04, 0xbb, 0x66, 0xfb, 0xce, 0x87, 0x05, 0x36, 0xbc, 0x63, 0xf3, 0xde,
		0xcd, 0xe9, 0x1d, 0x10, 0xe3, 0xab, 0x1c, 0x66, 0x60, 0x85, 0x7d, 0x92, 0xd6, 0x5d, 0xd3, 0x1b,
		0xb7, 0x25, 0xcd, 0x02, 0x5f, 0x2b, 0x5d, 0xd3, 0x7b, 0xbd, 0x11, 0xd0, 0x0b, 0xe8, 0x05, 0xf4,
		0x02, 0x7a, 0x01, 0xbd, 0x64, 0xd6, 0xfb, 0x9f, 0xa2, 0xb5, 0x5a, 0x57, 0x31, 0xb1, 0x11, 0x46,
		0xeb, 0x85, 0x86, 0x8f, 0x18, 0xce, 0x95, 0xbe, 0x86, 0x33, 0x7d, 0xc9, 0xb9, 0xaf, 0x1a, 0x81,
		0x82, 0x2a, 0x80, 0x83, 0x6a, 0x81, 0x84, 0xaa, 0x80, 0x85, 0xca, 0x81, 0x86, 0xca, 0x81, 0x87,
		0xca, 0x81, 0x08, 0x9b, 0x60, 0xc2, 0x28, 0xa8, 0x28, 0x9e, 0xae, 0xd9, 0x8a, 0xda, 0x42, 0xdc,
		0x1c, 0x44, 0x71, 0xde, 0xdc, 0xb6, 0x1c, 0x33, 0x27, 0x59, 0x7c, 0xdb, 0xf0, 0x14, 0x6d, 0x2a,
		0x67, 0xdc, 0xfd, 0xb2, 0x9d, 0x73, 0xd6, 0xac, 0x2b, 0x6b, 0x54, 0x0c, 0x5e, 0x2e, 0x4c, 0xd7,
		0xb8, 0xf2, 0xc6, 0xc2, 0x7c, 0x2b, 0xa0, 0x36, 0x50, 0x91, 0x74, 0x34, 0xef, 0x62, 0xc1, 0x57,
		0x5c, 0xcc, 0xb1, 0x8b, 0x6d, 0x6f, 0x6d, 0x6d, 0x6e, 0xe1, 0x66, 0xab, 0x85, 0x45, 0xed, 0xcf,
		0xee, 0xec, 0x19, 0xeb, 0x55, 0xd1, 0x30, 0x6e, 0x78, 0x27, 0xdc, 0x02, 0xa5, 0xb0, 0xba, 0x23,
		0xae, 0x22, 0x59, 0x85, 0xba, 0x60, 0x99, 0xc6, 0x48, 0x5d, 0xb0, 0x54, 0xcf, 0xa1, 0x2e, 0xe8,
		0x78, 0xc2, 0xd4, 0x05, 0x6b, 0x4c, 0xc4, 0x2a, 0x56, 0x17, 0x7c, 0x55, 0x81, 0xb2, 0xe0, 0x16,
		0x65, 0xc1, 0x25, 0xbf, 0x28, 0x0b, 0x52, 0xb3, 0xa0, 0x2c, 0xb8, 0x82, 0xd9, 0x68, 0xde, 0xc5,
		0x28, 0x0b, 0x3a, 0x77, 0xb1, 0x8d, 0x2d, 0x8a, 0x82, 0x2b, 0x06, 0x44, 0xed, 0xcf, 0x8e, 0xa2,
		0x60, 0x65, 0x83, 0xf8, 0xb8, 0xd2, 0x76, 0x3d, 0x89, 0x2e, 0x55, 0xa8, 0x0a, 0x8e, 0xe7, 0x4a,
		0x59, 0xf0, 0x67, 0xa6, 0x47, 0x59, 0xb0, 0x44, 0x6b, 0xa4, 0x2c, 0x58, 0xaa, 0xe7, 0x50, 0x16,
		0x74, 0x3c, 0x61, 0xca, 0x82, 0x35, 0x26, 0x62, 0x15, 0x2a, 0x0b, 0x9e, 0x47, 0x71, 0x90, 0x7e,
		0xab, 0x40, 0x5d, 0x70, 0xd7, 0xf0, 0x14, 0x0f, 0xc3, 0xf8, 0x72, 0x74, 0x30, 0x97, 0xc2, 0xe0,
		0xb2, 0x55, 0x0b, 0x0a, 0x83, 0xce, 0xab, 0x16, 0x4d, 0x6a, 0x16, 0x2b, 0x96, 0x8f, 0xe6, 0x5d,
		0x8c, 0xc2, 0xa0, 0x73, 0x17, 0x63, 0xbf, 0xe0, 0x0a, 0x82, 0x51, 0xfb, 0xb3, 0xa3, 0x34, 0x58,
		0xd9, 0x30, 0xee, 0x85, 0x5f, 0xf3, 0x30, 0xee, 0x86, 0x5d, 0xfb, 0x85, 0xc1, 0x62, 0xa6, 0x94,
		0x05, 0x7f, 0x66, 0x7a, 0x94, 0x05, 0x4b, 0xb4, 0x45, 0xca, 0x82, 0xa5, 0x7a, 0x0e, 0x65, 0x41,
		0xc7, 0x13, 0xa6, 0x2c, 0x58, 0x63, 0x1a, 0x56, 0xa5, 0xb2, 0xa0, 0xb9, 0xeb, 0xd2, 0x1e, 0x4a,
		0xe3, 0x46, 0xae, 0x4f, 0x03, 0xd4, 0xfe, 0xcc, 0x33, 0x4c, 0xfa, 0x43, 0xe6, 0x19, 0xf4, 0xec,
		0x83, 0xda, 0x62, 0xa6, 0x80, 0x5a, 0x40, 0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0x02,
		0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x9c, 0x62, 0xfe, 0x19, 0xf6, 0x83, 0x34, 0x8f, 0xaa, 0x80, 0x69,
		0xa7, 0x13, 0x05, 0xd2, 0x02, 0x69, 0x81, 0xb4, 0x40, 0x5a, 0x20, 0x2d, 0x90, 0x16, 0x48, 0x0b,
		0xa4, 0x05, 0xd2, 0xe2, 0x14, 0xf3, 0xcf, 0x30, 0x4f, 0x83, 0x38, 0x8b, 0xf2, 0xe8, 0xba, 0x02,
		0xe7, 0x92, 0x6e, 0xcd, 0x15, 0x60, 0x0b, 0xb0, 0x05, 0xd8, 0x02, 0x6c, 0x01, 0xb6, 0x00, 0x5b,
		0x80, 0x2d, 0xc0, 0x16, 0x60, 0xcb, 0x8c, 0x8c, 0xba, 0xa8, 0xb7, 0x17, 0xc7, 0x49, 0x1e, 0xe4,
		0x51, 0x62, 0xf3, 0x00, 0x94, 0x97, 0x75, 0xbe, 0x84, 0x57, 0x41, 0x7f, 0x72, 0x01, 0x65, 0x23,
		0xe9, 0x87, 0x71, 0x67, 0x04, 0x14, 0xfd, 0x38, 0xcc, 0xff, 0x4a, 0xd2, 0x3f, 0xfd, 0x28, 0xce,
		0xf2, 0x20, 0xee, 0x84, 0x8d, 0xbb, 0x3f, 0xc8, 0x16, 0x7e, 0xd2, 0xe8, 0xa7, 0x49, 0x9e, 0x74,
		0x92, 0x5e, 0x56, 0xbc, 0x6a, 0x9c, 0x5f, 0xf6, 0x1b, 0x69, 0x74, 0xde, 0x08, 0x2e, 0x22, 0x3f,
		0x0b, 0x2e, 0xa2, 0xac, 0x78, 0xd5, 0x88, 0xfa, 0xd7, 0x2d, 0x3f, 0x4b, 0xf3, 0xd0, 0xef, 0x27,
		0xbd, 0xa8, 0xf3, 0xad, 0x11, 0x87, 0xd1, 0xe5, 0x97, 0xf3, 0x24, 0xcd, 0x8a, 0x57, 0x8d, 0xa0,
		0xfb, 0xc7, 0x28, 0x5b, 0x45, 0xb1, 0xdf, 0x4f, 0xc3, 0x46, 0x9a, 0x0c, 0xf2, 0x30, 0x1b, 0x7f,
		0x6b, 0x0c, 0xe2, 0x3f, 0xe3, 0xe4, 0xaf, 0xd8, 0x0f, 0xf2, 0x3c, 0x8d, 0xce, 0x47, 0xff, 0xb0,
		0xf0, 0xa3, 0x86, 0xc5, 0xeb, 0x0f, 0xc7, 0x2b, 0x9f, 0xa7, 0x83, 0x4e, 0x1e, 0x4f, 0x02, 0xe3,
		0x51, 0xb1, 0xf0, 0xef, 0xc7, 0x8b, 0x7a, 0x30, 0x59, 0xd3, 0xf6, 0x9d, 0xff, 0xce, 0xee, 0xfe,
		0xa0, 0x7d, 0x3c, 0x5d, 0xf4, 0xe2, 0x55, 0xfb, 0xcd, 0x65, 0xbf, 0x7d, 0x12, 0x9d, 0xb7, 0xf7,
		0x2e, 0xa2, 0xd3, 0xe1, 0x9a, 0x4f, 0x5f, 0xb4, 0x0f, 0xfa, 0xd7, 0xad, 0xd3, 0x34, 0x0f, 0x8f,
		0x47, 0x0b, 0xde, 0x7e, 0x3f, 0x5d, 0xf0, 0xe2, 0x55, 0x7b, 0xaf, 0xfb, 0xc7, 0x49, 0x74, 0x7e,
		0x10, 0x1f, 0xa7, 0x61, 0xfb, 0x64, 0xb4, 0xda, 0xe3, 0x6f, 0xed, 0x8f, 0xe3, 0xa5, 0xdd, 0x2b,
		0x16, 0x7b, 0xe1, 0x27, 0xed, 0xd3, 0xd1, 0x5a, 0x73, 0x65, 0xa9, 0xe1, 0x99, 0x18, 0x89, 0x8f,
		0x43, 0xc8, 0x6f, 0x51, 0x83, 0xd8, 0x3b, 0x8c, 0xb2, 0x7c, 0x68, 0xd0, 0xa6, 0xa2, 0xb5, 0xf7,
		0x2e, 0x8a, 0xf7, 0x7b, 0xe1, 0x10, 0xc0, 0x67, 0xb6, 0x08, 0xbc, 0xf7, 0x2e, 0xf8, 0x7a, 0x6b,
		0x66, 0xcd, 0x57, 0xad, 0xd6, 0xf6, 0x4e, 0xab, 0xb5, 0xbe, 0xb3, 0xb9, 0xb3, 0xbe, 0xbb, 0xb5,
		0xd5, 0xdc, 0x6e, 0x1a, 0x3a, 0x2f, 0xe7, 0x1d, 0xa5, 0xdd, 0x30, 0x0d, 0xbb, 0x6f, 0x86, 0xa6,
		0x17, 0x0f, 0x7a, 0x3d, 0x3c, 0xd2, 0x3e, 0x52, 0xa9, 0x3d, 0x42, 0xf1, 0x4c, 0x5d, 0x65, 0x5d,
		0x37, 0x4c, 0x62, 0x03, 0x8d, 0xe8, 0xe7, 0x7e, 0xdd, 0x19, 0x28, 0xc7, 0x38, 0x6b, 0xb1, 0xad,
		0x66, 0x31, 0xcd, 0x40, 0x04, 0xab, 0x7e, 0xe4, 0xd2, 0x0d, 0x54, 0x7a, 0xe1, 0x41, 0x67, 0x64,
		0xa5, 0x80, 0x34, 0xa5, 0x3d, 0x43, 0xcf, 0xf7, 0xa3, 0xee, 0x5a, 0x18, 0x77, 0xfb, 0x49, 0x14,
		0xe7, 0x6b, 0x9d, 0xa4, 0x97, 0xa4, 0x4a, 0x7e, 0x64, 0x83, 0xf3, 0xd8, 0xe1, 0x38, 0xa6, 0x39,
		0x8d, 0x0d, 0x0e, 0xa3, 0xe5, 0x3e, 0x46, 0xf2, 0x78, 0x95, 0xf3, 0xb7, 0x62, 0xb2, 0xae, 0x5a,
		0x92, 0xd6, 0x49, 0xc9, 0xf2, 0x09, 0x51, 0x76, 0x44, 0xe1, 0xd8, 0xa1, 0x1d, 0x33, 0xaa, 0x19,
		0x2b, 0x14, 0xa2, 0x44, 0x75, 0xa2, 0x83, 0x6c, 0x5c, 0x90, 0xf3, 0x4e, 0x99, 0x91, 0x84, 0xfc,
		0x5f, 0xcb, 0xef, 0x2b, 0xe6, 0xef, 0x82, 0x8e, 0x5e, 0x01, 0x07, 0x97, 0xf1, 0x6c, 0xf7, 0x7e,
		0x26, 0xe0, 0x63, 0xde, 0xd4, 0x8e, 0x92, 0x41, 0xee, 0xf7, 0x93, 0x2c, 0x17, 0xf3, 0xb2, 0xd9,
		0x55, 0x05, 0x77, 0x67, 0x20, 0x14, 0x59, 0xa6, 0x3b, 0x84, 0x84, 0x86, 0x93, 0xde, 0xb8, 0xab,
		0xb1, 0x11, 0x57, 0x77, 0x63, 0xad, 0xd6, 0x46, 0x59, 0xf5, 0x8d, 0xaf, 0xea, 0x1b, 0x59, 0xd5,
		0x37, 0xa6, 0xd6, 0x0b, 0xf3, 0xbc, 0x8d, 0x64, 0x8b, 0x78, 0xde, 0x84, 0x2d, 0x88, 0x3b, 0xce,
		0x34, 0x5c, 0xa8, 0xb0, 0x15, 0xe1, 0x04, 0xa0, 0x96, 0x08, 0x34, 0x13, 0x82, 0x8d, 0xc4, 0xa0,
		0x9d, 0x20, 0xcc, 0x24, 0x0a, 0x33, 0x09, 0xc3, 0x4c, 0xe2, 0x58, 0x8d, 0xe2, 0x99, 0x74, 0x42,
		0x99, 0x4f, 0x2c, 0x7a, 0xfe, 0x36, 0x97, 0x5f, 0xb4, 0x7c, 0x4d, 0x27, 0xcd, 0xa8, 0xa7, 0x1b,
		0x0b, 0x69, 0xc7, 0x56, 0xfa, 0xb1, 0x92, 0x86, 0xcc, 0xa5, 0x23, 0x73, 0x69, 0xc9, 0x5c, 0x7a,
		0xd2, 0x49, 0x53, 0x4a, 0xe9, 0x4a, 0x3d, 0x6d, 0x15, 0x13, 0x18, 0xef, 0xe7, 0x50, 0xf7, 0xd3,
		0x69, 0xf4, 0xd2, 0xdc, 0x5e, 0x72, 0x37, 0x9d, 0x29, 0xef, 0x5e, 0x37, 0x73, 0x0e, 0xde, 0xd2,
		0x79, 0x77, 0x9b, 0xe7, 0xda, 0xad, 0x9d, 0x5f, 0x37, 0x7b, 0x4e, 0xdd, 0xec, 0x79, 0x74, 0xb3,
		0xe7, 0xce, 0x57, 0x7b, 0x3b, 0xb4, 0x99, 0xf3, 0xe2, 0x45, 0xdc, 0xe9, 0x85, 0xc1, 0x45, 0x1a,
		0x5e, 0x58, 0x08, 0x3a, 0x53, 0xd6, 0xb5, 0x63, 0x60, 0x2e, 0xc7, 0x93, 0x2e, 0xf2, 0x2f, 0xbf,
		0x8c, 0xcf, 0xb1, 0x36, 0xc6, 0x89, 0x7c, 0x55, 0xb7, 0x0a, 0x2b, 0x32, 0xaf, 0xe9, 0x4e, 0x5d,
		0x3b, 0x98, 0xae, 0x98, 0x11, 0xb0, 0x0e, 0x58, 0x07, 0xac, 0x03, 0xd6, 0x01, 0xeb, 0x80, 0x75,
		0xc0, 0xba, 0x4a, 0xc2, 0xba, 0x22, 0x97, 0x83, 0xec, 0xc4, 0x1f, 0xc6, 0xe4, 0x2c, 0x96, 0x1d,
		0x60, 0x37, 0x9d, 0x10, 0xb8, 0x0e, 0x5c, 0x07, 0xae, 0x03, 0xd7, 0x81, 0xeb, 0xc0, 0x75, 0xe0,
		0xba, 0x4a, 0xe2, 0xba, 0x69, 0x2a, 0x07, 0xd6, 0x89, 0x3f, 0x8b, 0xb1, 0xee, 0x9f, 0x19, 0x50,
		0x67, 0x41, 0x86, 0x50, 0x79, 0x43, 0x11, 0x90, 0x0e, 0x48, 0x07, 0xa4, 0x03, 0xd2, 0x01, 0xe9,
		0xf4, 0x37, 0x28, 0x15, 0x13, 0x19, 0x09, 0x70, 0x46, 0x71, 0x37, 0xb4, 0x73, 0xf1, 0xc2, 0xec,
		0x7c, 0xdf, 0x6c, 0x6e, 0x56, 0x54, 0x4b, 0x4d, 0x5d, 0xf1, 0x61, 0xee, 0x4a, 0x0f, 0x8b, 0x57,
		0x78, 0xd8, 0xbe, 0xb2, 0xc3, 0xea, 0x15, 0x1d, 0xe6, 0xaf, 0xe4, 0x30, 0x7f, 0x05, 0x87, 0xf9,
		0x2b, 0x37, 0xd0, 0xa3, 0x36, 0x59, 0x63, 0x31, 0x5c, 0x6b, 0xb1, 0x58, 0x73, 0xb9, 0xaf, 0xf6,
		0xf2, 0x0f, 0xff, 0x1b, 0x41, 0x8a, 0x2c, 0xcc, 0xb3, 0xe2, 0xd5, 0xa4, 0x52, 0x33, 0x86, 0x19,
		0x88, 0xc5, 0x5a, 0x71, 0x4a, 0x23, 0x3b, 0xe8, 0x17, 0xbc, 0xd1, 0xc2, 0x4e, 0x7a, 0xe0, 0x28,
		0x70, 0x14, 0x38, 0x0a, 0x1c, 0x05, 0x8e, 0x02, 0x47, 0xc5, 0xe3, 0xd6, 0x20, 0x8a, 0xf3, 0xcd,
		0x0d, 0x83, 0x68, 0xd4, 0x12, 0x18, 0x3d, 0x09, 0xe2, 0xcb, 0xe1, 0x6a, 0x7d, 0x36, 0x15, 0x03,
		0x0c, 0x5e, 0x3f, 0xf6, 0x2e, 0x8a, 0xed, 0x5e, 0x3d, 0x6c, 0xfc, 0x42, 0xdf, 0x4f, 0x41, 0x6f,
		0x10, 0x1a, 0x9e, 0xdf, 0x6f, 0x69, 0xd0, 0xc9, 0xa3, 0x24, 0x7e, 0x1b, 0x5d, 0x46, 0x63, 0x4d,
		0x6f, 0x2e, 0xe5, 0x7e, 0x8c, 0x4b, 0x04, 0x5f, 0x71, 0x89, 0x25, 0x5d, 0xa2, 0xb5, 0xb1, 0xdb,
		0xda, 0xdd, 0xde, 0xd9, 0xd8, 0xdd, 0xc2, 0x37, 0xaa, 0x0d, 0xc8, 0xec, 0xcd, 0xe6, 0x8c, 0x22,
		0x91, 0x95, 0xd8, 0xe9, 0x75, 0x92, 0xab, 0xab, 0x41, 0x1c, 0xe5, 0xdf, 0xac, 0xb6, 0x30, 0xef,
		0x4e, 0x90, 0xc2, 0xd1, 0x7d, 0xd3, 0xa1, 0x70, 0xf4, 0x04, 0x93, 0xa2, 0x70, 0xf4, 0x24, 0x4b,
		0xa7, 0x70, 0xb4, 0xe4, 0x04, 0x29, 0x1c, 0x55, 0x88, 0x49, 0xd0, 0xc7, 0xfc, 0x89, 0x34, 0x58,
		0xc1, 0x3e, 0xe6, 0x14, 0x57, 0x44, 0x61, 0x56, 0xbc, 0xfe, 0x46, 0x2b, 0xd3, 0x26, 0x4a, 0x35,
		0xa3, 0x1d, 0xb1, 0xe0, 0x93, 0x46, 0x34, 0x24, 0xc0, 0xa5, 0xe0, 0x52, 0x70, 0x29, 0xb8, 0x14,
		0x5c, 0x0a, 0x2e, 0x15, 0x8f, 0x5b, 0x51, 0xdf, 0x0f, 0xba, 0xdd, 0x34, 0xcc, 0x32, 0x8b, 0xd0,
		0x74, 0xd7, 0xd0, 0x9c, 0x26, 0xcf, 0x90, 0xa6, 0xe6, 0xa3, 0x2d, 0xeb, 0xba, 0x65, 0xd0, 0xb6,
		0x16, 0x6c, 0xec, 0x95, 0xc1, 0xb9, 0x1d, 0x07, 0x79, 0x1e, 0xa6, 0xb1, 0x39, 0x73, 0x2b, 0x26,
		0xf8, 0xfc, 0xf9, 0xe7, 0x75, 0x7f, 0xf7, 0xec, 0xfb, 0xe7, 0xa6, 0xbf, 0x7b, 0x36, 0x7e, 0xd9,
		0x1c, 0x7d, 0x1b, 0xbf, 0xde, 0xf8, 0xbc, 0xee, 0xb7, 0xa6, 0xaf, 0xb7, 0x3e, 0xaf, 0xfb, 0x5b,
		0x67, 0x2f, 0x7e, 0xff, 0xfd, 0x97, 0x17, 0x7f, 0x6f, 0xde, 0x3c, 0xfd, 0x0f, 0x3d, 0x73, 0x4b,
		0x70, 0x66, 0xd1, 0x64, 0x8e, 0x4e, 0x0f, 0xfe, 0x63, 0xde, 0x6e, 0xfe, 0x2b, 0x69, 0x38, 0xff,
		0x32, 0x68, 0x39, 0xb6, 0xda, 0x8a, 0x2f, 0x49, 0x66, 0x8f, 0x4e, 0x66, 0xdb, 0x24, 0xb3, 0x5a,
		0x27, 0xb3, 0xc0, 0xbf, 0xd8, 0xf3, 0x7f, 0x3b, 0xfb, 0xbb, 0xf9, 0xb2, 0x75, 0xf3, 0xfa, 0xc5,
		0xdf, 0x3b, 0x37, 0x77, 0x7f, 0xf8, 0xfd, 0xbe, 0x5f, 0x6b, 0xbe, 0xdc, 0xb9, 0x79, 0xfd, 0xc0,
		0xbf, 0x6c, 0xdf, 0xbc, 0x7e, 0xe4, 0x7b, 0x6c, 0xdd, 0x3c, 0x5f, 0xf8, 0xd5, 0xe1, 0xcf, 0x37,
		0x1e, 0xfa, 0x83, 0xd6, 0x03, 0x7f, 0xb0, 0xf9, 0xd0, 0x1f, 0x6c, 0x3e, 0xf0, 0x07, 0x0f, 0x4e,
		0x69, 0xe3, 0x81, 0x3f, 0xd8, 0xba, 0xf9, 0xbe, 0xf0, 0xfb, 0xcf, 0xef, 0xff, 0xd5, 0xed, 0x9b,
		0x17, 0xdf, 0x1f, 0xfa, 0xb7, 0x9d, 0x9b, 0xef, 0xaf, 0x5f, 0x90, 0xda, 0xeb, 0x97, 0xda, 0x71,
		0x23, 0x79, 0x37, 0x02, 0xe8, 0x54, 0xa2, 0x1a, 0xb5, 0xc6, 0xfe, 0x29, 0x4b, 0xd0, 0xd3, 0x0b,
		0xbf, 0xe6, 0xbe, 0xf9, 0x3d, 0x54, 0xf7, 0x4d, 0x92, 0x7e, 0xd5, 0x7d, 0xd3, 0xa1, 0x5f, 0xf5,
		0x04, 0xb3, 0xa2, 0x5f, 0xf5, 0x24, 0x4b, 0xa7, 0x5f, 0xb5, 0xe4, 0x04, 0xe9, 0x57, 0x55, 0xa8,
		0x20, 0xc3, 0x3e, 0xaa, 0x9f, 0xa9, 0xbd, 0x54, 0x6f, 0x1f, 0xd5, 0x6d, 0x6c, 0x11, 0x85, 0xd9,
		0xdc, 0x7f, 0xb3, 0x9f, 0xca, 0x28, 0x6a, 0x8d, 0xe2, 0xeb, 0xa0, 0x17, 0x75, 0xfd, 0x34, 0x0c,
		0xb2, 0x24, 0xb6, 0x07, 0x58, 0xef, 0xcc, 0x0f, 0xac, 0x0a, 0x56, 0x05, 0xab, 0x82, 0x55, 0xc1,
		0xaa, 0x60, 0xd5, 0x15, 0xc3, 0xaa, 0x51, 0x37, 0x8c, 0xf3, 0x28, 0xff, 0x66, 0x14, 0xaf, 0x1a,
		0x3a, 0x1d, 0xec, 0x1d, 0x4c, 0x96, 0xea, 0x4d, 0x90, 0x19, 0x0c, 0xa9, 0xd3, 0x07, 0x7a, 0xf0,
		0xfe, 0xd3, 0xde, 0xe1, 0xc1, 0xdb, 0xf6, 0xc9, 0xd1, 0xc7, 0x0f, 0xfb, 0xed, 0x93, 0xfd, 0xbd,
		0xd3, 0xa3, 0xf7, 0xd6, 0xa2, 0xeb, 0xe8, 0x10, 0x78, 0x66, 0xb2, 0x4d, 0x64, 0xf4, 0x54, 0xff,
		0xdd, 0xa7, 0xfb, 0xeb, 0xe1, 0xc7, 0xd3, 0x0f, 0xfb, 0x27, 0xed, 0xc3, 0xa3, 0xa3, 0x63, 0x0f,
		0xd1, 0x86, 0xda, 0x3c, 0xd7, 0xa3, 0x93, 0x83, 0x7f, 0x1f, 0xbc, 0xdf, 0xfb, 0x70, 0x74, 0xc2,
		0x53, 0xad, 0xcf, 0x53, 0xdd, 0x3b, 0xc5, 0x51, 0xeb, 0x16, 0x80, 0x8f, 0xde, 0xff, 0xb6, 0xff,
		0xd6, 0x43, 0x13, 0xe4, 0x1f, 0xbf, 0xce, 0xe0, 0x23, 0xc6, 0x66, 0x61, 0xa1, 0x3a, 0xd8, 0x0b,
		0xb2, 0xdc, 0xbf, 0x4a, 0xba, 0xd1, 0x45, 0x14, 0x76, 0xed, 0x15, 0x07, 0xe7, 0xa7, 0x47, 0x6d,
		0xf0, 0xbe, 0xe9, 0x50, 0x1b, 0x7c, 0x82, 0x41, 0x51, 0x1b, 0x7c, 0x92, 0xa5, 0x53, 0x1b, 0x5c,
		0x72, 0x82, 0xd4, 0x06, 0x2b, 0x84, 0x7d, 0x0d, 0xd7, 0x06, 0xf3, 0xe8, 0x2a, 0xcc, 0xa3, 0xce,
		0x9f, 0xd9, 0x76, 0xcb, 0x60, 0x6d, 0xd0, 0xd0, 0x31, 0x02, 0xef, 0x63, 0x3c, 0xd6, 0x08, 0xf4,
		0xe2, 0x20, 0x4e, 0xb2, 0xb0, 0x93, 0xc4, 0x5d, 0x53, 0x67, 0x55, 0x51, 0xbb, 0x7d, 0xe4, 0x42,
		0xa1, 0x76, 0xfb, 0xf3, 0xd3, 0x43, 0xed, 0xb6, 0x8e, 0xf5, 0x18, 0xd4, 0x6e, 0x4b, 0x70, 0x89,
		0xe6, 0xab, 0x56, 0x6b, 0x7b, 0xa7, 0xd5, 0x5a, 0xdf, 0xd9, 0xdc, 0x59, 0xdf, 0xdd, 0xda, 0x6a,
		0x6e, 0x37, 0xd1, 0xbd, 0xad, 0x38, 0x7e, 0xb4, 0x37, 0x1b, 0xce, 0x6d, 0x98, 0x89, 0xa2, 0xde,
		0xf4, 0x5e, 0x71, 0x73, 0xd5, 0xad, 0xe9, 0xc4, 0x8c, 0xb0, 0x9f, 0xb7, 0xe1, 0x45, 0x30, 0xe8,
		0x8d, 0xa8, 0xea, 0x3a, 0xb5, 0xb6, 0x7b, 0xa7, 0x43, 0xad, 0xed, 0x09, 0xe6, 0x4d, 0xad, 0xed,
		0x49, 0x96, 0x4e, 0xad, 0x6d, 0xc9, 0x09, 0x52, 0x6b, 0xab, 0x10, 0xaf, 0xe1, 0xd2, 0xa6, 0xa7,
		0x67, 0x41, 0x2e, 0x6d, 0xfa, 0xd1, 0x17, 0x65, 0xac, 0x5a, 0x72, 0x76, 0xca, 0x58, 0x55, 0x0f,
		0xf7, 0xf3, 0x2e, 0x41, 0x19, 0x6b, 0x69, 0x97, 0xe0, 0xd2, 0xa6, 0xba, 0x00, 0x32, 0x7b, 0xb3,
		0xa1, 0x78, 0x65, 0x26, 0x76, 0x7a, 0x93, 0xc3, 0x91, 0xc9, 0x20, 0x0f, 0xed, 0x15, 0xb0, 0x6e,
		0x4f, 0x8e, 0x82, 0xd1, 0x7d, 0xd3, 0xa1, 0x60, 0xf4, 0x04, 0x73, 0xa2, 0x60, 0xf4, 0x24, 0x4b,
		0xa7, 0x60, 0xb4, 0xe4, 0x04, 0x29, 0x18, 0x55, 0x88, 0x41, 0x18, 0x2e, 0x18, 0x9d, 0x27, 0x49,
		0x2f, 0x0c, 0x62, 0x8b, 0x87, 0x36, 0x9b, 0x40, 0x39, 0x03, 0x33, 0x50, 0x76, 0x21, 0x6f, 0x2f,
		0x8e, 0x93, 0x3c, 0x18, 0xb2, 0x31, 0x13, 0x0e, 0xe4, 0x65, 0x9d, 0x2f, 0xe1, 0x55, 0xd0, 0x9f,
		0x88, 0xce, 0x34, 0x92, 0x7e, 0x18, 0x77, 0x46, 0x40, 0xc9, 0x8f, 0xc3, 0xfc, 0xaf, 0x24, 0xfd,
		0xd3, 0x8f, 0xe2, 0x2c, 0x0f, 0xe2, 0x4e, 0xd8, 0xb8, 0xfb, 0x83, 0x6c, 0xe1, 0x27, 0x8d, 0x7e,
		0x9a, 0xe4, 0x49, 0x27, 0xe9, 0x65, 0xc5, 0xab, 0xc6, 0xf9, 0x65, 0xbf, 0x91, 0x46, 0xe7, 0x8d,
		0xe0, 0x22, 0xf2, 0xb3, 0xe0, 0x22, 0xca, 0x8a, 0x57, 0x8d, 0xd1, 0x3d, 0x03, 0x59, 0x9a, 0x87,
		0x7e, 0x3f, 0xe9, 0x45, 0x9d, 0x6f, 0x8d, 0x38, 0x8c, 0x2e, 0xbf, 0x9c, 0x27, 0x69, 0x56, 0xbc,
		0x6a, 0x04, 0xdd, 0x3f, 0x46, 0xd9, 0x20, 0x19, 0xe4, 0x7e, 0x3f, 0xc9, 0xf2, 0xc6, 0x08, 0xe2,
		0x66, 0xe3, 0x6f, 0x63, 0xa1, 0x1b, 0x03, 0xce, 0xee, 0x65, 0x79, 0x3a, 0xe8, 0xe4, 0xf1, 0x24,
		0x0a, 0x1d, 0x15, 0xab, 0xf8, 0x7e, 0xbc, 0x42, 0x07, 0x93, 0x05, 0x6a, 0xdf, 0xf9, 0xef, 0xec,
		0xee, 0x0f, 0xda, 0xc7, 0xd3, 0x15, 0x2c, 0x5e, 0xb5, 0xdf, 0x5c, 0xf6, 0xdb, 0x27, 0xd1, 0x79,
		0x7b, 0xef, 0x22, 0x3a, 0x1d, 0x2e, 0xe0, 0xf4, 0x45, 0xfb, 0xa0, 0x7f, 0xdd, 0x3a, 0x4d, 0xf3,
		0xf0, 0x78, 0xb4, 0x7a, 0xed, 0xf7, 0xd3, 0xd5, 0x2b, 0x5e, 0xb5, 0xf7, 0xba, 0x7f, 0x9c, 0x44,
		0xe7, 0x47, 0x83, 0xfc, 0x38, 0xc9, 0xf2, 0xf6, 0xc9, 0x68, 0xe9, 0xc6, 0xdf, 0xda, 0xa7, 0xa3,
		0xa5, 0x7b, 0xb6, 0x9a, 0x91, 0x40, 0x31, 0x0a, 0x78, 0x83, 0xf8, 0xcf, 0x38, 0xf9, 0x2b, 0xf6,
		0x83, 0x3c, 0x4f, 0xa3, 0xf3, 0xe1, 0x13, 0x51, 0x8f, 0x04, 0xb3, 0x7e, 0xcb, 0xe2, 0xdc, 0x94,
		0xe3, 0xe5, 0x34, 0x7b, 0x2a, 0x4f, 0xc3, 0x0a, 0x79, 0xb4, 0x44, 0x1a, 0x6d, 0x92, 0x45, 0x6b,
		0x24, 0xd1, 0x2c, 0x39, 0x34, 0x4b, 0x0a, 0xcd, 0x92, 0xc1, 0xd5, 0x46, 0xae, 0x6f, 0xa3, 0xd4,
		0x46, 0xd8, 0x59, 0x48, 0x52, 0xf6, 0xaa, 0xb1, 0x8b, 0x53, 0xb4, 0x55, 0x93, 0x6d, 0x52, 0x93,
		0x35, 0x9f, 0x5e, 0x6d, 0xa7, 0x59, 0xab, 0xe9, 0xd6, 0x7c, 0xda, 0x35, 0x9f, 0x7e, 0xcd, 0xa7,
		0x61, 0x3b, 0xa5, 0xac, 0x35, 0x43, 0x35, 0x59, 0x2b, 0xe9, 0xb9, 0x98, 0xd0, 0x30, 0xf7, 0xf9,
		0xb9, 0xb5, 0x4a, 0xf1, 0x5c, 0x44, 0x9d, 0x4d, 0xd1, 0x98, 0xeb, 0xd9, 0xdc, 0xf9, 0x62, 0x2e,
		0x5d, 0x5b, 0x4e, 0xdb, 0xd5, 0x48, 0xdf, 0xd6, 0xd3, 0x78, 0x65, 0xd2, 0x79, 0x65, 0xd2, 0x7a,
		0x65, 0xd2, 0xbb, 0xad, 0x34, 0x6f, 0x2c, 0xdd, 0x17, 0x4f, 0xf1, 0x83, 0xc5, 0x04, 0xbb, 0x66,
		0xfb, 0xde, 0x87, 0x05, 0x36, 0xbc, 0x63, 0xf3, 0xee, 0xcd, 0xe9, 0x3d, 0x10, 0xe3, 0xeb, 0x1c,
		0x66, 0x60, 0x85, 0xbd, 0x92, 0xd6, 0x5d, 0xd3, 0x1b, 0x37, 0x26, 0xcd, 0x02, 0x5f, 0x2b, 0x7d,
		0xd3, 0x7b, 0xbd, 0x11, 0xd0, 0x0b, 0xe8, 0x05, 0xf4, 0x02, 0x7a, 0x01, 0xbd, 0x64, 0xd6, 0xfb,
		0x9f, 0xa2, 0xb5, 0x5a, 0x57, 0x31, 0xb1, 0x11, 0x46, 0xeb, 0x85, 0x86, 0x8f, 0x19, 0xce, 0x95,
		0xbe, 0x86, 0x33, 0x7d, 0xc9, 0xd9, 0xaf, 0x1a, 0x81, 0x82, 0x2a, 0x80, 0x83, 0x6a, 0x81, 0x84,
		0xaa, 0x80, 0x85, 0xca, 0x81, 0x86, 0xca, 0x81, 0x87, 0xca, 0x81, 0x08, 0x9b, 0x60, 0xc2, 0x28,
		0xa8, 0x28, 0x9e, 0xae, 0xd9, 0x8a, 0xda, 0x42, 0xdc, 0x1c, 0x44, 0x71, 0xde, 0xdc, 0xb6, 0x1c,
		0x33, 0x27, 0x59, 0x7c, 0xdb, 0xf0, 0x14, 0x6d, 0xaa, 0x67, 0xdc, 0xfd, 0xb2, 0x9d, 0x73, 0xd6,
		0xac, 0xab, 0x6b, 0x54, 0x0c, 0x5e, 0x2e, 0x4c, 0xd7, 0xb8, 0xfa, 0xc6, 0xc2, 0x7c, 0x2b, 0xa0,
		0x38, 0x50, 0x91, 0x74, 0x34, 0xef, 0x62, 0xc1, 0x57, 0x5c, 0xcc, 0xb1, 0x8b, 0x6d, 0x6f, 0x6d,
		0x6d, 0x6e, 0xe1, 0x66, 0xab, 0x85, 0x45, 0xed, 0xcf, 0xee, 0xec, 0x19, 0xeb, 0x55, 0xd1, 0x30,
		0x6e, 0x78, 0x27, 0xdc, 0x02, 0xa5, 0xb0, 0xba, 0x23, 0xae, 0x22, 0x59, 0x85, 0xba, 0x60, 0x99,
		0xc6, 0x48, 0x5d, 0xb0, 0x54, 0xcf, 0xa1, 0x2e, 0xe8, 0x78, 0xc2, 0xd4, 0x05, 0x6b, 0x4c, 0xc4,
		0x2a, 0x56, 0x17, 0x7c, 0x55, 0x81, 0xb2, 0xe0, 0x16, 0x65, 0xc1, 0x25, 0xbf, 0x28, 0x0b, 0x52,
		0xb3, 0xa0, 0x2c, 0xb8, 0x82, 0xd9, 0x68, 0xde, 0xc5, 0x28, 0x0b, 0x3a, 0x77, 0xb1, 0x8d, 0x2d,
		0x8a, 0x82, 0x2b, 0x06, 0x44, 0xed, 0xcf, 0x8e, 0xa2, 0x60, 0x65, 0x83, 0xf8, 0xb8, 0xd2, 0x76,
		0x3d, 0x89, 0x2e, 0x55, 0xa8, 0x0a, 0x8e, 0xe7, 0x4a, 0x59, 0xf0, 0x67, 0xa6, 0x47, 0x59, 0xb0,
		0x44, 0x6b, 0xa4, 0x2c, 0x58, 0xaa, 0xe7, 0x50, 0x16, 0x74, 0x3c, 0x61, 0xca, 0x82, 0x35, 0x26,
		0x62, 0x15, 0x2a, 0x0b, 0x9e, 0x47, 0x71, 0x90, 0x7e, 0xab, 0x40, 0x5d, 0x70, 0xd7, 0xf0, 0x14,
		0x0f, 0xc3, 0xf8, 0x72, 0x74, 0x30, 0x97, 0xc2, 0xe0, 0xb2, 0x55, 0x0b, 0x0a, 0x83, 0xce, 0xab,
		0x16, 0x4d, 0x6a, 0x16, 0x2b, 0x96, 0x8f, 0xe6, 0x5d, 0x8c, 0xc2, 0xa0, 0x73, 0x17, 0x63, 0xbf,
		0xe0, 0x0a, 0x82, 0x51, 0xfb, 0xb3, 0xa3, 0x34, 0x58, 0xd9, 0x30, 0xee, 0x85, 0x5f, 0xf3, 0x30,
		0xee, 0x86, 0x5d, 0xfb, 0x85, 0xc1, 0x62, 0xa6, 0x94, 0x05, 0x7f, 0x66, 0x7a, 0x94, 0x05, 0x4b,
		0xb4, 0x45, 0xca, 0x82, 0xa5, 0x7a, 0x0e, 0x65, 0x41, 0xc7, 0x13, 0xa6, 0x2c, 0x58, 0x63, 0x1a,
		0x56, 0xa5, 0xb2, 0xa0, 0xb9, 0x2b, 0xd3, 0x1e, 0x4a, 0xe3, 0x46, 0xae, 0x50, 0x03, 0xd4, 0xfe,
		0xcc, 0x33, 0x4c, 0xfa, 0x43, 0xe6, 0x19, 0xf4, 0xec, 0x83, 0xda, 0x62, 0xa6, 0x80, 0x5a, 0x40,
		0x2d, 0xa0, 0x16, 0x50, 0x0b, 0xa8, 0x05, 0xd4, 0x02, 0x6a, 0x01, 0xb5, 0x80, 0x5a, 0x9c, 0x62,
		0xfe, 0x19, 0xf6, 0x83, 0x34, 0x8f, 0xaa, 0x80, 0x69, 0xa7, 0x13, 0x05, 0xd2, 0x02, 0x69, 0x81,
		0xb4, 0x40, 0x5a, 0x20, 0x2d, 0x90, 0x16, 0x48, 0x0b, 0xa4, 0x05, 0xd2, 0xe2, 0x14, 0xf3, 0xcf,
		0x30, 0x4f, 0x83, 0x38, 0x8b, 0xf2, 0xe8, 0xba, 0x02, 0xe7, 0x92, 0x6e, 0xcd, 0x15, 0x60, 0x0b,
		0xb0, 0x05, 0xd8, 0x02, 0x6c, 0x01, 0xb6, 0x00, 0x5b, 0x80, 0x2d, 0xc0, 0x16, 0x60, 0xcb, 0x8c,
		0x8c, 0xba, 0xa8, 0xb7, 0x17, 0xc7, 0x49, 0x1e, 0xe4, 0x51, 0x62, 0xf3, 0x00, 0x94, 0x97, 0x75,
		0xbe, 0x84, 0x57, 0x41, 0x7f, 0x72, 0x01, 0x65, 0x23, 0xe9, 0x87, 0x71, 0x67, 0x04, 0x14, 0xfd,
		0x38, 0xcc, 0xff, 0x4a, 0xd2, 0x3f, 0xfd, 0x28, 0xce, 0xf2, 0x20, 0xee, 0x84, 0x8d, 0xbb, 0x3f,
		0xc8, 0x16, 0x7e, 0xd2, 0xe8, 0xa7, 0x49, 0x9e, 0x74, 0x92, 0x5e, 0x56, 0xbc, 0x6a, 0x9c, 0x5f,
		0xf6, 0x1b, 0x69, 0x74, 0xde, 0x08, 0x2e, 0x22, 0x3f, 0x0b, 0x2e, 0xa2, 0xac, 0x78, 0xd5, 0x88,
		0xfa, 0xd7, 0x2d, 0x3f, 0x4b, 0xf3, 0xd0, 0xef, 0x27, 0xbd, 0xa8, 0xf3, 0xad, 0x11, 0x87, 0xd1,
		0xe5, 0x97, 0xf3, 0x24, 0xcd, 0x8a, 0x57, 0x8d, 0xa0, 0xfb, 0xc7, 0x28, 0x5b, 0x25, 0x83, 0xdc,
		0xef, 0x27, 0x59, 0xde, 0x48, 0x93, 0x41, 0x1e, 0x66, 0xe3, 0x6f, 0x8d, 0x41, 0xfc, 0x67, 0x9c,
		0xfc, 0x15, 0xfb, 0x41, 0x9e, 0xa7, 0xd1, 0xf9, 0xe8, 0x1f, 0x16, 0x7e, 0xd4, 0xb0, 0x78, 0x01,
		0xe2, 0x78, 0xed, 0xf3, 0x74, 0xd0, 0xc9, 0xe3, 0x49, 0x68, 0x3c, 0x2a, 0x96, 0xfe, 0xfd, 0x78,
		0x59, 0x0f, 0x26, 0xab, 0xda, 0xbe, 0xf3, 0xdf, 0xd9, 0xdd, 0x1f, 0xb4, 0x8f, 0xa7, 0xcb, 0x5e,
		0xbc, 0x6a, 0xbf, 0xb9, 0xec, 0xb7, 0x4f, 0xa2, 0xf3, 0xf6, 0xde, 0x45, 0x74, 0x3a, 0x5c, 0xf5,
		0xe9, 0x8b, 0xf6, 0x41, 0xff, 0xba, 0x75, 0x9a, 0xe6, 0xe1, 0xf1, 0x68, 0xc9, 0xdb, 0xef, 0xa7,
		0x4b, 0x5e, 0xbc, 0x6a, 0xef, 0x75, 0xff, 0x38, 0x89, 0xce, 0x8f, 0x06, 0xf9, 0x71, 0x92, 0xe5,
		0xed, 0x93, 0xd1, 0x7a, 0x8f, 0xbf, 0xb5, 0x3f, 0x8e, 0x17, 0x77, 0xaf, 0x58, 0xee, 0x85, 0x9f,
		0xb4, 0x4f, 0x47, 0xab, 0xcd, 0xb5, 0xa5, 0x86, 0x67, 0x62, 0x24, 0x46, 0x0e, 0x61, 0xbf, 0x45,
		0x1d, 0x62, 0xef, 0x30, 0xca, 0xf2, 0xa1, 0x41, 0x9b, 0x8a, 0xd8, 0xde, 0xbb, 0x28, 0xde, 0xef,
		0x85, 0x43, 0x10, 0x9f, 0xd9, 0x22, 0xf1, 0xde, 0xbb, 0xe0, 0xeb, 0xad, 0x99, 0x35, 0x5f, 0xb5,
		0x5a, 0xdb, 0x3b, 0xad, 0xd6, 0xfa, 0xce, 0xe6, 0xce, 0xfa, 0xee, 0xd6, 0x56, 0x73, 0xbb, 0x69,
		0xe8, 0xcc, 0x9c, 0x77, 0x94, 0x76, 0xc3, 0x34, 0xec, 0xbe, 0x19, 0x9a, 0x5e, 0x3c, 0xe8, 0xf5,
		0xf0, 0x48, 0xfb, 0x68, 0x65, 0x05, 0x50, 0x8a, 0x67, 0xea, 0x42, 0xeb, 0xfa, 0xe1, 0x12, 0x1b,
		0x88, 0x44, 0x3f, 0xff, 0xeb, 0xce, 0x40, 0x39, 0xce, 0x59, 0x8b, 0x6f, 0xb5, 0x8b, 0x6b, 0x06,
		0xa2, 0x58, 0x1d, 0xa2, 0x97, 0x6e, 0xb0, 0xd2, 0x0b, 0x11, 0x3a, 0x23, 0x2b, 0x05, 0xa5, 0x29,
		0xfd, 0x19, 0x7a, 0xbf, 0x1f, 0x75, 0xd7, 0xc2, 0xb8, 0xdb, 0x4f, 0xa2, 0x38, 0x5f, 0xeb, 0x24,
		0xbd, 0x24, 0x55, 0xf2, 0x24, 0x1b, 0xdc, 0xc7, 0x0e, 0xd7, 0x31, 0xcd, 0x6d, 0x6c, 0x70, 0x19,
		0x2d, 0xf7, 0x31, 0x92, 0xcb, 0xab, 0x9d, 0xc3, 0x15, 0x13, 0x76, 0xf5, 0x12, 0xb5, 0x4e, 0x5a,
		0x96, 0x4f, 0x8a, 0xb2, 0x23, 0x0a, 0xc7, 0x0f, 0xed, 0xb8, 0x51, 0xd5, 0x78, 0xa1, 0x10, 0x29,
		0xaa, 0x14, 0x21, 0x64, 0x63, 0x83, 0x9c, 0x87, 0xca, 0x8c, 0x24, 0x14, 0x03, 0xb4, 0x7c, 0xbf,
		0x72, 0x3e, 0x2f, 0xe8, 0xec, 0x95, 0x70, 0x72, 0x19, 0xef, 0x76, 0xef, 0x6b, 0x02, 0x7e, 0xe6,
		0xcd, 0xd9, 0x52, 0x2a, 0xb7, 0x2f, 0x69, 0x76, 0x83, 0xc1, 0x9d, 0x09, 0x08, 0xc5, 0x96, 0xe9,
		0xbe, 0x21, 0xa1, 0xe1, 0xa4, 0xb7, 0xf3, 0x6a, 0x6c, 0xcf, 0xd5, 0xdd, 0x6e, 0xab, 0xb5, 0x7d,
		0x56, 0x7d, 0x3b, 0xac, 0xfa, 0xf6, 0x56, 0xf5, 0xed, 0xaa, 0xf5, 0x42, 0x3d, 0x6f, 0x23, 0xd9,
		0x72, 0x9e, 0x37, 0x61, 0x0c, 0xe2, 0x8e, 0x33, 0x0d, 0x17, 0x2a, 0x8c, 0x45, 0x38, 0x01, 0xa8,
		0x25, 0x02, 0xcd, 0x84, 0x60, 0x23, 0x31, 0x68, 0x27, 0x08, 0x33, 0x89, 0xc2, 0x4c, 0xc2, 0x30,
		0x93, 0x38, 0x56, 0xa3, 0x84, 0x26, 0x9d, 0x50, 0xe6, 0x13, 0x8b, 0x9e, 0xbf, 0xcd, 0xe5, 0x17,
		0x2d, 0x5f, 0xd3, 0x49, 0x33, 0xea, 0xe9, 0xc6, 0x42, 0xda, 0xb1, 0x95, 0x7e, 0xac, 0xa4, 0x21,
		0x73, 0xe9, 0xc8, 0x5c, 0x5a, 0x32, 0x97, 0x9e, 0x74, 0xd2, 0x94, 0x52, 0xba, 0x52, 0x4f, 0x5b,
		0xc5, 0x04, 0xc6, 0x3b, 0x3b, 0xd4, 0xfd, 0x74, 0x1a, 0xbd, 0x34, 0x37, 0x9a, 0xdc, 0x4d, 0x67,
		0xca, 0xfb, 0xd9, 0xcd, 0x9c, 0x8e, 0xb7, 0x74, 0x0a, 0xde, 0xe6, 0x69, 0x77, 0x6b, 0xa7, 0xda,
		0xcd, 0x9e, 0x5e, 0x37, 0x7b, 0x4a, 0xdd, 0xec, 0x69, 0xf4, 0xd5, 0xde, 0x1c, 0x6d, 0xe6, 0x14,
		0x79, 0x11, 0x77, 0x7a, 0x61, 0x70, 0x91, 0x86, 0x17, 0x16, 0x82, 0xce, 0x94, 0x75, 0xed, 0x18,
		0x98, 0xcb, 0xf1, 0xa4, 0x8f, 0xfc, 0xcb, 0x2f, 0xe3, 0xb3, 0xad, 0x8d, 0x71, 0x22, 0x5f, 0xd5,
		0x4d, 0xc3, 0x8a, 0xcc, 0x6b, 0xba, 0x67, 0xd7, 0x0e, 0xa6, 0x2b, 0x66, 0x04, 0xac, 0x03, 0xd6,
		0x01, 0xeb, 0x80, 0x75, 0xc0, 0x3a, 0x60, 0x1d, 0xb0, 0xae, 0x92, 0xb0, 0xae, 0xc8, 0xe5, 0x20,
		0x3b, 0xf1, 0x87, 0x31, 0x39, 0x95, 0x65, 0x07, 0xd8, 0x4d, 0x27, 0x04, 0xae, 0x03, 0xd7, 0x81,
		0xeb, 0xc0, 0x75, 0xe0, 0x3a, 0x70, 0x1d, 0xb8, 0xae, 0x92, 0xb8, 0x6e, 0x9a, 0xca, 0x81, 0x75,
		0xe2, 0xcf, 0x62, 0xac, 0x05, 0x68, 0x06, 0xd4, 0x59, 0x90, 0x26, 0x54, 0xde, 0x50, 0x04, 0xa4,
		0x03, 0xd2, 0x01, 0xe9, 0x80, 0x74, 0x40, 0x3a, 0xfd, 0x0d, 0x4a, 0xc5, 0x44, 0x46, 0x92, 0x9c,
		0x51, 0xdc, 0x0d, 0xed, 0x5c, 0xc7, 0x30, 0x3b, 0xde, 0x37, 0x9b, 0x9b, 0x15, 0x1d, 0x53, 0x53,
		0x17, 0x7f, 0x98, 0xbb, 0xe8, 0xc3, 0xe2, 0xc5, 0x1e, 0xb6, 0x2f, 0xf2, 0xb0, 0x7a, 0x71, 0x87,
		0xf9, 0x8b, 0x3a, 0xcc, 0x5f, 0xcc, 0x61, 0xfe, 0x22, 0x0e, 0x14, 0xaa, 0x4d, 0xd6, 0x58, 0x0c,
		0xd7, 0x5a, 0x2c, 0xd6, 0x5c, 0xee, 0xab, 0xbd, 0xfc, 0xc3, 0xff, 0x46, 0x90, 0x22, 0x0b, 0xf3,
		0xac, 0x78, 0x35, 0xa9, 0xd4, 0x8c, 0x61, 0x06, 0xd2, 0xb1, 0x56, 0x9c, 0xd2, 0xc8, 0x0e, 0xfa,
		0x05, 0x6f, 0xb4, 0xb0, 0x93, 0x1e, 0x38, 0x0a, 0x1c, 0x05, 0x8e, 0x02, 0x47, 0x81, 0xa3, 0xc0,
		0x51, 0xf1, 0xb8, 0x35, 0x88, 0xe2, 0x7c, 0x73, 0xc3, 0x20, 0x1a, 0xb5, 0x04, 0x46, 0x4f, 0x82,
		0xf8, 0x72, 0xb8, 0x5a, 0x9f, 0x4d, 0xc5, 0x00, 0x83, 0x97, 0x92, 0xbd, 0x8b, 0x62, 0xbb, 0x17,
		0x12, 0x1b, 0xbf, 0xe6, 0xf7, 0x53, 0xd0, 0x1b, 0x84, 0x86, 0xe7, 0xf7, 0x5b, 0x1a, 0x74, 0xf2,
		0x28, 0x89, 0xdf, 0x46, 0x97, 0xd1, 0x58, 0xdd, 0x9b, 0xab, 0xba, 0x1f, 0xe3, 0x12, 0xc1, 0x57,
		0x5c, 0x62, 0x49, 0x97, 0x68, 0x6d, 0xec, 0xb6, 0x76, 0xb7, 0x77, 0x36, 0x76, 0xb7, 0xf0, 0x8d,
		0x6a, 0x03, 0x32, 0x7b, 0xb3, 0x39, 0xa3, 0x48, 0x64, 0x25, 0x76, 0x7a, 0x9d, 0xe4, 0xea, 0x6a,
		0x10, 0x47, 0xf9, 0x37, 0xab, 0x2d, 0xcc, 0xbb, 0x13, 0xa4, 0x70, 0x74, 0xdf, 0x74, 0x28, 0x1c,
		0x3d, 0xc1, 0xa4, 0x28, 0x1c, 0x3d, 0xc9, 0xd2, 0x29, 0x1c, 0x2d, 0x39, 0x41, 0x0a, 0x47, 0x15,
		0x62, 0x12, 0xf4, 0x31, 0x7f, 0x22, 0x0d, 0x56, 0xb0, 0x8f, 0x39, 0xc5, 0x15, 0x51, 0x98, 0x15,
		0xaf, 0xbf, 0xd1, 0xca, 0xb4, 0x89, 0x52, 0xcd, 0x68, 0x47, 0x2c, 0xf8, 0xa4, 0x11, 0x0d, 0x09,
		0x70, 0x29, 0xb8, 0x14, 0x5c, 0x0a, 0x2e, 0x05, 0x97, 0x82, 0x4b, 0xc5, 0xe3, 0x56, 0xd4, 0xf7,
		0x83, 0x6e, 0x37, 0x0d, 0xb3, 0xcc, 0x22, 0x34, 0xdd, 0x35, 0x34, 0xa7, 0xc9, 0x33, 0xa4, 0xa9,
		0xf9, 0x68, 0xcb, 0xba, 0x6e, 0x19, 0xb4, 0xad, 0x05, 0x1b, 0x7b, 0x65, 0x70, 0x6e, 0xc7, 0x41,
		0x9e, 0x87, 0x69, 0x6c, 0xce, 0xdc, 0x8a, 0x09, 0x3e, 0x7f, 0xfe, 0x79, 0xdd, 0xdf, 0x3d, 0xfb,
		0xfe, 0xb9, 0xe9, 0xef, 0x9e, 0x8d, 0x5f, 0x36, 0x47, 0xdf, 0xc6, 0xaf, 0x37, 0x3e, 0xaf, 0xfb,
		0xad, 0xe9, 0xeb, 0xad, 0xcf, 0xeb, 0xfe, 0xd6, 0xd9, 0x8b, 0xdf, 0x7f, 0xff, 0xe5, 0xc5, 0xdf,
		0x9b, 0x37, 0x4f, 0xff, 0x43, 0xcf, 0xdc, 0x12, 0x9c, 0x59, 0x34, 0x99, 0xa3, 0xd3, 0x83, 0xff,
		0x98, 0xb7, 0x9b, 0xff, 0x4a, 0x1a, 0xce, 0xbf, 0x0c, 0x5a, 0x8e, 0xad, 0xb6, 0xe2, 0x4b, 0x92,
		0xd9, 0xa3, 0x93, 0xd9, 0x36, 0xc9, 0xac, 0xd6, 0xc9, 0x2c, 0xf0, 0x2f, 0xf6, 0xfc, 0xdf, 0xce,
		0xfe, 0x6e, 0xbe, 0x6c, 0xdd, 0xbc, 0x7e, 0xf1, 0xf7, 0xce, 0xcd, 0xdd, 0x1f, 0x7e, 0xbf, 0xef,
		0xd7, 0x9a, 0x2f, 0x77, 0x6e, 0x5e, 0x3f, 0xf0, 0x2f, 0xdb, 0x37, 0xaf, 0x1f, 0xf9, 0x1e, 0x5b,
		0x37, 0xcf, 0x17, 0x7e, 0x75, 0xf8, 0xf3, 0x8d, 0x87, 0xfe, 0xa0, 0xf5, 0xc0, 0x1f, 0x6c, 0x3e,
		0xf4, 0x07, 0x9b, 0x0f, 0xfc, 0xc1, 0x83, 0x53, 0xda, 0x78, 0xe0, 0x0f, 0xb6, 0x6e, 0xbe, 0x2f,
		0xfc, 0xfe, 0xf3, 0xfb, 0x7f, 0x75, 0xfb, 0xe6, 0xc5, 0xf7, 0x87, 0xfe, 0x6d, 0xe7, 0xe6, 0xfb,
		0xeb, 0x17, 0xa4, 0xf6, 0xfa, 0xa5, 0x76, 0xdc, 0x48, 0xde, 0x8d, 0x00, 0x3a, 0x95, 0xa8, 0x46,
		0xad, 0xb1, 0x7f, 0xca, 0x12, 0xf4, 0xf4, 0xc2, 0xaf, 0xb9, 0x6f, 0x7e, 0x0f, 0xd5, 0x7d, 0x93,
		0xa4, 0x5f, 0x75, 0xdf, 0x74, 0xe8, 0x57, 0x3d, 0xc1, 0xac, 0xe8, 0x57, 0x3d, 0xc9, 0xd2, 0xe9,
		0x57, 0x2d, 0x39, 0x41, 0xfa, 0x55, 0x15, 0x2a, 0xc8, 0xb0, 0x8f, 0xea, 0x67, 0x6a, 0x2f, 0xd5,
		0xdb, 0x47, 0x75, 0x1b, 0x5b, 0x44, 0x61, 0x36, 0xf7, 0xdf, 0xec, 0xa7, 0x32, 0x8a, 0x5a, 0xa3,
		0xf8, 0x3a, 0xe8, 0x45, 0x5d, 0x3f, 0x0d, 0x83, 0x2c, 0x89, 0xed, 0x01, 0xd6, 0x3b, 0xf3, 0x03,
		0xab, 0x82, 0x55, 0xc1, 0xaa, 0x60, 0x55, 0xb0, 0x2a, 0x58, 0x75, 0xc5, 0xb0, 0x6a, 0xd4, 0x0d,
		0xe3, 0x3c, 0xca, 0xbf, 0x19, 0xc5, 0xab, 0x86, 0x4e, 0x07, 0x7b, 0x07, 0x93, 0xa5, 0x7a, 0x13,
		0x64, 0x06, 0x43, 0xea, 0xf4, 0x81, 0x1e, 0xbc, 0xff, 0xb4, 0x77, 0x78, 0xf0, 0xb6, 0x7d, 0x72,
		0xf4, 0xf1, 0xc3, 0x7e, 0xfb, 0x64, 0x7f, 0xef, 0xf4, 0xe8, 0xbd, 0xb5, 0xe8, 0x3a, 0x3a, 0x04,
		0x9e, 0x99, 0x6c, 0x13, 0x19, 0x3d, 0xd5, 0x7f, 0xf7, 0xe9, 0xfe, 0x7a, 0xf8, 0xf1, 0xf4, 0xc3,
		0xfe, 0x49, 0xfb, 0xf0, 0xe8, 0xe8, 0xd8, 0x43, 0xb4, 0xa1, 0x36, 0xcf, 0xf5, 0xe8, 0xe4, 0xe0,
		0xdf, 0x07, 0xef, 0xf7, 0x3e, 0x1c, 0x9d, 0xf0, 0x54, 0xeb, 0xf3, 0x54, 0xf7, 0x4e, 0x71, 0xd4,
		0xba, 0x05, 0xe0, 0xa3, 0xf7, 0xbf, 0xed, 0xbf, 0xf5, 0xd0, 0x04, 0xf9, 0xc7, 0xaf, 0x33, 0xf8,
		0x88, 0xb1, 0x59, 0x58, 0xa8, 0x0e, 0xf6, 0x82, 0x2c, 0xf7, 0xaf, 0x92, 0x6e, 0x74, 0x11, 0x85,
		0x5d, 0x7b, 0xc5, 0xc1, 0xf9, 0xe9, 0x51, 0x1b, 0xbc, 0x6f, 0x3a, 0xd4, 0x06, 0x9f, 0x60, 0x50,
		0xd4, 0x06, 0x9f, 0x64, 0xe9, 0xd4, 0x06, 0x97, 0x9c, 0x20, 0xb5, 0xc1, 0x0a, 0x61, 0x5f, 0xc3,
		0xb5, 0xc1, 0x3c, 0xba, 0x0a, 0xf3, 0xa8, 0xf3, 0x67, 0xb6, 0xdd, 0x32, 0x58, 0x1b, 0x34, 0x74,
		0x8c, 0xc0, 0xfb, 0x18, 0x8f, 0x35, 0x02, 0xbd, 0x38, 0x88, 0x93, 0x2c, 0xec, 0x24, 0x71, 0xd7,
		0xd4, 0x59, 0x55, 0xd4, 0x6e, 0x1f, 0xb9, 0x50, 0xa8, 0xdd, 0xfe, 0xfc, 0xf4, 0x50, 0xbb, 0xad,
		0x63, 0x3d, 0x06, 0xb5, 0xdb, 0x12, 0x5c, 0xa2, 0xf9, 0xaa, 0xd5, 0xda, 0xde, 0x69, 0xb5, 0xd6,
		0x77, 0x36, 0x77, 0xd6, 0x77, 0xb7, 0xb6, 0x9a, 0xdb, 0x4d, 0x74, 0x6f, 0x2b, 0x8e, 0x1f, 0xed,
		0xcd, 0x86, 0x73, 0x1b, 0x66, 0xa2, 0xa8, 0x37, 0xbd, 0x57, 0xdc, 0x5c, 0x75, 0x6b, 0x3a, 0x31,
		0x23, 0xec, 0xe7, 0x6d, 0x78, 0x11, 0x0c, 0x7a, 0x23, 0xaa, 0xba, 0x4e, 0xad, 0xed, 0xde, 0xe9,
		0x50, 0x6b, 0x7b, 0x82, 0x79, 0x53, 0x6b, 0x7b, 0x92, 0xa5, 0x53, 0x6b, 0x5b, 0x72, 0x82, 0xd4,
		0xda, 0x2a, 0xc4, 0x6b, 0xb8, 0xb4, 0xe9, 0xe9, 0x59, 0x90, 0x4b, 0x9b, 0x7e, 0xf4, 0x45, 0x19,
		0xab, 0x96, 0x9c, 0x9d, 0x32, 0x56, 0xd5, 0xc3, 0xfd, 0xbc, 0x4b, 0x50, 0xc6, 0x5a, 0xda, 0x25,
		0xb8, 0xb4, 0xa9, 0x2e, 0x80, 0xcc, 0xde, 0x6c, 0x28, 0x5e, 0x99, 0x89, 0x9d, 0xde, 0xe4, 0x70,
		0x64, 0x32, 0xc8, 0x43, 0x7b, 0x05, 0xac, 0xdb, 0x93, 0xa3, 0x60, 0x74, 0xdf, 0x74, 0x28, 0x18,
		0x3d, 0xc1, 0x9c, 0x28, 0x18, 0x3d, 0xc9, 0xd2, 0x29, 0x18, 0x2d, 0x39, 0x41, 0x0a, 0x46, 0x15,
		0x62, 0x10, 0x86, 0x0b, 0x46, 0xe7, 0x49, 0xd2, 0x0b, 0x83, 0xd8, 0xe2, 0xa1, 0xcd, 0x26, 0x50,
		0xce, 0xc0, 0x0c, 0x94, 0x5d, 0xc8, 0xdb, 0x8b, 0xe3, 0x24, 0x0f, 0x86, 0x6c, 0xcc, 0x84, 0x03,
		0x79, 0x59, 0xe7, 0x4b, 0x78, 0x15, 0xf4, 0x27, 0xa2, 0x33, 0x8d, 0xa4, 0x1f, 0xc6, 0x9d, 0x11,
		0x50, 0xf2, 0xe3, 0x30, 0xff, 0x2b, 0x49, 0xff, 0xf4, 0xa3, 0x38, 0xcb, 0x83, 0xb8, 0x13, 0x36,
		0xee, 0xfe, 0x20, 0x5b, 0xf8, 0x49, 0xa3, 0x9f, 0x26, 0x79, 0xd2, 0x49, 0x7a, 0x59, 0xf1, 0xaa,
		0x71, 0x7e, 0xd9, 0x6f, 0xa4, 0xd1, 0x79, 0x23, 0xb8, 0x88, 0xfc, 0x2c, 0xb8, 0x88, 0xb2, 0xe2,
		0x55, 0x63, 0x74, 0xcf, 0x40, 0x96, 0xe6, 0xa1, 0xdf, 0x4f, 0x7a, 0x51, 0xe7, 0x5b, 0x23, 0x0e,
		0xa3, 0xcb, 0x2f, 0xe7, 0x49, 0x9a, 0x15, 0xaf, 0x1a, 0x41, 0xf7, 0x8f, 0x51, 0x36, 0x48, 0x06,
		0xb9, 0xdf, 0x4f, 0xc3, 0xc6, 0x08, 0xe1, 0x66, 0xe3, 0x6f, 0x63, 0x9d, 0x1b, 0x03, 0xbe, 0xee,
		0x65, 0x79, 0x3a, 0xe8, 0xe4, 0xf1, 0x24, 0x08, 0x1d, 0x15, 0x8b, 0xf8, 0x7e, 0xbc, 0x40, 0x07,
		0x93, 0xf5, 0x69, 0xdf, 0xf9, 0xef, 0xec, 0xee, 0x0f, 0xda, 0xc7, 0xd3, 0x05, 0x2c, 0x5e, 0xb5,
		0xdf, 0x5c, 0xf6, 0xdb, 0xff, 0x3f, 0x7b, 0xdf, 0xfb, 0xd3, 0x36, 0xd2, 0x7d, 0xff, 0xbe, 0x7f,
		0x05, 0xb2, 0x9e, 0x17, 0x45, 0xaa, 0x6b, 0x02, 0xf9, 0x51, 0xfa, 0x2e, 0x5d, 0xe8, 0x2a, 0xfa,
		0x52, 0x82, 0x92, 0xb2, 0x7a, 0x3e, 0x62, 0x79, 0x2c, 0x27, 0x99, 0xd0, 0x29, 0x61, 0x6c, 0xd9,
		0x13, 0x0a, 0x6a, 0xf9, 0xdf, 0xbf, 0x8a, 0x1d, 0x1b, 0x92, 0xc0, 0x6e, 0x03, 0xc4, 0x73, 0x26,
		0x39, 0xd1, 0x4a, 0x99, 0x98, 0xa4, 0xbe, 0x3b, 0x33, 0xf7, 0x9e, 0x73, 0x8f, 0x67, 0xe6, 0x76,
		0x64, 0xcf, 0x6f, 0x0e, 0x65, 0x77, 0xd2, 0x7f, 0x79, 0xc3, 0x6f, 0x45, 0xd7, 0xd5, 0x6e, 0xac,
		0xc5, 0x49, 0xda, 0x79, 0xfe, 0x71, 0xde, 0x79, 0x45, 0xcb, 0x6f, 0x0e, 0xbe, 0x77, 0x64, 0xaf,
		0x3d, 0xd6, 0x27, 0xb1, 0xf0, 0x3b, 0x69, 0xcf, 0x65, 0x6f, 0x7e, 0x37, 0xed, 0xb9, 0x37, 0x9b,
		0x19, 0x07, 0x0c, 0xc6, 0x00, 0x67, 0xac, 0x2e, 0x55, 0xf8, 0x43, 0xb9, 0x81, 0xd6, 0xb1, 0xec,
		0x4d, 0x46, 0xc4, 0x78, 0x1c, 0xb8, 0x7f, 0xda, 0xb2, 0x68, 0x9b, 0xe1, 0x68, 0x99, 0x63, 0xa7,
		0x61, 0x33, 0x50, 0x52, 0x47, 0xa4, 0x94, 0x11, 0x33, 0x55, 0x44, 0x4b, 0x11, 0x61, 0x53, 0x43,
		0xd8, 0x94, 0x10, 0x36, 0x15, 0xdc, 0x6c, 0xde, 0x7a, 0x20, 0x63, 0x8c, 0xb0, 0xb3, 0x00, 0x52,
		0x78, 0x5a, 0xec, 0xa2, 0x89, 0x58, 0x8a, 0x6c, 0x85, 0x8a, 0x2c, 0x3c, 0xbc, 0x62, 0xc3, 0x2c,
		0x2a, 0xdc, 0xc2, 0xc3, 0x2e, 0x3c, 0xfc, 0xc2, 0xc3, 0x30, 0x8e, 0x90, 0xb5, 0x05, 0xa4, 0xc8,
		0xa2, 0xc0, 0x73, 0x61, 0xd0, 0x04, 0xfb, 0x5c, 0x8d, 0xa6, 0x13, 0xcf, 0x44, 0xd4, 0x7b, 0x13,
		0xc1, 0x5c, 0x0f, 0x73, 0xdd, 0x0b, 0x1c, 0x5c, 0x23, 0xc3, 0xb6, 0x1d, 0xf0, 0x8d, 0x0e, 0xe3,
		0xd6, 0xc0, 0xb9, 0x35, 0xb0, 0x6e, 0x0d, 0xbc, 0x63, 0xc1, 0x3c, 0x18, 0xdc, 0x17, 0xa3, 0xf8,
		0x15, 0x11, 0x60, 0xb7, 0xb0, 0xab, 0x3e, 0x2c, 0x64, 0xc3, 0x0d, 0xcc, 0xca, 0x9b, 0x79, 0x15,
		0x88, 0xac, 0x98, 0xc3, 0x3d, 0x59, 0xe1, 0x4a, 0x49, 0x74, 0xd7, 0x74, 0xb2, 0xe7, 0x92, 0xb0,
		0xc4, 0x17, 0xe5, 0xb1, 0xe9, 0xa3, 0xde, 0x48, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b,
		0xd2, 0x4b, 0x64, 0x7d, 0x7c, 0x14, 0xd1, 0xb4, 0xae, 0xc2, 0xb0, 0x94, 0xa3, 0x8d, 0x04, 0xf0,
		0x26, 0xc3, 0x19, 0xe9, 0x6b, 0x62, 0xe9, 0x3b, 0xee, 0xfc, 0x5a, 0x23, 0x52, 0x60, 0x03, 0x39,
		0xb0, 0x8b, 0x24, 0xd8, 0x42, 0x16, 0xac, 0x23, 0x0d, 0xd6, 0x91, 0x07, 0xeb, 0x48, 0x04, 0x26,
		0x99, 0x00, 0x25, 0x15, 0xc5, 0xe8, 0xc2, 0x2a, 0x6a, 0x0b, 0x71, 0x73, 0x2c, 0x95, 0xae, 0xd4,
		0x91, 0x63, 0xe6, 0x14, 0xc5, 0xeb, 0xc0, 0x26, 0x62, 0x9e, 0x9d, 0x31, 0xff, 0xc2, 0xc6, 0x9c,
		0x2d, 0xf4, 0xb3, 0x35, 0x2c, 0xa3, 0x97, 0x0b, 0xe6, 0x82, 0x9f, 0xbd, 0xb1, 0x60, 0xaf, 0x05,
		0xe7, 0x0d, 0x58, 0x02, 0x47, 0xb3, 0x2e, 0x16, 0xdc, 0xd0, 0xc5, 0x56, 0xec, 0x62, 0xf5, 0x5a,
		0x6d, 0xaf, 0x46, 0x37, 0xdb, 0x2c, 0x2e, 0x8a, 0x6f, 0xdd, 0xf9, 0x1b, 0xf6, 0x97, 0xa5, 0x61,
		0x1c, 0x78, 0x25, 0xdc, 0x42, 0x4a, 0x81, 0xba, 0x22, 0xce, 0x12, 0x54, 0xa1, 0x2e, 0xf8, 0x9a,
		0x93, 0x91, 0xba, 0xe0, 0xab, 0x7a, 0x0e, 0x75, 0xc1, 0x15, 0x1b, 0x4c, 0x5d, 0x70, 0x8d, 0x13,
		0x31, 0xcb, 0x74, 0xc1, 0x0f, 0x16, 0xc8, 0x82, 0x35, 0xca, 0x82, 0x2f, 0x7c, 0x51, 0x16, 0xa4,
		0x66, 0x41, 0x59, 0x70, 0x03, 0xd1, 0x68, 0xd6, 0xc5, 0x28, 0x0b, 0xae, 0xdc, 0xc5, 0x76, 0x6b,
		0x14, 0x05, 0x37, 0x8c, 0x88, 0xe2, 0x5b, 0x47, 0x51, 0xd0, 0xda, 0x20, 0x9e, 0x29, 0x6d, 0xd7,
		0xd3, 0xe8, 0x62, 0x83, 0x2a, 0x98, 0xd9, 0x4a, 0x59, 0xf0, 0x39, 0xe6, 0x51, 0x16, 0x7c, 0xc5,
		0xd9, 0x48, 0x59, 0xf0, 0x55, 0x3d, 0x87, 0xb2, 0xe0, 0x8a, 0x0d, 0xa6, 0x2c, 0xb8, 0xc6, 0x89,
		0x98, 0x45, 0xb2, 0x60, 0x4f, 0xaa, 0x20, 0xbe, 0xb5, 0x40, 0x17, 0xdc, 0x07, 0x36, 0xf1, 0x48,
		0xa8, 0x8b, 0x74, 0x63, 0x2e, 0x85, 0xc1, 0x97, 0xaa, 0x16, 0x14, 0x06, 0x57, 0xae, 0x5a, 0x54,
		0xa8, 0x59, 0x6c, 0x18, 0x1e, 0xcd, 0xba, 0x18, 0x85, 0xc1, 0x95, 0xbb, 0x18, 0xd7, 0x0b, 0x6e,
		0x20, 0x19, 0xc5, 0xb7, 0x8e, 0xd2, 0xa0, 0xb5, 0x61, 0xdc, 0x11, 0x37, 0x5a, 0xa8, 0x81, 0x18,
		0xe0, 0x0b, 0x83, 0x85, 0xa5, 0x94, 0x05, 0x9f, 0x63, 0x1e, 0x65, 0xc1, 0x57, 0x9c, 0x8b, 0x94,
		0x05, 0x5f, 0xd5, 0x73, 0x28, 0x0b, 0xae, 0xd8, 0x60, 0xca, 0x82, 0x6b, 0x9c, 0x86, 0xd9, 0x24,
		0x0b, 0xc2, 0x15, 0x4c, 0x7b, 0x0a, 0xc6, 0x41, 0x0a, 0xa8, 0x91, 0xd4, 0x3e, 0x67, 0x0c, 0xc3,
		0x68, 0x92, 0x79, 0x06, 0x23, 0x7c, 0x52, 0x5b, 0x58, 0x4a, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b,
		0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0xa7, 0x98, 0x1d, 0xc3,
		0x28, 0x88, 0xb5, 0xb4, 0x81, 0xd3, 0xe6, 0x86, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2,
		0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0xd2, 0x29, 0x66, 0xc7, 0x50, 0xc7,
		0x81, 0x4a, 0xa4, 0x96, 0xd7, 0x16, 0xec, 0x4b, 0x7a, 0x60, 0x2b, 0x89, 0x2d, 0x89, 0x2d, 0x89,
		0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x2d, 0x02, 0x75,
		0x51, 0xa7, 0xa9, 0x54, 0xa8, 0x03, 0x2d, 0x43, 0xcc, 0x0d, 0x50, 0x4e, 0xd2, 0xff, 0x26, 0xae,
		0x82, 0x68, 0x5a, 0x80, 0xd2, 0x0b, 0x23, 0xa1, 0xfa, 0x29, 0x51, 0x74, 0x95, 0xd0, 0x3f, 0xc2,
		0xf8, 0xd2, 0x95, 0x2a, 0xd1, 0x81, 0xea, 0x0b, 0x6f, 0xfe, 0x42, 0xb2, 0x70, 0xc5, 0x8b, 0xe2,
		0x50, 0x87, 0xfd, 0x70, 0x94, 0x14, 0x2d, 0xaf, 0x77, 0x11, 0x79, 0xb1, 0xec, 0x79, 0xc1, 0x50,
		0xba, 0x49, 0x30, 0x94, 0x49, 0xd1, 0xf2, 0x64, 0x74, 0x5d, 0x75, 0x93, 0x58, 0x0b, 0x37, 0x0a,
		0x47, 0xb2, 0x7f, 0xeb, 0x29, 0x21, 0x2f, 0xbe, 0xf5, 0xc2, 0x38, 0x29, 0x5a, 0x5e, 0x30, 0xf8,
		0x9e, 0xa2, 0x55, 0x38, 0xd6, 0x6e, 0x14, 0x0b, 0x2f, 0x0e, 0xc7, 0x5a, 0x24, 0xd9, 0x9b, 0x37,
		0x56, 0x97, 0x2a, 0xfc, 0xa1, 0xdc, 0x40, 0xeb, 0x58, 0xf6, 0xd2, 0x3f, 0x2c, 0x5c, 0xf2, 0x10,
		0xeb, 0x1f, 0x66, 0x5d, 0xaf, 0xe3, 0x71, 0x5f, 0xab, 0x69, 0x64, 0x6c, 0x17, 0x3d, 0x7f, 0x9c,
		0xf5, 0x6a, 0x6b, 0xda, 0xa9, 0xfe, 0xdc, 0xe7, 0x64, 0xfe, 0x82, 0x7f, 0x92, 0xf7, 0x7a, 0xd1,
		0xf2, 0x3f, 0x5d, 0x44, 0x7e, 0x47, 0xf6, 0xfc, 0xe6, 0x50, 0x76, 0x27, 0x9d, 0x9e, 0x37, 0xfc,
		0x56, 0x74, 0x5d, 0xed, 0xc6, 0x5a, 0x9c, 0xa4, 0x3d, 0xee, 0x1f, 0xe7, 0x3d, 0x5e, 0xb4, 0xfc,
		0xe6, 0xe0, 0x7b, 0x47, 0xf6, 0xda, 0x63, 0x7d, 0x12, 0x0b, 0xbf, 0x93, 0x76, 0x77, 0xf6, 0xe6,
		0x9f, 0x66, 0x7d, 0xdb, 0x2c, 0x7a, 0x7b, 0xe1, 0x8a, 0xdf, 0x4d, 0x3b, 0x9b, 0x45, 0x4b, 0x81,
		0x2d, 0x01, 0x89, 0x90, 0x13, 0xd2, 0x8f, 0x78, 0x0a, 0xb1, 0x73, 0x24, 0x13, 0x3d, 0x99, 0xd0,
		0x50, 0xf1, 0xda, 0xf9, 0x22, 0xd5, 0xe1, 0x48, 0x4c, 0x28, 0x7c, 0x82, 0x95, 0xc2, 0x3b, 0x5f,
		0x82, 0x9b, 0x07, 0x96, 0x55, 0x3e, 0x54, 0xab, 0xf5, 0x46, 0xb5, 0xba, 0xd3, 0xd8, 0x6b, 0xec,
		0xec, 0xd7, 0x6a, 0x95, 0x7a, 0x05, 0x68, 0xc7, 0x9c, 0xd3, 0x8e, 0x07, 0x22, 0x16, 0x83, 0x4f,
		0x93, 0xa9, 0xa7, 0xc6, 0xa3, 0x11, 0x3d, 0x12, 0x9f, 0xab, 0xac, 0x3f, 0x47, 0x71, 0xa0, 0xaa,
		0x59, 0xaf, 0x1d, 0x2b, 0xc1, 0xe0, 0x23, 0xe6, 0xd1, 0xdf, 0xac, 0x05, 0x86, 0xa3, 0x1c, 0x5a,
		0x74, 0x5b, 0xb7, 0xa8, 0x06, 0x10, 0xc3, 0xd6, 0x20, 0x76, 0x99, 0x0d, 0x55, 0xe6, 0x02, 0x84,
		0x99, 0x3b, 0x1b, 0x0a, 0x49, 0x79, 0xea, 0x33, 0xf1, 0x7d, 0x57, 0x0e, 0xb6, 0x84, 0x1a, 0x44,
		0xa1, 0x54, 0x7a, 0xab, 0x1f, 0x8e, 0xc2, 0xd8, 0x90, 0x23, 0x61, 0xe4, 0x3d, 0x38, 0x79, 0x0e,
		0x74, 0x5e, 0x83, 0x91, 0xc7, 0x98, 0x72, 0x1f, 0x10, 0x24, 0xb7, 0x1a, 0xc1, 0x0d, 0xc2, 0xb5,
		0x75, 0x30, 0x6d, 0x06, 0x94, 0xcb, 0x87, 0xc4, 0x72, 0xef, 0x58, 0x72, 0xf4, 0x30, 0x1d, 0x35,
		0x2c, 0x8d, 0x16, 0x06, 0xe2, 0x84, 0x45, 0xf1, 0xa1, 0xdc, 0xc8, 0x50, 0x9e, 0x7f, 0x96, 0x73,
		0xa7, 0x92, 0x22, 0x80, 0x29, 0xcf, 0xb7, 0xcd, 0xe3, 0x4b, 0x74, 0x75, 0x1b, 0x5c, 0xbc, 0x1c,
		0xdf, 0x5e, 0xbd, 0xa7, 0x95, 0xe0, 0x65, 0x4e, 0x3e, 0xa5, 0xdc, 0x60, 0x30, 0x88, 0x45, 0x92,
		0x94, 0xe6, 0x67, 0xc5, 0xc2, 0xa2, 0x05, 0x0b, 0x4a, 0x8a, 0x2d, 0xe5, 0x2e, 0xfa, 0x2d, 0x7d,
		0x11, 0xaf, 0x89, 0x45, 0xb9, 0x66, 0x17, 0xd9, 0x9a, 0x5a, 0x34, 0x6b, 0x7c, 0x11, 0xac, 0xf1,
		0x45, 0xad, 0xc6, 0x17, 0xa9, 0xae, 0x17, 0xeb, 0x29, 0x7d, 0x51, 0x68, 0xe1, 0xb7, 0x23, 0x11,
		0x0c, 0x63, 0x31, 0x2c, 0xd3, 0x69, 0xf3, 0x45, 0x9b, 0x8d, 0x12, 0xef, 0x79, 0x32, 0x25, 0x76,
		0xef, 0xdf, 0x67, 0x6b, 0xcc, 0xbc, 0x05, 0x0c, 0x22, 0x83, 0x58, 0x82, 0x10, 0x06, 0x5a, 0x94,
		0x4f, 0x1b, 0xca, 0x5c, 0x1c, 0x58, 0x4c, 0x52, 0x72, 0x05, 0x72, 0x05, 0x72, 0x05, 0x72, 0x05,
		0x1c, 0xae, 0x70, 0x20, 0xcb, 0x7d, 0xec, 0x67, 0x2e, 0x61, 0x44, 0x49, 0x1c, 0x0d, 0x25, 0x90,
		0xc6, 0xc0, 0xc1, 0x24, 0x48, 0x60, 0x80, 0x85, 0x69, 0xd0, 0x80, 0x01, 0x0f, 0x18, 0x10, 0x81,
		0x01, 0x93, 0x72, 0x41, 0xa5, 0x64, 0x70, 0x31, 0x97, 0x90, 0x2e, 0xf8, 0xbd, 0x8c, 0x0c, 0x45,
		0xf9, 0x19, 0xfa, 0x6f, 0xa0, 0xe4, 0x59, 0xde, 0xf7, 0x66, 0x0a, 0x99, 0x19, 0x5c, 0xa2, 0x71,
		0x3f, 0xf2, 0xd7, 0x55, 0x83, 0x63, 0xbf, 0x30, 0x07, 0x3e, 0x18, 0xb4, 0xe1, 0x24, 0xd0, 0x5a,
		0xc4, 0xca, 0x78, 0x5d, 0x3b, 0xe7, 0xed, 0xdb, 0xb3, 0x1d, 0x77, 0xff, 0xfc, 0xd7, 0x59, 0xc5,
		0xdd, 0x3f, 0xcf, 0x9a, 0x95, 0xf4, 0x2d, 0x6b, 0xef, 0x9e, 0xed, 0xb8, 0xd5, 0xbc, 0x5d, 0x3b,
		0xdb, 0x71, 0x6b, 0xe7, 0xdb, 0x7f, 0xff, 0xfd, 0x7e, 0xfb, 0xe7, 0xde, 0xdd, 0xf2, 0x3f, 0x34,
		0xb7, 0xb0, 0xf2, 0xdc, 0xe4, 0x50, 0xb7, 0xbb, 0xad, 0xff, 0xc2, 0x8c, 0xf7, 0xff, 0xca, 0x1c,
		0xf0, 0xff, 0x18, 0x1c, 0xf1, 0x4d, 0x5a, 0x8d, 0x87, 0x11, 0xdc, 0xeb, 0x0c, 0xee, 0x90, 0xc1,
		0x3d, 0x70, 0x87, 0x4d, 0xf7, 0xf3, 0xf9, 0xcf, 0xca, 0xbb, 0xea, 0xdd, 0xc7, 0xed, 0x9f, 0x8d,
		0xbb, 0xf9, 0x8b, 0xbf, 0x1e, 0xfb, 0x5a, 0xe5, 0x5d, 0xe3, 0xee, 0xe3, 0x13, 0x7f, 0xa9, 0xdf,
		0x7d, 0xfc, 0xcd, 0x7f, 0xa3, 0x76, 0xf7, 0x76, 0xe1, 0xab, 0x93, 0xeb, 0xbb, 0x4f, 0xfd, 0xa0,
		0xfa, 0xc4, 0x0f, 0xf6, 0x9e, 0xfa, 0xc1, 0xde, 0x13, 0x3f, 0x78, 0xd2, 0xa4, 0xdd, 0x27, 0x7e,
		0x50, 0xbb, 0xfb, 0xb5, 0xf0, 0xfd, 0xb7, 0x8f, 0x7f, 0xb5, 0x7e, 0xb7, 0xfd, 0xeb, 0xa9, 0xbf,
		0x35, 0xee, 0x7e, 0x7d, 0xdc, 0x26, 0xd4, 0xe1, 0x40, 0x1d, 0xa7, 0x7f, 0xf9, 0xd3, 0x7f, 0xf3,
		0x80, 0xff, 0xcd, 0x7a, 0xff, 0x7f, 0x72, 0xd9, 0xe3, 0x33, 0x55, 0x2d, 0x2e, 0x7b, 0x7c, 0x74,
		0xd9, 0x63, 0xd9, 0x07, 0xc2, 0xa0, 0x2e, 0x76, 0x2c, 0xf1, 0xac, 0x96, 0x12, 0xd6, 0x28, 0xbc,
		0xb1, 0xd8, 0x65, 0xf3, 0x0d, 0x81, 0x25, 0x3f, 0x8b, 0x2a, 0x77, 0xcb, 0x5f, 0xf9, 0x5b, 0xfb,
		0x20, 0xb6, 0xf0, 0x95, 0xbb, 0x55, 0x6f, 0xd5, 0x13, 0xb5, 0x64, 0x4c, 0x41, 0xc7, 0x12, 0xa7,
		0x94, 0x95, 0x51, 0x88, 0xe8, 0xb1, 0x5a, 0xdc, 0x58, 0x5d, 0x34, 0x5f, 0xcd, 0xbf, 0xbc, 0x22,
		0xb7, 0x2b, 0xcb, 0xdd, 0x40, 0xdd, 0x6c, 0x85, 0xde, 0x85, 0xe5, 0x55, 0xab, 0x71, 0xa6, 0xd7,
		0x9f, 0xea, 0xaf, 0xfb, 0x2f, 0xbe, 0xb2, 0xd3, 0xac, 0xda, 0x59, 0xa0, 0x9c, 0x64, 0x05, 0xae,
		0x81, 0xe0, 0x12, 0xaf, 0xeb, 0x08, 0xaf, 0x37, 0x5d, 0x5f, 0x71, 0xaa, 0x66, 0x8f, 0xa2, 0xc7,
		0x4a, 0xf6, 0x83, 0x44, 0xbf, 0xfa, 0x44, 0x9d, 0x7d, 0xe0, 0x9d, 0xdf, 0xe5, 0x95, 0x1d, 0x6d,
		0x35, 0xeb, 0x98, 0x57, 0xb6, 0x24, 0x6d, 0x95, 0x4b, 0xce, 0xca, 0x59, 0x52, 0xb6, 0xea, 0x25,
		0x63, 0xa5, 0x2d, 0x09, 0x2b, 0x6d, 0xc9, 0x57, 0x69, 0x4b, 0xba, 0xb0, 0x21, 0x71, 0x55, 0xeb,
		0x7a, 0x9d, 0x51, 0xd6, 0xa7, 0xab, 0x9b, 0x91, 0xc5, 0x5e, 0xa2, 0xe9, 0x8d, 0x56, 0x34, 0x4d,
		0x56, 0xbb, 0x25, 0xe3, 0x3e, 0xa4, 0xed, 0xae, 0xe8, 0x06, 0x25, 0xac, 0xa6, 0x2d, 0x77, 0xd5,
		0x6c, 0x59, 0xab, 0x63, 0x4b, 0x5f, 0x05, 0x5b, 0xfa, 0x6a, 0xd7, 0xd2, 0x57, 0xb5, 0xda, 0x95,
		0x5a, 0xaf, 0x7a, 0xcb, 0x83, 0x33, 0x3d, 0x3f, 0x65, 0xe5, 0x13, 0x39, 0x77, 0xcf, 0x52, 0xce,
		0x6b, 0x29, 0x69, 0x0f, 0x5b, 0x69, 0xdb, 0x13, 0xca, 0xdc, 0x8e, 0x60, 0x66, 0xfb, 0x41, 0xd9,
		0xdb, 0x0d, 0x8c, 0x6d, 0x2f, 0x30, 0xb6, 0x9d, 0xc0, 0xd8, 0xf6, 0x01, 0xbb, 0x9f, 0x79, 0x95,
		0xb5, 0xe7, 0x2c, 0x0b, 0x8c, 0xe5, 0x6f, 0x2d, 0x2e, 0xf3, 0x98, 0x3d, 0x6e, 0x2d, 0x5e, 0x97,
		0x70, 0x6d, 0x2a, 0x6c, 0x1b, 0x0f, 0xdf, 0xc6, 0xc3, 0xb8, 0xf1, 0x70, 0x5e, 0x4e, 0x58, 0x2f,
		0x29, 0xbc, 0x97, 0x1e, 0xe6, 0x8b, 0x1b, 0x86, 0xb1, 0xbc, 0x90, 0xca, 0xdc, 0x86, 0xe2, 0xe9,
		0xfd, 0xb9, 0x8d, 0x78, 0xdd, 0x00, 0x01, 0x03, 0x18, 0x4c, 0x03, 0x04, 0x0c, 0x50, 0xc0, 0x00,
		0x06, 0x0c, 0x70, 0x94, 0x0b, 0x20, 0x25, 0x03, 0x49, 0xd1, 0xcb, 0xe6, 0xb7, 0x11, 0x97, 0x7f,
		0xbe, 0xd5, 0x02, 0xcf, 0x6f, 0x18, 0xb8, 0xf7, 0xc2, 0x79, 0x57, 0x53, 0xa4, 0x5b, 0xd7, 0xc5,
		0xe0, 0x25, 0x92, 0xfd, 0x69, 0x25, 0x08, 0x73, 0xa4, 0x25, 0x37, 0x80, 0xac, 0x85, 0xac, 0x85,
		0xac, 0x85, 0xac, 0x85, 0xac, 0x85, 0xac, 0x65, 0x4d, 0x59, 0x4b, 0x0e, 0x75, 0xa4, 0x2d, 0x2f,
		0xa7, 0x2d, 0x66, 0xe0, 0xec, 0x9e, 0xb5, 0x18, 0x11, 0x28, 0x49, 0x5a, 0x48, 0x5a, 0x48, 0x5a,
		0x48, 0x5a, 0x48, 0x5a, 0x48, 0x5a, 0x4a, 0x23, 0x2d, 0x99, 0xdb, 0x93, 0xb3, 0xbc, 0xb8, 0x6b,
		0xcb, 0x3d, 0x68, 0x7c, 0x61, 0x42, 0x97, 0xbd, 0xf9, 0x7c, 0xab, 0xfc, 0xd5, 0x01, 0x64, 0x2c,
		0x64, 0x2c, 0x64, 0x2c, 0x64, 0x2c, 0x26, 0x18, 0x4b, 0xd9, 0xab, 0x0d, 0x8a, 0x1b, 0x07, 0x5a,
		0xc7, 0xae, 0x54, 0x03, 0x71, 0x63, 0xce, 0xe9, 0xf2, 0xd0, 0xf3, 0xc0, 0x16, 0x53, 0x05, 0xae,
		0x8d, 0xa4, 0xc8, 0xc6, 0x81, 0x07, 0x01, 0x80, 0xb0, 0x80, 0x08, 0x05, 0x90, 0xe0, 0x80, 0x09,
		0x0e, 0xa0, 0xe0, 0x80, 0xca, 0x0c, 0x60, 0x19, 0x02, 0x2e, 0xf3, 0x29, 0x37, 0x50, 0xea, 0x8d,
		0x90, 0x82, 0x3f, 0x96, 0x8a, 0x3f, 0xfa, 0x5f, 0x0a, 0xb6, 0x89, 0xd0, 0x49, 0xd1, 0x9a, 0xa6,
		0xec, 0x19, 0x00, 0x6f, 0x4a, 0xe9, 0x70, 0x03, 0x39, 0x4e, 0x3f, 0xbc, 0xba, 0x1a, 0x2b, 0xa9,
		0x6f, 0x51, 0x78, 0xd7, 0xbc, 0x41, 0x24, 0x5f, 0x24, 0x5f, 0x24, 0x5f, 0x24, 0x5f, 0x24, 0x5f,
		0x24, 0x5f, 0x24, 0x5f, 0xab, 0x20, 0x5f, 0x39, 0xe2, 0x4a, 0x91, 0x14, 0xed, 0x5b, 0xf2, 0xaf,
		0x72, 0x06, 0x47, 0xdc, 0x68, 0x17, 0x8e, 0x83, 0x3d, 0x66, 0x14, 0x79, 0x18, 0x79, 0x18, 0x79,
		0x18, 0x79, 0x18, 0x79, 0x18, 0x79, 0x18, 0x79, 0xd8, 0x2a, 0x78, 0xd8, 0x43, 0xd4, 0x9d, 0x70,
		0xb1, 0x19, 0x14, 0x26, 0x1f, 0x2b, 0x67, 0x90, 0xa4, 0xba, 0x0e, 0x46, 0x72, 0xe0, 0xc6, 0x22,
		0x48, 0x42, 0x65, 0x9e, 0x8a, 0xcd, 0xd9, 0x43, 0x16, 0x46, 0x16, 0x46, 0x16, 0x46, 0x16, 0x46,
		0x16, 0x46, 0x16, 0xb6, 0x2c, 0x92, 0x0c, 0x84, 0xd2, 0x52, 0xdf, 0x82, 0x30, 0xb1, 0x9a, 0x41,
		0x1b, 0x5a, 0xd3, 0xae, 0xf8, 0x14, 0x24, 0x00, 0x21, 0x2c, 0x1f, 0xa0, 0xd6, 0xf1, 0x5f, 0xcd,
		0xa3, 0xd6, 0x81, 0xdf, 0x69, 0x9f, 0x7e, 0x3d, 0xf4, 0x3b, 0x87, 0xcd, 0x6e, 0xfb, 0xd8, 0x74,
		0x34, 0xfb, 0x2b, 0x18, 0x8d, 0xd3, 0xf3, 0x17, 0xcd, 0x96, 0x02, 0xdc, 0x32, 0x5a, 0x23, 0xf5,
		0x1f, 0x47, 0xeb, 0x8f, 0xa3, 0xd3, 0xee, 0xd7, 0xc3, 0x8e, 0x7f, 0xd4, 0x6e, 0x9f, 0x38, 0xc6,
		0x4d, 0xbc, 0x7b, 0xc7, 0x71, 0x7a, 0x7c, 0x9c, 0xda, 0x9d, 0xd6, 0x9f, 0xad, 0xe3, 0xe6, 0xd7,
		0x76, 0x87, 0xa3, 0x84, 0x3b, 0x4a, 0xcd, 0x2e, 0x1d, 0x09, 0x3d, 0xe0, 0xb5, 0x8f, 0x3f, 0x1f,
		0x1e, 0x00, 0x8c, 0x90, 0x51, 0x0b, 0xce, 0x37, 0x8d, 0x3f, 0x6f, 0x84, 0xfa, 0x33, 0x0a, 0x12,
		0xed, 0x5e, 0x85, 0x03, 0x39, 0x94, 0x62, 0x60, 0x5e, 0xfc, 0x99, 0x35, 0x87, 0xda, 0x0f, 0xb5,
		0x1f, 0x6a, 0x3f, 0xd4, 0x7e, 0xa8, 0xfd, 0x50, 0xfb, 0x59, 0x32, 0x6e, 0x68, 0x79, 0x25, 0xb4,
		0xec, 0x5f, 0x26, 0xf5, 0x2a, 0x80, 0xf6, 0xf3, 0xc1, 0xa0, 0x09, 0xa7, 0x4a, 0xa6, 0x75, 0x6c,
		0x1d, 0x15, 0xa8, 0x30, 0x11, 0xfd, 0x50, 0x0d, 0x12, 0x93, 0x5d, 0xd2, 0x09, 0xd4, 0x85, 0x30,
		0xae, 0xaf, 0x98, 0x4f, 0x35, 0x9c, 0x2f, 0x52, 0x19, 0x47, 0x14, 0x10, 0xce, 0xb3, 0x60, 0x4e,
		0xaa, 0xc2, 0x01, 0xd9, 0xf3, 0x39, 0x0e, 0xfa, 0x5a, 0x86, 0xea, 0x40, 0x5e, 0x64, 0xde, 0xb4,
		0xc3, 0x7c, 0x3d, 0xab, 0x94, 0xcd, 0x29, 0xfc, 0x2f, 0x53, 0xd8, 0x4c, 0xfd, 0x70, 0x6b, 0x67,
		0xf5, 0x9b, 0xcd, 0xbc, 0xfb, 0x39, 0x35, 0x8e, 0x95, 0x4d, 0x73, 0x43, 0x47, 0xfb, 0x2f, 0xe6,
		0xb2, 0x26, 0x8e, 0xf8, 0xa7, 0xaa, 0x41, 0x55, 0x83, 0xaa, 0x06, 0x55, 0x0d, 0xaa, 0x1a, 0x6b,
		0xa0, 0x6a, 0x8c, 0x95, 0x34, 0xb6, 0x24, 0xf2, 0x21, 0x88, 0x54, 0xf6, 0x0d, 0xda, 0x30, 0x1d,
		0x8e, 0x8d, 0xd7, 0x0f, 0xee, 0x6b, 0xb6, 0xbb, 0xc1, 0x60, 0x10, 0x8b, 0x24, 0x71, 0x00, 0x52,
		0x42, 0x80, 0x19, 0x82, 0x35, 0x53, 0x70, 0x66, 0xcc, 0x23, 0x33, 0xe7, 0xba, 0x0a, 0x34, 0x77,
		0x16, 0xe6, 0xd0, 0x07, 0x20, 0x9b, 0x4e, 0x02, 0xad, 0x45, 0xac, 0x60, 0xa6, 0x53, 0x61, 0xd8,
		0xdb, 0xb7, 0x67, 0x3b, 0xee, 0xfe, 0xf9, 0xaf, 0xb3, 0x8a, 0xbb, 0x7f, 0x9e, 0x35, 0x2b, 0xe9,
		0x5b, 0xd6, 0xde, 0x3d, 0xdb, 0x71, 0xab, 0x79, 0xbb, 0x76, 0xb6, 0xe3, 0xd6, 0xce, 0xb7, 0xff,
		0xfe, 0xfb, 0xfd, 0xf6, 0xcf, 0xbd, 0xbb, 0xe5, 0x7f, 0xe8, 0xc0, 0xfc, 0xaf, 0x9f, 0x23, 0x4d,
		0x8d, 0x76, 0xb7, 0xf5, 0x5f, 0xd8, 0xf9, 0xf1, 0xbf, 0x32, 0x27, 0xc8, 0x7f, 0x80, 0x66, 0x08,
		0x84, 0x25, 0x77, 0xef, 0x08, 0x3e, 0x4f, 0x82, 0x4f, 0x9d, 0xe0, 0xb3, 0x16, 0xe0, 0x13, 0xb8,
		0xc3, 0xa6, 0xfb, 0xf9, 0xfc, 0x67, 0xe5, 0x5d, 0xf5, 0xee, 0xe3, 0xf6, 0xcf, 0xc6, 0xdd, 0xfc,
		0xc5, 0x5f, 0x8f, 0x7d, 0xad, 0xf2, 0xae, 0x71, 0xf7, 0xf1, 0x89, 0xbf, 0xd4, 0xef, 0x3e, 0xfe,
		0xe6, 0xbf, 0x51, 0xbb, 0x7b, 0xbb, 0xf0, 0xd5, 0xc9, 0xf5, 0xdd, 0xa7, 0x7e, 0x50, 0x7d, 0xe2,
		0x07, 0x7b, 0x4f, 0xfd, 0x60, 0xef, 0x89, 0x1f, 0x3c, 0x69, 0xd2, 0xee, 0x13, 0x3f, 0xa8, 0xdd,
		0xfd, 0x5a, 0xf8, 0xfe, 0xdb, 0xc7, 0xbf, 0x5a, 0xbf, 0xdb, 0xfe, 0xf5, 0xd4, 0xdf, 0x1a, 0x77,
		0xbf, 0x3e, 0x6e, 0x13, 0x8a, 0xed, 0x85, 0x62, 0xba, 0x4b, 0xf9, 0xee, 0x42, 0x62, 0x02, 0x21,
		0xe1, 0xe1, 0xf4, 0x83, 0x61, 0x62, 0x86, 0xa4, 0x1f, 0x41, 0x6c, 0x93, 0x5b, 0xe0, 0x5f, 0x00,
		0x0f, 0xc9, 0xb1, 0xb6, 0xcd, 0x2d, 0x0c, 0x5c, 0xeb, 0xb8, 0xfb, 0xb5, 0x79, 0x74, 0xe4, 0x9f,
		0x74, 0xda, 0x5f, 0xdb, 0x7f, 0xb4, 0x8f, 0xfc, 0xaf, 0xff, 0x77, 0x72, 0xe8, 0x20, 0x2d, 0x7f,
		0x48, 0xa0, 0x30, 0xf8, 0x27, 0x16, 0x1b, 0xc8, 0x87, 0xf1, 0xa0, 0xd5, 0x39, 0xfc, 0xe3, 0xeb,
		0xd1, 0xff, 0xf9, 0x7f, 0xb4, 0x8f, 0x8f, 0x0f, 0xff, 0xf8, 0x8a, 0xb0, 0xd5, 0x04, 0x2c, 0x7d,
		0x05, 0x1e, 0xbd, 0x4f, 0x7f, 0x9e, 0x70, 0xb8, 0xec, 0x19, 0xae, 0xd6, 0x9f, 0x5f, 0x38, 0x5e,
		0x16, 0x8d, 0xd7, 0x49, 0xeb, 0x0b, 0x87, 0xcb, 0x9e, 0xe1, 0xea, 0x7e, 0x6d, 0x7e, 0x6d, 0xfd,
		0xc1, 0x11, 0xb3, 0x67, 0xc4, 0xda, 0xdd, 0x93, 0xcf, 0x1c, 0x2f, 0xbb, 0xc6, 0x6b, 0x8f, 0x03,
		0x66, 0x11, 0xe3, 0xe8, 0xb6, 0xba, 0x1c, 0x2f, 0x7b, 0xc6, 0xeb, 0xa8, 0xfd, 0x47, 0xf3, 0xc8,
		0x6f, 0xfe, 0xf9, 0x67, 0xe7, 0xf0, 0xcf, 0xe6, 0xd7, 0x43, 0xa0, 0xa1, 0x83, 0xb0, 0xe4, 0x9c,
		0x5b, 0x04, 0x36, 0xaa, 0xe7, 0x37, 0x63, 0x8b, 0x40, 0x5e, 0xdd, 0xdf, 0xf8, 0x1e, 0x81, 0xdc,
		0x10, 0x43, 0x4b, 0x5d, 0x0f, 0xc4, 0x30, 0x18, 0x8f, 0xd2, 0x75, 0xc6, 0x3b, 0xdc, 0xa8, 0xc0,
		0x8d, 0x0a, 0xdc, 0xa8, 0x30, 0x33, 0x33, 0xb9, 0x51, 0xe1, 0x5f, 0x0c, 0xe2, 0x46, 0x85, 0x2d,
		0x6e, 0x54, 0xf8, 0xb8, 0xe5, 0x8c, 0xa5, 0xd2, 0x7b, 0xbb, 0x00, 0x3b, 0x15, 0x1a, 0x3c, 0xe9,
		0x80, 0x27, 0x1d, 0x00, 0xd1, 0x8b, 0x05, 0x73, 0x78, 0xd2, 0x81, 0x0d, 0x9a, 0x05, 0x4f, 0x3a,
		0xf8, 0x8d, 0x29, 0x5c, 0xdd, 0xdd, 0xaf, 0xee, 0xd7, 0x1b, 0xbb, 0xfb, 0x3c, 0xdf, 0x80, 0xe2,
		0x05, 0xc5, 0x8b, 0xf2, 0xc4, 0x0b, 0xb3, 0x09, 0xe3, 0xbd, 0x76, 0x61, 0x32, 0x27, 0xa2, 0x6c,
		0x40, 0xd9, 0x80, 0xb2, 0x01, 0x65, 0x03, 0xca, 0x06, 0x16, 0xcb, 0x06, 0xe9, 0x86, 0x64, 0xe3,
		0x3e, 0x82, 0xb0, 0x05, 0x0c, 0x66, 0xcb, 0x57, 0xa9, 0xfb, 0x8b, 0xbd, 0xe9, 0xcd, 0xb6, 0x7f,
		0xbd, 0x3d, 0xab, 0xb8, 0xbb, 0xe7, 0xf9, 0x87, 0xbd, 0xb3, 0x1d, 0x77, 0xf7, 0xdc, 0xe4, 0xa6,
		0xa7, 0x73, 0x93, 0x53, 0x01, 0x69, 0x53, 0x53, 0xb9, 0xfb, 0x89, 0xff, 0x6d, 0x42, 0x18, 0xdc,
		0xd6, 0xc3, 0x8c, 0x66, 0x75, 0x73, 0x6c, 0x5a, 0x01, 0x30, 0x1c, 0x6b, 0x61, 0x3e, 0xad, 0x79,
		0x68, 0x0c, 0x73, 0x1b, 0xe6, 0x36, 0xcc, 0x6d, 0x98, 0xdb, 0x30, 0xb7, 0x61, 0x6e, 0xb3, 0x64,
		0xdc, 0xe8, 0x85, 0xe1, 0x48, 0x04, 0x10, 0xa7, 0xb7, 0x55, 0x36, 0x85, 0xba, 0xbc, 0x59, 0xe3,
		0x29, 0xee, 0x34, 0x95, 0x0a, 0x75, 0xa0, 0xa5, 0xa1, 0xa2, 0xcd, 0x4e, 0xd2, 0xff, 0x26, 0xae,
		0x82, 0x68, 0x5a, 0xe3, 0xdb, 0x0b, 0x23, 0xa1, 0xfa, 0x29, 0x51, 0x70, 0x95, 0xd0, 0x3f, 0xc2,
		0xf8, 0xd2, 0x95, 0x2a, 0xd1, 0x81, 0xea, 0x0b, 0x6f, 0xfe, 0x42, 0xb2, 0x70, 0xc5, 0x8b, 0xe2,
		0x50, 0x87, 0xfd, 0x70, 0x94, 0x14, 0x2d, 0xaf, 0x77, 0x11, 0x79, 0xb1, 0xec, 0x79, 0xc1, 0x50,
		0xba, 0x49, 0x30, 0x94, 0x49, 0xd1, 0xf2, 0x52, 0xa1, 0x60, 0xac, 0x64, 0x3f, 0x48, 0xb4, 0x37,
		0xca, 0xc2, 0xaa, 0x97, 0x52, 0xb4, 0x24, 0x7b, 0xcb, 0xaa, 0x87, 0x1b, 0x70, 0x36, 0x27, 0xd1,
		0xf1, 0xb8, 0xaf, 0x55, 0xbe, 0x5c, 0xbf, 0xe8, 0x95, 0xe3, 0xec, 0xff, 0xb8, 0x35, 0xfd, 0x1f,
		0xf6, 0xe7, 0x3e, 0x27, 0xf3, 0x17, 0xfc, 0x93, 0xbc, 0x47, 0x8a, 0x96, 0xff, 0xe9, 0x22, 0xf2,
		0x3b, 0xb2, 0xe7, 0x37, 0x87, 0xb2, 0x3b, 0xe9, 0x90, 0xbc, 0xe1, 0xb7, 0xa2, 0xeb, 0xea, 0x69,
		0xd6, 0x1d, 0xfe, 0x51, 0xd8, 0x9f, 0x7c, 0xa7, 0x93, 0xf6, 0x46, 0xf6, 0xe6, 0x77, 0xd3, 0xde,
		0x78, 0xb3, 0x9e, 0xce, 0x57, 0xa2, 0xe3, 0x39, 0x63, 0x75, 0xa9, 0xc2, 0x1f, 0xca, 0x0d, 0xb4,
		0x8e, 0x65, 0x6f, 0xd2, 0xc3, 0xa5, 0x3b, 0xdf, 0x83, 0xd3, 0x40, 0x17, 0x6c, 0x29, 0x39, 0x04,
		0xe5, 0x80, 0x52, 0xf2, 0x6d, 0x4d, 0xe5, 0x23, 0x26, 0xf3, 0x10, 0x8c, 0xfc, 0xc3, 0x74, 0xde,
		0x01, 0x93, 0x6f, 0xc0, 0xe4, 0x19, 0x30, 0xf9, 0xc5, 0x7a, 0x93, 0xad, 0x03, 0x19, 0x9b, 0x71,
		0xfb, 0x85, 0x20, 0x6f, 0x5e, 0x10, 0x5b, 0x34, 0xc9, 0xac, 0x2c, 0x56, 0xa1, 0x2c, 0x46, 0x59,
		0x8c, 0xb2, 0x18, 0x65, 0x31, 0xca, 0x62, 0xe8, 0x70, 0x56, 0x18, 0x30, 0xc1, 0x0e, 0x57, 0x9b,
		0x16, 0xe7, 0x66, 0x22, 0xd8, 0xbd, 0x49, 0x86, 0x5d, 0x03, 0x63, 0x79, 0xaf, 0x71, 0x78, 0x43,
		0x82, 0x39, 0x4c, 0xb8, 0x43, 0x83, 0x3d, 0x58, 0xf8, 0x83, 0x85, 0x41, 0x58, 0x38, 0x34, 0x0b,
		0x8b, 0x86, 0xe1, 0xb1, 0x18, 0x95, 0xaf, 0x08, 0x00, 0x35, 0x13, 0x77, 0x46, 0x22, 0x18, 0x82,
		0x1d, 0xd4, 0xd9, 0x00, 0xb0, 0xe5, 0x64, 0xfa, 0x14, 0xe2, 0xfd, 0xfb, 0x4c, 0xf8, 0xf7, 0xee,
		0xc1, 0x7c, 0x43, 0x37, 0x5c, 0x18, 0x74, 0x1d, 0x27, 0x7b, 0xf6, 0x02, 0x43, 0xec, 0x4c, 0x3d,
		0x0a, 0x02, 0xd2, 0x2a, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0xcc, 0x6b,
		0x1f, 0xb3, 0x1a, 0xc8, 0x48, 0x28, 0xbc, 0x93, 0xc5, 0x0b, 0xcb, 0xde, 0x71, 0xc3, 0x33, 0x30,
		0x88, 0x22, 0x82, 0x29, 0x36, 0xa8, 0xa2, 0x82, 0x2b, 0x3c, 0xc8, 0xc2, 0x83, 0x2d, 0x3c, 0xe8,
		0x62, 0x80, 0x2f, 0x08, 0x08, 0xe3, 0x29, 0x2c, 0x0b, 0x71, 0x6b, 0x2c, 0x95, 0xae, 0xd4, 0x01,
		0x2b, 0xd3, 0xd5, 0x81, 0x4c, 0xc2, 0x38, 0xe2, 0x68, 0xfe, 0x85, 0x15, 0xd3, 0xb7, 0xd0, 0x8e,
		0x40, 0x02, 0xa7, 0x57, 0x0b, 0xe6, 0x81, 0x1d, 0x91, 0xb4, 0x60, 0x1f, 0xe0, 0x31, 0x33, 0xa0,
		0xe1, 0x7e, 0xd6, 0x25, 0x82, 0x1b, 0xba, 0xc4, 0x0b, 0x5d, 0xa2, 0x5e, 0xab, 0xed, 0xd5, 0xe8,
		0x16, 0x76, 0x73, 0x31, 0x3c, 0x6b, 0x58, 0xa2, 0x10, 0x26, 0x6c, 0x02, 0xad, 0x94, 0x59, 0xa0,
		0xc8, 0x28, 0x2b, 0x66, 0x40, 0xa3, 0x36, 0x75, 0xa2, 0x65, 0x26, 0x13, 0x75, 0xa2, 0xa5, 0x66,
		0x3a, 0x75, 0xa2, 0x17, 0x1a, 0x48, 0x9d, 0xc8, 0xa2, 0xc4, 0x01, 0x5c, 0x27, 0xfa, 0x00, 0x28,
		0x13, 0xd5, 0x28, 0x13, 0xfd, 0xcb, 0x8b, 0x32, 0xd1, 0x5a, 0xe6, 0xc4, 0x94, 0x89, 0x6c, 0x8f,
		0xf6, 0xb3, 0x2e, 0x41, 0x99, 0xe8, 0xc5, 0x2e, 0xb1, 0x5b, 0xa3, 0x48, 0xb4, 0x06, 0xb2, 0xcc,
		0x16, 0x45, 0x22, 0xc0, 0xfe, 0x80, 0x11, 0x89, 0xae, 0xa7, 0xde, 0x8e, 0xa8, 0x12, 0x65, 0xb6,
		0x51, 0x26, 0x7a, 0xcc, 0x1c, 0xca, 0x44, 0x4b, 0xcc, 0x26, 0xca, 0x44, 0x4b, 0xcd, 0x74, 0xca,
		0x44, 0x2f, 0x34, 0x90, 0x32, 0x91, 0x45, 0x89, 0x03, 0xb0, 0x4c, 0xd4, 0x93, 0x2a, 0x88, 0x6f,
		0x01, 0x75, 0xa2, 0x7d, 0x20, 0x93, 0x8e, 0x84, 0xba, 0x48, 0x37, 0x72, 0x51, 0x28, 0xfa, 0xb7,
		0xac, 0x98, 0x42, 0xd1, 0x8b, 0xb3, 0xe2, 0x0a, 0x73, 0x62, 0xcb, 0xe3, 0xfd, 0xac, 0x4b, 0x50,
		0x28, 0x7a, 0xb1, 0x4b, 0x70, 0x3d, 0xd1, 0x9a, 0x88, 0x33, 0x5b, 0x94, 0x8a, 0x00, 0xfb, 0x03,
		0x41, 0x2a, 0x12, 0x37, 0x5a, 0xa8, 0x81, 0x18, 0xe0, 0x09, 0x45, 0x85, 0x65, 0x94, 0x89, 0x1e,
		0x33, 0x87, 0x32, 0xd1, 0x12, 0x73, 0x89, 0x32, 0xd1, 0x52, 0x33, 0x9d, 0x32, 0xd1, 0x0b, 0x0d,
		0xa4, 0x4c, 0x64, 0x51, 0xda, 0x80, 0x2c, 0x13, 0x19, 0xaf, 0x12, 0xf1, 0x14, 0x0c, 0x1a, 0xaa,
		0x1a, 0x41, 0x12, 0xf7, 0xd8, 0x98, 0x84, 0xd1, 0x24, 0x13, 0x0a, 0x46, 0x78, 0x24, 0xae, 0xb0,
		0x8c, 0x24, 0x8e, 0x24, 0x8e, 0x24, 0x8e, 0x24, 0x8e, 0x24, 0x8e, 0x24, 0x8e, 0x24, 0x8e, 0x24,
		0x8e, 0x24, 0x6e, 0x7e, 0x4c, 0xa2, 0x20, 0xd6, 0x12, 0x91, 0xc3, 0xe5, 0x86, 0x91, 0xc2, 0x91,
		0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0x91, 0xc2, 0xcd,
		0x8f, 0x89, 0x8e, 0x03, 0x95, 0x48, 0x2d, 0xaf, 0x01, 0xd7, 0xdd, 0x3f, 0xb0, 0x8d, 0x44, 0x8e,
		0x44, 0x8e, 0x44, 0x8e, 0x44, 0x8e, 0x44, 0x8e, 0x44, 0x8e, 0x44, 0x8e, 0x44, 0x0e, 0x8c, 0xc8,
		0x6d, 0xf4, 0x71, 0xf4, 0x86, 0xcb, 0xf8, 0x2f, 0xd8, 0x83, 0x5d, 0xd6, 0x7f, 0xb1, 0xe6, 0xf9,
		0xe2, 0x25, 0x0f, 0xa1, 0xe0, 0x4b, 0xd6, 0x97, 0x3a, 0x1e, 0xf7, 0xb5, 0x9a, 0x86, 0xa2, 0x76,
		0xd1, 0x95, 0xf3, 0xa5, 0xfe, 0xe7, 0x3e, 0x27, 0xf3, 0x17, 0xfc, 0x93, 0xbc, 0x1b, 0x8b, 0x96,
		0xff, 0xe9, 0x22, 0xf2, 0x3b, 0xb2, 0xe7, 0x37, 0x87, 0xb2, 0x3b, 0xe9, 0xc5, 0xbc, 0xe1, 0xb7,
		0xa2, 0xeb, 0xea, 0x69, 0xd6, 0x87, 0xfe, 0x51, 0xd8, 0x9f, 0x7c, 0xa7, 0x93, 0x76, 0x61, 0xf6,
		0xe6, 0x9f, 0x66, 0xfd, 0xd5, 0x2c, 0x7a, 0x70, 0xe1, 0x8a, 0xdf, 0x4d, 0x3b, 0x70, 0x53, 0x2b,
		0x27, 0x6d, 0x54, 0x25, 0xd0, 0xff, 0x27, 0x6e, 0x11, 0x8e, 0xf2, 0x73, 0x8e, 0x64, 0xa2, 0x27,
		0x13, 0xd0, 0x6c, 0x59, 0xd2, 0x2f, 0x52, 0x1d, 0x8e, 0xc4, 0x84, 0x77, 0x26, 0x66, 0xf3, 0x42,
		0xe7, 0x4b, 0x70, 0xf3, 0xc0, 0x92, 0xca, 0x87, 0x6a, 0xb5, 0xde, 0xa8, 0x56, 0x77, 0x1a, 0x7b,
		0x8d, 0x9d, 0xfd, 0x5a, 0xad, 0x52, 0xaf, 0x18, 0xdc, 0xa6, 0xe1, 0xb4, 0xe3, 0x81, 0x88, 0xc5,
		0xe0, 0xd3, 0x64, 0xea, 0xa8, 0xf1, 0x68, 0xb4, 0x51, 0x1e, 0x03, 0x02, 0xd8, 0x6b, 0x00, 0xd4,
		0x8e, 0xd1, 0x1a, 0x75, 0x56, 0x42, 0xb3, 0x19, 0x50, 0x2e, 0x1f, 0x12, 0xcb, 0xbd, 0x63, 0xc9,
		0xa1, 0xc4, 0x74, 0x08, 0xb1, 0x2e, 0x74, 0x18, 0x08, 0x14, 0x96, 0x04, 0x88, 0x72, 0xe3, 0x41,
		0x79, 0x5e, 0x59, 0xce, 0x9d, 0x4a, 0xf2, 0xfb, 0x9c, 0x64, 0x67, 0x52, 0xf0, 0x56, 0x18, 0xcb,
		0x0b, 0xa9, 0xb6, 0x26, 0xee, 0xe7, 0xca, 0xb2, 0x76, 0xbb, 0x99, 0x21, 0xd8, 0xe6, 0x08, 0x35,
		0x14, 0x81, 0x36, 0x43, 0x98, 0xcb, 0x9a, 0xdd, 0x86, 0xd0, 0x0c, 0x1b, 0xc5, 0x4a, 0x84, 0x2c,
		0x48, 0xa8, 0x2a, 0x07, 0x98, 0x56, 0x0f, 0x13, 0xab, 0xbd, 0xc3, 0x8a, 0x5d, 0xb4, 0x6c, 0xd7,
		0x44, 0x75, 0xc9, 0x12, 0x9c, 0x11, 0xcc, 0x09, 0x57, 0xeb, 0x7e, 0xab, 0x73, 0x8a, 0x15, 0x3a,
		0x44, 0x49, 0x65, 0xe9, 0x4b, 0x2d, 0x3b, 0x5f, 0x52, 0x59, 0xf9, 0xfb, 0xa5, 0x32, 0xbb, 0x2b,
		0xbe, 0x51, 0x89, 0x4b, 0x60, 0xcc, 0x2c, 0x6d, 0x29, 0x7b, 0xc9, 0x8a, 0xb1, 0xa5, 0x28, 0xc6,
		0x96, 0x98, 0x18, 0x5b, 0x3a, 0x42, 0xaa, 0x60, 0x35, 0x55, 0x28, 0xeb, 0xa9, 0x31, 0x0c, 0x53,
		0x28, 0xe1, 0x29, 0xef, 0x0a, 0x89, 0xc2, 0x1b, 0x8b, 0x9c, 0xac, 0x2c, 0xe7, 0x82, 0x73, 0x2a,
		0x67, 0xa5, 0x74, 0x0e, 0xc2, 0x8d, 0x56, 0xe3, 0x40, 0xaf, 0x3f, 0xbd, 0x57, 0x30, 0xb5, 0x1d,
		0x25, 0xe4, 0xc5, 0xb7, 0x5e, 0x18, 0x27, 0x2b, 0x9b, 0xd5, 0x05, 0x49, 0xbb, 0xbf, 0xd5, 0x8a,
		0x5c, 0x74, 0xb5, 0x4c, 0x7a, 0xe5, 0x0c, 0xba, 0x0c, 0xe6, 0x5c, 0x2e, 0x63, 0x2e, 0x8b, 0x29,
		0x97, 0xce, 0x90, 0x4b, 0x67, 0xc6, 0xa5, 0x33, 0x62, 0xbb, 0xc0, 0xf9, 0x40, 0xae, 0xf6, 0xa1,
		0x48, 0x11, 0xbb, 0xca, 0xd3, 0x1e, 0x8a, 0x3b, 0xae, 0x99, 0xfc, 0xb0, 0x43, 0xf9, 0x81, 0xf2,
		0x03, 0xe5, 0x87, 0x35, 0x94, 0x1f, 0x56, 0x1d, 0x84, 0x8b, 0x1b, 0x05, 0x83, 0xef, 0xe9, 0x98,
		0x48, 0xe5, 0x46, 0x61, 0xa2, 0xcb, 0xf3, 0x84, 0xa2, 0x1e, 0xd2, 0x9c, 0x01, 0x65, 0xad, 0x41,
		0x28, 0x25, 0x54, 0x97, 0x1e, 0xb2, 0x4d, 0x84, 0x6e, 0xb3, 0x21, 0xdc, 0x54, 0x28, 0x37, 0x1e,
		0xd2, 0x8d, 0x87, 0x76, 0xe3, 0x21, 0xbe, 0x9c, 0x50, 0x5f, 0x52, 0xc8, 0x2f, 0x3d, 0xf4, 0x17,
		0x37, 0x9c, 0x3e, 0x14, 0x2e, 0xdd, 0x71, 0xf2, 0x70, 0x51, 0xda, 0x43, 0x69, 0x83, 0x00, 0x50,
		0x9a, 0xf0, 0x81, 0x04, 0x08, 0x18, 0xc0, 0x60, 0x1a, 0x20, 0x60, 0x80, 0x02, 0x06, 0x30, 0x60,
		0x80, 0xa3, 0x5c, 0x00, 0x29, 0x19, 0x48, 0x8c, 0x01, 0xca, 0x2c, 0xb0, 0x98, 0xf3, 0xb7, 0x19,
		0x7c, 0x31, 0xe5, 0x6b, 0x66, 0x60, 0xc6, 0x58, 0xde, 0x81, 0x04, 0x3b, 0x58, 0xf0, 0x83, 0x02,
		0x43, 0x70, 0x70, 0x04, 0x07, 0x4b, 0x70, 0xf0, 0x64, 0x06, 0xa6, 0x0c, 0xc1, 0x95, 0x71, 0xd8,
		0x2a, 0x0c, 0xc8, 0x77, 0xa4, 0x18, 0xf7, 0xd4, 0xfb, 0x83, 0x68, 0xcb, 0xdc, 0x22, 0xf3, 0x6f,
		0x90, 0x66, 0xf8, 0x98, 0x30, 0x98, 0xf3, 0xca, 0x90, 0xce, 0x29, 0xc3, 0x3c, 0x9f, 0x0c, 0xed,
		0x5c, 0x32, 0xd8, 0xf3, 0xc8, 0x60, 0xcf, 0x21, 0x83, 0x3d, 0x7f, 0x6c, 0xb3, 0x0f, 0x4b, 0x82,
		0x39, 0x67, 0xac, 0x88, 0x3b, 0x23, 0x11, 0x0c, 0x63, 0x31, 0x44, 0x08, 0x3a, 0x79, 0xe6, 0xd5,
		0x00, 0xb0, 0xe5, 0x64, 0xba, 0x04, 0xf1, 0xfd, 0xfb, 0x6c, 0x5d, 0xad, 0x97, 0x43, 0xf9, 0xa6,
		0x1e, 0x2a, 0x64, 0x30, 0xff, 0x8a, 0x30, 0xe0, 0xfa, 0x9e, 0xd5, 0x41, 0x24, 0x5f, 0x24, 0x75,
		0x24, 0x75, 0x24, 0x75, 0x24, 0x75, 0x24, 0x75, 0x24, 0x75, 0x24, 0x75, 0xcf, 0x24, 0x75, 0x59,
		0xd8, 0x21, 0xa7, 0x2b, 0x7d, 0x28, 0xca, 0xd9, 0xcb, 0xfc, 0xdb, 0x0e, 0x83, 0x70, 0xe2, 0xaa,
		0xe1, 0x27, 0x4f, 0x64, 0x74, 0x64, 0x74, 0x64, 0x74, 0x64, 0x74, 0x64, 0x74, 0xe6, 0x9f, 0x64,
		0x15, 0x86, 0xa4, 0xc7, 0x1a, 0x4b, 0x35, 0x10, 0x37, 0x78, 0xf5, 0x79, 0x1e, 0xd8, 0xc6, 0xfa,
		0x3c, 0xc8, 0x40, 0x8a, 0x08, 0xa8, 0xd8, 0xc0, 0x8a, 0x0a, 0xb0, 0xf0, 0x40, 0x0b, 0x0f, 0xb8,
		0xf0, 0xc0, 0x8b, 0x01, 0xc0, 0x20, 0x40, 0x8c, 0x27, 0xb1, 0x00, 0x4b, 0x2d, 0x88, 0x92, 0xcb,
		0x63, 0xd2, 0xcb, 0x3f, 0xfc, 0x97, 0x52, 0x8a, 0x44, 0xe8, 0xa4, 0x68, 0x4d, 0x85, 0x9a, 0x8c,
		0x66, 0xb0, 0xde, 0x10, 0x8a, 0x53, 0x3a, 0x3d, 0x91, 0x68, 0x77, 0x7a, 0x4e, 0x0b, 0x18, 0x2f,
		0xbd, 0x37, 0x8d, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x94, 0xb4, 0x74, 0xc3,
		0x68, 0x29, 0xcb, 0x46, 0x92, 0xc6, 0xfd, 0xc6, 0x98, 0xf4, 0xc3, 0xab, 0xab, 0xb1, 0x92, 0xfa,
		0x16, 0x55, 0x64, 0x9c, 0x37, 0x90, 0x94, 0x8e, 0x94, 0x8e, 0x94, 0x8e, 0x94, 0x8e, 0x94, 0x8e,
		0x94, 0x6e, 0xc3, 0x28, 0x1d, 0x95, 0xc6, 0xdf, 0x83, 0x9e, 0xdf, 0x52, 0x1a, 0x73, 0x5e, 0x21,
		0x45, 0x52, 0xb4, 0x6f, 0x29, 0x36, 0x62, 0xb2, 0x54, 0x71, 0xa3, 0x5d, 0x78, 0xa6, 0xfa, 0x98,
		0x91, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64, 0xab, 0x64,
		0xab, 0xcf, 0x65, 0xab, 0x0f, 0xb9, 0xc5, 0x84, 0xb1, 0xce, 0x70, 0x0d, 0xb2, 0x56, 0x4c, 0xd6,
		0x2a, 0xd5, 0x75, 0x30, 0x92, 0x03, 0x37, 0x16, 0x41, 0x62, 0xb8, 0xd6, 0xfe, 0xa3, 0x1e, 0x3a,
		0x67, 0x1f, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0xea, 0x86, 0x71,
		0x55, 0x39, 0x10, 0x4a, 0x4b, 0x7d, 0x0b, 0xca, 0x57, 0x6b, 0x40, 0x36, 0xb5, 0xa6, 0x5d, 0xf5,
		0x29, 0x48, 0x00, 0x43, 0x6a, 0x3e, 0xa0, 0xad, 0xe3, 0xbf, 0x9a, 0x47, 0xad, 0x03, 0xbf, 0xd3,
		0x3e, 0xfd, 0x7a, 0xe8, 0x77, 0x0e, 0x9b, 0xdd, 0xf6, 0x31, 0x5a, 0x74, 0xfd, 0x2b, 0x18, 0x8d,
		0xd3, 0x43, 0xbc, 0xcf, 0xa0, 0xec, 0x9a, 0xbc, 0x7e, 0xc2, 0x59, 0xf4, 0xe8, 0xe8, 0xfe, 0x71,
		0x74, 0xda, 0xfd, 0x7a, 0xd8, 0xf1, 0x8f, 0xda, 0xed, 0x13, 0x07, 0xce, 0xe4, 0xbb, 0x77, 0x1c,
		0xd7, 0xe7, 0x8d, 0x6b, 0xbb, 0xd3, 0xfa, 0xb3, 0x75, 0xdc, 0xfc, 0xda, 0xee, 0x70, 0x54, 0xd7,
		0x67, 0x54, 0x9b, 0x5d, 0x3a, 0xea, 0xba, 0x05, 0xe0, 0xf6, 0xf1, 0xe7, 0xc3, 0x03, 0xc0, 0x11,
		0x85, 0xb2, 0xe8, 0x9c, 0xf9, 0x08, 0x98, 0x15, 0x08, 0xea, 0xe0, 0x28, 0x48, 0xb4, 0x7b, 0x15,
		0x0e, 0xe4, 0x50, 0x8a, 0x01, 0x9e, 0x38, 0x38, 0x6b, 0x1e, 0xb5, 0xc1, 0xc7, 0xcc, 0xa1, 0x36,
		0xb8, 0xc4, 0x84, 0xa2, 0x36, 0xb8, 0xd4, 0x4c, 0xa7, 0x36, 0xf8, 0x42, 0x03, 0xa9, 0x0d, 0x5a,
		0xc4, 0x7d, 0x81, 0xb5, 0x41, 0x2d, 0xaf, 0x84, 0x96, 0xfd, 0xcb, 0xa4, 0x5e, 0x05, 0xd4, 0x06,
		0x3f, 0x00, 0x99, 0x74, 0xaa, 0xa4, 0x4e, 0xd2, 0xe2, 0xcd, 0x81, 0x0a, 0x13, 0xd1, 0x0f, 0xd5,
		0x20, 0x41, 0xea, 0xb2, 0x4e, 0xa0, 0x2e, 0x04, 0x9c, 0xde, 0x86, 0x97, 0xea, 0x39, 0x5f, 0xa4,
		0x82, 0x43, 0x44, 0x50, 0x0e, 0xb8, 0x60, 0x5e, 0xaa, 0xea, 0x02, 0xdb, 0xf7, 0x39, 0x0e, 0xfa,
		0x5a, 0x86, 0xea, 0x40, 0x5e, 0x64, 0xde, 0xba, 0x43, 0x3d, 0xe6, 0x77, 0x5c, 0x22, 0xb8, 0xa1,
		0x4b, 0xbc, 0xd0, 0x25, 0x2a, 0x1f, 0xaa, 0xd5, 0x7a, 0xa3, 0x5a, 0xdd, 0x69, 0xec, 0x35, 0x76,
		0xf6, 0x6b, 0xb5, 0x4a, 0x1d, 0xe9, 0xc9, 0x96, 0x75, 0x5e, 0xf2, 0x86, 0xd6, 0x3c, 0xf6, 0x3a,
		0xa7, 0xc6, 0x85, 0x12, 0x45, 0x61, 0xea, 0x71, 0x2d, 0x90, 0x7a, 0x8c, 0xba, 0x5c, 0xa0, 0x01,
		0x9c, 0xba, 0xd6, 0x32, 0x53, 0x89, 0xba, 0xd6, 0x52, 0x33, 0x9d, 0xba, 0xd6, 0x0b, 0x0d, 0xa4,
		0xae, 0x65, 0x51, 0x0e, 0x01, 0xac, 0x6b, 0x8d, 0xa5, 0xd2, 0x7b, 0xbb, 0x80, 0x92, 0x56, 0x83,
		0x92, 0xd1, 0xbf, 0xbc, 0x28, 0x19, 0xad, 0x65, 0x7e, 0x4c, 0xc9, 0xc8, 0xf6, 0x70, 0x3f, 0xeb,
		0x12, 0x94, 0x8c, 0x5e, 0xec, 0x12, 0xd5, 0xdd, 0xfd, 0xea, 0x7e, 0xbd, 0xb1, 0xbb, 0x4f, 0xa1,
		0x68, 0x0d, 0xa4, 0x99, 0x2d, 0x0a, 0x45, 0x80, 0xfd, 0x01, 0x21, 0x14, 0x61, 0x25, 0xf8, 0x58,
		0x95, 0x3e, 0x41, 0x83, 0x36, 0x65, 0xa2, 0x65, 0x66, 0x12, 0x65, 0xa2, 0xa5, 0x66, 0x3a, 0x65,
		0xa2, 0x17, 0x1a, 0x48, 0x99, 0xc8, 0xa2, 0xbc, 0x01, 0x79, 0x6b, 0x64, 0x74, 0x5d, 0x75, 0xe1,
		0x7c, 0xb0, 0xd8, 0x1a, 0xf9, 0x01, 0xeb, 0x28, 0x0f, 0x2d, 0x62, 0x05, 0x27, 0x17, 0x39, 0x6f,
		0xdf, 0x9e, 0xed, 0xb8, 0xfb, 0xe7, 0xbf, 0xce, 0x2a, 0xee, 0xfe, 0x79, 0xd6, 0xac, 0xa4, 0x6f,
		0x59, 0x7b, 0xf7, 0x6c, 0xc7, 0xad, 0xe6, 0xed, 0xda, 0xd9, 0x8e, 0x5b, 0x3b, 0xdf, 0xfe, 0xfb,
		0xef, 0xf7, 0xdb, 0x3f, 0xf7, 0xee, 0x96, 0xff, 0xa1, 0x37, 0xbd, 0xd9, 0xf6, 0xaf, 0xb7, 0x67,
		0x15, 0x77, 0xf7, 0x3c, 0xff, 0xb0, 0x77, 0xb6, 0xe3, 0xee, 0x9e, 0x6f, 0x6f, 0xe3, 0x44, 0xa0,
		0x73, 0xa4, 0xa9, 0xd3, 0xee, 0xb6, 0xfe, 0x0b, 0x3b, 0x7f, 0xfe, 0x87, 0x34, 0x81, 0xfe, 0xe3,
		0x30, 0x83, 0x64, 0x06, 0xb9, 0x30, 0x47, 0xa7, 0x47, 0xd9, 0x84, 0x63, 0x2d, 0xf0, 0xd2, 0xc8,
		0x87, 0xc6, 0x31, 0x97, 0x64, 0x2e, 0xc9, 0x5c, 0x92, 0xb9, 0x24, 0x73, 0x49, 0xe6, 0x92, 0x1b,
		0x96, 0x4b, 0xb2, 0x26, 0x0d, 0x3e, 0x95, 0xdb, 0xe8, 0xb2, 0xdf, 0x4d, 0xa5, 0x42, 0x1d, 0x68,
		0x09, 0x72, 0x5a, 0xa3, 0x93, 0xf4, 0xbf, 0x89, 0xab, 0x60, 0x5a, 0x65, 0xd1, 0xf1, 0xc2, 0x48,
		0xa8, 0x7e, 0x4a, 0x94, 0x5c, 0x25, 0xf4, 0x8f, 0x30, 0xbe, 0x74, 0xa5, 0x4a, 0x74, 0xa0, 0xfa,
		0xc2, 0x9b, 0xbf, 0x90, 0x2c, 0x5c, 0xf1, 0xa2, 0x38, 0xd4, 0x61, 0x3f, 0x1c, 0x25, 0x45, 0xcb,
		0xeb, 0x5d, 0x44, 0x5e, 0x2c, 0x7b, 0x5e, 0x30, 0x94, 0x6e, 0x12, 0x0c, 0x65, 0x52, 0xb4, 0xbc,
		0x54, 0xf8, 0x19, 0x2b, 0xd9, 0x0f, 0x12, 0xed, 0x29, 0x21, 0x2f, 0xbe, 0xf5, 0xc2, 0x38, 0x29,
		0x5a, 0x5e, 0x30, 0xf8, 0x9e, 0x22, 0x81, 0x54, 0x6e, 0x14, 0x26, 0xda, 0x4b, 0xd9, 0x6d, 0x92,
		0xbd, 0x65, 0x27, 0x92, 0x02, 0xf8, 0xb9, 0x93, 0xe8, 0x78, 0xdc, 0xd7, 0x6a, 0x1a, 0x80, 0xda,
		0x45, 0x07, 0x1e, 0x67, 0x9d, 0xd3, 0x9a, 0xf6, 0x8d, 0x3f, 0xf7, 0x39, 0x99, 0xbf, 0xe0, 0x9f,
		0xe4, 0x9d, 0x57, 0xb4, 0xfc, 0x4f, 0x17, 0x91, 0xdf, 0x91, 0x3d, 0xbf, 0x39, 0x94, 0xdd, 0x49,
		0xdf, 0xe5, 0x0d, 0xbf, 0x15, 0x5d, 0x57, 0x4f, 0xb3, 0x9e, 0xf3, 0x8f, 0xf3, 0x9e, 0x2b, 0x5a,
		0x7e, 0x73, 0xf0, 0xbd, 0x23, 0x7b, 0x2d, 0x75, 0x12, 0x26, 0xda, 0xef, 0xa4, 0xdd, 0x96, 0xbd,
		0xf9, 0xdd, 0xb4, 0xdb, 0xde, 0x6c, 0x66, 0x00, 0x30, 0xe8, 0xfc, 0xce, 0x58, 0x5d, 0xaa, 0xf0,
		0x87, 0x72, 0x03, 0xad, 0x63, 0xd9, 0x9b, 0x8c, 0x88, 0xf1, 0x00, 0x70, 0xbf, 0x50, 0x6f, 0xd1,
		0x36, 0xc3, 0x61, 0x32, 0x07, 0x4d, 0xc3, 0x66, 0xa0, 0xe4, 0x8c, 0x48, 0xb9, 0x22, 0x66, 0x8e,
		0x88, 0x96, 0x1b, 0xc2, 0xe6, 0x84, 0xb0, 0xb9, 0x20, 0x6c, 0x0e, 0xb8, 0xd9, 0x84, 0xf5, 0x40,
		0xc6, 0x18, 0x61, 0x67, 0x01, 0xa4, 0xf0, 0x44, 0xd8, 0x45, 0x13, 0xb1, 0xa4, 0xd8, 0x0a, 0xa5,
		0x58, 0x78, 0x78, 0xc5, 0x86, 0x59, 0x54, 0xb8, 0x85, 0x87, 0x5d, 0x78, 0xf8, 0x85, 0x87, 0x61,
		0x1c, 0x05, 0x6b, 0x0b, 0x48, 0x8a, 0x45, 0x81, 0xe7, 0xc2, 0xa0, 0x09, 0xf6, 0xb9, 0x1a, 0x4d,
		0x20, 0x9e, 0x89, 0xa8, 0xf7, 0x26, 0x82, 0xb9, 0x1e, 0xe6, 0x96, 0x09, 0x38, 0xb8, 0x46, 0x86,
		0x6d, 0x3b, 0xe0, 0x1b, 0x1d, 0xc6, 0xad, 0x81, 0x73, 0x6b, 0x60, 0xdd, 0x1a, 0x78, 0xc7, 0x82,
		0x79, 0x30, 0xb8, 0x2f, 0x46, 0xf1, 0x2b, 0x22, 0xc0, 0x6e, 0x61, 0x17, 0xe7, 0x5b, 0xc8, 0x86,
		0x1b, 0x80, 0xb6, 0x3d, 0x28, 0xd6, 0x97, 0xd5, 0xdc, 0xbb, 0x27, 0x2b, 0xdc, 0x64, 0x87, 0xee,
		0x9a, 0x4e, 0xf6, 0x50, 0x12, 0x96, 0xf8, 0xa2, 0x3c, 0x33, 0x7d, 0xd4, 0x1b, 0x49, 0x7a, 0x49,
		0x7a, 0x49, 0x7a, 0x49, 0x7a, 0x49, 0x7a, 0x89, 0xac, 0x8f, 0x8f, 0x22, 0x9a, 0xd6, 0x55, 0x18,
		0x96, 0x72, 0xb4, 0x91, 0x00, 0x3e, 0x9f, 0x66, 0x46, 0xfa, 0x9a, 0x58, 0xfa, 0x8e, 0x87, 0x86,
		0xac, 0x11, 0x29, 0xb0, 0x81, 0x1c, 0xd8, 0x45, 0x12, 0x6c, 0x21, 0x0b, 0xd6, 0x91, 0x06, 0xeb,
		0xc8, 0x83, 0x75, 0x24, 0x02, 0x93, 0x4c, 0x80, 0x92, 0x8a, 0x62, 0x74, 0x61, 0x15, 0xb5, 0x85,
		0xb8, 0x39, 0x96, 0x4a, 0x57, 0xea, 0xc8, 0x31, 0x73, 0x8a, 0xe2, 0x75, 0x60, 0x13, 0x31, 0x8f,
		0x5d, 0x9c, 0x7f, 0x61, 0x63, 0xce, 0x16, 0xfa, 0xb1, 0x8c, 0x96, 0xd1, 0xcb, 0x05, 0x73, 0xc1,
		0x8f, 0x6d, 0x5c, 0xb0, 0xd7, 0x82, 0xa3, 0xea, 0x2c, 0x81, 0xa3, 0x59, 0x17, 0x0b, 0x6e, 0xe8,
		0x62, 0x2b, 0x76, 0xb1, 0x7a, 0xad, 0xb6, 0x57, 0xa3, 0x9b, 0x6d, 0x16, 0x17, 0xc5, 0xb7, 0xee,
		0xfc, 0x0d, 0xfb, 0xcb, 0xd2, 0x30, 0x0e, 0xbc, 0x12, 0x6e, 0x21, 0xa5, 0x40, 0x5d, 0x11, 0x67,
		0x09, 0xaa, 0x50, 0x17, 0x7c, 0xcd, 0xc9, 0x48, 0x5d, 0xf0, 0x55, 0x3d, 0x87, 0xba, 0xe0, 0x8a,
		0x0d, 0xa6, 0x2e, 0xb8, 0xc6, 0x89, 0x98, 0x65, 0xba, 0xe0, 0x07, 0x0b, 0x64, 0xc1, 0x1a, 0x65,
		0xc1, 0x17, 0xbe, 0x28, 0x0b, 0x52, 0xb3, 0xa0, 0x2c, 0xb8, 0x81, 0x68, 0x34, 0xeb, 0x62, 0x94,
		0x05, 0x57, 0xee, 0x62, 0xbb, 0x35, 0x8a, 0x82, 0x1b, 0x46, 0x44, 0xf1, 0xad, 0xa3, 0x28, 0x68,
		0x6d, 0x10, 0xcf, 0x94, 0xb6, 0xeb, 0x69, 0x74, 0xb1, 0x41, 0x15, 0xcc, 0x6c, 0xa5, 0x2c, 0xf8,
		0x1c, 0xf3, 0x28, 0x0b, 0xbe, 0xe2, 0x6c, 0xa4, 0x2c, 0xf8, 0xaa, 0x9e, 0x43, 0x59, 0x70, 0xc5,
		0x06, 0x53, 0x16, 0x5c, 0xe3, 0x44, 0xcc, 0x22, 0x59, 0xb0, 0x27, 0x55, 0x10, 0xdf, 0x5a, 0xa0,
		0x0b, 0xee, 0x03, 0x9b, 0x78, 0x24, 0xd4, 0x45, 0xba, 0x31, 0x97, 0xc2, 0xe0, 0x4b, 0x55, 0x0b,
		0x0a, 0x83, 0x2b, 0x57, 0x2d, 0x2a, 0xd4, 0x2c, 0x36, 0x0c, 0x8f, 0x66, 0x5d, 0x8c, 0xc2, 0xe0,
		0xca, 0x5d, 0x8c, 0xeb, 0x05, 0x37, 0x90, 0x8c, 0xe2, 0x5b, 0x47, 0x69, 0xd0, 0xda, 0x30, 0xee,
		0x88, 0x1b, 0x2d, 0xd4, 0x40, 0x0c, 0xf0, 0x85, 0xc1, 0xc2, 0x52, 0xca, 0x82, 0xcf, 0x31, 0x8f,
		0xb2, 0xe0, 0x2b, 0xce, 0x45, 0xca, 0x82, 0xaf, 0xea, 0x39, 0x94, 0x05, 0x57, 0x6c, 0x30, 0x65,
		0xc1, 0x35, 0x4e, 0xc3, 0x6c, 0x92, 0x05, 0xe1, 0x2a, 0xa5, 0x3d, 0x05, 0xe3, 0x20, 0x95, 0xd3,
		0x48, 0x6a, 0x9f, 0x33, 0x86, 0x61, 0x34, 0xc9, 0x3c, 0x83, 0x11, 0x3e, 0xa9, 0x2d, 0x2c, 0x25,
		0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25, 0xa9, 0x25,
		0xa9, 0xa5, 0x53, 0xcc, 0x8e, 0x61, 0x14, 0xc4, 0x5a, 0xda, 0xc0, 0x69, 0x73, 0x43, 0x49, 0x69,
		0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69, 0x49, 0x69,
		0xe9, 0x14, 0xb3, 0x63, 0xa8, 0xe3, 0x40, 0x25, 0x52, 0xcb, 0x6b, 0x0b, 0xf6, 0x25, 0x3d, 0xb0,
		0x95, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4, 0x96, 0xc4,
		0x96, 0xc4, 0x96, 0x16, 0x81, 0xba, 0xa8, 0xd3, 0x54, 0x2a, 0xd4, 0x81, 0x96, 0x21, 0xe6, 0x06,
		0x28, 0x27, 0xe9, 0x7f, 0x13, 0x57, 0x41, 0x34, 0x2d, 0x40, 0xe9, 0x85, 0x91, 0x50, 0xfd, 0x94,
		0x28, 0xba, 0x4a, 0xe8, 0x1f, 0x61, 0x7c, 0xe9, 0x4a, 0x95, 0xe8, 0x40, 0xf5, 0x85, 0x37, 0x7f,
		0x21, 0x59, 0xb8, 0xe2, 0x45, 0x71, 0xa8, 0xc3, 0x7e, 0x38, 0x4a, 0x8a, 0x96, 0xd7, 0xbb, 0x88,
		0xbc, 0x58, 0xf6, 0xbc, 0x60, 0x28, 0xdd, 0x24, 0x18, 0xca, 0xa4, 0x68, 0x79, 0x32, 0xba, 0xae,
		0xba, 0x63, 0x25, 0xfb, 0x41, 0xa2, 0x3d, 0x25, 0xe4, 0xc5, 0xb7, 0x5e, 0x18, 0x27, 0x45, 0xcb,
		0x0b, 0x06, 0xdf, 0x53, 0xa4, 0x92, 0xca, 0x8d, 0xc2, 0x44, 0x7b, 0x71, 0x38, 0xd6, 0x22, 0xc9,
		0xde, 0xbc, 0xb1, 0xba, 0x54, 0xe1, 0x0f, 0xe5, 0x06, 0x5a, 0xc7, 0xb2, 0x97, 0xfe, 0x61, 0xe1,
		0x92, 0x87, 0x58, 0xfb, 0x30, 0xeb, 0x76, 0x1d, 0x8f, 0xfb, 0x5a, 0x4d, 0xa3, 0x62, 0xbb, 0xe8,
		0xf5, 0xe3, 0xac, 0x47, 0x5b, 0xd3, 0x0e, 0xf5, 0xe7, 0x3e, 0x27, 0xf3, 0x17, 0xfc, 0x93, 0xbc,
		0xc7, 0x8b, 0x96, 0xff, 0xe9, 0x22, 0xf2, 0x3b, 0xb2, 0xe7, 0x37, 0x87, 0xb2, 0x3b, 0xe9, 0xf0,
		0xbc, 0xe1, 0xb7, 0xa2, 0xeb, 0xea, 0x69, 0xd6, 0xdd, 0xfe, 0x71, 0xde, 0xdd, 0x45, 0xcb, 0x6f,
		0x0e, 0xbe, 0x77, 0x64, 0xaf, 0xa5, 0x4e, 0xc2, 0x44, 0xfb, 0x9d, 0xb4, 0xaf, 0xb3, 0x37, 0xff,
		0x34, 0xeb, 0xd8, 0x66, 0xd1, 0xd5, 0x0b, 0x57, 0xfc, 0x6e, 0xda, 0xd3, 0xac, 0x56, 0x0a, 0x6c,
		0x09, 0x48, 0x68, 0x9c, 0xb0, 0x7d, 0xc4, 0xe3, 0x87, 0x9d, 0x23, 0x99, 0xe8, 0xc9, 0x84, 0x86,
		0x0a, 0xd4, 0xce, 0x17, 0xa9, 0x0e, 0x47, 0x62, 0xc2, 0xdd, 0x13, 0xac, 0xdc, 0xdd, 0xf9, 0x12,
		0xdc, 0x3c, 0xb0, 0xac, 0xf2, 0xa1, 0x5a, 0xad, 0x37, 0xaa, 0xd5, 0x9d, 0xc6, 0x5e, 0x63, 0x67,
		0xbf, 0x56, 0xab, 0xd4, 0x2b, 0x40, 0x5b, 0xe5, 0x9c, 0x76, 0x3c, 0x10, 0xb1, 0x18, 0x7c, 0x9a,
		0x4c, 0x3d, 0x35, 0x1e, 0x8d, 0xe8, 0x91, 0xf8, 0x24, 0x65, 0xbd, 0xc9, 0x89, 0x03, 0x55, 0xc2,
		0x7a, 0xbd, 0xe8, 0x08, 0x06, 0x11, 0x31, 0x0f, 0xfb, 0x66, 0x2d, 0x30, 0x1c, 0xde, 0xd0, 0xc2,
		0xda, 0x3a, 0x85, 0x33, 0x80, 0xe0, 0x65, 0x7b, 0xd0, 0x32, 0x1b, 0xa3, 0xcc, 0x45, 0x06, 0x33,
		0x77, 0x36, 0x14, 0x8b, 0xf2, 0x64, 0x27, 0x7b, 0xac, 0xb1, 0x35, 0xf1, 0x7d, 0x57, 0x9a, 0xda,
		0x42, 0x8d, 0x91, 0xe1, 0xe0, 0x64, 0x34, 0xd0, 0x19, 0x0c, 0x46, 0xc6, 0x62, 0xca, 0x6d, 0x40,
		0xa0, 0xdb, 0x5a, 0xc8, 0x36, 0x88, 0xcf, 0x76, 0xe1, 0xb2, 0x19, 0x14, 0x2e, 0x1f, 0x03, 0xcb,
		0xbd, 0x63, 0xc9, 0x61, 0xc3, 0x74, 0xb8, 0xb0, 0x30, 0x4c, 0x18, 0x08, 0x10, 0xb6, 0x04, 0x86,
		0x72, 0x43, 0x42, 0x79, 0x8e, 0x59, 0xa2, 0x53, 0x3a, 0xd9, 0x83, 0xb7, 0xb2, 0x7d, 0xb1, 0x58,
		0x66, 0x60, 0xe2, 0xb9, 0x5f, 0xb1, 0x70, 0xa0, 0xe4, 0xdb, 0x16, 0xeb, 0xfa, 0x76, 0x4b, 0xbe,
		0xb1, 0xc1, 0xf5, 0x7a, 0x18, 0xeb, 0xf0, 0x4c, 0xaf, 0xaf, 0x83, 0x59, 0x37, 0x07, 0xb3, 0x1e,
		0x0e, 0x66, 0x9d, 0x1b, 0xe9, 0x16, 0xe9, 0x56, 0x46, 0xb7, 0x4c, 0x2d, 0x41, 0xc1, 0x67, 0x5b,
		0x06, 0x96, 0x8c, 0x94, 0x48, 0xb6, 0xde, 0xac, 0x91, 0xe3, 0x9b, 0x72, 0x78, 0x9b, 0x1c, 0xdd,
		0x29, 0x95, 0x5d, 0x63, 0xbb, 0x76, 0x39, 0x4e, 0xbd, 0x7a, 0x17, 0x2b, 0xc1, 0xbd, 0x9c, 0x87,
		0xd3, 0x28, 0x2e, 0x8f, 0x4b, 0xde, 0xd7, 0x7b, 0x9a, 0xbd, 0x7f, 0x49, 0x01, 0xa5, 0xdc, 0x5c,
		0xa9, 0xf4, 0xbd, 0x4f, 0x26, 0x72, 0x23, 0xb3, 0x39, 0x91, 0xa9, 0x5c, 0xc8, 0x78, 0x0e, 0x64,
		0x3c, 0xf7, 0x31, 0x9e, 0xf3, 0xac, 0x17, 0xd5, 0x39, 0x90, 0xe5, 0x3e, 0x1e, 0x75, 0xa6, 0x7a,
		0xac, 0x31, 0xad, 0xcc, 0x88, 0x1e, 0x4c, 0xb1, 0x8c, 0x62, 0x19, 0xc5, 0x32, 0x8a, 0x65, 0x1b,
		0x20, 0x96, 0x95, 0x0d, 0x28, 0xb3, 0xc0, 0x62, 0xce, 0xdf, 0x66, 0xf0, 0xc5, 0x94, 0xaf, 0x99,
		0x81, 0x19, 0x63, 0x79, 0x07, 0x12, 0xec, 0x60, 0xc1, 0x0f, 0x0a, 0x0c, 0xc1, 0xc1, 0x11, 0x1c,
		0x2c, 0xc1, 0xc1, 0x93, 0x19, 0x98, 0x32, 0x04, 0x57, 0xc6, 0x61, 0xab, 0x30, 0x20, 0x5f, 0x2b,
		0x6b, 0xdc, 0x53, 0xef, 0xcf, 0xd5, 0x34, 0xb9, 0x78, 0x77, 0x1e, 0xd2, 0x0c, 0xef, 0x04, 0x84,
		0x39, 0x4e, 0x08, 0xe9, 0xd8, 0x20, 0xcc, 0xe3, 0x81, 0xd0, 0x8e, 0x01, 0x82, 0x3d, 0xee, 0x07,
		0xf6, 0x58, 0x1f, 0xd8, 0xe3, 0x7b, 0x36, 0x7b, 0x7f, 0x19, 0xcc, 0xb1, 0x3b, 0x45, 0xdc, 0x19,
		0x89, 0x60, 0x18, 0x8b, 0x21, 0x42, 0xd0, 0xc9, 0x33, 0xaf, 0x06, 0x80, 0x2d, 0x27, 0xd3, 0x07,
		0xc8, 0xef, 0xdf, 0x67, 0xcb, 0x31, 0xbc, 0x1c, 0xca, 0x37, 0x75, 0x0b, 0x96, 0xc1, 0xfc, 0x2b,
		0xc2, 0x80, 0xeb, 0x7b, 0x56, 0x07, 0x91, 0x7c, 0x91, 0xd4, 0x91, 0xd4, 0x91, 0xd4, 0x91, 0xd4,
		0x91, 0xd4, 0x91, 0xd4, 0x91, 0xd4, 0x3d, 0x93, 0xd4, 0x65, 0x61, 0x87, 0x9c, 0xae, 0xf4, 0xa1,
		0x30, 0xb3, 0xdb, 0xe7, 0x49, 0x87, 0x41, 0x38, 0xf5, 0xcf, 0xf0, 0x93, 0x27, 0x32, 0x3a, 0x32,
		0x3a, 0x32, 0x3a, 0x32, 0x3a, 0x32, 0x3a, 0xf3, 0x4f, 0xb2, 0x0a, 0x43, 0xd2, 0x13, 0x2f, 0xa5,
		0x1a, 0x08, 0x9c, 0x22, 0x07, 0xf7, 0xcb, 0xc0, 0xef, 0x6d, 0x43, 0x39, 0x26, 0x14, 0xaa, 0x9c,
		0x06, 0x5c, 0xf9, 0x0c, 0xc4, 0x72, 0x19, 0xd8, 0xe5, 0x31, 0x50, 0xcb, 0x61, 0xc0, 0x97, 0xbf,
		0x80, 0x2f, 0x77, 0x01, 0x5f, 0xde, 0x82, 0x07, 0x40, 0x43, 0x4a, 0x2c, 0xc0, 0x52, 0x0b, 0xa2,
		0xe4, 0xf2, 0x98, 0xf4, 0xf2, 0x0f, 0xff, 0xa5, 0x94, 0x22, 0x11, 0x3a, 0x29, 0x5a, 0x53, 0xa1,
		0x26, 0xa3, 0x19, 0x3c, 0xa2, 0x15, 0xc5, 0x29, 0x9d, 0x7e, 0x78, 0x75, 0x35, 0x56, 0x52, 0xdf,
		0xa2, 0xb2, 0xd3, 0x79, 0x03, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49,
		0x51, 0x49, 0x51, 0x49, 0x51, 0x9f, 0x4b, 0x51, 0x73, 0x5e, 0x21, 0x45, 0x52, 0xb4, 0x6f, 0xc9,
		0x52, 0x31, 0x59, 0xaa, 0xb8, 0xd1, 0x2e, 0x3c, 0x53, 0x7d, 0xcc, 0x48, 0xb2, 0x55, 0xb2, 0x55,
		0xb2, 0x55, 0xb2, 0x55, 0xb2, 0x55, 0xb2, 0x55, 0xb2, 0x55, 0xb2, 0xd5, 0xe7, 0xb2, 0xd5, 0x87,
		0xdc, 0x62, 0xc2, 0x58, 0x67, 0xb8, 0x06, 0x59, 0x2b, 0x26, 0x6b, 0x95, 0xea, 0x3a, 0x18, 0xc9,
		0x81, 0x1b, 0x8b, 0x20, 0x01, 0xaa, 0xaf, 0x57, 0x78, 0xe8, 0x9c, 0x7d, 0xe4, 0xaa, 0xe4, 0xaa,
		0xe4, 0xaa, 0xe4, 0xaa, 0xe4, 0xaa, 0xe4, 0xaa, 0x1b, 0xc6, 0x55, 0xe5, 0x40, 0x28, 0x2d, 0xf5,
		0x2d, 0x28, 0x5f, 0x45, 0xaa, 0xa6, 0xdc, 0x9a, 0x76, 0xd5, 0xa7, 0x20, 0x01, 0x0c, 0xa9, 0xf9,
		0x80, 0xb6, 0x8e, 0xff, 0x6a, 0x1e, 0xb5, 0x0e, 0xfc, 0x4e, 0xfb, 0xf4, 0xeb, 0xa1, 0xdf, 0x39,
		0x6c, 0x76, 0xdb, 0xc7, 0x68, 0xd1, 0xf5, 0xaf, 0x60, 0x34, 0x4e, 0x4f, 0x7f, 0x3c, 0x83, 0xb2,
		0x6b, 0xf2, 0xfa, 0x09, 0x67, 0xd1, 0xa3, 0xa3, 0xfb, 0xc7, 0xd1, 0x69, 0xf7, 0xeb, 0x61, 0xc7,
		0x3f, 0x6a, 0xb7, 0x4f, 0x1c, 0x38, 0x93, 0xef, 0xde, 0x71, 0x5c, 0x9f, 0x37, 0xae, 0xed, 0x4e,
		0xeb, 0xcf, 0xd6, 0x71, 0xf3, 0x6b, 0xbb, 0xc3, 0x51, 0x5d, 0x9f, 0x51, 0x6d, 0x76, 0xe9, 0xa8,
		0xeb, 0x16, 0x80, 0xdb, 0xc7, 0x9f, 0x0f, 0x0f, 0x00, 0x47, 0x14, 0xca, 0xa2, 0x73, 0xe6, 0x23,
		0x60, 0x56, 0x20, 0xa8, 0x83, 0xa3, 0x20, 0xd1, 0xee, 0x55, 0x38, 0x90, 0x43, 0x29, 0x06, 0x78,
		0xe2, 0xe0, 0xac, 0x79, 0xd4, 0x06, 0x1f, 0x33, 0x87, 0xda, 0xe0, 0x12, 0x13, 0x8a, 0xda, 0xe0,
		0x52, 0x33, 0x9d, 0xda, 0xe0, 0x0b, 0x0d, 0xa4, 0x36, 0x68, 0x11, 0xf7, 0x05, 0xd6, 0x06, 0xb5,
		0xbc, 0x12, 0x5a, 0xf6, 0x2f, 0x93, 0x7a, 0x15, 0x50, 0x1b, 0xfc, 0x00, 0x64, 0xd2, 0xa9, 0x92,
		0x3a, 0x99, 0x74, 0x99, 0x0a, 0x54, 0x98, 0x88, 0x7e, 0xa8, 0x06, 0x09, 0x52, 0x97, 0x75, 0x02,
		0x75, 0x21, 0xe0, 0xf4, 0x36, 0xbc, 0x54, 0xcf, 0xf9, 0x22, 0x15, 0x1c, 0x22, 0x82, 0x72, 0xc0,
		0x05, 0xf3, 0x52, 0x55, 0x17, 0xd8, 0xbe, 0xcf, 0x71, 0xd0, 0xd7, 0x32, 0x54, 0x07, 0xf2, 0x22,
		0xf3, 0xd6, 0x1d, 0xea, 0x31, 0xbf, 0xe3, 0x12, 0xc1, 0x0d, 0x5d, 0xe2, 0x85, 0x2e, 0x51, 0xf9,
		0x50, 0xad, 0xd6, 0x1b, 0xd5, 0xea, 0x4e, 0x63, 0xaf, 0xb1, 0xb3, 0x5f, 0xab, 0x55, 0xea, 0x48,
		0x4f, 0xb6, 0xac, 0xf3, 0x92, 0x37, 0xb4, 0xe6, 0xb1, 0xd7, 0x39, 0x35, 0x2e, 0x94, 0x28, 0x0a,
		0x53, 0xc8, 0x61, 0x81, 0xd4, 0x63, 0x14, 0x74, 0x00, 0x0d, 0xe0, 0xd4, 0xb5, 0x96, 0x99, 0x4a,
		0xd4, 0xb5, 0x96, 0x9a, 0xe9, 0xd4, 0xb5, 0x5e, 0x68, 0x20, 0x75, 0x2d, 0x8b, 0x72, 0x08, 0x60,
		0x5d, 0x6b, 0x2c, 0x95, 0xde, 0xdb, 0x05, 0x94, 0xb4, 0x1a, 0x94, 0x8c, 0xfe, 0xe5, 0x45, 0xc9,
		0x68, 0x2d, 0xf3, 0x63, 0x4a, 0x46, 0xb6, 0x87, 0xfb, 0x59, 0x97, 0xa0, 0x64, 0xf4, 0x62, 0x97,
		0xa8, 0xee, 0xee, 0x57, 0xf7, 0xeb, 0x8d, 0xdd, 0x7d, 0x0a, 0x45, 0x6b, 0x20, 0xcd, 0x6c, 0x51,
		0x28, 0x02, 0xec, 0x0f, 0x08, 0xa1, 0x08, 0x2b, 0xc1, 0xc7, 0x2a, 0x11, 0x05, 0x1a, 0xb4, 0x29,
		0x13, 0x2d, 0x33, 0x93, 0x28, 0x13, 0x2d, 0x35, 0xd3, 0x29, 0x13, 0xbd, 0xd0, 0x40, 0xca, 0x44,
		0x16, 0xe5, 0x0d, 0xc8, 0x5b, 0x23, 0xa3, 0xeb, 0xaa, 0x0b, 0xe7, 0x83, 0xc5, 0xd6, 0xc8, 0x0f,
		0x58, 0x47, 0x79, 0x68, 0x11, 0x2b, 0x38, 0xb9, 0xc8, 0x79, 0xfb, 0xf6, 0x6c, 0xc7, 0xdd, 0x3f,
		0xff, 0x75, 0x56, 0x71, 0xf7, 0xcf, 0xb3, 0x66, 0x25, 0x7d, 0xcb, 0xda, 0xbb, 0x67, 0x3b, 0x6e,
		0x35, 0x6f, 0xd7, 0xce, 0x76, 0xdc, 0xda, 0xf9, 0xf6, 0xdf, 0x7f, 0xbf, 0xdf, 0xfe, 0xb9, 0x77,
		0xb7, 0xfc, 0x0f, 0xbd, 0xe9, 0xcd, 0xb6, 0x7f, 0xbd, 0x3d, 0xab, 0xb8, 0xbb, 0xe7, 0xf9, 0x87,
		0xbd, 0xb3, 0x1d, 0x77, 0xf7, 0x7c, 0x7b, 0x1b, 0x27, 0x02, 0x9d, 0x23, 0x4d, 0x9d, 0x76, 0xb7,
		0xf5, 0x5f, 0xd8, 0xf9, 0xf3, 0x3f, 0xa4, 0x09, 0xf4, 0x1f, 0x87, 0x19, 0x24, 0x33, 0xc8, 0x85,
		0x39, 0x3a, 0x3d, 0xca, 0x26, 0x1c, 0x6b, 0x81, 0x97, 0x46, 0x3e, 0x34, 0x8e, 0xb9, 0x24, 0x73,
		0x49, 0xe6, 0x92, 0xcc, 0x25, 0x99, 0x4b, 0x32, 0x97, 0xdc, 0xb0, 0x5c, 0xb2, 0x17, 0x86, 0x23,
		0x11, 0x28, 0xc4, 0x3c, 0xb2, 0x42, 0x2a, 0x07, 0x60, 0x81, 0xe9, 0x7a, 0x91, 0x4d, 0xa5, 0x42,
		0x1d, 0x68, 0x09, 0x72, 0x5a, 0xa3, 0x93, 0xf4, 0xbf, 0x89, 0xab, 0x20, 0x9a, 0x1e, 0x11, 0xea,
		0x85, 0x91, 0x50, 0xfd, 0x94, 0x28, 0xb9, 0x4a, 0xe8, 0x1f, 0x61, 0x7c, 0xe9, 0x4a, 0x95, 0xe8,
		0x40, 0xf5, 0x85, 0x37, 0x7f, 0x21, 0x59, 0xb8, 0xe2, 0x45, 0x71, 0xa8, 0xc3, 0x7e, 0x38, 0x4a,
		0x8a, 0x96, 0xd7, 0xbb, 0x88, 0xbc, 0x58, 0xf6, 0xbc, 0x60, 0x28, 0xdd, 0x24, 0x18, 0xca, 0xa4,
		0x68, 0x79, 0xa9, 0xf0, 0x33, 0x56, 0xb2, 0x1f, 0x24, 0xda, 0x53, 0x42, 0x5e, 0x7c, 0xeb, 0x85,
		0x71, 0x52, 0xb4, 0xbc, 0x60, 0xf0, 0x3d, 0x45, 0x02, 0xa9, 0xdc, 0x28, 0x16, 0x5e, 0x4a, 0x6e,
		0x93, 0xec, 0xcd, 0x43, 0x28, 0xc3, 0x9c, 0x75, 0xa0, 0x8e, 0xc7, 0x7d, 0xad, 0xa6, 0xf1, 0xa7,
		0x5d, 0xf4, 0xdf, 0x71, 0xd6, 0x37, 0xad, 0x69, 0xd7, 0xf8, 0x73, 0x9f, 0x93, 0xf9, 0x0b, 0xfe,
		0x49, 0xde, 0x77, 0x45, 0xcb, 0xff, 0x74, 0x11, 0xf9, 0x1d, 0xd9, 0xf3, 0x9b, 0x43, 0xd9, 0x9d,
		0x74, 0x5d, 0xde, 0xf0, 0x5b, 0xd1, 0x75, 0xf5, 0x34, 0xeb, 0x38, 0xff, 0x38, 0xef, 0xb8, 0xa2,
		0xe5, 0x37, 0x07, 0xdf, 0x3b, 0xb2, 0xd7, 0x52, 0x27, 0xb1, 0xf0, 0x3b, 0x69, 0xaf, 0x65, 0x6f,
		0x7e, 0x37, 0xed, 0x35, 0x16, 0x31, 0x2f, 0x7d, 0x96, 0x8c, 0xd5, 0xa5, 0x0a, 0x7f, 0x28, 0x37,
		0xd0, 0x3a, 0x96, 0xbd, 0xc9, 0x88, 0xe0, 0x54, 0x34, 0x7f, 0xc4, 0x36, 0x96, 0x37, 0x67, 0x79,
		0x73, 0x9b, 0x32, 0x44, 0x96, 0x37, 0xb7, 0x3d, 0x13, 0x64, 0x79, 0x73, 0x48, 0xba, 0x0a, 0x53,
		0xde, 0x7c, 0x01, 0xa4, 0xf0, 0x24, 0xd8, 0x45, 0x13, 0xb1, 0x84, 0xd8, 0x0a, 0x85, 0x58, 0x78,
		0x78, 0xc5, 0x86, 0x59, 0x54, 0xb8, 0x85, 0x87, 0x5d, 0x78, 0xf8, 0x85, 0x87, 0x61, 0x1c, 0xfd,
		0x6a, 0x0b, 0x48, 0x88, 0x45, 0x81, 0xe7, 0xc2, 0xa0, 0xb4, 0x18, 0xb7, 0x46, 0x93, 0x87, 0x67,
		0x22, 0xea, 0xbd, 0x89, 0x60, 0xae, 0x87, 0xb9, 0x61, 0x02, 0x0e, 0xae, 0x91, 0x61, 0xdb, 0x0e,
		0xf8, 0x46, 0x87, 0x71, 0x6b, 0xe0, 0xdc, 0x1a, 0x58, 0xb7, 0x06, 0xde, 0xb1, 0x60, 0x1e, 0x0c,
		0xee, 0x8b, 0x51, 0xfc, 0x8a, 0x08, 0xb0, 0x5b, 0xd8, 0xa5, 0xf9, 0x16, 0xb2, 0xe1, 0x06, 0xa0,
		0x6d, 0x0f, 0x4a, 0xf5, 0x65, 0x15, 0xf7, 0xee, 0xc9, 0x0a, 0xb7, 0xd8, 0xa1, 0xbb, 0xa6, 0x93,
		0x3d, 0x93, 0x84, 0x25, 0xbe, 0x28, 0x8f, 0x4c, 0x1f, 0xf5, 0x46, 0x92, 0x5e, 0x92, 0x5e, 0x92,
		0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x22, 0xeb, 0xe3, 0xa3, 0x88, 0xa6, 0x75, 0x15, 0x86, 0xa5, 0x1c,
		0x6d, 0x24, 0x80, 0x4f, 0xa7, 0x99, 0x91, 0xbe, 0x26, 0x96, 0xbe, 0xe3, 0x91, 0x21, 0x6b, 0x44,
		0x0a, 0x6c, 0x20, 0x07, 0x76, 0x91, 0x04, 0x5b, 0xc8, 0x82, 0x75, 0xa4, 0xc1, 0x3a, 0xf2, 0x60,
		0x1d, 0x89, 0xc0, 0x24, 0x13, 0xa0, 0xa4, 0xa2, 0x18, 0x5d, 0x58, 0x45, 0x6d, 0x21, 0x6e, 0x8e,
		0xa5, 0xd2, 0x95, 0x3a, 0x72, 0xcc, 0x9c, 0xa2, 0x78, 0x1d, 0xd8, 0x44, 0xcc, 0x43, 0x17, 0xe7,
		0x5f, 0xd8, 0x98, 0xb3, 0x85, 0x7e, 0x28, 0xa3, 0x65, 0xf4, 0x72, 0xc1, 0x5c, 0xf0, 0x43, 0x1b,
		0x17, 0xec, 0xb5, 0xe0, 0xa0, 0x3a, 0x4b, 0xe0, 0x68, 0xd6, 0xc5, 0x82, 0x1b, 0xba, 0xd8, 0x8a,
		0x5d, 0xac, 0x5e, 0xab, 0xed, 0xd5, 0xe8, 0x66, 0x9b, 0xc5, 0x45, 0xf1, 0xad, 0x3b, 0x7f, 0xc3,
		0xfe, 0xb2, 0x34, 0x8c, 0x03, 0xaf, 0x84, 0x5b, 0x48, 0x29, 0x50, 0x57, 0xc4, 0x59, 0x82, 0x2a,
		0xd4, 0x05, 0x5f, 0x73, 0x32, 0x52, 0x17, 0x7c, 0x55, 0xcf, 0xa1, 0x2e, 0xb8, 0x62, 0x83, 0xa9,
		0x0b, 0xae, 0x71, 0x22, 0x66, 0x99, 0x2e, 0xf8, 0xc1, 0x02, 0x59, 0xb0, 0x46, 0x59, 0xf0, 0x85,
		0x2f, 0xca, 0x82, 0xd4, 0x2c, 0x28, 0x0b, 0x6e, 0x20, 0x1a, 0xcd, 0xba, 0x18, 0x65, 0xc1, 0x95,
		0xbb, 0xd8, 0x6e, 0x8d, 0xa2, 0xe0, 0x86, 0x11, 0x51, 0x7c, 0xeb, 0x28, 0x0a, 0x5a, 0x1b, 0xc4,
		0x33, 0xa5, 0xed, 0x7a, 0x1a, 0x5d, 0x6c, 0x50, 0x05, 0x33, 0x5b, 0x29, 0x0b, 0x3e, 0xc7, 0x3c,
		0xca, 0x82, 0xaf, 0x38, 0x1b, 0x29, 0x0b, 0xbe, 0xaa, 0xe7, 0x50, 0x16, 0x5c, 0xb1, 0xc1, 0x94,
		0x05, 0xd7, 0x38, 0x11, 0xb3, 0x48, 0x16, 0xec, 0x49, 0x15, 0xc4, 0xb7, 0x16, 0xe8, 0x82, 0xfb,
		0xc0, 0x26, 0x1e, 0x09, 0x75, 0x91, 0x6e, 0xcc, 0xa5, 0x30, 0xf8, 0x52, 0xd5, 0x82, 0xc2, 0xe0,
		0xca, 0x55, 0x8b, 0x0a, 0x35, 0x8b, 0x0d, 0xc3, 0xa3, 0x59, 0x17, 0xa3, 0x30, 0xb8, 0x72, 0x17,
		0xe3, 0x7a, 0xc1, 0x0d, 0x24, 0xa3, 0xf8, 0xd6, 0x51, 0x1a, 0xb4, 0x36, 0x8c, 0x3b, 0xe2, 0x46,
		0x0b, 0x35, 0x10, 0x03, 0x7c, 0x61, 0xb0, 0xb0, 0x94, 0xb2, 0xe0, 0x73, 0xcc, 0xa3, 0x2c, 0xf8,
		0x8a, 0x73, 0x91, 0xb2, 0xe0, 0xab, 0x7a, 0x0e, 0x65, 0xc1, 0x15, 0x1b, 0x4c, 0x59, 0x70, 0x8d,
		0xd3, 0x30, 0x9b, 0x64, 0x41, 0xb8, 0x3a, 0x69, 0x4f, 0xc1, 0x38, 0x48, 0xdd, 0x34, 0x92, 0xda,
		0xe7, 0x8c, 0x61, 0x18, 0x4d, 0x32, 0xcf, 0x60, 0x84, 0x4f, 0x6a, 0x0b, 0x4b, 0x49, 0x6a, 0x49,
		0x6a, 0x49, 0x6a, 0x49, 0x6a, 0x49, 0x6a, 0x49, 0x6a, 0x49, 0x6a, 0x49, 0x6a, 0x49, 0x6a, 0xe9,
		0x14, 0xb3, 0x63, 0x18, 0x05, 0xb1, 0x96, 0x36, 0x70, 0xda, 0xdc, 0x50, 0x52, 0x5a, 0x52, 0x5a,
		0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x52, 0x5a, 0x3a, 0xc5,
		0xec, 0x18, 0xea, 0x38, 0x50, 0x89, 0xd4, 0xf2, 0xda, 0x82, 0x7d, 0x49, 0x0f, 0x6c, 0x25, 0xb1,
		0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1, 0x25, 0xb1,
		0xa5, 0x45, 0xa0, 0x2e, 0xea, 0x34, 0x95, 0x0a, 0x75, 0xa0, 0x65, 0x88, 0xb9, 0x01, 0xca, 0x49,
		0xfa, 0xdf, 0xc4, 0x55, 0x10, 0x4d, 0x0b, 0x50, 0x7a, 0x61, 0x24, 0x54, 0x3f, 0x25, 0x8a, 0xae,
		0x12, 0xfa, 0x47, 0x18, 0x5f, 0xba, 0x52, 0x25, 0x3a, 0x50, 0x7d, 0xe1, 0xcd, 0x5f, 0x48, 0x16,
		0xae, 0x78, 0x51, 0x1c, 0xea, 0xb0, 0x1f, 0x8e, 0x92, 0xa2, 0xe5, 0xf5, 0x2e, 0x22, 0x2f, 0x96,
		0x3d, 0x2f, 0x18, 0x4a, 0x37, 0x09, 0x86, 0x32, 0x29, 0x5a, 0x9e, 0x8c, 0xae, 0xab, 0xee, 0x58,
		0xc9, 0x7e, 0x90, 0x68, 0x4f, 0x09, 0x79, 0xf1, 0xad, 0x17, 0xc6, 0x49, 0xd1, 0xf2, 0x82, 0xc1,
		0xf7, 0x14, 0xa9, 0xa4, 0x72, 0xa3, 0x58, 0x78, 0x71, 0x38, 0xd6, 0x22, 0xc9, 0xde, 0xbc, 0xb1,
		0xba, 0x54, 0xe1, 0x0f, 0xe5, 0x06, 0x5a, 0xc7, 0xb2, 0x97, 0xfe, 0x61, 0xe1, 0x92, 0x87, 0x58,
		0xfa, 0x30, 0xeb, 0x75, 0x1d, 0x8f, 0xfb, 0x5a, 0x4d, 0x83, 0x62, 0xbb, 0xe8, 0xf4, 0xe3, 0xac,
		0x43, 0x5b, 0xd3, 0xfe, 0xf4, 0xe7, 0x3e, 0x27, 0xf3, 0x17, 0xfc, 0x93, 0xbc, 0xc3, 0x8b, 0x96,
		0xff, 0xe9, 0x22, 0xf2, 0x3b, 0xb2, 0xe7, 0x37, 0x87, 0xb2, 0x3b, 0xe9, 0xef, 0xbc, 0xe1, 0xb7,
		0xa2, 0xeb, 0xea, 0x69, 0xd6, 0xdb, 0xfe, 0x71, 0xde, 0xdb, 0x45, 0xcb, 0x6f, 0x0e, 0xbe, 0x77,
		0x64, 0xaf, 0xa5, 0x4e, 0x62, 0xe1, 0x77, 0xd2, 0xae, 0xce, 0xde, 0xfc, 0xd3, 0xac, 0x5f, 0x9b,
		0x45, 0x4f, 0x2f, 0x5c, 0xf1, 0xbb, 0x69, 0x47, 0xb3, 0x56, 0x29, 0xb0, 0x25, 0x20, 0x81, 0x71,
		0xc2, 0xf5, 0x11, 0x0f, 0x1f, 0x76, 0x8e, 0x64, 0xa2, 0x27, 0x13, 0x1a, 0x2a, 0x4c, 0x3b, 0x5f,
		0xa4, 0x3a, 0x1c, 0x89, 0x09, 0x73, 0x4f, 0xb0, 0x32, 0x77, 0xe7, 0x4b, 0x70, 0xf3, 0xc0, 0xb2,
		0xca, 0x87, 0x6a, 0xb5, 0xde, 0xa8, 0x56, 0x77, 0x1a, 0x7b, 0x8d, 0x9d, 0xfd, 0x5a, 0xad, 0x52,
		0xaf, 0x00, 0x6d, 0x94, 0x73, 0xda, 0xf1, 0x40, 0xc4, 0x62, 0xf0, 0x69, 0x32, 0xf5, 0xd4, 0x78,
		0x34, 0xa2, 0x47, 0xe2, 0x53, 0x94, 0xb5, 0xa6, 0x26, 0x0e, 0x54, 0xfd, 0xea, 0xb5, 0x22, 0x23,
		0x18, 0x34, 0xc4, 0x3c, 0xe8, 0x9b, 0xb5, 0xc0, 0x70, 0x70, 0x43, 0x0b, 0x6a, 0x6b, 0x14, 0xcc,
		0x00, 0x42, 0x97, 0xe5, 0x21, 0xcb, 0x6c, 0x84, 0x32, 0x17, 0x17, 0xcc, 0xdc, 0xd9, 0x50, 0x24,
		0xca, 0x13, 0x9d, 0xec, 0x81, 0xc6, 0xd6, 0xc4, 0xf3, 0x5d, 0x69, 0x6a, 0xf3, 0x34, 0x46, 0x76,
		0x83, 0x93, 0xcd, 0x40, 0x67, 0x2f, 0x18, 0xd9, 0x8a, 0x29, 0xb7, 0x01, 0x01, 0x6e, 0x5b, 0x01,
		0xdb, 0x20, 0x3a, 0x5b, 0x85, 0xca, 0x66, 0x30, 0xb8, 0x7c, 0x04, 0x2c, 0xf7, 0x8e, 0x25, 0x07,
		0x0d, 0xd3, 0xc1, 0xc2, 0xbe, 0x20, 0x61, 0x20, 0x3c, 0x58, 0x12, 0x16, 0xca, 0x0d, 0x08, 0xe5,
		0xb9, 0x65, 0x89, 0x2e, 0xe9, 0x64, 0xcf, 0xdb, 0xca, 0xf6, 0xc4, 0x62, 0x71, 0x81, 0x89, 0xc7,
		0x7d, 0xc5, 0x72, 0x81, 0x92, 0x6f, 0x5b, 0xac, 0xe6, 0xdb, 0x2d, 0xf9, 0xc6, 0x06, 0x57, 0xe9,
		0x61, 0xac, 0xbe, 0x33, 0xbd, 0xaa, 0x0e, 0x66, 0xb5, 0x1c, 0xcc, 0x2a, 0x38, 0x98, 0xd5, 0x6d,
		0x24, 0x5b, 0x24, 0x5b, 0x29, 0xd9, 0x32, 0xb5, 0xf0, 0x04, 0x9e, 0x6b, 0x19, 0x58, 0x28, 0x52,
		0x22, 0xd5, 0x7a, 0xb3, 0x46, 0x6e, 0x6f, 0xca, 0xdd, 0x2d, 0x72, 0x73, 0xa7, 0x54, 0x6a, 0x0d,
		0xed, 0xd8, 0xe5, 0xb8, 0xf4, 0xea, 0x1d, 0xac, 0x04, 0xe7, 0x72, 0xf2, 0x49, 0x14, 0x8e, 0xb5,
		0x1b, 0x85, 0x89, 0x2e, 0xcd, 0xbd, 0xee, 0x6b, 0x3c, 0xcd, 0x5b, 0x50, 0x52, 0x48, 0x29, 0x37,
		0x57, 0x2a, 0x7d, 0xc7, 0x93, 0x89, 0xdc, 0xc8, 0x6c, 0x4e, 0x64, 0x2a, 0x17, 0x32, 0x9e, 0x03,
		0x19, 0xcf, 0x7d, 0x8c, 0xe7, 0x3c, 0xeb, 0x45, 0x76, 0x0e, 0x64, 0xb9, 0x8f, 0x46, 0x9d, 0xa9,
		0x1c, 0x6b, 0x4c, 0x2b, 0x33, 0x22, 0x07, 0x53, 0x2c, 0xa3, 0x58, 0x46, 0xb1, 0x8c, 0x62, 0xd9,
		0x06, 0x88, 0x65, 0x65, 0x03, 0xca, 0x2c, 0xb0, 0x98, 0xf3, 0xb7, 0x19, 0x7c, 0x31, 0xe5, 0x6b,
		0x66, 0x60, 0xc6, 0x58, 0xde, 0x81, 0x04, 0x3b, 0x58, 0xf0, 0x83, 0x02, 0x43, 0x70, 0x70, 0x04,
		0x07, 0x4b, 0x70, 0xf0, 0x64, 0x06, 0xa6, 0x0c, 0xc1, 0x95, 0x71, 0xd8, 0x2a, 0x0c, 0xc8, 0xd7,
		0xc9, 0x1a, 0xf7, 0xd4, 0xfb, 0xd3, 0x34, 0x4d, 0x2e, 0xdc, 0x9d, 0x87, 0x34, 0xc3, 0x3b, 0x00,
		0x61, 0x0e, 0x11, 0x42, 0x3a, 0x2c, 0x08, 0xf3, 0x50, 0x20, 0xb4, 0xc3, 0x7f, 0x60, 0x0f, 0xf9,
		0x81, 0x3d, 0xcc, 0x07, 0xf6, 0xd0, 0x9e, 0xcd, 0xde, 0x59, 0x06, 0x73, 0xd8, 0x4e, 0x11, 0x77,
		0x46, 0x22, 0x18, 0xc6, 0x62, 0x88, 0x10, 0x74, 0xf2, 0xcc, 0xab, 0x01, 0x60, 0xcb, 0xc9, 0xf4,
		0x11, 0xf2, 0xfb, 0xf7, 0xd9, 0x7a, 0x0c, 0x2f, 0x87, 0xf2, 0x4d, 0xdd, 0x7e, 0x65, 0x30, 0xff,
		0x8a, 0x30, 0xe0, 0xfa, 0x9e, 0xd5, 0x41, 0x24, 0x5f, 0x24, 0x75, 0x24, 0x75, 0x24, 0x75, 0x24,
		0x75, 0x24, 0x75, 0x24, 0x75, 0x24, 0x75, 0xcf, 0x24, 0x75, 0x59, 0xd8, 0x21, 0xa7, 0x2b, 0x7d,
		0x28, 0xcc, 0xec, 0xf6, 0x79, 0xd2, 0x61, 0x10, 0x0e, 0xfb, 0x33, 0xfc, 0xe4, 0x89, 0x8c, 0x8e,
		0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0x8e, 0x8c, 0xce, 0xfc, 0x93, 0xac, 0xc2, 0x90, 0xf4, 0xa4, 0x4b,
		0xa9, 0x06, 0x02, 0xa7, 0xb4, 0xc1, 0xfd, 0x42, 0xf0, 0x7b, 0xdb, 0x50, 0x8e, 0x07, 0x85, 0x2a,
		0xa2, 0x01, 0x57, 0x34, 0x03, 0xb1, 0x48, 0x06, 0x76, 0x51, 0x0c, 0xd4, 0x22, 0x18, 0xf0, 0x45,
		0x2f, 0xe0, 0x8b, 0x5c, 0xc0, 0x17, 0xb5, 0xe0, 0xc1, 0xcf, 0x90, 0x12, 0x0b, 0xb0, 0xd4, 0x82,
		0x28, 0xb9, 0x3c, 0x26, 0xbd, 0xfc, 0xc3, 0x7f, 0x29, 0xa5, 0x48, 0x84, 0x4e, 0x8a, 0xd6, 0x54,
		0xa8, 0xc9, 0x68, 0x06, 0x0f, 0x67, 0x45, 0x71, 0x4a, 0xa7, 0x1f, 0x5e, 0x5d, 0x8d, 0x95, 0xd4,
		0xb7, 0xa8, 0xec, 0x74, 0xde, 0x40, 0x52, 0x54, 0x52, 0x54, 0x52, 0x54, 0x52, 0x54, 0x52, 0x54,
		0x52, 0x54, 0x52, 0x54, 0x52, 0xd4, 0xe7, 0x52, 0xd4, 0x9c, 0x57, 0x48, 0x91, 0x14, 0xed, 0x5b,
		0xb2, 0x54, 0x4c, 0x96, 0x2a, 0x6e, 0xb4, 0x0b, 0xcf, 0x54, 0x1f, 0x33, 0x92, 0x6c, 0x95, 0x6c,
		0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0x95, 0x6c, 0xf5, 0xb9, 0x6c, 0xf5,
		0x21, 0xb7, 0x98, 0x30, 0xd6, 0x19, 0xae, 0x41, 0xd6, 0x8a, 0xc9, 0x5a, 0xa5, 0xba, 0x0e, 0x46,
		0x72, 0xe0, 0xc6, 0x22, 0x48, 0x80, 0xea, 0xea, 0x15, 0x1e, 0x3a, 0x67, 0x1f, 0xb9, 0x2a, 0xb9,
		0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0xea, 0x86, 0x71, 0x55, 0x39, 0x10, 0x4a, 0x4b,
		0x7d, 0x0b, 0xca, 0x57, 0x91, 0xaa, 0x28, 0xb7, 0xa6, 0x5d, 0xf5, 0x29, 0x48, 0x00, 0x43, 0x6a,
		0x3e, 0xa0, 0xad, 0xe3, 0xbf, 0x9a, 0x47, 0xad, 0x03, 0xbf, 0xd3, 0x3e, 0xfd, 0x7a, 0xe8, 0x77,
		0x0e, 0x9b, 0xdd, 0xf6, 0x31, 0x5a, 0x74, 0xfd, 0x2b, 0x18, 0x8d, 0xd3, 0xd3, 0x1f, 0xcf, 0xa0,
		0xec, 0x9a, 0xbc, 0x7e, 0xc2, 0x59, 0xf4, 0xe8, 0xe8, 0xfe, 0x71, 0x74, 0xda, 0xfd, 0x7a, 0xd8,
		0xf1, 0x8f, 0xda, 0xed, 0x13, 0x07, 0xce, 0xe4, 0xbb, 0x77, 0x1c, 0xd7, 0xe7, 0x8d, 0x6b, 0xbb,
		0xd3, 0xfa, 0xb3, 0x75, 0xdc, 0xfc, 0xda, 0xee, 0x70, 0x54, 0xd7, 0x67, 0x54, 0x9b, 0x5d, 0x3a,
		0xea, 0xba, 0x05, 0xe0, 0xf6, 0xf1, 0xe7, 0xc3, 0x03, 0xc0, 0x11, 0x85, 0xb2, 0xe8, 0x9c, 0xf9,
		0x08, 0x98, 0x15, 0x08, 0xea, 0xe0, 0x28, 0x48, 0xb4, 0x7b, 0x15, 0x0e, 0xe4, 0x50, 0x8a, 0x01,
		0x9e, 0x38, 0x38, 0x6b, 0x1e, 0xb5, 0xc1, 0xc7, 0xcc, 0xa1, 0x36, 0xb8, 0xc4, 0x84, 0xa2, 0x36,
		0xb8, 0xd4, 0x4c, 0xa7, 0x36, 0xf8, 0x42, 0x03, 0xa9, 0x0d, 0x5a, 0xc4, 0x7d, 0x81, 0xb5, 0x41,
		0x2d, 0xaf, 0x84, 0x96, 0xfd, 0xcb, 0xa4, 0x5e, 0x05, 0xd4, 0x06, 0x3f, 0x00, 0x99, 0x74, 0xaa,
		0xa4, 0x4e, 0x26, 0x5d, 0xa6, 0x02, 0x15, 0x26, 0xa2, 0x1f, 0xaa, 0x41, 0x82, 0xd4, 0x65, 0x9d,
		0x40, 0x5d, 0x08, 0x38, 0xbd, 0x0d, 0x2f, 0xd5, 0x73, 0xbe, 0x48, 0x05, 0x87, 0x88, 0xa0, 0x1c,
		0x70, 0xc1, 0xbc, 0x54, 0xd5, 0x05, 0xb6, 0xef, 0x73, 0x1c, 0xf4, 0xb5, 0x0c, 0xd5, 0x81, 0xbc,
		0xc8, 0xbc, 0x75, 0x87, 0x7a, 0xcc, 0xef, 0xb8, 0x44, 0x70, 0x43, 0x97, 0x78, 0xa1, 0x4b, 0x54,
		0x3e, 0x54, 0xab, 0xf5, 0x46, 0xb5, 0xba, 0xd3, 0xd8, 0x6b, 0xec, 0xec, 0xd7, 0x6a, 0x95, 0x3a,
		0xd2, 0x93, 0x2d, 0xeb, 0xbc, 0xe4, 0x0d, 0xad, 0x79, 0xec, 0x75, 0x4e, 0x8d, 0x0b, 0x25, 0x8a,
		0xc2, 0x14, 0x72, 0x58, 0x20, 0xf5, 0x18, 0x05, 0x1d, 0x40, 0x03, 0x38, 0x75, 0xad, 0x65, 0xa6,
		0x12, 0x75, 0xad, 0xa5, 0x66, 0x3a, 0x75, 0xad, 0x17, 0x1a, 0x48, 0x5d, 0xcb, 0xa2, 0x1c, 0x02,
		0x58, 0xd7, 0x1a, 0x4b, 0xa5, 0xf7, 0x76, 0x01, 0x25, 0xad, 0x06, 0x25, 0xa3, 0x7f, 0x79, 0x51,
		0x32, 0x5a, 0xcb, 0xfc, 0x98, 0x92, 0x91, 0xed, 0xe1, 0x7e, 0xd6, 0x25, 0x28, 0x19, 0xbd, 0xd8,
		0x25, 0xaa, 0xbb, 0xfb, 0xd5, 0xfd, 0x7a, 0x63, 0x77, 0x9f, 0x42, 0xd1, 0x1a, 0x48, 0x33, 0x5b,
		0x14, 0x8a, 0x00, 0xfb, 0x03, 0x42, 0x28, 0xc2, 0x4a, 0xf0, 0xb1, 0x4a, 0x44, 0x81, 0x06, 0x6d,
		0xca, 0x44, 0xcb, 0xcc, 0x24, 0xca, 0x44, 0x4b, 0xcd, 0x74, 0xca, 0x44, 0x2f, 0x34, 0x90, 0x32,
		0x91, 0x45, 0x79, 0x03, 0xf2, 0xd6, 0xc8, 0xe8, 0xba, 0xea, 0xc2, 0xf9, 0x60, 0xb1, 0x35, 0xf2,
		0x03, 0xd6, 0x51, 0x1e, 0x5a, 0xc4, 0x0a, 0x4e, 0x2e, 0x72, 0xde, 0xbe, 0x3d, 0xdb, 0x71, 0xf7,
		0xcf, 0x7f, 0x9d, 0x55, 0xdc, 0xfd, 0xf3, 0xac, 0x59, 0x49, 0xdf, 0xb2, 0xf6, 0xee, 0xd9, 0x8e,
		0x5b, 0xcd, 0xdb, 0xb5, 0xb3, 0x1d, 0xb7, 0x76, 0xbe, 0xfd, 0xf7, 0xdf, 0xef, 0xb7, 0x7f, 0xee,
		0xdd, 0x2d, 0xff, 0x43, 0x6f, 0x7a, 0xb3, 0xed, 0x5f, 0x6f, 0xcf, 0x2a, 0xee, 0xee, 0x79, 0xfe,
		0x61, 0xef, 0x6c, 0xc7, 0xdd, 0x3d, 0xdf, 0xde, 0xc6, 0x89, 0x40, 0xe7, 0x48, 0x53, 0xa7, 0xdd,
		0x6d, 0xfd, 0x17, 0x76, 0xfe, 0xfc, 0x0f, 0x69, 0x02, 0xfd, 0xc7, 0x61, 0x06, 0xc9, 0x0c, 0x72,
		0x61, 0x8e, 0x4e, 0x8f, 0xb2, 0x09, 0xc7, 0x5a, 0xe0, 0xa5, 0x91, 0x0f, 0x8d, 0x63, 0x2e, 0xc9,
		0x5c, 0x92, 0xb9, 0x24, 0x73, 0x49, 0xe6, 0x92, 0xcc, 0x25, 0x37, 0x2c, 0x97, 0xec, 0x85, 0xe1,
		0x48, 0x04, 0x0a, 0x31, 0x8f, 0xac, 0x90, 0xca, 0x01, 0x58, 0x60, 0xba, 0x5e, 0x64, 0x53, 0xa9,
		0x50, 0x07, 0x5a, 0x82, 0x9c, 0xd6, 0xe8, 0x24, 0xfd, 0x6f, 0xe2, 0x2a, 0x88, 0xa6, 0x47, 0x84,
		0x7a, 0x61, 0x24, 0x54, 0x3f, 0x25, 0x4a, 0xae, 0x12, 0xfa, 0x47, 0x18, 0x5f, 0xba, 0x52, 0x25,
		0x3a, 0x50, 0x7d, 0xe1, 0xcd, 0x5f, 0x48, 0x16, 0xae, 0x78, 0x51, 0x1c, 0xea, 0xb0, 0x1f, 0x8e,
		0x92, 0xa2, 0xe5, 0xf5, 0x2e, 0x22, 0x2f, 0x96, 0x3d, 0x2f, 0x18, 0x4a, 0x37, 0x09, 0x86, 0x32,
		0x29, 0x5a, 0x5e, 0x2a, 0xfc, 0x8c, 0x95, 0xec, 0x07, 0x89, 0xf6, 0x94, 0x90, 0x17, 0xdf, 0x7a,
		0x61, 0x9c, 0x14, 0x2d, 0x2f, 0x18, 0x7c, 0x4f, 0x91, 0x20, 0x1c, 0x6b, 0x37, 0x0a, 0x13, 0xed,
		0xa5, 0xf4, 0x36, 0xc9, 0xde, 0x3c, 0x84, 0x42, 0xcc, 0x59, 0x17, 0xea, 0x78, 0xdc, 0xd7, 0x6a,
		0x1a, 0x81, 0xda, 0x45, 0x0f, 0x1e, 0x67, 0xbd, 0xd3, 0x9a, 0x76, 0x8e, 0x3f, 0xf7, 0x39, 0x99,
		0xbf, 0xe0, 0x9f, 0xe4, 0xbd, 0x57, 0xb4, 0xfc, 0x4f, 0x17, 0x91, 0xdf, 0x91, 0x3d, 0xbf, 0x39,
		0x94, 0xdd, 0x49, 0xe7, 0xe5, 0x0d, 0xbf, 0x15, 0x5d, 0x57, 0x4f, 0xb3, 0xae, 0xf3, 0x8f, 0xf3,
		0xae, 0x2b, 0x5a, 0x7e, 0x73, 0xf0, 0xbd, 0x23, 0x7b, 0xed, 0xb1, 0x3e, 0x09, 0x13, 0xed, 0x77,
		0xd2, 0x7e, 0xcb, 0xde, 0xfc, 0x6e, 0xda, 0x6f, 0x2c, 0x64, 0x5e, 0xfa, 0x3c, 0x19, 0xab, 0x4b,
		0x15, 0xfe, 0x50, 0x6e, 0xa0, 0x75, 0x2c, 0x7b, 0x93, 0x11, 0xc1, 0xa9, 0x6a, 0xfe, 0x88, 0x6d,
		0x2c, 0x71, 0xce, 0x12, 0xe7, 0x36, 0x65, 0x89, 0x2c, 0x71, 0x6e, 0x7b, 0x36, 0xc8, 0x12, 0xe7,
		0x90, 0x94, 0x15, 0xa6, 0xc4, 0xf9, 0x02, 0x48, 0xe1, 0xc9, 0xb0, 0x8b, 0x26, 0x62, 0x89, 0xb1,
		0x15, 0x8a, 0xb1, 0xf0, 0xf0, 0x8a, 0x0d, 0xb3, 0xa8, 0x70, 0x0b, 0x0f, 0xbb, 0xf0, 0xf0, 0x0b,
		0x0f, 0xc3, 0x38, 0x1a, 0xd6, 0x16, 0x90, 0x18, 0x8b, 0x02, 0xcf, 0x85, 0x41, 0x69, 0x41, 0x6e,
		0x8d, 0x26, 0x11, 0xcf, 0x44, 0xd4, 0x7b, 0x13, 0xc1, 0x5c, 0x0f, 0x73, 0xd3, 0x04, 0x1c, 0x5c,
		0x23, 0xc3, 0xb6, 0x1d, 0xf0, 0x8d, 0x0e, 0xe3, 0xd6, 0xc0, 0xb9, 0x35, 0xb0, 0x6e, 0x0d, 0xbc,
		0x63, 0xc1, 0x3c, 0x18, 0xdc, 0x17, 0xa3, 0xf8, 0x15, 0x11, 0x60, 0xb7, 0xb0, 0xcb, 0xf3, 0x2d,
		0x64, 0xc3, 0x0d, 0x40, 0xdb, 0x1e, 0x94, 0xeb, 0xcb, 0xaa, 0xee, 0xdd, 0x93, 0x15, 0x6e, 0xb3,
		0x43, 0x77, 0x4d, 0x27, 0x7b, 0x2a, 0x09, 0x4b, 0x7c, 0x51, 0x1e, 0x9a, 0x3e, 0xea, 0x8d, 0x24,
		0xbd, 0x24, 0xbd, 0x24, 0xbd, 0x24, 0xbd, 0x24, 0xbd, 0x44, 0xd6, 0xc7, 0x47, 0x11, 0x4d, 0xeb,
		0x2a, 0x0c, 0x4b, 0x39, 0xda, 0x48, 0x00, 0x9f, 0x50, 0x33, 0x23, 0x7d, 0x4d, 0x2c, 0x7d, 0xc7,
		0x63, 0x43, 0xd6, 0x88, 0x14, 0xd8, 0x40, 0x0e, 0xec, 0x22, 0x09, 0xb6, 0x90, 0x05, 0xeb, 0x48,
		0x83, 0x75, 0xe4, 0xc1, 0x3a, 0x12, 0x81, 0x49, 0x26, 0x40, 0x49, 0x45, 0x31, 0xba, 0xb0, 0x8a,
		0xda, 0x42, 0xdc, 0x1c, 0x4b, 0xa5, 0x2b, 0x75, 0xe4, 0x98, 0x39, 0x45, 0xf1, 0x3a, 0xb0, 0x89,
		0x98, 0x07, 0x2f, 0xce, 0xbf, 0xb0, 0x31, 0x67, 0x0b, 0xfd, 0x60, 0x46, 0xcb, 0xe8, 0xe5, 0x82,
		0xb9, 0xe0, 0x07, 0x37, 0x2e, 0xd8, 0x6b, 0xc1, 0x61, 0x75, 0x96, 0xc0, 0xd1, 0xac, 0x8b, 0x05,
		0x37, 0x74, 0xb1, 0x15, 0xbb, 0x58, 0xbd, 0x56, 0xdb, 0xab, 0xd1, 0xcd, 0x36, 0x8b, 0x8b, 0xe2,
		0x5b, 0x77, 0xfe, 0x86, 0xfd, 0x65, 0x69, 0x18, 0x07, 0x5e, 0x09, 0xb7, 0x90, 0x52, 0xa0, 0xae,
		0x88, 0xb3, 0x04, 0x55, 0xa8, 0x0b, 0xbe, 0xe6, 0x64, 0xa4, 0x2e, 0xf8, 0xaa, 0x9e, 0x43, 0x5d,
		0x70, 0xc5, 0x06, 0x53, 0x17, 0x5c, 0xe3, 0x44, 0xcc, 0x32, 0x5d, 0xf0, 0x83, 0x05, 0xb2, 0x60,
		0x8d, 0xb2, 0xe0, 0x0b, 0x5f, 0x94, 0x05, 0xa9, 0x59, 0x50, 0x16, 0xdc, 0x40, 0x34, 0x9a, 0x75,
		0x31, 0xca, 0x82, 0x2b, 0x77, 0xb1, 0xdd, 0x1a, 0x45, 0xc1, 0x0d, 0x23, 0xa2, 0xf8, 0xd6, 0x51,
		0x14, 0xb4, 0x36, 0x88, 0x67, 0x4a, 0xdb, 0xf5, 0x34, 0xba, 0xd8, 0xa0, 0x0a, 0x66, 0xb6, 0x52,
		0x16, 0x7c, 0x8e, 0x79, 0x94, 0x05, 0x5f, 0x71, 0x36, 0x52, 0x16, 0x7c, 0x55, 0xcf, 0xa1, 0x2c,
		0xb8, 0x62, 0x83, 0x29, 0x0b, 0xae, 0x71, 0x22, 0x66, 0x91, 0x2c, 0xd8, 0x93, 0x2a, 0x88, 0x6f,
		0x2d, 0xd0, 0x05, 0xf7, 0x81, 0x4d, 0x3c, 0x12, 0xea, 0x22, 0xdd, 0x98, 0x4b, 0x61, 0xf0, 0xa5,
		0xaa, 0x05, 0x85, 0xc1, 0x95, 0xab, 0x16, 0x15, 0x6a, 0x16, 0x1b, 0x86, 0x47, 0xb3, 0x2e, 0x46,
		0x61, 0x70, 0xe5, 0x2e, 0xc6, 0xf5, 0x82, 0x1b, 0x48, 0x46, 0xf1, 0xad, 0xa3, 0x34, 0x68, 0x6d,
		0x18, 0x77, 0xc4, 0x8d, 0x16, 0x6a, 0x20, 0x06, 0xf8, 0xc2, 0x60, 0x61, 0x29, 0x65, 0xc1, 0xe7,
		0x98, 0x47, 0x59, 0xf0, 0x15, 0xe7, 0x22, 0x65, 0xc1, 0x57, 0xf5, 0x1c, 0xca, 0x82, 0x2b, 0x36,
		0x98, 0xb2, 0xe0, 0x1a, 0xa7, 0x61, 0x36, 0xc9, 0x82, 0x70, 0xb5, 0xd2, 0x9e, 0x82, 0x71, 0x90,
		0xda, 0x69, 0x24, 0xb5, 0xcf, 0x19, 0xc3, 0x30, 0x9a, 0x64, 0x9e, 0xc1, 0x08, 0x9f, 0xd4, 0x16,
		0x96, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92, 0xd4, 0x92,
		0xd4, 0x92, 0xd4, 0xd2, 0x29, 0x66, 0xc7, 0x30, 0x0a, 0x62, 0x2d, 0x6d, 0xe0, 0xb4, 0xb9, 0xa1,
		0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4, 0xa4, 0xb4,
		0xa4, 0xb4, 0x74, 0x8a, 0xd9, 0x31, 0xd4, 0x71, 0xa0, 0x12, 0xa9, 0xe5, 0xb5, 0x05, 0xfb, 0x92,
		0x1e, 0xd8, 0x4a, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x62,
		0x4b, 0x62, 0x4b, 0x62, 0x4b, 0x8b, 0x40, 0x5d, 0xd4, 0x69, 0x2a, 0x15, 0xea, 0x40, 0xcb, 0x10,
		0x73, 0x03, 0x94, 0x93, 0xf4, 0xbf, 0x89, 0xab, 0x20, 0x9a, 0x16, 0xa0, 0xf4, 0xc2, 0x48, 0xa8,
		0x7e, 0x4a, 0x14, 0x5d, 0x25, 0xf4, 0x8f, 0x30, 0xbe, 0x74, 0xa5, 0x4a, 0x74, 0xa0, 0xfa, 0xc2,
		0x9b, 0xbf, 0x90, 0x2c, 0x5c, 0xf1, 0xa2, 0x38, 0xd4, 0x61, 0x3f, 0x1c, 0x25, 0x45, 0xcb, 0xeb,
		0x5d, 0x44, 0x5e, 0x2c, 0x7b, 0x5e, 0x30, 0x94, 0x6e, 0x12, 0x0c, 0x65, 0x52, 0xb4, 0x3c, 0x19,
		0x5d, 0x57, 0xdd, 0xb1, 0x92, 0xfd, 0x20, 0xd1, 0x9e, 0x12, 0xf2, 0xe2, 0x5b, 0x2f, 0x8c, 0x93,
		0xa2, 0xe5, 0x05, 0x83, 0xef, 0x29, 0x52, 0x85, 0x63, 0xed, 0x46, 0x61, 0xa2, 0xbd, 0x38, 0x1c,
		0x6b, 0x91, 0x64, 0x6f, 0xde, 0x58, 0x5d, 0xaa, 0xf0, 0x87, 0x72, 0x03, 0xad, 0x63, 0xd9, 0x4b,
		0xff, 0xb0, 0x70, 0xc9, 0x43, 0x2c, 0x7e, 0x98, 0xf5, 0xbb, 0x8e, 0xc7, 0x7d, 0xad, 0xa6, 0x61,
		0xb1, 0x5d, 0x74, 0xfb, 0x71, 0xd6, 0xa5, 0xad, 0x69, 0x8f, 0xfa, 0x73, 0x9f, 0x93, 0xf9, 0x0b,
		0xfe, 0x49, 0xde, 0xe5, 0x45, 0xcb, 0xff, 0x74, 0x11, 0xf9, 0x1d, 0xd9, 0xf3, 0x9b, 0x43, 0xd9,
		0x9d, 0xf4, 0x78, 0xde, 0xf0, 0x5b, 0xd1, 0x75, 0xf5, 0x34, 0xeb, 0x6f, 0xff, 0x38, 0xef, 0xef,
		0xa2, 0xe5, 0x37, 0x07, 0xdf, 0x3b, 0xb2, 0xd7, 0x1e, 0xeb, 0x93, 0x30, 0xd1, 0x7e, 0x27, 0xed,
		0xec, 0xec, 0xcd, 0x3f, 0xcd, 0x7a, 0xb6, 0x59, 0xf4, 0xf5, 0xc2, 0x15, 0xbf, 0x9b, 0x76, 0x35,
		0xeb, 0x95, 0x02, 0x5b, 0x02, 0x12, 0x1c, 0x27, 0x7c, 0x1f, 0xf1, 0x00, 0x62, 0xe7, 0x48, 0x26,
		0x7a, 0x32, 0xa1, 0xa1, 0x42, 0xb5, 0xf3, 0x45, 0xaa, 0xc3, 0x91, 0x98, 0xb0, 0xf7, 0x04, 0x2b,
		0x7b, 0x77, 0xbe, 0x04, 0x37, 0x0f, 0x2c, 0xab, 0x7c, 0xa8, 0x56, 0xeb, 0x8d, 0x6a, 0x75, 0xa7,
		0xb1, 0xd7, 0xd8, 0xd9, 0xaf, 0xd5, 0x2a, 0xf5, 0x0a, 0xd0, 0x66, 0x39, 0xa7, 0x1d, 0x0f, 0x44,
		0x2c, 0x06, 0x9f, 0x26, 0x53, 0x4f, 0x8d, 0x47, 0x23, 0x7a, 0x24, 0x3e, 0x4d, 0x59, 0x73, 0x7a,
		0xe2, 0x40, 0x55, 0xb1, 0x5e, 0x33, 0x42, 0x82, 0x41, 0x45, 0xcc, 0x03, 0xbf, 0x59, 0x0b, 0x0c,
		0x07, 0x38, 0xb4, 0xc0, 0xb6, 0x56, 0x01, 0x0d, 0x20, 0x7c, 0x59, 0x1f, 0xb6, 0xcc, 0x46, 0x29,
		0x73, 0xb1, 0xc1, 0xcc, 0x9d, 0x0d, 0x45, 0xa3, 0x3c, 0xe1, 0xc9, 0x1e, 0x6e, 0x6c, 0x4d, 0xbc,
		0xdf, 0x95, 0xa6, 0x36, 0x52, 0x63, 0x64, 0x39, 0x38, 0x59, 0x0d, 0x74, 0x16, 0x83, 0x91, 0xb5,
		0x98, 0x72, 0x1b, 0x10, 0xf0, 0xb6, 0x17, 0xb4, 0x0d, 0x22, 0xb4, 0x65, 0xc8, 0x6c, 0x06, 0x87,
		0xcb, 0x47, 0xc1, 0x72, 0xef, 0x58, 0x72, 0xe0, 0x30, 0x1d, 0x30, 0x6c, 0x0c, 0x14, 0x06, 0x42,
		0x84, 0x35, 0xa1, 0xa1, 0xdc, 0xa0, 0x50, 0x9e, 0x6b, 0x96, 0xe8, 0x96, 0x4e, 0xf6, 0x04, 0xae,
		0x6c, 0x6f, 0x2c, 0x16, 0x1c, 0x98, 0x78, 0x00, 0x58, 0x2c, 0x21, 0x28, 0xf9, 0xb6, 0xc5, 0x0a,
		0xbf, 0xdd, 0x92, 0x6f, 0x6c, 0x70, 0xe5, 0x1e, 0xc6, 0x8a, 0x3c, 0xd3, 0x2b, 0xed, 0x60, 0x56,
		0xd0, 0xc1, 0xac, 0x8c, 0x83, 0x59, 0xf1, 0x46, 0xc2, 0x45, 0xc2, 0x35, 0x25, 0x5c, 0xa6, 0x16,
		0xa3, 0x58, 0xc0, 0xb7, 0x0c, 0x2c, 0x1e, 0x29, 0x91, 0x6e, 0xbd, 0x59, 0x23, 0xd7, 0x37, 0xe5,
		0xf2, 0x56, 0xb9, 0xba, 0x53, 0x2a, 0xc1, 0x06, 0x77, 0xee, 0x72, 0xdc, 0x7a, 0xf5, 0x4e, 0x56,
		0x82, 0x83, 0x39, 0x33, 0x13, 0x29, 0x2e, 0x8f, 0x50, 0xde, 0x97, 0x7f, 0x9a, 0x33, 0xa0, 0xa4,
		0xa0, 0x52, 0x6e, 0xc6, 0x54, 0xfa, 0x5e, 0x28, 0x13, 0x19, 0x92, 0xd9, 0xcc, 0xc8, 0x54, 0x46,
		0x64, 0x3c, 0x13, 0x32, 0x9e, 0x01, 0x19, 0xcf, 0x7c, 0xd6, 0x8b, 0xee, 0x1c, 0xc8, 0x72, 0x1f,
		0x94, 0x3a, 0x53, 0x59, 0xd6, 0x98, 0x62, 0x66, 0x44, 0x16, 0xa6, 0x64, 0x46, 0xc9, 0x8c, 0x92,
		0x19, 0x25, 0xb3, 0x0d, 0x90, 0xcc, 0xca, 0x06, 0x94, 0x59, 0x60, 0x31, 0xe7, 0x6f, 0x33, 0xf8,
		0x62, 0xca, 0xd7, 0xcc, 0xc0, 0x8c, 0xb1, 0xbc, 0x03, 0x09, 0x76, 0xb0, 0xe0, 0x07, 0x05, 0x86,
		0xe0, 0xe0, 0x08, 0x0e, 0x96, 0xe0, 0xe0, 0xc9, 0x0c, 0x4c, 0x19, 0x82, 0x2b, 0xe3, 0xb0, 0x55,
		0x18, 0x90, 0xaf, 0x9a, 0x35, 0xee, 0xa9, 0xf7, 0xe7, 0x6c, 0x9a, 0x5c, 0xc6, 0x3b, 0x0f, 0x69,
		0x86, 0xf7, 0x05, 0xc2, 0x1c, 0x2f, 0x84, 0x74, 0x8c, 0x10, 0xe6, 0x71, 0x41, 0x68, 0xc7, 0x02,
		0xc1, 0x1e, 0xff, 0x03, 0x7b, 0xcc, 0x0f, 0xec, 0x71, 0x3e, 0x9b, 0xbd, 0xd7, 0x0c, 0xe6, 0x18,
		0x9e, 0x22, 0xee, 0x8c, 0x44, 0x30, 0x8c, 0xc5, 0x10, 0x21, 0xe8, 0xe4, 0x99, 0x57, 0x03, 0xc0,
		0x96, 0x93, 0xe9, 0x43, 0xe4, 0xf7, 0xef, 0xb3, 0x35, 0x19, 0x5e, 0x0e, 0xe5, 0x9b, 0xba, 0x19,
		0xcb, 0x60, 0xfe, 0x15, 0x61, 0xc0, 0xf5, 0x3d, 0xab, 0x83, 0x48, 0xbe, 0x48, 0xea, 0x48, 0xea,
		0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x48, 0xea, 0x9e, 0x49, 0xea, 0xb2, 0xb0, 0x43,
		0x4e, 0x57, 0xfa, 0x50, 0x98, 0xd9, 0xf3, 0xf3, 0xa4, 0xc3, 0x20, 0x1c, 0x02, 0x68, 0xf8, 0xc9,
		0x13, 0x19, 0x1d, 0x19, 0x1d, 0x19, 0x1d, 0x19, 0x1d, 0x19, 0x9d, 0xf9, 0x27, 0x59, 0x85, 0x21,
		0xe9, 0xf9, 0x97, 0x52, 0x0d, 0x04, 0x4e, 0xd1, 0x83, 0xfb, 0x75, 0xe0, 0xf7, 0xb6, 0xa1, 0x1c,
		0x1a, 0x0a, 0x55, 0x5e, 0x03, 0xae, 0x9c, 0x06, 0x62, 0xf9, 0x0c, 0xec, 0x72, 0x19, 0xa8, 0xe5,
		0x31, 0xe0, 0xcb, 0x61, 0xc0, 0x97, 0xbf, 0x80, 0x2f, 0x77, 0xc1, 0xe3, 0xa0, 0x21, 0x25, 0x16,
		0x60, 0xa9, 0x05, 0x51, 0x72, 0x79, 0x4c, 0x7a, 0xf9, 0x87, 0xff, 0x52, 0x4a, 0x91, 0x08, 0x9d,
		0x14, 0xad, 0xa9, 0x50, 0x93, 0xd1, 0x0c, 0x1e, 0xd7, 0x8a, 0xe2, 0x94, 0x4e, 0x3f, 0xbc, 0xba,
		0x1a, 0x2b, 0xa9, 0x6f, 0x51, 0xd9, 0xe9, 0xbc, 0x81, 0xa4, 0xa8, 0xa4, 0xa8, 0xa4, 0xa8, 0xa4,
		0xa8, 0xa4, 0xa8, 0xa4, 0xa8, 0xa4, 0xa8, 0xa4, 0xa8, 0xcf, 0xa5, 0xa8, 0x39, 0xaf, 0x90, 0x22,
		0x29, 0xda, 0xb7, 0x64, 0xa9, 0x98, 0x2c, 0x55, 0xdc, 0x68, 0x17, 0x9e, 0xa9, 0x3e, 0x66, 0x24,
		0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0x2a, 0xd9, 0xea,
		0x73, 0xd9, 0xea, 0x43, 0x6e, 0x31, 0x61, 0xac, 0x33, 0x5c, 0x83, 0xac, 0x15, 0x93, 0xb5, 0x4a,
		0x75, 0x1d, 0x8c, 0xe4, 0xc0, 0x8d, 0x45, 0x90, 0x00, 0x55, 0xdb, 0x2b, 0x3c, 0x74, 0xce, 0x3e,
		0x72, 0x55, 0x72, 0x55, 0x72, 0x55, 0x72, 0x55, 0x72, 0x55, 0x72, 0xd5, 0x0d, 0xe3, 0xaa, 0x72,
		0x20, 0x94, 0x96, 0xfa, 0x16, 0x94, 0xaf, 0x22, 0xd5, 0x56, 0x6e, 0x4d, 0xbb, 0xea, 0x53, 0x90,
		0x00, 0x86, 0xd4, 0x7c, 0x40, 0x5b, 0xc7, 0x7f, 0x35, 0x8f, 0x5a, 0x07, 0x7e, 0xa7, 0x7d, 0xfa,
		0xf5, 0xd0, 0xef, 0x1c, 0x36, 0xbb, 0xed, 0x63, 0xb4, 0xe8, 0xfa, 0x57, 0x30, 0x1a, 0xa7, 0xa7,
		0x3f, 0x9e, 0x41, 0xd9, 0x35, 0x79, 0xfd, 0x84, 0xb3, 0xe8, 0xd1, 0xd1, 0xfd, 0xe3, 0xe8, 0xb4,
		0xfb, 0xf5, 0xb0, 0xe3, 0x1f, 0xb5, 0xdb, 0x27, 0x0e, 0x9c, 0xc9, 0x77, 0xef, 0x38, 0xae, 0xcf,
		0x1b, 0xd7, 0x76, 0xa7, 0xf5, 0x67, 0xeb, 0xb8, 0xf9, 0xb5, 0xdd, 0xe1, 0xa8, 0xae, 0xcf, 0xa8,
		0x36, 0xbb, 0x74, 0xd4, 0x75, 0x0b, 0xc0, 0xed, 0xe3, 0xcf, 0x87, 0x07, 0x80, 0x23, 0x0a, 0x65,
		0xd1, 0x39, 0xf3, 0x11, 0x30, 0x2b, 0x10, 0xd4, 0xc1, 0x51, 0x90, 0x68, 0xf7, 0x2a, 0x1c, 0xc8,
		0xa1, 0x14, 0x03, 0x3c, 0x71, 0x70, 0xd6, 0x3c, 0x6a, 0x83, 0x8f, 0x99, 0x43, 0x6d, 0x70, 0x89,
		0x09, 0x45, 0x6d, 0x70, 0xa9, 0x99, 0x4e, 0x6d, 0xf0, 0x85, 0x06, 0x52, 0x1b, 0xb4, 0x88, 0xfb,
		0x02, 0x6b, 0x83, 0x5a, 0x5e, 0x09, 0x2d, 0xfb, 0x97, 0x49, 0xbd, 0x0a, 0xa8, 0x0d, 0x7e, 0x00,
		0x32, 0xe9, 0x54, 0x49, 0x9d, 0x4c, 0xba, 0x4c, 0x05, 0x2a, 0x4c, 0x44, 0x3f, 0x54, 0x83, 0x04,
		0xa9, 0xcb, 0x3a, 0x81, 0xba, 0x10, 0x70, 0x7a, 0x1b, 0x5e, 0xaa, 0xe7, 0x7c, 0x91, 0x0a, 0x0e,
		0x11, 0x41, 0x39, 0xe0, 0x82, 0x79, 0xa9, 0xaa, 0x0b, 0x6c, 0xdf, 0xe7, 0x38, 0xe8, 0x6b, 0x19,
		0xaa, 0x03, 0x79, 0x91, 0x79, 0xeb, 0x0e, 0xf5, 0x98, 0xdf, 0x71, 0x89, 0xe0, 0x86, 0x2e, 0xf1,
		0x42, 0x97, 0xa8, 0x7c, 0xa8, 0x56, 0xeb, 0x8d, 0x6a, 0x75, 0xa7, 0xb1, 0xd7, 0xd8, 0xd9, 0xaf,
		0xd5, 0x2a, 0x75, 0xa4, 0x27, 0x5b, 0xd6, 0x79, 0xc9, 0x1b, 0x5a, 0xf3, 0xd8, 0xeb, 0x9c, 0x1a,
		0x17, 0x4a, 0x14, 0x85, 0x29, 0xe4, 0xb0, 0x40, 0xea, 0x31, 0x0a, 0x3a, 0x80, 0x06, 0x70, 0xea,
		0x5a, 0xcb, 0x4c, 0x25, 0xea, 0x5a, 0x4b, 0xcd, 0x74, 0xea, 0x5a, 0x2f, 0x34, 0x90, 0xba, 0x96,
		0x45, 0x39, 0x04, 0xb0, 0xae, 0x35, 0x96, 0x4a, 0xef, 0xed, 0x02, 0x4a, 0x5a, 0x0d, 0x4a, 0x46,
		0xff, 0xf2, 0xa2, 0x64, 0xb4, 0x96, 0xf9, 0x31, 0x25, 0x23, 0xdb, 0xc3, 0xfd, 0xac, 0x4b, 0x50,
		0x32, 0x7a, 0xb1, 0x4b, 0x54, 0x77, 0xf7, 0xab, 0xfb, 0xf5, 0xc6, 0xee, 0x3e, 0x85, 0xa2, 0x35,
		0x90, 0x66, 0xb6, 0x28, 0x14, 0x01, 0xf6, 0x07, 0x84, 0x50, 0x84, 0x95, 0xe0, 0x63, 0x95, 0x88,
		0x02, 0x0d, 0xda, 0x94, 0x89, 0x96, 0x99, 0x49, 0x94, 0x89, 0x96, 0x9a, 0xe9, 0x94, 0x89, 0x5e,
		0x68, 0x20, 0x65, 0x22, 0x8b, 0xf2, 0x06, 0xe4, 0xad, 0x91, 0xd1, 0x75, 0xd5, 0x85, 0xf3, 0xc1,
		0x62, 0x6b, 0xe4, 0x07, 0xac, 0xa3, 0x3c, 0xb4, 0x88, 0x15, 0x9c, 0x5c, 0xe4, 0xbc, 0x7d, 0x7b,
		0xb6, 0xe3, 0xee, 0x9f, 0xff, 0x3a, 0xab, 0xb8, 0xfb, 0xe7, 0x59, 0xb3, 0x92, 0xbe, 0x65, 0xed,
		0xdd, 0xb3, 0x1d, 0xb7, 0x9a, 0xb7, 0x6b, 0x67, 0x3b, 0x6e, 0xed, 0x7c, 0xfb, 0xef, 0xbf, 0xdf,
		0x6f, 0xff, 0xdc, 0xbb, 0x5b, 0xfe, 0x87, 0xde, 0xf4, 0x66, 0xdb, 0xbf, 0xde, 0x9e, 0x55, 0xdc,
		0xdd, 0xf3, 0xfc, 0xc3, 0xde, 0xd9, 0x8e, 0xbb, 0x7b, 0xbe, 0xbd, 0x8d, 0x13, 0x81, 0xce, 0x91,
		0xa6, 0x4e, 0xbb, 0xdb, 0xfa, 0x2f, 0xec, 0xfc, 0xf9, 0x1f, 0xd2, 0x04, 0xfa, 0x8f, 0xc3, 0x0c,
		0x92, 0x19, 0xe4, 0xc2, 0x1c, 0x9d, 0x1e, 0x65, 0x13, 0x8e, 0xb5, 0xc0, 0x4b, 0x23, 0x1f, 0x1a,
		0xc7, 0x5c, 0x92, 0xb9, 0x24, 0x73, 0x49, 0xe6, 0x92, 0xcc, 0x25, 0x99, 0x4b, 0x6e, 0x58, 0x2e,
		0xd9, 0x0b, 0xc3, 0x91, 0x08, 0x14, 0x62, 0x1e, 0x59, 0x21, 0x95, 0x03, 0xb0, 0xc0, 0x74, 0xbd,
		0xc8, 0xa6, 0x52, 0xa1, 0x0e, 0xb4, 0x04, 0x39, 0xad, 0xd1, 0x49, 0xfa, 0xdf, 0xc4, 0x55, 0x10,
		0x4d, 0x8f, 0x08, 0xf5, 0xc2, 0x48, 0xa8, 0x7e, 0x4a, 0x94, 0x5c, 0x25, 0xf4, 0x8f, 0x30, 0xbe,
		0x74, 0xa5, 0x4a, 0x74, 0xa0, 0xfa, 0xc2, 0x9b, 0xbf, 0x90, 0x2c, 0x5c, 0xf1, 0xa2, 0x38, 0xd4,
		0x61, 0x3f, 0x1c, 0x25, 0x45, 0xcb, 0xeb, 0x5d, 0x44, 0x5e, 0x2c, 0x7b, 0x5e, 0x30, 0x94, 0x6e,
		0x12, 0x0c, 0x65, 0x52, 0xb4, 0xbc, 0x54, 0xf8, 0x19, 0x2b, 0xd9, 0x0f, 0x12, 0xed, 0x29, 0x21,
		0x2f, 0xbe, 0xf5, 0xc2, 0x38, 0x29, 0x5a, 0x5e, 0x30, 0xf8, 0x9e, 0x22, 0x41, 0x38, 0xd6, 0x6e,
		0x14, 0x0b, 0x2f, 0x65, 0xb7, 0x49, 0xf6, 0xe6, 0x21, 0xd4, 0x61, 0xce, 0x7a, 0x50, 0xc7, 0xe3,
		0xbe, 0x56, 0xd3, 0x00, 0xd4, 0x2e, 0x3a, 0xf0, 0x38, 0xeb, 0x9c, 0xd6, 0xb4, 0x6f, 0xfc, 0xb9,
		0xcf, 0xc9, 0xfc, 0x05, 0xff, 0x24, 0xef, 0xbc, 0xa2, 0xe5, 0x7f, 0xba, 0x88, 0xfc, 0x8e, 0xec,
		0xf9, 0xcd, 0xa1, 0xec, 0x4e, 0xfa, 0x2e, 0x6f, 0xf8, 0xad, 0xe8, 0xba, 0x7a, 0x9a, 0xf5, 0x9c,
		0x7f, 0x9c, 0xf7, 0x5c, 0xd1, 0xf2, 0x9b, 0x83, 0xef, 0x1d, 0xd9, 0x6b, 0x8f, 0xf5, 0x49, 0x2c,
		0xfc, 0x4e, 0xda, 0x6d, 0xd9, 0x9b, 0xdf, 0x4d, 0xbb, 0x8d, 0x65, 0xcc, 0x4b, 0x9f, 0x26, 0x63,
		0x75, 0xa9, 0xc2, 0x1f, 0xca, 0x0d, 0xb4, 0x8e, 0x65, 0x6f, 0x32, 0x22, 0x38, 0x35, 0xcd, 0x1f,
		0xb1, 0x8d, 0x05, 0xce, 0x59, 0xe0, 0xdc, 0xa6, 0x1c, 0x91, 0x05, 0xce, 0x6d, 0xcf, 0x05, 0x59,
		0xe0, 0x1c, 0x92, 0xb0, 0xc2, 0x14, 0x38, 0x5f, 0x00, 0x29, 0x3c, 0x11, 0x76, 0xd1, 0x44, 0x2c,
		0x29, 0xb6, 0x42, 0x29, 0x16, 0x1e, 0x5e, 0xb1, 0x61, 0x16, 0x15, 0x6e, 0xe1, 0x61, 0x17, 0x1e,
		0x7e, 0xe1, 0x61, 0x18, 0x47, 0xc1, 0xda, 0x02, 0x92, 0x62, 0x51, 0xe0, 0xb9, 0x30, 0x28, 0x2d,
		0xc7, 0xad, 0xd1, 0x04, 0xe2, 0x99, 0x88, 0x7a, 0x6f, 0x22, 0x98, 0xeb, 0x61, 0x6e, 0x99, 0x80,
		0x83, 0x6b, 0x64, 0xd8, 0xb6, 0x03, 0xbe, 0xd1, 0x61, 0xdc, 0x1a, 0x38, 0xb7, 0x06, 0xd6, 0xad,
		0x81, 0x77, 0x2c, 0x98, 0x07, 0x83, 0xfb, 0x62, 0x14, 0xbf, 0x22, 0x02, 0xec, 0x16, 0x76, 0x71,
		0xbe, 0x85, 0x6c, 0xb8, 0x01, 0x68, 0xdb, 0x83, 0x62, 0x7d, 0x59, 0xcd, 0xbd, 0x7b, 0xb2, 0xc2,
		0x4d, 0x76, 0xe8, 0xae, 0xe9, 0x64, 0x0f, 0x25, 0x61, 0x89, 0x2f, 0xca, 0x33, 0xd3, 0x47, 0xbd,
		0x91, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xc8, 0xfa, 0xf8, 0x28, 0xa2,
		0x69, 0x5d, 0x85, 0x61, 0x29, 0x47, 0x1b, 0x09, 0xe0, 0xf3, 0x69, 0x66, 0xa4, 0xaf, 0x89, 0xa5,
		0xef, 0x78, 0x68, 0xc8, 0x1a, 0x91, 0x02, 0x1b, 0xc8, 0x81, 0x5d, 0x24, 0xc1, 0x16, 0xb2, 0x60,
		0x1d, 0x69, 0xb0, 0x8e, 0x3c, 0x58, 0x47, 0x22, 0x30, 0xc9, 0x04, 0x28, 0xa9, 0x28, 0x46, 0x17,
		0x56, 0x51, 0x5b, 0x88, 0x9b, 0x63, 0xa9, 0x74, 0xa5, 0x8e, 0x1c, 0x33, 0xa7, 0x28, 0x5e, 0x07,
		0x36, 0x11, 0xf3, 0xd8, 0xc5, 0xf9, 0x17, 0x36, 0xe6, 0x6c, 0xa1, 0x1f, 0xcb, 0x68, 0x19, 0xbd,
		0x5c, 0x30, 0x17, 0xfc, 0xd8, 0xc6, 0x05, 0x7b, 0x2d, 0x38, 0xaa, 0xce, 0x12, 0x38, 0x9a, 0x75,
		0xb1, 0xe0, 0x86, 0x2e, 0xb6, 0x62, 0x17, 0xab, 0xd7, 0x6a, 0x7b, 0x35, 0xba, 0xd9, 0x66, 0x71,
		0x51, 0x7c, 0xeb, 0xce, 0xdf, 0xb0, 0xbf, 0x2c, 0x0d, 0xe3, 0xc0, 0x2b, 0xe1, 0x16, 0x52, 0x0a,
		0xd4, 0x15, 0x71, 0x96, 0xa0, 0x0a, 0x75, 0xc1, 0xd7, 0x9c, 0x8c, 0xd4, 0x05, 0x5f, 0xd5, 0x73,
		0xa8, 0x0b, 0xae, 0xd8, 0x60, 0xea, 0x82, 0x6b, 0x9c, 0x88, 0x59, 0xa6, 0x0b, 0x7e, 0xb0, 0x40,
		0x16, 0xac, 0x51, 0x16, 0x7c, 0xe1, 0x8b, 0xb2, 0x20, 0x35, 0x0b, 0xca, 0x82, 0x1b, 0x88, 0x46,
		0xb3, 0x2e, 0x46, 0x59, 0x70, 0xe5, 0x2e, 0xb6, 0x5b, 0xa3, 0x28, 0xb8, 0x61, 0x44, 0x14, 0xdf,
		0x3a, 0x8a, 0x82, 0xd6, 0x06, 0xf1, 0x4c, 0x69, 0xbb, 0x9e, 0x46, 0x17, 0x1b, 0x54, 0xc1, 0xcc,
		0x56, 0xca, 0x82, 0xcf, 0x31, 0x8f, 0xb2, 0xe0, 0x2b, 0xce, 0x46, 0xca, 0x82, 0xaf, 0xea, 0x39,
		0x94, 0x05, 0x57, 0x6c, 0x30, 0x65, 0xc1, 0x35, 0x4e, 0xc4, 0x2c, 0x92, 0x05, 0x7b, 0x52, 0x05,
		0xf1, 0xad, 0x05, 0xba, 0xe0, 0x3e, 0xb0, 0x89, 0x47, 0x42, 0x5d, 0xa4, 0x1b, 0x73, 0x29, 0x0c,
		0xbe, 0x54, 0xb5, 0xa0, 0x30, 0xb8, 0x72, 0xd5, 0xa2, 0x42, 0xcd, 0x62, 0xc3, 0xf0, 0x68, 0xd6,
		0xc5, 0x28, 0x0c, 0xae, 0xdc, 0xc5, 0xb8, 0x5e, 0x70, 0x03, 0xc9, 0x28, 0xbe, 0x75, 0x94, 0x06,
		0xad, 0x0d, 0xe3, 0x8e, 0xb8, 0xd1, 0x42, 0x0d, 0xc4, 0x00, 0x5f, 0x18, 0x2c, 0x2c, 0xa5, 0x2c,
		0xf8, 0x1c, 0xf3, 0x28, 0x0b, 0xbe, 0xe2, 0x5c, 0xa4, 0x2c, 0xf8, 0xaa, 0x9e, 0x43, 0x59, 0x70,
		0xc5, 0x06, 0x53, 0x16, 0x5c, 0xe3, 0x34, 0xcc, 0x26, 0x59, 0x10, 0xae, 0x52, 0xda, 0x53, 0x30,
		0x0e, 0x52, 0x39, 0x8d, 0xa4, 0xf6, 0x39, 0x63, 0x18, 0x46, 0x93, 0xcc, 0x33, 0x18, 0xe1, 0x93,
		0xda, 0xc2, 0x52, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92,
		0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x3a, 0xc5, 0xec, 0x18, 0x46, 0x41, 0xac, 0xa5, 0x0d, 0x9c, 0x36,
		0x37, 0x94, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96,
		0x94, 0x96, 0x94, 0x96, 0x4e, 0x31, 0x3b, 0x86, 0x3a, 0x0e, 0x54, 0x22, 0xb5, 0xbc, 0xb6, 0x60,
		0x5f, 0xd2, 0x03, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c,
		0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0xa8, 0x8b, 0x3a, 0x4d, 0xa5, 0x42, 0x1d, 0x68,
		0x19, 0x62, 0x6e, 0x80, 0x72, 0x92, 0xfe, 0x37, 0x71, 0x15, 0x44, 0xd3, 0x02, 0x94, 0x5e, 0x18,
		0x09, 0xd5, 0x4f, 0x89, 0xa2, 0xab, 0x84, 0xfe, 0x11, 0xc6, 0x97, 0xae, 0x54, 0x89, 0x0e, 0x54,
		0x5f, 0x78, 0xf3, 0x17, 0x92, 0x85, 0x2b, 0x5e, 0x14, 0x87, 0x3a, 0xec, 0x87, 0xa3, 0xa4, 0x68,
		0x79, 0xbd, 0x8b, 0xc8, 0x8b, 0x65, 0xcf, 0x0b, 0x86, 0xd2, 0x4d, 0x82, 0xa1, 0x4c, 0x8a, 0x96,
		0x27, 0xa3, 0xeb, 0xaa, 0x3b, 0x56, 0xb2, 0x1f, 0x24, 0xda, 0x53, 0x42, 0x5e, 0x7c, 0xeb, 0x85,
		0x71, 0x52, 0xb4, 0xbc, 0x60, 0xf0, 0x3d, 0x45, 0xaa, 0x70, 0xac, 0xdd, 0x28, 0x16, 0x5e, 0x1c,
		0x8e, 0xb5, 0x48, 0xb2, 0x37, 0x6f, 0xac, 0x2e, 0x55, 0xf8, 0x43, 0xb9, 0x81, 0xd6, 0xb1, 0xec,
		0xa5, 0x7f, 0x58, 0xb8, 0xe4, 0x21, 0xd6, 0x3e, 0xcc, 0xba, 0x5d, 0xc7, 0xe3, 0xbe, 0x56, 0xd3,
		0xa8, 0xd8, 0x2e, 0x7a, 0xfd, 0x38, 0xeb, 0xd1, 0xd6, 0xb4, 0x43, 0xfd, 0xb9, 0xcf, 0xc9, 0xfc,
		0x05, 0xff, 0x24, 0xef, 0xf1, 0xa2, 0xe5, 0x7f, 0xba, 0x88, 0xfc, 0x8e, 0xec, 0xf9, 0xcd, 0xa1,
		0xec, 0x4e, 0x3a, 0x3c, 0x6f, 0xf8, 0xad, 0xe8, 0xba, 0x7a, 0x9a, 0x75, 0xb7, 0x7f, 0x9c, 0x77,
		0x77, 0xd1, 0xf2, 0x9b, 0x83, 0xef, 0x1d, 0xd9, 0x6b, 0x8f, 0xf5, 0x49, 0x2c, 0xfc, 0x4e, 0xda,
		0xd7, 0xd9, 0x9b, 0x7f, 0x9a, 0x75, 0x6c, 0xb3, 0xe8, 0xea, 0x85, 0x2b, 0x7e, 0x37, 0xed, 0x69,
		0x56, 0x2b, 0x05, 0xb6, 0x04, 0x24, 0x34, 0x4e, 0xd8, 0x3e, 0xe2, 0xf1, 0xc3, 0xce, 0x91, 0x4c,
		0xf4, 0x64, 0x42, 0x43, 0x05, 0x6a, 0xe7, 0x8b, 0x54, 0x87, 0x23, 0x31, 0xe1, 0xee, 0x09, 0x56,
		0xee, 0xee, 0x7c, 0x09, 0x6e, 0x1e, 0x58, 0x56, 0xf9, 0x50, 0xad, 0xd6, 0x1b, 0xd5, 0xea, 0x4e,
		0x63, 0xaf, 0xb1, 0xb3, 0x5f, 0xab, 0x55, 0xea, 0x15, 0xa0, 0xad, 0x72, 0x4e, 0x3b, 0x1e, 0x88,
		0x58, 0x0c, 0x3e, 0x4d, 0xa6, 0x9e, 0x1a, 0x8f, 0x46, 0xf4, 0x48, 0x7c, 0x92, 0xb2, 0xde, 0xe4,
		0xc4, 0x81, 0x2a, 0x61, 0xbd, 0x5e, 0x74, 0x04, 0x83, 0x88, 0x98, 0x87, 0x7d, 0xb3, 0x16, 0x18,
		0x0e, 0x6f, 0x68, 0x61, 0x6d, 0x9d, 0xc2, 0x19, 0x40, 0xf0, 0xb2, 0x3d, 0x68, 0x99, 0x8d, 0x51,
		0xe6, 0x22, 0x83, 0x99, 0x3b, 0x1b, 0x8a, 0x45, 0x79, 0xb2, 0x93, 0x3d, 0xd6, 0xd8, 0x9a, 0xf8,
		0xbe, 0x2b, 0x4d, 0x6d, 0xa1, 0xc6, 0xc8, 0x70, 0x70, 0x32, 0x1a, 0xe8, 0x0c, 0x06, 0x23, 0x63,
		0x31, 0xe5, 0x36, 0x20, 0xd0, 0x6d, 0x2d, 0x64, 0x1b, 0xc4, 0x67, 0xbb, 0x70, 0xd9, 0x0c, 0x0a,
		0x97, 0x8f, 0x81, 0xe5, 0xde, 0xb1, 0xe4, 0xb0, 0x61, 0x3a, 0x5c, 0x58, 0x18, 0x26, 0x0c, 0x04,
		0x08, 0x5b, 0x02, 0x43, 0xb9, 0x21, 0xa1, 0x3c, 0xc7, 0x2c, 0xd1, 0x29, 0x9d, 0xec, 0xc1, 0x5b,
		0xd9, 0xbe, 0x58, 0x2c, 0x33, 0x30, 0xf1, 0xdc, 0xaf, 0x58, 0x38, 0x50, 0xf2, 0x6d, 0x8b, 0x75,
		0x7d, 0xbb, 0x25, 0xdf, 0xd8, 0xe0, 0x7a, 0x3d, 0x8c, 0x75, 0x78, 0xa6, 0xd7, 0xd7, 0xc1, 0xac,
		0x9b, 0x83, 0x59, 0x0f, 0x07, 0xb3, 0xce, 0x8d, 0x74, 0x8b, 0x74, 0x2b, 0xa3, 0x5b, 0xa6, 0x96,
		0xa0, 0xe0, 0xb3, 0x2d, 0x03, 0x4b, 0x46, 0x4a, 0x24, 0x5b, 0x6f, 0xd6, 0xc8, 0xf1, 0x4d, 0x39,
		0xbc, 0x4d, 0x8e, 0xee, 0x94, 0xca, 0xae, 0xb1, 0x5d, 0xbb, 0x1c, 0xa7, 0x5e, 0xbd, 0x8b, 0x95,
		0xe0, 0x5e, 0x4e, 0x3e, 0x9f, 0xdc, 0x60, 0x30, 0x88, 0x45, 0x92, 0x94, 0xe6, 0x60, 0x05, 0x87,
		0x5e, 0xb0, 0xa0, 0xa4, 0xa0, 0x52, 0xee, 0x7e, 0xa9, 0xd2, 0xf7, 0x3f, 0x99, 0xc8, 0x8f, 0xcc,
		0xe6, 0x45, 0xa6, 0xf2, 0x21, 0xe3, 0x79, 0x90, 0xf1, 0xfc, 0xc7, 0x78, 0xde, 0xb3, 0x5e, 0x74,
		0xa7, 0xf4, 0xfd, 0x34, 0x85, 0xdf, 0x8e, 0x44, 0x30, 0x8c, 0xc5, 0xb0, 0x4c, 0xa7, 0xcd, 0x65,
		0xab, 0x46, 0x89, 0xf7, 0x3c, 0x99, 0x32, 0xba, 0xf7, 0xef, 0xb3, 0xfc, 0xc8, 0x5b, 0xc0, 0x20,
		0x32, 0x88, 0x25, 0xd8, 0x60, 0x99, 0x5a, 0xab, 0x11, 0x8d, 0xb5, 0x64, 0x6d, 0x95, 0x5c, 0x81,
		0x5c, 0x81, 0x5c, 0x81, 0x5c, 0xe1, 0x77, 0x7a, 0xf3, 0x40, 0x96, 0xbb, 0x9c, 0xca, 0x5c, 0xc2,
		0x88, 0x92, 0x38, 0x1a, 0x4a, 0x20, 0x8d, 0x81, 0x83, 0x49, 0x90, 0xc0, 0x00, 0x0b, 0xd3, 0xa0,
		0x01, 0x03, 0x1e, 0x30, 0x20, 0x02, 0x03, 0x26, 0xe5, 0x82, 0x4a, 0xc9, 0xe0, 0x62, 0x2e, 0x21,
		0x5d, 0xf0, 0x7b, 0x19, 0x19, 0x8a, 0xf2, 0x33, 0xf4, 0xdf, 0x40, 0xb5, 0xd8, 0xbc, 0xef, 0xcd,
		0xd4, 0x80, 0x35, 0xb8, 0xf4, 0xf5, 0x7e, 0xe4, 0xaf, 0xab, 0x06, 0xc7, 0x7e, 0x61, 0x0e, 0x7c,
		0x30, 0x68, 0xc3, 0x49, 0xa0, 0xb5, 0x88, 0x95, 0xf1, 0x92, 0xc0, 0xce, 0xdb, 0xb7, 0x67, 0x3b,
		0xee, 0xfe, 0xf9, 0xaf, 0xb3, 0x8a, 0xbb, 0x7f, 0x9e, 0x35, 0x2b, 0xe9, 0x5b, 0xd6, 0xde, 0x3d,
		0xdb, 0x71, 0xab, 0x79, 0xbb, 0x76, 0xb6, 0xe3, 0xd6, 0xce, 0xb7, 0xff, 0xfe, 0xfb, 0xfd, 0xf6,
		0xcf, 0xbd, 0xbb, 0xe5, 0x7f, 0x68, 0x6e, 0xa3, 0xca, 0xb9, 0xc9, 0xa1, 0x6e, 0x77, 0x5b, 0xff,
		0x85, 0x19, 0xef, 0xff, 0x95, 0x39, 0xe0, 0xff, 0x31, 0x38, 0xe2, 0x9b, 0xb4, 0xcb, 0x01, 0x23,
		0xb8, 0xd7, 0x19, 0xdc, 0x21, 0x83, 0x7b, 0xe0, 0x0e, 0x9b, 0xee, 0xe7, 0xf3, 0x9f, 0x95, 0x77,
		0xd5, 0xbb, 0x8f, 0xdb, 0x3f, 0x1b, 0x77, 0xf3, 0x17, 0x7f, 0x3d, 0xf6, 0xb5, 0xca, 0xbb, 0xc6,
		0xdd, 0xc7, 0x27, 0xfe, 0x52, 0xbf, 0xfb, 0xf8, 0x9b, 0xff, 0x46, 0xed, 0xee, 0xed, 0xc2, 0x57,
		0x27, 0xd7, 0x77, 0x9f, 0xfa, 0x41, 0xf5, 0x89, 0x1f, 0xec, 0x3d, 0xf5, 0x83, 0xbd, 0x27, 0x7e,
		0xf0, 0xa4, 0x49, 0xbb, 0x4f, 0xfc, 0xa0, 0x76, 0xf7, 0x6b, 0xe1, 0xfb, 0x6f, 0x1f, 0xff, 0x6a,
		0xfd, 0x6e, 0xfb, 0xd7, 0x53, 0x7f, 0x6b, 0xdc, 0xfd, 0xfa, 0xb8, 0x4d, 0xa8, 0xc3, 0x81, 0x3a,
		0x4e, 0xff, 0xf2, 0xa7, 0xff, 0xe6, 0x01, 0xff, 0x9b, 0xf5, 0xfe, 0xff, 0xe4, 0x7a, 0xc7, 0x67,
		0xaa, 0x5a, 0x5c, 0xef, 0xb8, 0xb0, 0xde, 0xb1, 0xec, 0x85, 0xcc, 0x90, 0xab, 0x1c, 0x4b, 0x5c,
		0xb3, 0x5c, 0xc2, 0xe2, 0x84, 0x37, 0x16, 0xfb, 0x6a, 0x7e, 0xb2, 0x42, 0xc9, 0x0f, 0xa1, 0xca,
		0x3d, 0x43, 0xa1, 0xfc, 0xb3, 0x12, 0x20, 0xce, 0x44, 0x28, 0xf7, 0xec, 0x83, 0x55, 0x4f, 0xd4,
		0x92, 0xc1, 0x04, 0x19, 0x44, 0x9c, 0x52, 0x96, 0x43, 0xc1, 0xc1, 0xc6, 0x6a, 0x01, 0x63, 0x75,
		0x61, 0x7c, 0x35, 0xff, 0xf2, 0x8a, 0xfc, 0xad, 0x2c, 0x3f, 0x03, 0xf4, 0xaf, 0x15, 0xba, 0x15,
		0x90, 0x3b, 0xad, 0xc6, 0x8b, 0x5e, 0x7f, 0x8e, 0xbf, 0xee, 0xbf, 0xf8, 0xca, 0xde, 0xb2, 0x6a,
		0x2f, 0x81, 0xf1, 0x8e, 0x15, 0xf8, 0x84, 0x71, 0x5f, 0x78, 0x5d, 0x0f, 0x78, 0xbd, 0x79, 0xfa,
		0x8a, 0x73, 0x34, 0x7b, 0x22, 0x91, 0xc4, 0x5a, 0xb8, 0x51, 0x38, 0x92, 0xfd, 0xdb, 0x57, 0x9f,
		0xa5, 0xb3, 0xcf, 0x3e, 0x1e, 0xde, 0xe9, 0x95, 0x3d, 0x6d, 0x35, 0x6b, 0x96, 0x57, 0xb6, 0xfc,
		0x6c, 0x95, 0xcb, 0xcb, 0xca, 0x59, 0x3e, 0xb6, 0xea, 0xe5, 0x61, 0xa5, 0x2d, 0xff, 0x2a, 0x6d,
		0x79, 0x57, 0x69, 0xcb, 0xb7, 0xb0, 0x31, 0x71, 0x55, 0x6b, 0x78, 0x9d, 0x51, 0xd6, 0xa7, 0xab,
		0x9b, 0x91, 0xc5, 0xbe, 0xa1, 0xe9, 0x8d, 0x56, 0x34, 0x4d, 0x56, 0xbb, 0xfd, 0x62, 0xe5, 0x2b,
		0x6a, 0xcb, 0x58, 0x39, 0x5b, 0xee, 0x0a, 0xd9, 0xb2, 0x56, 0xc2, 0x96, 0xbe, 0xe2, 0xb5, 0xf4,
		0x95, 0xad, 0xa5, 0xaf, 0x60, 0xb5, 0x2b, 0xa9, 0x5e, 0xf5, 0xf6, 0x06, 0x67, 0x7a, 0x1c, 0xdd,
		0xca, 0x27, 0x72, 0xee, 0x9e, 0xa5, 0x1c, 0x7f, 0x57, 0xd2, 0x7e, 0xb5, 0xd2, 0xb6, 0x22, 0x94,
		0xb9, 0xf5, 0xc0, 0xcc, 0x56, 0x83, 0xb2, 0xb7, 0x16, 0x18, 0xdb, 0x4a, 0x60, 0x6c, 0xeb, 0x80,
		0xb1, 0xad, 0x02, 0x76, 0x3f, 0xe6, 0x2a, 0x6b, 0x7f, 0x59, 0x16, 0x18, 0xcb, 0xdf, 0x46, 0x5c,
		0xe6, 0x71, 0xc5, 0xdc, 0x46, 0xbc, 0x2e, 0xe1, 0xda, 0x54, 0xd8, 0x36, 0x1e, 0xbe, 0x8d, 0x87,
		0x71, 0xe3, 0xe1, 0xbc, 0x9c, 0xb0, 0x5e, 0x52, 0x78, 0x2f, 0x3d, 0xcc, 0x17, 0x37, 0xec, 0x87,
		0xa3, 0x30, 0x36, 0xb7, 0x77, 0x38, 0xbb, 0x3d, 0x37, 0x0c, 0xaf, 0x1b, 0x1c, 0x60, 0xc0, 0x82,
		0x69, 0x78, 0x80, 0x81, 0x09, 0x18, 0xb8, 0x80, 0x81, 0x8d, 0x72, 0xe1, 0xa3, 0x64, 0x18, 0x29,
		0x7a, 0xd9, 0xfc, 0x86, 0xe1, 0xf2, 0x4f, 0xb2, 0x5a, 0x60, 0xf9, 0x0d, 0x03, 0xf7, 0x5e, 0x38,
		0xd9, 0x2a, 0x03, 0x3a, 0x96, 0x14, 0x78, 0x71, 0xcf, 0x0a, 0x35, 0x88, 0x42, 0x99, 0x06, 0x0e,
		0x43, 0x9c, 0xa5, 0xb0, 0x80, 0xb4, 0x85, 0xb4, 0x85, 0xb4, 0x85, 0xb4, 0x85, 0xb4, 0x85, 0xb4,
		0x65, 0x4d, 0x69, 0x4b, 0x81, 0x75, 0x64, 0x2e, 0x2f, 0xee, 0xdc, 0xbc, 0xea, 0xa7, 0x31, 0xe2,
		0x62, 0xa6, 0xec, 0x28, 0x79, 0x0b, 0x79, 0x0b, 0x79, 0x0b, 0x79, 0x0b, 0x79, 0x0b, 0x79, 0x4b,
		0x69, 0xbc, 0x25, 0x87, 0x3a, 0xd2, 0x96, 0x17, 0xf7, 0x2d, 0x6b, 0x38, 0x92, 0xb2, 0x90, 0xb2,
		0x90, 0xb2, 0x90, 0xb2, 0xac, 0x23, 0x65, 0x29, 0x7b, 0xc1, 0x41, 0x71, 0xe3, 0x40, 0xeb, 0xd8,
		0x95, 0x6a, 0x20, 0x6e, 0xcc, 0x39, 0x5d, 0x1e, 0x7a, 0x1e, 0xd8, 0x62, 0x68, 0xb2, 0x9b, 0xc9,
		0x91, 0x8d, 0x03, 0x0f, 0x02, 0x00, 0x61, 0x01, 0x11, 0x0a, 0x20, 0xc1, 0x01, 0x13, 0x1c, 0x40,
		0xc1, 0x01, 0x95, 0x19, 0xc0, 0x32, 0x04, 0x5c, 0xe6, 0x73, 0x6e, 0xa0, 0xdc, 0x1b, 0x21, 0x07,
		0x7f, 0x2c, 0x17, 0x7f, 0xf4, 0xbf, 0x14, 0x6c, 0x13, 0xa1, 0x93, 0xa2, 0x35, 0xcd, 0xd9, 0x33,
		0x00, 0xde, 0x90, 0x03, 0x00, 0x0d, 0xb8, 0x8b, 0xa1, 0xb5, 0x9e, 0x0b, 0x7e, 0x62, 0x62, 0xcd,
		0x27, 0x89, 0x16, 0x89, 0x16, 0x89, 0x16, 0x89, 0x16, 0x89, 0xd6, 0x1a, 0x10, 0xad, 0xb1, 0x54,
		0x7a, 0x6f, 0x17, 0x80, 0x67, 0x99, 0xa4, 0x59, 0x9d, 0x40, 0x5d, 0x08, 0xe3, 0xc7, 0x74, 0x9b,
		0x8d, 0x99, 0x5b, 0xd3, 0xb3, 0x31, 0x8d, 0x07, 0x6f, 0x10, 0x7a, 0xb1, 0x60, 0xce, 0x5f, 0xc1,
		0x68, 0x2c, 0x80, 0xec, 0xf9, 0x1c, 0x07, 0x7d, 0x2d, 0x43, 0x75, 0x20, 0x2f, 0x64, 0x76, 0x94,
		0xa9, 0x71, 0xbb, 0xee, 0xde, 0x01, 0x4c, 0xe1, 0xe0, 0x86, 0x53, 0xf8, 0x5f, 0xa6, 0x70, 0x75,
		0x77, 0xbf, 0xba, 0x5f, 0x6f, 0xec, 0xee, 0xd7, 0x38, 0x97, 0xb1, 0x08, 0x89, 0xf9, 0xbb, 0x9f,
		0x53, 0x34, 0x58, 0xa1, 0x68, 0x70, 0x75, 0x35, 0x56, 0x52, 0xdf, 0xa2, 0x3c, 0xac, 0x99, 0x37,
		0x88, 0x42, 0x02, 0x85, 0x04, 0x0a, 0x09, 0x14, 0x12, 0x28, 0x24, 0x50, 0x48, 0x58, 0x32, 0x6e,
		0xf0, 0x89, 0xcd, 0xd6, 0xef, 0x3c, 0xb1, 0xc9, 0x11, 0x57, 0x8a, 0xa4, 0x68, 0xdf, 0xf2, 0xa1,
		0x4d, 0x39, 0x83, 0x63, 0x6c, 0xbf, 0xeb, 0x82, 0xb7, 0x18, 0xda, 0xf7, 0x4a, 0xc6, 0x45, 0xc6,
		0x45, 0xc6, 0x45, 0xc6, 0x45, 0xc6, 0xb5, 0x06, 0x8c, 0x4b, 0x46, 0x48, 0x65, 0x86, 0xf7, 0x0d,
		0xda, 0x30, 0x1d, 0x93, 0x8d, 0x7f, 0x7c, 0xf3, 0xa0, 0x0c, 0x43, 0x15, 0x60, 0x6e, 0x2c, 0xcc,
		0x91, 0x0f, 0x00, 0xb6, 0xa0, 0x14, 0xe5, 0x2d, 0x0c, 0x2a, 0xb3, 0x0c, 0xbd, 0x63, 0xfc, 0x7f,
		0xf9, 0x1c, 0x61, 0x0a, 0x20, 0x15, 0x67, 0x2e, 0xac, 0xfa, 0x5f, 0x99, 0x13, 0xe1, 0x3f, 0x00,
		0x33, 0xc1, 0xec, 0x03, 0x96, 0x77, 0x04, 0x8b, 0x07, 0x35, 0x7b, 0x08, 0x16, 0x36, 0x81, 0x05,
		0x0b, 0xb9, 0x97, 0x5f, 0xc8, 0x9d, 0xd0, 0x09, 0x0f, 0x9d, 0x74, 0x8b, 0xf2, 0xdd, 0x82, 0x44,
		0x82, 0x2b, 0x35, 0xd6, 0x8f, 0xaa, 0x39, 0xe2, 0x46, 0xbb, 0x70, 0xab, 0x35, 0x1e, 0x33, 0x8a,
		0xcf, 0x0f, 0xcc, 0xe0, 0x20, 0x9f, 0x1f, 0xcc, 0x59, 0xc3, 0xe7, 0x07, 0x4f, 0x18, 0xc4, 0xe7,
		0x07, 0x90, 0x08, 0xca, 0xe7, 0x07, 0x5c, 0xb1, 0xb1, 0xf5, 0x3b, 0x2b, 0x36, 0x1e, 0xa2, 0xae,
		0x14, 0xc9, 0xcc, 0x67, 0xae, 0xdc, 0x28, 0x69, 0x90, 0xa4, 0xba, 0x0e, 0x46, 0x72, 0xe0, 0xc6,
		0x22, 0x48, 0x42, 0x65, 0x9e, 0x8a, 0xcd, 0xd9, 0x43, 0x16, 0x46, 0x16, 0x46, 0x16, 0x46, 0x16,
		0x46, 0x16, 0x46, 0x16, 0xb6, 0x2c, 0x92, 0x0c, 0x84, 0xd2, 0x52, 0xdf, 0x82, 0x30, 0x31, 0x83,
		0x3b, 0xc2, 0x9c, 0xd6, 0xb4, 0x2b, 0x3e, 0x05, 0x09, 0x40, 0x08, 0xcb, 0x07, 0xa8, 0x75, 0xfc,
		0x57, 0xf3, 0xa8, 0x75, 0xe0, 0x77, 0xda, 0xa7, 0x5f, 0x0f, 0xfd, 0xce, 0x61, 0xb3, 0xdb, 0x3e,
		0x36, 0x1d, 0xcd, 0xd2, 0x8d, 0x7c, 0x09, 0x84, 0x00, 0x0f, 0xb2, 0xd3, 0x72, 0x7e, 0xb4, 0xfe,
		0x38, 0x3a, 0xed, 0x7e, 0x3d, 0xec, 0xf8, 0x47, 0xed, 0xf6, 0x89, 0xc3, 0x8d, 0xb1, 0xb0, 0xe3,
		0xd4, 0xee, 0xb4, 0xfe, 0x6c, 0x1d, 0x37, 0xbf, 0xb6, 0x3b, 0x1c, 0x25, 0xdc, 0x51, 0x6a, 0x76,
		0xe9, 0x48, 0xe8, 0x01, 0xaf, 0x7d, 0xfc, 0xf9, 0xf0, 0xc0, 0xd9, 0xf0, 0x7d, 0xd3, 0xe7, 0x9b,
		0xc6, 0x9f, 0x37, 0x42, 0xfd, 0x19, 0x05, 0x89, 0x76, 0xaf, 0xc2, 0x81, 0x1c, 0x4a, 0x31, 0x30,
		0x2f, 0xfe, 0xcc, 0x9a, 0x43, 0xed, 0x87, 0xda, 0x0f, 0xb5, 0x1f, 0x6a, 0x3f, 0xd4, 0x7e, 0xa8,
		0xfd, 0x2c, 0x19, 0x37, 0xb4, 0xbc, 0x12, 0x5a, 0xf6, 0x2f, 0x93, 0x7a, 0x15, 0x40, 0xfb, 0x31,
		0xb8, 0xe0, 0xd6, 0x39, 0x55, 0xd9, 0xb9, 0x3f, 0x8e, 0x0a, 0x54, 0x98, 0x88, 0x7e, 0xa8, 0x06,
		0x46, 0x77, 0x35, 0xf1, 0x44, 0xb8, 0x69, 0x47, 0xf0, 0x44, 0xb8, 0xa7, 0xcd, 0xe1, 0x89, 0x70,
		0x36, 0xe4, 0xeb, 0x3c, 0x11, 0xee, 0x37, 0xa6, 0x70, 0xe5, 0x43, 0xb5, 0x5a, 0x6f, 0x54, 0xab,
		0x3b, 0x8d, 0xbd, 0xc6, 0xce, 0x7e, 0xad, 0x56, 0xa9, 0x57, 0x78, 0x36, 0x1c, 0xa8, 0xc6, 0xc1,
		0x15, 0xc7, 0xeb, 0xa8, 0x71, 0x98, 0xaa, 0x68, 0xbb, 0x40, 0x4a, 0xcd, 0x54, 0xb6, 0x2d, 0xcc,
		0x38, 0x10, 0xc3, 0x60, 0x3c, 0x4a, 0x53, 0xa3, 0x1d, 0x6a, 0x2b, 0xd4, 0x56, 0xa8, 0xad, 0x50,
		0x5b, 0xa1, 0xb6, 0x42, 0x6d, 0x65, 0xd9, 0xb8, 0xc1, 0x83, 0xed, 0x29, 0x63, 0x50, 0xc6, 0xa0,
		0x8c, 0x41, 0x19, 0x63, 0x83, 0xa6, 0x30, 0x0f, 0xb6, 0xa7, 0x78, 0x41, 0xf1, 0xa2, 0x7c, 0xf1,
		0x62, 0xba, 0x19, 0x26, 0x1c, 0x6b, 0x61, 0x5e, 0xc0, 0x78, 0x68, 0x0c, 0x05, 0x04, 0x0a, 0x08,
		0x14, 0x10, 0x28, 0x20, 0x50, 0x40, 0xa0, 0x80, 0xb0, 0x64, 0xdc, 0xe8, 0x85, 0xe1, 0x48, 0x04,
		0x0a, 0x61, 0x53, 0x4e, 0x65, 0x53, 0xa8, 0xcb, 0x9b, 0x35, 0x9e, 0xe2, 0x4e, 0x53, 0xa9, 0x50,
		0x07, 0x93, 0x6c, 0xc0, 0xc8, 0x04, 0x77, 0x92, 0xfe, 0x37, 0x71, 0x15, 0x44, 0xd3, 0xed, 0xee,
		0x5e, 0x18, 0x09, 0xd5, 0x4f, 0x89, 0x82, 0xab, 0x84, 0xfe, 0x11, 0xc6, 0x97, 0xae, 0x54, 0x89,
		0x0e, 0x54, 0x5f, 0x78, 0xf3, 0x17, 0x92, 0x85, 0x2b, 0x5e, 0x14, 0x87, 0x3a, 0xec, 0x87, 0xa3,
		0xa4, 0x68, 0x79, 0xbd, 0x8b, 0xc8, 0x8b, 0x65, 0xcf, 0x0b, 0x86, 0xd2, 0x4d, 0x82, 0xa1, 0x4c,
		0x8a, 0x96, 0x97, 0x1e, 0x32, 0x98, 0xc4, 0x5a, 0xb8, 0x51, 0x38, 0x92, 0xfd, 0x5b, 0x6f, 0x94,
		0x85, 0x56, 0x2f, 0xa5, 0x69, 0x49, 0xf6, 0x96, 0x6d, 0xa6, 0x37, 0xe0, 0x70, 0x4e, 0xa2, 0xe3,
		0x71, 0x5f, 0xab, 0xa9, 0xe7, 0xb7, 0x8b, 0x9e, 0x39, 0xce, 0xfe, 0xaf, 0x5b, 0xd3, 0xff, 0x69,
		0x7f, 0xee, 0x73, 0x32, 0x7f, 0xc1, 0x3f, 0xc9, 0x7b, 0xa5, 0x68, 0xf9, 0x9f, 0x2e, 0x22, 0xbf,
		0x23, 0x7b, 0x7e, 0x73, 0x28, 0xbb, 0x93, 0x4e, 0xc9, 0x1b, 0x7e, 0x2b, 0xba, 0xae, 0x77, 0x63,
		0x2d, 0x4e, 0xd2, 0x1e, 0xf1, 0x8f, 0xc2, 0xfe, 0xe4, 0x6b, 0x9d, 0xb4, 0x43, 0xb2, 0x37, 0xbf,
		0x9b, 0x76, 0xc8, 0x9b, 0xf5, 0xf4, 0xc1, 0x12, 0xfd, 0xcf, 0x19, 0xab, 0x4b, 0x15, 0xfe, 0x50,
		0x6e, 0xa0, 0x75, 0x2c, 0x7b, 0x93, 0x1e, 0x2e, 0xdd, 0x07, 0xef, 0x95, 0xe9, 0x45, 0x5b, 0x4a,
		0x8e, 0x44, 0x39, 0xae, 0x94, 0x7c, 0x5b, 0x53, 0x69, 0x89, 0xc9, 0x74, 0x04, 0x23, 0x0d, 0x31,
		0x9d, 0x7e, 0xc0, 0xa4, 0x1d, 0x30, 0xe9, 0x06, 0x4c, 0x9a, 0xb1, 0xde, 0x9c, 0xeb, 0x40, 0xc6,
		0x66, 0xdc, 0x7e, 0x21, 0xc8, 0x9b, 0xd7, 0xc5, 0x16, 0x4d, 0x32, 0xab, 0x8e, 0x55, 0xa8, 0x8e,
		0x51, 0x1d, 0xa3, 0x3a, 0x46, 0x75, 0x8c, 0xea, 0x18, 0x3a, 0x9c, 0x15, 0x06, 0x4c, 0xb0, 0xc3,
		0xd5, 0xa6, 0x35, 0xba, 0x99, 0x08, 0x76, 0x6f, 0x92, 0x61, 0xd7, 0xc0, 0x78, 0x26, 0x6e, 0x1c,
		0xde, 0x90, 0x60, 0x0e, 0x13, 0xee, 0xd0, 0x60, 0x0f, 0x16, 0xfe, 0x60, 0x61, 0x10, 0x16, 0x0e,
		0xcd, 0xc2, 0xa2, 0x61, 0x78, 0x2c, 0x46, 0xe5, 0x2b, 0x02, 0x40, 0x6d, 0x61, 0x9d, 0xb5, 0xbb,
		0x90, 0x7d, 0x35, 0x30, 0xea, 0xeb, 0xe4, 0x67, 0xef, 0x66, 0x07, 0xe9, 0xde, 0x83, 0xf9, 0x86,
		0xae, 0x52, 0x32, 0xe8, 0x3a, 0x4e, 0xf6, 0xf8, 0x05, 0x86, 0xd8, 0x99, 0x7a, 0x1a, 0x04, 0xa4,
		0x55, 0x90, 0xd4, 0x91, 0xd4, 0x91, 0xd4, 0x91, 0xd4, 0x91, 0xd4, 0x99, 0xd7, 0x3e, 0x66, 0x35,
		0x90, 0x91, 0x00, 0xda, 0x50, 0x32, 0x23, 0x85, 0x4c, 0x2c, 0x7b, 0xc7, 0x5d, 0x02, 0xc0, 0x20,
		0x8a, 0x08, 0xa6, 0xd8, 0xa0, 0x8a, 0x0a, 0xae, 0xf0, 0x20, 0x0b, 0x0f, 0xb6, 0xf0, 0xa0, 0x8b,
		0x01, 0xbe, 0x20, 0x20, 0x8c, 0xa7, 0xb0, 0x2c, 0xc4, 0xad, 0xb1, 0x54, 0xba, 0x52, 0x47, 0x8a,
		0x59, 0x53, 0x14, 0xac, 0x03, 0x99, 0x84, 0xb1, 0x2f, 0x78, 0xfe, 0x85, 0x15, 0xd3, 0xb7, 0xd0,
		0xf6, 0x0d, 0x83, 0xd3, 0xab, 0x05, 0xf3, 0xc0, 0xf6, 0x15, 0x2f, 0xd8, 0x07, 0xb8, 0x37, 0x13,
		0x34, 0xdc, 0xcf, 0xba, 0x44, 0x70, 0x43, 0x97, 0x78, 0xa1, 0x4b, 0xd4, 0x6b, 0xb5, 0xbd, 0x1a,
		0xdd, 0xc2, 0x6e, 0x2e, 0x86, 0x67, 0xcd, 0xf9, 0x1b, 0xf6, 0x07, 0x48, 0xd8, 0x04, 0x5a, 0x29,
		0xb3, 0x40, 0x91, 0x51, 0x56, 0xcc, 0x80, 0x46, 0x6d, 0xea, 0x44, 0xcb, 0x4c, 0x26, 0xea, 0x44,
		0x4b, 0xcd, 0x74, 0xea, 0x44, 0x2f, 0x34, 0x90, 0x3a, 0x91, 0x45, 0x89, 0x03, 0xb8, 0x4e, 0xf4,
		0x01, 0x50, 0x26, 0xaa, 0x51, 0x26, 0xfa, 0x97, 0x17, 0x65, 0xa2, 0xb5, 0xcc, 0x89, 0x29, 0x13,
		0xd9, 0x1e, 0xed, 0x67, 0x5d, 0x82, 0x32, 0xd1, 0x8b, 0x5d, 0x62, 0xb7, 0x46, 0x91, 0x68, 0x0d,
		0x64, 0x99, 0x2d, 0x8a, 0x44, 0x80, 0xfd, 0x01, 0x23, 0x12, 0x5d, 0x4f, 0xbd, 0x1d, 0x51, 0x25,
		0xca, 0x6c, 0xa3, 0x4c, 0xf4, 0x98, 0x39, 0x94, 0x89, 0x96, 0x98, 0x4d, 0x94, 0x89, 0x96, 0x9a,
		0xe9, 0x94, 0x89, 0x5e, 0x68, 0x20, 0x65, 0x22, 0x8b, 0x12, 0x07, 0x60, 0x99, 0xa8, 0x27, 0x55,
		0x10, 0xdf, 0x02, 0xea, 0x44, 0xfb, 0x40, 0x26, 0x1d, 0x09, 0x75, 0x91, 0x6e, 0xe4, 0xa2, 0x50,
		0xf4, 0x6f, 0x59, 0x31, 0x85, 0xa2, 0x17, 0x67, 0xc5, 0x15, 0xe6, 0xc4, 0x96, 0xc7, 0xfb, 0x59,
		0x97, 0xa0, 0x50, 0xf4, 0x62, 0x97, 0xe0, 0x7a, 0xa2, 0x35, 0x11, 0x67, 0xb6, 0x28, 0x15, 0x01,
		0xf6, 0x07, 0x82, 0x54, 0x24, 0x6e, 0xb4, 0x50, 0x03, 0x31, 0xc0, 0x13, 0x8a, 0x0a, 0xcb, 0x28,
		0x13, 0x3d, 0x66, 0x0e, 0x65, 0xa2, 0x25, 0xe6, 0x12, 0x65, 0xa2, 0xa5, 0x66, 0x3a, 0x65, 0xa2,
		0x17, 0x1a, 0x48, 0x99, 0xc8, 0xa2, 0xb4, 0x01, 0x59, 0x26, 0x32, 0x5e, 0x2c, 0xe2, 0x29, 0x18,
		0x34, 0x54, 0x3c, 0x82, 0x24, 0xee, 0xb1, 0x31, 0x09, 0xa3, 0x49, 0x26, 0x14, 0x8c, 0xf0, 0x48,
		0x5c, 0x61, 0x19, 0x49, 0x1c, 0x49, 0x1c, 0x49, 0x1c, 0x49, 0x1c, 0x49, 0x1c, 0x49, 0x1c, 0x49,
		0x1c, 0x49, 0x1c, 0x49, 0xdc, 0xfc, 0x98, 0x44, 0x41, 0xac, 0x25, 0x22, 0x87, 0xcb, 0x0d, 0x23,
		0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23, 0x85, 0x23,
		0x85, 0x9b, 0x1f, 0x13, 0x1d, 0x07, 0x2a, 0x91, 0x5a, 0x5e, 0x03, 0xae, 0xbb, 0x7f, 0x60, 0x1b,
		0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c, 0x89, 0x1c,
		0x18, 0x91, 0xdb, 0xe8, 0xe3, 0xe8, 0x0d, 0x57, 0xf3, 0x5f, 0xb0, 0x07, 0xbf, 0xba, 0xff, 0x62,
		0xdd, 0xf3, 0xc5, 0x4b, 0x1e, 0x42, 0xd1, 0x97, 0xac, 0x3f, 0x75, 0x3c, 0xee, 0x6b, 0x35, 0x0d,
		0x47, 0xed, 0xa2, 0x3b, 0xe7, 0x2b, 0xfe, 0xcf, 0x7d, 0x4e, 0xe6, 0x2f, 0xf8, 0x27, 0x79, 0x57,
		0x16, 0x2d, 0xff, 0xd3, 0x45, 0xe4, 0x77, 0x64, 0xcf, 0x6f, 0x0e, 0x65, 0x77, 0xd2, 0x93, 0x79,
		0xc3, 0x6f, 0x45, 0xd7, 0xf5, 0x6e, 0xac, 0xc5, 0x49, 0xda, 0x8d, 0xfe, 0x51, 0xd8, 0x9f, 0x7c,
		0xad, 0x93, 0xf6, 0x62, 0xf6, 0xe6, 0x9f, 0x66, 0x5d, 0xd6, 0x2c, 0x3a, 0x71, 0xe1, 0x8a, 0xdf,
		0x4d, 0xfb, 0x70, 0x53, 0x0b, 0x28, 0x6d, 0x54, 0x41, 0xd0, 0xff, 0x27, 0x6e, 0x11, 0x4e, 0xf4,
		0x73, 0x8e, 0x64, 0xa2, 0x27, 0x13, 0xd0, 0x6c, 0x75, 0xd2, 0x2f, 0x52, 0x1d, 0x8e, 0xc4, 0x84,
		0x7e, 0x26, 0x66, 0xd3, 0x43, 0xe7, 0x4b, 0x70, 0xf3, 0xc0, 0x92, 0xca, 0x87, 0x6a, 0xb5, 0xde,
		0xa8, 0x56, 0x77, 0x1a, 0x7b, 0x8d, 0x9d, 0xfd, 0x5a, 0xad, 0x52, 0xaf, 0x18, 0xdc, 0xad, 0xe1,
		0xb4, 0xe3, 0x81, 0x88, 0xc5, 0xe0, 0xd3, 0x64, 0xea, 0xa8, 0xf1, 0x68, 0xb4, 0x51, 0x1e, 0x03,
		0x82, 0xdb, 0x6b, 0x82, 0xd7, 0x8e, 0xd1, 0x72, 0x75, 0xb6, 0x22, 0xb4, 0x19, 0x6c, 0x2e, 0x1f,
		0x19, 0xcb, 0xbd, 0x63, 0xc9, 0x11, 0xc5, 0x74, 0x24, 0xb1, 0x32, 0x82, 0x18, 0x88, 0x17, 0xf6,
		0xc4, 0x89, 0x72, 0xc3, 0x42, 0x79, 0xce, 0x59, 0xce, 0x9d, 0x4a, 0x72, 0xff, 0x9c, 0x72, 0x4f,
		0xfc, 0xce, 0x95, 0x83, 0x2d, 0xa1, 0x06, 0x51, 0x28, 0x95, 0xde, 0xea, 0x87, 0xa3, 0x30, 0x2e,
		0x69, 0x7e, 0x9b, 0xe1, 0xdb, 0xe6, 0xf8, 0x35, 0x14, 0x9f, 0x36, 0xc3, 0x9f, 0xcb, 0x9a, 0xde,
		0x86, 0x50, 0x0d, 0x1f, 0xcd, 0x4a, 0x84, 0x2e, 0x54, 0xc8, 0x2a, 0x07, 0xa0, 0x56, 0x0f, 0x17,
		0xab, 0xbd, 0xc3, 0x8a, 0x3d, 0xb5, 0x6c, 0x0f, 0x45, 0xf6, 0xcc, 0x12, 0x7c, 0x12, 0xcf, 0x17,
		0x57, 0xeb, 0x85, 0xab, 0xf3, 0x8d, 0xd5, 0xfc, 0xcb, 0x2b, 0xf2, 0xb6, 0xb2, 0xbc, 0x0c, 0xd2,
		0xbb, 0x56, 0xe8, 0x56, 0x40, 0xee, 0xb4, 0x1a, 0x3f, 0x7a, 0xfd, 0x59, 0xbe, 0x82, 0x19, 0xee,
		0x28, 0x21, 0x2f, 0xbe, 0xf5, 0xc2, 0x38, 0x59, 0xd9, 0xe4, 0x2e, 0x9e, 0xe4, 0xdf, 0xdf, 0x6a,
		0x45, 0x9e, 0x9a, 0x3f, 0x97, 0x5f, 0xd1, 0x3f, 0xbf, 0xea, 0xe5, 0x66, 0x65, 0x2c, 0x1f, 0x2b,
		0x77, 0x39, 0x58, 0x59, 0xcb, 0xbb, 0x4a, 0x5f, 0xae, 0x55, 0xfa, 0xf2, 0xab, 0xd2, 0x97, 0x53,
		0xd9, 0x85, 0xd1, 0x07, 0x72, 0xb5, 0x02, 0x48, 0x11, 0xbb, 0x56, 0x3f, 0x95, 0xe7, 0xa3, 0xe5,
		0xaa, 0x67, 0xf2, 0x6a, 0x83, 0x66, 0x69, 0xc1, 0xb3, 0xcc, 0x20, 0x6a, 0x26, 0x98, 0x96, 0x1d,
		0x54, 0x8d, 0x05, 0x57, 0x63, 0x41, 0xd6, 0x58, 0xb0, 0x5d, 0x0f, 0x39, 0x62, 0xd5, 0x41, 0xb8,
		0xb8, 0x51, 0x30, 0xf8, 0x9e, 0x8e, 0x89, 0x54, 0x6e, 0x14, 0x26, 0xba, 0x3c, 0x4f, 0x28, 0x2a,
		0x22, 0xcc, 0x19, 0x50, 0xd6, 0x03, 0x87, 0x52, 0x42, 0x75, 0xe9, 0x21, 0xdb, 0x44, 0xe8, 0x36,
		0x1b, 0xc2, 0x4d, 0x85, 0x72, 0xe3, 0x21, 0xdd, 0x78, 0x68, 0x37, 0x1e, 0xe2, 0xcb, 0x09, 0xf5,
		0x25, 0x85, 0xfc, 0xd2, 0x43, 0x7f, 0x71, 0xc3, 0xa9, 0xea, 0x5b, 0xba, 0xe3, 0xe4, 0xe1, 0xa2,
		0x34, 0xd5, 0xd9, 0x20, 0x00, 0x18, 0x03, 0x02, 0x93, 0x80, 0x80, 0x01, 0x0c, 0xa6, 0x01, 0x02,
		0x06, 0x28, 0x60, 0x00, 0x03, 0x06, 0x38, 0xca, 0x05, 0x90, 0x92, 0x81, 0xc4, 0x18, 0xa0, 0xcc,
		0x02, 0x8b, 0x39, 0x7f, 0x9b, 0xc1, 0x17, 0x53, 0xbe, 0x66, 0x06, 0x66, 0x8c, 0xc3, 0x0d, 0x02,
		0xec, 0x60, 0xc1, 0x0f, 0x0a, 0x0c, 0xc1, 0xc1, 0x11, 0x1c, 0x2c, 0xc1, 0xc1, 0x93, 0x19, 0x98,
		0x32, 0x04, 0x57, 0xc6, 0x61, 0xab, 0x30, 0x20, 0x5b, 0x7b, 0x6a, 0xdc, 0x4f, 0xf3, 0xe8, 0x55,
		0xe6, 0x52, 0xd8, 0x7f, 0x83, 0x33, 0xc3, 0x87, 0x84, 0xc0, 0x9c, 0x56, 0x82, 0x74, 0x4a, 0x09,
		0xe6, 0xe9, 0x24, 0x68, 0xa7, 0x92, 0xc0, 0x9e, 0x46, 0x02, 0x7b, 0x0a, 0x09, 0xec, 0xe9, 0x23,
		0x9b, 0x7d, 0x54, 0x02, 0xcc, 0x29, 0x23, 0x45, 0xdc, 0x19, 0x89, 0x60, 0x18, 0x8b, 0x21, 0x42,
		0xd0, 0xc9, 0xb3, 0xae, 0x06, 0x80, 0x2d, 0x27, 0xd3, 0x55, 0x88, 0xef, 0xdf, 0x67, 0xe7, 0x30,
		0x78, 0x19, 0x90, 0x6f, 0xea, 0x49, 0x02, 0x06, 0x33, 0xaf, 0x7c, 0x57, 0x11, 0x0e, 0xa7, 0x2b,
		0x2c, 0x22, 0xad, 0x23, 0xad, 0x23, 0xad, 0x23, 0xad, 0x23, 0xad, 0x23, 0xad, 0x23, 0xad, 0xb3,
		0x92, 0xd6, 0x15, 0x58, 0x4e, 0x66, 0x57, 0xfa, 0x60, 0x4c, 0xf7, 0x8d, 0xe3, 0x10, 0xbb, 0xdc,
		0x20, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0xf2, 0x3a, 0x2b,
		0x79, 0x5d, 0x0e, 0xe5, 0xa4, 0x75, 0xa5, 0x8f, 0x45, 0x76, 0x6e, 0x2d, 0x0c, 0xa9, 0x43, 0x38,
		0x46, 0xd7, 0xf0, 0x82, 0x22, 0x52, 0x3a, 0x52, 0x3a, 0x52, 0x3a, 0x52, 0x3a, 0x52, 0x3a, 0xf3,
		0x0b, 0x94, 0x0a, 0x43, 0xd2, 0x83, 0xaa, 0xa5, 0x1a, 0x88, 0x1b, 0xbc, 0xc2, 0x4b, 0x0f, 0x6c,
		0x63, 0xe1, 0x25, 0x64, 0x20, 0x45, 0x04, 0x54, 0x6c, 0x60, 0x45, 0x05, 0x58, 0x78, 0xa0, 0x85,
		0x07, 0x5c, 0x78, 0xe0, 0xc5, 0x00, 0x60, 0x10, 0x20, 0xc6, 0xd3, 0x58, 0x80, 0xb5, 0x16, 0x44,
		0xcd, 0xe5, 0x31, 0xed, 0xe5, 0x1f, 0xfe, 0x4b, 0x29, 0x45, 0x22, 0x74, 0x52, 0xb4, 0xa6, 0x4a,
		0x4d, 0x46, 0x33, 0x58, 0x48, 0x0a, 0xc5, 0x29, 0x9d, 0x9e, 0x48, 0xb4, 0x3b, 0x3d, 0x85, 0x0f,
		0x8c, 0x97, 0xde, 0x9b, 0x46, 0x5a, 0x4a, 0x5a, 0x4a, 0x5a, 0x4a, 0x5a, 0x4a, 0x5a, 0x4a, 0x5a,
		0xba, 0x61, 0xb4, 0x94, 0xf5, 0x40, 0x49, 0xe3, 0x7e, 0x63, 0x4c, 0x30, 0x36, 0x42, 0x2e, 0xcc,
		0x5e, 0x84, 0x0d, 0x91, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f, 0xa4, 0x6f,
		0xa5, 0xc7, 0xad, 0xb1, 0x54, 0x7a, 0x6f, 0x17, 0x90, 0xbd, 0x21, 0x69, 0x8a, 0x9d, 0x40, 0x5d,
		0x4c, 0x7a, 0xeb, 0x0c, 0x2a, 0x06, 0x60, 0xc5, 0xf4, 0xad, 0x69, 0x1d, 0x32, 0x38, 0xb0, 0x01,
		0xa5, 0x57, 0x0b, 0xe6, 0xfd, 0x15, 0x8c, 0xc6, 0x02, 0xd8, 0xbe, 0xcf, 0x71, 0xd0, 0xd7, 0x32,
		0x54, 0x07, 0xf2, 0x42, 0x66, 0x65, 0xe6, 0xe0, 0xec, 0xbc, 0x7b, 0x07, 0xe8, 0x12, 0xc1, 0x0d,
		0x5d, 0xe2, 0x85, 0x2e, 0x51, 0xdd, 0xdd, 0xaf, 0xee, 0xd7, 0x1b, 0xbb, 0xfb, 0x35, 0xfa, 0x86,
		0xdd, 0x84, 0x0c, 0xcf, 0x9a, 0x73, 0x8a, 0x44, 0x28, 0xb1, 0xd3, 0xe9, 0x87, 0x57, 0x57, 0x63,
		0x25, 0xf5, 0x2d, 0xea, 0x4a, 0xb4, 0x79, 0x03, 0x29, 0x1c, 0x3d, 0x66, 0x0e, 0x85, 0xa3, 0x25,
		0xa6, 0x14, 0x85, 0xa3, 0xa5, 0x66, 0x3a, 0x85, 0xa3, 0x17, 0x1a, 0x48, 0xe1, 0xc8, 0xa2, 0x4c,
		0x82, 0xcb, 0xd1, 0x9e, 0x01, 0x83, 0x16, 0x2e, 0x47, 0xcb, 0x79, 0x85, 0x14, 0x49, 0xd1, 0xbe,
		0xe5, 0x8a, 0x34, 0x4c, 0x96, 0x0a, 0x73, 0x04, 0xd8, 0x82, 0x4f, 0x82, 0x1c, 0x05, 0x46, 0x5e,
		0x4a, 0x5e, 0x4a, 0x5e, 0x4a, 0x5e, 0x4a, 0x5e, 0x4a, 0x5e, 0x5a, 0x7a, 0xdc, 0x92, 0x91, 0x1b,
		0x0c, 0x06, 0xb1, 0x48, 0x12, 0x44, 0x6a, 0xba, 0x0f, 0x64, 0xd3, 0x74, 0x0c, 0xf9, 0x50, 0xf3,
		0xb7, 0x67, 0xd6, 0x75, 0x15, 0x70, 0x6e, 0x2d, 0xcc, 0xb1, 0x0f, 0x80, 0xb6, 0x9d, 0x04, 0x5a,
		0x8b, 0x58, 0xc1, 0x4d, 0xb7, 0xc2, 0xc0, 0xb7, 0x6f, 0xcf, 0x76, 0xdc, 0xfd, 0xf3, 0x5f, 0x67,
		0x15, 0x77, 0xff, 0x3c, 0x6b, 0x56, 0xd2, 0xb7, 0xac, 0xbd, 0x7b, 0xb6, 0xe3, 0x56, 0xf3, 0x76,
		0xed, 0x6c, 0xc7, 0xad, 0x9d, 0x6f, 0xff, 0xfd, 0xf7, 0xfb, 0xed, 0x9f, 0x7b, 0x77, 0xcb, 0xff,
		0xd0, 0x81, 0xeb, 0x82, 0x73, 0xc4, 0x29, 0xd3, 0xee, 0xb6, 0xfe, 0x0b, 0x3f, 0x6f, 0xfe, 0x57,
		0xe6, 0xc4, 0xf9, 0x0f, 0xe0, 0xcc, 0xc1, 0x7a, 0xac, 0xf8, 0x8e, 0x60, 0xf6, 0xdb, 0x60, 0x56,
		0x27, 0x98, 0xad, 0x35, 0x98, 0x05, 0xee, 0xb0, 0xe9, 0x7e, 0x3e, 0xff, 0x59, 0x79, 0x57, 0xbd,
		0xfb, 0xb8, 0xfd, 0xb3, 0x71, 0x37, 0x7f, 0xf1, 0xd7, 0x63, 0x5f, 0xab, 0xbc, 0x6b, 0xdc, 0x7d,
		0x7c, 0xe2, 0x2f, 0xf5, 0xbb, 0x8f, 0xbf, 0xf9, 0x6f, 0xd4, 0xee, 0xde, 0x2e, 0x7c, 0x75, 0x72,
		0x7d, 0xf7, 0xa9, 0x1f, 0x54, 0x9f, 0xf8, 0xc1, 0xde, 0x53, 0x3f, 0xd8, 0x7b, 0xe2, 0x07, 0x4f,
		0x9a, 0xb4, 0xfb, 0xc4, 0x0f, 0x6a, 0x77, 0xbf, 0x16, 0xbe, 0xff, 0xf6, 0xf1, 0xaf, 0xd6, 0xef,
		0xb6, 0x7f, 0x3d, 0xf5, 0xb7, 0xc6, 0xdd, 0xaf, 0x8f, 0xdb, 0x84, 0xf6, 0xf5, 0x83, 0x76, 0xba,
		0x51, 0xf9, 0x6e, 0x44, 0xa2, 0x63, 0x85, 0x1a, 0xb5, 0xc5, 0xf5, 0x53, 0x48, 0xd4, 0xd3, 0x11,
		0x37, 0xda, 0x85, 0x5f, 0x43, 0xf5, 0x98, 0x91, 0x7c, 0x5e, 0xf5, 0x98, 0x39, 0x7c, 0x5e, 0xb5,
		0xc4, 0xb4, 0xe2, 0xf3, 0xaa, 0xa5, 0x66, 0x3a, 0x9f, 0x57, 0xbd, 0xd0, 0x40, 0x3e, 0xaf, 0xb2,
		0x48, 0x90, 0xe1, 0x3a, 0xaa, 0xe7, 0x68, 0x2f, 0xf6, 0xad, 0xa3, 0x7a, 0xc8, 0x2d, 0xa4, 0x48,
		0x66, 0x3e, 0x73, 0x3d, 0x15, 0x28, 0x6b, 0x95, 0xea, 0x3a, 0x18, 0xc9, 0x81, 0x1b, 0x8b, 0x20,
		0x09, 0x15, 0x1e, 0x61, 0x9d, 0xb3, 0x8f, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c, 0x95, 0x5c,
		0x95, 0x5c, 0x75, 0xc3, 0xb8, 0xaa, 0x1c, 0x08, 0xa5, 0xa5, 0xbe, 0x05, 0xe5, 0xab, 0x40, 0xbb,
		0x83, 0x9d, 0xd6, 0xb4, 0xab, 0x3e, 0x05, 0x09, 0x60, 0x48, 0xcd, 0x07, 0xb4, 0x75, 0xfc, 0x57,
		0xf3, 0xa8, 0x75, 0xe0, 0x77, 0xda, 0xa7, 0x5f, 0x0f, 0xfd, 0xce, 0x61, 0xb3, 0xdb, 0x3e, 0x46,
		0x8b, 0xae, 0xe9, 0x26, 0xf0, 0x04, 0xf2, 0x31, 0x11, 0xe8, 0xae, 0xfe, 0xf9, 0xd1, 0xfd, 0xe3,
		0xe8, 0xb4, 0xfb, 0xf5, 0xb0, 0xe3, 0x1f, 0xb5, 0xdb, 0x27, 0x0e, 0x0f, 0x6d, 0x58, 0x9b, 0x71,
		0x6d, 0x77, 0x5a, 0x7f, 0xb6, 0x8e, 0x9b, 0x5f, 0xdb, 0x1d, 0x8e, 0xea, 0xfa, 0x8c, 0x6a, 0xb3,
		0x4b, 0x47, 0x5d, 0xb7, 0x00, 0xdc, 0x3e, 0xfe, 0x7c, 0x78, 0xe0, 0xf0, 0x4c, 0x90, 0x7f, 0x7c,
		0x9d, 0x33, 0x1f, 0x01, 0xb3, 0x02, 0x41, 0x1d, 0x1c, 0x05, 0x89, 0x76, 0xaf, 0xc2, 0x81, 0x1c,
		0x4a, 0x31, 0xc0, 0x13, 0x07, 0x67, 0xcd, 0xa3, 0x36, 0xf8, 0x98, 0x39, 0xd4, 0x06, 0x97, 0x98,
		0x50, 0xd4, 0x06, 0x97, 0x9a, 0xe9, 0xd4, 0x06, 0x5f, 0x68, 0x20, 0xb5, 0x41, 0x8b, 0xb8, 0x2f,
		0xb0, 0x36, 0xa8, 0xe5, 0x95, 0xd0, 0xb2, 0x7f, 0x99, 0xd4, 0xab, 0x80, 0xda, 0x20, 0xd0, 0x36,
		0x02, 0xe7, 0x54, 0x65, 0x67, 0x04, 0x3a, 0x2a, 0x50, 0x61, 0x22, 0xfa, 0xa1, 0x1a, 0x40, 0xed,
		0x55, 0xe5, 0x69, 0xb7, 0xbf, 0xd9, 0x51, 0x3c, 0xed, 0xf6, 0xf9, 0xe6, 0xf1, 0xb4, 0xdb, 0x75,
		0xd4, 0x63, 0x78, 0xda, 0xed, 0x2b, 0xb8, 0x44, 0xe5, 0x43, 0xb5, 0x5a, 0x6f, 0x54, 0xab, 0x3b,
		0x8d, 0xbd, 0xc6, 0xce, 0x7e, 0xad, 0x56, 0xa9, 0x57, 0x78, 0xee, 0xad, 0xe5, 0xfc, 0x11, 0xcf,
		0x1a, 0xee, 0xdb, 0x80, 0x89, 0xa2, 0x4e, 0x14, 0xe8, 0x6f, 0xae, 0x04, 0x54, 0xb7, 0x72, 0xc3,
		0x40, 0xb2, 0x9f, 0x03, 0x31, 0x0c, 0xc6, 0xa3, 0x34, 0x55, 0xdd, 0xa1, 0xd6, 0xf6, 0xa8, 0x39,
		0xd4, 0xda, 0x96, 0x98, 0xde, 0xd4, 0xda, 0x96, 0x9a, 0xe9, 0xd4, 0xda, 0x5e, 0x68, 0x20, 0xb5,
		0x36, 0x8b, 0xf2, 0x1a, 0x16, 0x6d, 0x5a, 0x1e, 0x05, 0x59, 0xb4, 0xe9, 0xdf, 0x5e, 0x94, 0xb1,
		0xd6, 0x32, 0x67, 0xa7, 0x8c, 0x65, 0x7b, 0xb8, 0x9f, 0x75, 0x09, 0xca, 0x58, 0x2f, 0x76, 0x09,
		0x16, 0x6d, 0x5a, 0x17, 0x42, 0x86, 0x67, 0x0d, 0xc5, 0x2b, 0x98, 0xd8, 0xe9, 0x4c, 0x37, 0x47,
		0x86, 0x63, 0x2d, 0xf0, 0x04, 0xac, 0x87, 0xc6, 0x51, 0x30, 0x7a, 0xcc, 0x1c, 0x0a, 0x46, 0x4b,
		0x4c, 0x27, 0x0a, 0x46, 0x4b, 0xcd, 0x74, 0x0a, 0x46, 0x2f, 0x34, 0x90, 0x82, 0x91, 0x45, 0x19,
		0x04, 0xb0, 0x60, 0xd4, 0x0b, 0xc3, 0x91, 0x08, 0x14, 0xe2, 0xa6, 0xcd, 0x0a, 0xa9, 0x1c, 0x80,
		0x05, 0x86, 0x5d, 0xc8, 0x69, 0x2a, 0x15, 0xea, 0x60, 0x92, 0x8d, 0x41, 0x38, 0x90, 0x93, 0xf4,
		0xbf, 0x89, 0xab, 0x20, 0x9a, 0x1e, 0x3a, 0xe3, 0x85, 0x91, 0x50, 0xfd, 0x94, 0x28, 0xb9, 0x4a,
		0xe8, 0x1f, 0x61, 0x7c, 0xe9, 0x4a, 0x95, 0xe8, 0x40, 0xf5, 0x85, 0x37, 0x7f, 0x21, 0x59, 0xb8,
		0xe2, 0x45, 0x71, 0xa8, 0xc3, 0x7e, 0x38, 0x4a, 0x8a, 0x96, 0xd7, 0xbb, 0x88, 0xbc, 0x58, 0xf6,
		0xbc, 0x60, 0x28, 0xdd, 0x24, 0x18, 0xca, 0xa4, 0x68, 0x79, 0xe9, 0xd1, 0xcc, 0x49, 0xac, 0x85,
		0x1b, 0x85, 0x23, 0xd9, 0xbf, 0xf5, 0x94, 0x90, 0x17, 0xdf, 0x7a, 0x61, 0x9c, 0x14, 0x2d, 0x2f,
		0x18, 0x7c, 0x4f, 0xd1, 0x40, 0x2a, 0x37, 0x0a, 0x13, 0xed, 0xa5, 0x0c, 0x37, 0xc9, 0xde, 0xb2,
		0x73, 0x6e, 0x00, 0x7c, 0xdd, 0x49, 0x74, 0x3c, 0xee, 0x6b, 0x35, 0x0d, 0x42, 0xed, 0xa2, 0x13,
		0x8f, 0xb3, 0x0e, 0x6a, 0x4d, 0xfb, 0xc7, 0x9f, 0xfb, 0x9c, 0xcc, 0x5f, 0xf0, 0x4f, 0xf2, 0x0e,
		0x2c, 0x5a, 0xfe, 0xa7, 0x8b, 0xc8, 0xef, 0xc8, 0x9e, 0xdf, 0x1c, 0xca, 0xee, 0xa4, 0xff, 0xf2,
		0x86, 0xdf, 0x8a, 0xae, 0xeb, 0xdd, 0x58, 0x8b, 0x93, 0xb4, 0xf3, 0xfc, 0xe3, 0xbc, 0xf3, 0x8a,
		0x96, 0xdf, 0x1c, 0x7c, 0xef, 0xc8, 0x5e, 0x4b, 0x9d, 0x84, 0x89, 0xf6, 0x3b, 0x69, 0xcf, 0x65,
		0x6f, 0x7e, 0x37, 0xed, 0xb9, 0x37, 0x9b, 0x19, 0x07, 0x0c, 0xc6, 0x00, 0x67, 0xac, 0x2e, 0x55,
		0xf8, 0x43, 0xb9, 0x81, 0xd6, 0xb1, 0xec, 0x4d, 0x46, 0xc4, 0x78, 0x1c, 0xb8, 0x7f, 0xda, 0xb2,
		0x68, 0x9b, 0xe1, 0x68, 0x99, 0x63, 0xa7, 0x61, 0x33, 0x50, 0x52, 0x47, 0xa4, 0x94, 0x11, 0x33,
		0x55, 0x44, 0x4b, 0x11, 0x61, 0x53, 0x43, 0xd8, 0x94, 0x10, 0x36, 0x15, 0xdc, 0x6c, 0xde, 0x7a,
		0x20, 0x63, 0x8c, 0xb0, 0xb3, 0x00, 0x52, 0x78, 0x5a, 0xec, 0xa2, 0x89, 0x58, 0x8a, 0x6c, 0x85,
		0x8a, 0x2c, 0x3c, 0xbc, 0x62, 0xc3, 0x2c, 0x2a, 0xdc, 0xc2, 0xc3, 0x2e, 0x3c, 0xfc, 0xc2, 0xc3,
		0x30, 0x8e, 0x90, 0xb5, 0x05, 0xa4, 0xc8, 0xa2, 0xc0, 0x73, 0x61, 0xd0, 0x04, 0xfb, 0x5c, 0x8d,
		0xa6, 0x13, 0xcf, 0x44, 0xd4, 0x7b, 0x13, 0xc1, 0x5c, 0x0f, 0x73, 0xdd, 0x0b, 0x1c, 0x5c, 0x23,
		0xc3, 0xb6, 0x1d, 0xf0, 0x8d, 0x0e, 0xe3, 0xd6, 0xc0, 0xb9, 0x35, 0xb0, 0x6e, 0x0d, 0xbc, 0x63,
		0xc1, 0x3c, 0x18, 0xdc, 0x17, 0xa3, 0xf8, 0x15, 0x11, 0x60, 0xb7, 0xb0, 0xab, 0x3e, 0x2c, 0x64,
		0xc3, 0x0d, 0xcc, 0xca, 0x9b, 0x79, 0x15, 0x88, 0xac, 0x98, 0xc3, 0x3d, 0x59, 0xe1, 0x4a, 0x49,
		0x74, 0xd7, 0x74, 0xb2, 0xe7, 0x92, 0xb0, 0xc4, 0x17, 0xe5, 0xb1, 0xe9, 0xa3, 0xde, 0x48, 0xd2,
		0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0xd2, 0x4b, 0x64, 0x7d, 0x7c, 0x14, 0xd1, 0xb4, 0xae,
		0xc2, 0xb0, 0x94, 0xa3, 0x8d, 0x04, 0xf0, 0x26, 0xc3, 0x19, 0xe9, 0x6b, 0x62, 0xe9, 0x3b, 0xee,
		0xfc, 0x5a, 0x23, 0x52, 0x60, 0x03, 0x39, 0xb0, 0x8b, 0x24, 0xd8, 0x42, 0x16, 0xac, 0x23, 0x0d,
		0xd6, 0x91, 0x07, 0xeb, 0x48, 0x04, 0x26, 0x99, 0x00, 0x25, 0x15, 0xc5, 0xe8, 0xc2, 0x2a, 0x6a,
		0x0b, 0x71, 0x73, 0x2c, 0x95, 0xae, 0xd4, 0x91, 0x63, 0xe6, 0x14, 0xc5, 0xeb, 0xc0, 0x26, 0x62,
		0x9e, 0x9d, 0x31, 0xff, 0xc2, 0xc6, 0x9c, 0x2d, 0xf4, 0xb3, 0x35, 0x2c, 0xa3, 0x97, 0x0b, 0xe6,
		0x82, 0x9f, 0xbd, 0xb1, 0x60, 0xaf, 0x05, 0xe7, 0x0d, 0x58, 0x02, 0x47, 0xb3, 0x2e, 0x16, 0xdc,
		0xd0, 0xc5, 0x56, 0xec, 0x62, 0xf5, 0x5a, 0x6d, 0xaf, 0x46, 0x37, 0xdb, 0x2c, 0x2e, 0x8a, 0x6f,
		0xdd, 0xf9, 0x1b, 0xf6, 0x97, 0xa5, 0x61, 0x1c, 0x78, 0x25, 0xdc, 0x42, 0x4a, 0x81, 0xba, 0x22,
		0xce, 0x12, 0x54, 0xa1, 0x2e, 0xf8, 0x9a, 0x93, 0x91, 0xba, 0xe0, 0xab, 0x7a, 0x0e, 0x75, 0xc1,
		0x15, 0x1b, 0x4c, 0x5d, 0x70, 0x8d, 0x13, 0x31, 0xcb, 0x74, 0xc1, 0x0f, 0x16, 0xc8, 0x82, 0x35,
		0xca, 0x82, 0x2f, 0x7c, 0x51, 0x16, 0xa4, 0x66, 0x41, 0x59, 0x70, 0x03, 0xd1, 0x68, 0xd6, 0xc5,
		0x28, 0x0b, 0xae, 0xdc, 0xc5, 0x76, 0x6b, 0x14, 0x05, 0x37, 0x8c, 0x88, 0xe2, 0x5b, 0x47, 0x51,
		0xd0, 0xda, 0x20, 0x9e, 0x29, 0x6d, 0xd7, 0xd3, 0xe8, 0x62, 0x83, 0x2a, 0x98, 0xd9, 0x4a, 0x59,
		0xf0, 0x39, 0xe6, 0x51, 0x16, 0x7c, 0xc5, 0xd9, 0x48, 0x59, 0xf0, 0x55, 0x3d, 0x87, 0xb2, 0xe0,
		0x8a, 0x0d, 0xa6, 0x2c, 0xb8, 0xc6, 0x89, 0x98, 0x45, 0xb2, 0x60, 0x4f, 0xaa, 0x20, 0xbe, 0xb5,
		0x40, 0x17, 0xdc, 0x07, 0x36, 0xf1, 0x48, 0xa8, 0x8b, 0x74, 0x63, 0x2e, 0x85, 0xc1, 0x97, 0xaa,
		0x16, 0x14, 0x06, 0x57, 0xae, 0x5a, 0x54, 0xa8, 0x59, 0x6c, 0x18, 0x1e, 0xcd, 0xba, 0x18, 0x85,
		0xc1, 0x95, 0xbb, 0x18, 0xd7, 0x0b, 0x6e, 0x20, 0x19, 0xc5, 0xb7, 0x8e, 0xd2, 0xa0, 0xb5, 0x61,
		0xdc, 0x11, 0x37, 0x5a, 0xa8, 0x81, 0x18, 0xe0, 0x0b, 0x83, 0x85, 0xa5, 0x94, 0x05, 0x9f, 0x63,
		0x1e, 0x65, 0xc1, 0x57, 0x9c, 0x8b, 0x94, 0x05, 0x5f, 0xd5, 0x73, 0x28, 0x0b, 0xae, 0xd8, 0x60,
		0xca, 0x82, 0x6b, 0x9c, 0x86, 0xd9, 0x24, 0x0b, 0xc2, 0x15, 0x4c, 0x7b, 0x0a, 0xc6, 0x41, 0x0a,
		0xa8, 0x91, 0xd4, 0x3e, 0x67, 0x0c, 0xc3, 0x68, 0x92, 0x79, 0x06, 0x23, 0x7c, 0x52, 0x5b, 0x58,
		0x4a, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52, 0x4b, 0x52,
		0x4b, 0x52, 0x4b, 0xa7, 0x98, 0x1d, 0xc3, 0x28, 0x88, 0xb5, 0xb4, 0x81, 0xd3, 0xe6, 0x86, 0x92,
		0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92, 0xd2, 0x92,
		0xd2, 0xd2, 0x29, 0x66, 0xc7, 0x50, 0xc7, 0x81, 0x4a, 0xa4, 0x96, 0xd7, 0x16, 0xec, 0x4b, 0x7a,
		0x60, 0x2b, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d, 0x89, 0x2d,
		0x89, 0x2d, 0x89, 0x2d, 0x2d, 0x02, 0x75, 0x51, 0xa7, 0xa9, 0x54, 0xa8, 0x03, 0x2d, 0x43, 0xcc,
		0x0d, 0x50, 0x4e, 0xd2, 0xff, 0x26, 0xae, 0x82, 0x68, 0x5a, 0x80, 0xd2, 0x0b, 0x23, 0xa1, 0xfa,
		0x29, 0x51, 0x74, 0x95, 0xd0, 0x3f, 0xc2, 0xf8, 0xd2, 0x95, 0x2a, 0xd1, 0x81, 0xea, 0x0b, 0x6f,
		0xfe, 0x42, 0xb2, 0x70, 0xc5, 0x8b, 0xe2, 0x50, 0x87, 0xfd, 0x70, 0x94, 0x14, 0x2d, 0xaf, 0x77,
		0x11, 0x79, 0xb1, 0xec, 0x79, 0xc1, 0x50, 0xba, 0x49, 0x30, 0x94, 0x49, 0xd1, 0xf2, 0x64, 0x74,
		0x5d, 0x77, 0x93, 0x58, 0x0b, 0x37, 0x0a, 0x47, 0xb2, 0x7f, 0xeb, 0x29, 0x21, 0x2f, 0xbe, 0xf5,
		0xc2, 0x38, 0x29, 0x5a, 0x5e, 0x30, 0xf8, 0x9e, 0xa2, 0x95, 0x54, 0x6e, 0x14, 0x26, 0xda, 0x8b,
		0xc3, 0xb1, 0x16, 0x49, 0xf6, 0xe6, 0x8d, 0xd5, 0xa5, 0x0a, 0x7f, 0x28, 0x37, 0xd0, 0x3a, 0x96,
		0xbd, 0xf4, 0x0f, 0x0b, 0x97, 0x3c, 0xc4, 0xfa, 0x87, 0x59, 0xd7, 0xeb, 0x78, 0xdc, 0xd7, 0x6a,
		0x1a, 0x19, 0xdb, 0x45, 0xcf, 0x1f, 0x67, 0xbd, 0xda, 0x9a, 0x76, 0xaa, 0x3f, 0xf7, 0x39, 0x99,
		0xbf, 0xe0, 0x9f, 0xe4, 0xbd, 0x5e, 0xb4, 0xfc, 0x4f, 0x17, 0x91, 0xdf, 0x91, 0x3d, 0xbf, 0x39,
		0x94, 0xdd, 0x49, 0xa7, 0xe7, 0x0d, 0xbf, 0x15, 0x5d, 0xd7, 0xbb, 0xb1, 0x16, 0x27, 0x69, 0x8f,
		0xfb, 0xc7, 0x79, 0x8f, 0x17, 0x2d, 0xbf, 0x39, 0xf8, 0xde, 0x91, 0xbd, 0x96, 0x3a, 0x09, 0x13,
		0xed, 0x77, 0xd2, 0xee, 0xce, 0xde, 0xfc, 0xd3, 0xac, 0x6f, 0x9b, 0x45, 0x6f, 0x2f, 0x5c, 0xf1,
		0xbb, 0x69, 0x67, 0xb3, 0x68, 0x29, 0xb0, 0x25, 0x20, 0x11, 0x72, 0x42, 0xfa, 0x11, 0x4f, 0x21,
		0x76, 0x8e, 0x64, 0xa2, 0x27, 0x13, 0x1a, 0x2a, 0x5e, 0x3b, 0x5f, 0xa4, 0x3a, 0x1c, 0x89, 0x09,
		0x85, 0x4f, 0xb0, 0x52, 0x78, 0xe7, 0x4b, 0x70, 0xf3, 0xc0, 0xb2, 0xca, 0x87, 0x6a, 0xb5, 0xde,
		0xa8, 0x56, 0x77, 0x1a, 0x7b, 0x8d, 0x9d, 0xfd, 0x5a, 0xad, 0x52, 0xaf, 0x00, 0xed, 0x98, 0x73,
		0xda, 0xf1, 0x40, 0xc4, 0x62, 0xf0, 0x69, 0x32, 0xf5, 0xd4, 0x78, 0x34, 0xa2, 0x47, 0xe2, 0x73,
		0x95, 0xf5, 0xe7, 0x28, 0x0e, 0x54, 0x35, 0xeb, 0xb5, 0x63, 0x25, 0x18, 0x7c, 0xc4, 0x3c, 0xfa,
		0x9b, 0xb5, 0xc0, 0x70, 0x94, 0x43, 0x8b, 0x6e, 0xeb, 0x16, 0xd5, 0x00, 0x62, 0xd8, 0x1a, 0xc4,
		0x2e, 0xb3, 0xa1, 0xca, 0x5c, 0x80, 0x30, 0x73, 0x67, 0x43, 0x21, 0x29, 0x4f, 0x7d, 0x26, 0xbe,
		0xef, 0xca, 0xc1, 0x96, 0x50, 0x83, 0x28, 0x94, 0x4a, 0x6f, 0xf5, 0xc3, 0x51, 0x18, 0x1b, 0x72,
		0x24, 0x8c, 0xbc, 0x07, 0x27, 0xcf, 0x81, 0xce, 0x6b, 0x30, 0xf2, 0x18, 0x53, 0xee, 0x03, 0x82,
		0xe4, 0x56, 0x23, 0xb8, 0x41, 0xb8, 0xb6, 0x0e, 0xa6, 0xcd, 0x80, 0x72, 0xf9, 0x90, 0x58, 0xee,
		0x1d, 0x4b, 0x8e, 0x1e, 0xa6, 0xa3, 0x86, 0xa5, 0xd1, 0xc2, 0x40, 0x9c, 0xb0, 0x28, 0x3e, 0x94,
		0x1b, 0x19, 0xca, 0xf3, 0xcf, 0x72, 0xee, 0x54, 0x52, 0x04, 0x30, 0xe5, 0xf9, 0xb6, 0x79, 0x7c,
		0x89, 0xae, 0x6e, 0x83, 0x8b, 0x97, 0xe3, 0xdb, 0xab, 0xf7, 0xb4, 0x12, 0xbc, 0xcc, 0x79, 0x38,
		0x93, 0xe2, 0xf2, 0x96, 0x22, 0xdd, 0x17, 0x2d, 0x98, 0xbd, 0x7f, 0x49, 0x71, 0x25, 0x5f, 0x29,
		0x54, 0xd2, 0xed, 0xca, 0x5e, 0xc0, 0x6b, 0x62, 0x41, 0xae, 0xd9, 0x05, 0xb6, 0xa6, 0x16, 0xcc,
		0x1a, 0x5f, 0x00, 0x6b, 0x7c, 0x41, 0xab, 0xf1, 0x05, 0xaa, 0xeb, 0xc5, 0x78, 0x0e, 0x64, 0xb9,
		0x32, 0x9e, 0x33, 0x4d, 0x16, 0x4a, 0x77, 0x9c, 0x3c, 0x5c, 0x18, 0x49, 0x56, 0x4a, 0x06, 0x00,
		0x63, 0x40, 0x60, 0x12, 0x10, 0x30, 0x80, 0xc1, 0x34, 0x40, 0xc0, 0x00, 0x05, 0x0c, 0x60, 0xc0,
		0x00, 0xc7, 0x66, 0x88, 0x67, 0x65, 0x03, 0xca, 0x2c, 0xb0, 0x98, 0xf3, 0xb7, 0x19, 0x7c, 0x31,
		0xe5, 0x6b, 0x66, 0x60, 0xc6, 0x38, 0xdc, 0x20, 0xc0, 0x0e, 0x16, 0xfc, 0xa0, 0xc0, 0x10, 0x1c,
		0x1c, 0xc1, 0xc1, 0x12, 0x1c, 0x3c, 0x99, 0x81, 0x29, 0x43, 0x70, 0x65, 0x1c, 0xb6, 0x0a, 0x03,
		0xb2, 0x15, 0x1d, 0xc6, 0xfd, 0x34, 0x8f, 0x5e, 0x26, 0x17, 0x98, 0xcc, 0xc3, 0x99, 0xe1, 0x35,
		0xec, 0x30, 0xfb, 0xe1, 0x91, 0xf6, 0xbd, 0x63, 0xee, 0x6f, 0x47, 0xdb, 0xc7, 0x0e, 0xbb, 0x5f,
		0x1d, 0x76, 0x5f, 0x3a, 0xec, 0xfe, 0xf3, 0xcd, 0x5e, 0x12, 0x0d, 0xb3, 0x6f, 0xbc, 0x88, 0x3b,
		0x23, 0x11, 0x0c, 0x63, 0x31, 0x44, 0x08, 0x3a, 0x79, 0xd6, 0xd5, 0x00, 0xb0, 0xe5, 0x64, 0xfa,
		0x0c, 0xf9, 0xfd, 0xfb, 0x6c, 0x3b, 0xab, 0x97, 0x01, 0xf9, 0xa6, 0x2e, 0x16, 0x36, 0x98, 0x79,
		0xe5, 0x6b, 0x75, 0x71, 0x38, 0x5d, 0x61, 0x11, 0x69, 0x1d, 0x69, 0x1d, 0x69, 0x1d, 0x69, 0x1d,
		0x69, 0x1d, 0x69, 0x1d, 0x69, 0x9d, 0x95, 0xb4, 0xae, 0xc0, 0x72, 0x32, 0xbb, 0xd2, 0x07, 0x63,
		0xba, 0x1b, 0x0b, 0x87, 0xd8, 0xe5, 0x06, 0x91, 0xd7, 0x91, 0xd7, 0x91, 0xd7, 0x91, 0xd7, 0x91,
		0xd7, 0x91, 0xd7, 0x91, 0xd7, 0x59, 0xc9, 0xeb, 0x72, 0x28, 0x27, 0xad, 0x2b, 0x7d, 0x2c, 0xb2,
		0xe3, 0xff, 0x60, 0x48, 0x1d, 0xc2, 0x69, 0x84, 0x86, 0x17, 0x14, 0x91, 0xd2, 0x91, 0xd2, 0x91,
		0xd2, 0x91, 0xd2, 0x91, 0xd2, 0x99, 0x5f, 0xa0, 0x54, 0x18, 0x92, 0x1e, 0xc3, 0x29, 0xd5, 0x40,
		0xe0, 0x14, 0x60, 0xb8, 0xdf, 0xdd, 0x77, 0x6f, 0x1b, 0xca, 0xd9, 0xa5, 0x50, 0xa5, 0x3e, 0xe0,
		0x4a, 0x7b, 0x20, 0x96, 0xf2, 0xc0, 0x2e, 0xdd, 0x81, 0x5a, 0xaa, 0x03, 0xbe, 0x34, 0x07, 0x7c,
		0x29, 0x0e, 0xf8, 0xd2, 0x1b, 0x3c, 0x95, 0x1a, 0x52, 0x63, 0x01, 0xd6, 0x5a, 0x10, 0x35, 0x97,
		0xc7, 0xb4, 0x97, 0x7f, 0xf8, 0x2f, 0xa5, 0x14, 0x89, 0xd0, 0x49, 0xd1, 0x9a, 0x2a, 0x35, 0x19,
		0xcd, 0xe0, 0x81, 0xb1, 0x28, 0x4e, 0x09, 0xb2, 0x82, 0x7e, 0xc1, 0x1b, 0x11, 0x56, 0xd2, 0x93,
		0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x92, 0x8e, 0x96, 0x1e, 0xb7, 0xc6, 0x52,
		0xe9, 0xbd, 0x5d, 0x40, 0x36, 0x8a, 0x44, 0x46, 0x3b, 0x81, 0xba, 0x98, 0xf4, 0xd6, 0x19, 0x54,
		0x0c, 0x00, 0x2c, 0x43, 0xf6, 0x45, 0x2a, 0xdc, 0x12, 0xc4, 0xe0, 0x85, 0x7d, 0xff, 0x0a, 0x46,
		0x63, 0x01, 0x6c, 0xdf, 0xe7, 0x38, 0xe8, 0x6b, 0x19, 0xaa, 0x03, 0x79, 0x21, 0xb3, 0x53, 0xbd,
		0x59, 0x9c, 0xfb, 0x77, 0x5c, 0x22, 0xb8, 0xa1, 0x4b, 0xbc, 0xd0, 0x25, 0xaa, 0xbb, 0xfb, 0xd5,
		0xfd, 0x7a, 0x63, 0x77, 0xbf, 0x46, 0xdf, 0xb0, 0x9b, 0x90, 0xe1, 0x59, 0x73, 0x4e, 0x91, 0x08,
		0x25, 0x76, 0x3a, 0xfd, 0xf0, 0xea, 0x6a, 0xac, 0xa4, 0xbe, 0x45, 0x7d, 0x84, 0x39, 0x6f, 0x20,
		0x85, 0xa3, 0xc7, 0xcc, 0xa1, 0x70, 0xb4, 0xc4, 0x94, 0xa2, 0x70, 0xb4, 0xd4, 0x4c, 0xa7, 0x70,
		0xf4, 0x42, 0x03, 0x29, 0x1c, 0x59, 0x94, 0x49, 0xf0, 0x39, 0xe6, 0x33, 0x60, 0xd0, 0xc2, 0xe7,
		0x98, 0x39, 0xaf, 0x90, 0x22, 0x29, 0xda, 0xb7, 0x7c, 0x94, 0x89, 0xc9, 0x52, 0x61, 0xce, 0x8e,
		0x58, 0xf0, 0x49, 0x90, 0x33, 0x24, 0xc8, 0x4b, 0xc9, 0x4b, 0xc9, 0x4b, 0xc9, 0x4b, 0xc9, 0x4b,
		0xc9, 0x4b, 0x4b, 0x8f, 0x5b, 0x32, 0x72, 0x83, 0xc1, 0x20, 0x16, 0x49, 0x82, 0x48, 0x4d, 0xf7,
		0x81, 0x6c, 0x9a, 0x8e, 0x21, 0x1f, 0x6a, 0xfe, 0xf6, 0xcc, 0xba, 0xae, 0x02, 0xce, 0xad, 0x85,
		0x39, 0xf6, 0x01, 0xd0, 0xb6, 0x93, 0x40, 0x6b, 0x11, 0x2b, 0xb8, 0xe9, 0x56, 0x18, 0xf8, 0xf6,
		0xed, 0xd9, 0x8e, 0xbb, 0x7f, 0xfe, 0xeb, 0xac, 0xe2, 0xee, 0x9f, 0x67, 0xcd, 0x4a, 0xfa, 0x96,
		0xb5, 0x77, 0xcf, 0x76, 0xdc, 0x6a, 0xde, 0xae, 0x9d, 0xed, 0xb8, 0xb5, 0xf3, 0xed, 0xbf, 0xff,
		0x7e, 0xbf, 0xfd, 0x73, 0xef, 0x6e, 0xf9, 0x1f, 0x3a, 0x70, 0x5d, 0x70, 0x8e, 0x38, 0x65, 0xda,
		0xdd, 0xd6, 0x7f, 0xe1, 0xe7, 0xcd, 0xff, 0xca, 0x9c, 0x38, 0xff, 0x01, 0x9c, 0x39, 0x58, 0x8f,
		0x15, 0xdf, 0x11, 0xcc, 0x7e, 0x1b, 0xcc, 0xea, 0x04, 0xb3, 0xb5, 0x06, 0xb3, 0xc0, 0x1d, 0x36,
		0xdd, 0xcf, 0xe7, 0x3f, 0x2b, 0xef, 0xaa, 0x77, 0x1f, 0xb7, 0x7f, 0x36, 0xee, 0xe6, 0x2f, 0xfe,
		0x7a, 0xec, 0x6b, 0x95, 0x77, 0x8d, 0xbb, 0x8f, 0x4f, 0xfc, 0xa5, 0x7e, 0xf7, 0xf1, 0x37, 0xff,
		0x8d, 0xda, 0xdd, 0xdb, 0x85, 0xaf, 0x4e, 0xae, 0xef, 0x3e, 0xf5, 0x83, 0xea, 0x13, 0x3f, 0xd8,
		0x7b, 0xea, 0x07, 0x7b, 0x4f, 0xfc, 0xe0, 0x49, 0x93, 0x76, 0x9f, 0xf8, 0x41, 0xed, 0xee, 0xd7,
		0xc2, 0xf7, 0xdf, 0x3e, 0xfe, 0xd5, 0xfa, 0xdd, 0xf6, 0xaf, 0xa7, 0xfe, 0xd6, 0xb8, 0xfb, 0xf5,
		0x71, 0x9b, 0xd0, 0xbe, 0x7e, 0xd0, 0x4e, 0x37, 0x2a, 0xdf, 0x8d, 0x48, 0x74, 0xac, 0x50, 0xa3,
		0xb6, 0xb8, 0x7e, 0x0a, 0x89, 0x7a, 0x3a, 0xe2, 0x46, 0xbb, 0xf0, 0x6b, 0xa8, 0x1e, 0x33, 0x92,
		0xcf, 0xab, 0x1e, 0x33, 0x87, 0xcf, 0xab, 0x96, 0x98, 0x56, 0x7c, 0x5e, 0xb5, 0xd4, 0x4c, 0xe7,
		0xf3, 0xaa, 0x17, 0x1a, 0xc8, 0xe7, 0x55, 0x16, 0x09, 0x32, 0x5c, 0x47, 0xf5, 0x1c, 0xed, 0xc5,
		0xbe, 0x75, 0x54, 0x0f, 0xb9, 0x85, 0x14, 0xc9, 0xcc, 0x67, 0xae, 0xa7, 0x02, 0x65, 0xad, 0x52,
		0x5d, 0x07, 0x23, 0x39, 0x70, 0x63, 0x11, 0x24, 0xa1, 0xc2, 0x23, 0xac, 0x73, 0xf6, 0x91, 0xab,
		0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x92, 0xab, 0x6e, 0x18, 0x57, 0x95, 0x03, 0xa1,
		0xb4, 0xd4, 0xb7, 0xa0, 0x7c, 0x15, 0x68, 0x77, 0xb0, 0xd3, 0x9a, 0x76, 0xd5, 0xa7, 0x20, 0x01,
		0x0c, 0xa9, 0xf9, 0x80, 0xb6, 0x8e, 0xff, 0x6a, 0x1e, 0xb5, 0x0e, 0xfc, 0x4e, 0xfb, 0xf4, 0xeb,
		0xa1, 0xdf, 0x39, 0x6c, 0x76, 0xdb, 0xc7, 0x68, 0xd1, 0x35, 0xdd, 0x04, 0x9e, 0x40, 0x3e, 0x26,
		0x02, 0xdd, 0xd5, 0x3f, 0x3f, 0xba, 0x7f, 0x1c, 0x9d, 0x76, 0xbf, 0x1e, 0x76, 0xfc, 0xa3, 0x76,
		0xfb, 0xc4, 0xe1, 0xa1, 0x0d, 0x6b, 0x33, 0xae, 0xed, 0x4e, 0xeb, 0xcf, 0xd6, 0x71, 0xf3, 0x6b,
		0xbb, 0xc3, 0x51, 0x5d, 0x9f, 0x51, 0x6d, 0x76, 0xe9, 0xa8, 0xeb, 0x16, 0x80, 0xdb, 0xc7, 0x9f,
		0x0f, 0x0f, 0x1c, 0x9e, 0x09, 0xf2, 0x8f, 0xaf, 0x73, 0xe6, 0x23, 0x60, 0x56, 0x20, 0xa8, 0x83,
		0xa3, 0x20, 0xd1, 0xee, 0x55, 0x38, 0x90, 0x43, 0x29, 0x06, 0x78, 0xe2, 0xe0, 0xac, 0x79, 0xd4,
		0x06, 0x1f, 0x33, 0x87, 0xda, 0xe0, 0x12, 0x13, 0x8a, 0xda, 0xe0, 0x52, 0x33, 0x9d, 0xda, 0xe0,
		0x0b, 0x0d, 0xa4, 0x36, 0x68, 0x11, 0xf7, 0x05, 0xd6, 0x06, 0xb5, 0xbc, 0x12, 0x5a, 0xf6, 0x2f,
		0x93, 0x7a, 0x15, 0x50, 0x1b, 0x04, 0xda, 0x46, 0xe0, 0x9c, 0xaa, 0xec, 0x8c, 0x40, 0x47, 0x05,
		0x2a, 0x4c, 0x44, 0x3f, 0x54, 0x03, 0xa8, 0xbd, 0xaa, 0x3c, 0xed, 0xf6, 0x37, 0x3b, 0x8a, 0xa7,
		0xdd, 0x3e, 0xdf, 0x3c, 0x9e, 0x76, 0xbb, 0x8e, 0x7a, 0x0c, 0x4f, 0xbb, 0x7d, 0x05, 0x97, 0xa8,
		0x7c, 0xa8, 0x56, 0xeb, 0x8d, 0x6a, 0x75, 0xa7, 0xb1, 0xd7, 0xd8, 0xd9, 0xaf, 0xd5, 0x2a, 0xf5,
		0x0a, 0xcf, 0xbd, 0xb5, 0x9c, 0x3f, 0xe2, 0x59, 0xc3, 0x7d, 0x1b, 0x30, 0x51, 0xd4, 0xc9, 0xeb,
		0x8a, 0xc3, 0xa9, 0x5b, 0xb9, 0x61, 0x20, 0xd9, 0xcf, 0x81, 0x18, 0x06, 0xe3, 0x51, 0x9a, 0xaa,
		0xee, 0x50, 0x6b, 0x7b, 0xd4, 0x1c, 0x6a, 0x6d, 0x4b, 0x4c, 0x6f, 0x6a, 0x6d, 0x4b, 0xcd, 0x74,
		0x6a, 0x6d, 0x2f, 0x34, 0x90, 0x5a, 0x9b, 0x45, 0x79, 0x0d, 0x8b, 0x36, 0x2d, 0x8f, 0x82, 0x2c,
		0xda, 0xf4, 0x6f, 0x2f, 0xca, 0x58, 0x6b, 0x99, 0xb3, 0x53, 0xc6, 0xb2, 0x3d, 0xdc, 0xcf, 0xba,
		0x04, 0x65, 0xac, 0x17, 0xbb, 0x04, 0x8b, 0x36, 0xad, 0x0b, 0x21, 0xc3, 0xb3, 0x86, 0xe2, 0x15,
		0x4c, 0xec, 0x74, 0xa6, 0x9b, 0x23, 0xc3, 0xb1, 0x16, 0x78, 0x02, 0xd6, 0x43, 0xe3, 0x28, 0x18,
		0x3d, 0x66, 0x0e, 0x05, 0xa3, 0x25, 0xa6, 0x13, 0x05, 0xa3, 0xa5, 0x66, 0x3a, 0x05, 0xa3, 0x17,
		0x1a, 0x48, 0xc1, 0xc8, 0xa2, 0x0c, 0x02, 0x58, 0x30, 0xea, 0x85, 0xe1, 0x48, 0x04, 0x0a, 0x71,
		0xd3, 0x66, 0x85, 0x54, 0x0e, 0xc0, 0x02, 0xc3, 0x2e, 0xe4, 0x34, 0x95, 0x0a, 0x75, 0x30, 0xc9,
		0xc6, 0x20, 0x1c, 0xc8, 0x49, 0xfa, 0xdf, 0xc4, 0x55, 0x10, 0x4d, 0x0f, 0x9d, 0xf1, 0xc2, 0x48,
		0xa8, 0x7e, 0x4a, 0x94, 0x5c, 0x25, 0xf4, 0x8f, 0x30, 0xbe, 0x74, 0xa5, 0x4a, 0x74, 0xa0, 0xfa,
		0xc2, 0x9b, 0xbf, 0x90, 0x2c, 0x5c, 0xf1, 0xa2, 0x38, 0xd4, 0x61, 0x3f, 0x1c, 0x25, 0x45, 0xcb,
		0xeb, 0x5d, 0x44, 0x5e, 0x2c, 0x7b, 0x5e, 0x30, 0x94, 0x6e, 0x12, 0x0c, 0x65, 0x52, 0xb4, 0xbc,
		0xf4, 0x68, 0xe6, 0x24, 0xd6, 0xc2, 0x8d, 0xc2, 0x91, 0xec, 0xdf, 0x7a, 0x4a, 0xc8, 0x8b, 0x6f,
		0xbd, 0x30, 0x4e, 0x8a, 0x96, 0x17, 0x0c, 0xbe, 0xa7, 0x68, 0x20, 0x95, 0x1b, 0xc5, 0xc2, 0x4b,
		0x09, 0x6e, 0x92, 0xbd, 0x65, 0xc7, 0xdc, 0x00, 0xb8, 0xba, 0x93, 0xe8, 0x78, 0xdc, 0xd7, 0x6a,
		0x1a, 0x83, 0xda, 0x45, 0x1f, 0x1e, 0x67, 0xfd, 0xd3, 0x9a, 0x76, 0x8f, 0x3f, 0xf7, 0x39, 0x99,
		0xbf, 0xe0, 0x9f, 0xe4, 0xfd, 0x57, 0xb4, 0xfc, 0x4f, 0x17, 0x91, 0xdf, 0x91, 0x3d, 0xbf, 0x39,
		0x94, 0xdd, 0x49, 0xf7, 0xe5, 0x0d, 0xbf, 0x15, 0x5d, 0xd7, 0xbb, 0xb1, 0x16, 0x27, 0x69, 0xdf,
		0xf9, 0xc7, 0x79, 0xdf, 0x15, 0x2d, 0xbf, 0x39, 0xf8, 0xde, 0x91, 0xbd, 0x96, 0x3a, 0x89, 0x85,
		0xdf, 0x49, 0x3b, 0x2e, 0x7b, 0xf3, 0xbb, 0x69, 0xc7, 0xbd, 0xd9, 0xcc, 0x28, 0x60, 0x30, 0x02,
		0x38, 0x63, 0x75, 0xa9, 0xc2, 0x1f, 0xca, 0x0d, 0xb4, 0x8e, 0x65, 0x6f, 0x32, 0x22, 0xc6, 0xa3,
		0xc0, 0xfd, 0xb3, 0x96, 0x45, 0xdb, 0x0c, 0xc7, 0xca, 0x1c, 0x39, 0x0d, 0x9b, 0x81, 0x92, 0x38,
		0x22, 0x25, 0x8c, 0x98, 0x89, 0x22, 0x5a, 0x82, 0x08, 0x9b, 0x18, 0xc2, 0x26, 0x84, 0xb0, 0x89,
		0xe0, 0x66, 0xb3, 0xd6, 0x03, 0x19, 0x63, 0x84, 0x9d, 0x05, 0x90, 0xc2, 0x53, 0x62, 0x17, 0x4d,
		0xc4, 0xd2, 0x63, 0x2b, 0xd4, 0x63, 0xe1, 0xe1, 0x15, 0x1b, 0x66, 0x51, 0xe1, 0x16, 0x1e, 0x76,
		0xe1, 0xe1, 0x17, 0x1e, 0x86, 0x71, 0x64, 0xac, 0x2d, 0x20, 0x3d, 0x16, 0x05, 0x9e, 0x0b, 0x83,
		0x26, 0xd8, 0xe7, 0x6a, 0x34, 0x95, 0x78, 0x26, 0xa2, 0xde, 0x9b, 0x08, 0xe6, 0x7a, 0x98, 0xab,
		0x5e, 0xe0, 0xe0, 0x1a, 0x19, 0xb6, 0xed, 0x80, 0x6f, 0x74, 0x18, 0xb7, 0x06, 0xce, 0xad, 0x81,
		0x75, 0x6b, 0xe0, 0x1d, 0x0b, 0xe6, 0xc1, 0xe0, 0xbe, 0x18, 0xc5, 0xaf, 0x88, 0x00, 0xbb, 0x85,
		0x5d, 0xf3, 0x61, 0x21, 0x1b, 0x6e, 0x60, 0xd6, 0xdd, 0xcc, 0x6b, 0x40, 0x64, 0xa5, 0x1c, 0xee,
		0xc9, 0x0a, 0xd7, 0x49, 0xa2, 0xbb, 0xa6, 0x93, 0x3d, 0x96, 0x84, 0x25, 0xbe, 0x28, 0x4f, 0x4d,
		0x1f, 0xf5, 0x46, 0x92, 0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x92, 0x5e, 0x22, 0xeb, 0xe3,
		0xa3, 0x88, 0xa6, 0x75, 0x15, 0x86, 0xa5, 0x1c, 0x6d, 0x24, 0x80, 0xb7, 0x18, 0xce, 0x48, 0x5f,
		0x13, 0x4b, 0xdf, 0x71, 0xdf, 0xd7, 0x1a, 0x91, 0x02, 0x1b, 0xc8, 0x81, 0x5d, 0x24, 0xc1, 0x16,
		0xb2, 0x60, 0x1d, 0x69, 0xb0, 0x8e, 0x3c, 0x58, 0x47, 0x22, 0x30, 0xc9, 0x04, 0x28, 0xa9, 0x28,
		0x46, 0x17, 0x56, 0x51, 0x5b, 0x88, 0x9b, 0x63, 0xa9, 0x74, 0xa5, 0x8e, 0x1c, 0x33, 0xa7, 0x28,
		0x5e, 0x07, 0x36, 0x11, 0xf3, 0xe4, 0x8c, 0xf9, 0x17, 0x36, 0xe6, 0x6c, 0xa1, 0x9f, 0xac, 0x61,
		0x19, 0xbd, 0x5c, 0x30, 0x17, 0xfc, 0xe4, 0x8d, 0x05, 0x7b, 0x2d, 0x38, 0x6d, 0xc0, 0x12, 0x38,
		0x9a, 0x75, 0xb1, 0xe0, 0x86, 0x2e, 0xb6, 0x62, 0x17, 0xab, 0xd7, 0x6a, 0x7b, 0x35, 0xba, 0xd9,
		0x66, 0x71, 0x51, 0x7c, 0xeb, 0xce, 0xdf, 0xb0, 0xbf, 0x2c, 0x0d, 0xe3, 0xc0, 0x2b, 0xe1, 0x16,
		0x52, 0x0a, 0xd4, 0x15, 0x71, 0x96, 0xa0, 0x0a, 0x75, 0xc1, 0xd7, 0x9c, 0x8c, 0xd4, 0x05, 0x5f,
		0xd5, 0x73, 0xa8, 0x0b, 0xae, 0xd8, 0x60, 0xea, 0x82, 0x6b, 0x9c, 0x88, 0x59, 0xa6, 0x0b, 0x7e,
		0xb0, 0x40, 0x16, 0xac, 0x51, 0x16, 0x7c, 0xe1, 0x8b, 0xb2, 0x20, 0x35, 0x0b, 0xca, 0x82, 0x1b,
		0x88, 0x46, 0xb3, 0x2e, 0x46, 0x59, 0x70, 0xe5, 0x2e, 0xb6, 0x5b, 0xa3, 0x28, 0xb8, 0x61, 0x44,
		0x14, 0xdf, 0x3a, 0x8a, 0x82, 0xd6, 0x06, 0xf1, 0x4c, 0x69, 0xbb, 0x9e, 0x46, 0x17, 0x1b, 0x54,
		0xc1, 0xcc, 0x56, 0xca, 0x82, 0xcf, 0x31, 0x8f, 0xb2, 0xe0, 0x2b, 0xce, 0x46, 0xca, 0x82, 0xaf,
		0xea, 0x39, 0x94, 0x05, 0x57, 0x6c, 0x30, 0x65, 0xc1, 0x35, 0x4e, 0xc4, 0x2c, 0x92, 0x05, 0x7b,
		0x52, 0x05, 0xf1, 0xad, 0x05, 0xba, 0xe0, 0x3e, 0xb0, 0x89, 0x47, 0x42, 0x5d, 0xa4, 0x1b, 0x73,
		0x29, 0x0c, 0xbe, 0x54, 0xb5, 0xa0, 0x30, 0xb8, 0x72, 0xd5, 0xa2, 0x42, 0xcd, 0x62, 0xc3, 0xf0,
		0x68, 0xd6, 0xc5, 0x28, 0x0c, 0xae, 0xdc, 0xc5, 0xb8, 0x5e, 0x70, 0x03, 0xc9, 0x28, 0xbe, 0x75,
		0x94, 0x06, 0xad, 0x0d, 0xe3, 0x8e, 0xb8, 0xd1, 0x42, 0x0d, 0xc4, 0x00, 0x5f, 0x18, 0x2c, 0x2c,
		0xa5, 0x2c, 0xf8, 0x1c, 0xf3, 0x28, 0x0b, 0xbe, 0xe2, 0x5c, 0xa4, 0x2c, 0xf8, 0xaa, 0x9e, 0x43,
		0x59, 0x70, 0xc5, 0x06, 0x53, 0x16, 0x5c, 0xe3, 0x34, 0xcc, 0x26, 0x59, 0x10, 0xae, 0x5c, 0xda,
		0x53, 0x30, 0x0e, 0x52, 0x3e, 0x8d, 0xa4, 0xf6, 0x39, 0x63, 0x18, 0x46, 0x93, 0xcc, 0x33, 0x18,
		0xe1, 0x93, 0xda, 0xc2, 0x52, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92,
		0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x92, 0x5a, 0x3a, 0xc5, 0xec, 0x18, 0x46, 0x41, 0xac, 0xa5, 0x0d,
		0x9c, 0x36, 0x37, 0x94, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x94, 0x96,
		0x94, 0x96, 0x94, 0x96, 0x94, 0x96, 0x4e, 0x31, 0x3b, 0x86, 0x3a, 0x0e, 0x54, 0x22, 0xb5, 0xbc,
		0xb6, 0x60, 0x5f, 0xd2, 0x03, 0x5b, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c,
		0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x49, 0x6c, 0x69, 0x11, 0xa8, 0x8b, 0x3a, 0x4d, 0xa5, 0x42,
		0x1d, 0x68, 0x19, 0x62, 0x6e, 0x80, 0x72, 0x92, 0xfe, 0x37, 0x71, 0x15, 0x44, 0xd3, 0x02, 0x94,
		0x5e, 0x18, 0x09, 0xd5, 0x4f, 0x89, 0xa2, 0xab, 0x84, 0xfe, 0x11, 0xc6, 0x97, 0xae, 0x54, 0x89,
		0x0e, 0x54, 0x5f, 0x78, 0xf3, 0x17, 0x92, 0x85, 0x2b, 0x5e, 0x14, 0x87, 0x3a, 0xec, 0x87, 0xa3,
		0xa4, 0x68, 0x79, 0xbd, 0x8b, 0xc8, 0x8b, 0x65, 0xcf, 0x0b, 0x86, 0xd2, 0x4d, 0x82, 0xa1, 0x4c,
		0x8a, 0x96, 0x27, 0xa3, 0xeb, 0xba, 0x9b, 0xc4, 0x5a, 0xb8, 0x51, 0x38, 0x92, 0xfd, 0x5b, 0x4f,
		0x09, 0x79, 0xf1, 0xad, 0x17, 0xc6, 0x49, 0xd1, 0xf2, 0x82, 0xc1, 0xf7, 0x14, 0xad, 0xa4, 0x72,
		0xa3, 0x58, 0x78, 0x71, 0x38, 0xd6, 0x22, 0xc9, 0xde, 0xbc, 0xb1, 0xba, 0x54, 0xe1, 0x0f, 0xe5,
		0x06, 0x5a, 0xc7, 0xb2, 0x97, 0xfe, 0x61, 0xe1, 0x92, 0x87, 0x58, 0xfe, 0x30, 0xeb, 0x79, 0x1d,
		0x8f, 0xfb, 0x5a, 0x4d, 0x03, 0x63, 0xbb, 0xe8, 0xf8, 0xe3, 0xac, 0x53, 0x5b, 0xd3, 0x3e, 0xf5,
		0xe7, 0x3e, 0x27, 0xf3, 0x17, 0xfc, 0x93, 0xbc, 0xd3, 0x8b, 0x96, 0xff, 0xe9, 0x22, 0xf2, 0x3b,
		0xb2, 0xe7, 0x37, 0x87, 0xb2, 0x3b, 0xe9, 0xf3, 0xbc, 0xe1, 0xb7, 0xa2, 0xeb, 0x7a, 0x37, 0xd6,
		0xe2, 0x24, 0xed, 0x70, 0xff, 0x38, 0xef, 0xf0, 0xa2, 0xe5, 0x37, 0x07, 0xdf, 0x3b, 0xb2, 0xd7,
		0x52, 0x27, 0xb1, 0xf0, 0x3b, 0x69, 0x6f, 0x67, 0x6f, 0xfe, 0x69, 0xd6, 0xb5, 0xcd, 0xa2, 0xb3,
		0x17, 0xae, 0xf8, 0xdd, 0xb4, 0xaf, 0x59, 0xb2, 0x14, 0xd8, 0x12, 0x90, 0xf8, 0x38, 0xa1, 0xfc,
		0x88, 0x67, 0x10, 0x3b, 0x47, 0x32, 0xd1, 0x93, 0x09, 0x0d, 0x15, 0xad, 0x9d, 0x2f, 0x52, 0x1d,
		0x8e, 0xc4, 0x84, 0xc0, 0x27, 0x58, 0x09, 0xbc, 0xf3, 0x25, 0xb8, 0x79, 0x60, 0x59, 0xe5, 0x43,
		0xb5, 0x5a, 0x6f, 0x54, 0xab, 0x3b, 0x8d, 0xbd, 0xc6, 0xce, 0x7e, 0xad, 0x56, 0xa9, 0x57, 0x80,
		0xf6, 0xcb, 0x39, 0xed, 0x78, 0x20, 0x62, 0x31, 0xf8, 0x34, 0x99, 0x7a, 0x6a, 0x3c, 0x1a, 0xd1,
		0x23, 0xf1, 0x99, 0xca, 0xda, 0x33, 0x14, 0x07, 0xaa, 0x94, 0xf5, 0xba, 0x71, 0x12, 0x0c, 0x36,
		0x62, 0x1e, 0xfb, 0xcd, 0x5a, 0x60, 0x38, 0xc6, 0xa1, 0xc5, 0xb6, 0x35, 0x8b, 0x69, 0x00, 0x11,
		0xcc, 0xfe, 0xc8, 0x65, 0x36, 0x50, 0x99, 0x0b, 0x0f, 0x66, 0xee, 0x6c, 0x28, 0x20, 0xe5, 0x69,
		0xcf, 0xc4, 0xf3, 0x5d, 0x39, 0xd8, 0x12, 0x6a, 0x10, 0x85, 0x52, 0xe9, 0xad, 0x7e, 0x38, 0x0a,
		0x63, 0x43, 0x7e, 0x84, 0x91, 0xf3, 0xe0, 0xe4, 0x38, 0xd0, 0x39, 0x0d, 0x46, 0x0e, 0x63, 0xca,
		0x7d, 0x40, 0x70, 0xdc, 0x66, 0xfc, 0x36, 0x08, 0xd6, 0xb6, 0x81, 0xb4, 0x19, 0x48, 0x2e, 0x1f,
		0x10, 0xcb, 0xbd, 0x63, 0xc9, 0xb1, 0xc3, 0x74, 0xcc, 0xb0, 0x33, 0x56, 0x18, 0x88, 0x12, 0xf6,
		0x44, 0x87, 0x72, 0xe3, 0x42, 0x79, 0xde, 0x59, 0xce, 0x9d, 0x4a, 0xf2, 0x7f, 0x53, 0x7e, 0x6f,
		0x99, 0xbf, 0x97, 0xe8, 0xe8, 0x16, 0x38, 0x78, 0x39, 0x9e, 0xbd, 0x7a, 0x3f, 0x2b, 0xc1, 0xc7,
		0x9c, 0x7c, 0x1e, 0x85, 0x63, 0xed, 0x46, 0x61, 0xa2, 0x4b, 0xf3, 0xb2, 0xfb, 0x52, 0x05, 0xf3,
		0x16, 0x94, 0x14, 0x59, 0xf2, 0x15, 0x42, 0x25, 0xdd, 0xae, 0xec, 0x85, 0xbb, 0x26, 0x16, 0xe2,
		0x9a, 0x5d, 0x58, 0x6b, 0x6a, 0xa1, 0xac, 0xf1, 0x85, 0xaf, 0xc6, 0x17, 0xb2, 0x1a, 0x5f, 0x98,
		0xba, 0x5e, 0x9c, 0xe7, 0x40, 0x96, 0x2b, 0xe2, 0x39, 0xd3, 0x6c, 0xa1, 0x74, 0xc7, 0xc9, 0xc3,
		0x85, 0x91, 0x6c, 0xa5, 0x64, 0x00, 0x30, 0x06, 0x04, 0x26, 0x01, 0x01, 0x03, 0x18, 0x4c, 0x03,
		0x04, 0x0c, 0x50, 0xc0, 0x00, 0x06, 0x0c, 0x70, 0x6c, 0x86, 0x78, 0x56, 0x36, 0xa0, 0xcc, 0x02,
		0x8b, 0x39, 0x7f, 0x9b, 0xc1, 0x17, 0x53, 0xbe, 0x66, 0x06, 0x66, 0x8c, 0xc3, 0x0d, 0x02, 0xec,
		0x60, 0xc1, 0x0f, 0x0a, 0x0c, 0xc1, 0xc1, 0x11, 0x1c, 0x2c, 0xc1, 0xc1, 0x93, 0x19, 0x98, 0x32,
		0x04, 0x57, 0xc6, 0x61, 0xab, 0x30, 0x20, 0x5b, 0xcf, 0x61, 0xdc, 0x4f, 0xf3, 0xe8, 0x65, 0x72,
		0x79, 0xc9, 0x3c, 0x9c, 0x19, 0x5e, 0xbd, 0x0e, 0xb3, 0x0f, 0x1e, 0x69, 0xbf, 0x3b, 0xe6, 0xbe,
		0x76, 0xb4, 0xfd, 0xeb, 0xb0, 0xfb, 0xd4, 0x61, 0xf7, 0xa3, 0xc3, 0xee, 0x3b, 0xdf, 0xec, 0xe5,
		0xd0, 0x30, 0xfb, 0xc5, 0x8b, 0xb8, 0x33, 0x12, 0xc1, 0x30, 0x16, 0x43, 0x84, 0xa0, 0x93, 0x67,
		0x5d, 0x0d, 0x00, 0x5b, 0x4e, 0xa6, 0x4f, 0x91, 0xdf, 0xbf, 0xcf, 0xf6, 0xb1, 0x7a, 0x19, 0x90,
		0x6f, 0xea, 0x52, 0x61, 0x83, 0x99, 0x57, 0xbe, 0x52, 0x17, 0x87, 0xd3, 0x15, 0x16, 0x91, 0xd6,
		0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x91, 0xd6, 0x59, 0x49, 0xeb, 0x0a,
		0x2c, 0x27, 0xb3, 0x2b, 0x7d, 0x30, 0xa6, 0x7b, 0xb1, 0x70, 0x88, 0x5d, 0x6e, 0x10, 0x79, 0x1d,
		0x79, 0x1d, 0x79, 0x1d, 0x79, 0x1d, 0x79, 0x1d, 0x79, 0x1d, 0x79, 0x9d, 0x95, 0xbc, 0x2e, 0x87,
		0x72, 0xd2, 0xba, 0xd2, 0xc7, 0x22, 0x3b, 0xf7, 0x0f, 0x86, 0xd4, 0x21, 0x1c, 0x43, 0x68, 0x78,
		0x41, 0x11, 0x29, 0x1d, 0x29, 0x1d, 0x29, 0x1d, 0x29, 0x1d, 0x29, 0x9d, 0xf9, 0x05, 0x4a, 0x85,
		0x21, 0xe9, 0x01, 0x9c, 0x52, 0x0d, 0x04, 0x4e, 0xe1, 0x85, 0xfb, 0xfd, 0x7d, 0xf7, 0xb6, 0xa1,
		0x9c, 0x5a, 0x0a, 0x55, 0xe2, 0x03, 0xae, 0xa4, 0x07, 0x62, 0x09, 0x0f, 0xec, 0x92, 0x1d, 0xa8,
		0x25, 0x3a, 0xe0, 0x4b, 0x72, 0xc0, 0x97, 0xe0, 0x80, 0x2f, 0xb9, 0xc1, 0xf3, 0xa8, 0x21, 0x35,
		0x16, 0x60, 0xad, 0x05, 0x51, 0x73, 0x79, 0x4c, 0x7b, 0xf9, 0x87, 0xff, 0x52, 0x4a, 0x91, 0x08,
		0x9d, 0x14, 0xad, 0xa9, 0x52, 0x93, 0xd1, 0x0c, 0x1e, 0x16, 0x8b, 0xe2, 0x94, 0x20, 0x2b, 0xe8,
		0x17, 0xbc, 0x11, 0x61, 0x25, 0x3d, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28, 0xe9, 0x28,
		0xe9, 0x68, 0xe9, 0x71, 0x6b, 0x2c, 0x95, 0xde, 0xdb, 0x05, 0x64, 0xa3, 0x48, 0x64, 0xb4, 0x13,
		0xa8, 0x8b, 0x49, 0x6f, 0x9d, 0x41, 0xc5, 0x00, 0xc0, 0xf2, 0x63, 0x5f, 0xa4, 0xc2, 0x2d, 0x3d,
		0x0c, 0x5e, 0xd0, 0xf7, 0xaf, 0x60, 0x34, 0x16, 0xc0, 0xf6, 0x7d, 0x8e, 0x83, 0xbe, 0x96, 0xa1,
		0x3a, 0x90, 0x17, 0x32, 0x3b, 0xd3, 0x9b, 0x45, 0xb9, 0x7f, 0xc7, 0x25, 0x82, 0x1b, 0xba, 0xc4,
		0x0b, 0x5d, 0xa2, 0xba, 0xbb, 0x5f, 0xdd, 0xaf, 0x37, 0x76, 0xf7, 0x6b, 0xf4, 0x0d, 0xbb, 0x09,
		0x19, 0x9e, 0x35, 0xe7, 0x14, 0x89, 0x50, 0x62, 0xa7, 0xd3, 0x0f, 0xaf, 0xae, 0xc6, 0x4a, 0xea,
		0x5b, 0xd4, 0x47, 0x98, 0xf3, 0x06, 0x52, 0x38, 0x7a, 0xcc, 0x1c, 0x0a, 0x47, 0x4b, 0x4c, 0x29,
		0x0a, 0x47, 0x4b, 0xcd, 0x74, 0x0a, 0x47, 0x2f, 0x34, 0x90, 0xc2, 0x91, 0x45, 0x99, 0x04, 0x9f,
		0x63, 0x3e, 0x03, 0x06, 0x2d, 0x7c, 0x8e, 0x99, 0xf3, 0x0a, 0x29, 0x92, 0xa2, 0x7d, 0xcb, 0x47,
		0x99, 0x98, 0x2c, 0x15, 0xe6, 0xec, 0x88, 0x05, 0x9f, 0x04, 0x39, 0x43, 0x82, 0xbc, 0x94, 0xbc,
		0x94, 0xbc, 0x94, 0xbc, 0x94, 0xbc, 0x94, 0xbc, 0xb4, 0xf4, 0xb8, 0x25, 0x23, 0x37, 0x18, 0x0c,
		0x62, 0x91, 0x24, 0x88, 0xd4, 0x74, 0x1f, 0xc8, 0xa6, 0xe9, 0x18, 0xf2, 0xa1, 0xe6, 0x6f, 0xcf,
		0xac, 0xeb, 0x2a, 0xe0, 0xdc, 0x5a, 0x98, 0x63, 0x1f, 0x00, 0x6d, 0x3b, 0x09, 0xb4, 0x16, 0xb1,
		0x82, 0x9b, 0x6e, 0x85, 0x81, 0x6f, 0xdf, 0x9e, 0xed, 0xb8, 0xfb, 0xe7, 0xbf, 0xce, 0x2a, 0xee,
		0xfe, 0x79, 0xd6, 0xac, 0xa4, 0x6f, 0x59, 0x7b, 0xf7, 0x6c, 0xc7, 0xad, 0xe6, 0xed, 0xda, 0xd9,
		0x8e, 0x5b, 0x3b, 0xdf, 0xfe, 0xfb, 0xef, 0xf7, 0xdb, 0x3f, 0xf7, 0xee, 0x96, 0xff, 0xa1, 0x03,
		0xd7, 0x05, 0xe7, 0x88, 0x53, 0xa6, 0xdd, 0x6d, 0xfd, 0x17, 0x7e, 0xde, 0xfc, 0xaf, 0xcc, 0x89,
		0xf3, 0x1f, 0xc0, 0x99, 0x83, 0xf5, 0x58, 0xf1, 0x1d, 0xc1, 0xec, 0xb7, 0xc1, 0xac, 0x4e, 0x30,
		0x5b, 0x6b, 0x30, 0x0b, 0xdc, 0x61, 0xd3, 0xfd, 0x7c, 0xfe, 0xb3, 0xf2, 0xae, 0x7a, 0xf7, 0x71,
		0xfb, 0x67, 0xe3, 0x6e, 0xfe, 0xe2, 0xaf, 0xc7, 0xbe, 0x56, 0x79, 0xd7, 0xb8, 0xfb, 0xf8, 0xc4,
		0x5f, 0xea, 0x77, 0x1f, 0x7f, 0xf3, 0xdf, 0xa8, 0xdd, 0xbd, 0x5d, 0xf8, 0xea, 0xe4, 0xfa, 0xee,
		0x53, 0x3f, 0xa8, 0x3e, 0xf1, 0x83, 0xbd, 0xa7, 0x7e, 0xb0, 0xf7, 0xc4, 0x0f, 0x9e, 0x34, 0x69,
		0xf7, 0x89, 0x1f, 0xd4, 0xee, 0x7e, 0x2d, 0x7c, 0xff, 0xed, 0xe3, 0x5f, 0xad, 0xdf, 0x6d, 0xff,
		0x7a, 0xea, 0x6f, 0x8d, 0xbb, 0x5f, 0x1f, 0xb7, 0x09, 0xed, 0xeb, 0x07, 0xed, 0x74, 0xa3, 0xf2,
		0xdd, 0x88, 0x44, 0xc7, 0x0a, 0x35, 0x6a, 0x8b, 0xeb, 0xa7, 0x90, 0xa8, 0xa7, 0x23, 0x6e, 0xb4,
		0x0b, 0xbf, 0x86, 0xea, 0x31, 0x23, 0xf9, 0xbc, 0xea, 0x31, 0x73, 0xf8, 0xbc, 0x6a, 0x89, 0x69,
		0xc5, 0xe7, 0x55, 0x4b, 0xcd, 0x74, 0x3e, 0xaf, 0x7a, 0xa1, 0x81, 0x7c, 0x5e, 0x65, 0x91, 0x20,
		0xc3, 0x75, 0x54, 0xcf, 0xd1, 0x5e, 0xec, 0x5b, 0x47, 0xf5, 0x90, 0x5b, 0x48, 0x91, 0xcc, 0x7c,
		0xe6, 0x7a, 0x2a, 0x50, 0xd6, 0x2a, 0xd5, 0x75, 0x30, 0x92, 0x03, 0x37, 0x16, 0x41, 0x12, 0x2a,
		0x3c, 0xc2, 0x3a, 0x67, 0x1f, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9, 0x2a, 0xb9,
		0xea, 0x86, 0x71, 0x55, 0x39, 0x10, 0x4a, 0x4b, 0x7d, 0x0b, 0xca, 0x57, 0x81, 0x76, 0x07, 0x3b,
		0xad, 0x69, 0x57, 0x7d, 0x0a, 0x12, 0xc0, 0x90, 0x9a, 0x0f, 0x68, 0xeb, 0xf8, 0xaf, 0xe6, 0x51,
		0xeb, 0xc0, 0xef, 0xb4, 0x4f, 0xbf, 0x1e, 0xfa, 0x9d, 0xc3, 0x66, 0xb7, 0x7d, 0x8c, 0x16, 0x5d,
		0xd3, 0x4d, 0xe0, 0x09, 0xe4, 0x63, 0x22, 0xd0, 0x5d, 0xfd, 0xf3, 0xa3, 0xfb, 0xc7, 0xd1, 0x69,
		0xf7, 0xeb, 0x61, 0xc7, 0x3f, 0x6a, 0xb7, 0x4f, 0x1c, 0x1e, 0xda, 0xb0, 0x36, 0xe3, 0xda, 0xee,
		0xb4, 0xfe, 0x6c, 0x1d, 0x37, 0xbf, 0xb6, 0x3b, 0x1c, 0xd5, 0xf5, 0x19, 0xd5, 0x66, 0x97, 0x8e,
		0xba, 0x6e, 0x01, 0xb8, 0x7d, 0xfc, 0xf9, 0xf0, 0xc0, 0xe1, 0x99, 0x20, 0xff, 0xf8, 0x3a, 0x67,
		0x3e, 0x02, 0x66, 0x05, 0x82, 0x3a, 0x38, 0x0a, 0x12, 0xed, 0x5e, 0x85, 0x03, 0x39, 0x94, 0x62,
		0x80, 0x27, 0x0e, 0xce, 0x9a, 0x47, 0x6d, 0xf0, 0x31, 0x73, 0xa8, 0x0d, 0x2e, 0x31, 0xa1, 0xa8,
		0x0d, 0x2e, 0x35, 0xd3, 0xa9, 0x0d, 0xbe, 0xd0, 0x40, 0x6a, 0x83, 0x16, 0x71, 0x5f, 0x60, 0x6d,
		0x50, 0xcb, 0x2b, 0xa1, 0x65, 0xff, 0x32, 0xa9, 0x57, 0x01, 0xb5, 0x41, 0xa0, 0x6d, 0x04, 0xce,
		0xa9, 0xca, 0xce, 0x08, 0x74, 0x54, 0xa0, 0xc2, 0x44, 0xf4, 0x43, 0x35, 0x80, 0xda, 0xab, 0xca,
		0xd3, 0x6e, 0x7f, 0xb3, 0xa3, 0x78, 0xda, 0xed, 0xf3, 0xcd, 0xe3, 0x69, 0xb7, 0xeb, 0xa8, 0xc7,
		0xf0, 0xb4, 0xdb, 0x57, 0x70, 0x89, 0xca, 0x87, 0x6a, 0xb5, 0xde, 0xa8, 0x56, 0x77, 0x1a, 0x7b,
		0x8d, 0x9d, 0xfd, 0x5a, 0xad, 0x52, 0xaf, 0xf0, 0xdc, 0x5b, 0xcb, 0xf9, 0x23, 0x9e, 0x35, 0xdc,
		0xb7, 0x01, 0x13, 0x45, 0x9d, 0xbc, 0xae, 0x38, 0x9c, 0xba, 0x95, 0x1b, 0x06, 0x92, 0xfd, 0x1c,
		0x88, 0x61, 0x30, 0x1e, 0xa5, 0xa9, 0xea, 0x0e, 0xb5, 0xb6, 0x47, 0xcd, 0xa1, 0xd6, 0xb6, 0xc4,
		0xf4, 0xa6, 0xd6, 0xb6, 0xd4, 0x4c, 0xa7, 0xd6, 0xf6, 0x42, 0x03, 0xa9, 0xb5, 0x59, 0x94, 0xd7,
		0xb0, 0x68, 0xd3, 0xf2, 0x28, 0xc8, 0xa2, 0x4d, 0xff, 0xf6, 0xa2, 0x8c, 0xb5, 0x96, 0x39, 0x3b,
		0x65, 0x2c, 0xdb, 0xc3, 0xfd, 0xac, 0x4b, 0x50, 0xc6, 0x7a, 0xb1, 0x4b, 0xb0, 0x68, 0xd3, 0xba,
		0x10, 0x32, 0x3c, 0x6b, 0x28, 0x5e, 0xc1, 0xc4, 0x4e, 0x67, 0xba, 0x39, 0x32, 0x1c, 0x6b, 0x81,
		0x27, 0x60, 0x3d, 0x34, 0x8e, 0x82, 0xd1, 0x63, 0xe6, 0x50, 0x30, 0x5a, 0x62, 0x3a, 0x51, 0x30,
		0x5a, 0x6a, 0xa6, 0x53, 0x30, 0x7a, 0xa1, 0x81, 0x14, 0x8c, 0x2c, 0xca, 0x20, 0x80, 0x05, 0xa3,
		0x5e, 0x18, 0x8e, 0x44, 0xa0, 0x10, 0x37, 0x6d, 0x56, 0x48, 0xe5, 0x00, 0x2c, 0x30, 0xec, 0x42,
		0x4e, 0x53, 0xa9, 0x50, 0x07, 0x93, 0x6c, 0x0c, 0xc2, 0x81, 0x9c, 0xa4, 0xff, 0x4d, 0x5c, 0x05,
		0xd1, 0xf4, 0xd0, 0x19, 0x2f, 0x8c, 0x84, 0xea, 0xa7, 0x44, 0xc9, 0x55, 0x42, 0xff, 0x08, 0xe3,
		0x4b, 0x57, 0xaa, 0x44, 0x07, 0xaa, 0x2f, 0xbc, 0xf9, 0x0b, 0xc9, 0xc2, 0x15, 0x2f, 0x8a, 0x43,
		0x1d, 0xf6, 0xc3, 0x51, 0x52, 0xb4, 0xbc, 0xde, 0x45, 0xe4, 0xc5, 0xb2, 0xe7, 0x05, 0x43, 0xe9,
		0x26, 0xc1, 0x50, 0x26, 0x45, 0xcb, 0x4b, 0x8f, 0x66, 0x4e, 0x62, 0x2d, 0xdc, 0x28, 0x1c, 0xc9,
		0xfe, 0xad, 0xa7, 0x84, 0xbc, 0xf8, 0xd6, 0x0b, 0xe3, 0xa4, 0x68, 0x79, 0xc1, 0xe0, 0x7b, 0x8a,
		0x06, 0xe1, 0x58, 0xbb, 0x51, 0x98, 0x68, 0x2f, 0xa5, 0xb8, 0x49, 0xf6, 0x96, 0x1d, 0x74, 0x03,
		0xe0, 0xec, 0x4e, 0xa2, 0xe3, 0x71, 0x5f, 0xab, 0x69, 0x14, 0x6a, 0x17, 0xbd, 0x78, 0x9c, 0xf5,
		0x50, 0x6b, 0xda, 0x41, 0xfe, 0xdc, 0xe7, 0x64, 0xfe, 0x82, 0x7f, 0x92, 0xf7, 0x60, 0xd1, 0xf2,
		0x3f, 0x5d, 0x44, 0x7e, 0x47, 0xf6, 0xfc, 0xe6, 0x50, 0x76, 0x27, 0x1d, 0x98, 0x37, 0xfc, 0x56,
		0x74, 0x5d, 0xef, 0xc6, 0x5a, 0x9c, 0xa4, 0xbd, 0xe7, 0x1f, 0xe7, 0xbd, 0x57, 0xb4, 0xfc, 0xe6,
		0xe0, 0x7b, 0x47, 0xf6, 0xda, 0x63, 0x7d, 0x12, 0x26, 0xda, 0xef, 0xa4, 0x5d, 0x97, 0xbd, 0xf9,
		0xdd, 0xb4, 0xeb, 0xde, 0x6c, 0x66, 0x24, 0x30, 0x18, 0x05, 0x9c, 0xb1, 0xba, 0x54, 0xe1, 0x0f,
		0xe5, 0x06, 0x5a, 0xc7, 0xb2, 0x37, 0x19, 0x11, 0xe3, 0x91, 0xe0, 0xfe, 0x79, 0xcb, 0xa2, 0x6d,
		0x86, 0xe3, 0x65, 0x8e, 0x9e, 0x86, 0xcd, 0x40, 0x49, 0x1e, 0x91, 0x92, 0x46, 0xcc, 0x64, 0x11,
		0x2d, 0x49, 0x84, 0x4d, 0x0e, 0x61, 0x93, 0x42, 0xd8, 0x64, 0x70, 0xb3, 0x99, 0xeb, 0x81, 0x8c,
		0x31, 0xc2, 0xce, 0x02, 0x48, 0xe1, 0xa9, 0xb1, 0x8b, 0x26, 0x62, 0x69, 0xb2, 0x15, 0x6a, 0xb2,
		0xf0, 0xf0, 0x8a, 0x0d, 0xb3, 0xa8, 0x70, 0x0b, 0x0f, 0xbb, 0xf0, 0xf0, 0x0b, 0x0f, 0xc3, 0x38,
		0x52, 0xd6, 0x16, 0x90, 0x26, 0x8b, 0x02, 0xcf, 0x85, 0x41, 0x13, 0xec, 0x73, 0x35, 0x9a, 0x52,
		0x3c, 0x13, 0x51, 0xef, 0x4d, 0x04, 0x73, 0x3d, 0xcc, 0x95, 0x2f, 0x70, 0x70, 0x8d, 0x0c, 0xdb,
		0x76, 0xc0, 0x37, 0x3a, 0x8c, 0x5b, 0x03, 0xe7, 0xd6, 0xc0, 0xba, 0x35, 0xf0, 0x8e, 0x05, 0xf3,
		0x60, 0x70, 0x5f, 0x8c, 0xe2, 0x57, 0x44, 0x80, 0xdd, 0xc2, 0xae, 0xfb, 0xb0, 0x90, 0x0d, 0x37,
		0x30, 0x6b, 0x6f, 0xe6, 0x75, 0x20, 0xb2, 0x72, 0x0e, 0xf7, 0x64, 0x85, 0x6b, 0x25, 0xd1, 0x5d,
		0xd3, 0xc9, 0x1e, 0x4c, 0xc2, 0x12, 0x5f, 0x94, 0xe7, 0xa6, 0x8f, 0x7a, 0x23, 0x49, 0x2f, 0x49,
		0x2f, 0x49, 0x2f, 0x49, 0x2f, 0x49, 0x2f, 0x91, 0xf5, 0xf1, 0x51, 0x44, 0xd3, 0xba, 0x0a, 0xc3,
		0x52, 0x8e, 0x36, 0x12, 0xc0, 0xdb, 0x0c, 0x67, 0xa4, 0xaf, 0x89, 0xa5, 0xef, 0xb8, 0xf7, 0x6b,
		0x8d, 0x48, 0x81, 0x0d, 0xe4, 0xc0, 0x2e, 0x92, 0x60, 0x0b, 0x59, 0xb0, 0x8e, 0x34, 0x58, 0x47,
		0x1e, 0xac, 0x23, 0x11, 0x98, 0x64, 0x02, 0x94, 0x54, 0x14, 0xa3, 0x0b, 0xab, 0xa8, 0x2d, 0xc4,
		0xcd, 0xb1, 0x54, 0xba, 0x52, 0x47, 0x8e, 0x99, 0x53, 0x14, 0xaf, 0x03, 0x9b, 0x88, 0x79, 0x7a,
		0xc6, 0xfc, 0x0b, 0x1b, 0x73, 0xb6, 0xd0, 0x4f, 0xd7, 0xb0, 0x8c, 0x5e, 0x2e, 0x98, 0x0b, 0x7e,
		0xfa, 0xc6, 0x82, 0xbd, 0x16, 0x9c, 0x38, 0x60, 0x09, 0x1c, 0xcd, 0xba, 0x58, 0x70, 0x43, 0x17,
		0x5b, 0xb1, 0x8b, 0xd5, 0x6b, 0xb5, 0xbd, 0x1a, 0xdd, 0x6c, 0xb3, 0xb8, 0x28, 0xbe, 0x75, 0xe7,
		0x6f, 0xd8, 0x5f, 0x96, 0x86, 0x71, 0xe0, 0x95, 0x70, 0x0b, 0x29, 0x05, 0xea, 0x8a, 0x38, 0x4b,
		0x50, 0x85, 0xba, 0xe0, 0x6b, 0x4e, 0x46, 0xea, 0x82, 0xaf, 0xea, 0x39, 0xd4, 0x05, 0x57, 0x6c,
		0x30, 0x75, 0xc1, 0x35, 0x4e, 0xc4, 0x2c, 0xd3, 0x05, 0x3f, 0x58, 0x20, 0x0b, 0xd6, 0x28, 0x0b,
		0xbe, 0xf0, 0x45, 0x59, 0x90, 0x9a, 0x05, 0x65, 0xc1, 0x0d, 0x44, 0xa3, 0x59, 0x17, 0xa3, 0x2c,
		0xb8, 0x72, 0x17, 0xdb, 0xad, 0x51, 0x14, 0xdc, 0x30, 0x22, 0x8a, 0x6f, 0x1d, 0x45, 0x41, 0x6b,
		0x83, 0x78, 0xa6, 0xb4, 0x5d, 0x4f, 0xa3, 0x8b, 0x0d, 0xaa, 0x60, 0x66, 0x2b, 0x65, 0xc1, 0xe7,
		0x98, 0x47, 0x59, 0xf0, 0x15, 0x67, 0x23, 0x65, 0xc1, 0x57, 0xf5, 0x1c, 0xca, 0x82, 0x2b, 0x36,
		0x98, 0xb2, 0xe0, 0x1a, 0x27, 0x62, 0x16, 0xc9, 0x82, 0x3d, 0xa9, 0x82, 0xf8, 0xd6, 0x02, 0x5d,
		0x70, 0x1f, 0xd8, 0xc4, 0x23, 0xa1, 0x2e, 0xd2, 0x8d, 0xb9, 0x14, 0x06, 0x5f, 0xaa, 0x5a, 0x50,
		0x18, 0x5c, 0xb9, 0x6a, 0x51, 0xa1, 0x66, 0xb1, 0x61, 0x78, 0x34, 0xeb, 0x62, 0x14, 0x06, 0x57,
		0xee, 0x62, 0x5c, 0x2f, 0xb8, 0x81, 0x64, 0x14, 0xdf, 0x3a, 0x4a, 0x83, 0xd6, 0x86, 0x71, 0x47,
		0xdc, 0x68, 0xa1, 0x06, 0x62, 0x80, 0x2f, 0x0c, 0x16, 0x96, 0x52, 0x16, 0x7c, 0x8e, 0x79, 0x94,
		0x05, 0x5f, 0x71, 0x2e, 0x52, 0x16, 0x7c, 0x55, 0xcf, 0xa1, 0x2c, 0xb8, 0x62, 0x83, 0x29, 0x0b,
		0xae, 0x71, 0x1a, 0x66, 0x93, 0x2c, 0x08, 0x57, 0x32, 0xed, 0x29, 0x18, 0x07, 0x29, 0xa1, 0x46,
		0x52, 0xfb, 0x9c, 0x31, 0x0c, 0xa3, 0x49, 0xe6, 0x19, 0x8c, 0xf0, 0x49, 0x6d, 0x61, 0x29, 0x49,
		0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49, 0x2d, 0x49,
		0x2d, 0x9d, 0x62, 0x76, 0x0c, 0xa3, 0x20, 0xd6, 0xd2, 0x06, 0x4e, 0x9b, 0x1b, 0x4a, 0x4a, 0x4b,
		0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b, 0x4a, 0x4b,
		0xa7, 0x98, 0x1d, 0x43, 0x1d, 0x07, 0x2a, 0x91, 0x5a, 0x5e, 0x5b, 0xb0, 0x2f, 0xe9, 0x81, 0xad,
		0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6, 0x24, 0xb6,
		0x24, 0xb6, 0xb4, 0x08, 0xd4, 0x45, 0x9d, 0xa6, 0x52, 0xa1, 0x0e, 0xb4, 0x0c, 0x31, 0x37, 0x40,
		0x39, 0x49, 0xff, 0x9b, 0xb8, 0x0a, 0xa2, 0x69, 0x01, 0x4a, 0x2f, 0x8c, 0x84, 0xea, 0xa7, 0x44,
		0xd1, 0x55, 0x42, 0xff, 0x08, 0xe3, 0x4b, 0x57, 0xaa, 0x44, 0x07, 0xaa, 0x2f, 0xbc, 0xf9, 0x0b,
		0xc9, 0xc2, 0x15, 0x2f, 0x8a, 0x43, 0x1d, 0xf6, 0xc3, 0x51, 0x52, 0xb4, 0xbc, 0xde, 0x45, 0xe4,
		0xc5, 0xb2, 0xe7, 0x05, 0x43, 0xe9, 0x26, 0xc1, 0x50, 0x26, 0x45, 0xcb, 0x93, 0xd1, 0x75, 0xdd,
		0x4d, 0x62, 0x2d, 0xdc, 0x28, 0x1c, 0xc9, 0xfe, 0xad, 0xa7, 0x84, 0xbc, 0xf8, 0xd6, 0x0b, 0xe3,
		0xa4, 0x68, 0x79, 0xc1, 0xe0, 0x7b, 0x8a, 0x56, 0xe1, 0x58, 0xbb, 0x51, 0x98, 0x68, 0x2f, 0x0e,
		0xc7, 0x5a, 0x24, 0xd9, 0x9b, 0x37, 0x56, 0x97, 0x2a, 0xfc, 0xa1, 0xdc, 0x40, 0xeb, 0x58, 0xf6,
		0xd2, 0x3f, 0x2c, 0x5c, 0xf2, 0x10, 0x0b, 0x20, 0x66, 0x7d, 0xaf, 0xe3, 0x71, 0x5f, 0xab, 0x69,
		0x68, 0x6c, 0x17, 0x5d, 0x7f, 0x9c, 0x75, 0x6b, 0x6b, 0xda, 0xab, 0xfe, 0xdc, 0xe7, 0x64, 0xfe,
		0x82, 0x7f, 0x92, 0x77, 0x7b, 0xd1, 0xf2, 0x3f, 0x5d, 0x44, 0x7e, 0x47, 0xf6, 0xfc, 0xe6, 0x50,
		0x76, 0x27, 0xbd, 0x9e, 0x37, 0xfc, 0x56, 0x74, 0x5d, 0xef, 0xc6, 0x5a, 0x9c, 0xa4, 0x5d, 0xee,
		0x1f, 0xe7, 0x5d, 0x5e, 0xb4, 0xfc, 0xe6, 0xe0, 0x7b, 0x47, 0xf6, 0xda, 0x63, 0x7d, 0x12, 0x26,
		0xda, 0xef, 0xa4, 0xfd, 0x9d, 0xbd, 0xf9, 0xa7, 0x59, 0xe7, 0x36, 0x8b, 0xee, 0x5e, 0xb8, 0xe2,
		0x77, 0xd3, 0xde, 0x66, 0xd9, 0x52, 0x60, 0x4b, 0x40, 0x62, 0xe4, 0x84, 0xf6, 0x23, 0x9e, 0x43,
		0xec, 0x1c, 0xc9, 0x44, 0x4f, 0x26, 0x34, 0x54, 0xc4, 0x76, 0xbe, 0x48, 0x75, 0x38, 0x12, 0x13,
		0x12, 0x9f, 0x60, 0x25, 0xf1, 0xce, 0x97, 0xe0, 0xe6, 0x81, 0x65, 0x95, 0x0f, 0xd5, 0x6a, 0xbd,
		0x51, 0xad, 0xee, 0x34, 0xf6, 0x1a, 0x3b, 0xfb, 0xb5, 0x5a, 0xa5, 0x5e, 0x01, 0xda, 0x33, 0xe7,
		0xb4, 0xe3, 0x81, 0x88, 0xc5, 0xe0, 0xd3, 0x64, 0xea, 0xa9, 0xf1, 0x68, 0x44, 0x8f, 0xc4, 0x67,
		0x2b, 0x1b, 0xc0, 0x52, 0x1c, 0xa8, 0x82, 0xd6, 0xeb, 0xc7, 0x4b, 0x30, 0x18, 0x89, 0x79, 0xfc,
		0x37, 0x6b, 0x81, 0xe1, 0x38, 0x87, 0x16, 0xdf, 0xd6, 0x2e, 0xae, 0x01, 0x44, 0xb1, 0x75, 0x88,
		0x5e, 0x66, 0x83, 0x95, 0xb9, 0x10, 0x61, 0xe6, 0xce, 0x86, 0x82, 0x52, 0x9e, 0xfe, 0x4c, 0xbc,
		0xdf, 0x95, 0x83, 0x2d, 0xa1, 0x06, 0x51, 0x28, 0x95, 0xde, 0xea, 0x87, 0xa3, 0x30, 0x36, 0xe4,
		0x49, 0x18, 0xb9, 0x0f, 0x4e, 0xae, 0x03, 0x9d, 0xdb, 0x60, 0xe4, 0x32, 0xa6, 0xdc, 0x07, 0x04,
		0xcb, 0xed, 0xc6, 0x70, 0x83, 0x80, 0x6d, 0x1f, 0x50, 0x9b, 0x81, 0xe5, 0xf2, 0x41, 0xb1, 0xdc,
		0x3b, 0x96, 0x1c, 0x3f, 0x4c, 0xc7, 0x0d, 0x5b, 0xe3, 0x85, 0x81, 0x48, 0x61, 0x53, 0x84, 0x28,
		0x37, 0x36, 0x94, 0xe7, 0xa1, 0xe5, 0xdc, 0xa9, 0xa4, 0x18, 0x60, 0xca, 0xf7, 0xad, 0xf3, 0xf9,
		0x12, 0x9d, 0xdd, 0x0a, 0x27, 0x2f, 0xc7, 0xbb, 0x57, 0xef, 0x6b, 0x25, 0xf8, 0x99, 0x33, 0x33,
		0x97, 0xe2, 0xf2, 0xd6, 0x25, 0xdd, 0x57, 0x30, 0x98, 0x33, 0xa0, 0xa4, 0xd8, 0x92, 0xaf, 0x1b,
		0x2a, 0xe9, 0x76, 0x65, 0x2f, 0xe7, 0x35, 0xb1, 0x3c, 0xd7, 0xec, 0x72, 0x5b, 0x53, 0xcb, 0x67,
		0x8d, 0x2f, 0x87, 0x35, 0xbe, 0xbc, 0xd5, 0xf8, 0x72, 0xd5, 0xf5, 0x62, 0x3d, 0x07, 0xb2, 0x5c,
		0x39, 0xcf, 0x99, 0x66, 0x0c, 0xa5, 0x3b, 0x4e, 0x1e, 0x2e, 0x8c, 0x64, 0x2c, 0x25, 0x03, 0x80,
		0x31, 0x20, 0x30, 0x09, 0x08, 0x18, 0xc0, 0x60, 0x1a, 0x20, 0x60, 0x80, 0x02, 0x06, 0x30, 0x60,
		0x80, 0x63, 0x33, 0x24, 0xb4, 0xb2, 0x01, 0x65, 0x16, 0x58, 0xcc, 0xf9, 0xdb, 0x0c, 0xbe, 0x98,
		0xf2, 0x35, 0x33, 0x30, 0x63, 0x1c, 0x6e, 0x10, 0x60, 0x07, 0x0b, 0x7e, 0x50, 0x60, 0x08, 0x0e,
		0x8e, 0xe0, 0x60, 0x09, 0x0e, 0x9e, 0xcc, 0xc0, 0x94, 0x21, 0xb8, 0x32, 0x0e, 0x5b, 0x85, 0x01,
		0xd9, 0xca, 0x0e, 0xe3, 0x7e, 0x9a, 0x47, 0x2f, 0x93, 0x0b, 0x4d, 0xe6, 0xe1, 0xcc, 0xf0, 0x7a,
		0x76, 0x98, 0xdd, 0xf1, 0x48, 0xbb, 0xe0, 0x31, 0x77, 0xbb, 0xa3, 0xed, 0x6a, 0x87, 0xdd, 0xbd,
		0x0e, 0xbb, 0x4b, 0x1d, 0x76, 0x37, 0xfa, 0x66, 0x2f, 0x8e, 0x86, 0xd9, 0x45, 0x5e, 0xc4, 0x9d,
		0x91, 0x08, 0x86, 0xb1, 0x18, 0x22, 0x04, 0x9d, 0x3c, 0xeb, 0x6a, 0x00, 0xd8, 0x72, 0x32, 0x7d,
		0x8e, 0xfc, 0xfe, 0x7d, 0xb6, 0xb7, 0xd5, 0xcb, 0x80, 0x7c, 0x53, 0x17, 0x0d, 0x1b, 0xcc, 0xbc,
		0xf2, 0x35, 0xbb, 0x38, 0x9c, 0xae, 0xb0, 0x88, 0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0x8e,
		0xb4, 0x8e, 0xb4, 0x8e, 0xb4, 0xce, 0x4a, 0x5a, 0x57, 0x60, 0x39, 0x99, 0x5d, 0xe9, 0x83, 0x31,
		0xdd, 0x95, 0x85, 0x43, 0xec, 0x72, 0x83, 0xc8, 0xeb, 0xc8, 0xeb, 0xc8, 0xeb, 0xc8, 0xeb, 0xc8,
		0xeb, 0xc8, 0xeb, 0xc8, 0xeb, 0xac, 0xe4, 0x75, 0x39, 0x94, 0x93, 0xd6, 0x95, 0x3e, 0x16, 0xd9,
		0x59, 0x80, 0x30, 0xa4, 0x0e, 0xe1, 0x68, 0x42, 0xc3, 0x0b, 0x8a, 0x48, 0xe9, 0x48, 0xe9, 0x48,
		0xe9, 0x48, 0xe9, 0x48, 0xe9, 0xcc, 0x2f, 0x50, 0x2a, 0x0c, 0x49, 0x8f, 0xe4, 0x94, 0x6a, 0x20,
		0x70, 0xca, 0x31, 0xdc, 0x6f, 0xef, 0xbb, 0xb7, 0x0d, 0xe5, 0x1c, 0x53, 0xa8, 0xc2, 0x1f, 0x70,
		0x85, 0x3e, 0x10, 0x0b, 0x7b, 0x60, 0x17, 0xf2, 0x40, 0x2d, 0xdc, 0x01, 0x5f, 0xa8, 0x03, 0xbe,
		0x30, 0x07, 0x7c, 0x21, 0x0e, 0x9e, 0x50, 0x0d, 0xa9, 0xb1, 0x00, 0x6b, 0x2d, 0x88, 0x9a, 0xcb,
		0x63, 0xda, 0xcb, 0x3f, 0xfc, 0x97, 0x52, 0x8a, 0x44, 0xe8, 0xa4, 0x68, 0x4d, 0x95, 0x9a, 0x8c,
		0x66, 0xf0, 0xe8, 0x58, 0x14, 0xa7, 0x04, 0x59, 0x41, 0xbf, 0xe0, 0x8d, 0x08, 0x2b, 0xe9, 0x49,
		0x47, 0x49, 0x47, 0x49, 0x47, 0x49, 0x47, 0x49, 0x47, 0x49, 0x47, 0x4b, 0x8f, 0x5b, 0x63, 0xa9,
		0xf4, 0xde, 0x2e, 0x20, 0x1b, 0x45, 0x22, 0xa3, 0x9d, 0x40, 0x5d, 0x4c, 0x7a, 0xeb, 0x0c, 0x2a,
		0x06, 0x00, 0x16, 0x25, 0xfb, 0x22, 0x15, 0x6e, 0x41, 0x62, 0xf0, 0x32, 0xbf, 0x7f, 0x05, 0xa3,
		0xb1, 0x00, 0xb6, 0xef, 0x73, 0x1c, 0xf4, 0xb5, 0x0c, 0xd5, 0x81, 0xbc, 0x90, 0xd9, 0xe9, 0xde,
		0x2c, 0xd5, 0xfd, 0x3b, 0x2e, 0x11, 0xdc, 0xd0, 0x25, 0x5e, 0xe8, 0x12, 0xd5, 0xdd, 0xfd, 0xea,
		0x7e, 0xbd, 0xb1, 0xbb, 0x5f, 0xa3, 0x6f, 0xd8, 0x4d, 0xc8, 0xf0, 0xac, 0x39, 0xa7, 0x48, 0x84,
		0x12, 0x3b, 0x9d, 0x7e, 0x78, 0x75, 0x35, 0x56, 0x52, 0xdf, 0xa2, 0x3e, 0xc2, 0x9c, 0x37, 0x90,
		0xc2, 0xd1, 0x63, 0xe6, 0x50, 0x38, 0x5a, 0x62, 0x4a, 0x51, 0x38, 0x5a, 0x6a, 0xa6, 0x53, 0x38,
		0x7a, 0xa1, 0x81, 0x14, 0x8e, 0x2c, 0xca, 0x24, 0xf8, 0x1c, 0xf3, 0x19, 0x30, 0x68, 0xe1, 0x73,
		0xcc, 0x9c, 0x57, 0x48, 0x91, 0x14, 0xed, 0x5b, 0x3e, 0xca, 0xc4, 0x64, 0xa9, 0x30, 0x67, 0x47,
		0x2c, 0xf8, 0x24, 0xc8, 0x19, 0x12, 0xe4, 0xa5, 0xe4, 0xa5, 0xe4, 0xa5, 0xe4, 0xa5, 0xe4, 0xa5,
		0xe4, 0xa5, 0xa5, 0xc7, 0x2d, 0x19, 0xb9, 0xc1, 0x60, 0x10, 0x8b, 0x24, 0x41, 0xa4, 0xa6, 0xfb,
		0x40, 0x36, 0x4d, 0xc7, 0x90, 0x0f, 0x35, 0x7f, 0x7b, 0x66, 0x5d, 0x57, 0x01, 0xe7, 0xd6, 0xc2,
		0x1c, 0xfb, 0x00, 0x68, 0xdb, 0x49, 0xa0, 0xb5, 0x88, 0x15, 0xdc, 0x74, 0x2b, 0x0c, 0x7c, 0xfb,
		0xf6, 0x6c, 0xc7, 0xdd, 0x3f, 0xff, 0x75, 0x56, 0x71, 0xf7, 0xcf, 0xb3, 0x66, 0x25, 0x7d, 0xcb,
		0xda, 0xbb, 0x67, 0x3b, 0x6e, 0x35, 0x6f, 0xd7, 0xce, 0x76, 0xdc, 0xda, 0xf9, 0xf6, 0xdf, 0x7f,
		0xbf, 0xdf, 0xfe, 0xb9, 0x77, 0xb7, 0xfc, 0x0f, 0x1d, 0xb8, 0x2e, 0x38, 0x47, 0x9c, 0x32, 0xed,
		0x6e, 0xeb, 0xbf, 0xf0, 0xf3, 0xe6, 0x7f, 0x65, 0x4e, 0x9c, 0xff, 0x00, 0xce, 0x1c, 0xac, 0xc7,
		0x8a, 0xef, 0x08, 0x66, 0xbf, 0x0d, 0x66, 0x75, 0x82, 0xd9, 0x5a, 0x83, 0x59, 0xe0, 0x0e, 0x9b,
		0xee, 0xe7, 0xf3, 0x9f, 0x95, 0x77, 0xd5, 0xbb, 0x8f, 0xdb, 0x3f, 0x1b, 0x77, 0xf3, 0x17, 0x7f,
		0x3d, 0xf6, 0xb5, 0xca, 0xbb, 0xc6, 0xdd, 0xc7, 0x27, 0xfe, 0x52, 0xbf, 0xfb, 0xf8, 0x9b, 0xff,
		0x46, 0xed, 0xee, 0xed, 0xc2, 0x57, 0x27, 0xd7, 0x77, 0x9f, 0xfa, 0x41, 0xf5, 0x89, 0x1f, 0xec,
		0x3d, 0xf5, 0x83, 0xbd, 0x27, 0x7e, 0xf0, 0xa4, 0x49, 0xbb, 0x4f, 0xfc, 0xa0, 0x76, 0xf7, 0x6b,
		0xe1, 0xfb, 0x6f, 0x1f, 0xff, 0x6a, 0xfd, 0x6e, 0xfb, 0xd7, 0x53, 0x7f, 0x6b, 0xdc, 0xfd, 0xfa,
		0xb8, 0x4d, 0x68, 0x5f, 0x3f, 0x68, 0xa7, 0x1b, 0x95, 0xef, 0x46, 0x24, 0x3a, 0x56, 0xa8, 0x51,
		0x5b, 0x5c, 0x3f, 0x85, 0x44, 0x3d, 0x1d, 0x71, 0xa3, 0x5d, 0xf8, 0x35, 0x54, 0x8f, 0x19, 0xc9,
		0xe7, 0x55, 0x8f, 0x99, 0xc3, 0xe7, 0x55, 0x4b, 0x4c, 0x2b, 0x3e, 0xaf, 0x5a, 0x6a, 0xa6, 0xf3,
		0x79, 0xd5, 0x0b, 0x0d, 0xe4, 0xf3, 0x2a, 0x8b, 0x04, 0x19, 0xae, 0xa3, 0x7a, 0x8e, 0xf6, 0x62,
		0xdf, 0x3a, 0xaa, 0x87, 0xdc, 0x42, 0x8a, 0x64, 0xe6, 0x33, 0xd7, 0x53, 0x81, 0xb2, 0x56, 0xa9,
		0xae, 0x83, 0x91, 0x1c, 0xb8, 0xb1, 0x08, 0x92, 0x50, 0xe1, 0x11, 0xd6, 0x39, 0xfb, 0xc8, 0x55,
		0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0xc9, 0x55, 0x37, 0x8c, 0xab, 0xca, 0x81, 0x50,
		0x5a, 0xea, 0x5b, 0x50, 0xbe, 0x0a, 0xb4, 0x3b, 0xd8, 0x69, 0x4d, 0xbb, 0xea, 0x53, 0x90, 0x00,
		0x86, 0xd4, 0x7c, 0x40, 0x5b, 0xc7, 0x7f, 0x35, 0x8f, 0x5a, 0x07, 0x7e, 0xa7, 0x7d, 0xfa, 0xf5,
		0xd0, 0xef, 0x1c, 0x36, 0xbb, 0xed, 0x63, 0xb4, 0xe8, 0x9a, 0x6e, 0x02, 0x4f, 0x20, 0x1f, 0x13,
		0x81, 0xee, 0xea, 0x9f, 0x1f, 0xdd, 0x3f, 0x8e, 0x4e, 0xbb, 0x5f, 0x0f, 0x3b, 0xfe, 0x51, 0xbb,
		0x7d, 0xe2, 0xf0, 0xd0, 0x86, 0xb5, 0x19, 0xd7, 0x76, 0xa7, 0xf5, 0x67, 0xeb, 0xb8, 0xf9, 0xb5,
		0xdd, 0xe1, 0xa8, 0xae, 0xcf, 0xa8, 0x36, 0xbb, 0x74, 0xd4, 0x75, 0x0b, 0xc0, 0xed, 0xe3, 0xcf,
		0x87, 0x07, 0x0e, 0xcf, 0x04, 0xf9, 0xc7, 0xd7, 0x39, 0xf3, 0x11, 0x30, 0x2b, 0x10, 0xd4, 0xc1,
		0x51, 0x90, 0x68, 0xf7, 0x2a, 0x1c, 0xc8, 0xa1, 0x14, 0x03, 0x3c, 0x71, 0x70, 0xd6, 0x3c, 0x6a,
		0x83, 0x8f, 0x99, 0x43, 0x6d, 0x70, 0x89, 0x09, 0x45, 0x6d, 0x70, 0xa9, 0x99, 0x4e, 0x6d, 0xf0,
		0x85, 0x06, 0x52, 0x1b, 0xb4, 0x88, 0xfb, 0x02, 0x6b, 0x83, 0x5a, 0x5e, 0x09, 0x2d, 0xfb, 0x97,
		0x49, 0xbd, 0x0a, 0xa8, 0x0d, 0x02, 0x6d, 0x23, 0x70, 0x4e, 0x55, 0x76, 0x46, 0xa0, 0xa3, 0x02,
		0x15, 0x26, 0xa2, 0x1f, 0xaa, 0x01, 0xd4, 0x5e, 0x55, 0x9e, 0x76, 0xfb, 0x9b, 0x1d, 0xc5, 0xd3,
		0x6e, 0x9f, 0x6f, 0x1e, 0x4f, 0xbb, 0x5d, 0x47, 0x3d, 0x86, 0xa7, 0xdd, 0xbe, 0x82, 0x4b, 0x54,
		0x3e, 0x54, 0xab, 0xf5, 0x46, 0xb5, 0xba, 0xd3, 0xd8, 0x6b, 0xec, 0xec, 0xd7, 0x6a, 0x95, 0x7a,
		0x85, 0xe7, 0xde, 0x5a, 0xce, 0x1f, 0xf1, 0xac, 0xe1, 0xbe, 0x0d, 0x98, 0x28, 0xea, 0xe4, 0x75,
		0xc5, 0xe1, 0xd4, 0xad, 0xdc, 0x30, 0x90, 0xec, 0xe7, 0x40, 0x0c, 0x83, 0xf1, 0x28, 0x4d, 0x55,
		0x77, 0xa8, 0xb5, 0x3d, 0x6a, 0x0e, 0xb5, 0xb6, 0x25, 0xa6, 0x37, 0xb5, 0xb6, 0xa5, 0x66, 0x3a,
		0xb5, 0xb6, 0x17, 0x1a, 0x48, 0xad, 0xcd, 0xa2, 0xbc, 0x86, 0x45, 0x9b, 0x96, 0x47, 0x41, 0x16,
		0x6d, 0xfa, 0xb7, 0x17, 0x65, 0xac, 0xb5, 0xcc, 0xd9, 0x29, 0x63, 0xd9, 0x1e, 0xee, 0x67, 0x5d,
		0x82, 0x32, 0xd6, 0x8b, 0x5d, 0x82, 0x45, 0x9b, 0xd6, 0x85, 0x90, 0xe1, 0x59, 0x43, 0xf1, 0x0a,
		0x26, 0x76, 0x3a, 0xd3, 0xcd, 0x91, 0xe1, 0x58, 0x0b, 0x3c, 0x01, 0xeb, 0xa1, 0x71, 0x14, 0x8c,
		0x1e, 0x33, 0x87, 0x82, 0xd1, 0x12, 0xd3, 0x89, 0x82, 0xd1, 0x52, 0x33, 0x9d, 0x82, 0xd1, 0x0b,
		0x0d, 0xa4, 0x60, 0x64, 0x51, 0x06, 0x01, 0x2c, 0x18, 0xf5, 0xc2, 0x70, 0x24, 0x02, 0x85, 0xb8,
		0x69, 0xb3, 0x42, 0x2a, 0x07, 0x60, 0x81, 0x61, 0x17, 0x72, 0x9a, 0x4a, 0x85, 0x3a, 0x98, 0x64,
		0x63, 0x10, 0x0e, 0xe4, 0x24, 0xfd, 0x6f, 0xe2, 0x2a, 0x88, 0xa6, 0x87, 0xce, 0x78, 0x61, 0x24,
		0x54, 0x3f, 0x25, 0x4a, 0xae, 0x12, 0xfa, 0x47, 0x18, 0x5f, 0xba, 0x52, 0x25, 0x3a, 0x50, 0x7d,
		0xe1, 0xcd, 0x5f, 0x48, 0x16, 0xae, 0x78, 0x51, 0x1c, 0xea, 0xb0, 0x1f, 0x8e, 0x92, 0xa2, 0xe5,
		0xf5, 0x2e, 0x22, 0x2f, 0x96, 0x3d, 0x2f, 0x18, 0x4a, 0x37, 0x09, 0x86, 0x32, 0x29, 0x5a, 0x5e,
		0x7a, 0x34, 0x73, 0x12, 0x6b, 0xe1, 0x46, 0xe1, 0x48, 0xf6, 0x6f, 0x3d, 0x25, 0xe4, 0xc5, 0xb7,
		0x5e, 0x18, 0x27, 0x45, 0xcb, 0x0b, 0x06, 0xdf, 0x53, 0x34, 0x08, 0xc7, 0xda, 0x8d, 0x62, 0xe1,
		0xa5, 0x0c, 0x37, 0xc9, 0xde, 0xb2, 0x73, 0x6e, 0x00, 0x7c, 0xdd, 0x49, 0x74, 0x3c, 0xee, 0x6b,
		0x35, 0x0d, 0x42, 0xed, 0xa2, 0x13, 0x8f, 0xb3, 0x0e, 0x6a, 0x4d, 0xfb, 0xc7, 0x9f, 0xfb, 0x9c,
		0xcc, 0x5f, 0xf0, 0x4f, 0xf2, 0x0e, 0x2c, 0x5a, 0xfe, 0xa7, 0x8b, 0xc8, 0xef, 0xc8, 0x9e, 0xdf,
		0x1c, 0xca, 0xee, 0xa4, 0xff, 0xf2, 0x86, 0xdf, 0x8a, 0xae, 0xeb, 0xdd, 0x58, 0x8b, 0x93, 0xb4,
		0xf3, 0xfc, 0xe3, 0xbc, 0xf3, 0x8a, 0x96, 0xdf, 0x1c, 0x7c, 0xef, 0xc8, 0x5e, 0x7b, 0xac, 0x4f,
		0x62, 0xe1, 0x77, 0xd2, 0x9e, 0xcb, 0xde, 0xfc, 0x6e, 0xda, 0x73, 0x6f, 0x36, 0x33, 0x0e, 0x18,
		0x8c, 0x01, 0xce, 0x58, 0x5d, 0xaa, 0xf0, 0x87, 0x72, 0x03, 0xad, 0x63, 0xd9, 0x9b, 0x8c, 0x88,
		0xf1, 0x38, 0x70, 0xff, 0xb4, 0x65, 0xd1, 0x36, 0xc3, 0xd1, 0x32, 0xc7, 0x4e, 0xc3, 0x66, 0xa0,
		0xa4, 0x8e, 0x48, 0x29, 0x23, 0x66, 0xaa, 0x88, 0x96, 0x22, 0xc2, 0xa6, 0x86, 0xb0, 0x29, 0x21,
		0x6c, 0x2a, 0xb8, 0xd9, 0xbc, 0xf5, 0x40, 0xc6, 0x18, 0x61, 0x67, 0x01, 0xa4, 0xf0, 0xb4, 0xd8,
		0x45, 0x13, 0xb1, 0x14, 0xd9, 0x0a, 0x15, 0x59, 0x78, 0x78, 0xc5, 0x86, 0x59, 0x54, 0xb8, 0x85,
		0x87, 0x5d, 0x78, 0xf8, 0x85, 0x87, 0x61, 0x1c, 0x21, 0x6b, 0x0b, 0x48, 0x91, 0x45, 0x81, 0xe7,
		0xc2, 0xa0, 0x09, 0xf6, 0xb9, 0x1a, 0x4d, 0x27, 0x9e, 0x89, 0xa8, 0xf7, 0x26, 0x82, 0xb9, 0x1e,
		0xe6, 0xba, 0x17, 0x38, 0xb8, 0x46, 0x86, 0x6d, 0x3b, 0xe0, 0x1b, 0x1d, 0xc6, 0xad, 0x81, 0x73,
		0x6b, 0x60, 0xdd, 0x1a, 0x78, 0xc7, 0x82, 0x79, 0x30, 0xb8, 0x2f, 0x46, 0xf1, 0x2b, 0x22, 0xc0,
		0x6e, 0x61, 0x57, 0x7d, 0x58, 0xc8, 0x86, 0x1b, 0x98, 0x95, 0x37, 0xf3, 0x2a, 0x10, 0x59, 0x31,
		0x87, 0x7b, 0xb2, 0xc2, 0x95, 0x92, 0xe8, 0xae, 0xe9, 0x64, 0xcf, 0x25, 0x61, 0x89, 0x2f, 0xca,
		0x63, 0xd3, 0x47, 0xbd, 0x91, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xa4, 0x97, 0xc8,
		0xfa, 0xf8, 0x28, 0xa2, 0x69, 0x5d, 0x85, 0x61, 0x29, 0x47, 0x1b, 0x09, 0xe0, 0x4d, 0x86, 0x33,
		0xd2, 0xd7, 0xc4, 0xd2, 0x77, 0xdc, 0xf9, 0xb5, 0x46, 0xa4, 0xc0, 0x06, 0x72, 0x60, 0x17, 0x49,
		0xb0, 0x85, 0x2c, 0x58, 0x47, 0x1a, 0xac, 0x23, 0x0f, 0xd6, 0x91, 0x08, 0x4c, 0x32, 0x01, 0x4a,
		0x2a, 0x8a, 0xd1, 0x85, 0x55, 0xd4, 0x16, 0xe2, 0xe6, 0x58, 0x2a, 0x5d, 0xa9, 0x23, 0xc7, 0xcc,
		0x29, 0x8a, 0xd7, 0x81, 0x4d, 0xc4, 0x3c, 0x3b, 0x63, 0xfe, 0x85, 0x8d, 0x39, 0x5b, 0xe8, 0x67,
		0x6b, 0x58, 0x46, 0x2f, 0x17, 0xcc, 0x05, 0x3f, 0x7b, 0x63, 0xc1, 0x5e, 0x0b, 0xce, 0x1b, 0xb0,
		0x04, 0x8e, 0x66, 0x5d, 0x2c, 0xb8, 0xa1, 0x8b, 0xad, 0xd8, 0xc5, 0xea, 0xb5, 0xda, 0x5e, 0x8d,
		0x6e, 0xb6, 0x59, 0x5c, 0x14, 0xdf, 0xba, 0xf3, 0x37, 0xec, 0x2f, 0x4b, 0xc3, 0x38, 0xf0, 0x4a,
		0xb8, 0x85, 0x94, 0x02, 0x75, 0x45, 0x9c, 0x25, 0xa8, 0x42, 0x5d, 0xf0, 0x35, 0x27, 0x23, 0x75,
		0xc1, 0x57, 0xf5, 0x1c, 0xea, 0x82, 0x2b, 0x36, 0x98, 0xba, 0xe0, 0x1a, 0x27, 0x62, 0x96, 0xe9,
		0x82, 0x1f, 0x2c, 0x90, 0x05, 0x6b, 0x94, 0x05, 0x5f, 0xf8, 0xa2, 0x2c, 0x48, 0xcd, 0x82, 0xb2,
		0xe0, 0x06, 0xa2, 0xd1, 0xac, 0x8b, 0x51, 0x16, 0x5c, 0xb9, 0x8b, 0xed, 0xd6, 0x28, 0x0a, 0x6e,
		0x18, 0x11, 0xc5, 0xb7, 0x8e, 0xa2, 0xa0, 0xb5, 0x41, 0x3c, 0x53, 0xda, 0xae, 0xa7, 0xd1, 0xc5,
		0x06, 0x55, 0x30, 0xb3, 0x95, 0xb2, 0xe0, 0x73, 0xcc, 0xa3, 0x2c, 0xf8, 0x8a, 0xb3, 0x91, 0xb2,
		0xe0, 0xab, 0x7a, 0x0e, 0x65, 0xc1, 0x15, 0x1b, 0x4c, 0x59, 0x70, 0x8d, 0x13, 0x31, 0x8b, 0x64,
		0xc1, 0x9e, 0x54, 0x41, 0x7c, 0x6b, 0x81, 0x2e, 0xb8, 0x0f, 0x6c, 0xe2, 0x91, 0x50, 0x17, 0xe9,
		0xc6, 0x5c, 0x0a, 0x83, 0x2f, 0x55, 0x2d, 0x28, 0x0c, 0xae, 0x5c, 0xb5, 0xa8, 0x50, 0xb3, 0xd8,
		0x30, 0x3c, 0x9a, 0x75, 0x31, 0x0a, 0x83, 0x2b, 0x77, 0x31, 0xae, 0x17, 0xdc, 0x40, 0x32, 0x8a,
		0x6f, 0x1d, 0xa5, 0x41, 0x6b, 0xc3, 0xb8, 0x23, 0x6e, 0xb4, 0x50, 0x03, 0x31, 0xc0, 0x17, 0x06,
		0x0b, 0x4b, 0x29, 0x0b, 0x3e, 0xc7, 0x3c, 0xca, 0x82, 0xaf, 0x38, 0x17, 0x29, 0x0b, 0xbe, 0xaa,
		0xe7, 0x50, 0x16, 0x5c, 0xb1, 0xc1, 0x94, 0x05, 0xd7, 0x38, 0x0d, 0xb3, 0x49, 0x16, 0x84, 0x2b,
		0x98, 0xf6, 0x14, 0x8c, 0x83, 0x14, 0x50, 0x23, 0xa9, 0x7d, 0xce, 0x18, 0x86, 0xd1, 0x24, 0xf3,
		0x0c, 0x46, 0xf8, 0xa4, 0xb6, 0xb0, 0x94, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4,
		0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0xa4, 0x96, 0x4e, 0x31, 0x3b, 0x86, 0x51, 0x10, 0x6b,
		0x69, 0x03, 0xa7, 0xcd, 0x0d, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25,
		0xa5, 0x25, 0xa5, 0x25, 0xa5, 0x25, 0xa5, 0xa5, 0x53, 0xcc, 0x8e, 0xa1, 0x8e, 0x03, 0x95, 0x48,
		0x2d, 0xaf, 0x2d, 0xd8, 0x97, 0xf4, 0xc0, 0x56, 0x12, 0x5b, 0x12, 0x5b, 0x12, 0x5b, 0x12, 0x5b,
		0x12, 0x5b, 0x12, 0x5b, 0x12, 0x5b, 0x12, 0x5b, 0x12, 0x5b, 0x5a, 0x04, 0xea, 0xa2, 0x4e, 0x53,
		0xa9, 0x50, 0x07, 0x5a, 0x86, 0x98, 0x1b, 0xa0, 0x9c, 0xa4, 0xff, 0x4d, 0x5c, 0x05, 0xd1, 0xb4,
		0x00, 0xa5, 0x17, 0x46, 0x42, 0xf5, 0x53, 0xa2, 0xe8, 0x2a, 0xa1, 0x7f, 0x84, 0xf1, 0xa5, 0x2b,
		0x55, 0xa2, 0x03, 0xd5, 0x17, 0xde, 0xfc, 0x85, 0x64, 0xe1, 0x8a, 0x17, 0xc5, 0xa1, 0x0e, 0xfb,
		0xe1, 0x28, 0x29, 0x5a, 0x5e, 0xef, 0x22, 0xf2, 0x62, 0xd9, 0xf3, 0x82, 0xa1, 0x74, 0x93, 0x60,
		0x28, 0x93, 0xa2, 0xe5, 0xc9, 0xe8, 0xba, 0xee, 0x26, 0xb1, 0x16, 0x6e, 0x14, 0x8e, 0x64, 0xff,
		0xd6, 0x53, 0x42, 0x5e, 0x7c, 0xeb, 0x85, 0x71, 0x52, 0xb4, 0xbc, 0x60, 0xf0, 0x3d, 0x45, 0xab,
		0x70, 0xac, 0xdd, 0x28, 0x16, 0x5e, 0x1c, 0x8e, 0xb5, 0x48, 0xb2, 0x37, 0x6f, 0xac, 0x2e, 0x55,
		0xf8, 0x43, 0xb9, 0x81, 0xd6, 0xb1, 0xec, 0xa5, 0x7f, 0x58, 0xb8, 0xe4, 0x21, 0xd6, 0x3f, 0xcc,
		0xba, 0x5e, 0xc7, 0xe3, 0xbe, 0x56, 0xd3, 0xc8, 0xd8, 0x2e, 0x7a, 0xfe, 0x38, 0xeb, 0xd5, 0xd6,
		0xb4, 0x53, 0xfd, 0xb9, 0xcf, 0xc9, 0xfc, 0x05, 0xff, 0x24, 0xef, 0xf5, 0xa2, 0xe5, 0x7f, 0xba,
		0x88, 0xfc, 0x8e, 0xec, 0xf9, 0xcd, 0xa1, 0xec, 0x4e, 0x3a, 0x3d, 0x6f, 0xf8, 0xad, 0xe8, 0xba,
		0xde, 0x8d, 0xb5, 0x38, 0x49, 0x7b, 0xdc, 0x3f, 0xce, 0x7b, 0xbc, 0x68, 0xf9, 0xcd, 0xc1, 0xf7,
		0x8e, 0xec, 0xb5, 0xc7, 0xfa, 0x24, 0x16, 0x7e, 0x27, 0xed, 0xee, 0xec, 0xcd, 0x3f, 0xcd, 0xfa,
		0xb6, 0x59, 0xf4, 0xf6, 0xc2, 0x15, 0xbf, 0x9b, 0x76, 0x36, 0x8b, 0x96, 0x02, 0x5b, 0x02, 0x12,
		0x21, 0x27, 0xa4, 0x1f, 0xf1, 0x14, 0x62, 0xe7, 0x48, 0x26, 0x7a, 0x32, 0xa1, 0xa1, 0xe2, 0xb5,
		0xf3, 0x45, 0xaa, 0xc3, 0x91, 0x98, 0x50, 0xf8, 0x04, 0x2b, 0x85, 0x77, 0xbe, 0x04, 0x37, 0x0f,
		0x2c, 0xab, 0x7c, 0xa8, 0x56, 0xeb, 0x8d, 0x6a, 0x75, 0xa7, 0xb1, 0xd7, 0xd8, 0xd9, 0xaf, 0xd5,
		0x2a, 0xf5, 0x0a, 0xd0, 0x8e, 0x39, 0xa7, 0x1d, 0x0f, 0x44, 0x2c, 0x06, 0x9f, 0x26, 0x53, 0x4f,
		0x8d, 0x47, 0x23, 0x7a, 0x24, 0x3e, 0x57, 0x59, 0x7f, 0x8e, 0xe2, 0x40, 0x55, 0xb3, 0x5e, 0x3b,
		0x56, 0x82, 0xc1, 0x47, 0xcc, 0xa3, 0xbf, 0x59, 0x0b, 0x0c, 0x47, 0x39, 0xb4, 0xe8, 0xb6, 0x6e,
		0x51, 0x0d, 0x20, 0x86, 0xad, 0x41, 0xec, 0x32, 0x1b, 0xaa, 0xcc, 0x05, 0x08, 0x33, 0x77, 0x36,
		0x14, 0x92, 0xf2, 0xd4, 0x67, 0xe2, 0xfb, 0xae, 0x1c, 0x6c, 0x09, 0x35, 0x88, 0x42, 0xa9, 0xf4,
		0x56, 0x3f, 0x1c, 0x85, 0xb1, 0x21, 0x47, 0xc2, 0xc8, 0x7b, 0x70, 0xf2, 0x1c, 0xe8, 0xbc, 0x06,
		0x23, 0x8f, 0x31, 0xe5, 0x3e, 0x20, 0x48, 0x6e, 0x35, 0x82, 0x1b, 0x84, 0x6b, 0xeb, 0x60, 0xda,
		0x0c, 0x28, 0x97, 0x0f, 0x89, 0xe5, 0xde, 0xb1, 0xe4, 0xe8, 0x61, 0x3a, 0x6a, 0x58, 0x1a, 0x2d,
		0x0c, 0xc4, 0x09, 0x8b, 0xe2, 0x43, 0xb9, 0x91, 0xa1, 0x3c, 0xff, 0x2c, 0xe7, 0x4e, 0x25, 0x45,
		0x00, 0x53, 0x9e, 0x6f, 0x9b, 0xc7, 0x97, 0xe8, 0xea, 0x36, 0xb8, 0x78, 0x39, 0xbe, 0xbd, 0x7a,
		0x4f, 0x2b, 0xc1, 0xcb, 0x9c, 0x7c, 0x4a, 0xb9, 0xc1, 0x60, 0x10, 0x8b, 0x24, 0x29, 0xcd, 0xcf,
		0x8a, 0x85, 0x45, 0x0b, 0x16, 0x94, 0x14, 0x5b, 0xca, 0x5d, 0xf4, 0x5b, 0xfa, 0x22, 0x5e, 0x13,
		0x8b, 0x72, 0xcd, 0x2e, 0xb2, 0x35, 0xb5, 0x68, 0xd6, 0xf8, 0x22, 0x58, 0xe3, 0x8b, 0x5a, 0x8d,
		0x2f, 0x52, 0x5d, 0x2f, 0xd6, 0x53, 0xfa, 0xa2, 0xd0, 0xc2, 0x6f, 0x47, 0x22, 0x18, 0xc6, 0x62,
		0x58, 0xa6, 0xd3, 0xe6, 0x8b, 0x36, 0x1b, 0x25, 0xde, 0xf3, 0x64, 0x4a, 0xec, 0xde, 0xbf, 0xcf,
		0xd6, 0x98, 0x79, 0x0b, 0x18, 0x44, 0x06, 0xb1, 0x04, 0x21, 0x0c, 0xb4, 0x28, 0x9f, 0x36, 0x94,
		0xb9, 0x38, 0xb0, 0x98, 0xa4, 0xe4, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a, 0xe4, 0x0a, 0x38, 0x5c, 0xe1,
		0x40, 0x96, 0xfb, 0xd8, 0xcf, 0x5c, 0xc2, 0x88, 0x92, 0x38, 0x1a, 0x4a, 0x20, 0x8d, 0x81, 0x83,
		0x49, 0x90, 0xc0, 0x00, 0x0b, 0xd3, 0xa0, 0x01, 0x03, 0x1e, 0x30, 0x20, 0x02, 0x03, 0x26, 0xe5,
		0x82, 0x4a, 0xc9, 0xe0, 0x62, 0x2e, 0x21, 0x5d, 0xf0, 0x7b, 0x19, 0x19, 0x8a, 0xf2, 0x33, 0xf4,
		0xdf, 0x40, 0xc9, 0xb3, 0xbc, 0xef, 0xcd, 0x14, 0x32, 0x33, 0xb8, 0x44, 0xe3, 0x7e, 0xe4, 0xaf,
		0xab, 0x06, 0xc7, 0x7e, 0x61, 0x0e, 0x7c, 0x30, 0x68, 0xc3, 0x49, 0xa0, 0xb5, 0x88, 0x95, 0xf1,
		0xba, 0x76, 0xce, 0xdb, 0xb7, 0x67, 0x3b, 0xee, 0xfe, 0xf9, 0xaf, 0xb3, 0x8a, 0xbb, 0x7f, 0x9e,
		0x35, 0x2b, 0xe9, 0x5b, 0xd6, 0xde, 0x3d, 0xdb, 0x71, 0xab, 0x79, 0xbb, 0x76, 0xb6, 0xe3, 0xd6,
		0xce, 0xb7, 0xff, 0xfe, 0xfb, 0xfd, 0xf6, 0xcf, 0xbd, 0xbb, 0xe5, 0x7f, 0x68, 0x6e, 0x61, 0xe5,
		0xb9, 0xc9, 0xa1, 0x6e, 0xff, 0x7f, 0xf6, 0xfe, 0xff, 0x39, 0x6d, 0xe4, 0xf9, 0x16, 0xc6, 0x7f,
		0xcf, 0x5f, 0xe1, 0x52, 0xbd, 0x6e, 0x95, 0x5d, 0x37, 0x0a, 0x06, 0xf3, 0xc5, 0x76, 0xd5, 0xa7,
		0x6e, 0x91, 0xc4, 0xc9, 0x87, 0xe7, 0x65, 0x1b, 0x3f, 0xe0, 0xe4, 0xbd, 0x5b, 0x5e, 0x56, 0x25,
		0x60, 0x20, 0xb3, 0xc1, 0x12, 0x57, 0x12, 0x5e, 0xbb, 0x62, 0xfe, 0xf7, 0xa7, 0xf8, 0x26, 0x1b,
		0x04, 0x49, 0x6c, 0x34, 0x3d, 0x3d, 0xe2, 0xb8, 0xb6, 0xd6, 0x04, 0x03, 0x1a, 0x46, 0xd3, 0xa7,
		0x4f, 0x9f, 0xe9, 0xee, 0x69, 0xd6, 0xfe, 0x60, 0x73, 0xbf, 0xff, 0xa6, 0xbc, 0xe1, 0xff, 0xd1,
		0x78, 0xc7, 0x77, 0x29, 0x1b, 0x8f, 0x07, 0xb8, 0x97, 0x01, 0xee, 0x2c, 0xc1, 0xdd, 0xb5, 0x7b,
		0x55, 0xfb, 0x53, 0xeb, 0x47, 0xfe, 0x6d, 0x71, 0x7c, 0x7a, 0xf0, 0xa3, 0x32, 0x5e, 0x7d, 0xf2,
		0x71, 0xdd, 0xcb, 0xf2, 0x6f, 0x2b, 0xe3, 0xd3, 0x0d, 0x7f, 0x29, 0x8f, 0x4f, 0x7f, 0xf3, 0x33,
		0x4a, 0xe3, 0xfd, 0xc4, 0x4b, 0x27, 0xcf, 0x17, 0x36, 0xbd, 0xa1, 0xb8, 0xe1, 0x0d, 0x47, 0x9b,
		0xde, 0x70, 0xb4, 0xe1, 0x0d, 0x1b, 0x87, 0x54, 0xd8, 0xf0, 0x86, 0xd2, 0xf8, 0x31, 0xf1, 0xfa,
		0xfd, 0xf5, 0x2f, 0x2d, 0x8f, 0x0f, 0x1e, 0x37, 0xfd, 0xad, 0x32, 0x7e, 0x3c, 0x3d, 0x80, 0xab,
		0xe3, 0xe3, 0xea, 0xb0, 0xfc, 0xe9, 0x97, 0xff, 0xee, 0x39, 0xfe, 0x37, 0xd9, 0xfe, 0x9e, 0x48,
		0x7b, 0x7c, 0xa5, 0xaa, 0x85, 0xb4, 0xc7, 0xb5, 0x69, 0x8f, 0xd4, 0x0d, 0x61, 0xb8, 0x26, 0x3b,
		0x12, 0xf6, 0x6a, 0x21, 0xc8, 0x51, 0x78, 0x63, 0xb0, 0xc9, 0x2e, 0x0a, 0x02, 0x89, 0xf7, 0xa2,
		0x68, 0x4b, 0xfe, 0xe8, 0x4b, 0xfb, 0x58, 0x94, 0xf0, 0xd1, 0x96, 0xea, 0xa9, 0x5e, 0xa8, 0xc4,
		0x3e, 0x85, 0xbb, 0x2f, 0xb1, 0x48, 0x32, 0xa3, 0x38, 0x7a, 0x0f, 0xb5, 0x7e, 0x43, 0x1d, 0x9a,
		0xab, 0xf9, 0x64, 0x45, 0x66, 0x47, 0x65, 0x6e, 0x4c, 0xcd, 0x4c, 0xa1, 0x75, 0xf1, 0xb2, 0x2a,
		0x35, 0xc6, 0x94, 0xfe, 0x52, 0x4f, 0xf7, 0x13, 0x53, 0x36, 0x1a, 0xd5, 0xc6, 0xc2, 0xca, 0x48,
		0x14, 0x98, 0x06, 0x07, 0x93, 0x48, 0xd7, 0x10, 0xd2, 0x5b, 0xae, 0x29, 0x2e, 0xd5, 0xd9, 0x6e,
		0xc5, 0xc8, 0x93, 0x1d, 0x37, 0x8c, 0x52, 0x5f, 0xa8, 0xcb, 0x7b, 0x22, 0x8b, 0xab, 0xa4, 0x6c,
		0x68, 0x6a, 0xf2, 0x98, 0x95, 0xa5, 0xa4, 0xa9, 0x4c, 0x39, 0xa3, 0x49, 0x29, 0x53, 0x9d, 0x32,
		0x46, 0x96, 0x12, 0x46, 0x96, 0xf2, 0x45, 0x96, 0xd2, 0xc5, 0xdb, 0x25, 0xaa, 0xca, 0xeb, 0xb5,
		0x06, 0xb3, 0x39, 0x55, 0xb7, 0x22, 0xe3, 0x5a, 0xa2, 0xf9, 0x85, 0x14, 0x2d, 0x13, 0xb5, 0x25,
		0x19, 0x4f, 0x90, 0x56, 0x50, 0x74, 0x01, 0x82, 0x6c, 0x5a, 0xda, 0xac, 0x59, 0xaa, 0xec, 0x58,
		0xf2, 0x2c, 0x58, 0xf2, 0x6c, 0x57, 0xf2, 0xac, 0x56, 0xb3, 0x42, 0x6b, 0xd5, 0x25, 0x0f, 0xd6,
		0xbc, 0x7f, 0x8a, 0xf2, 0x85, 0xbc, 0x30, 0x4f, 0x92, 0x7e, 0x2d, 0x44, 0x35, 0x6c, 0x64, 0xe5,
		0x09, 0x94, 0xe5, 0x08, 0x7a, 0xca, 0x0f, 0xa8, 0xcb, 0x0d, 0xb4, 0x95, 0x17, 0x68, 0x2b, 0x27,
		0xd0, 0x56, 0x3e, 0x60, 0xf6, 0x9e, 0x17, 0x55, 0xcd, 0xd9, 0x0c, 0x18, 0xe9, 0x4b, 0x8b, 0x29,
		0xdb, 0xec, 0xa1, 0xb4, 0x38, 0x2b, 0x70, 0xad, 0x0b, 0xb6, 0xb5, 0xc3, 0xb7, 0x76, 0x18, 0xd7,
		0x0e, 0xe7, 0x34, 0xb0, 0x4e, 0x04, 0xef, 0xe4, 0x30, 0x1f, 0x5f, 0xd0, 0x0f, 0x64, 0x5f, 0x7a,
		0xfa, 0x0a, 0x8a, 0xe7, 0xd7, 0x47, 0x19, 0x71, 0xd6, 0x1c, 0x02, 0x0f, 0xc7, 0xa0, 0xdb, 0x41,
		0xb0, 0x71, 0x14, 0x6c, 0x1c, 0x06, 0x1b, 0xc7, 0x41, 0xeb, 0x40, 0x88, 0x1d, 0x49, 0x3c, 0xcb,
		0xfa, 0xcb, 0x88, 0xe9, 0xfb, 0x5b, 0x25, 0x78, 0x7e, 0x45, 0xc3, 0xb5, 0x13, 0xfd, 0xae, 0xe6,
		0x9e, 0x2e, 0xab, 0xc9, 0xe0, 0x84, 0x64, 0x7f, 0x7e, 0x12, 0x84, 0x3e, 0xd2, 0xb2, 0x18, 0x00,
		0x58, 0x0b, 0x58, 0x0b, 0x58, 0x0b, 0x58, 0x0b, 0x58, 0x0b, 0x58, 0x4b, 0x46, 0x59, 0xcb, 0xc2,
		0xd5, 0x81, 0xb6, 0x6c, 0x4f, 0x5b, 0xf4, 0xb8, 0xb3, 0x27, 0xd6, 0xa2, 0x45, 0xa0, 0x04, 0x69,
		0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x01, 0x69, 0x21, 0x23, 0x2d, 0x33, 0xb3, 0x07,
		0x67, 0xd9, 0x7a, 0x6a, 0x69, 0x1b, 0x8d, 0x27, 0x16, 0x34, 0x75, 0xf1, 0xf9, 0x1e, 0x7d, 0x76,
		0x00, 0x18, 0x0b, 0x18, 0x0b, 0x18, 0x0b, 0x18, 0x8b, 0x0e, 0xc6, 0x42, 0x9d, 0x6d, 0x10, 0x5f,
		0xd8, 0x8d, 0xa2, 0xc0, 0x96, 0x5e, 0x57, 0xdc, 0xeb, 0x33, 0xba, 0x05, 0xf4, 0x3c, 0x1b, 0x8b,
		0xae, 0x03, 0xae, 0xb5, 0x84, 0xc8, 0xda, 0x1d, 0x0f, 0x07, 0x07, 0xc4, 0xcb, 0x11, 0x71, 0x71,
		0x48, 0xec, 0x1c, 0x13, 0x3b, 0x07, 0xc5, 0xce, 0x51, 0xe9, 0x71, 0x58, 0x9a, 0x1c, 0x97, 0xfe,
		0x90, 0x9b, 0x51, 0xe8, 0xcd, 0x21, 0x04, 0x5f, 0x17, 0x8a, 0xaf, 0xfd, 0x6f, 0xea, 0x6c, 0x43,
		0x11, 0x85, 0xf1, 0xa3, 0x79, 0xc8, 0x3e, 0x73, 0xc0, 0xbb, 0x72, 0x74, 0xb8, 0x86, 0x18, 0xa7,
		0xe3, 0xdf, 0xde, 0x8e, 0x3c, 0x19, 0x3d, 0x70, 0xe1, 0x5d, 0xab, 0x03, 0x02, 0xf9, 0x02, 0xf9,
		0x02, 0xf9, 0x02, 0xf9, 0x02, 0xf9, 0x02, 0xf9, 0x02, 0xf9, 0x52, 0x41, 0xbe, 0x16, 0x1e, 0x57,
		0x8a, 0x30, 0x7e, 0xfc, 0x00, 0xfe, 0x45, 0x73, 0x73, 0xc4, 0x7d, 0x64, 0xb3, 0xe3, 0x60, 0xeb,
		0x06, 0x05, 0x1e, 0x06, 0x1e, 0x06, 0x1e, 0x06, 0x1e, 0x06, 0x1e, 0x06, 0x1e, 0x06, 0x1e, 0xa6,
		0x82, 0x87, 0x3d, 0xf7, 0xba, 0x13, 0x2e, 0xb6, 0xe4, 0x85, 0xc1, 0xc7, 0x68, 0x6e, 0x92, 0xf4,
		0xee, 0xdc, 0x81, 0xec, 0xda, 0x81, 0x70, 0x43, 0xdf, 0xd3, 0x4f, 0xc5, 0x56, 0xc6, 0x03, 0x16,
		0x06, 0x16, 0x06, 0x16, 0x06, 0x16, 0x06, 0x16, 0x06, 0x16, 0xf6, 0x52, 0x4f, 0xd2, 0x15, 0x5e,
		0x24, 0xa3, 0x07, 0x26, 0x4c, 0xac, 0xa4, 0x71, 0x0c, 0xb5, 0xf9, 0x54, 0xbc, 0x77, 0x43, 0x06,
		0x10, 0xb6, 0xb8, 0x41, 0xb5, 0xcb, 0xaf, 0xd5, 0xf3, 0xda, 0x47, 0xa7, 0x51, 0xff, 0x72, 0x7d,
		0xe6, 0x34, 0xce, 0xaa, 0xcd, 0xfa, 0xa5, 0x6e, 0x34, 0xfb, 0xea, 0x0e, 0x46, 0xd3, 0xfe, 0x8b,
		0x7a, 0x8f, 0x02, 0xdc, 0xd3, 0x7a, 0x46, 0xea, 0x4f, 0xef, 0xd6, 0x87, 0xf3, 0x2f, 0xcd, 0xeb,
		0xb3, 0x86, 0x73, 0x5e, 0xaf, 0x5f, 0x59, 0xda, 0x87, 0x38, 0x7e, 0x8b, 0xfb, 0xb4, 0xfe, 0x3e,
		0xd5, 0x1b, 0xb5, 0xcf, 0xb5, 0xcb, 0xea, 0x75, 0xbd, 0x81, 0xbb, 0xc4, 0xf7, 0x2e, 0x55, 0x9b,
		0x30, 0x24, 0xee, 0x80, 0x57, 0xbf, 0xfc, 0x74, 0xf6, 0x91, 0xc1, 0x1d, 0xd2, 0x3a, 0x82, 0xd6,
		0xae, 0xf1, 0xe7, 0x9d, 0x50, 0x7f, 0x06, 0x6e, 0x18, 0xd9, 0xb7, 0x7e, 0x57, 0xf6, 0xa4, 0xe8,
		0xea, 0x17, 0x7f, 0x96, 0x87, 0x03, 0xed, 0x07, 0xda, 0x0f, 0xb4, 0x1f, 0x68, 0x3f, 0xd0, 0x7e,
		0xa0, 0xfd, 0xbc, 0x10, 0x37, 0x22, 0x79, 0x2b, 0x22, 0xd9, 0xf9, 0x1e, 0x96, 0x8b, 0x0c, 0xb4,
		0x9f, 0x63, 0x8d, 0x43, 0xf8, 0xe2, 0xc9, 0xe9, 0x39, 0xb6, 0x96, 0xe7, 0x7a, 0x7e, 0x28, 0x3a,
		0xbe, 0xd7, 0x0d, 0x75, 0x4e, 0x49, 0xc3, 0xf5, 0xfa, 0x42, 0xbb, 0xbe, 0xa2, 0x3f, 0xd4, 0xb0,
		0x2e, 0xa4, 0xa7, 0xdd, 0xa3, 0x30, 0xe1, 0x3c, 0x89, 0xe1, 0x4c, 0x55, 0x38, 0x46, 0xe3, 0xf9,
		0x14, 0xb8, 0x9d, 0x48, 0xfa, 0xde, 0x47, 0xd9, 0x9f, 0x59, 0xd3, 0x21, 0xe2, 0xf5, 0xd9, 0x49,
		0xd9, 0x58, 0xc2, 0xbf, 0x58, 0xc2, 0x7a, 0xce, 0x0f, 0x37, 0x76, 0x55, 0xbf, 0xd9, 0xcd, 0xab,
		0xb7, 0xa0, 0x71, 0x28, 0x5b, 0xe6, 0x9a, 0x5a, 0xfb, 0x27, 0x63, 0x59, 0x1d, 0x2d, 0xfe, 0xa1,
		0x6a, 0x40, 0xd5, 0x80, 0xaa, 0x01, 0x55, 0x03, 0xaa, 0x46, 0x06, 0x54, 0x8d, 0x91, 0x27, 0xb5,
		0xa5, 0x44, 0x3e, 0x77, 0x22, 0xf9, 0x13, 0x8d, 0x63, 0x98, 0xdf, 0x8e, 0x9d, 0xd7, 0x0f, 0x9e,
		0xce, 0x6c, 0xb7, 0xdd, 0x6e, 0x37, 0x10, 0x61, 0x68, 0x31, 0x08, 0x09, 0x19, 0xac, 0x10, 0x5e,
		0x2b, 0x85, 0xcf, 0x8a, 0x59, 0xb3, 0x72, 0xee, 0x8a, 0x8c, 0xd6, 0x4e, 0x62, 0x0d, 0x1d, 0x33,
		0x1a, 0xd3, 0x95, 0x1b, 0x45, 0x22, 0xf0, 0xd8, 0x2c, 0xa7, 0x78, 0x60, 0xfb, 0xfb, 0x37, 0x87,
		0xf6, 0x49, 0xeb, 0xf1, 0x26, 0x6f, 0x9f, 0xb4, 0x66, 0x0f, 0xf3, 0xd3, 0x5f, 0xb3, 0xc7, 0x85,
		0x9b, 0x43, 0xbb, 0xb8, 0x78, 0x5c, 0xba, 0x39, 0xb4, 0x4b, 0xad, 0x83, 0xbf, 0xfe, 0x7a, 0x77,
		0xf0, 0xe3, 0x68, 0xfc, 0xf2, 0x37, 0x5a, 0x6c, 0xbe, 0x7a, 0x8b, 0xd3, 0xd2, 0xa8, 0x37, 0x6b,
		0x7f, 0xb0, 0x5d, 0x1f, 0x7f, 0x53, 0x2e, 0x90, 0xff, 0x30, 0x5a, 0x21, 0x2c, 0x46, 0x32, 0x7e,
		0x0b, 0xe7, 0xb3, 0xd1, 0xf9, 0x94, 0xe1, 0x7c, 0x32, 0xe1, 0x7c, 0x5c, 0xbb, 0x57, 0xb5, 0x3f,
		0xb5, 0x7e, 0xe4, 0xdf, 0x16, 0xc7, 0xa7, 0x07, 0x3f, 0x2a, 0xe3, 0xd5, 0x27, 0x1f, 0xd7, 0xbd,
		0x2c, 0xff, 0xb6, 0x32, 0x3e, 0xdd, 0xf0, 0x97, 0xf2, 0xf8, 0xf4, 0x37, 0x3f, 0xa3, 0x34, 0xde,
		0x4f, 0xbc, 0x74, 0xf2, 0x7c, 0x61, 0xd3, 0x1b, 0x8a, 0x1b, 0xde, 0x70, 0xb4, 0xe9, 0x0d, 0x47,
		0x1b, 0xde, 0xb0, 0x71, 0x48, 0x85, 0x0d, 0x6f, 0x28, 0x8d, 0x1f, 0x13, 0xaf, 0xdf, 0x5f, 0xff,
		0xd2, 0xf2, 0xf8, 0xe0, 0x71, 0xd3, 0xdf, 0x2a, 0xe3, 0xc7, 0xd3, 0x03, 0xb8, 0x62, 0x73, 0x5d,
		0x31, 0xcc, 0x85, 0xde, 0x5c, 0x40, 0x4c, 0x58, 0x48, 0x78, 0x7c, 0xe6, 0x41, 0x33, 0x31, 0xe3,
		0xa4, 0x1f, 0xb1, 0x28, 0x93, 0x4b, 0xf0, 0x2f, 0x06, 0x9b, 0xe4, 0xbc, 0xca, 0xe6, 0x12, 0x37,
		0xae, 0x76, 0xd9, 0xbc, 0xae, 0x9e, 0x9f, 0x3b, 0x57, 0x8d, 0xfa, 0x75, 0xfd, 0x43, 0xfd, 0xdc,
		0xb9, 0xfe, 0xf3, 0xea, 0xcc, 0xe2, 0x94, 0xfe, 0x10, 0xb2, 0xf2, 0xc1, 0x3f, 0x78, 0xb1, 0x81,
		0xc5, 0x6d, 0xfc, 0x58, 0x6b, 0x9c, 0x7d, 0xb8, 0x3e, 0xff, 0xd3, 0xf9, 0x50, 0xbf, 0xbc, 0x3c,
		0xfb, 0x70, 0xcd, 0xa1, 0xd4, 0x84, 0x59, 0xf8, 0xca, 0xf8, 0xee, 0xbd, 0xff, 0x7c, 0x85, 0xdb,
		0x65, 0xce, 0xed, 0xaa, 0x7d, 0xbe, 0xc0, 0xfd, 0x32, 0xe8, 0x7e, 0x5d, 0xd5, 0x2e, 0x70, 0xbb,
		0xcc, 0xb9, 0x5d, 0xcd, 0xeb, 0xea, 0x75, 0xed, 0x03, 0xee, 0x98, 0x39, 0x77, 0xac, 0xde, 0xbc,
		0xfa, 0x84, 0xfb, 0x65, 0xd6, 0xfd, 0x3a, 0xc2, 0x0d, 0x33, 0x88, 0x71, 0x34, 0x6b, 0x4d, 0xdc,
		0x2f, 0x73, 0xee, 0xd7, 0x79, 0xfd, 0x43, 0xf5, 0xdc, 0xa9, 0x7e, 0xfe, 0xdc, 0x38, 0xfb, 0x5c,
		0xbd, 0x3e, 0x63, 0x74, 0xeb, 0x58, 0x8c, 0xa4, 0x85, 0x12, 0x81, 0x9d, 0x9a, 0xf9, 0xdd, 0x28,
		0x11, 0x58, 0x9c, 0xee, 0xaf, 0xbd, 0x46, 0x60, 0x31, 0x10, 0x4d, 0xa9, 0xae, 0x1f, 0x45, 0xcf,
		0x1d, 0x0d, 0xa6, 0x79, 0xc6, 0x87, 0x28, 0x54, 0x40, 0xa1, 0x02, 0x0a, 0x15, 0x96, 0x56, 0x26,
		0x0a, 0x15, 0x7e, 0x31, 0x20, 0x14, 0x2a, 0xec, 0xa1, 0x50, 0xe1, 0x74, 0xcf, 0x1a, 0x49, 0x2f,
		0x3a, 0x2a, 0x30, 0xa8, 0x54, 0xa8, 0xa0, 0xd3, 0x01, 0x3a, 0x1d, 0x30, 0xa2, 0x17, 0x89, 0xe1,
		0xa0, 0xd3, 0x81, 0x09, 0x9a, 0x05, 0x3a, 0x1d, 0xfc, 0xc6, 0x12, 0x2e, 0x16, 0x4e, 0x8a, 0x27,
		0xe5, 0x4a, 0xe1, 0x04, 0xfd, 0x0d, 0x20, 0x5e, 0x40, 0xbc, 0xa0, 0x13, 0x2f, 0xf4, 0x06, 0x8c,
		0x4f, 0xda, 0x85, 0xce, 0x98, 0x08, 0xb2, 0x01, 0x64, 0x03, 0xc8, 0x06, 0x90, 0x0d, 0x20, 0x1b,
		0x18, 0x2c, 0x1b, 0x4c, 0x6b, 0xc2, 0xb4, 0xdb, 0x08, 0x87, 0x12, 0x30, 0x36, 0x25, 0x5f, 0x28,
		0xf1, 0xd2, 0x56, 0xb3, 0x92, 0xdb, 0xcf, 0x17, 0x6e, 0x0e, 0xed, 0xe3, 0x59, 0xd9, 0x6d, 0xbe,
		0x95, 0xa8, 0xc6, 0x9d, 0xfe, 0x5f, 0x63, 0x25, 0x58, 0x4b, 0xa7, 0x7d, 0x70, 0xaa, 0xf4, 0x42,
		0x65, 0x17, 0x7b, 0x2b, 0xd1, 0x58, 0x00, 0x86, 0xd8, 0x57, 0x9d, 0xe1, 0xcd, 0xcf, 0x8a, 0xf4,
		0x47, 0x91, 0xd0, 0x1f, 0x00, 0x3f, 0x1f, 0x0c, 0xa2, 0x60, 0x44, 0xc1, 0x88, 0x82, 0x11, 0x05,
		0x23, 0x0a, 0x46, 0x14, 0xfc, 0x42, 0xdc, 0x68, 0xfb, 0xfe, 0x40, 0xb8, 0x2c, 0xfa, 0xfc, 0xe5,
		0x77, 0x85, 0xba, 0xbc, 0xc9, 0xf0, 0x12, 0xb7, 0xaa, 0x9e, 0xe7, 0x47, 0x6e, 0x24, 0x35, 0x1d,
		0xef, 0x6d, 0x85, 0x9d, 0x6f, 0xe2, 0xd6, 0x1d, 0xce, 0x4f, 0x83, 0xcf, 0xf9, 0x43, 0xe1, 0x75,
		0xa6, 0x44, 0xc1, 0xf6, 0x44, 0xf4, 0xaf, 0x1f, 0x7c, 0xb7, 0xa5, 0x17, 0x46, 0xae, 0xd7, 0x11,
		0xb9, 0xd5, 0x27, 0xc2, 0xc4, 0x33, 0xb9, 0x61, 0xe0, 0x47, 0x7e, 0xc7, 0x1f, 0x84, 0xf1, 0xa3,
		0x5c, 0xbb, 0x3f, 0xcc, 0x05, 0xb2, 0x9d, 0x73, 0x7b, 0xd2, 0x0e, 0xdd, 0x9e, 0x0c, 0xe3, 0x47,
		0xb9, 0xa9, 0xa4, 0x34, 0xf2, 0x64, 0xc7, 0x0d, 0xa3, 0xdc, 0x60, 0x06, 0xab, 0xb9, 0x29, 0x45,
		0x0b, 0x67, 0xbf, 0x66, 0xe7, 0xcc, 0x6b, 0x30, 0x36, 0x2b, 0x8c, 0x82, 0x51, 0x27, 0xf2, 0x16,
		0x85, 0x1d, 0xf1, 0xac, 0x5c, 0xce, 0xbe, 0x71, 0x6d, 0xfe, 0x85, 0x9d, 0x95, 0x7f, 0x87, 0xab,
		0x4f, 0x38, 0x57, 0x8b, 0x19, 0x89, 0x1f, 0x39, 0xef, 0xfb, 0x43, 0xa7, 0x21, 0xdb, 0x4e, 0xb5,
		0x27, 0x9b, 0x93, 0x09, 0x59, 0x3c, 0x70, 0x6a, 0xc3, 0xbb, 0xf2, 0x97, 0xd9, 0x74, 0x38, 0xe7,
		0x7e, 0x67, 0xf2, 0x9a, 0xc6, 0x74, 0x36, 0x66, 0xbf, 0x9c, 0xe6, 0x74, 0x36, 0xde, 0x64, 0xd3,
		0xf8, 0x08, 0x0d, 0xcf, 0x1a, 0x79, 0xdf, 0x3d, 0xff, 0x5f, 0xcf, 0x76, 0xa3, 0x28, 0x90, 0xed,
		0xc9, 0x0c, 0x93, 0x1b, 0xdf, 0xb3, 0xbe, 0xb1, 0x89, 0xb1, 0x10, 0x43, 0xd0, 0xc2, 0xa1, 0x10,
		0x5f, 0x56, 0x57, 0x3c, 0xa2, 0x33, 0x0e, 0xe1, 0x11, 0x7f, 0xe8, 0x8e, 0x3b, 0xd8, 0xc4, 0x1b,
		0x6c, 0xe2, 0x0c, 0x36, 0xf1, 0x45, 0xb6, 0xc9, 0xd6, 0x47, 0x19, 0xe8, 0x31, 0xfb, 0x04, 0xc8,
		0xeb, 0x17, 0xc4, 0x92, 0x43, 0xd2, 0x2b, 0x8b, 0xe5, 0x21, 0x8b, 0x41, 0x16, 0x83, 0x2c, 0x06,
		0x59, 0x0c, 0xb2, 0x18, 0x77, 0x77, 0x16, 0x0f, 0x60, 0xe2, 0x3b, 0xec, 0x48, 0xb7, 0x38, 0xb7,
		0x84, 0x60, 0x4f, 0x43, 0xd2, 0x6c, 0x1a, 0x3c, 0x12, 0xc1, 0xb5, 0xbb, 0x37, 0x4e, 0x6e, 0x8e,
		0xa7, 0xbb, 0xe3, 0xe6, 0xf6, 0xd8, 0xba, 0x3f, 0xb6, 0x6e, 0x90, 0xad, 0x3b, 0xd4, 0xeb, 0x16,
		0x35, 0xbb, 0xc7, 0xf8, 0xae, 0x5c, 0x73, 0x70, 0x50, 0x4b, 0xb8, 0x33, 0x10, 0x6e, 0x8f, 0x59,
		0x4b, 0xd7, 0x0a, 0x83, 0xb1, 0x5c, 0xcd, 0x77, 0x21, 0xde, 0xbd, 0x9b, 0x09, 0xff, 0xb9, 0x27,
		0x67, 0xbe, 0xa3, 0xa5, 0x39, 0x1a, 0x4d, 0xc7, 0x9a, 0xed, 0xbd, 0xb0, 0x21, 0x76, 0xba, 0xb6,
		0x82, 0x18, 0x69, 0x15, 0x20, 0x75, 0x20, 0x75, 0x20, 0x75, 0x20, 0x75, 0x20, 0x75, 0xfa, 0xb5,
		0x8f, 0x65, 0x0d, 0x64, 0x20, 0x3c, 0x7e, 0x3d, 0xe8, 0xe3, 0x91, 0xbd, 0x45, 0x69, 0x3c, 0x63,
		0x27, 0xca, 0xd1, 0x99, 0xf2, 0x76, 0xaa, 0x5c, 0x9d, 0x2b, 0x7b, 0x27, 0xcb, 0xde, 0xd9, 0xb2,
		0x77, 0xba, 0x3c, 0x9c, 0x2f, 0x13, 0x27, 0xcc, 0x4f, 0x61, 0x49, 0xe0, 0xd6, 0x48, 0x7a, 0x51,
		0xbe, 0xcc, 0xf0, 0x0c, 0xc3, 0x32, 0xa3, 0x21, 0xf1, 0x68, 0x86, 0xb5, 0xfa, 0xc3, 0x0b, 0xd3,
		0xf7, 0xb8, 0x35, 0xcb, 0x62, 0x4e, 0xaf, 0x12, 0xc3, 0x63, 0xd6, 0x4c, 0x2b, 0x31, 0x3e, 0x86,
		0x0d, 0x89, 0x98, 0xc2, 0xfd, 0xb2, 0x49, 0xb8, 0xf7, 0x30, 0x89, 0x2d, 0x4d, 0xa2, 0x5c, 0x2a,
		0x1d, 0x95, 0x60, 0x16, 0x66, 0x73, 0x31, 0x7e, 0xa3, 0xc1, 0x61, 0x96, 0x6c, 0x60, 0x93, 0x51,
		0xa6, 0x4c, 0x82, 0x22, 0x73, 0xc9, 0x98, 0x61, 0x8a, 0xda, 0xd0, 0x89, 0x5e, 0xb2, 0x98, 0xa0,
		0x13, 0xbd, 0x68, 0xa5, 0x43, 0x27, 0xda, 0x72, 0x80, 0xd0, 0x89, 0x0c, 0x0a, 0x1c, 0x98, 0xeb,
		0x44, 0xc7, 0x0c, 0x65, 0xa2, 0x12, 0x64, 0xa2, 0x5f, 0xfc, 0x40, 0x26, 0xca, 0x64, 0x4c, 0x0c,
		0x99, 0xc8, 0x74, 0xb4, 0x5f, 0x36, 0x09, 0xc8, 0x44, 0x5b, 0x9b, 0x44, 0xa1, 0x04, 0x91, 0x28,
		0x03, 0xb2, 0xcc, 0x1e, 0x44, 0x22, 0x86, 0xf3, 0xc1, 0x46, 0x24, 0xba, 0x9b, 0x5b, 0x3b, 0x47,
		0x95, 0x68, 0x36, 0x36, 0xc8, 0x44, 0xeb, 0x86, 0x03, 0x99, 0xe8, 0x05, 0xab, 0x09, 0x32, 0xd1,
		0x8b, 0x56, 0x3a, 0x64, 0xa2, 0x2d, 0x07, 0x08, 0x99, 0xc8, 0xa0, 0xc0, 0x81, 0xb1, 0x4c, 0xd4,
		0x96, 0x9e, 0x1b, 0x3c, 0x30, 0xd4, 0x89, 0x4e, 0x18, 0x0d, 0xe9, 0x5c, 0x78, 0xfd, 0x69, 0x21,
		0x17, 0x84, 0xa2, 0x5f, 0x45, 0xc5, 0x10, 0x8a, 0xb6, 0x8e, 0x8a, 0xf3, 0x88, 0x89, 0x0d, 0xc7,
		0xfb, 0x65, 0x93, 0x80, 0x50, 0xb4, 0xb5, 0x49, 0x20, 0x9f, 0x28, 0x23, 0xe2, 0xcc, 0x1e, 0xa4,
		0x22, 0x86, 0xf3, 0xc1, 0x41, 0x2a, 0x12, 0xf7, 0x91, 0xf0, 0xba, 0xa2, 0xcb, 0x4f, 0x28, 0x8a,
		0x47, 0x06, 0x99, 0x68, 0xdd, 0x70, 0x20, 0x13, 0xbd, 0x60, 0x2d, 0x41, 0x26, 0x7a, 0xd1, 0x4a,
		0x87, 0x4c, 0xb4, 0xe5, 0x00, 0x21, 0x13, 0x19, 0x14, 0x36, 0x70, 0x96, 0x89, 0xb4, 0x9f, 0x12,
		0xb1, 0xc9, 0x0d, 0x6a, 0x3a, 0x35, 0x02, 0x24, 0x6e, 0xdd, 0x3d, 0xf1, 0x87, 0x93, 0x48, 0xc8,
		0x1d, 0xf0, 0x23, 0x71, 0xf1, 0xc8, 0x40, 0xe2, 0x40, 0xe2, 0x40, 0xe2, 0x40, 0xe2, 0x40, 0xe2,
		0x40, 0xe2, 0x40, 0xe2, 0x40, 0xe2, 0x40, 0xe2, 0x56, 0xef, 0xc9, 0xd0, 0x0d, 0x22, 0xc9, 0x91,
		0xc3, 0x2d, 0x06, 0x06, 0x0a, 0x07, 0x0a, 0x07, 0x0a, 0x07, 0x0a, 0x07, 0x0a, 0x07, 0x0a, 0x07,
		0x0a, 0x07, 0x0a, 0x07, 0x0a, 0xb7, 0x7a, 0x4f, 0xa2, 0xc0, 0xf5, 0x42, 0x19, 0xc9, 0x3b, 0x86,
		0x79, 0xf7, 0xcf, 0xc6, 0x06, 0x22, 0x07, 0x22, 0x07, 0x22, 0x07, 0x22, 0x07, 0x22, 0x07, 0x22,
		0x07, 0x22, 0x07, 0x22, 0xc7, 0x8c, 0xc8, 0xed, 0x74, 0x3b, 0x7a, 0xcd, 0xc7, 0xf8, 0x27, 0xc6,
		0xc3, 0xfb, 0x58, 0xff, 0xe4, 0x99, 0xe7, 0xc9, 0xa7, 0x72, 0x1c, 0x0e, 0x7c, 0x99, 0xcd, 0x65,
		0x14, 0x8c, 0x3a, 0x91, 0x37, 0x87, 0xa2, 0x7a, 0x3c, 0x95, 0xab, 0x47, 0xfd, 0xaf, 0xfc, 0x3b,
		0x5c, 0x7d, 0xc2, 0xb9, 0x5a, 0x4c, 0x63, 0xfc, 0xc8, 0x79, 0xdf, 0x1f, 0x3a, 0x0d, 0xd9, 0x76,
		0xaa, 0x3d, 0xd9, 0x9c, 0xcc, 0xe2, 0xe2, 0x81, 0x53, 0x1b, 0xde, 0x95, 0xbf, 0xcc, 0xe6, 0xd0,
		0x39, 0xf7, 0x3b, 0x93, 0xd7, 0x34, 0xa6, 0x53, 0x38, 0xfb, 0xe5, 0x7c, 0x99, 0xcd, 0x57, 0x35,
		0x9e, 0xc1, 0xc4, 0x33, 0x4e, 0x73, 0x3a, 0x81, 0xbb, 0x7a, 0x72, 0xd2, 0x4e, 0x9d, 0x04, 0xfa,
		0x5f, 0xf1, 0xc0, 0xa1, 0x95, 0x9f, 0x75, 0x2e, 0xc3, 0x68, 0xb2, 0x00, 0xf5, 0x1e, 0x4b, 0x7a,
		0x21, 0xbd, 0xb3, 0x81, 0x98, 0xf0, 0xce, 0x50, 0x6f, 0x5c, 0x68, 0x5d, 0xb8, 0xf7, 0xcf, 0x46,
		0x92, 0x3f, 0x2e, 0x16, 0xcb, 0x95, 0x62, 0xf1, 0xb0, 0x72, 0x54, 0x39, 0x3c, 0x29, 0x95, 0xf2,
		0xe5, 0xbc, 0xc6, 0x32, 0x0d, 0xab, 0x1e, 0x74, 0x45, 0x20, 0xba, 0xef, 0x27, 0x4b, 0xc7, 0x1b,
		0x0d, 0x06, 0x3b, 0x65, 0x31, 0x4c, 0x1c, 0x76, 0x06, 0x1c, 0xb5, 0xa5, 0xf5, 0x8c, 0x3a, 0x23,
		0x5d, 0xb3, 0x1e, 0xa7, 0x4c, 0xef, 0x12, 0x69, 0xaf, 0x48, 0x0c, 0x25, 0xba, 0x21, 0xc4, 0x38,
		0xe8, 0xd0, 0x00, 0x14, 0x86, 0x00, 0x04, 0x2d, 0x1e, 0xd0, 0x59, 0x25, 0xcd, 0x95, 0x88, 0xec,
		0x7e, 0x41, 0xb2, 0x67, 0x52, 0xf0, 0x9e, 0x1f, 0xc8, 0xbe, 0xf4, 0xf6, 0x26, 0xe6, 0x67, 0x4b,
		0xaa, 0x6a, 0x37, 0x3d, 0x04, 0x5b, 0x1f, 0xa1, 0x66, 0x45, 0xa0, 0xf5, 0x10, 0x66, 0xaa, 0xd5,
		0xad, 0xc9, 0x9b, 0xf1, 0xf6, 0x62, 0x84, 0x2e, 0x8b, 0xa5, 0xab, 0xa2, 0x71, 0x4c, 0xea, 0xdd,
		0x84, 0xda, 0x2b, 0x28, 0x36, 0x51, 0x6a, 0xd3, 0xe4, 0x6a, 0x92, 0x04, 0xc6, 0xc8, 0xcc, 0x08,
		0xd5, 0x9a, 0x9f, 0x3a, 0xa3, 0x50, 0x68, 0x10, 0x44, 0xc7, 0xd2, 0x93, 0x1e, 0x3b, 0x4f, 0x74,
		0xac, 0xfc, 0x53, 0xaa, 0x4c, 0x41, 0xf1, 0x85, 0x08, 0x53, 0x60, 0xf4, 0xa4, 0xb6, 0x50, 0xa7,
		0xac, 0x68, 0x4b, 0x45, 0xd1, 0x96, 0x62, 0xa2, 0x2d, 0x75, 0x04, 0x54, 0xc1, 0x68, 0xaa, 0x40,
		0xb5, 0x6b, 0xcc, 0x86, 0x29, 0x10, 0xec, 0xf2, 0x2a, 0x24, 0x0a, 0x6f, 0x0c, 0x32, 0x32, 0x2a,
		0xe3, 0x62, 0x67, 0x54, 0x96, 0x52, 0x3a, 0xc7, 0xc2, 0x8c, 0xd4, 0x18, 0x50, 0xfa, 0xcb, 0x5b,
		0xc1, 0xd2, 0xb6, 0x3c, 0x21, 0xfb, 0xdf, 0xda, 0x7e, 0x10, 0x2a, 0x5b, 0xd5, 0x31, 0x49, 0x7b,
		0xba, 0x94, 0x22, 0x13, 0x55, 0xcb, 0xa4, 0x95, 0x33, 0x68, 0x0a, 0xe6, 0x4c, 0xcb, 0x98, 0xa9,
		0x98, 0x32, 0x39, 0x43, 0x26, 0x67, 0xc6, 0xe4, 0x8c, 0xd8, 0x2c, 0xe7, 0xfc, 0x51, 0xaa, 0xdd,
		0x14, 0x89, 0xb1, 0x8b, 0x4e, 0x7b, 0x88, 0xaf, 0x98, 0x31, 0xf9, 0xe1, 0x10, 0xf2, 0x03, 0xe4,
		0x07, 0xc8, 0x0f, 0x19, 0x94, 0x1f, 0x54, 0x83, 0x70, 0x7c, 0x21, 0xb7, 0xfb, 0xcf, 0xf4, 0x9e,
		0x48, 0xcf, 0x1e, 0xfa, 0x61, 0x44, 0x67, 0x09, 0xf1, 0x79, 0x48, 0x2b, 0x03, 0xa0, 0xca, 0x41,
		0x20, 0x81, 0x6a, 0x72, 0xc8, 0xd6, 0x01, 0xdd, 0x7a, 0x21, 0x5c, 0x17, 0x94, 0x6b, 0x87, 0x74,
		0xed, 0xd0, 0xae, 0x1d, 0xe2, 0x69, 0xa0, 0x9e, 0x08, 0xf2, 0xc9, 0xa1, 0x3f, 0xbe, 0xe0, 0x7c,
		0x53, 0x98, 0xdc, 0x70, 0x16, 0x70, 0x41, 0xb6, 0x29, 0xad, 0xd1, 0x01, 0x90, 0x09, 0x1f, 0x9c,
		0x1c, 0x02, 0x0f, 0xc7, 0xa0, 0xdb, 0x41, 0xb0, 0x71, 0x14, 0x6c, 0x1c, 0x06, 0x1b, 0xc7, 0x41,
		0xeb, 0x40, 0x88, 0x1d, 0x89, 0x36, 0x87, 0xb2, 0xec, 0x58, 0xf4, 0xd9, 0xdb, 0x92, 0x7f, 0xd1,
		0x65, 0x6b, 0x7a, 0xdc, 0x8c, 0xb6, 0xb8, 0x83, 0x93, 0xdb, 0xe1, 0xe5, 0x7e, 0xb8, 0xb8, 0x21,
		0x76, 0xee, 0x88, 0x9d, 0x5b, 0x62, 0xe7, 0x9e, 0xf4, 0xb8, 0x29, 0x4d, 0xee, 0x4a, 0xbb, 0xdb,
		0x8a, 0x07, 0xb0, 0xa8, 0x48, 0xd1, 0x6e, 0xa9, 0x4f, 0x8d, 0x68, 0x29, 0x4b, 0x64, 0x7e, 0xe5,
		0xd2, 0x34, 0xb7, 0x09, 0x63, 0xd3, 0xaf, 0x8c, 0x53, 0x9f, 0x32, 0x9e, 0xfd, 0xc9, 0xb8, 0xf5,
		0x25, 0x63, 0xdb, 0x8f, 0x8c, 0x6d, 0x1f, 0x32, 0xb6, 0xfd, 0xc7, 0x76, 0xbb, 0x59, 0x12, 0x9b,
		0x3e, 0x63, 0x31, 0xee, 0x0c, 0x84, 0xdb, 0x0b, 0x44, 0x8f, 0x03, 0xe8, 0x2c, 0x22, 0xaf, 0x0a,
		0x83, 0xb1, 0x5c, 0xcd, 0x53, 0x10, 0xdf, 0xbd, 0x9b, 0xe5, 0xd5, 0xe6, 0x16, 0xae, 0x7c, 0x57,
		0x9b, 0x0a, 0x69, 0x8c, 0xbf, 0x86, 0x3c, 0xdc, 0xf5, 0x13, 0xab, 0x63, 0x11, 0x7c, 0x81, 0xd4,
		0x81, 0xd4, 0x81, 0xd4, 0x81, 0xd4, 0x81, 0xd4, 0x81, 0xd4, 0x81, 0xd4, 0xbd, 0x92, 0xd4, 0xcd,
		0x60, 0x07, 0x9c, 0x8e, 0xfc, 0x56, 0xd0, 0xd4, 0x32, 0xff, 0xb6, 0xc1, 0x70, 0xe8, 0xb8, 0xaa,
		0x79, 0xe7, 0x09, 0x8c, 0x0e, 0x8c, 0x0e, 0x8c, 0x0e, 0x8c, 0x0e, 0x8c, 0x4e, 0xff, 0x4e, 0x56,
		0x3c, 0x90, 0x69, 0x5b, 0x63, 0xe9, 0x75, 0xc5, 0x3d, 0xbf, 0xf3, 0x79, 0x9e, 0x8d, 0x0d, 0xe7,
		0xf3, 0x70, 0x76, 0xa4, 0x1c, 0x1d, 0x2a, 0x6f, 0xc7, 0xca, 0xd5, 0xc1, 0xb2, 0x77, 0xb4, 0xec,
		0x1d, 0x2e, 0x7b, 0xc7, 0xcb, 0xc3, 0x01, 0x33, 0x71, 0xc4, 0xfc, 0x24, 0x16, 0xc6, 0x52, 0x0b,
		0x47, 0xc9, 0x65, 0x9d, 0xf4, 0xf2, 0x93, 0xff, 0xa6, 0x94, 0x22, 0x14, 0x51, 0x18, 0x3f, 0x9a,
		0x0b, 0x35, 0x33, 0x9a, 0x81, 0xf3, 0x86, 0xb8, 0x18, 0xa5, 0xd5, 0x16, 0x61, 0x64, 0xcf, 0xfb,
		0xb4, 0x30, 0xe3, 0xa5, 0x4f, 0x43, 0x03, 0x2d, 0x05, 0x2d, 0x05, 0x2d, 0x05, 0x2d, 0x05, 0x2d,
		0x05, 0x2d, 0xdd, 0x31, 0x5a, 0x8a, 0x63, 0x23, 0x41, 0xe3, 0x7e, 0xe3, 0x9e, 0x74, 0xfc, 0xdb,
		0xdb, 0x91, 0x27, 0xa3, 0x07, 0xae, 0x22, 0xe3, 0xea, 0x00, 0x41, 0xe9, 0x40, 0xe9, 0x40, 0xe9,
		0x40, 0xe9, 0x40, 0xe9, 0x40, 0xe9, 0x76, 0x8c, 0xd2, 0x41, 0x69, 0xfc, 0x3d, 0xd7, 0xf3, 0x5b,
		0x4a, 0xe3, 0x82, 0x57, 0x48, 0x11, 0xc6, 0x8f, 0x1f, 0x20, 0x36, 0xf2, 0x64, 0xa9, 0xe2, 0x3e,
		0xb2, 0xd9, 0x33, 0xd5, 0x75, 0x83, 0x04, 0x5b, 0x05, 0x5b, 0x05, 0x5b, 0x05, 0x5b, 0x05, 0x5b,
		0x05, 0x5b, 0x05, 0x5b, 0x05, 0x5b, 0x7d, 0x2d, 0x5b, 0x7d, 0xce, 0x2d, 0x26, 0x8c, 0x75, 0x89,
		0x6b, 0x80, 0xb5, 0xf2, 0x64, 0xad, 0xd2, 0xbb, 0x73, 0x07, 0xb2, 0x6b, 0x07, 0xc2, 0x0d, 0x35,
		0x9f, 0xb5, 0xbf, 0xd6, 0x42, 0x57, 0xc6, 0x07, 0xae, 0x0a, 0xae, 0x0a, 0xae, 0x0a, 0xae, 0x0a,
		0xae, 0x0a, 0xae, 0xba, 0x63, 0x5c, 0x55, 0x76, 0x85, 0x17, 0xc9, 0xe8, 0x81, 0x29, 0x5f, 0x2d,
		0x31, 0x1a, 0x53, 0x6d, 0x3e, 0x55, 0xef, 0xdd, 0x90, 0x21, 0xa4, 0x2e, 0x6e, 0x68, 0xed, 0xf2,
		0x6b, 0xf5, 0xbc, 0xf6, 0xd1, 0x69, 0xd4, 0xbf, 0x5c, 0x9f, 0x39, 0x8d, 0xb3, 0x6a, 0xb3, 0x7e,
		0xc9, 0x0d, 0x5d, 0xbf, 0xba, 0x83, 0xd1, 0xb4, 0x89, 0xf7, 0x0d, 0xab, 0x71, 0x4d, 0x7e, 0x7e,
		0xb0, 0x1b, 0xd1, 0xda, 0xbb, 0xfb, 0xe1, 0xfc, 0x4b, 0xf3, 0xfa, 0xac, 0xe1, 0x9c, 0xd7, 0xeb,
		0x57, 0x16, 0xbb, 0x21, 0x8f, 0xdf, 0xe2, 0xbe, 0xbe, 0xee, 0xbe, 0xd6, 0x1b, 0xb5, 0xcf, 0xb5,
		0xcb, 0xea, 0x75, 0xbd, 0x81, 0xbb, 0x9a, 0x9d, 0xbb, 0x5a, 0x6d, 0xc2, 0x50, 0xb3, 0x06, 0xc0,
		0xf5, 0xcb, 0x4f, 0x67, 0x1f, 0x19, 0xde, 0x51, 0x56, 0x23, 0x6a, 0x21, 0x1e, 0x61, 0x36, 0x0a,
		0x0e, 0xea, 0xe0, 0xc0, 0x0d, 0x23, 0xfb, 0xd6, 0xef, 0xca, 0x9e, 0x14, 0x5d, 0x7e, 0xe2, 0xe0,
		0xf2, 0xf0, 0xa0, 0x0d, 0xae, 0x1b, 0x0e, 0xb4, 0xc1, 0x17, 0x2c, 0x28, 0x68, 0x83, 0x2f, 0x5a,
		0xe9, 0xd0, 0x06, 0xb7, 0x1c, 0x20, 0xb4, 0x41, 0x83, 0xb8, 0x2f, 0x63, 0x6d, 0x30, 0x92, 0xb7,
		0x22, 0x92, 0x9d, 0xef, 0x61, 0xb9, 0xc8, 0x50, 0x1b, 0x3c, 0x66, 0x34, 0xa4, 0x2f, 0x9e, 0x8c,
		0xc2, 0xe9, 0xe1, 0xcd, 0xae, 0xe7, 0x87, 0xa2, 0xe3, 0x7b, 0xdd, 0x90, 0xd3, 0x94, 0x35, 0x5c,
		0xaf, 0x2f, 0xd8, 0xe9, 0x6d, 0xfc, 0x42, 0x3d, 0xeb, 0x42, 0x7a, 0xec, 0x3c, 0x22, 0x53, 0x0e,
		0x98, 0x18, 0xde, 0x54, 0xd5, 0x65, 0x3c, 0xbe, 0x4f, 0x81, 0xdb, 0x89, 0xa4, 0xef, 0x7d, 0x94,
		0xfd, 0x99, 0xb5, 0x1e, 0x42, 0x8f, 0xf9, 0x1d, 0x93, 0x70, 0xef, 0x61, 0x12, 0x5b, 0x9a, 0x44,
		0xfe, 0xb8, 0x58, 0x2c, 0x57, 0x8a, 0xc5, 0xc3, 0xca, 0x51, 0xe5, 0xf0, 0xa4, 0x54, 0xca, 0x97,
		0x39, 0xed, 0x6c, 0x19, 0x67, 0x25, 0x6f, 0x30, 0x9a, 0x75, 0x3f, 0x2d, 0x68, 0x5c, 0x5c, 0x50,
		0x94, 0xcd, 0x79, 0x5c, 0x09, 0x52, 0xcf, 0xe3, 0x5c, 0x2e, 0xa6, 0x00, 0x0e, 0x5d, 0xeb, 0x25,
		0x4b, 0x09, 0xba, 0xd6, 0x8b, 0x56, 0x3a, 0x74, 0xad, 0x2d, 0x07, 0x08, 0x5d, 0xcb, 0xa0, 0x18,
		0x82, 0xb1, 0xae, 0x35, 0x92, 0x5e, 0x74, 0x54, 0x60, 0x28, 0x69, 0x55, 0x20, 0x19, 0xfd, 0xe2,
		0x07, 0x92, 0x51, 0x26, 0xe3, 0x63, 0x48, 0x46, 0xa6, 0xc3, 0xfd, 0xb2, 0x49, 0x40, 0x32, 0xda,
		0xda, 0x24, 0x8a, 0x85, 0x93, 0xe2, 0x49, 0xb9, 0x52, 0x38, 0x81, 0x50, 0x94, 0x01, 0x69, 0x66,
		0x0f, 0x42, 0x11, 0xc3, 0xf9, 0x60, 0x21, 0x14, 0xf1, 0x0a, 0xf0, 0x79, 0x9d, 0xf4, 0xc9, 0x14,
		0xb4, 0x21, 0x13, 0xbd, 0x64, 0x25, 0x41, 0x26, 0x7a, 0xd1, 0x4a, 0x87, 0x4c, 0xb4, 0xe5, 0x00,
		0x21, 0x13, 0x19, 0x14, 0x37, 0x70, 0x2e, 0x8d, 0x1c, 0xde, 0x95, 0x6d, 0x76, 0x36, 0x18, 0x97,
		0x46, 0x1e, 0xf3, 0x6a, 0xe5, 0x11, 0x89, 0xc0, 0x63, 0x27, 0x17, 0x59, 0xfb, 0xfb, 0x37, 0x87,
		0xf6, 0x89, 0x6b, 0xf7, 0xaa, 0xf6, 0xa7, 0xd6, 0x8f, 0xfc, 0xdb, 0xe2, 0xf8, 0xf4, 0xe0, 0x47,
		0x65, 0xbc, 0xfa, 0xe4, 0xe3, 0xba, 0x97, 0xe5, 0xdf, 0x56, 0xc6, 0xa7, 0x1b, 0xfe, 0x52, 0x1e,
		0x9f, 0xfe, 0xe6, 0x67, 0x94, 0xc6, 0xfb, 0x89, 0x97, 0x4e, 0x9e, 0x2f, 0x6c, 0x7a, 0x43, 0x71,
		0xc3, 0x1b, 0x8e, 0x36, 0xbd, 0xe1, 0x68, 0xc3, 0x1b, 0x36, 0x0e, 0xa9, 0xb0, 0xe1, 0x0d, 0xa5,
		0xf1, 0x63, 0xe2, 0xf5, 0xfb, 0xeb, 0x5f, 0x5a, 0x1e, 0x1f, 0x3c, 0x6e, 0xfa, 0x5b, 0x65, 0xfc,
		0x78, 0x7a, 0x70, 0x90, 0xdb, 0xcf, 0x17, 0x6e, 0x0e, 0xed, 0xe3, 0xd6, 0x63, 0xfe, 0xe6, 0xd0,
		0xce, 0xb7, 0x26, 0xaf, 0x6c, 0x3d, 0xde, 0xe4, 0xed, 0x93, 0xc5, 0xc3, 0xc9, 0xff, 0x0f, 0xf8,
		0xc0, 0x72, 0x8b, 0x93, 0x3d, 0xd5, 0x9b, 0xb5, 0x3f, 0xd8, 0x1a, 0xd5, 0xdf, 0xb0, 0x2a, 0xe6,
		0x56, 0xf5, 0x1f, 0x0b, 0x5a, 0x03, 0xb4, 0x86, 0x84, 0xe1, 0xce, 0x9b, 0x1e, 0xf9, 0xa3, 0x48,
		0xf0, 0x13, 0x1c, 0x9e, 0x0f, 0x0e, 0xaa, 0x03, 0x54, 0x07, 0xa8, 0x0e, 0x50, 0x1d, 0xa0, 0x3a,
		0x40, 0x75, 0xd8, 0x31, 0xd5, 0x01, 0xa7, 0x17, 0xf1, 0xa7, 0x72, 0x3b, 0x7d, 0x40, 0x7c, 0xd5,
		0xf3, 0xfc, 0xc8, 0x8d, 0x24, 0x93, 0xbe, 0x9e, 0x56, 0xd8, 0xf9, 0x26, 0x6e, 0xdd, 0xf9, 0x79,
		0x9c, 0x56, 0xce, 0x1f, 0x0a, 0xaf, 0x33, 0x25, 0x4a, 0xb6, 0x27, 0xa2, 0x7f, 0xfd, 0xe0, 0xbb,
		0x2d, 0xbd, 0x30, 0x72, 0xbd, 0x8e, 0xc8, 0xad, 0x3e, 0x11, 0x26, 0x9e, 0xc9, 0x0d, 0x03, 0x3f,
		0xf2, 0x3b, 0xfe, 0x20, 0x8c, 0x1f, 0xe5, 0xda, 0xfd, 0x61, 0x2e, 0x90, 0xed, 0x9c, 0xdb, 0x93,
		0x76, 0xe8, 0xf6, 0x64, 0x18, 0x3f, 0xca, 0x4d, 0x25, 0xc2, 0x91, 0x27, 0x3b, 0x6e, 0x18, 0xe5,
		0x3c, 0x21, 0xfb, 0xdf, 0xda, 0x7e, 0x10, 0xc6, 0x8f, 0x72, 0x6e, 0xf7, 0x9f, 0xa9, 0x27, 0x90,
		0x9e, 0x3d, 0xf4, 0xc3, 0x28, 0x37, 0x65, 0xb7, 0xe1, 0xec, 0xd7, 0xac, 0x77, 0x2d, 0x03, 0x3b,
		0xb7, 0xc2, 0x28, 0x18, 0x75, 0x22, 0x6f, 0x0e, 0x40, 0xf5, 0x78, 0x02, 0x2f, 0x67, 0x93, 0x53,
		0x9b, 0xcf, 0x8d, 0xb3, 0xf2, 0xef, 0x70, 0xf5, 0x09, 0xe7, 0x6a, 0x31, 0x79, 0xf1, 0x23, 0xe7,
		0x7d, 0x7f, 0xe8, 0x34, 0x64, 0xdb, 0xa9, 0xf6, 0x64, 0x73, 0x32, 0x77, 0x8b, 0x07, 0x4e, 0x6d,
		0x78, 0x57, 0xfe, 0x32, 0x9b, 0x39, 0xe7, 0x72, 0x31, 0x73, 0xf1, 0x23, 0xa7, 0xda, 0xfd, 0xa7,
		0x21, 0xdb, 0x35, 0xef, 0xca, 0x0f, 0x23, 0xa7, 0x31, 0x9d, 0xb6, 0xd9, 0x2f, 0xa7, 0x39, 0x9d,
		0xb6, 0x37, 0xbb, 0x09, 0x00, 0x1a, 0x8d, 0xdf, 0x1a, 0x79, 0xdf, 0x3d, 0xff, 0x5f, 0xcf, 0x76,
		0xa3, 0x28, 0x90, 0xed, 0xc9, 0x1d, 0xd1, 0x0e, 0x00, 0x4f, 0x29, 0x9d, 0xc9, 0xb1, 0x69, 0x86,
		0xc9, 0x85, 0xd3, 0xd4, 0x3c, 0x0c, 0x2e, 0x31, 0x23, 0xa7, 0x58, 0x91, 0x67, 0x8c, 0xc8, 0x2d,
		0x36, 0x64, 0x1b, 0x13, 0xb2, 0x8d, 0x05, 0xd9, 0xc6, 0x80, 0xbb, 0x4d, 0x58, 0x3f, 0xca, 0x80,
		0x07, 0xec, 0x24, 0x9c, 0x14, 0x3f, 0x11, 0x36, 0x39, 0x44, 0x5e, 0x52, 0x6c, 0x1e, 0x52, 0x2c,
		0x7b, 0xf7, 0xca, 0xdb, 0xcd, 0x72, 0x75, 0xb7, 0xec, 0xdd, 0x2e, 0x7b, 0xf7, 0xcb, 0xde, 0x0d,
		0xf3, 0x51, 0xb0, 0xf6, 0x18, 0x49, 0xb1, 0x5c, 0xdc, 0x73, 0x3c, 0xa0, 0x89, 0xef, 0xb3, 0x23,
		0x6e, 0x02, 0xf1, 0x12, 0xa2, 0x3e, 0x0d, 0x91, 0x99, 0xe9, 0xf1, 0x2c, 0xae, 0x61, 0xe7, 0xae,
		0x39, 0xbb, 0x6d, 0x33, 0xdc, 0x37, 0x77, 0x37, 0x6e, 0x8c, 0x3b, 0x37, 0xc6, 0xad, 0x1b, 0xe3,
		0xde, 0x79, 0xb9, 0x79, 0x66, 0xee, 0x3e, 0xbe, 0x8b, 0xd7, 0x1c, 0x1d, 0xec, 0x1e, 0xef, 0x63,
		0x1c, 0x13, 0xd1, 0x70, 0x85, 0xe1, 0xd8, 0x9e, 0x1d, 0xeb, 0x38, 0x3b, 0x9d, 0xf1, 0x89, 0xac,
		0xa0, 0x1c, 0x93, 0xbb, 0x69, 0x5a, 0xb3, 0x4d, 0x49, 0xb6, 0xc4, 0x97, 0xcb, 0x9e, 0xe9, 0x5a,
		0x6b, 0x04, 0xe9, 0x05, 0xe9, 0x05, 0xe9, 0x05, 0xe9, 0x05, 0xe9, 0x85, 0x67, 0x5d, 0x7f, 0x17,
		0xb9, 0x69, 0x5d, 0xf1, 0xc0, 0xa6, 0x1c, 0x6d, 0x20, 0x18, 0x77, 0x32, 0x5a, 0x92, 0xbe, 0x26,
		0x23, 0x7d, 0x8b, 0xf6, 0x32, 0x19, 0x22, 0x05, 0x26, 0x90, 0x03, 0xb3, 0x48, 0x82, 0x29, 0x64,
		0xc1, 0x38, 0xd2, 0x60, 0x1c, 0x79, 0x30, 0x8e, 0x44, 0xf0, 0x24, 0x13, 0x4c, 0x49, 0x45, 0x7c,
		0x77, 0xd9, 0x2a, 0x6a, 0x09, 0xdc, 0x1c, 0x49, 0x2f, 0xca, 0x97, 0x39, 0x63, 0xe6, 0xdc, 0x8b,
		0x97, 0x19, 0x0f, 0x91, 0x67, 0x83, 0xce, 0xd5, 0x1f, 0xde, 0x3e, 0x67, 0x8f, 0x7b, 0x03, 0x4f,
		0xc3, 0xe8, 0x65, 0x62, 0xb8, 0xcc, 0x1b, 0x7c, 0x26, 0xc6, 0x6b, 0x40, 0x53, 0x43, 0x43, 0xdc,
		0xd1, 0xb2, 0x89, 0xb9, 0xf7, 0x30, 0x31, 0xc5, 0x26, 0x56, 0x2e, 0x95, 0x8e, 0x4a, 0x30, 0xb3,
		0xdd, 0xe2, 0xa2, 0xfc, 0x47, 0xd7, 0x7a, 0x83, 0xf9, 0x32, 0x14, 0xc6, 0x19, 0x67, 0xc2, 0x25,
		0x42, 0x0a, 0xae, 0x19, 0x71, 0x86, 0x78, 0x15, 0xe8, 0x82, 0x69, 0x2e, 0x46, 0xe8, 0x82, 0xa9,
		0x5a, 0x0e, 0x74, 0x41, 0xc5, 0x03, 0x86, 0x2e, 0x98, 0xe1, 0x40, 0xcc, 0x30, 0x5d, 0xf0, 0xd8,
		0x00, 0x59, 0xb0, 0x04, 0x59, 0x70, 0xcb, 0x1f, 0xc8, 0x82, 0xd0, 0x2c, 0x20, 0x0b, 0xee, 0xa0,
		0x37, 0x5a, 0x36, 0x31, 0xc8, 0x82, 0xca, 0x4d, 0xac, 0x50, 0x82, 0x28, 0xb8, 0x63, 0x44, 0x94,
		0xff, 0xe8, 0x20, 0x0a, 0x1a, 0x0b, 0xe2, 0x33, 0xa5, 0xed, 0x6e, 0x8e, 0x2e, 0x26, 0xa8, 0x82,
		0xb3, 0xb1, 0x42, 0x16, 0x7c, 0xcd, 0xf0, 0x20, 0x0b, 0xa6, 0xb8, 0x1a, 0x21, 0x0b, 0xa6, 0x6a,
		0x39, 0x90, 0x05, 0x15, 0x0f, 0x18, 0xb2, 0x60, 0x86, 0x03, 0x31, 0x83, 0x64, 0xc1, 0xb6, 0xf4,
		0xdc, 0xe0, 0xc1, 0x00, 0x5d, 0xf0, 0x84, 0xf1, 0x10, 0xcf, 0x85, 0xd7, 0x9f, 0x16, 0xe6, 0x42,
		0x18, 0xdc, 0x56, 0xb5, 0x80, 0x30, 0xa8, 0x5c, 0xb5, 0xc8, 0x43, 0xb3, 0xd8, 0x31, 0x7f, 0xb4,
		0x6c, 0x62, 0x10, 0x06, 0x95, 0x9b, 0x18, 0xf2, 0x05, 0x77, 0x90, 0x8c, 0xf2, 0x1f, 0x1d, 0xa4,
		0x41, 0x63, 0x61, 0xdc, 0x12, 0xf7, 0x91, 0xf0, 0xba, 0xa2, 0xcb, 0x5f, 0x18, 0x8c, 0x47, 0x0a,
		0x59, 0xf0, 0x35, 0xc3, 0x83, 0x2c, 0x98, 0xe2, 0x5a, 0x84, 0x2c, 0x98, 0xaa, 0xe5, 0x40, 0x16,
		0x54, 0x3c, 0x60, 0xc8, 0x82, 0x19, 0x0e, 0xc3, 0x4c, 0x92, 0x05, 0xd9, 0x9d, 0x94, 0xb6, 0xc9,
		0x8d, 0x33, 0x39, 0x39, 0x0d, 0xa4, 0xf6, 0x35, 0xf7, 0xd0, 0x1f, 0x4e, 0x22, 0x4f, 0x77, 0xc0,
		0x9f, 0xd4, 0xc6, 0x23, 0x05, 0xa9, 0x05, 0xa9, 0x05, 0xa9, 0x05, 0xa9, 0x05, 0xa9, 0x05, 0xa9,
		0x05, 0xa9, 0x05, 0xa9, 0x05, 0xa9, 0x85, 0x51, 0x2c, 0xdf, 0xc3, 0xa1, 0x1b, 0x44, 0xd2, 0x04,
		0x4e, 0xbb, 0x18, 0x28, 0x28, 0x2d, 0x28, 0x2d, 0x28, 0x2d, 0x28, 0x2d, 0x28, 0x2d, 0x28, 0x2d,
		0x28, 0x2d, 0x28, 0x2d, 0x28, 0x2d, 0x8c, 0x62, 0xf9, 0x1e, 0x46, 0x81, 0xeb, 0x85, 0x32, 0x92,
		0x77, 0x06, 0xd4, 0x25, 0x3d, 0x1b, 0x2b, 0x88, 0x2d, 0x88, 0x2d, 0x88, 0x2d, 0x88, 0x2d, 0x88,
		0x2d, 0x88, 0x2d, 0x88, 0x2d, 0x88, 0x2d, 0x88, 0x2d, 0x46, 0xc4, 0xd4, 0x44, 0xad, 0xaa, 0xe7,
		0xf9, 0x91, 0x1b, 0x49, 0x9f, 0x67, 0x01, 0x94, 0x15, 0x76, 0xbe, 0x89, 0x5b, 0x77, 0x38, 0x3f,
		0x80, 0x32, 0xe7, 0x0f, 0x85, 0xd7, 0x99, 0x12, 0x45, 0xdb, 0x13, 0xd1, 0xbf, 0x7e, 0xf0, 0xdd,
		0x96, 0x5e, 0x18, 0xb9, 0x5e, 0x47, 0xe4, 0x56, 0x9f, 0x08, 0x13, 0xcf, 0xe4, 0x86, 0x81, 0x1f,
		0xf9, 0x1d, 0x7f, 0x10, 0xc6, 0x8f, 0x72, 0xed, 0xfe, 0x30, 0x17, 0xc8, 0x76, 0xce, 0xed, 0x49,
		0x3b, 0x74, 0x7b, 0x32, 0x8c, 0x1f, 0xe5, 0xe4, 0xf0, 0xae, 0x6c, 0x8f, 0x3c, 0xd9, 0x71, 0xc3,
		0x28, 0xe7, 0x09, 0xd9, 0xff, 0xd6, 0xf6, 0x83, 0x30, 0x7e, 0x94, 0x73, 0xbb, 0xff, 0x4c, 0x3d,
		0x95, 0xf4, 0xec, 0xa1, 0x1f, 0x46, 0xb9, 0xc0, 0x1f, 0x45, 0x22, 0x9c, 0xfd, 0xca, 0x8d, 0xbc,
		0xef, 0x9e, 0xff, 0xaf, 0x67, 0xbb, 0x51, 0x14, 0xc8, 0xf6, 0xf4, 0x0f, 0x89, 0xa7, 0x72, 0x1c,
		0xcf, 0x3e, 0x9c, 0x4d, 0x7b, 0x14, 0x8c, 0x3a, 0x91, 0x37, 0x47, 0xc5, 0x7a, 0x3c, 0xeb, 0x97,
		0xb3, 0x19, 0xad, 0xcd, 0x27, 0xd4, 0x59, 0xf9, 0x77, 0xb8, 0xfa, 0x84, 0x73, 0xb5, 0x98, 0xf1,
		0xf8, 0x91, 0xf3, 0xbe, 0x3f, 0x74, 0x1a, 0xb2, 0xed, 0x54, 0x7b, 0xb2, 0x39, 0x99, 0xf0, 0xc5,
		0x03, 0xa7, 0x36, 0xbc, 0x2b, 0x7f, 0x99, 0x4d, 0xb7, 0x73, 0xb9, 0x98, 0xee, 0xf8, 0x91, 0x53,
		0xed, 0xfe, 0xd3, 0x90, 0xed, 0x9a, 0x77, 0xe5, 0x87, 0x91, 0xd3, 0x98, 0xce, 0xf5, 0xec, 0x97,
		0xf3, 0x65, 0x36, 0xb1, 0xd5, 0x78, 0xaa, 0x13, 0xcf, 0x38, 0xcd, 0xe9, 0x4c, 0xe3, 0xb4, 0x52,
		0xc6, 0x23, 0x61, 0x02, 0x8d, 0x13, 0xb6, 0xcf, 0xb1, 0xfd, 0xb0, 0x75, 0x2e, 0xc3, 0x68, 0xb2,
		0xa0, 0x59, 0x01, 0xb5, 0x75, 0x21, 0xbd, 0xb3, 0x81, 0x98, 0x70, 0xf7, 0x90, 0x57, 0xec, 0x6e,
		0x5d, 0xb8, 0xf7, 0xcf, 0x46, 0x96, 0x3f, 0x2e, 0x16, 0xcb, 0x95, 0x62, 0xf1, 0xb0, 0x72, 0x54,
		0x39, 0x3c, 0x29, 0x95, 0xf2, 0xe5, 0x3c, 0xa3, 0x52, 0x39, 0xab, 0x1e, 0x74, 0x45, 0x20, 0xba,
		0xef, 0x27, 0x4b, 0xcf, 0x1b, 0x0d, 0x06, 0xb0, 0x48, 0xfe, 0x24, 0x25, 0xdb, 0xe4, 0xc4, 0x62,
		0x75, 0x84, 0x75, 0xb6, 0xe8, 0x08, 0x0f, 0x22, 0xa2, 0xdf, 0xed, 0xeb, 0x1d, 0x81, 0x66, 0x78,
		0xe3, 0x06, 0x6b, 0x59, 0x82, 0x33, 0x06, 0xe0, 0x65, 0x3a, 0x68, 0xe9, 0xc5, 0x28, 0x7d, 0xc8,
		0xa0, 0xe7, 0xca, 0x9a, 0xb0, 0x68, 0x11, 0xec, 0xcc, 0xb6, 0x35, 0xf6, 0x26, 0xb6, 0x6f, 0x4b,
		0x5d, 0x25, 0xd4, 0x3c, 0x22, 0x1c, 0x3e, 0x11, 0x0d, 0xeb, 0x08, 0x86, 0x47, 0xc4, 0xa2, 0xcb,
		0x6c, 0x98, 0xb8, 0x6e, 0x63, 0x5d, 0xb6, 0x46, 0xff, 0x6c, 0x96, 0x5f, 0xd6, 0xe3, 0x85, 0xe9,
		0x7d, 0x20, 0xed, 0x15, 0x89, 0x61, 0x43, 0x37, 0x5c, 0x18, 0x08, 0x13, 0x1a, 0x00, 0xc2, 0x14,
		0x60, 0xa0, 0x85, 0x04, 0x3a, 0xc3, 0xa4, 0xb9, 0x12, 0x91, 0xe9, 0xeb, 0x32, 0x79, 0x93, 0x4c,
		0x9d, 0xd0, 0xc6, 0xd9, 0xdb, 0x36, 0x8d, 0x51, 0xab, 0x37, 0x31, 0x02, 0xf3, 0xb2, 0x9e, 0x2f,
		0xa3, 0x80, 0x2e, 0xb1, 0xe8, 0xe9, 0x08, 0x82, 0xe5, 0xeb, 0x13, 0x01, 0xca, 0x22, 0xef, 0x87,
		0xe8, 0x72, 0xd4, 0xe9, 0xb8, 0x3a, 0xd2, 0x6b, 0xf5, 0xa6, 0xcb, 0xea, 0x4a, 0x7f, 0xd5, 0x9e,
		0xce, 0xaa, 0x3d, 0x3d, 0x55, 0x7b, 0xba, 0x69, 0xb6, 0xa8, 0xce, 0x47, 0x49, 0xab, 0xd8, 0x59,
		0xf3, 0x10, 0x81, 0xdc, 0x70, 0x16, 0x70, 0xa1, 0x25, 0x44, 0x21, 0x76, 0x00, 0x49, 0x47, 0x50,
		0x20, 0xbe, 0xb0, 0xc6, 0x7a, 0x0b, 0x1e, 0x75, 0x14, 0xba, 0xeb, 0x23, 0xd8, 0xd4, 0x3d, 0xb0,
		0xa9, 0x67, 0x60, 0x53, 0xa7, 0x90, 0x6d, 0xb9, 0x8c, 0xda, 0xa1, 0x2c, 0x3b, 0x16, 0x7d, 0xf6,
		0xb6, 0xe4, 0x5f, 0x74, 0xd9, 0x9a, 0x1e, 0x37, 0xa3, 0x2d, 0xee, 0xe0, 0xe4, 0x76, 0x78, 0xb9,
		0x1f, 0x2e, 0x6e, 0x88, 0x9d, 0x3b, 0x62, 0xe7, 0x96, 0xd8, 0xb9, 0x27, 0x3d, 0x6e, 0x4a, 0x93,
		0xbb, 0xd2, 0xee, 0xb6, 0xe2, 0x01, 0x2c, 0xd2, 0x37, 0xb4, 0x5b, 0xea, 0x53, 0xab, 0x27, 0x9d,
		0xf9, 0x24, 0xab, 0x2e, 0x4d, 0x73, 0x72, 0x3a, 0x9b, 0x0a, 0x77, 0x4e, 0x95, 0xec, 0x3c, 0x2b,
		0xd6, 0xb9, 0x55, 0xa6, 0xb3, 0xad, 0x40, 0x67, 0x5b, 0x69, 0xce, 0xb6, 0xa2, 0x7c, 0xb7, 0x53,
		0x9e, 0xd9, 0x54, 0x82, 0xc7, 0xb8, 0x33, 0x10, 0x6e, 0x2f, 0x10, 0x3d, 0x0e, 0xa0, 0xb3, 0x88,
		0xbc, 0x2a, 0x0c, 0xc6, 0x72, 0x35, 0xdf, 0x40, 0x7e, 0xf7, 0x6e, 0x56, 0xa4, 0x9a, 0x5b, 0xb8,
		0xf2, 0x5d, 0xcd, 0x0a, 0xd6, 0x18, 0x7f, 0x0d, 0x79, 0xb8, 0xeb, 0x27, 0x56, 0xc7, 0x22, 0xf8,
		0x02, 0xa9, 0x03, 0xa9, 0x03, 0xa9, 0x03, 0xa9, 0x03, 0xa9, 0x03, 0xa9, 0x03, 0xa9, 0x7b, 0x25,
		0xa9, 0x9b, 0xc1, 0x0e, 0x38, 0x1d, 0xf9, 0xad, 0x98, 0x75, 0x7e, 0x61, 0x43, 0xe9, 0x38, 0x34,
		0xa2, 0xd1, 0xbc, 0xf3, 0x04, 0x46, 0x07, 0x46, 0x07, 0x46, 0x07, 0x46, 0x07, 0x46, 0xa7, 0x7f,
		0x27, 0x2b, 0x1e, 0xc8, 0xb4, 0x09, 0x93, 0xf4, 0xba, 0x82, 0x4f, 0xdf, 0xdd, 0xa7, 0x34, 0xf0,
		0xa7, 0xb1, 0x71, 0xe9, 0x5c, 0xc5, 0xaa, 0xc3, 0x33, 0xbb, 0x8e, 0xce, 0x1c, 0x3b, 0x38, 0xf3,
		0xee, 0xd8, 0xcc, 0xb5, 0x43, 0x33, 0xfb, 0x8e, 0xcc, 0xec, 0x3b, 0x30, 0xb3, 0xef, 0xb8, 0x8c,
		0x9e, 0x84, 0x2c, 0x25, 0x16, 0xc6, 0x52, 0x0b, 0x47, 0xc9, 0x65, 0x9d, 0xf4, 0xf2, 0x93, 0xff,
		0xa6, 0x94, 0x22, 0x14, 0x51, 0x18, 0x3f, 0x9a, 0x0b, 0x35, 0x33, 0x9a, 0x81, 0xae, 0x61, 0x5c,
		0x8c, 0xd2, 0xea, 0xf8, 0xb7, 0xb7, 0x23, 0x4f, 0x46, 0x0f, 0x5c, 0xd9, 0xe9, 0xea, 0x00, 0x41,
		0x51, 0x41, 0x51, 0x41, 0x51, 0x41, 0x51, 0x41, 0x51, 0x41, 0x51, 0x41, 0x51, 0x41, 0x51, 0x5f,
		0x4b, 0x51, 0x17, 0xbc, 0x42, 0x8a, 0x30, 0x7e, 0xfc, 0x00, 0x96, 0xca, 0x93, 0xa5, 0x8a, 0xfb,
		0xc8, 0x66, 0xcf, 0x54, 0xd7, 0x0d, 0x12, 0x6c, 0x15, 0x6c, 0x15, 0x6c, 0x15, 0x6c, 0x15, 0x6c,
		0x15, 0x6c, 0x15, 0x6c, 0x15, 0x6c, 0xf5, 0xb5, 0x6c, 0xf5, 0x39, 0xb7, 0x98, 0x30, 0xd6, 0x25,
		0xae, 0x01, 0xd6, 0xca, 0x93, 0xb5, 0x4a, 0xef, 0xce, 0x1d, 0xc8, 0xae, 0x1d, 0x08, 0x37, 0x64,
		0x74, 0xe4, 0x4b, 0x6c, 0xa1, 0x2b, 0xe3, 0x03, 0x57, 0x05, 0x57, 0x05, 0x57, 0x05, 0x57, 0x05,
		0x57, 0x05, 0x57, 0xdd, 0x31, 0xae, 0x2a, 0xbb, 0xc2, 0x8b, 0x64, 0xf4, 0xc0, 0x94, 0xaf, 0x72,
		0x3a, 0xe0, 0xaf, 0x36, 0x9f, 0xaa, 0xf7, 0x6e, 0xc8, 0x10, 0x52, 0x17, 0x37, 0xb4, 0x76, 0xf9,
		0xb5, 0x7a, 0x5e, 0xfb, 0xe8, 0x34, 0xea, 0x5f, 0xae, 0xcf, 0x9c, 0xc6, 0x59, 0xb5, 0x59, 0xbf,
		0xe4, 0x86, 0xae, 0x5f, 0xdd, 0xc1, 0x68, 0xda, 0xfd, 0xf1, 0x86, 0xdd, 0xb9, 0xb9, 0x3c, 0x4f,
		0x38, 0x4f, 0xdc, 0xdd, 0x0f, 0xe7, 0x5f, 0x9a, 0xd7, 0x67, 0x0d, 0xe7, 0xbc, 0x5e, 0xbf, 0xe2,
		0x77, 0xc6, 0x3e, 0xc3, 0x53, 0xec, 0x0d, 0xb9, 0xaf, 0xf5, 0x46, 0xed, 0x73, 0xed, 0xb2, 0x7a,
		0x5d, 0x6f, 0xe0, 0xae, 0x66, 0xe7, 0xae, 0x56, 0x9b, 0x30, 0xd4, 0xac, 0x01, 0x70, 0xfd, 0xf2,
		0xd3, 0xd9, 0x47, 0x86, 0x77, 0x94, 0xd5, 0x88, 0x5a, 0x88, 0x47, 0x98, 0x8d, 0x82, 0x83, 0x3a,
		0x38, 0x70, 0xc3, 0xc8, 0xbe, 0xf5, 0xbb, 0xb2, 0x27, 0x45, 0x97, 0x9f, 0x38, 0xb8, 0x3c, 0x3c,
		0x68, 0x83, 0xeb, 0x86, 0x03, 0x6d, 0xf0, 0x05, 0x0b, 0x0a, 0xda, 0xe0, 0x8b, 0x56, 0x3a, 0xb4,
		0xc1, 0x2d, 0x07, 0x08, 0x6d, 0xd0, 0x20, 0xee, 0xcb, 0x58, 0x1b, 0x8c, 0xe4, 0xad, 0x88, 0x64,
		0xe7, 0x7b, 0x58, 0x2e, 0x32, 0xd4, 0x06, 0x8f, 0x19, 0x0d, 0xe9, 0x8b, 0x27, 0xa7, 0x07, 0xfc,
		0x5a, 0x9e, 0xeb, 0xf9, 0xa1, 0xe8, 0xf8, 0x5e, 0x37, 0xe4, 0x34, 0x65, 0x0d, 0xd7, 0xeb, 0x0b,
		0x76, 0x7a, 0x1b, 0xbf, 0x50, 0xcf, 0xba, 0x90, 0x1e, 0x3b, 0x8f, 0xc8, 0x94, 0x03, 0x26, 0x86,
		0x37, 0x55, 0x75, 0x19, 0x8f, 0xef, 0x53, 0xe0, 0x76, 0x22, 0xe9, 0x7b, 0x1f, 0x65, 0x7f, 0x66,
		0xad, 0x87, 0xd0, 0x63, 0x7e, 0xc7, 0x24, 0xdc, 0x7b, 0x98, 0xc4, 0x96, 0x26, 0xc1, 0xeb, 0xe0,
		0x77, 0xe3, 0xad, 0xe4, 0x0d, 0x46, 0xb3, 0xee, 0xa7, 0x05, 0x8d, 0x8b, 0x0b, 0x8a, 0xb2, 0x39,
		0xc8, 0x21, 0x41, 0xea, 0x79, 0x1c, 0xe8, 0xc0, 0x14, 0xc0, 0xa1, 0x6b, 0xbd, 0x64, 0x29, 0x41,
		0xd7, 0x7a, 0xd1, 0x4a, 0x87, 0xae, 0xb5, 0xe5, 0x00, 0xa1, 0x6b, 0x19, 0x14, 0x43, 0x30, 0xd6,
		0xb5, 0x46, 0xd2, 0x8b, 0x8e, 0x0a, 0x0c, 0x25, 0xad, 0x0a, 0x24, 0xa3, 0x5f, 0xfc, 0x40, 0x32,
		0xca, 0x64, 0x7c, 0x0c, 0xc9, 0xc8, 0x74, 0xb8, 0x5f, 0x36, 0x09, 0x48, 0x46, 0x5b, 0x9b, 0x44,
		0xb1, 0x70, 0x52, 0x3c, 0x29, 0x57, 0x0a, 0x27, 0x10, 0x8a, 0x32, 0x20, 0xcd, 0xec, 0x41, 0x28,
		0x62, 0x38, 0x1f, 0x2c, 0x84, 0x22, 0x5e, 0x01, 0x3e, 0xaf, 0x23, 0xa2, 0x98, 0x82, 0x36, 0x64,
		0xa2, 0x97, 0xac, 0x24, 0xc8, 0x44, 0x2f, 0x5a, 0xe9, 0x90, 0x89, 0xb6, 0x1c, 0x20, 0x64, 0x22,
		0x83, 0xe2, 0x06, 0xce, 0xa5, 0x91, 0xc3, 0xbb, 0xb2, 0xcd, 0xce, 0x06, 0xe3, 0xd2, 0xc8, 0x63,
		0x5e, 0xad, 0x3c, 0x22, 0x11, 0x78, 0xec, 0xe4, 0x22, 0x6b, 0x7f, 0xff, 0xe6, 0xd0, 0x3e, 0x71,
		0xed, 0x5e, 0xd5, 0xfe, 0xd4, 0xfa, 0x91, 0x7f, 0x5b, 0x1c, 0x9f, 0x1e, 0xfc, 0xa8, 0x8c, 0x57,
		0x9f, 0x7c, 0x5c, 0xf7, 0xb2, 0xfc, 0xdb, 0xca, 0xf8, 0x74, 0xc3, 0x5f, 0xca, 0xe3, 0xd3, 0xdf,
		0xfc, 0x8c, 0xd2, 0x78, 0x3f, 0xf1, 0xd2, 0xc9, 0xf3, 0x85, 0x4d, 0x6f, 0x28, 0x6e, 0x78, 0xc3,
		0xd1, 0xa6, 0x37, 0x1c, 0x6d, 0x78, 0xc3, 0xc6, 0x21, 0x15, 0x36, 0xbc, 0xa1, 0x34, 0x7e, 0x4c,
		0xbc, 0x7e, 0x7f, 0xfd, 0x4b, 0xcb, 0xe3, 0x83, 0xc7, 0x4d, 0x7f, 0xab, 0x8c, 0x1f, 0x4f, 0x0f,
		0x0e, 0x72, 0xfb, 0xf9, 0xc2, 0xcd, 0xa1, 0x7d, 0xdc, 0x7a, 0xcc, 0xdf, 0x1c, 0xda, 0xf9, 0xd6,
		0xe4, 0x95, 0xad, 0xc7, 0x9b, 0xbc, 0x7d, 0xb2, 0x78, 0x38, 0xf9, 0xff, 0x01, 0x1f, 0x58, 0x6e,
		0x71, 0xb2, 0xa7, 0x7a, 0xb3, 0xf6, 0x07, 0x5b, 0xa3, 0xfa, 0x1b, 0x56, 0xc5, 0xdc, 0xaa, 0xfe,
		0x63, 0x41, 0x6b, 0x80, 0xd6, 0x90, 0x30, 0xdc, 0x79, 0xd3, 0x23, 0x7f, 0x14, 0x09, 0x7e, 0x82,
		0xc3, 0xf3, 0xc1, 0x41, 0x75, 0x80, 0xea, 0x00, 0xd5, 0x01, 0xaa, 0x03, 0x54, 0x07, 0xa8, 0x0e,
		0x3b, 0xa6, 0x3a, 0xb4, 0x7d, 0x7f, 0x20, 0x5c, 0x8f, 0xa3, 0xe2, 0x90, 0x07, 0x95, 0x63, 0x30,
		0x02, 0xdd, 0x27, 0x8b, 0x56, 0x3d, 0xcf, 0x8f, 0xdc, 0x48, 0x32, 0xe9, 0xeb, 0x69, 0x85, 0x9d,
		0x6f, 0xe2, 0xd6, 0x1d, 0xce, 0x9b, 0xc9, 0xe6, 0xfc, 0xa1, 0xf0, 0x3a, 0x53, 0xa2, 0x64, 0x7b,
		0x22, 0xfa, 0xd7, 0x0f, 0xbe, 0xdb, 0xd2, 0x0b, 0x23, 0xd7, 0xeb, 0x88, 0xdc, 0xea, 0x13, 0x61,
		0xe2, 0x99, 0xdc, 0x30, 0xf0, 0x23, 0xbf, 0xe3, 0x0f, 0xc2, 0xf8, 0x51, 0xae, 0xdd, 0x1f, 0xe6,
		0x02, 0xd9, 0xce, 0xb9, 0x3d, 0x69, 0x87, 0x6e, 0x4f, 0x86, 0xf1, 0xa3, 0xdc, 0x54, 0x22, 0x1c,
		0x79, 0xb2, 0xe3, 0x86, 0x51, 0xce, 0x13, 0xb2, 0xff, 0xad, 0xed, 0x07, 0x61, 0xfc, 0x28, 0xe7,
		0x76, 0xff, 0x99, 0x7a, 0x02, 0xe9, 0xd9, 0xc3, 0x40, 0xe4, 0xa6, 0xe4, 0x36, 0x9c, 0xfd, 0xca,
		0x71, 0x38, 0xb0, 0x7b, 0x36, 0x81, 0x51, 0x30, 0xea, 0x44, 0xde, 0x1c, 0x7f, 0xea, 0xf1, 0xfc,
		0x5d, 0xce, 0xe6, 0xa6, 0x36, 0x9f, 0x1a, 0x67, 0xe5, 0xdf, 0xe1, 0xea, 0x13, 0xce, 0xd5, 0x62,
		0xee, 0xe2, 0x47, 0xce, 0xfb, 0xfe, 0xd0, 0x69, 0xc8, 0xb6, 0x53, 0xed, 0xc9, 0xe6, 0x64, 0xea,
		0x16, 0x0f, 0x9c, 0xda, 0xf0, 0xae, 0xfc, 0x65, 0x36, 0x71, 0xce, 0xe5, 0x62, 0xe2, 0xe2, 0x47,
		0x4e, 0xb5, 0xfb, 0x4f, 0x43, 0xb6, 0x6b, 0xde, 0x55, 0x20, 0x9c, 0xc6, 0x74, 0xd6, 0x66, 0xbf,
		0x9c, 0xe6, 0x74, 0xd6, 0x70, 0xdc, 0x3d, 0xf9, 0x2a, 0x19, 0x79, 0xdf, 0x3d, 0xff, 0x5f, 0xcf,
		0x76, 0xa3, 0x28, 0x90, 0xed, 0xc9, 0x1d, 0xe1, 0x73, 0xf6, 0xfd, 0x9a, 0xb1, 0xe1, 0x20, 0x7c,
		0x1c, 0x84, 0x6f, 0x52, 0x84, 0x88, 0x83, 0xf0, 0x4d, 0x8f, 0x04, 0x71, 0x10, 0x3e, 0x4b, 0xba,
		0xca, 0xe6, 0x20, 0xfc, 0x84, 0x93, 0xe2, 0x27, 0xc1, 0x26, 0x87, 0xc8, 0x4b, 0x88, 0xcd, 0x43,
		0x88, 0x65, 0xef, 0x5e, 0x79, 0xbb, 0x59, 0xae, 0xee, 0x96, 0xbd, 0xdb, 0x65, 0xef, 0x7e, 0xd9,
		0xbb, 0x61, 0x3e, 0xfa, 0xd5, 0x1e, 0x23, 0x21, 0x96, 0x8b, 0x7b, 0x8e, 0x07, 0x34, 0x3d, 0xb6,
		0x3d, 0xe2, 0x26, 0x0f, 0x2f, 0x21, 0xea, 0xd3, 0x10, 0x99, 0x99, 0x1e, 0xcf, 0xd2, 0x1a, 0x76,
		0xee, 0x9a, 0xb3, 0xdb, 0x36, 0xc3, 0x7d, 0x73, 0x77, 0xe3, 0xc6, 0xb8, 0x73, 0x63, 0xdc, 0xba,
		0x31, 0xee, 0x9d, 0x97, 0x9b, 0x67, 0xe6, 0xee, 0xe3, 0xbb, 0x78, 0xcd, 0xd1, 0xc1, 0xee, 0xf1,
		0x3e, 0xc4, 0x31, 0x11, 0x0d, 0x57, 0x18, 0x8e, 0xed, 0xd9, 0xa1, 0x8e, 0xb3, 0xb3, 0x19, 0x9f,
		0xc8, 0x0a, 0x8a, 0x31, 0xb9, 0x9b, 0xa6, 0x35, 0xdb, 0x93, 0x64, 0x4b, 0x7c, 0xb9, 0x6c, 0x99,
		0xae, 0xb5, 0x46, 0x90, 0x5e, 0x90, 0x5e, 0x90, 0x5e, 0x90, 0x5e, 0x90, 0x5e, 0x78, 0xd6, 0xf5,
		0x77, 0x91, 0x9b, 0xd6, 0x15, 0x0f, 0x6c, 0xca, 0xd1, 0x06, 0x82, 0x71, 0x1f, 0xa3, 0x25, 0xe9,
		0x6b, 0x32, 0xd2, 0xb7, 0x68, 0x2e, 0x93, 0x21, 0x52, 0x60, 0x02, 0x39, 0x30, 0x8b, 0x24, 0x98,
		0x42, 0x16, 0x8c, 0x23, 0x0d, 0xc6, 0x91, 0x07, 0xe3, 0x48, 0x04, 0x4f, 0x32, 0xc1, 0x94, 0x54,
		0xc4, 0x77, 0x97, 0xad, 0xa2, 0x96, 0xc0, 0xcd, 0x91, 0xf4, 0xa2, 0x7c, 0x99, 0x33, 0x66, 0xce,
		0xbd, 0x78, 0x99, 0xf1, 0x10, 0x79, 0xb6, 0xe7, 0x5c, 0xfd, 0xe1, 0xed, 0x73, 0xf6, 0xb8, 0xb7,
		0xef, 0x34, 0x8c, 0x5e, 0x26, 0x86, 0xcb, 0xbc, 0xbd, 0x67, 0x62, 0xbc, 0x06, 0xb4, 0x34, 0x34,
		0xc4, 0x1d, 0x2d, 0x9b, 0x98, 0x7b, 0x0f, 0x13, 0x53, 0x6c, 0x62, 0xe5, 0x52, 0xe9, 0xa8, 0x04,
		0x33, 0xdb, 0x2d, 0x2e, 0xca, 0x7f, 0x74, 0xad, 0x37, 0x98, 0x2f, 0x43, 0x61, 0x9c, 0x71, 0x26,
		0x5c, 0x22, 0xa4, 0xe0, 0x9a, 0x11, 0x67, 0x88, 0x57, 0x81, 0x2e, 0x98, 0xe6, 0x62, 0x84, 0x2e,
		0x98, 0xaa, 0xe5, 0x40, 0x17, 0x54, 0x3c, 0x60, 0xe8, 0x82, 0x19, 0x0e, 0xc4, 0x0c, 0xd3, 0x05,
		0x8f, 0x0d, 0x90, 0x05, 0x4b, 0x90, 0x05, 0xb7, 0xfc, 0x81, 0x2c, 0x08, 0xcd, 0x02, 0xb2, 0xe0,
		0x0e, 0x7a, 0xa3, 0x65, 0x13, 0x83, 0x2c, 0xa8, 0xdc, 0xc4, 0x0a, 0x25, 0x88, 0x82, 0x3b, 0x46,
		0x44, 0xf9, 0x8f, 0x0e, 0xa2, 0xa0, 0xb1, 0x20, 0x3e, 0x53, 0xda, 0xee, 0xe6, 0xe8, 0x62, 0x82,
		0x2a, 0x38, 0x1b, 0x2b, 0x64, 0xc1, 0xd7, 0x0c, 0x0f, 0xb2, 0x60, 0x8a, 0xab, 0x11, 0xb2, 0x60,
		0xaa, 0x96, 0x03, 0x59, 0x50, 0xf1, 0x80, 0x21, 0x0b, 0x66, 0x38, 0x10, 0x33, 0x48, 0x16, 0x6c,
		0x4b, 0xcf, 0x0d, 0x1e, 0x0c, 0xd0, 0x05, 0x4f, 0x18, 0x0f, 0xf1, 0x5c, 0x78, 0xfd, 0x69, 0x61,
		0x2e, 0x84, 0xc1, 0x6d, 0x55, 0x0b, 0x08, 0x83, 0xca, 0x55, 0x8b, 0x3c, 0x34, 0x8b, 0x1d, 0xf3,
		0x47, 0xcb, 0x26, 0x06, 0x61, 0x50, 0xb9, 0x89, 0x21, 0x5f, 0x70, 0x07, 0xc9, 0x28, 0xff, 0xd1,
		0x41, 0x1a, 0x34, 0x16, 0xc6, 0x2d, 0x71, 0x1f, 0x09, 0xaf, 0x2b, 0xba, 0xfc, 0x85, 0xc1, 0x78,
		0xa4, 0x90, 0x05, 0x5f, 0x33, 0x3c, 0xc8, 0x82, 0x29, 0xae, 0x45, 0xc8, 0x82, 0xa9, 0x5a, 0x0e,
		0x64, 0x41, 0xc5, 0x03, 0x86, 0x2c, 0x98, 0xe1, 0x30, 0xcc, 0x24, 0x59, 0x90, 0xdd, 0x39, 0x69,
		0x9b, 0xdc, 0x38, 0x93, 0x73, 0xd3, 0x40, 0x6a, 0x5f, 0x73, 0x0f, 0xfd, 0xe1, 0x24, 0xf2, 0x74,
		0x07, 0xfc, 0x49, 0x6d, 0x3c, 0x52, 0x90, 0x5a, 0x90, 0x5a, 0x90, 0x5a, 0x90, 0x5a, 0x90, 0x5a,
		0x90, 0x5a, 0x90, 0x5a, 0x90, 0x5a, 0x90, 0x5a, 0x18, 0xc5, 0xf2, 0x3d, 0x1c, 0xba, 0x41, 0x24,
		0x4d, 0xe0, 0xb4, 0x8b, 0x81, 0x82, 0xd2, 0x82, 0xd2, 0x82, 0xd2, 0x82, 0xd2, 0x82, 0xd2, 0x82,
		0xd2, 0x82, 0xd2, 0x82, 0xd2, 0x82, 0xd2, 0xc2, 0x28, 0x96, 0xef, 0x61, 0x14, 0xb8, 0x5e, 0x28,
		0x23, 0x79, 0x67, 0x40, 0x5d, 0xd2, 0xb3, 0xb1, 0x82, 0xd8, 0x82, 0xd8, 0x82, 0xd8, 0x82, 0xd8,
		0x82, 0xd8, 0x82, 0xd8, 0x82, 0xd8, 0x82, 0xd8, 0x82, 0xd8, 0x62, 0x44, 0x4c, 0x4d, 0xd4, 0xaa,
		0x7a, 0x9e, 0x1f, 0xb9, 0x91, 0xf4, 0x79, 0x16, 0x40, 0x59, 0x61, 0xe7, 0x9b, 0xb8, 0x75, 0x87,
		0xf3, 0x03, 0x28, 0x73, 0xfe, 0x50, 0x78, 0x9d, 0x29, 0x51, 0xb4, 0x3d, 0x11, 0xfd, 0xeb, 0x07,
		0xdf, 0x6d, 0xe9, 0x85, 0x91, 0xeb, 0x75, 0x44, 0x6e, 0xf5, 0x89, 0x30, 0xf1, 0x4c, 0x6e, 0x18,
		0xf8, 0x91, 0xdf, 0xf1, 0x07, 0x61, 0xfc, 0x28, 0xd7, 0xee, 0x0f, 0x73, 0x81, 0x6c, 0xe7, 0xdc,
		0x9e, 0xb4, 0x43, 0xb7, 0x27, 0xc3, 0xf8, 0x51, 0x4e, 0x0e, 0xef, 0xca, 0xf6, 0xc8, 0x93, 0x1d,
		0x37, 0x8c, 0x72, 0x9e, 0x90, 0xfd, 0x6f, 0x6d, 0x3f, 0x08, 0xe3, 0x47, 0x39, 0xb7, 0xfb, 0xcf,
		0xd4, 0x53, 0x49, 0xcf, 0x1e, 0x06, 0x22, 0x17, 0xf8, 0xa3, 0x48, 0x84, 0xb3, 0x5f, 0xb9, 0x91,
		0xf7, 0xdd, 0xf3, 0xff, 0xf5, 0x6c, 0x37, 0x8a, 0x02, 0xd9, 0x9e, 0xfe, 0x21, 0xf1, 0x54, 0x8e,
		0xe3, 0xd1, 0x87, 0xb3, 0x59, 0x8f, 0x82, 0x51, 0x27, 0xf2, 0xe6, 0xa0, 0x58, 0x8f, 0x27, 0xfd,
		0x72, 0x36, 0xa1, 0xb5, 0xf9, 0x7c, 0x3a, 0x2b, 0xff, 0x0e, 0x57, 0x9f, 0x70, 0xae, 0x16, 0x13,
		0x1e, 0x3f, 0x72, 0xde, 0xf7, 0x87, 0x4e, 0x43, 0xb6, 0x9d, 0x6a, 0x4f, 0x36, 0x27, 0xf3, 0xbd,
		0x78, 0xe0, 0xd4, 0x86, 0x77, 0xe5, 0x2f, 0xb3, 0xd9, 0x76, 0x2e, 0x17, 0xb3, 0x1d, 0x3f, 0x72,
		0xaa, 0xdd, 0x7f, 0x1a, 0xb2, 0x5d, 0xf3, 0xae, 0x02, 0xe1, 0x34, 0xa6, 0x53, 0x3d, 0xfb, 0xe5,
		0x7c, 0x99, 0xcd, 0x6b, 0x35, 0x9e, 0xe9, 0xc4, 0x33, 0x4e, 0x73, 0x3a, 0xd1, 0x38, 0xab, 0x94,
		0xf1, 0x48, 0x98, 0x00, 0xe3, 0x84, 0xeb, 0x73, 0x6c, 0x3e, 0x6c, 0x9d, 0xcb, 0x30, 0x9a, 0x2c,
		0x68, 0x56, 0x30, 0x6d, 0x5d, 0x48, 0xef, 0x6c, 0x20, 0x26, 0xcc, 0x3d, 0xe4, 0x15, 0xb9, 0x5b,
		0x17, 0xee, 0xfd, 0xb3, 0x91, 0xe5, 0x8f, 0x8b, 0xc5, 0x72, 0xa5, 0x58, 0x3c, 0xac, 0x1c, 0x55,
		0x0e, 0x4f, 0x4a, 0xa5, 0x7c, 0x39, 0xcf, 0xa8, 0x50, 0xce, 0xaa, 0x07, 0x5d, 0x11, 0x88, 0xee,
		0xfb, 0xc9, 0xd2, 0xf3, 0x46, 0x83, 0x01, 0x2c, 0x92, 0x3f, 0x45, 0xc9, 0x34, 0x35, 0xb1, 0x58,
		0x9d, 0x5f, 0x9d, 0x29, 0x32, 0xc2, 0x83, 0x86, 0xe8, 0x77, 0xfa, 0x7a, 0x47, 0xa0, 0x19, 0xdc,
		0xb8, 0x81, 0x5a, 0x86, 0xc0, 0x8c, 0x01, 0x74, 0x19, 0x0e, 0x59, 0x7a, 0x11, 0x4a, 0x1f, 0x2e,
		0xe8, 0xb9, 0xb2, 0x26, 0x24, 0x5a, 0x04, 0x3a, 0xb3, 0x0d, 0x8d, 0xbd, 0x89, 0xe5, 0xdb, 0x52,
		0x57, 0xf1, 0x34, 0x8f, 0xe8, 0x86, 0x4f, 0x34, 0xc3, 0x3a, 0x7a, 0xe1, 0x11, 0xad, 0xe8, 0x32,
		0x1b, 0x26, 0x8e, 0xdb, 0x54, 0x87, 0xad, 0xd1, 0x3b, 0x1b, 0xe5, 0x95, 0xf5, 0xf8, 0x60, 0x7a,
		0x0f, 0x48, 0x7b, 0x45, 0x62, 0xd0, 0xd0, 0x0d, 0x16, 0xe6, 0x81, 0x84, 0x06, 0x78, 0x30, 0x04,
		0x16, 0x68, 0x01, 0x81, 0xce, 0x2c, 0x69, 0xae, 0x44, 0x64, 0xf8, 0xba, 0x0c, 0xde, 0x20, 0x43,
		0x27, 0xb4, 0x70, 0xee, 0x96, 0x4d, 0x63, 0xd2, 0xea, 0x0d, 0x8c, 0xc0, 0xb8, 0xac, 0xc5, 0x22,
		0xf2, 0x47, 0x91, 0x3d, 0xf4, 0xc3, 0x88, 0xcc, 0xbc, 0x9e, 0x0e, 0x1e, 0x58, 0x1d, 0x01, 0x11,
		0xa4, 0x2c, 0xf2, 0x7d, 0x88, 0x2e, 0x47, 0x9d, 0x86, 0xab, 0x23, 0xad, 0x56, 0x6f, 0x9a, 0xac,
		0xae, 0xb4, 0x57, 0xed, 0x69, 0xac, 0xda, 0xd3, 0x52, 0xb5, 0xa7, 0x99, 0x66, 0x8b, 0xec, 0x7c,
		0x94, 0xb4, 0x7a, 0x9d, 0x35, 0x8f, 0x11, 0xc8, 0x0d, 0x67, 0x01, 0x17, 0x5a, 0x62, 0x14, 0x62,
		0x07, 0x90, 0x74, 0x04, 0x05, 0xe2, 0x0b, 0x6b, 0xac, 0xb3, 0xe0, 0x51, 0x3f, 0xa1, 0xbb, 0x2e,
		0x82, 0x4d, 0xbd, 0x03, 0x9b, 0x3a, 0x06, 0x36, 0xf5, 0x09, 0xd9, 0x96, 0xcb, 0xa8, 0x1d, 0xca,
		0xb2, 0x63, 0xd1, 0x67, 0x6f, 0x4b, 0xfe, 0x45, 0x97, 0xad, 0xe9, 0x71, 0x33, 0xda, 0xe2, 0x0e,
		0x4e, 0x6e, 0x87, 0x97, 0xfb, 0xe1, 0xe2, 0x86, 0xd8, 0xb9, 0x23, 0x76, 0x6e, 0x89, 0x9d, 0x7b,
		0xd2, 0xe3, 0xa6, 0x34, 0xb9, 0x2b, 0xed, 0x6e, 0x2b, 0x1e, 0xc0, 0x22, 0x79, 0x43, 0xbb, 0xa5,
		0x3e, 0xb5, 0x78, 0xd2, 0x99, 0x4d, 0xb2, 0xea, 0xd2, 0x34, 0xa7, 0xa5, 0xb3, 0xa9, 0x6c, 0xe7,
		0x54, 0xc1, 0xce, 0xb3, 0x52, 0x9d, 0x5b, 0x45, 0x3a, 0xdb, 0xca, 0x73, 0xb6, 0x15, 0xe6, 0x6c,
		0x2b, 0xc9, 0x77, 0x3b, 0xdd, 0x99, 0x4d, 0x05, 0x78, 0x8c, 0x3b, 0x03, 0xe1, 0xf6, 0x02, 0xd1,
		0xe3, 0x00, 0x3a, 0x8b, 0xc8, 0xab, 0xc2, 0x60, 0x2c, 0x57, 0xf3, 0x2d, 0xe4, 0x77, 0xef, 0x66,
		0xd5, 0xa9, 0xb9, 0x85, 0x2b, 0xdf, 0xd5, 0x9c, 0x60, 0x8d, 0xf1, 0xd7, 0x90, 0x87, 0xbb, 0x7e,
		0x62, 0x75, 0x2c, 0x82, 0x2f, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90, 0x3a, 0x90,
		0x3a, 0x90, 0xba, 0x57, 0x92, 0xba, 0x19, 0xec, 0x80, 0xd3, 0x91, 0xdf, 0x8a, 0x59, 0xcb, 0x17,
		0x36, 0x94, 0x8e, 0x43, 0x07, 0x1a, 0xcd, 0x3b, 0x4f, 0x60, 0x74, 0x60, 0x74, 0x60, 0x74, 0x60,
		0x74, 0x60, 0x74, 0xfa, 0x77, 0xb2, 0xe2, 0x81, 0x4c, 0xdb, 0x2f, 0x49, 0xaf, 0x2b, 0xf8, 0xf4,
		0xdb, 0x7d, 0x4a, 0x04, 0x7f, 0x1a, 0x1b, 0x97, 0x9e, 0x55, 0xac, 0x3a, 0x3b, 0xb3, 0xeb, 0xe4,
		0xcc, 0xb1, 0x73, 0x33, 0xef, 0x4e, 0xcd, 0x5c, 0x3b, 0x33, 0xb3, 0xef, 0xc4, 0xcc, 0xbe, 0xf3,
		0x32, 0xfb, 0x4e, 0xcb, 0xe8, 0x46, 0xc8, 0x52, 0x62, 0x61, 0x2c, 0xb5, 0x70, 0x94, 0x5c, 0xd6,
		0x49, 0x2f, 0x3f, 0xf9, 0x6f, 0x4a, 0x29, 0x42, 0x11, 0x85, 0xf1, 0xa3, 0xb9, 0x50, 0x33, 0xa3,
		0x19, 0xe8, 0x18, 0xc6, 0xc5, 0x28, 0xad, 0x8e, 0x7f, 0x7b, 0x3b, 0xf2, 0x64, 0xf4, 0xc0, 0x95,
		0x9d, 0xae, 0x0e, 0x10, 0x14, 0x15, 0x14, 0x15, 0x14, 0x15, 0x14, 0x15, 0x14, 0x15, 0x14, 0x15,
		0x14, 0x15, 0x14, 0xf5, 0xb5, 0x14, 0x75, 0xc1, 0x2b, 0xa4, 0x08, 0xe3, 0xc7, 0x0f, 0x60, 0xa9,
		0x3c, 0x59, 0xaa, 0xb8, 0x8f, 0x6c, 0xf6, 0x4c, 0x75, 0xdd, 0x20, 0xc1, 0x56, 0xc1, 0x56, 0xc1,
		0x56, 0xc1, 0x56, 0xc1, 0x56, 0xc1, 0x56, 0xc1, 0x56, 0xc1, 0x56, 0x5f, 0xcb, 0x56, 0x9f, 0x73,
		0x8b, 0x09, 0x63, 0x5d, 0xe2, 0x1a, 0x60, 0xad, 0x3c, 0x59, 0xab, 0xf4, 0xee, 0xdc, 0x81, 0xec,
		0xda, 0x81, 0x70, 0x43, 0x46, 0x87, 0xbd, 0xc4, 0x16, 0xba, 0x32, 0x3e, 0x70, 0x55, 0x70, 0x55,
		0x70, 0x55, 0x70, 0x55, 0x70, 0x55, 0x70, 0xd5, 0x1d, 0xe3, 0xaa, 0xb2, 0x2b, 0xbc, 0x48, 0x46,
		0x0f, 0x4c, 0xf9, 0x2a, 0xa7, 0xa3, 0xfd, 0x6a, 0xf3, 0xa9, 0x7a, 0xef, 0x86, 0x0c, 0x21, 0x75,
		0x71, 0x43, 0x6b, 0x97, 0x5f, 0xab, 0xe7, 0xb5, 0x8f, 0x4e, 0xa3, 0xfe, 0xe5, 0xfa, 0xcc, 0x69,
		0x9c, 0x55, 0x9b, 0xf5, 0x4b, 0x6e, 0xe8, 0xfa, 0xd5, 0x1d, 0x8c, 0xa6, 0xdd, 0x1f, 0x6f, 0xd8,
		0x1d, 0x98, 0xcb, 0xf3, 0x64, 0xf3, 0xc4, 0xdd, 0xfd, 0x70, 0xfe, 0xa5, 0x79, 0x7d, 0xd6, 0x70,
		0xce, 0xeb, 0xf5, 0x2b, 0x7e, 0x67, 0xeb, 0x33, 0x3c, 0xbd, 0xde, 0x90, 0xfb, 0x5a, 0x6f, 0xd4,
		0x3e, 0xd7, 0x2e, 0xab, 0xd7, 0xf5, 0x06, 0xee, 0x6a, 0x76, 0xee, 0x6a, 0xb5, 0x09, 0x43, 0xcd,
		0x1a, 0x00, 0xd7, 0x2f, 0x3f, 0x9d, 0x7d, 0x64, 0x78, 0x47, 0x59, 0x8d, 0xa8, 0x85, 0x78, 0x84,
		0xd9, 0x28, 0x38, 0xa8, 0x83, 0x03, 0x37, 0x8c, 0xec, 0x5b, 0xbf, 0x2b, 0x7b, 0x52, 0x74, 0xf9,
		0x89, 0x83, 0xcb, 0xc3, 0x83, 0x36, 0xb8, 0x6e, 0x38, 0xd0, 0x06, 0x5f, 0xb0, 0xa0, 0xa0, 0x0d,
		0xbe, 0x68, 0xa5, 0x43, 0x1b, 0xdc, 0x72, 0x80, 0xd0, 0x06, 0x0d, 0xe2, 0xbe, 0x8c, 0xb5, 0xc1,
		0x48, 0xde, 0x8a, 0x48, 0x76, 0xbe, 0x87, 0xe5, 0x22, 0x43, 0x6d, 0xf0, 0x98, 0xd1, 0x90, 0xbe,
		0x78, 0x72, 0x7a, 0xbc, 0xaf, 0xe5, 0xb9, 0x9e, 0x1f, 0x8a, 0x8e, 0xef, 0x75, 0x43, 0x4e, 0x53,
		0xd6, 0x70, 0xbd, 0xbe, 0x60, 0xa7, 0xb7, 0xf1, 0x0b, 0xf5, 0xac, 0x0b, 0xe9, 0xb1, 0xf3, 0x88,
		0x4c, 0x39, 0x60, 0x62, 0x78, 0x53, 0x55, 0x97, 0xf1, 0xf8, 0x3e, 0x05, 0x6e, 0x27, 0x92, 0xbe,
		0xf7, 0x51, 0xf6, 0x67, 0xd6, 0x7a, 0x08, 0x3d, 0xe6, 0x77, 0x4c, 0xc2, 0xbd, 0x87, 0x49, 0x6c,
		0x69, 0x12, 0xbc, 0x8e, 0x7d, 0x37, 0xde, 0x4a, 0xde, 0x60, 0x34, 0xeb, 0x7e, 0x5a, 0xd0, 0xb8,
		0xb8, 0xa0, 0x28, 0x9b, 0x83, 0x1c, 0x12, 0xa4, 0x9e, 0xc7, 0x81, 0x0e, 0x4c, 0x01, 0x1c, 0xba,
		0xd6, 0x4b, 0x96, 0x12, 0x74, 0xad, 0x17, 0xad, 0x74, 0xe8, 0x5a, 0x5b, 0x0e, 0x10, 0xba, 0x96,
		0x41, 0x31, 0x04, 0x63, 0x5d, 0x6b, 0x24, 0xbd, 0xe8, 0xa8, 0xc0, 0x50, 0xd2, 0xaa, 0x40, 0x32,
		0xfa, 0xc5, 0x0f, 0x24, 0xa3, 0x4c, 0xc6, 0xc7, 0x90, 0x8c, 0x4c, 0x87, 0xfb, 0x65, 0x93, 0x80,
		0x64, 0xb4, 0xb5, 0x49, 0x14, 0x0b, 0x27, 0xc5, 0x93, 0x72, 0xa5, 0x70, 0x02, 0xa1, 0x28, 0x03,
		0xd2, 0xcc, 0x1e, 0x84, 0x22, 0x86, 0xf3, 0xc1, 0x42, 0x28, 0xe2, 0x15, 0xe0, 0xf3, 0x3a, 0x22,
		0x8a, 0x29, 0x68, 0x43, 0x26, 0x7a, 0xc9, 0x4a, 0x82, 0x4c, 0xf4, 0xa2, 0x95, 0x0e, 0x99, 0x68,
		0xcb, 0x01, 0x42, 0x26, 0x32, 0x28, 0x6e, 0xe0, 0x5c, 0x1a, 0x39, 0xbc, 0x2b, 0xdb, 0xec, 0x6c,
		0x30, 0x2e, 0x8d, 0x3c, 0xe6, 0xd5, 0xca, 0x23, 0x12, 0x81, 0xc7, 0x4e, 0x2e, 0xb2, 0xf6, 0xf7,
		0x6f, 0x0e, 0xed, 0x13, 0xd7, 0xee, 0x55, 0xed, 0x4f, 0xad, 0x1f, 0xf9, 0xb7, 0xc5, 0xf1, 0xe9,
		0xc1, 0x8f, 0xca, 0x78, 0xf5, 0xc9, 0xc7, 0x75, 0x2f, 0xcb, 0xbf, 0xad, 0x8c, 0x4f, 0x37, 0xfc,
		0xa5, 0x3c, 0x3e, 0xfd, 0xcd, 0xcf, 0x28, 0x8d, 0xf7, 0x13, 0x2f, 0x9d, 0x3c, 0x5f, 0xd8, 0xf4,
		0x86, 0xe2, 0x86, 0x37, 0x1c, 0x6d, 0x7a, 0xc3, 0xd1, 0x86, 0x37, 0x6c, 0x1c, 0x52, 0x61, 0xc3,
		0x1b, 0x4a, 0xe3, 0xc7, 0xc4, 0xeb, 0xf7, 0xd7, 0xbf, 0xb4, 0x3c, 0x3e, 0x78, 0xdc, 0xf4, 0xb7,
		0xca, 0xf8, 0xf1, 0xf4, 0xe0, 0x20, 0xb7, 0x9f, 0x2f, 0xdc, 0x1c, 0xda, 0xc7, 0xad, 0xc7, 0xfc,
		0xcd, 0xa1, 0x9d, 0x6f, 0x4d, 0x5e, 0xd9, 0x7a, 0xbc, 0xc9, 0xdb, 0x27, 0x8b, 0x87, 0x93, 0xff,
		0x1f, 0xf0, 0x81, 0xe5, 0x16, 0x27, 0x7b, 0xaa, 0x37, 0x6b, 0x7f, 0xb0, 0x35, 0xaa, 0xbf, 0x61,
		0x55, 0xcc, 0xad, 0xea, 0x3f, 0x16, 0xb4, 0x06, 0x68, 0x0d, 0x09, 0xc3, 0x9d, 0x37, 0x3d, 0xf2,
		0x47, 0x91, 0xe0, 0x27, 0x38, 0x3c, 0x1f, 0x1c, 0x54, 0x07, 0xa8, 0x0e, 0x50, 0x1d, 0xa0, 0x3a,
		0x40, 0x75, 0x80, 0xea, 0xb0, 0x63, 0xaa, 0x43, 0xdb, 0xf7, 0x07, 0xc2, 0xf5, 0x38, 0x2a, 0x0e,
		0x79, 0x50, 0x39, 0x06, 0x23, 0xd0, 0x7d, 0xb2, 0x68, 0xd5, 0xf3, 0xfc, 0xc8, 0x8d, 0x24, 0x93,
		0xbe, 0x9e, 0x56, 0xd8, 0xf9, 0x26, 0x6e, 0xdd, 0xe1, 0xbc, 0x99, 0x6c, 0xce, 0x1f, 0x0a, 0xaf,
		0x33, 0x25, 0x4a, 0xb6, 0x27, 0xa2, 0x7f, 0xfd, 0xe0, 0xbb, 0x2d, 0xbd, 0x30, 0x72, 0xbd, 0x8e,
		0xc8, 0xad, 0x3e, 0x11, 0x26, 0x9e, 0xc9, 0x0d, 0x03, 0x3f, 0xf2, 0x3b, 0xfe, 0x20, 0x8c, 0x1f,
		0xe5, 0xda, 0xfd, 0x61, 0x2e, 0x90, 0xed, 0x9c, 0xdb, 0x93, 0x76, 0xe8, 0xf6, 0x64, 0x18, 0x3f,
		0xca, 0x4d, 0x25, 0xc2, 0x91, 0x27, 0x3b, 0x6e, 0x18, 0xe5, 0x3c, 0x21, 0xfb, 0xdf, 0xda, 0x7e,
		0x10, 0xc6, 0x8f, 0x72, 0x6e, 0xf7, 0x9f, 0xa9, 0x27, 0xf0, 0x47, 0x91, 0x3d, 0xf4, 0xc3, 0x28,
		0x37, 0xa5, 0xb7, 0xe1, 0xec, 0x57, 0x8e, 0xc3, 0x91, 0xdd, 0xb3, 0x29, 0x8c, 0x82, 0x51, 0x27,
		0xf2, 0xe6, 0x08, 0x54, 0x8f, 0x67, 0xf0, 0x72, 0x36, 0x3b, 0xb5, 0xf9, 0xe4, 0x38, 0x2b, 0xff,
		0x0e, 0x57, 0x9f, 0x70, 0xae, 0x16, 0xb3, 0x17, 0x3f, 0x72, 0xde, 0xf7, 0x87, 0x4e, 0x43, 0xb6,
		0x9d, 0x6a, 0x4f, 0x36, 0x27, 0x93, 0xb7, 0x78, 0xe0, 0xd4, 0x86, 0x77, 0xe5, 0x2f, 0xb3, 0xa9,
		0x73, 0x2e, 0x17, 0x53, 0x17, 0x3f, 0x72, 0xaa, 0xdd, 0x7f, 0x1a, 0xb2, 0x5d, 0x1f, 0x45, 0x57,
		0x7e, 0x18, 0x39, 0x8d, 0xe9, 0xbc, 0xcd, 0x7e, 0x39, 0xcd, 0xe9, 0xbc, 0xe1, 0xc8, 0x7b, 0xf2,
		0x75, 0x32, 0xf2, 0xbe, 0x7b, 0xfe, 0xbf, 0x9e, 0xed, 0x46, 0x51, 0x20, 0xdb, 0x93, 0x3b, 0xc2,
		0xe7, 0xfc, 0xfb, 0x35, 0x63, 0xc3, 0x61, 0xf8, 0x38, 0x0c, 0xdf, 0xa4, 0x28, 0x11, 0x87, 0xe1,
		0x9b, 0x1e, 0x0d, 0xe2, 0x30, 0x7c, 0x96, 0x94, 0x95, 0xcd, 0x61, 0xf8, 0x09, 0x27, 0xc5, 0x4f,
		0x86, 0x4d, 0x0e, 0x91, 0x97, 0x18, 0x9b, 0x87, 0x18, 0xcb, 0xde, 0xbd, 0xf2, 0x76, 0xb3, 0x5c,
		0xdd, 0x2d, 0x7b, 0xb7, 0xcb, 0xde, 0xfd, 0xb2, 0x77, 0xc3, 0x7c, 0x34, 0xac, 0x3d, 0x46, 0x62,
		0x2c, 0x17, 0xf7, 0x1c, 0x0f, 0x68, 0x7a, 0x74, 0x7b, 0xc4, 0x4d, 0x22, 0x5e, 0x42, 0xd4, 0xa7,
		0x21, 0x32, 0x33, 0x3d, 0x9e, 0xe5, 0x35, 0xec, 0xdc, 0x35, 0x67, 0xb7, 0x6d, 0x86, 0xfb, 0xe6,
		0xee, 0xc6, 0x8d, 0x71, 0xe7, 0xc6, 0xb8, 0x75, 0x63, 0xdc, 0x3b, 0x2f, 0x37, 0xcf, 0xcc, 0xdd,
		0xc7, 0x77, 0xf1, 0x9a, 0xa3, 0x83, 0xdd, 0xe3, 0x7d, 0x90, 0x63, 0x22, 0x1a, 0xae, 0x30, 0x1c,
		0xdb, 0xb3, 0x83, 0x1d, 0x67, 0xe7, 0x33, 0x3e, 0x91, 0x15, 0x14, 0x64, 0x72, 0x37, 0x4d, 0x6b,
		0xb6, 0x2b, 0xc9, 0x96, 0xf8, 0x72, 0xd9, 0x34, 0x5d, 0x6b, 0x8d, 0x20, 0xbd, 0x20, 0xbd, 0x20,
		0xbd, 0x20, 0xbd, 0x20, 0xbd, 0xf0, 0xac, 0xeb, 0xef, 0x22, 0x37, 0xad, 0x2b, 0x1e, 0xd8, 0x94,
		0xa3, 0x0d, 0x04, 0xe3, 0x5e, 0x46, 0x4b, 0xd2, 0xd7, 0x64, 0xa4, 0x6f, 0xd1, 0x60, 0x26, 0x43,
		0xa4, 0xc0, 0x04, 0x72, 0x60, 0x16, 0x49, 0x30, 0x85, 0x2c, 0x18, 0x47, 0x1a, 0x8c, 0x23, 0x0f,
		0xc6, 0x91, 0x08, 0x9e, 0x64, 0x82, 0x29, 0xa9, 0x88, 0xef, 0x2e, 0x5b, 0x45, 0x2d, 0x81, 0x9b,
		0x23, 0xe9, 0x45, 0xf9, 0x32, 0x67, 0xcc, 0x9c, 0x7b, 0xf1, 0x32, 0xe3, 0x21, 0xf2, 0x6c, 0xd1,
		0xb9, 0xfa, 0xc3, 0xdb, 0xe7, 0xec, 0x71, 0x6f, 0xe1, 0x69, 0x18, 0xbd, 0x4c, 0x0c, 0x97, 0x79,
		0x8b, 0xcf, 0xc4, 0x78, 0x0d, 0x68, 0x6b, 0x68, 0x88, 0x3b, 0x5a, 0x36, 0x31, 0xf7, 0x1e, 0x26,
		0xa6, 0xd8, 0xc4, 0xca, 0xa5, 0xd2, 0x51, 0x09, 0x66, 0xb6, 0x5b, 0x5c, 0x94, 0xff, 0xe8, 0x5a,
		0x6f, 0x30, 0x5f, 0x86, 0xc2, 0x38, 0xe3, 0x4c, 0xb8, 0x44, 0x48, 0xc1, 0x35, 0x23, 0xce, 0x10,
		0xaf, 0x02, 0x5d, 0x30, 0xcd, 0xc5, 0x08, 0x5d, 0x30, 0x55, 0xcb, 0x81, 0x2e, 0xa8, 0x78, 0xc0,
		0xd0, 0x05, 0x33, 0x1c, 0x88, 0x19, 0xa6, 0x0b, 0x1e, 0x1b, 0x20, 0x0b, 0x96, 0x20, 0x0b, 0x6e,
		0xf9, 0x03, 0x59, 0x10, 0x9a, 0x05, 0x64, 0xc1, 0x1d, 0xf4, 0x46, 0xcb, 0x26, 0x06, 0x59, 0x50,
		0xb9, 0x89, 0x15, 0x4a, 0x10, 0x05, 0x77, 0x8c, 0x88, 0xf2, 0x1f, 0x1d, 0x44, 0x41, 0x63, 0x41,
		0x7c, 0xa6, 0xb4, 0xdd, 0xcd, 0xd1, 0xc5, 0x04, 0x55, 0x70, 0x36, 0x56, 0xc8, 0x82, 0xaf, 0x19,
		0x1e, 0x64, 0xc1, 0x14, 0x57, 0x23, 0x64, 0xc1, 0x54, 0x2d, 0x07, 0xb2, 0xa0, 0xe2, 0x01, 0x43,
		0x16, 0xcc, 0x70, 0x20, 0x66, 0x90, 0x2c, 0xd8, 0x96, 0x9e, 0x1b, 0x3c, 0x18, 0xa0, 0x0b, 0x9e,
		0x30, 0x1e, 0xe2, 0xb9, 0xf0, 0xfa, 0xd3, 0xc2, 0x5c, 0x08, 0x83, 0xdb, 0xaa, 0x16, 0x10, 0x06,
		0x95, 0xab, 0x16, 0x79, 0x68, 0x16, 0x3b, 0xe6, 0x8f, 0x96, 0x4d, 0x0c, 0xc2, 0xa0, 0x72, 0x13,
		0x43, 0xbe, 0xe0, 0x0e, 0x92, 0x51, 0xfe, 0xa3, 0x83, 0x34, 0x68, 0x2c, 0x8c, 0x5b, 0xe2, 0x3e,
		0x12, 0x5e, 0x57, 0x74, 0xf9, 0x0b, 0x83, 0xf1, 0x48, 0x21, 0x0b, 0xbe, 0x66, 0x78, 0x90, 0x05,
		0x53, 0x5c, 0x8b, 0x90, 0x05, 0x53, 0xb5, 0x1c, 0xc8, 0x82, 0x8a, 0x07, 0x0c, 0x59, 0x30, 0xc3,
		0x61, 0x98, 0x49, 0xb2, 0x20, 0xbb, 0xb3, 0xd2, 0x36, 0xb9, 0x71, 0x26, 0x67, 0xa7, 0x81, 0xd4,
		0xbe, 0xe6, 0x1e, 0xfa, 0xc3, 0x49, 0xe4, 0xe9, 0x0e, 0xf8, 0x93, 0xda, 0x78, 0xa4, 0x20, 0xb5,
		0x20, 0xb5, 0x20, 0xb5, 0x20, 0xb5, 0x20, 0xb5, 0x20, 0xb5, 0x20, 0xb5, 0x20, 0xb5, 0x20, 0xb5,
		0x30, 0x8a, 0xe5, 0x7b, 0x38, 0x74, 0x83, 0x48, 0x9a, 0xc0, 0x69, 0x17, 0x03, 0x05, 0xa5, 0x05,
		0xa5, 0x05, 0xa5, 0x05, 0xa5, 0x05, 0xa5, 0x05, 0xa5, 0x05, 0xa5, 0x05, 0xa5, 0x05, 0xa5, 0x85,
		0x51, 0x2c, 0xdf, 0xc3, 0x28, 0x70, 0xbd, 0x50, 0x46, 0xf2, 0xce, 0x80, 0xba, 0xa4, 0x67, 0x63,
		0x05, 0xb1, 0x05, 0xb1, 0x05, 0xb1, 0x05, 0xb1, 0x05, 0xb1, 0x05, 0xb1, 0x05, 0xb1, 0x05, 0xb1,
		0x05, 0xb1, 0xc5, 0x88, 0x98, 0x9a, 0xa8, 0x55, 0xf5, 0x3c, 0x3f, 0x72, 0x23, 0xe9, 0xf3, 0x2c,
		0x80, 0xb2, 0xc2, 0xce, 0x37, 0x71, 0xeb, 0x0e, 0xe7, 0x07, 0x50, 0xe6, 0xfc, 0xa1, 0xf0, 0x3a,
		0x53, 0xa2, 0x68, 0x7b, 0x22, 0xfa, 0xd7, 0x0f, 0xbe, 0xdb, 0xd2, 0x0b, 0x23, 0xd7, 0xeb, 0x88,
		0xdc, 0xea, 0x13, 0x61, 0xe2, 0x99, 0xdc, 0x30, 0xf0, 0x23, 0xbf, 0xe3, 0x0f, 0xc2, 0xf8, 0x51,
		0xae, 0xdd, 0x1f, 0xe6, 0x02, 0xd9, 0xce, 0xb9, 0x3d, 0x69, 0x87, 0x6e, 0x4f, 0x86, 0xf1, 0xa3,
		0x9c, 0x1c, 0xde, 0x95, 0xed, 0x91, 0x27, 0x3b, 0x6e, 0x18, 0xe5, 0x3c, 0x21, 0xfb, 0xdf, 0xda,
		0x7e, 0x10, 0xc6, 0x8f, 0x72, 0x6e, 0xf7, 0x9f, 0xa9, 0xa7, 0xf2, 0x47, 0x91, 0x3d, 0xf4, 0xc3,
		0x28, 0x17, 0xf8, 0xa3, 0x48, 0x84, 0xb3, 0x5f, 0xb9, 0x91, 0xf7, 0xdd, 0xf3, 0xff, 0xf5, 0x6c,
		0x37, 0x8a, 0x02, 0xd9, 0x9e, 0xfe, 0x21, 0xf1, 0x54, 0x8e, 0xe3, 0xe1, 0x87, 0xb3, 0x79, 0x8f,
		0x82, 0x51, 0x27, 0xf2, 0xe6, 0xb0, 0x58, 0x8f, 0xa7, 0xfd, 0x72, 0x36, 0xa5, 0xb5, 0xf9, 0x8c,
		0x3a, 0x2b, 0xff, 0x0e, 0x57, 0x9f, 0x70, 0xae, 0x16, 0x53, 0x1e, 0x3f, 0x72, 0xde, 0xf7, 0x87,
		0x4e, 0x43, 0xb6, 0x9d, 0x6a, 0x4f, 0x36, 0x27, 0x33, 0xbe, 0x78, 0xe0, 0xd4, 0x86, 0x77, 0xe5,
		0x2f, 0xb3, 0xf9, 0x76, 0x2e, 0x17, 0xf3, 0x1d, 0x3f, 0x72, 0xaa, 0xdd, 0x7f, 0x1a, 0xb2, 0x5d,
		0x1f, 0x45, 0x57, 0x7e, 0x18, 0x39, 0x8d, 0xe9, 0x64, 0xcf, 0x7e, 0x39, 0x5f, 0x66, 0x33, 0x5b,
		0x8d, 0xe7, 0x3a, 0xf1, 0x8c, 0xd3, 0x9c, 0x4e, 0x35, 0xce, 0x2b, 0x65, 0x3c, 0x12, 0x26, 0xe0,
		0x38, 0xe1, 0xfb, 0x1c, 0x1b, 0x10, 0x5b, 0xe7, 0x32, 0x8c, 0x26, 0x0b, 0x9a, 0x15, 0x54, 0x5b,
		0x17, 0xd2, 0x3b, 0x1b, 0x88, 0x09, 0x7b, 0x0f, 0x79, 0x45, 0xef, 0xd6, 0x85, 0x7b, 0xff, 0x6c,
		0x64, 0xf9, 0xe3, 0x62, 0xb1, 0x5c, 0x29, 0x16, 0x0f, 0x2b, 0x47, 0x95, 0xc3, 0x93, 0x52, 0x29,
		0x5f, 0xce, 0x33, 0x2a, 0x96, 0xb3, 0xea, 0x41, 0x57, 0x04, 0xa2, 0xfb, 0x7e, 0xb2, 0xf4, 0xbc,
		0xd1, 0x60, 0x00, 0x8b, 0xe4, 0x4f, 0x53, 0x32, 0x4e, 0x4f, 0x2c, 0x56, 0xa7, 0x58, 0x67, 0x8c,
		0x90, 0xf0, 0xa0, 0x22, 0xfa, 0x1d, 0xbf, 0xde, 0x11, 0x68, 0x06, 0x38, 0x6e, 0xc0, 0x96, 0x29,
		0x40, 0x63, 0x00, 0x5f, 0xc6, 0xc3, 0x96, 0x5e, 0x94, 0xd2, 0x87, 0x0d, 0x7a, 0xae, 0xac, 0x09,
		0x8d, 0x16, 0x01, 0xcf, 0x6c, 0x73, 0x63, 0x6f, 0x62, 0xfd, 0xb6, 0xd4, 0x55, 0x48, 0xcd, 0x23,
		0xca, 0xe1, 0x13, 0xd5, 0xb0, 0x8e, 0x62, 0x78, 0x44, 0x2d, 0xba, 0xcc, 0x86, 0x89, 0xf3, 0x36,
		0xd7, 0x69, 0x6b, 0xf4, 0xd0, 0x86, 0x79, 0x66, 0x3d, 0x7e, 0x98, 0xde, 0x0b, 0xd2, 0x5e, 0x91,
		0x18, 0x38, 0x74, 0x03, 0x86, 0x89, 0x40, 0xa1, 0x01, 0x22, 0x8c, 0x81, 0x06, 0x5a, 0x50, 0xa0,
		0x33, 0x4d, 0x9a, 0x2b, 0x11, 0x19, 0xbf, 0x2e, 0xa3, 0x37, 0xca, 0xd8, 0x09, 0xad, 0x9c, 0xbf,
		0x75, 0xd3, 0x98, 0xb5, 0x7a, 0x23, 0x23, 0x30, 0x30, 0x6b, 0x69, 0x21, 0x05, 0x74, 0x59, 0x46,
		0x4f, 0xe7, 0x11, 0xac, 0x0c, 0x80, 0x08, 0x54, 0x16, 0x59, 0x40, 0x44, 0x97, 0xa3, 0x4e, 0xce,
		0xd5, 0x91, 0x6c, 0xab, 0x37, 0x79, 0x56, 0x57, 0x32, 0xac, 0xf6, 0xe4, 0x56, 0xed, 0xc9, 0xaa,
		0xda, 0x93, 0x4f, 0xb3, 0x45, 0x77, 0x3e, 0x4a, 0x5a, 0xe5, 0xce, 0x9a, 0xc7, 0x09, 0xe4, 0x86,
		0xb3, 0x80, 0x0b, 0x2d, 0x71, 0x0a, 0xb1, 0x03, 0x48, 0x3a, 0x82, 0x02, 0xf1, 0x85, 0x35, 0x56,
		0x5f, 0xf0, 0xa8, 0xaa, 0xd0, 0x5d, 0x2d, 0xc1, 0xa6, 0x0a, 0x82, 0x4d, 0x75, 0x03, 0x9b, 0xaa,
		0x85, 0x6c, 0x8b, 0x66, 0xd4, 0x0e, 0x65, 0xd9, 0xb1, 0xe8, 0xb3, 0xb7, 0x25, 0xff, 0xa2, 0xcb,
		0xd6, 0xf4, 0xb8, 0x19, 0x6d, 0x71, 0x07, 0x27, 0xb7, 0xc3, 0xcb, 0xfd, 0x70, 0x71, 0x43, 0xec,
		0xdc, 0x11, 0x3b, 0xb7, 0xc4, 0xce, 0x3d, 0xe9, 0x71, 0x53, 0x9a, 0xdc, 0x95, 0x76, 0xb7, 0x15,
		0x0f, 0x60, 0x91, 0xc6, 0xa1, 0xdd, 0x52, 0x9f, 0x1a, 0x3f, 0xe9, 0xcc, 0x2b, 0x59, 0x75, 0x69,
		0x9a, 0x13, 0xd5, 0xd9, 0xd4, 0xbb, 0x73, 0xaa, 0x6b, 0xe7, 0x59, 0xbf, 0xce, 0xad, 0x4e, 0x9d,
		0x6d, 0x3d, 0x3a, 0xdb, 0xba, 0x73, 0xb6, 0xf5, 0xe5, 0xbb, 0x9d, 0xfc, 0xcc, 0xa6, 0x2e, 0x3c,
		0xc6, 0x9d, 0x81, 0x70, 0x7b, 0x81, 0xe8, 0x71, 0x00, 0x9d, 0x45, 0xe4, 0x55, 0x61, 0x30, 0x96,
		0xab, 0xf9, 0x26, 0xf2, 0xbb, 0x77, 0xb3, 0x8a, 0xd5, 0xdc, 0xc2, 0x95, 0xef, 0x6a, 0x76, 0xb0,
		0xc6, 0xf8, 0x6b, 0xc8, 0xc3, 0x5d, 0x3f, 0xb1, 0x3a, 0x16, 0xc1, 0x17, 0x48, 0x1d, 0x48, 0x1d,
		0x48, 0x1d, 0x48, 0x1d, 0x48, 0x1d, 0x48, 0x1d, 0x48, 0xdd, 0x2b, 0x49, 0xdd, 0x0c, 0x76, 0xc0,
		0xe9, 0xc8, 0x6f, 0xc5, 0xac, 0x0d, 0x0c, 0x1b, 0x4a, 0xc7, 0xa1, 0x2b, 0x8d, 0xe6, 0x9d, 0x27,
		0x30, 0x3a, 0x30, 0x3a, 0x30, 0x3a, 0x30, 0x3a, 0x30, 0x3a, 0xfd, 0x3b, 0x59, 0xf1, 0x40, 0xa6,
		0x0d, 0x99, 0xa4, 0xd7, 0x15, 0x7c, 0xba, 0xf0, 0x3e, 0xe5, 0x81, 0x3f, 0x8d, 0x8d, 0x4b, 0x17,
		0x2b, 0x56, 0xfd, 0x9e, 0xd9, 0xf5, 0x77, 0xe6, 0xd8, 0xcf, 0x99, 0x77, 0xff, 0x66, 0xae, 0xfd,
		0x9a, 0xd9, 0xf7, 0x67, 0x66, 0xdf, 0x8f, 0x99, 0x7d, 0xff, 0x65, 0xf4, 0x27, 0x64, 0x29, 0xb1,
		0x30, 0x96, 0x5a, 0x38, 0x4a, 0x2e, 0xeb, 0xa4, 0x97, 0x9f, 0xfc, 0x37, 0xa5, 0x14, 0xa1, 0x88,
		0xc2, 0xf8, 0xd1, 0x5c, 0xa8, 0x99, 0xd1, 0x0c, 0xf4, 0x0f, 0xe3, 0x62, 0x94, 0x56, 0xc7, 0xbf,
		0xbd, 0x1d, 0x79, 0x32, 0x7a, 0xe0, 0xca, 0x4e, 0x57, 0x07, 0x08, 0x8a, 0x0a, 0x8a, 0x0a, 0x8a,
		0x0a, 0x8a, 0x0a, 0x8a, 0x0a, 0x8a, 0x0a, 0x8a, 0x0a, 0x8a, 0xfa, 0x5a, 0x8a, 0xba, 0xe0, 0x15,
		0x52, 0x84, 0xf1, 0xe3, 0x07, 0xb0, 0x54, 0x9e, 0x2c, 0x55, 0xdc, 0x47, 0x36, 0x7b, 0xa6, 0xba,
		0x6e, 0x90, 0x60, 0xab, 0x60, 0xab, 0x60, 0xab, 0x60, 0xab, 0x60, 0xab, 0x60, 0xab, 0x60, 0xab,
		0x60, 0xab, 0xaf, 0x65, 0xab, 0xcf, 0xb9, 0xc5, 0x84, 0xb1, 0x2e, 0x71, 0x0d, 0xb0, 0x56, 0x9e,
		0xac, 0x55, 0x7a, 0x77, 0xee, 0x40, 0x76, 0xed, 0x40, 0xb8, 0x21, 0xa3, 0xe3, 0x5f, 0x62, 0x0b,
		0x5d, 0x19, 0x1f, 0xb8, 0x2a, 0xb8, 0x2a, 0xb8, 0x2a, 0xb8, 0x2a, 0xb8, 0x2a, 0xb8, 0xea, 0x8e,
		0x71, 0x55, 0xd9, 0x15, 0x5e, 0x24, 0xa3, 0x07, 0xa6, 0x7c, 0x95, 0xd3, 0x61, 0x7f, 0xb5, 0xf9,
		0x54, 0xbd, 0x77, 0x43, 0x86, 0x90, 0xba, 0xb8, 0xa1, 0xb5, 0xcb, 0xaf, 0xd5, 0xf3, 0xda, 0x47,
		0xa7, 0x51, 0xff, 0x72, 0x7d, 0xe6, 0x34, 0xce, 0xaa, 0xcd, 0xfa, 0x25, 0x37, 0x74, 0xfd, 0xea,
		0x0e, 0x46, 0xd3, 0xee, 0x8f, 0x37, 0xec, 0x0e, 0xd1, 0xe5, 0x79, 0xde, 0x79, 0xe2, 0xee, 0x7e,
		0x38, 0xff, 0xd2, 0xbc, 0x3e, 0x6b, 0x38, 0xe7, 0xf5, 0xfa, 0x15, 0xbf, 0x13, 0xf7, 0x19, 0x9e,
		0x69, 0x6f, 0xc8, 0x7d, 0xad, 0x37, 0x6a, 0x9f, 0x6b, 0x97, 0xd5, 0xeb, 0x7a, 0x03, 0x77, 0x35,
		0x3b, 0x77, 0xb5, 0xda, 0x84, 0xa1, 0x66, 0x0d, 0x80, 0xeb, 0x97, 0x9f, 0xce, 0x3e, 0x32, 0xbc,
		0xa3, 0xac, 0x46, 0xd4, 0x42, 0x3c, 0xc2, 0x6c, 0x14, 0x1c, 0xd4, 0xc1, 0x81, 0x1b, 0x46, 0xf6,
		0xad, 0xdf, 0x95, 0x3d, 0x29, 0xba, 0xfc, 0xc4, 0xc1, 0xe5, 0xe1, 0x41, 0x1b, 0x5c, 0x37, 0x1c,
		0x68, 0x83, 0x2f, 0x58, 0x50, 0xd0, 0x06, 0x5f, 0xb4, 0xd2, 0xa1, 0x0d, 0x6e, 0x39, 0x40, 0x68,
		0x83, 0x06, 0x71, 0x5f, 0xc6, 0xda, 0x60, 0x24, 0x6f, 0x45, 0x24, 0x3b, 0xdf, 0xc3, 0x72, 0x91,
		0xa1, 0x36, 0x78, 0xcc, 0x68, 0x48, 0x5f, 0x3c, 0x39, 0x3d, 0xe8, 0xd7, 0xf2, 0x5c, 0xcf, 0x0f,
		0x45, 0xc7, 0xf7, 0xba, 0x21, 0xa7, 0x29, 0x6b, 0xb8, 0x5e, 0x5f, 0xb0, 0xd3, 0xdb, 0xf8, 0x85,
		0x7a, 0xd6, 0x85, 0xf4, 0xd8, 0x79, 0x44, 0xa6, 0x1c, 0x30, 0x31, 0xbc, 0xa9, 0xaa, 0xcb, 0x78,
		0x7c, 0x9f, 0x02, 0xb7, 0x13, 0x49, 0xdf, 0xfb, 0x28, 0xfb, 0x33, 0x6b, 0x3d, 0x84, 0x1e, 0xf3,
		0x3b, 0x26, 0xe1, 0xde, 0xc3, 0x24, 0xb6, 0x34, 0x09, 0x5e, 0x07, 0xc0, 0x1b, 0x6f, 0x25, 0x6f,
		0x30, 0x9a, 0x75, 0x3f, 0x2d, 0x68, 0x5c, 0x5c, 0x50, 0x94, 0xcd, 0x41, 0x0e, 0x09, 0x52, 0xcf,
		0xe3, 0x40, 0x07, 0xa6, 0x00, 0x0e, 0x5d, 0xeb, 0x25, 0x4b, 0x09, 0xba, 0xd6, 0x8b, 0x56, 0x3a,
		0x74, 0xad, 0x2d, 0x07, 0x08, 0x5d, 0xcb, 0xa0, 0x18, 0x82, 0xb1, 0xae, 0x35, 0x92, 0x5e, 0x74,
		0x54, 0x60, 0x28, 0x69, 0x55, 0x20, 0x19, 0xfd, 0xe2, 0x07, 0x92, 0x51, 0x26, 0xe3, 0x63, 0x48,
		0x46, 0xa6, 0xc3, 0xfd, 0xb2, 0x49, 0x40, 0x32, 0xda, 0xda, 0x24, 0x8a, 0x85, 0x93, 0xe2, 0x49,
		0xb9, 0x52, 0x38, 0x81, 0x50, 0x94, 0x01, 0x69, 0x66, 0x0f, 0x42, 0x11, 0xc3, 0xf9, 0x60, 0x21,
		0x14, 0xf1, 0x0a, 0xf0, 0x79, 0x1d, 0x11, 0xc5, 0x14, 0xb4, 0x21, 0x13, 0xbd, 0x64, 0x25, 0x41,
		0x26, 0x7a, 0xd1, 0x4a, 0x87, 0x4c, 0xb4, 0xe5, 0x00, 0x21, 0x13, 0x19, 0x14, 0x37, 0x70, 0x2e,
		0x8d, 0x1c, 0xde, 0x95, 0x6d, 0x76, 0x36, 0x18, 0x97, 0x46, 0x1e, 0xf3, 0x6a, 0xe5, 0x11, 0x89,
		0xc0, 0x63, 0x27, 0x17, 0x59, 0xfb, 0xfb, 0x37, 0x87, 0xf6, 0x89, 0x6b, 0xf7, 0xaa, 0xf6, 0xa7,
		0xd6, 0x8f, 0xfc, 0xdb, 0xe2, 0xf8, 0xf4, 0xe0, 0x47, 0x65, 0xbc, 0xfa, 0xe4, 0xe3, 0xba, 0x97,
		0xe5, 0xdf, 0x56, 0xc6, 0xa7, 0x1b, 0xfe, 0x52, 0x1e, 0x9f, 0xfe, 0xe6, 0x67, 0x94, 0xc6, 0xfb,
		0x89, 0x97, 0x4e, 0x9e, 0x2f, 0x6c, 0x7a, 0x43, 0x71, 0xc3, 0x1b, 0x8e, 0x36, 0xbd, 0xe1, 0x68,
		0xc3, 0x1b, 0x36, 0x0e, 0xa9, 0xb0, 0xe1, 0x0d, 0xa5, 0xf1, 0x63, 0xe2, 0xf5, 0xfb, 0xeb, 0x5f,
		0x5a, 0x1e, 0x1f, 0x3c, 0x6e, 0xfa, 0x5b, 0x65, 0xfc, 0x78, 0x7a, 0x70, 0x90, 0xdb, 0xcf, 0x17,
		0x6e, 0x0e, 0xed, 0xe3, 0xd6, 0x63, 0xfe, 0xe6, 0xd0, 0xce, 0xb7, 0x26, 0xaf, 0x6c, 0x3d, 0xde,
		0xe4, 0xed, 0x93, 0xc5, 0xc3, 0xc9, 0xff, 0x0f, 0xf8, 0xc0, 0x72, 0x8b, 0x93, 0x3d, 0xd5, 0x9b,
		0xb5, 0x3f, 0xd8, 0x1a, 0xd5, 0xdf, 0xb0, 0x2a, 0xe6, 0x56, 0xf5, 0x1f, 0x0b, 0x5a, 0x03, 0xb4,
		0x86, 0x84, 0xe1, 0xce, 0x9b, 0x1e, 0xf9, 0xa3, 0x48, 0xf0, 0x13, 0x1c, 0x9e, 0x0f, 0x0e, 0xaa,
		0x03, 0x54, 0x07, 0xa8, 0x0e, 0x50, 0x1d, 0xa0, 0x3a, 0x40, 0x75, 0xd8, 0x31, 0xd5, 0xa1, 0xed,
		0xfb, 0x03, 0xe1, 0x7a, 0x1c, 0x15, 0x87, 0x3c, 0xa8, 0x1c, 0x83, 0x11, 0xe8, 0x3e, 0x59, 0xb4,
		0xea, 0x79, 0x7e, 0xe4, 0x46, 0x92, 0x49, 0x5f, 0x4f, 0x2b, 0xec, 0x7c, 0x13, 0xb7, 0xee, 0x70,
		0xde, 0x4c, 0x36, 0xe7, 0x0f, 0x85, 0xd7, 0x99, 0x12, 0x25, 0xdb, 0x13, 0xd1, 0xbf, 0x7e, 0xf0,
		0xdd, 0x96, 0x5e, 0x18, 0xb9, 0x5e, 0x47, 0xe4, 0x56, 0x9f, 0x08, 0x13, 0xcf, 0xe4, 0x86, 0x81,
		0x1f, 0xf9, 0x1d, 0x7f, 0x10, 0xc6, 0x8f, 0x72, 0xed, 0xfe, 0x30, 0x17, 0xc8, 0x76, 0xce, 0xed,
		0x49, 0x3b, 0x74, 0x7b, 0x32, 0x8c, 0x1f, 0xe5, 0xa6, 0x12, 0xe1, 0xc8, 0x93, 0x1d, 0x37, 0x8c,
		0x72, 0x9e, 0x90, 0xfd, 0x6f, 0x6d, 0x3f, 0x08, 0xe3, 0x47, 0x39, 0xb7, 0xfb, 0xcf, 0xd4, 0x13,
		0xf8, 0xa3, 0xc8, 0x1e, 0x06, 0x22, 0x37, 0x65, 0xb7, 0xe1, 0xec, 0x57, 0x8e, 0xc3, 0x89, 0xdd,
		0xb3, 0x19, 0x8c, 0x82, 0x51, 0x27, 0xf2, 0xe6, 0x00, 0x54, 0x8f, 0x27, 0xf0, 0x72, 0x36, 0x39,
		0xb5, 0xf9, 0xdc, 0x38, 0x2b, 0xff, 0x0e, 0x57, 0x9f, 0x70, 0xae, 0x16, 0x93, 0x17, 0x3f, 0x72,
		0xde, 0xf7, 0x87, 0x4e, 0x43, 0xb6, 0x9d, 0x6a, 0x4f, 0x36, 0x27, 0x73, 0xb7, 0x78, 0xe0, 0xd4,
		0x86, 0x77, 0xe5, 0x2f, 0xb3, 0x99, 0x73, 0x2e, 0x17, 0x33, 0x17, 0x3f, 0x72, 0xaa, 0xdd, 0x7f,
		0x1a, 0xb2, 0x5d, 0x1f, 0x45, 0x57, 0x81, 0x70, 0x1a, 0xd3, 0x69, 0x9b, 0xfd, 0x72, 0x9a, 0xd3,
		0x69, 0xc3, 0x81, 0xf7, 0xe4, 0xcb, 0x64, 0xe4, 0x7d, 0xf7, 0xfc, 0x7f, 0x3d, 0xdb, 0x8d, 0xa2,
		0x40, 0xb6, 0x27, 0x77, 0x84, 0xcf, 0xe9, 0xf7, 0x6b, 0xc6, 0x86, 0xa3, 0xf0, 0x71, 0x14, 0xbe,
		0x49, 0x31, 0x22, 0x8e, 0xc2, 0x37, 0x3d, 0x16, 0xc4, 0x51, 0xf8, 0x2c, 0x09, 0x2b, 0x9b, 0xa3,
		0xf0, 0x13, 0x4e, 0x8a, 0x9f, 0x08, 0x9b, 0x1c, 0x22, 0x2f, 0x29, 0x36, 0x0f, 0x29, 0x96, 0xbd,
		0x7b, 0xe5, 0xed, 0x66, 0xb9, 0xba, 0x5b, 0xf6, 0x6e, 0x97, 0xbd, 0xfb, 0x65, 0xef, 0x86, 0xf9,
		0x28, 0x58, 0x7b, 0x8c, 0xa4, 0x58, 0x2e, 0xee, 0x39, 0x1e, 0xd0, 0xf4, 0xe0, 0xf6, 0x88, 0x9b,
		0x40, 0xbc, 0x84, 0xa8, 0x4f, 0x43, 0x64, 0x66, 0x7a, 0x3c, 0x8b, 0x6b, 0xd8, 0xb9, 0x6b, 0xce,
		0x6e, 0xdb, 0x0c, 0xf7, 0xcd, 0xdd, 0x8d, 0x1b, 0xe3, 0xce, 0x8d, 0x71, 0xeb, 0xc6, 0xb8, 0x77,
		0x5e, 0x6e, 0x9e, 0x99, 0xbb, 0x8f, 0xef, 0xe2, 0x35, 0x47, 0x07, 0xbb, 0xc7, 0xfb, 0x18, 0xc7,
		0x44, 0x34, 0x5c, 0x61, 0x38, 0xb6, 0x67, 0xc7, 0x3a, 0xce, 0x4e, 0x67, 0x7c, 0x22, 0x2b, 0x28,
		0xc7, 0xe4, 0x6e, 0x9a, 0xd6, 0x6c, 0x53, 0x92, 0x2d, 0xf1, 0xe5, 0xb2, 0x67, 0xba, 0xd6, 0x1a,
		0x41, 0x7a, 0x41, 0x7a, 0x41, 0x7a, 0x41, 0x7a, 0x41, 0x7a, 0xe1, 0x59, 0xd7, 0xdf, 0x45, 0x6e,
		0x5a, 0x57, 0x3c, 0xb0, 0x29, 0x47, 0x1b, 0x08, 0xc6, 0x9d, 0x8c, 0x96, 0xa4, 0xaf, 0xc9, 0x48,
		0xdf, 0xa2, 0xbd, 0x4c, 0x86, 0x48, 0x81, 0x09, 0xe4, 0xc0, 0x2c, 0x92, 0x60, 0x0a, 0x59, 0x30,
		0x8e, 0x34, 0x18, 0x47, 0x1e, 0x8c, 0x23, 0x11, 0x3c, 0xc9, 0x04, 0x53, 0x52, 0x11, 0xdf, 0x5d,
		0xb6, 0x8a, 0x5a, 0x02, 0x37, 0x47, 0xd2, 0x8b, 0xf2, 0x65, 0xce, 0x98, 0x39, 0xf7, 0xe2, 0x65,
		0xc6, 0x43, 0xe4, 0xd9, 0xa0, 0x73, 0xf5, 0x87, 0xb7, 0xcf, 0xd9, 0xe3, 0xde, 0xc0, 0xd3, 0x30,
		0x7a, 0x99, 0x18, 0x2e, 0xf3, 0x06, 0x9f, 0x89, 0xf1, 0x1a, 0xd0, 0xd4, 0xd0, 0x10, 0x77, 0xb4,
		0x6c, 0x62, 0xee, 0x3d, 0x4c, 0x4c, 0xb1, 0x89, 0x95, 0x4b, 0xa5, 0xa3, 0x12, 0xcc, 0x6c, 0xb7,
		0xb8, 0x28, 0xff, 0xd1, 0xb5, 0xde, 0x60, 0xbe, 0x0c, 0x85, 0x71, 0xc6, 0x99, 0x70, 0x89, 0x90,
		0x82, 0x6b, 0x46, 0x9c, 0x21, 0x5e, 0x05, 0xba, 0x60, 0x9a, 0x8b, 0x11, 0xba, 0x60, 0xaa, 0x96,
		0x03, 0x5d, 0x50, 0xf1, 0x80, 0xa1, 0x0b, 0x66, 0x38, 0x10, 0x33, 0x4c, 0x17, 0x3c, 0x36, 0x40,
		0x16, 0x2c, 0x41, 0x16, 0xdc, 0xf2, 0x07, 0xb2, 0x20, 0x34, 0x0b, 0xc8, 0x82, 0x3b, 0xe8, 0x8d,
		0x96, 0x4d, 0x0c, 0xb2, 0xa0, 0x72, 0x13, 0x2b, 0x94, 0x20, 0x0a, 0xee, 0x18, 0x11, 0xe5, 0x3f,
		0x3a, 0x88, 0x82, 0xc6, 0x82, 0xf8, 0x4c, 0x69, 0xbb, 0x9b, 0xa3, 0x8b, 0x09, 0xaa, 0xe0, 0x6c,
		0xac, 0x90, 0x05, 0x5f, 0x33, 0x3c, 0xc8, 0x82, 0x29, 0xae, 0x46, 0xc8, 0x82, 0xa9, 0x5a, 0x0e,
		0x64, 0x41, 0xc5, 0x03, 0x86, 0x2c, 0x98, 0xe1, 0x40, 0xcc, 0x20, 0x59, 0xb0, 0x2d, 0x3d, 0x37,
		0x78, 0x30, 0x40, 0x17, 0x3c, 0x61, 0x3c, 0xc4, 0x73, 0xe1, 0xf5, 0xa7, 0x85, 0xb9, 0x10, 0x06,
		0xb7, 0x55, 0x2d, 0x20, 0x0c, 0x2a, 0x57, 0x2d, 0xf2, 0xd0, 0x2c, 0x76, 0xcc, 0x1f, 0x2d, 0x9b,
		0x18, 0x84, 0x41, 0xe5, 0x26, 0x86, 0x7c, 0xc1, 0x1d, 0x24, 0xa3, 0xfc, 0x47, 0x07, 0x69, 0xd0,
		0x58, 0x18, 0xb7, 0xc4, 0x7d, 0x24, 0xbc, 0xae, 0xe8, 0xf2, 0x17, 0x06, 0xe3, 0x91, 0x42, 0x16,
		0x7c, 0xcd, 0xf0, 0x20, 0x0b, 0xa6, 0xb8, 0x16, 0x21, 0x0b, 0xa6, 0x6a, 0x39, 0x90, 0x05, 0x15,
		0x0f, 0x18, 0xb2, 0x60, 0x86, 0xc3, 0x30, 0x93, 0x64, 0x41, 0x76, 0x27, 0xa5, 0x6d, 0x72, 0xe3,
		0x4c, 0x4e, 0x4e, 0x03, 0xa9, 0x7d, 0xcd, 0x3d, 0xf4, 0x87, 0x93, 0xc8, 0xd3, 0x1d, 0xf0, 0x27,
		0xb5, 0xf1, 0x48, 0x41, 0x6a, 0x41, 0x6a, 0x41, 0x6a, 0x41, 0x6a, 0x41, 0x6a, 0x41, 0x6a, 0x41,
		0x6a, 0x41, 0x6a, 0x41, 0x6a, 0x61, 0x14, 0xcb, 0xf7, 0x70, 0xe8, 0x06, 0x91, 0x34, 0x81, 0xd3,
		0x2e, 0x06, 0x0a, 0x4a, 0x0b, 0x4a, 0x0b, 0x4a, 0x0b, 0x4a, 0x0b, 0x4a, 0x0b, 0x4a, 0x0b, 0x4a,
		0x0b, 0x4a, 0x0b, 0x4a, 0x0b, 0xa3, 0x58, 0xbe, 0x87, 0x51, 0xe0, 0x7a, 0xa1, 0x8c, 0xe4, 0x9d,
		0x01, 0x75, 0x49, 0xcf, 0xc6, 0x0a, 0x62, 0x0b, 0x62, 0x0b, 0x62, 0x0b, 0x62, 0x0b, 0x62, 0x0b,
		0x62, 0x0b, 0x62, 0x0b, 0x62, 0x0b, 0x62, 0x8b, 0x11, 0x31, 0x35, 0x51, 0xab, 0xea, 0x79, 0x7e,
		0xe4, 0x46, 0xd2, 0xe7, 0x59, 0x00, 0x65, 0x85, 0x9d, 0x6f, 0xe2, 0xd6, 0x1d, 0xce, 0x0f, 0xa0,
		0xcc, 0xf9, 0x43, 0xe1, 0x75, 0xa6, 0x44, 0xd1, 0xf6, 0x44, 0xf4, 0xaf, 0x1f, 0x7c, 0xb7, 0xa5,
		0x17, 0x46, 0xae, 0xd7, 0x11, 0xb9, 0xd5, 0x27, 0xc2, 0xc4, 0x33, 0xb9, 0x61, 0xe0, 0x47, 0x7e,
		0xc7, 0x1f, 0x84, 0xf1, 0xa3, 0x5c, 0xbb, 0x3f, 0xcc, 0x05, 0xb2, 0x9d, 0x73, 0x7b, 0xd2, 0x0e,
		0xdd, 0x9e, 0x0c, 0xe3, 0x47, 0x39, 0x39, 0xbc, 0x2b, 0xdb, 0x23, 0x4f, 0x76, 0xdc, 0x30, 0xca,
		0x79, 0x42, 0xf6, 0xbf, 0xb5, 0xfd, 0x20, 0x8c, 0x1f, 0xe5, 0xdc, 0xee, 0x3f, 0x53, 0x4f, 0xe5,
		0x8f, 0x22, 0x7b, 0x18, 0x88, 0x5c, 0xe0, 0x8f, 0x22, 0x11, 0xce, 0x7e, 0xe5, 0x46, 0xde, 0x77,
		0xcf, 0xff, 0xd7, 0xb3, 0xdd, 0x28, 0x0a, 0x64, 0x7b, 0xfa, 0x87, 0xc4, 0x53, 0x39, 0x8e, 0x67,
		0x1f, 0xce, 0xa6, 0x3d, 0x0a, 0x46, 0x9d, 0xc8, 0x9b, 0xa3, 0x62, 0x3d, 0x9e, 0xf5, 0xcb, 0xd9,
		0x8c, 0xd6, 0xe6, 0x13, 0xea, 0xac, 0xfc, 0x3b, 0x5c, 0x7d, 0xc2, 0xb9, 0x5a, 0xcc, 0x78, 0xfc,
		0xc8, 0x79, 0xdf, 0x1f, 0x3a, 0x0d, 0xd9, 0x76, 0xaa, 0x3d, 0xd9, 0x9c, 0x4c, 0xf8, 0xe2, 0x81,
		0x53, 0x1b, 0xde, 0x95, 0xbf, 0xcc, 0xa6, 0xdb, 0xb9, 0x5c, 0x4c, 0x77, 0xfc, 0xc8, 0xa9, 0x76,
		0xff, 0x69, 0xc8, 0x76, 0x7d, 0x14, 0x5d, 0x05, 0xc2, 0x69, 0x4c, 0xe7, 0x7a, 0xf6, 0xcb, 0xf9,
		0x32, 0x9b, 0xd8, 0x6a, 0x3c, 0xd5, 0x89, 0x67, 0x9c, 0xe6, 0x74, 0xa6, 0x71, 0x5a, 0x29, 0xe3,
		0x91, 0x30, 0x81, 0xc6, 0x09, 0xdb, 0xe7, 0xd8, 0x7e, 0xd8, 0x3a, 0x97, 0x61, 0x34, 0x59, 0xd0,
		0xac, 0x80, 0xda, 0xba, 0x90, 0xde, 0xd9, 0x40, 0x4c, 0xb8, 0x7b, 0xc8, 0x2b, 0x76, 0xb7, 0x2e,
		0xdc, 0xfb, 0x67, 0x23, 0xcb, 0x1f, 0x17, 0x8b, 0xe5, 0x4a, 0xb1, 0x78, 0x58, 0x39, 0xaa, 0x1c,
		0x9e, 0x94, 0x4a, 0xf9, 0x72, 0x9e, 0x51, 0xa9, 0x9c, 0x55, 0x0f, 0xba, 0x22, 0x10, 0xdd, 0xf7,
		0x93, 0xa5, 0xe7, 0x8d, 0x06, 0x03, 0x58, 0x24, 0x7f, 0x92, 0x92, 0x6d, 0x72, 0x62, 0xb1, 0x3a,
		0xc2, 0x3a, 0x5b, 0x74, 0x84, 0x07, 0x11, 0xd1, 0xef, 0xf6, 0xf5, 0x8e, 0x40, 0x33, 0xbc, 0x71,
		0x83, 0xb5, 0x2c, 0xc1, 0x19, 0x03, 0xf0, 0x32, 0x1d, 0xb4, 0xf4, 0x62, 0x94, 0x3e, 0x64, 0xd0,
		0x73, 0x65, 0x4d, 0x58, 0xb4, 0x08, 0x76, 0x66, 0xdb, 0x1a, 0x7b, 0x13, 0xdb, 0xb7, 0xa5, 0xae,
		0x12, 0x6a, 0x1e, 0x11, 0x0e, 0x9f, 0x88, 0x86, 0x75, 0x04, 0xc3, 0x23, 0x62, 0xd1, 0x65, 0x36,
		0x4c, 0x5c, 0xb7, 0xb1, 0x2e, 0x5b, 0xa3, 0x7f, 0x36, 0xcb, 0x2f, 0xeb, 0xf1, 0xc2, 0xf4, 0x3e,
		0x90, 0xf6, 0x8a, 0xc4, 0xb0, 0xa1, 0x1b, 0x2e, 0x0c, 0x84, 0x09, 0x0d, 0x00, 0x61, 0x0a, 0x30,
		0xd0, 0x42, 0x02, 0x9d, 0x61, 0xd2, 0x5c, 0x89, 0xc8, 0xf4, 0x75, 0x99, 0xbc, 0x49, 0xa6, 0x4e,
		0x68, 0xe3, 0xec, 0x6d, 0x9b, 0xc6, 0xa8, 0xd5, 0x9b, 0x18, 0x81, 0x79, 0x59, 0x8b, 0xf5, 0x64,
		0xbb, 0xdd, 0x6e, 0x20, 0xc2, 0x90, 0xcc, 0xc0, 0xe2, 0x34, 0xa1, 0xc4, 0x08, 0x88, 0x40, 0x85,
		0x36, 0x85, 0x97, 0x3c, 0x25, 0x57, 0x47, 0x8a, 0xad, 0xde, 0x94, 0x59, 0x5d, 0x29, 0xb0, 0xda,
		0x53, 0x5a, 0xb5, 0xa7, 0xa8, 0x6a, 0x4f, 0x39, 0xcd, 0x16, 0xdd, 0x21, 0x4f, 0xf1, 0x8c, 0xed,
		0x76, 0x20, 0xdc, 0x5e, 0x20, 0x7a, 0x94, 0x46, 0xbb, 0x48, 0xc1, 0xac, 0x10, 0x5e, 0xf3, 0x6a,
		0xce, 0xe8, 0xde, 0xbd, 0x9b, 0x65, 0x8d, 0xe5, 0x12, 0x3e, 0x08, 0x0c, 0xe2, 0x05, 0x6c, 0xd0,
		0x8d, 0x04, 0x3d, 0x6d, 0xa0, 0x4c, 0xf7, 0x8b, 0x17, 0x29, 0xb8, 0x02, 0xb8, 0x02, 0xb8, 0x02,
		0xb8, 0x02, 0x1f, 0xae, 0xf0, 0x51, 0xd2, 0xee, 0xf0, 0xe9, 0x0b, 0x18, 0xb9, 0x04, 0x8e, 0x9a,
		0x02, 0x48, 0x6d, 0xce, 0x41, 0xa7, 0x93, 0xe0, 0xe1, 0x2c, 0x74, 0x3b, 0x0d, 0x36, 0xce, 0x83,
		0x8d, 0x13, 0x61, 0xe3, 0x4c, 0x68, 0x9d, 0x0a, 0xb1, 0x73, 0xd1, 0x17, 0x90, 0x26, 0xec, 0x5e,
		0x0e, 0x35, 0xa1, 0xfc, 0x12, 0xfd, 0xd7, 0x70, 0x80, 0xd9, 0x62, 0xee, 0xf5, 0x1c, 0x4b, 0xa6,
		0x31, 0x1b, 0xe3, 0xe9, 0xce, 0xdf, 0x15, 0x35, 0xde, 0xfb, 0xc4, 0x1a, 0x38, 0xd6, 0x38, 0x86,
		0x2b, 0x37, 0x8a, 0x44, 0xe0, 0x69, 0x3f, 0xa5, 0xce, 0xda, 0xdf, 0xbf, 0x39, 0xb4, 0x4f, 0x5a,
		0x8f, 0x37, 0x79, 0xfb, 0xa4, 0x35, 0x7b, 0x98, 0x9f, 0xfe, 0x9a, 0x3d, 0x2e, 0xdc, 0x1c, 0xda,
		0xc5, 0xc5, 0xe3, 0xd2, 0xcd, 0xa1, 0x5d, 0x6a, 0x1d, 0xfc, 0xf5, 0xd7, 0xbb, 0x83, 0x1f, 0x47,
		0xe3, 0x97, 0xbf, 0x51, 0x5f, 0xee, 0x64, 0x4b, 0xe7, 0xad, 0xae, 0x37, 0x6b, 0x7f, 0xb0, 0xb9,
		0xdf, 0x7f, 0x53, 0xde, 0xf0, 0xff, 0x68, 0xbc, 0xe3, 0xbb, 0x94, 0x78, 0xc7, 0x03, 0xdc, 0xcb,
		0x00, 0x77, 0x96, 0xe0, 0xee, 0xda, 0xbd, 0xaa, 0xfd, 0xa9, 0xf5, 0x23, 0xff, 0xb6, 0x38, 0x3e,
		0x3d, 0xf8, 0x51, 0x19, 0xaf, 0x3e, 0xf9, 0xb8, 0xee, 0x65, 0xf9, 0xb7, 0x95, 0xf1, 0xe9, 0x86,
		0xbf, 0x94, 0xc7, 0xa7, 0xbf, 0xf9, 0x19, 0xa5, 0xf1, 0x7e, 0xe2, 0xa5, 0x93, 0xe7, 0x0b, 0x9b,
		0xde, 0x50, 0xdc, 0xf0, 0x86, 0xa3, 0x4d, 0x6f, 0x38, 0xda, 0xf0, 0x86, 0x8d, 0x43, 0x2a, 0x6c,
		0x78, 0x43, 0x69, 0xfc, 0x98, 0x78, 0xfd, 0xfe, 0xfa, 0x97, 0x96, 0xc7, 0x07, 0x8f, 0x9b, 0xfe,
		0x56, 0x19, 0x3f, 0x9e, 0x1e, 0xc0, 0xd5, 0xf1, 0x71, 0x75, 0x58, 0xfe, 0xf4, 0xcb, 0x7f, 0xf7,
		0x1c, 0xff, 0x9b, 0x6c, 0x7f, 0x4f, 0xe4, 0x3b, 0xbe, 0x52, 0xd5, 0x42, 0xbe, 0x63, 0x22, 0xdf,
		0x91, 0xba, 0xbd, 0x0b, 0xcb, 0x2c, 0x47, 0xc2, 0xce, 0x2b, 0x04, 0xc9, 0x09, 0x6f, 0x0c, 0xb6,
		0xd5, 0x45, 0xb1, 0x1f, 0xf1, 0x26, 0x14, 0x6d, 0x59, 0x1f, 0x7d, 0xf9, 0x1e, 0x8b, 0x32, 0x3d,
		0xda, 0x72, 0x3c, 0xd5, 0x0b, 0x95, 0xd8, 0x99, 0x70, 0x76, 0x22, 0x16, 0x49, 0x3a, 0x14, 0x3b,
		0xb7, 0xa1, 0xd6, 0x61, 0xa8, 0x83, 0x71, 0x35, 0x9f, 0xac, 0xc8, 0xde, 0xa8, 0xec, 0x8c, 0xa1,
		0x7d, 0x29, 0x34, 0x2b, 0x46, 0xe6, 0xa4, 0xc6, 0x8a, 0xd2, 0x5f, 0xe3, 0xe9, 0x7e, 0x62, 0xca,
		0xd6, 0xa2, 0xda, 0x4a, 0xd8, 0x58, 0x87, 0x02, 0x9b, 0xd0, 0x6e, 0x0b, 0xe9, 0x5a, 0x40, 0x7a,
		0xeb, 0x34, 0xc5, 0x35, 0xaa, 0x28, 0x9b, 0x59, 0x69, 0xd6, 0xb2, 0xa2, 0xec, 0xe4, 0xa7, 0x44,
		0xb3, 0x42, 0xca, 0x1f, 0xac, 0x30, 0x91, 0x8c, 0x26, 0x51, 0x4c, 0x75, 0x22, 0x18, 0x59, 0xa2,
		0x17, 0x59, 0x22, 0x17, 0x59, 0xa2, 0x16, 0x6f, 0xef, 0xa7, 0x2a, 0x5b, 0xd7, 0x5a, 0xf8, 0x20,
		0x7b, 0xee, 0x1d, 0x14, 0xad, 0xcb, 0x85, 0x75, 0x2d, 0x5f, 0x4e, 0xd1, 0x92, 0x51, 0x9b, 0x5f,
		0xab, 0x3c, 0x8f, 0x96, 0x22, 0x5f, 0x96, 0x36, 0x2f, 0x96, 0x2a, 0xff, 0x95, 0x3c, 0xcf, 0x95,
		0x3c, 0x9f, 0x95, 0x3c, 0x6f, 0xd5, 0xac, 0x50, 0x5a, 0x79, 0xbe, 0xe9, 0x53, 0x02, 0x4a, 0x57,
		0x78, 0x91, 0x8c, 0x1e, 0xd4, 0x16, 0x3d, 0xc6, 0x0c, 0x4d, 0xa1, 0x78, 0x69, 0xd5, 0xe6, 0x5f,
		0xe5, 0xbd, 0x1b, 0x12, 0x98, 0xe8, 0x62, 0x02, 0xab, 0x9f, 0x6a, 0x4e, 0x73, 0xf2, 0xbf, 0xeb,
		0x3f, 0xaf, 0xce, 0x54, 0x9b, 0xe9, 0x57, 0x77, 0x30, 0x12, 0x21, 0x49, 0x8e, 0x00, 0x71, 0x35,
		0x63, 0xb3, 0x71, 0x7d, 0xe6, 0x5c, 0xd5, 0xcf, 0x6b, 0x1f, 0xfe, 0x74, 0x6a, 0x57, 0x5f, 0xcb,
		0x56, 0x16, 0x4a, 0x43, 0x89, 0xe7, 0xf0, 0xfc, 0xe8, 0xeb, 0xd5, 0xe5, 0x64, 0xf6, 0x8a, 0xce,
		0x97, 0xcb, 0xda, 0x87, 0x6a, 0xf3, 0x1a, 0xb3, 0xf8, 0x8a, 0x59, 0xac, 0x5d, 0xfe, 0xb7, 0x79,
		0x5d, 0xbd, 0x3e, 0x73, 0x9a, 0x57, 0x9f, 0x30, 0x81, 0x5b, 0x2d, 0xc3, 0x8b, 0x2f, 0xe7, 0xd7,
		0x58, 0x88, 0xaf, 0x9c, 0xc7, 0xaf, 0x57, 0x97, 0x5f, 0x8b, 0xce, 0xa7, 0xf3, 0xfa, 0xff, 0x34,
		0xaf, 0xce, 0x3e, 0x60, 0x06, 0xb7, 0x76, 0x2a, 0x45, 0xcc, 0xe1, 0x2b, 0xac, 0xb9, 0x30, 0xb1,
		0xe6, 0xaf, 0x57, 0xe7, 0x4d, 0xcc, 0xde, 0x6b, 0x67, 0xef, 0xec, 0xeb, 0xd5, 0x25, 0x66, 0x6f,
		0x0b, 0x57, 0x8c, 0xc9, 0x7b, 0xf9, 0xe4, 0x4d, 0x1d, 0xf0, 0x79, 0xf5, 0xfd, 0xd9, 0xf9, 0xd9,
		0x47, 0xf0, 0xc1, 0x34, 0xf8, 0x20, 0xac, 0x78, 0x3b, 0x3e, 0x58, 0x06, 0x1f, 0xdc, 0xda, 0xa0,
		0x41, 0x07, 0xb7, 0x9a, 0xc0, 0x32, 0x10, 0x31, 0x55, 0x83, 0xc6, 0x2c, 0x6e, 0x67, 0xce, 0x98,
		0xbf, 0xed, 0xac, 0x99, 0x6e, 0xfe, 0x94, 0x5e, 0xa1, 0x65, 0xda, 0xbe, 0x07, 0x92, 0xb6, 0x52,
		0xfd, 0x7c, 0x9d, 0x49, 0x5b, 0xaa, 0xea, 0x4a, 0xf4, 0x64, 0x6b, 0x29, 0x28, 0x10, 0x49, 0x31,
		0x4f, 0xeb, 0x0d, 0xa3, 0xc5, 0x1d, 0x1f, 0x4d, 0xab, 0x20, 0x95, 0x41, 0x4d, 0x95, 0x86, 0xba,
		0x6a, 0x0c, 0xd2, 0xaa, 0x0b, 0x35, 0xd5, 0x15, 0x69, 0xad, 0x0a, 0x45, 0x50, 0xa7, 0x13, 0xe2,
		0xac, 0x54, 0xd3, 0x23, 0xe9, 0x41, 0x2d, 0x1d, 0x38, 0xdb, 0x1e, 0x7c, 0xb6, 0xfb, 0x84, 0x2d,
		0x17, 0x68, 0xda, 0x0b, 0x53, 0xc3, 0x82, 0x4c, 0x61, 0x1d, 0x92, 0xae, 0xbf, 0xed, 0xd6, 0xdd,
		0xeb, 0x57, 0xcb, 0x16, 0x2b, 0x65, 0x76, 0xd0, 0x7a, 0x28, 0xa2, 0xed, 0xdb, 0x72, 0x3e, 0xe5,
		0xfa, 0xc5, 0x1f, 0xb9, 0xe5, 0x0a, 0x4e, 0x27, 0x4d, 0x39, 0xb5, 0xbc, 0xbd, 0x34, 0xf3, 0xf3,
		0xd4, 0xe4, 0xe1, 0xa5, 0x9d, 0x6f, 0xa7, 0x2c, 0xaf, 0x4e, 0x59, 0xfe, 0x9c, 0xb2, 0x3c, 0x39,
		0xbd, 0x58, 0x9e, 0x56, 0x1a, 0x70, 0x6c, 0x9b, 0xe9, 0x2d, 0x91, 0x55, 0xab, 0x4f, 0x6b, 0x85,
		0xa4, 0x5b, 0xa3, 0x90, 0x7a, 0xf2, 0xae, 0x8a, 0x64, 0x5d, 0xb5, 0xc9, 0xb9, 0xaa, 0x92, 0x71,
		0x95, 0x27, 0xdf, 0x2a, 0x4f, 0xb6, 0x55, 0x9e, 0x5c, 0xcb, 0x2b, 0x8e, 0x4d, 0xbb, 0xa6, 0xc0,
		0x72, 0xfb, 0xfd, 0x40, 0xf4, 0xdd, 0xc8, 0x0f, 0xd4, 0xd5, 0x41, 0x3d, 0xbb, 0x86, 0x61, 0xc5,
		0x50, 0x87, 0x28, 0x86, 0xa2, 0x01, 0x22, 0x32, 0x40, 0x22, 0x03, 0x26, 0x32, 0x80, 0x32, 0x43,
		0x55, 0x56, 0x56, 0x0c, 0xa5, 0xf6, 0x44, 0x1a, 0x92, 0x13, 0x68, 0x14, 0x9f, 0x38, 0xa3, 0xac,
		0xb6, 0x93, 0x02, 0xd6, 0x68, 0xe1, 0x8d, 0x0a, 0xe6, 0xc8, 0xe1, 0x8e, 0x1c, 0xf6, 0xc8, 0xe1,
		0x4f, 0x0d, 0x0c, 0x2a, 0x82, 0x43, 0xe5, 0xb0, 0xf8, 0xc4, 0xef, 0x88, 0x0e, 0x6e, 0x79, 0x22,
		0x7b, 0x34, 0xad, 0xb1, 0x68, 0xce, 0x63, 0x21, 0x3b, 0x7f, 0x85, 0xf2, 0xbc, 0x15, 0x3d, 0xe7,
		0xab, 0x50, 0x9f, 0xa7, 0xa2, 0xed, 0xfc, 0x14, 0x6d, 0xe7, 0xa5, 0x68, 0x3b, 0x1f, 0xc5, 0xec,
		0xde, 0x7e, 0x64, 0xe7, 0x9d, 0xe8, 0x3a, 0xe5, 0x82, 0xb2, 0xe1, 0x39, 0x79, 0x63, 0xf3, 0x8c,
		0x9d, 0x4e, 0xd1, 0xa2, 0xb8, 0x45, 0x3a, 0x5a, 0x70, 0x67, 0xee, 0x54, 0x89, 0x96, 0xa9, 0x7d,
		0xf6, 0x14, 0x46, 0x4d, 0x2e, 0x25, 0xcf, 0x04, 0xc5, 0x04, 0xc5, 0x04, 0xc5, 0x04, 0xc5, 0x04,
		0xc5, 0x5c, 0x8b, 0x8e, 0xb6, 0x37, 0xba, 0x6d, 0x8b, 0x80, 0x90, 0x5f, 0x12, 0x1c, 0xea, 0x6e,
		0x35, 0x5c, 0xaf, 0x4f, 0x77, 0x42, 0x1e, 0x61, 0x37, 0xfe, 0x0b, 0xe9, 0x69, 0x38, 0x9f, 0x5a,
		0xcf, 0xa1, 0xb6, 0xd3, 0xce, 0x2e, 0x1a, 0xae, 0xfb, 0x29, 0x70, 0x3b, 0x91, 0xf4, 0xbd, 0x8f,
		0xb2, 0x2f, 0x67, 0x59, 0xb5, 0x74, 0x47, 0x56, 0x10, 0x9e, 0x65, 0x70, 0xe1, 0xde, 0xef, 0xdc,
		0x52, 0x2a, 0x16, 0x4e, 0x8a, 0x27, 0xe5, 0x4a, 0xe1, 0xa4, 0xb4, 0x43, 0x6b, 0x2a, 0x23, 0x47,
		0x43, 0x20, 0x92, 0x5a, 0x17, 0x49, 0x15, 0x29, 0x43, 0xa9, 0x22, 0x62, 0x29, 0xc4, 0x52, 0x88,
		0xa5, 0x10, 0x4b, 0x21, 0x96, 0x42, 0x2c, 0x85, 0x58, 0x0a, 0xb1, 0x14, 0x62, 0x29, 0xc4, 0x52,
		0x88, 0xa5, 0x10, 0x4b, 0x91, 0xc5, 0x52, 0x38, 0xfd, 0x69, 0xcd, 0x75, 0xe8, 0xca, 0x36, 0x17,
		0x65, 0x7f, 0xf1, 0xa3, 0xdc, 0x53, 0xd2, 0xbe, 0xf2, 0xd3, 0x38, 0x69, 0x0a, 0x3d, 0xa3, 0x28,
		0x68, 0x8a, 0x28, 0x5c, 0x3c, 0x70, 0xaa, 0xf1, 0x17, 0x54, 0x79, 0xd2, 0x26, 0xba, 0x87, 0x64,
		0xd1, 0x24, 0x8c, 0x6d, 0x21, 0xb2, 0xd9, 0x08, 0x76, 0xe1, 0xbc, 0x27, 0x37, 0xb4, 0xe7, 0x2b,
		0x47, 0x55, 0xa5, 0xd3, 0xfc, 0x02, 0x28, 0x73, 0x42, 0x99, 0x13, 0x0b, 0xb5, 0x0b, 0x65, 0x4e,
		0xb4, 0xee, 0x4f, 0xdd, 0x99, 0x4f, 0xa1, 0x1d, 0x8a, 0xfe, 0x7c, 0x82, 0x55, 0x1f, 0xf8, 0xf4,
		0x74, 0x2d, 0xc3, 0x0b, 0x9e, 0x70, 0xda, 0x13, 0x13, 0xc0, 0x23, 0x07, 0x3e, 0x72, 0x00, 0x24,
		0x07, 0x42, 0x33, 0x43, 0x67, 0xe5, 0x05, 0x4f, 0x6a, 0xeb, 0x41, 0x13, 0xd6, 0xa9, 0x3a, 0x36,
		0x26, 0x80, 0xcb, 0x24, 0x6c, 0x16, 0xb0, 0x7b, 0x6a, 0x06, 0x9c, 0x6a, 0x83, 0x55, 0x6d, 0xf0,
		0xaa, 0x0d, 0x66, 0xd5, 0x6b, 0xa0, 0x7b, 0x04, 0xbb, 0xa7, 0xaa, 0xe1, 0x37, 0xbe, 0xd0, 0xad,
		0x98, 0xee, 0x98, 0x9e, 0x52, 0x77, 0x4a, 0x9e, 0x5f, 0x97, 0x68, 0x11, 0xd2, 0xee, 0xd4, 0x90,
		0xa5, 0xb7, 0xe8, 0x00, 0x6a, 0xbd, 0x80, 0xad, 0x0b, 0xb8, 0xb5, 0x03, 0xb8, 0x76, 0x20, 0xd7,
		0x0e, 0xe8, 0x34, 0xc0, 0x4e, 0x04, 0xf0, 0xf1, 0x6c, 0x92, 0xa5, 0xc9, 0xac, 0x53, 0x0f, 0xc8,
		0xd2, 0x65, 0x56, 0x81, 0xb8, 0x42, 0x78, 0x49, 0xda, 0xf4, 0x99, 0xc5, 0x0f, 0x2d, 0x2c, 0xed,
		0xe9, 0x4a, 0xa7, 0xd1, 0xe4, 0x61, 0x13, 0x97, 0xd7, 0x94, 0x5e, 0x13, 0x5f, 0x5f, 0x63, 0x4a,
		0x04, 0x31, 0x62, 0x2d, 0x2f, 0x39, 0x0d, 0x69, 0x37, 0xdc, 0x96, 0x9c, 0xae, 0x34, 0x1c, 0x56,
		0x6b, 0xef, 0x4d, 0x36, 0xaf, 0xd6, 0xca, 0x14, 0xd7, 0x50, 0x72, 0x00, 0xc2, 0xef, 0xb8, 0x25,
		0x35, 0x07, 0x24, 0xfc, 0x0e, 0x3a, 0x91, 0x1d, 0xa0, 0xf0, 0xcb, 0xc1, 0x28, 0x39, 0x60, 0x41,
		0xbf, 0xa5, 0x10, 0xac, 0x5d, 0x2b, 0xa2, 0xe4, 0xc8, 0x31, 0x3f, 0x9e, 0x5e, 0x15, 0xfa, 0x04,
		0xf4, 0x09, 0xe8, 0x13, 0xd0, 0x27, 0xa0, 0x4f, 0xe8, 0xd0, 0x27, 0x86, 0x6e, 0xf4, 0x6d, 0x91,
		0xe2, 0x60, 0x13, 0xe2, 0xf1, 0x73, 0x4c, 0xce, 0x17, 0x09, 0xaf, 0x79, 0xe6, 0x8d, 0x6e, 0x27,
		0xb3, 0x9d, 0x95, 0x34, 0x77, 0xb3, 0x37, 0x61, 0x88, 0xd2, 0xc7, 0xe3, 0xeb, 0x69, 0xcd, 0x99,
		0x9d, 0x59, 0x5b, 0xee, 0x29, 0xa7, 0x28, 0x47, 0xb1, 0x65, 0xbe, 0xa7, 0x2f, 0xa3, 0x36, 0xbc,
		0x72, 0xa3, 0x6f, 0x4e, 0x35, 0x6c, 0xce, 0xbe, 0xae, 0xca, 0xe4, 0x72, 0xf5, 0xe6, 0x60, 0x56,
		0x72, 0x09, 0x49, 0x20, 0x4a, 0x17, 0x78, 0x6a, 0x0d, 0x34, 0x69, 0x02, 0x4b, 0x54, 0xe8, 0xa4,
		0x09, 0xad, 0xd9, 0xab, 0xd1, 0x59, 0x01, 0x53, 0xd4, 0xe8, 0x18, 0x60, 0x1c, 0x1c, 0x8c, 0x22,
		0x3b, 0x05, 0x3a, 0x53, 0x0b, 0xd8, 0x8d, 0xe2, 0x9c, 0xa2, 0xf2, 0xea, 0x9c, 0x22, 0xca, 0x73,
		0x50, 0x9e, 0xc3, 0x48, 0xed, 0x42, 0x79, 0x0e, 0xad, 0xe7, 0x53, 0x58, 0x9e, 0x53, 0xa4, 0xac,
		0xcf, 0x29, 0xa2, 0x40, 0x47, 0x1b, 0xc4, 0xd1, 0x42, 0x1d, 0x15, 0xe4, 0x91, 0x43, 0x1f, 0x39,
		0x04, 0x92, 0x43, 0xa1, 0x99, 0x1a, 0x0a, 0x0a, 0x74, 0xd8, 0xc1, 0x65, 0x12, 0x36, 0x51, 0xa0,
		0x63, 0x08, 0x9c, 0x6a, 0x83, 0x55, 0x6d, 0xf0, 0xaa, 0x0d, 0x66, 0xd5, 0xc2, 0xad, 0x62, 0xd8,
		0x25, 0x83, 0xdf, 0xf8, 0x42, 0x28, 0xd0, 0x31, 0x90, 0xd7, 0xea, 0x04, 0x6a, 0xbd, 0x80, 0xad,
		0x0b, 0xb8, 0xb5, 0x03, 0xb8, 0x76, 0x20, 0xd7, 0x0e, 0xe8, 0x34, 0xc0, 0x4e, 0x04, 0xf0, 0xf1,
		0x6c, 0xa2, 0x40, 0x47, 0xf5, 0x25, 0x51, 0xa0, 0x93, 0x3d, 0x0f, 0x9b, 0xb8, 0x3c, 0x0a, 0x74,
		0x50, 0xa0, 0xa3, 0x69, 0xc9, 0xa1, 0x40, 0x07, 0x05, 0x3a, 0x66, 0x70, 0x0d, 0x14, 0xe8, 0xa0,
		0x40, 0xc7, 0xc0, 0xb5, 0x8b, 0x02, 0x1d, 0xe8, 0x13, 0xd0, 0x27, 0xa0, 0x4f, 0x40, 0x9f, 0xd8,
		0x35, 0x7d, 0x02, 0x05, 0x3a, 0xa6, 0xb3, 0x03, 0x14, 0xe8, 0xbc, 0xe0, 0x7a, 0x7a, 0x13, 0x66,
		0x8b, 0x8b, 0x34, 0xf2, 0xe2, 0xce, 0x94, 0xe8, 0x14, 0xe7, 0x69, 0xe5, 0x45, 0x14, 0xe9, 0x50,
		0x1b, 0x19, 0x8a, 0x74, 0x8c, 0x0b, 0x2e, 0x51, 0xa4, 0x93, 0x2e, 0xbc, 0x66, 0xb0, 0x4c, 0x67,
		0x15, 0x50, 0x51, 0xa8, 0x63, 0x80, 0x81, 0xb0, 0x30, 0x8c, 0x0c, 0x55, 0xea, 0x14, 0x77, 0xa5,
		0x54, 0x47, 0x7a, 0x5d, 0x71, 0xaf, 0xae, 0x4e, 0x67, 0xf6, 0xf1, 0x6a, 0x8a, 0x74, 0x0e, 0x51,
		0xa4, 0x83, 0x22, 0x1d, 0xa6, 0xca, 0x16, 0x8a, 0x74, 0xd4, 0x2a, 0x4f, 0xf1, 0xba, 0x1f, 0x08,
		0xb7, 0x17, 0x88, 0x9e, 0x8a, 0x45, 0xbf, 0x10, 0x8f, 0x14, 0x24, 0xba, 0x58, 0x57, 0x73, 0x47,
		0xfd, 0xee, 0xdd, 0x2c, 0x40, 0xcf, 0xcd, 0x80, 0x72, 0x07, 0x1c, 0x8e, 0x9a, 0x9a, 0x01, 0xa5,
		0x35, 0x02, 0xca, 0xab, 0x42, 0x0b, 0x70, 0x38, 0x70, 0x38, 0x70, 0x38, 0x29, 0xcc, 0x82, 0xba,
		0xaa, 0x50, 0xd9, 0x1f, 0x12, 0x94, 0x83, 0x4a, 0x65, 0x3b, 0x9c, 0x8a, 0xf7, 0xa7, 0x51, 0x07,
		0xca, 0x0e, 0xe4, 0xc8, 0xc1, 0x8e, 0x1c, 0xf4, 0xc8, 0xc1, 0x4f, 0x9d, 0x7a, 0xb5, 0xa7, 0x50,
		0x9c, 0x55, 0xbe, 0xff, 0x1b, 0xdb, 0xcd, 0x48, 0x7a, 0x51, 0xb9, 0xa8, 0xd2, 0x66, 0xe6, 0x28,
		0x76, 0xac, 0xf0, 0x12, 0x34, 0xc9, 0xe6, 0x04, 0x7b, 0x91, 0x94, 0xc9, 0xe4, 0xd4, 0xe9, 0x4f,
		0xc4, 0xc9, 0xe2, 0x3a, 0x12, 0x74, 0x29, 0xd2, 0xf2, 0x28, 0x93, 0xbf, 0x75, 0x2d, 0x11, 0x7d,
		0x49, 0xa3, 0x5a, 0x56, 0x8d, 0xa1, 0x3b, 0xdf, 0x2d, 0x53, 0xb6, 0x99, 0x14, 0x44, 0xbb, 0x6e,
		0xe4, 0xdf, 0xca, 0x8e, 0xed, 0xce, 0x4f, 0xf0, 0x17, 0x04, 0x81, 0xc6, 0xea, 0x15, 0x11, 0x74,
		0x20, 0xe8, 0x40, 0xd0, 0x81, 0xa0, 0xc3, 0xc0, 0xa0, 0xa3, 0xed, 0xfb, 0x03, 0xe1, 0x7a, 0x04,
		0x51, 0x47, 0x3e, 0xbf, 0xc3, 0x4e, 0xaa, 0x33, 0x18, 0x85, 0x91, 0x08, 0xec, 0x81, 0x0c, 0x09,
		0x1a, 0xa3, 0x2d, 0x5d, 0x0d, 0xce, 0x09, 0xce, 0x09, 0xce, 0x09, 0xce, 0xc9, 0x40, 0xe7, 0x24,
		0x87, 0x77, 0x45, 0xdb, 0xed, 0x76, 0x03, 0x11, 0x86, 0x14, 0x1e, 0x4a, 0xa5, 0x30, 0x76, 0xe5,
		0x46, 0x91, 0x08, 0x3c, 0xe5, 0xd2, 0x98, 0xb5, 0xbf, 0x7f, 0x73, 0x68, 0x9f, 0xb4, 0x1e, 0x6f,
		0xf2, 0xf6, 0x49, 0x6b, 0xf6, 0x30, 0x3f, 0xfd, 0x35, 0x7b, 0x5c, 0xb8, 0x39, 0xb4, 0x8b, 0x8b,
		0xc7, 0xa5, 0x9b, 0x43, 0xbb, 0xd4, 0x3a, 0xf8, 0xeb, 0xaf, 0x77, 0x07, 0x3f, 0x8e, 0xc6, 0x2f,
		0x7f, 0xa3, 0x3a, 0x93, 0x68, 0xa9, 0xbc, 0x15, 0xf5, 0x66, 0xed, 0x0f, 0xb2, 0xfb, 0xf1, 0x37,
		0xe5, 0x0d, 0xf9, 0x8f, 0x65, 0x9a, 0xc6, 0x80, 0xec, 0xfa, 0xdf, 0xbb, 0x52, 0xf6, 0xb3, 0xeb,
		0x8d, 0x20, 0xf2, 0x6a, 0x52, 0x3e, 0x93, 0x9e, 0x4f, 0x41, 0xea, 0x27, 0xa8, 0x3b, 0xa8, 0x3b,
		0xa8, 0x3b, 0xa8, 0x3b, 0x36, 0xb3, 0x7f, 0xf7, 0x12, 0xd8, 0xcc, 0xe6, 0xe7, 0x5e, 0x12, 0x97,
		0xc3, 0x66, 0x76, 0x5a, 0x04, 0x13, 0x9b, 0xd9, 0xd9, 0x5a, 0x35, 0xd8, 0xcc, 0x36, 0x2e, 0xbc,
		0x18, 0xf8, 0x1d, 0x77, 0x60, 0x4f, 0xb8, 0x99, 0xfa, 0x18, 0xe3, 0xd9, 0xb5, 0x10, 0x68, 0x20,
		0xd0, 0x40, 0xa0, 0x81, 0x40, 0xc3, 0xd0, 0x40, 0xe3, 0xa8, 0x40, 0x10, 0x68, 0x54, 0x10, 0x68,
		0x20, 0xd0, 0x40, 0xa0, 0x81, 0x40, 0xe3, 0x37, 0x96, 0x08, 0x75, 0x4b, 0x64, 0x84, 0x17, 0x08,
		0x2f, 0x7e, 0x67, 0x99, 0xdc, 0x8a, 0xae, 0xfa, 0xb8, 0x62, 0x72, 0x11, 0x04, 0x14, 0x08, 0x28,
		0x10, 0x50, 0x20, 0xa0, 0x40, 0x40, 0x81, 0x80, 0x02, 0x01, 0x05, 0x02, 0x0a, 0x04, 0x14, 0x08,
		0x28, 0x10, 0x50, 0x64, 0x2f, 0xa0, 0xf0, 0xc4, 0x7d, 0x64, 0x7f, 0xf3, 0x09, 0xba, 0x7b, 0xc4,
		0x57, 0x42, 0x68, 0x81, 0xd0, 0x02, 0xa1, 0x05, 0x42, 0x0b, 0x03, 0x43, 0x0b, 0x39, 0xa4, 0xac,
		0x66, 0x38, 0x51, 0x78, 0x8d, 0xf9, 0x9c, 0x19, 0x1f, 0x5e, 0x10, 0x57, 0x9a, 0x24, 0xee, 0xd1,
		0x31, 0xc1, 0xb5, 0xa8, 0x2a, 0x1d, 0xe2, 0x0b, 0x66, 0xa3, 0x02, 0x25, 0xa6, 0x77, 0x14, 0xb7,
		0x88, 0xb2, 0x22, 0x25, 0xbe, 0x6a, 0x56, 0x2a, 0x53, 0xd4, 0x12, 0x71, 0xa2, 0x50, 0x96, 0x16,
		0xec, 0xca, 0x00, 0xbb, 0x54, 0xc1, 0xce, 0xb5, 0x7b, 0x55, 0xfb, 0x53, 0xeb, 0x47, 0xfe, 0x6d,
		0x71, 0x7c, 0x7a, 0xf0, 0xa3, 0x32, 0x5e, 0x7d, 0xf2, 0x71, 0xdd, 0xcb, 0xf2, 0x6f, 0x2b, 0xe3,
		0xd3, 0x0d, 0x7f, 0x29, 0x8f, 0x4f, 0x7f, 0xf3, 0x33, 0x4a, 0xe3, 0xfd, 0xc4, 0x4b, 0x27, 0xcf,
		0x17, 0x36, 0xbd, 0xa1, 0xb8, 0xe1, 0x0d, 0x47, 0x9b, 0xde, 0x70, 0xb4, 0xe1, 0x0d, 0x1b, 0x87,
		0x54, 0xd8, 0xf0, 0x86, 0xd2, 0xf8, 0x31, 0xf1, 0xfa, 0xfd, 0xf5, 0x2f, 0x2d, 0x8f, 0x0f, 0x1e,
		0x37, 0xfd, 0xad, 0x32, 0x7e, 0x3c, 0x3d, 0x00, 0xf4, 0x6f, 0x0f, 0xfd, 0x58, 0xb6, 0xf4, 0xcb,
		0xd6, 0x7c, 0x47, 0x08, 0x25, 0x4d, 0x81, 0x92, 0xe6, 0x07, 0xb2, 0xaf, 0x70, 0xaf, 0xe3, 0x49,
		0xbb, 0x99, 0x5d, 0x07, 0x2a, 0x1a, 0x54, 0x34, 0xa8, 0x68, 0x50, 0xd1, 0x0c, 0x54, 0xd1, 0xda,
		0xfd, 0xa1, 0x3d, 0x43, 0x31, 0x7b, 0x7a, 0x8a, 0x92, 0xe2, 0x73, 0x51, 0x29, 0xce, 0x41, 0x55,
		0x7c, 0xee, 0xa9, 0x49, 0x1e, 0xd0, 0x8d, 0xfc, 0xc0, 0x96, 0x5d, 0x2a, 0x47, 0xb8, 0xb8, 0x1c,
		0xfc, 0x21, 0xfc, 0x21, 0xfc, 0x21, 0xfc, 0xa1, 0x81, 0xfe, 0x10, 0x5d, 0xb2, 0x5e, 0x2d, 0xdb,
		0xa1, 0x4b, 0x16, 0x13, 0x61, 0x0a, 0x5d, 0xb2, 0xa8, 0x09, 0x1c, 0x0e, 0x7c, 0xd5, 0x74, 0xe0,
		0xab, 0xaa, 0x33, 0xe5, 0xf5, 0x9c, 0xf6, 0xaa, 0xe0, 0xc0, 0x78, 0x9e, 0x47, 0xef, 0x45, 0x23,
		0xcf, 0x13, 0x03, 0x5b, 0x78, 0x1d, 0x77, 0x18, 0x8e, 0x06, 0x6a, 0x16, 0x67, 0xec, 0xd3, 0xd7,
		0x5e, 0x0d, 0x07, 0xf3, 0xe1, 0x60, 0x3e, 0x16, 0x31, 0x07, 0x0e, 0xe6, 0xa3, 0x75, 0x87, 0xca,
		0x0e, 0xe6, 0x9b, 0xc1, 0x4c, 0xa8, 0x5e, 0x6c, 0x59, 0x5c, 0x48, 0xad, 0xcc, 0x92, 0x87, 0xcc,
		0x02, 0x99, 0x05, 0x32, 0xcb, 0x2e, 0xc9, 0x2c, 0xaa, 0xa0, 0x71, 0x05, 0x22, 0xd5, 0x2f, 0xe4,
		0x65, 0xa4, 0x54, 0xbd, 0x8a, 0xd5, 0x02, 0x26, 0x19, 0x70, 0x52, 0x02, 0xa8, 0x1e, 0x20, 0xa5,
		0x06, 0x54, 0x6d, 0xc0, 0xaa, 0x0d, 0x60, 0xb5, 0x01, 0xad, 0x5a, 0xc0, 0x55, 0x0c, 0xbc, 0x64,
		0x00, 0xfc, 0x4c, 0xde, 0x50, 0x79, 0xb8, 0xdb, 0x46, 0x2b, 0x57, 0x25, 0xd7, 0x68, 0x84, 0x65,
		0xe5, 0xa1, 0x3a, 0x07, 0x98, 0xd6, 0x0b, 0xd7, 0xba, 0x60, 0x5b, 0x3b, 0x7c, 0x6b, 0x87, 0x71,
		0xed, 0x70, 0x4e, 0x03, 0xeb, 0x44, 0xf0, 0x4e, 0x0e, 0xf3, 0x4f, 0xbc, 0x5b, 0xf5, 0xfe, 0xe9,
		0xcf, 0x59, 0xb8, 0xda, 0x9c, 0xa2, 0x9f, 0x81, 0xff, 0x21, 0xf1, 0x65, 0xa9, 0x38, 0x3a, 0x07,
		0x67, 0xc0, 0xc3, 0x29, 0xe8, 0x76, 0x0e, 0x6c, 0x9c, 0x04, 0x1b, 0x67, 0xc1, 0xc6, 0x69, 0xd0,
		0x3a, 0x0f, 0x62, 0x27, 0x12, 0xcf, 0xf2, 0xb5, 0x0e, 0x6c, 0x5f, 0xb2, 0x7b, 0xd9, 0x15, 0x5e,
		0x24, 0xa3, 0x07, 0x75, 0xcd, 0xaf, 0x7f, 0x8b, 0xe7, 0x97, 0x34, 0x5c, 0xbb, 0x36, 0xff, 0xea,
		0xef, 0xdd, 0x50, 0x23, 0xf4, 0x2c, 0x6e, 0xc4, 0xf5, 0x97, 0xcb, 0xcb, 0xb3, 0x73, 0xe7, 0xec,
		0xf2, 0x43, 0xf5, 0xaa, 0xf9, 0xe5, 0xbc, 0x7a, 0x5d, 0xab, 0x5f, 0x3a, 0xd7, 0x7f, 0x5e, 0x9d,
		0xe9, 0x82, 0xa2, 0x69, 0xc7, 0x9d, 0x90, 0xac, 0x12, 0x6b, 0xdd, 0xcf, 0x0f, 0x6d, 0x57, 0x5e,
		0xba, 0x35, 0xcd, 0xc6, 0xf5, 0x99, 0x73, 0x55, 0x3f, 0xaf, 0x7d, 0xf8, 0xd3, 0x99, 0xdd, 0x26,
		0x4b, 0xdb, 0xc0, 0xc6, 0x5a, 0xae, 0xdc, 0xca, 0x3a, 0xee, 0x23, 0x18, 0x7a, 0x1d, 0x4b, 0x50,
		0x9b, 0x9e, 0xb4, 0xf1, 0xba, 0x3a, 0xd3, 0x96, 0xd6, 0x65, 0xa4, 0xcc, 0x9f, 0x0c, 0xe7, 0xbf,
		0x73, 0x94, 0x5a, 0xd9, 0x9e, 0xb6, 0x94, 0xa7, 0xeb, 0xe9, 0x97, 0x3d, 0x7b, 0x3e, 0x11, 0xf3,
		0xe7, 0xc2, 0xf9, 0x6f, 0x15, 0x59, 0x51, 0xfa, 0x2c, 0x8b, 0xa2, 0x87, 0x5f, 0x38, 0x6a, 0x47,
		0x83, 0xbb, 0x50, 0x83, 0xbc, 0x3b, 0xbf, 0x70, 0xc6, 0x05, 0xde, 0x43, 0x08, 0xbc, 0xd9, 0x8a,
		0xe1, 0x21, 0xf0, 0x42, 0xe0, 0x4d, 0x75, 0x36, 0xc9, 0x05, 0xde, 0x19, 0xf2, 0xea, 0x93, 0x78,
		0xe7, 0xd7, 0xd7, 0x23, 0xf2, 0xe6, 0x21, 0xf2, 0x66, 0xdc, 0x31, 0xe8, 0x76, 0x10, 0x6c, 0x1c,
		0x05, 0x1b, 0x87, 0xc1, 0xc6, 0x71, 0x68, 0x0a, 0xf6, 0x89, 0x2d, 0x9f, 0xda, 0xa1, 0xc4, 0x17,
		0x0e, 0xc4, 0xad, 0x1f, 0x09, 0x5b, 0x78, 0xdd, 0xa1, 0x2f, 0x67, 0xe7, 0xe5, 0x6b, 0x16, 0x39,
		0x13, 0x23, 0xd2, 0xb4, 0xf0, 0xf5, 0x38, 0x1f, 0xed, 0x4e, 0x88, 0x83, 0x33, 0xe2, 0xe5, 0x94,
		0xb8, 0x38, 0x27, 0x76, 0x4e, 0x8a, 0x9d, 0xb3, 0x62, 0xe7, 0xb4, 0xf4, 0x38, 0x2f, 0x4d, 0x4e,
		0x4c, 0xbb, 0x33, 0xdb, 0xe4, 0xd4, 0xf4, 0x5b, 0xec, 0x06, 0xdf, 0xa6, 0xdb, 0x6e, 0xf5, 0xba,
		0x38, 0x36, 0xae, 0x8e, 0x93, 0xcb, 0xe3, 0xe9, 0xfa, 0xb8, 0xb9, 0x40, 0xb6, 0xae, 0x90, 0xad,
		0x4b, 0x64, 0xeb, 0x1a, 0xf5, 0xba, 0x48, 0xcd, 0xae, 0x92, 0x8d, 0xcb, 0x8c, 0x07, 0xc2, 0xc6,
		0x67, 0x26, 0x80, 0x90, 0x89, 0xd3, 0x5c, 0x75, 0x9e, 0x87, 0x4c, 0x86, 0xc3, 0xc5, 0x89, 0x72,
		0x74, 0xa6, 0xbc, 0x9d, 0x2a, 0x57, 0xe7, 0xca, 0xde, 0xc9, 0xb2, 0x77, 0xb6, 0xec, 0x9d, 0x2e,
		0x0f, 0xe7, 0xcb, 0xc4, 0x09, 0xc7, 0x77, 0x4b, 0x5b, 0xc6, 0xed, 0x2f, 0x71, 0x6b, 0x20, 0xdc,
		0x9e, 0x9e, 0x2c, 0xdc, 0x5f, 0xc6, 0x90, 0x15, 0x46, 0x63, 0xba, 0x9a, 0x27, 0x7d, 0xbd, 0x7b,
		0x37, 0xcb, 0xb2, 0xca, 0xc5, 0xdc, 0xe1, 0x0d, 0xac, 0x8d, 0x89, 0xa5, 0x11, 0x97, 0xa8, 0xfe,
		0xb6, 0x89, 0x51, 0xa7, 0xe5, 0x19, 0x20, 0xd0, 0x24, 0x39, 0x66, 0x01, 0x1c, 0x13, 0x1c, 0x13,
		0x1c, 0x13, 0x1c, 0x13, 0x1c, 0xd3, 0x70, 0xc1, 0x27, 0x1e, 0x90, 0x1b, 0xf2, 0x03, 0x85, 0x05,
		0x94, 0xba, 0x21, 0x37, 0x34, 0xe0, 0x25, 0xfe, 0x24, 0x1d, 0x34, 0xb7, 0x81, 0x31, 0x74, 0xd4,
		0x66, 0x38, 0x6c, 0xee, 0x8e, 0xdb, 0x18, 0x07, 0x6e, 0x8c, 0x23, 0x37, 0xc6, 0xa1, 0xf3, 0x72,
		0xec, 0xcc, 0x1c, 0x7c, 0x7c, 0x17, 0xd9, 0x89, 0x49, 0x6b, 0xbc, 0xab, 0xed, 0x8d, 0x6e, 0xdb,
		0x22, 0xe0, 0x08, 0x7b, 0x73, 0x47, 0x5b, 0x61, 0x38, 0xb4, 0x86, 0xeb, 0xf5, 0x85, 0xd6, 0xda,
		0xe7, 0x9f, 0xfd, 0xf0, 0x74, 0x13, 0xd3, 0x89, 0xbb, 0x90, 0x1e, 0x5b, 0x3f, 0xc6, 0x9c, 0xe1,
		0x25, 0x86, 0x39, 0xad, 0xc0, 0x37, 0x60, 0x9c, 0x9f, 0x02, 0xb7, 0x13, 0x49, 0xdf, 0xfb, 0x28,
		0xfb, 0x72, 0x9a, 0x65, 0x7c, 0xc8, 0x76, 0xbc, 0xe3, 0xb7, 0x8c, 0x4d, 0xc7, 0xbd, 0x87, 0xe9,
		0xa4, 0x6c, 0x3a, 0xc5, 0xc2, 0x49, 0xf1, 0xa4, 0x5c, 0x29, 0x9c, 0x94, 0x60, 0x43, 0xd9, 0xe4,
		0x84, 0x7c, 0x47, 0xd5, 0x7a, 0x83, 0xf9, 0x61, 0x8e, 0xc1, 0xfc, 0x52, 0xa2, 0x12, 0x0c, 0x9e,
		0x59, 0x6a, 0x14, 0x73, 0x47, 0x00, 0x95, 0x6c, 0x9b, 0xb5, 0x06, 0x95, 0x6c, 0x2b, 0x8b, 0x80,
		0x4a, 0x96, 0xf2, 0x40, 0xa1, 0x92, 0x65, 0x20, 0xc6, 0x31, 0x40, 0x25, 0x93, 0x43, 0x82, 0x63,
		0x43, 0xb7, 0xf5, 0xb4, 0xf9, 0x13, 0x86, 0x63, 0x9b, 0xdf, 0x5b, 0xc8, 0x64, 0xaf, 0x5e, 0x79,
		0x24, 0x47, 0xd6, 0xa6, 0xb6, 0x06, 0x8f, 0x19, 0x8f, 0x91, 0xea, 0x88, 0xd6, 0xad, 0x07, 0x9a,
		0x8d, 0x23, 0x77, 0xb7, 0x0e, 0x8f, 0x39, 0x2f, 0x25, 0xca, 0x23, 0x7f, 0xb7, 0x1e, 0x6d, 0x56,
		0x8e, 0x0c, 0xce, 0x96, 0xe0, 0xc2, 0x94, 0x8e, 0x99, 0xe5, 0x1c, 0xcb, 0x70, 0x8e, 0x3b, 0xe9,
		0x1c, 0x5d, 0xbb, 0x57, 0xb5, 0x3f, 0xb5, 0x7e, 0xe4, 0xdf, 0x16, 0xc7, 0xa7, 0x07, 0x3f, 0x2a,
		0xe3, 0xd5, 0x27, 0x1f, 0xd7, 0xbd, 0x2c, 0xff, 0xb6, 0x32, 0x3e, 0xdd, 0xf0, 0x97, 0xf2, 0xf8,
		0xf4, 0x37, 0x3f, 0xa3, 0x34, 0xde, 0x4f, 0xbc, 0x74, 0xf2, 0x7c, 0x61, 0xd3, 0x1b, 0x8a, 0x1b,
		0xde, 0x70, 0xb4, 0xe9, 0x0d, 0x47, 0x1b, 0xde, 0xb0, 0x71, 0x48, 0x85, 0x0d, 0x6f, 0x28, 0x8d,
		0x1f, 0x13, 0xaf, 0xdf, 0x5f, 0xff, 0xd2, 0xf2, 0xf8, 0xe0, 0x71, 0xd3, 0xdf, 0x2a, 0xe3, 0xc7,
		0xd3, 0x03, 0x50, 0x85, 0xdd, 0xa1, 0x0a, 0x30, 0x2f, 0x7a, 0xf3, 0x02, 0x71, 0x32, 0x5a, 0x55,
		0xdb, 0xc3, 0x8e, 0x1e, 0xf3, 0x91, 0x70, 0x49, 0xff, 0xd7, 0xd4, 0x14, 0xff, 0x97, 0xe3, 0x62,
		0xdf, 0x34, 0x7f, 0xd6, 0x81, 0x7c, 0xfe, 0x3b, 0xb7, 0xda, 0x2b, 0x70, 0xf5, 0x89, 0x1c, 0xa7,
		0x6a, 0xbe, 0x3d, 0xd6, 0x4d, 0xf8, 0x67, 0x13, 0x3b, 0xff, 0xed, 0x34, 0xa6, 0xf3, 0x78, 0xb6,
		0x98, 0xd7, 0x95, 0x7f, 0x53, 0xb6, 0xec, 0xe7, 0x8f, 0x2b, 0xbb, 0xdd, 0xb9, 0xe6, 0xbf, 0xe2,
		0x81, 0x51, 0x0a, 0x82, 0x75, 0x2e, 0xc3, 0x68, 0xb2, 0xec, 0x79, 0x74, 0xd3, 0xb9, 0x90, 0xde,
		0xd9, 0x40, 0xdc, 0x8a, 0x59, 0x63, 0x55, 0x06, 0xe9, 0x06, 0xd6, 0x85, 0x7b, 0xff, 0x6c, 0x44,
		0xf9, 0xe3, 0x62, 0xb1, 0x5c, 0x29, 0x16, 0x0f, 0x2b, 0x47, 0x95, 0xc3, 0x93, 0x52, 0x29, 0x5f,
		0xce, 0x33, 0x48, 0x82, 0xb3, 0xea, 0x41, 0x57, 0x04, 0xa2, 0xfb, 0x7e, 0xb2, 0xb2, 0xbc, 0xd1,
		0x60, 0xb0, 0xd3, 0x06, 0xc6, 0x8c, 0x2a, 0x64, 0x8d, 0x22, 0x58, 0x2c, 0x5a, 0x21, 0x64, 0x80,
		0x14, 0xe8, 0xa5, 0x03, 0x63, 0xf4, 0x76, 0xdd, 0x25, 0x34, 0x32, 0x1d, 0x85, 0x74, 0xb6, 0xb1,
		0x36, 0x13, 0x6d, 0xf4, 0xc0, 0x0b, 0xbd, 0x71, 0x6b, 0x30, 0x6c, 0x2b, 0x14, 0xfd, 0x09, 0x23,
		0xb4, 0x07, 0x32, 0xe4, 0x70, 0x02, 0xc0, 0xf2, 0x70, 0xd0, 0xfe, 0x5f, 0xcb, 0x00, 0xd0, 0xfe,
		0x7f, 0x75, 0x34, 0x68, 0xff, 0xbf, 0x61, 0x40, 0x68, 0xff, 0x0f, 0x8a, 0xf8, 0x6c, 0xf6, 0xb5,
		0xb7, 0xff, 0x7f, 0xee, 0x3f, 0xf8, 0xf4, 0xfe, 0x5f, 0x1a, 0x15, 0x1a, 0xff, 0xa3, 0xf1, 0xbf,
		0x09, 0x4e, 0x8f, 0x9b, 0xf3, 0x63, 0xeb, 0x04, 0xd9, 0x3a, 0x43, 0xb6, 0x4e, 0x51, 0xbf, 0x72,
		0xb3, 0x87, 0xc6, 0xff, 0x4f, 0x03, 0x59, 0x68, 0x21, 0xb6, 0xec, 0xf2, 0x6b, 0xca, 0xfa, 0x7c,
		0x70, 0x68, 0xff, 0xcf, 0xd9, 0x95, 0x72, 0x74, 0xa9, 0xbc, 0x5d, 0x2b, 0x57, 0x17, 0xcb, 0xde,
		0xd5, 0xb2, 0x77, 0xb9, 0xec, 0x5d, 0x2f, 0x0f, 0x17, 0xcc, 0xc4, 0x15, 0xc7, 0x77, 0x0b, 0xed,
		0xff, 0x5f, 0x11, 0x49, 0xb2, 0x6e, 0xff, 0xff, 0x9c, 0x3e, 0x20, 0x69, 0x89, 0x8b, 0xb1, 0x2d,
		0x14, 0x91, 0x90, 0xe1, 0x21, 0x00, 0x8b, 0x91, 0xe1, 0x1c, 0x00, 0x90, 0x4d, 0x90, 0x4d, 0x90,
		0x4d, 0x90, 0x4d, 0x90, 0xcd, 0x4c, 0xeb, 0x3f, 0xab, 0x4e, 0x99, 0x6f, 0xb3, 0xb3, 0xc5, 0x00,
		0x79, 0xf6, 0x3a, 0xcb, 0xa3, 0xd7, 0x99, 0xb1, 0x2e, 0xdb, 0x0c, 0xd7, 0xcd, 0xdd, 0x85, 0x1b,
		0xe3, 0xca, 0x8d, 0x71, 0xe9, 0xc6, 0xb8, 0x76, 0x5e, 0x2e, 0x9e, 0x99, 0xab, 0x67, 0xeb, 0xf2,
		0xe3, 0x81, 0x49, 0xaf, 0x2b, 0xf8, 0xb6, 0x97, 0x7e, 0xb6, 0x19, 0x34, 0x19, 0x26, 0x53, 0x13,
		0xe5, 0xdd, 0xfb, 0x9a, 0x2d, 0x1d, 0x30, 0x81, 0x16, 0x98, 0x45, 0x0f, 0x4c, 0xa1, 0x09, 0xc6,
		0xd1, 0x05, 0xe3, 0x68, 0x83, 0x71, 0xf4, 0x81, 0x27, 0x8d, 0x60, 0x4a, 0x27, 0xe2, 0xbb, 0xcb,
		0xb6, 0x85, 0x6a, 0x02, 0x37, 0xf9, 0x6d, 0x63, 0x6d, 0x8c, 0xe6, 0x2b, 0xbc, 0xdb, 0x75, 0xad,
		0x6e, 0x73, 0x4d, 0x88, 0x11, 0xfa, 0xb4, 0x98, 0x6a, 0xc6, 0xcc, 0x8e, 0xc4, 0xde, 0x68, 0xbf,
		0xdc, 0x9a, 0x6a, 0xac, 0xb5, 0x5c, 0xee, 0x04, 0xbc, 0x00, 0x02, 0x0e, 0x02, 0x0e, 0x02, 0x0e,
		0x02, 0x0e, 0x02, 0x9e, 0x11, 0x02, 0xce, 0x55, 0xd7, 0x8b, 0x07, 0xc8, 0x5b, 0xdf, 0x4b, 0xa0,
		0x3b, 0x67, 0x9d, 0x6f, 0x95, 0x6e, 0x70, 0x3f, 0xeb, 0x8e, 0xbb, 0xee, 0x67, 0x12, 0xfd, 0x30,
		0x93, 0x86, 0x98, 0x46, 0x47, 0x8c, 0xa5, 0x25, 0xc6, 0xd2, 0x13, 0x63, 0x69, 0x0a, 0x6f, 0xba,
		0xc2, 0x9c, 0xb6, 0xc4, 0x77, 0x9d, 0xbd, 0x7e, 0x98, 0xc0, 0xdd, 0x91, 0xf4, 0xa2, 0x72, 0xd1,
		0x04, 0xcc, 0x9d, 0xb3, 0x84, 0x63, 0x03, 0x86, 0xca, 0xfb, 0x54, 0xf3, 0xd5, 0x1f, 0x33, 0x7c,
		0xd8, 0x9e, 0x29, 0xa7, 0x9e, 0x1b, 0x4a, 0x6f, 0x13, 0xc3, 0x36, 0xe4, 0x54, 0xf4, 0xc4, 0xb8,
		0x0d, 0x3a, 0xe1, 0xd9, 0x30, 0xf7, 0xb6, 0x6c, 0x8a, 0xee, 0x3d, 0x4c, 0x91, 0xd8, 0x14, 0x79,
		0xb6, 0x9a, 0xdd, 0x19, 0xeb, 0x7c, 0x83, 0x51, 0xa6, 0xf1, 0xd3, 0x7a, 0x83, 0xf9, 0xcb, 0x98,
		0x77, 0xb0, 0x06, 0x7e, 0xc7, 0x1d, 0xd8, 0xd2, 0x8b, 0x44, 0xd0, 0x73, 0x79, 0x35, 0xc0, 0xf8,
		0x65, 0x08, 0xb4, 0x66, 0xec, 0x10, 0x4c, 0xd3, 0x18, 0x26, 0x04, 0x53, 0x85, 0xab, 0x16, 0x82,
		0xa9, 0x52, 0x0b, 0x83, 0x60, 0x4a, 0x3c, 0x70, 0x08, 0xa6, 0x3b, 0x18, 0x51, 0x1a, 0x2a, 0x98,
		0x1e, 0x15, 0x0c, 0x12, 0x4c, 0x2b, 0x10, 0x4c, 0x53, 0xfe, 0x81, 0x60, 0x0a, 0x7a, 0xbb, 0x66,
		0xd8, 0x10, 0x4c, 0xe1, 0xde, 0x7e, 0x66, 0x8a, 0x10, 0x4c, 0xc9, 0x4d, 0xb1, 0x58, 0x38, 0x29,
		0x9e, 0x94, 0x2b, 0x85, 0x13, 0xc8, 0xa4, 0x20, 0xc4, 0x86, 0x8d, 0x12, 0x32, 0x69, 0xe6, 0x7c,
		0xc2, 0x42, 0x6a, 0x1c, 0xde, 0x15, 0x6d, 0xb7, 0xdb, 0x0d, 0x44, 0x18, 0x1a, 0x27, 0x93, 0x3e,
		0x1f, 0x3b, 0x64, 0xd2, 0x34, 0x86, 0x09, 0x99, 0x54, 0xe1, 0xaa, 0x85, 0x4c, 0xaa, 0xd4, 0xc2,
		0x20, 0x93, 0x12, 0x0f, 0x1c, 0x32, 0xe9, 0x0e, 0xc6, 0x91, 0x06, 0xca, 0xa4, 0x06, 0xf1, 0x84,
		0xe7, 0x5c, 0x21, 0x6f, 0x42, 0x7a, 0xe9, 0x95, 0x1b, 0x45, 0x22, 0xf0, 0x8c, 0xd1, 0x4b, 0xad,
		0xfd, 0xfd, 0x9b, 0x43, 0xfb, 0xa4, 0xf5, 0x78, 0x93, 0xb7, 0x4f, 0x5a, 0xb3, 0x87, 0xf9, 0xe9,
		0xaf, 0xd9, 0xe3, 0xc2, 0xcd, 0xa1, 0x5d, 0x5c, 0x3c, 0x2e, 0xdd, 0x1c, 0xda, 0xa5, 0xd6, 0xc1,
		0x5f, 0x7f, 0xbd, 0x3b, 0xf8, 0x71, 0x34, 0x7e, 0xf9, 0x1b, 0xf9, 0x43, 0x61, 0xcb, 0x84, 0x25,
		0x56, 0x6f, 0xd6, 0xfe, 0x30, 0x6e, 0x9d, 0xfd, 0x4d, 0xb9, 0xd0, 0xfe, 0x63, 0x41, 0x42, 0x80,
		0x84, 0xa0, 0x4f, 0x42, 0x28, 0x1b, 0x2c, 0x21, 0x94, 0x21, 0x21, 0x40, 0x42, 0x80, 0x84, 0x00,
		0x09, 0x01, 0x12, 0x02, 0x24, 0x04, 0x48, 0x08, 0x90, 0x10, 0x36, 0x48, 0x08, 0x65, 0x48, 0x08,
		0x90, 0x10, 0x9e, 0x49, 0x08, 0xae, 0xdd, 0xab, 0xda, 0x9f, 0x5a, 0x3f, 0xf2, 0x6f, 0x8b, 0xe3,
		0xd3, 0x83, 0x1f, 0x95, 0xf1, 0xea, 0x93, 0x8f, 0xeb, 0x5e, 0x96, 0x7f, 0x5b, 0x19, 0x9f, 0x6e,
		0xf8, 0x4b, 0x79, 0x7c, 0xfa, 0x9b, 0x9f, 0x51, 0x1a, 0xef, 0x27, 0x5e, 0x3a, 0x79, 0xbe, 0xb0,
		0xe9, 0x0d, 0xc5, 0x0d, 0x6f, 0x38, 0xda, 0xf4, 0x86, 0xa3, 0x0d, 0x6f, 0xd8, 0x38, 0xa4, 0xc2,
		0x86, 0x37, 0x94, 0xc6, 0x8f, 0x89, 0xd7, 0xef, 0xaf, 0x7f, 0x69, 0x79, 0x7c, 0xf0, 0xb8, 0xe9,
		0x6f, 0x95, 0xf1, 0xe3, 0xe9, 0x01, 0x04, 0x15, 0x08, 0x2a, 0x30, 0x3b, 0x7a, 0xb3, 0x83, 0xbc,
		0x04, 0x79, 0x49, 0x83, 0xc5, 0xdf, 0x0e, 0x07, 0xa1, 0xdd, 0xf6, 0x0d, 0x12, 0x95, 0xe2, 0x11,
		0x43, 0x4a, 0x82, 0x94, 0x04, 0x29, 0x09, 0x52, 0x12, 0xa4, 0x24, 0x48, 0x49, 0x90, 0x92, 0x20,
		0x25, 0x3d, 0xc3, 0xdd, 0xb6, 0xef, 0x0f, 0x84, 0xeb, 0x99, 0xa4, 0x22, 0xe5, 0x41, 0xae, 0xb3,
		0x49, 0xae, 0xa3, 0x8e, 0x61, 0xdc, 0x3a, 0xea, 0x80, 0x5a, 0x83, 0x5a, 0x83, 0x5a, 0x83, 0x5a,
		0x83, 0x5a, 0x83, 0x5a, 0x83, 0x5a, 0x83, 0x5a, 0xaf, 0xf6, 0xc3, 0x38, 0x36, 0x88, 0x58, 0x97,
		0xd0, 0x0e, 0x23, 0xe5, 0x1f, 0xb4, 0xc3, 0x00, 0xbb, 0x5d, 0x33, 0x6c, 0xb4, 0xc3, 0x80, 0x77,
		0xfb, 0x99, 0x29, 0xa2, 0x1d, 0x06, 0xb9, 0x29, 0x56, 0x60, 0x8a, 0xa0, 0xc1, 0x66, 0x8d, 0x12,
		0x39, 0x06, 0x99, 0x73, 0x05, 0x73, 0x55, 0x31, 0x1a, 0x98, 0xa6, 0x83, 0x46, 0x03, 0x08, 0xa1,
		0xa9, 0x0c, 0x13, 0x42, 0xa8, 0xc2, 0xb5, 0x0a, 0x21, 0x54, 0xa9, 0x85, 0x41, 0x08, 0x25, 0x1e,
		0x38, 0x84, 0xd0, 0x1d, 0x0c, 0x15, 0x21, 0x84, 0x2a, 0x27, 0x09, 0x10, 0x42, 0xd3, 0xfe, 0x81,
		0x10, 0x0a, 0x76, 0xbb, 0x66, 0xd8, 0x10, 0x42, 0xe1, 0xdd, 0x7e, 0x66, 0x8a, 0x10, 0x42, 0xc9,
		0x4d, 0xb1, 0x50, 0x42, 0x43, 0x60, 0x10, 0x61, 0xc3, 0x46, 0x09, 0x29, 0x34, 0x73, 0xce, 0xc0,
		0x0a, 0xc4, 0xad, 0x1f, 0x09, 0x43, 0x3b, 0x02, 0xaf, 0x1b, 0x3c, 0x04, 0xd2, 0x34, 0x86, 0x09,
		0x81, 0x54, 0xe1, 0xb2, 0x85, 0x40, 0xaa, 0xd4, 0xc2, 0x20, 0x90, 0x12, 0x0f, 0x1c, 0x02, 0xe9,
		0x0e, 0x86, 0x90, 0x68, 0x09, 0x4c, 0xc5, 0x15, 0xd0, 0xcf, 0x47, 0xc5, 0x80, 0xd1, 0x12, 0x78,
		0x29, 0xb4, 0x43, 0x07, 0x1b, 0x45, 0xa3, 0x46, 0x4b, 0x60, 0x88, 0x08, 0xbb, 0x23, 0x22, 0x94,
		0x4d, 0x16, 0x11, 0xd0, 0x14, 0x18, 0x22, 0x02, 0x44, 0x04, 0x88, 0x08, 0x10, 0x11, 0x20, 0x22,
		0x40, 0x44, 0x80, 0x88, 0xb0, 0x49, 0x44, 0x40, 0x53, 0x60, 0x88, 0x08, 0xcf, 0x45, 0x04, 0x74,
		0x27, 0x45, 0x53, 0x60, 0x48, 0x2a, 0xe4, 0x92, 0x0a, 0xcc, 0x0e, 0x4d, 0x81, 0x21, 0x30, 0xed,
		0x84, 0xc0, 0x14, 0xca, 0xae, 0x39, 0x82, 0xd2, 0x64, 0xb0, 0x10, 0x90, 0x20, 0x20, 0x41, 0x40,
		0x82, 0x80, 0x04, 0x01, 0x09, 0x02, 0x12, 0x04, 0x24, 0x08, 0x48, 0xcf, 0xe9, 0x41, 0x60, 0x87,
		0xb2, 0x6b, 0x47, 0x93, 0x81, 0x1b, 0xa4, 0x1f, 0x9d, 0x18, 0x30, 0xd6, 0xf9, 0x62, 0x40, 0xb1,
		0x9e, 0xa2, 0xa5, 0x3b, 0xed, 0x42, 0x31, 0x70, 0xdb, 0x62, 0x60, 0x19, 0x54, 0xdf, 0x64, 0xd0,
		0x0a, 0x36, 0x73, 0x25, 0x9b, 0xb7, 0xa2, 0x13, 0x2b, 0x7b, 0x24, 0xbd, 0xe8, 0xa8, 0x60, 0xbd,
		0x35, 0xef, 0x1b, 0xcc, 0x57, 0x77, 0xc5, 0xc0, 0xa1, 0x9b, 0x55, 0x5c, 0x6d, 0xfe, 0x6a, 0x8f,
		0x27, 0xde, 0xc4, 0xe2, 0x6b, 0x43, 0x35, 0x8c, 0x5f, 0x7e, 0x8d, 0x45, 0x45, 0x68, 0xbe, 0x6c,
		0xf8, 0x17, 0x31, 0xb8, 0x40, 0xd4, 0xb0, 0xa0, 0xe7, 0xe7, 0xb6, 0x6d, 0x60, 0x35, 0x77, 0xe6,
		0x6d, 0xfb, 0xb0, 0x78, 0x5c, 0xaa, 0x94, 0x60, 0xe0, 0x6c, 0x0c, 0xfc, 0x0d, 0x46, 0x4d, 0xf1,
		0xd3, 0x7a, 0x03, 0xd8, 0x07, 0x01, 0x4d, 0x86, 0x5b, 0xc2, 0x1b, 0xdd, 0x8a, 0xc0, 0x9d, 0xa0,
		0x89, 0xc1, 0x31, 0x57, 0xbe, 0x68, 0xe0, 0xd8, 0xcf, 0xbc, 0xd1, 0xed, 0x84, 0x20, 0x98, 0x05,
		0x26, 0xe6, 0x8c, 0xd6, 0x0c, 0xc8, 0x33, 0x04, 0xea, 0x0c, 0xd4, 0x48, 0x0d, 0xcb, 0x0f, 0x4d,
		0x60, 0xda, 0xb1, 0x41, 0x63, 0x36, 0x2d, 0x73, 0x2d, 0x1e, 0x38, 0x12, 0xd8, 0x90, 0x37, 0xfa,
		0x4b, 0x47, 0x62, 0x92, 0x21, 0x9a, 0x98, 0x47, 0x1a, 0x8f, 0x1e, 0xf9, 0xa4, 0xc8, 0x27, 0xcd,
		0x0c, 0xb1, 0x43, 0x7e, 0x6e, 0x46, 0xe7, 0x8f, 0x73, 0x7e, 0x6e, 0x64, 0x42, 0x16, 0x4e, 0x4c,
		0xd1, 0x0d, 0x48, 0xbd, 0x41, 0x86, 0x6e, 0xda, 0x0c, 0x05, 0x19, 0xba, 0x8a, 0x47, 0x8d, 0x0c,
		0x5d, 0xa2, 0x81, 0x23, 0x43, 0x17, 0x9c, 0xc0, 0x1c, 0x29, 0xcf, 0xc0, 0x0c, 0x5d, 0xb3, 0x76,
		0x27, 0x4c, 0xda, 0x8d, 0x30, 0x64, 0xf7, 0x81, 0x71, 0x10, 0xf0, 0x06, 0x10, 0xf4, 0x02, 0x87,
		0xe3, 0x79, 0x7e, 0x34, 0xb3, 0x63, 0xce, 0x00, 0x64, 0x85, 0x9d, 0x6f, 0xe2, 0xd6, 0x1d, 0xba,
		0xd1, 0xb7, 0x09, 0xfc, 0xe4, 0xfc, 0xa1, 0xf0, 0x3a, 0x53, 0x62, 0x6d, 0x7b, 0x22, 0xfa, 0xd7,
		0x0f, 0xbe, 0xdb, 0xd2, 0x0b, 0x23, 0xd7, 0xeb, 0x88, 0xdc, 0xea, 0x13, 0x61, 0xe2, 0x99, 0xdc,
		0x30, 0xf0, 0x23, 0xbf, 0xe3, 0x0f, 0xc2, 0xf8, 0x51, 0xae, 0xdd, 0x1f, 0xe6, 0x02, 0xd9, 0xce,
		0xb9, 0x51, 0x14, 0xd8, 0xa1, 0x88, 0xc2, 0xf8, 0x51, 0x2e, 0x1a, 0x79, 0x9e, 0x18, 0xd8, 0xc2,
		0xeb, 0xb8, 0xc3, 0x70, 0x34, 0x98, 0xce, 0xd6, 0xfc, 0xc9, 0x70, 0xfe, 0x3b, 0x17, 0x8e, 0xda,
		0xd1, 0xe0, 0x2e, 0x9c, 0xff, 0xce, 0x85, 0xa2, 0x3f, 0x71, 0xe3, 0xf6, 0x40, 0x86, 0x51, 0xb8,
		0xf4, 0xaf, 0xc5, 0x3f, 0xe2, 0x67, 0x73, 0x61, 0xe4, 0x46, 0x9c, 0x83, 0x2d, 0x2b, 0x8c, 0x82,
		0x51, 0x27, 0xf2, 0xe6, 0xd0, 0x5f, 0x8f, 0xa7, 0xfe, 0x72, 0x36, 0xad, 0xb5, 0xf9, 0xac, 0x3a,
		0x2b, 0xff, 0x0e, 0x57, 0x9f, 0x70, 0xae, 0x16, 0xd3, 0x1e, 0x3f, 0x72, 0xde, 0xf7, 0x87, 0x4e,
		0x43, 0xb6, 0x9d, 0x6a, 0x14, 0x05, 0x4d, 0x11, 0x85, 0x8b, 0x07, 0xce, 0xf5, 0x74, 0x5e, 0xcf,
		0x9e, 0xcf, 0xf9, 0xfc, 0xb9, 0x70, 0xfe, 0xdb, 0x69, 0xce, 0xe6, 0x7c, 0xfe, 0xdb, 0x69, 0xce,
		0xe6, 0xf3, 0x7c, 0x32, 0xe5, 0xcf, 0xff, 0xb1, 0x78, 0x1c, 0x3f, 0xe9, 0x34, 0xa7, 0x33, 0xfe,
		0x06, 0xe8, 0x65, 0xde, 0x88, 0x98, 0xe1, 0xe8, 0x24, 0x44, 0x9a, 0x6e, 0x69, 0x7a, 0x5d, 0xc1,
		0x2d, 0x3a, 0xb2, 0x26, 0x8b, 0x7f, 0x62, 0x4e, 0x2c, 0x91, 0xdd, 0xba, 0x90, 0xde, 0xd9, 0x40,
		0x4c, 0x0d, 0x93, 0xa7, 0x38, 0x62, 0x5d, 0xb8, 0xf7, 0xcf, 0x46, 0x98, 0x3f, 0x2e, 0x16, 0xcb,
		0x95, 0x62, 0xf1, 0xb0, 0x72, 0x54, 0x39, 0x3c, 0x29, 0x95, 0xf2, 0xe5, 0x3c, 0xc3, 0x74, 0x45,
		0xab, 0x1e, 0x74, 0x45, 0x20, 0xba, 0xef, 0x27, 0xcb, 0xd2, 0x1b, 0x0d, 0x06, 0xb0, 0x5e, 0x73,
		0xd9, 0x4f, 0x86, 0x59, 0x0f, 0x43, 0xbe, 0x93, 0x39, 0x9e, 0xc3, 0x8b, 0xe1, 0xf0, 0xe1, 0x11,
		0x3c, 0x46, 0xc2, 0x04, 0x0b, 0xb9, 0x62, 0x60, 0x06, 0xb1, 0x8f, 0x11, 0xe6, 0x65, 0x06, 0xeb,
		0x78, 0x60, 0x9c, 0x7e, 0x44, 0x61, 0x80, 0x26, 0xd6, 0x4c, 0xc8, 0xe0, 0x02, 0x22, 0x4f, 0xdd,
		0x24, 0x18, 0xe9, 0x2b, 0xb1, 0x12, 0xcd, 0x64, 0x38, 0xf1, 0xe6, 0x74, 0x81, 0xc9, 0x80, 0x18,
		0x6e, 0x42, 0xf3, 0xde, 0x6c, 0xe6, 0xba, 0xa9, 0xcc, 0x7e, 0xf3, 0x98, 0xfd, 0x26, 0x31, 0xfb,
		0xcd, 0x60, 0xf0, 0xe8, 0xe7, 0x77, 0xeb, 0xa3, 0xe4, 0x25, 0xb4, 0x59, 0x0b, 0xee, 0x6b, 0x33,
		0xec, 0x0c, 0xf9, 0x54, 0x0b, 0xf2, 0x6c, 0x90, 0xdc, 0xa4, 0x5d, 0x96, 0xf9, 0x65, 0x6c, 0xf3,
		0xc9, 0x38, 0xe7, 0x8f, 0x99, 0x91, 0x2f, 0xc6, 0x3d, 0x3f, 0xcc, 0x98, 0x7c, 0x30, 0x63, 0xf2,
		0xbf, 0x8c, 0xc9, 0xf7, 0xc2, 0x26, 0xe0, 0xcf, 0xee, 0x22, 0xdb, 0xfc, 0xad, 0xa5, 0xe6, 0x5d,
		0xe5, 0x22, 0x47, 0xcc, 0x9b, 0x7b, 0x59, 0x86, 0x35, 0x95, 0xcc, 0x9b, 0x6f, 0x31, 0x4e, 0xd6,
		0x31, 0xa1, 0x79, 0x96, 0x29, 0xe5, 0x03, 0x8b, 0x06, 0x39, 0xdc, 0xc7, 0x69, 0x50, 0xeb, 0x1b,
		0xce, 0x65, 0x42, 0x26, 0xf4, 0xa6, 0x32, 0xcd, 0x74, 0xcc, 0xc8, 0xdc, 0x30, 0xd6, 0x9a, 0x90,
		0x47, 0xf7, 0x5b, 0x3f, 0x2d, 0xec, 0xc6, 0x73, 0x47, 0x63, 0xeb, 0x5f, 0x21, 0xfb, 0xdf, 0x22,
		0xbe, 0x6a, 0xd9, 0x7c, 0x7c, 0x10, 0xca, 0x7e, 0x67, 0x58, 0x10, 0xca, 0xb6, 0x58, 0x69, 0x10,
		0xca, 0xb6, 0xb2, 0x08, 0x08, 0x65, 0x29, 0x0f, 0x14, 0x42, 0x59, 0x06, 0x22, 0x1d, 0x43, 0x84,
		0x32, 0x96, 0x5d, 0xee, 0x19, 0x77, 0xb1, 0x87, 0x50, 0xf6, 0xea, 0x68, 0x1f, 0x42, 0x59, 0xea,
		0xd1, 0x3e, 0x84, 0xb2, 0xac, 0xba, 0x8f, 0x65, 0xd3, 0x81, 0x50, 0x96, 0xba, 0xe9, 0x14, 0x0b,
		0x27, 0xc5, 0x93, 0x72, 0xa5, 0x70, 0x02, 0x79, 0x2c, 0xa3, 0x84, 0x90, 0xef, 0xa8, 0x20, 0x8f,
		0x71, 0x1e, 0x09, 0x8a, 0x55, 0x7e, 0x3e, 0xae, 0x0c, 0x15, 0xab, 0x30, 0xeb, 0x46, 0x60, 0x7e,
		0xa5, 0x0a, 0x9f, 0x66, 0x03, 0x0c, 0xca, 0x54, 0xde, 0xec, 0x30, 0x8a, 0x3d, 0x35, 0x0b, 0xe0,
		0x92, 0xf3, 0xca, 0xab, 0x45, 0x00, 0xbf, 0x96, 0x00, 0x46, 0xb4, 0x00, 0xe0, 0x55, 0xf2, 0xaf,
		0xdb, 0xc6, 0x98, 0x31, 0x84, 0xec, 0x30, 0x03, 0x8b, 0x45, 0x85, 0xa1, 0xd1, 0x5c, 0x40, 0x2f,
		0x0b, 0xd0, 0xe7, 0x7b, 0xf5, 0x5c, 0x59, 0x13, 0x12, 0x71, 0x41, 0x20, 0xa3, 0x91, 0x47, 0x23,
		0xd8, 0x98, 0x08, 0x32, 0x7a, 0x80, 0x85, 0xde, 0xac, 0x35, 0x98, 0xb4, 0xe6, 0xaa, 0x76, 0x16,
		0x55, 0xec, 0x9a, 0xab, 0xd6, 0xb5, 0x57, 0xa9, 0x73, 0xc8, 0xd8, 0xe1, 0x95, 0x99, 0xc3, 0x25,
		0x03, 0x87, 0x5d, 0xa6, 0x0d, 0xbb, 0x8c, 0x1a, 0x76, 0x99, 0x33, 0xbb, 0x45, 0x06, 0x75, 0x57,
		0x85, 0x5b, 0x6d, 0xe9, 0x75, 0xa5, 0xd7, 0xb7, 0x43, 0x06, 0x55, 0xe0, 0x31, 0x86, 0x3d, 0x1f,
		0x94, 0x6e, 0x4d, 0x8e, 0xc5, 0x16, 0x2d, 0x9b, 0x64, 0x55, 0x4e, 0xc9, 0xa9, 0x3c, 0x93, 0x51,
		0xb9, 0x25, 0x9f, 0xb2, 0x4d, 0x36, 0x65, 0x9b, 0x5c, 0xca, 0x36, 0x99, 0x74, 0xb7, 0x77, 0x47,
		0xd8, 0x24, 0x87, 0x3e, 0xc5, 0x5c, 0xc1, 0xc4, 0x43, 0xd9, 0x4c, 0x0e, 0xc3, 0x8a, 0xa3, 0xb0,
		0x13, 0x06, 0x63, 0x99, 0xdf, 0x2c, 0x1e, 0x19, 0x9f, 0x0c, 0x7b, 0x85, 0xdd, 0x0e, 0x07, 0xa1,
		0x3d, 0x70, 0xdb, 0x62, 0xc0, 0x69, 0x2f, 0x9d, 0xd1, 0x0a, 0xe2, 0xb9, 0x92, 0xf8, 0xad, 0xa8,
		0xc4, 0xca, 0x42, 0x86, 0xfa, 0x2b, 0x86, 0x86, 0x0c, 0xf5, 0x57, 0x4e, 0x1c, 0x32, 0xd4, 0xd3,
		0x1b, 0x66, 0x5c, 0x8f, 0x5e, 0x46, 0x7a, 0x6d, 0x46, 0x48, 0xeb, 0xcf, 0x6d, 0x07, 0x29, 0xea,
		0xe9, 0xdb, 0xce, 0x61, 0xf1, 0xb8, 0x54, 0x41, 0x7e, 0x7a, 0x46, 0x62, 0x4e, 0x73, 0x46, 0xd5,
		0x42, 0x61, 0xa7, 0x91, 0x74, 0x99, 0xf7, 0x49, 0x95, 0x9c, 0x4f, 0xa6, 0x64, 0x7a, 0x12, 0x25,
		0x9f, 0xd1, 0xb4, 0x50, 0x9a, 0xc1, 0x11, 0x02, 0x9e, 0x7a, 0x0b, 0x0f, 0xef, 0xca, 0xb6, 0xdb,
		0xed, 0x06, 0x22, 0x0c, 0x39, 0xaa, 0x30, 0x8c, 0x7a, 0x1e, 0x5a, 0x57, 0x6e, 0x14, 0x89, 0xc0,
		0x63, 0x17, 0x22, 0x5b, 0xfb, 0xfb, 0x37, 0x87, 0xf6, 0x89, 0x6b, 0xf7, 0xaa, 0xf6, 0xa7, 0xd6,
		0x8f, 0xfc, 0xdb, 0xe2, 0xf8, 0xf4, 0xe0, 0x47, 0x65, 0xbc, 0xfa, 0xe4, 0xe3, 0xba, 0x97, 0xe5,
		0xdf, 0x56, 0xc6, 0xa7, 0x1b, 0xfe, 0x52, 0x1e, 0x9f, 0xfe, 0xe6, 0x67, 0x94, 0xc6, 0xfb, 0x89,
		0x97, 0x4e, 0x9e, 0x2f, 0x6c, 0x7a, 0x43, 0x71, 0xc3, 0x1b, 0x8e, 0x36, 0xbd, 0xe1, 0x68, 0xc3,
		0x1b, 0x36, 0x0e, 0xa9, 0xb0, 0xe1, 0x0d, 0xa5, 0xf1, 0x63, 0xe2, 0xf5, 0xfb, 0xeb, 0x5f, 0x5a,
		0x1e, 0x1f, 0x3c, 0x6e, 0xfa, 0x5b, 0x65, 0xfc, 0x78, 0x7a, 0x70, 0xc0, 0xa7, 0xb9, 0x46, 0x8b,
		0x93, 0xa1, 0xd4, 0x9b, 0xb5, 0x3f, 0xd8, 0x5a, 0xcb, 0xdf, 0x30, 0x17, 0x5d, 0xe6, 0xf2, 0x1f,
		0x0b, 0xc4, 0x84, 0x19, 0x51, 0x6b, 0xed, 0x6a, 0xbe, 0xbd, 0xc6, 0xc4, 0xc0, 0x8e, 0x3f, 0xf0,
		0x83, 0x90, 0x4f, 0xaa, 0xd1, 0x7c, 0x3c, 0xc8, 0x32, 0x42, 0x96, 0xd1, 0x2f, 0x56, 0x0a, 0xb2,
		0x8c, 0x7e, 0xba, 0x82, 0x91, 0x65, 0xf4, 0xc2, 0x81, 0x21, 0xcb, 0x88, 0xa1, 0x5c, 0xc1, 0x30,
		0xcb, 0x88, 0xcd, 0x86, 0x3e, 0xa3, 0x0d, 0x7c, 0x66, 0x1b, 0xf6, 0x8c, 0xc4, 0x2d, 0x8e, 0x1b,
		0xf2, 0x5c, 0x3b, 0x00, 0x33, 0x6d, 0x09, 0xc7, 0x79, 0x7b, 0x90, 0x53, 0x37, 0x6e, 0x8e, 0xfb,
		0xe7, 0xdc, 0x97, 0x3a, 0xd7, 0x16, 0x6e, 0xac, 0xd7, 0x3c, 0xe4, 0x12, 0x0e, 0x72, 0x09, 0x5a,
		0xe1, 0x2c, 0xbb, 0x79, 0xb4, 0xc2, 0x79, 0xf9, 0x20, 0x79, 0xb5, 0xc2, 0xd9, 0x49, 0x01, 0x70,
		0x18, 0x88, 0x9e, 0x08, 0x84, 0xc7, 0xa1, 0x3a, 0x78, 0x11, 0x62, 0x3d, 0x1b, 0x93, 0x66, 0x94,
		0xf9, 0x28, 0x7a, 0xee, 0x68, 0x30, 0xd5, 0x04, 0xf2, 0x87, 0x87, 0x90, 0x25, 0xf7, 0x20, 0x4b,
		0xfe, 0x62, 0xed, 0x42, 0x96, 0xfc, 0xe9, 0x0a, 0x86, 0x2c, 0xf9, 0xc2, 0x81, 0x41, 0x96, 0xe4,
		0xc8, 0x3e, 0x21, 0x4b, 0xfe, 0xd2, 0x4b, 0x41, 0x96, 0x5c, 0xfd, 0x81, 0x2c, 0x69, 0xb4, 0x56,
		0x03, 0x59, 0xd2, 0x14, 0x78, 0x5e, 0x0d, 0x84, 0xb1, 0xd4, 0x5f, 0xb8, 0xd4, 0x21, 0x4b, 0x9a,
		0x46, 0x88, 0xf8, 0x8c, 0x02, 0x59, 0x5c, 0xf4, 0x66, 0x11, 0x71, 0xa0, 0xa3, 0x31, 0x15, 0x65,
		0xd0, 0x80, 0x03, 0x52, 0x09, 0xa4, 0x12, 0x48, 0x25, 0x90, 0x4a, 0x20, 0x95, 0x40, 0x2a, 0x49,
		0xe0, 0x8e, 0xec, 0x0a, 0x2f, 0x92, 0xd1, 0x43, 0x20, 0x7a, 0x9c, 0xfa, 0x44, 0x71, 0xd8, 0x90,
		0xab, 0xcd, 0xa7, 0xe6, 0xbd, 0x1b, 0x32, 0x82, 0xc2, 0xc5, 0x8d, 0xbb, 0xfe, 0x72, 0x79, 0x79,
		0x76, 0xee, 0x9c, 0x5d, 0x7e, 0xa8, 0x5e, 0x35, 0xbf, 0x9c, 0x57, 0xaf, 0x6b, 0xf5, 0x4b, 0xa7,
		0xf9, 0xe5, 0xfd, 0xf5, 0xf9, 0x57, 0xe7, 0xfa, 0xcf, 0xab, 0x33, 0x2e, 0x08, 0x39, 0x0d, 0xa3,
		0x42, 0x56, 0xe5, 0x46, 0x4c, 0x4f, 0xc8, 0x6f, 0x36, 0xae, 0xcf, 0x9c, 0xab, 0xc6, 0xd9, 0xa7,
		0xb3, 0xc6, 0xd9, 0xe5, 0x87, 0x33, 0x0b, 0x0a, 0x86, 0x59, 0xb7, 0xae, 0x79, 0xf6, 0xf9, 0xe2,
		0xec, 0xf2, 0xda, 0x39, 0xaf, 0x35, 0xaf, 0x71, 0xf3, 0xcc, 0xb9, 0x79, 0x73, 0x24, 0x6d, 0x9c,
		0x5d, 0xd4, 0xaf, 0xcf, 0x9c, 0xb3, 0xcb, 0x8f, 0x57, 0xf5, 0xda, 0x25, 0xee, 0xa0, 0x69, 0xe6,
		0xf7, 0xbe, 0x76, 0xf9, 0xb1, 0x76, 0xf9, 0xd9, 0x69, 0xd6, 0x3e, 0xe2, 0xde, 0x19, 0x67, 0x7d,
		0x1f, 0xea, 0xe7, 0xf5, 0x86, 0x05, 0x01, 0x73, 0xe9, 0xa7, 0xb5, 0xeb, 0xe1, 0x1a, 0x3a, 0xfd,
		0xd3, 0x88, 0x05, 0x38, 0xf6, 0xe9, 0x55, 0xc7, 0x3e, 0x69, 0x3e, 0x6f, 0xd6, 0x98, 0xe3, 0x9e,
		0xf4, 0x1d, 0x23, 0xbb, 0x1b, 0xe7, 0x3c, 0x69, 0xdd, 0xf2, 0xe0, 0xb0, 0xd5, 0xa1, 0x79, 0x8b,
		0x43, 0xfb, 0xd6, 0x06, 0x4e, 0x79, 0x4a, 0x8c, 0x06, 0xa7, 0x3c, 0x6d, 0x18, 0x10, 0x4e, 0x79,
		0x02, 0xf7, 0x7b, 0x36, 0xfb, 0xda, 0xb7, 0x24, 0x62, 0xdc, 0x18, 0x08, 0xb7, 0xa7, 0x77, 0x1b,
		0x22, 0xde, 0x7e, 0xd0, 0x98, 0xaf, 0x69, 0x5d, 0xcd, 0xe9, 0xef, 0xbb, 0x77, 0x33, 0x82, 0x99,
		0x9b, 0xfa, 0xd5, 0x5d, 0x61, 0x4f, 0x6f, 0x32, 0x6c, 0x73, 0x8b, 0x43, 0xf4, 0x35, 0x10, 0x25,
		0xbd, 0x25, 0x82, 0xfa, 0x4b, 0x02, 0x59, 0x96, 0x00, 0xea, 0x2d, 0xf9, 0xa3, 0x5e, 0xfc, 0x9a,
		0x45, 0x06, 0xc3, 0xc4, 0x05, 0x4b, 0xcb, 0x71, 0xc1, 0x26, 0xc8, 0x09, 0xb4, 0xae, 0x90, 0xce,
		0x21, 0xd1, 0x5c, 0x89, 0xc8, 0xea, 0x75, 0x59, 0xbb, 0x29, 0x56, 0x4e, 0x68, 0xde, 0xdc, 0xcd,
		0x9a, 0xc6, 0x9e, 0xd5, 0x5b, 0x17, 0x81, 0x65, 0xd1, 0x0a, 0x7d, 0x3a, 0x84, 0x3d, 0x62, 0x21,
		0x8f, 0x5c, 0xb8, 0xd3, 0x21, 0xd4, 0xe9, 0x15, 0xe6, 0x74, 0x09, 0x71, 0xda, 0x85, 0x37, 0xed,
		0x42, 0x9b, 0x76, 0x61, 0x2d, 0x5b, 0x8c, 0x86, 0x5c, 0x28, 0xd3, 0x28, 0x8c, 0xe9, 0x10, 0xc2,
		0x74, 0x0a, 0x5f, 0x04, 0xec, 0xe0, 0x8d, 0xc1, 0x36, 0x40, 0x28, 0x5c, 0xd1, 0x0a, 0x55, 0xf4,
		0xc2, 0x14, 0x0b, 0x21, 0x8a, 0x56, 0x78, 0x52, 0xbd, 0x38, 0x89, 0x43, 0x4d, 0xee, 0x21, 0x26,
		0x81, 0x9b, 0xe0, 0x1a, 0x52, 0xaa, 0x75, 0x16, 0xea, 0x20, 0x5c, 0xcd, 0x27, 0x2b, 0xb2, 0x3b,
		0x2a, 0x7b, 0x63, 0x6b, 0x67, 0x0a, 0x0d, 0x8c, 0x9d, 0x61, 0xa9, 0xb1, 0xa8, 0xf4, 0xd7, 0x7b,
		0xba, 0x9f, 0x98, 0xb2, 0xe5, 0xa8, 0xb6, 0x18, 0x76, 0x96, 0xa2, 0xc0, 0x42, 0xd8, 0x58, 0x46,
		0xba, 0x16, 0x91, 0xde, 0xba, 0x4d, 0xe7, 0x93, 0x52, 0x5a, 0xf9, 0x8b, 0x80, 0x41, 0x7a, 0x5d,
		0x91, 0x96, 0xee, 0xa2, 0x26, 0x32, 0x50, 0x17, 0x01, 0x90, 0x32, 0x7d, 0x35, 0x8c, 0x3e, 0xad,
		0xd5, 0xa0, 0x08, 0xff, 0x74, 0xe2, 0x5e, 0x8a, 0x10, 0xa7, 0x05, 0xda, 0xd2, 0x81, 0xb1, 0xed,
		0x41, 0x67, 0xbb, 0x4f, 0xd8, 0x72, 0x81, 0xa6, 0xbd, 0x30, 0x35, 0x2c, 0xc8, 0x14, 0xd6, 0x21,
		0xe9, 0xfa, 0xdb, 0x6e, 0xdd, 0xbd, 0x7e, 0xb5, 0x6c, 0xb1, 0x52, 0xac, 0x8e, 0x7f, 0x7b, 0x3b,
		0xf2, 0x64, 0x24, 0xc5, 0xf6, 0x87, 0xc3, 0x3d, 0x3b, 0xdc, 0xed, 0xe9, 0x43, 0xb7, 0x5c, 0xc5,
		0x0b, 0xb1, 0x76, 0xcb, 0x8f, 0x49, 0x6b, 0x2f, 0x2c, 0xcd, 0x3d, 0x2e, 0x35, 0x7b, 0x57, 0x69,
		0xef, 0x49, 0x29, 0xdb, 0x6b, 0x52, 0xb6, 0x87, 0xa4, 0x6c, 0x6f, 0x48, 0x2f, 0x9e, 0x7f, 0x94,
		0xe9, 0xb0, 0xc3, 0xd8, 0x3a, 0x1f, 0xd2, 0x5b, 0x23, 0xab, 0x86, 0xff, 0x90, 0xd6, 0x1a, 0x49,
		0xc7, 0xfc, 0x53, 0x87, 0x01, 0x15, 0x70, 0xa0, 0x16, 0x16, 0x54, 0xc1, 0x83, 0x72, 0x98, 0x50,
		0x0e, 0x17, 0xca, 0x61, 0x83, 0x67, 0x14, 0x9b, 0x16, 0x9c, 0xc4, 0x1f, 0x38, 0x8b, 0x87, 0x53,
		0x5f, 0x57, 0x71, 0x33, 0xa7, 0x14, 0xc3, 0xed, 0x55, 0x78, 0x49, 0x79, 0x6f, 0x4c, 0x59, 0xe6,
		0x8d, 0xca, 0x0c, 0x1b, 0x9a, 0x4c, 0x1a, 0xd5, 0x19, 0x33, 0x64, 0x99, 0x31, 0x64, 0x19, 0x30,
		0x64, 0x99, 0x2e, 0xbc, 0x65, 0x66, 0x65, 0x19, 0x2a, 0x04, 0x99, 0x28, 0x2a, 0x33, 0x4e, 0x92,
		0x99, 0x25, 0x33, 0xa0, 0xe4, 0xaa, 0xe4, 0xa6, 0x2a, 0x2d, 0xb9, 0x91, 0x50, 0xe7, 0x70, 0x54,
		0x74, 0x40, 0x48, 0x99, 0xcf, 0x26, 0x1d, 0x4e, 0x01, 0x0e, 0x07, 0x0e, 0x07, 0x0e, 0x87, 0x21,
		0x3f, 0x56, 0x18, 0x7e, 0x93, 0x85, 0xe3, 0x44, 0xfc, 0x59, 0x39, 0x8f, 0xa6, 0x80, 0x37, 0x5a,
		0x98, 0xa3, 0x82, 0x3b, 0x72, 0xd8, 0x23, 0x87, 0x3f, 0x72, 0x18, 0x54, 0x03, 0x87, 0x8a, 0x60,
		0x51, 0x3d, 0x1f, 0x4f, 0xd8, 0xcd, 0xc8, 0x53, 0x93, 0x75, 0x91, 0xe0, 0x64, 0x27, 0x0a, 0xaf,
		0x31, 0x9f, 0x2e, 0xb5, 0x7d, 0x82, 0x09, 0xf2, 0x43, 0x17, 0x37, 0xa5, 0xdd, 0x1f, 0xda, 0xff,
		0x8a, 0xc1, 0xc0, 0xfe, 0xee, 0xf9, 0xff, 0x7a, 0x76, 0xec, 0x68, 0x6c, 0xa2, 0x7a, 0x2a, 0xca,
		0x66, 0xda, 0x7a, 0x9a, 0x65, 0xc7, 0x53, 0xfd, 0xfe, 0xf3, 0x95, 0xf3, 0x3f, 0x67, 0xe7, 0xe7,
		0xce, 0x7f, 0x2f, 0xeb, 0xff, 0x73, 0xe9, 0x34, 0xaf, 0x3f, 0x3a, 0x1f, 0xea, 0x17, 0x17, 0x5f,
		0x2e, 0x6b, 0xd7, 0x7f, 0x52, 0x55, 0xae, 0x69, 0x68, 0x74, 0x4d, 0x5c, 0x51, 0xb5, 0x98, 0xed,
		0xcb, 0xba, 0x53, 0xfd, 0xf8, 0xf5, 0xac, 0x71, 0x5d, 0x6b, 0x12, 0x76, 0xa9, 0x26, 0xec, 0x57,
		0xa0, 0x6d, 0x5e, 0xaf, 0xce, 0xce, 0x1a, 0x98, 0xd1, 0x54, 0x57, 0xea, 0xd9, 0x1f, 0x57, 0xf5,
		0xc6, 0x35, 0x26, 0x55, 0xc1, 0xa4, 0x3a, 0xcd, 0x2f, 0xef, 0x3f, 0xd4, 0x2f, 0x3f, 0x9d, 0x7d,
		0xcc, 0x5a, 0x4d, 0x61, 0x0b, 0xf5, 0x60, 0x8c, 0x48, 0x54, 0x18, 0x75, 0x35, 0xb2, 0xa7, 0x13,
		0x82, 0x6b, 0x91, 0x50, 0x5f, 0x7a, 0xd8, 0xd0, 0x77, 0x20, 0xaf, 0x86, 0x83, 0x77, 0x35, 0x1d,
		0xb0, 0xab, 0xa7, 0x9b, 0x97, 0xbe, 0x6e, 0xb3, 0x9a, 0x3b, 0xbd, 0x6a, 0x3e, 0x00, 0x97, 0xc3,
		0xa1, 0x9f, 0x63, 0x3d, 0xed, 0xdb, 0x76, 0x7e, 0xc9, 0xe9, 0x3e, 0x88, 0x96, 0xc5, 0xda, 0xcb,
		0x68, 0xf3, 0xaf, 0x56, 0x96, 0x5a, 0x65, 0x68, 0x20, 0x18, 0x61, 0x14, 0x48, 0xaf, 0xaf, 0xa3,
		0x43, 0xc6, 0x31, 0x6d, 0x87, 0x8c, 0x48, 0x04, 0x1e, 0x39, 0xc7, 0xb0, 0xf6, 0xcb, 0xa5, 0xd2,
		0xd1, 0xcd, 0xa1, 0x5d, 0x6a, 0x3d, 0x96, 0x4b, 0xa5, 0x9b, 0x43, 0xbb, 0xd0, 0xba, 0x39, 0xb4,
		0x4f, 0x26, 0xff, 0x2a, 0x4e, 0x1f, 0xfc, 0x28, 0x8c, 0x1f, 0xcb, 0x93, 0x3f, 0x14, 0x5b, 0x4f,
		0xff, 0x7e, 0xf6, 0xcf, 0xa3, 0xf1, 0xe3, 0x4d, 0xde, 0x2e, 0xcd, 0xff, 0x55, 0x9c, 0xfe, 0xeb,
		0x64, 0xfe, 0xaf, 0xfc, 0xdb, 0xc9, 0x5f, 0x27, 0x0f, 0x0f, 0x4e, 0xa9, 0x2e, 0x44, 0x17, 0xb0,
		0xb6, 0x28, 0xd7, 0x47, 0xbd, 0x59, 0xfb, 0x43, 0xdb, 0x22, 0xf9, 0x3b, 0x73, 0xab, 0xe4, 0x3f,
		0x56, 0xd6, 0x1c, 0xc0, 0x1b, 0xb3, 0xbf, 0x87, 0xba, 0xf1, 0xb7, 0x8c, 0xda, 0x59, 0x24, 0x69,
		0x92, 0x43, 0xd7, 0x1c, 0x47, 0x6b, 0x53, 0x1c, 0x9a, 0x66, 0x38, 0x0a, 0x5a, 0x1e, 0x28, 0x48,
		0x04, 0x53, 0x93, 0x9f, 0x9e, 0x60, 0x6b, 0x2a, 0xf2, 0xd4, 0x89, 0xa2, 0x35, 0xe4, 0xdb, 0xbc,
		0xfc, 0x6a, 0xc8, 0xb7, 0x49, 0xeb, 0x82, 0xc8, 0xb7, 0xf9, 0xd9, 0xec, 0x10, 0xe6, 0xdb, 0x48,
		0x2f, 0x2a, 0x17, 0x09, 0x12, 0x6e, 0x14, 0x46, 0x97, 0x44, 0x7a, 0x35, 0x4d, 0x13, 0x3f, 0xba,
		0x94, 0x13, 0xe2, 0x06, 0xc5, 0xc4, 0x7a, 0xb3, 0x0e, 0x8d, 0x6f, 0x4c, 0xd3, 0x75, 0x31, 0xf3,
		0x4b, 0x44, 0xdf, 0xa1, 0x26, 0x5a, 0x56, 0x0d, 0x02, 0x4d, 0xb5, 0xe1, 0x05, 0x3a, 0xaa, 0x51,
		0x34, 0x72, 0x79, 0xd6, 0x06, 0x24, 0x7e, 0xfc, 0xa0, 0xec, 0x64, 0x59, 0x92, 0x56, 0x2f, 0x1f,
		0x9e, 0xbe, 0x52, 0xfc, 0xf8, 0x41, 0xc5, 0x21, 0xb0, 0x68, 0x9e, 0xa6, 0x59, 0x31, 0x42, 0xf3,
		0x34, 0x82, 0xd5, 0x60, 0x7c, 0xf3, 0xb4, 0xb5, 0x10, 0x67, 0x5a, 0xff, 0xb4, 0xb5, 0xa0, 0x86,
		0x26, 0x6a, 0x46, 0x37, 0x51, 0x4b, 0xaf, 0x05, 0x97, 0x8e, 0x65, 0x68, 0x62, 0x27, 0x35, 0x71,
		0x1f, 0xd9, 0x4a, 0xba, 0xa9, 0xad, 0x7e, 0x30, 0x3a, 0xaa, 0xfd, 0x72, 0xca, 0xd0, 0x51, 0x0d,
		0x1d, 0xd5, 0x7e, 0xfd, 0xad, 0x52, 0xeb, 0xa8, 0xf6, 0xdc, 0x42, 0x15, 0x74, 0x55, 0x5b, 0xfe,
		0x78, 0x74, 0x56, 0xe3, 0x05, 0x0f, 0xaa, 0x60, 0x42, 0x39, 0x5c, 0x28, 0x87, 0x0d, 0xe5, 0xf0,
		0xc1, 0x33, 0xc4, 0x45, 0x67, 0x35, 0x74, 0x56, 0xa3, 0x83, 0x1d, 0xd5, 0xf0, 0x43, 0x06, 0x43,
		0x64, 0x70, 0x44, 0x06, 0x4b, 0x66, 0xc8, 0xcd, 0xe8, 0xac, 0xb6, 0x09, 0x12, 0xd0, 0x59, 0x0d,
		0x9d, 0xd5, 0xd0, 0x59, 0x0d, 0x0e, 0x07, 0x0e, 0x27, 0xd5, 0x59, 0x50, 0xd6, 0x59, 0x4d, 0x4d,
		0x18, 0x4e, 0x1a, 0x96, 0x13, 0xf1, 0x68, 0xe5, 0x7c, 0x9a, 0x02, 0xe6, 0x68, 0xe1, 0x8e, 0x0a,
		0xf6, 0xc8, 0xe1, 0x8f, 0x1c, 0x06, 0xc9, 0xe1, 0x50, 0x0d, 0x2c, 0x2a, 0x82, 0x47, 0xf5, 0xbc,
		0x3c, 0x61, 0x37, 0xed, 0xfe, 0xd0, 0x5e, 0x02, 0x33, 0x3b, 0x10, 0x9d, 0x3b, 0xd5, 0xcd, 0x28,
		0xd0, 0x77, 0x2d, 0x95, 0x5b, 0x85, 0x96, 0x21, 0xec, 0xef, 0xde, 0x9a, 0x00, 0x08, 0x15, 0xbd,
		0x0a, 0x2f, 0x4c, 0x57, 0xab, 0x19, 0xb7, 0x2d, 0x98, 0x5d, 0x6d, 0xf1, 0xcf, 0x9b, 0x43, 0xfb,
		0x78, 0x7e, 0xc9, 0xf9, 0x53, 0x37, 0x87, 0x76, 0xfe, 0xe9, 0x5a, 0xb3, 0x27, 0x6f, 0x0e, 0xed,
		0xf2, 0xd3, 0x05, 0xa7, 0xcf, 0x4d, 0x3f, 0x26, 0xbe, 0xea, 0xe4, 0xa9, 0xa7, 0x8f, 0xfa, 0x51,
		0x9a, 0x3e, 0x73, 0x73, 0x68, 0x1f, 0xcd, 0x9f, 0x28, 0x8f, 0x1f, 0x8b, 0xcf, 0x3e, 0xb8, 0x32,
		0x1d, 0xe7, 0xe2, 0x8f, 0x27, 0x2b, 0xa3, 0x3e, 0x46, 0x79, 0xb0, 0xba, 0xab, 0xff, 0x8d, 0x25,
		0xf7, 0xb3, 0x25, 0x97, 0xbd, 0x5a, 0x63, 0x34, 0x9b, 0x80, 0x6b, 0x7a, 0x95, 0x6b, 0xda, 0x9f,
		0xd9, 0xe8, 0x93, 0x9d, 0x3c, 0xe6, 0xa7, 0xbf, 0x66, 0x8f, 0x0b, 0x4f, 0x88, 0xf0, 0x58, 0x28,
		0x4d, 0x4d, 0xf3, 0xe0, 0xaf, 0xbf, 0xde, 0x1d, 0xfc, 0x38, 0x1a, 0xbf, 0xfc, 0x8d, 0x68, 0x38,
		0x61, 0xb4, 0x47, 0xc9, 0xe2, 0x4a, 0x81, 0x23, 0x80, 0x23, 0x80, 0x23, 0x98, 0x3a, 0x02, 0x13,
		0x79, 0x1c, 0x3c, 0x8a, 0xd1, 0x1e, 0x05, 0x4b, 0x0e, 0xae, 0x09, 0xae, 0x09, 0xae, 0xe9, 0x17,
		0x17, 0x0e, 0xfc, 0x51, 0x24, 0xfe, 0xfa, 0xcb, 0x8e, 0xdc, 0xa0, 0x2f, 0xa2, 0x53, 0x48, 0x1b,
		0x50, 0xd3, 0x88, 0x3d, 0x15, 0x56, 0x20, 0xc4, 0x35, 0x38, 0x2e, 0x38, 0xae, 0x2d, 0x1d, 0x17,
		0xb4, 0x36, 0xf8, 0x9b, 0x57, 0xf9, 0x1b, 0x48, 0x6f, 0x70, 0x13, 0x70, 0x13, 0xbb, 0xe2, 0x26,
		0x20, 0x8b, 0xc0, 0xdf, 0xe8, 0xf5, 0x37, 0x58, 0x81, 0x70, 0x5c, 0x70, 0x5c, 0x70, 0x5c, 0xbf,
		0xe9, 0xb8, 0xfc, 0x40, 0xf6, 0xa5, 0x07, 0x59, 0x04, 0xc2, 0x9c, 0x2e, 0xc7, 0x85, 0x15, 0x08,
		0x61, 0x0e, 0x8e, 0x0b, 0x8e, 0xeb, 0x95, 0x8e, 0x0b, 0xc2, 0x1c, 0xfc, 0xcd, 0xab, 0xfc, 0x0d,
		0x84, 0x39, 0xb8, 0x09, 0xb8, 0x89, 0x5d, 0x71, 0x13, 0x90, 0x45, 0xe0, 0x6f, 0xf4, 0xfa, 0x1b,
		0xac, 0x40, 0x38, 0x2e, 0x38, 0x2e, 0x38, 0xae, 0x5f, 0x5c, 0xb8, 0xe3, 0x0f, 0xfc, 0xe0, 0x74,
		0x6a, 0xaa, 0x3f, 0x0a, 0x63, 0xe8, 0x65, 0xf0, 0x27, 0x73, 0x7f, 0x92, 0x85, 0x85, 0x81, 0x83,
		0x62, 0x99, 0x7d, 0x0f, 0xc5, 0x6e, 0x8a, 0xb2, 0x9b, 0x85, 0xf4, 0xdc, 0xe0, 0x81, 0xb0, 0x7b,
		0x05, 0x45, 0xf3, 0x8a, 0x73, 0xe1, 0xf5, 0xa7, 0x8d, 0x03, 0x33, 0xd7, 0xbe, 0x82, 0xf2, 0x2c,
		0xba, 0xd5, 0x3b, 0x77, 0xf8, 0x96, 0xf6, 0xb2, 0x8b, 0x83, 0xc7, 0x8e, 0x89, 0xaf, 0xab, 0xe1,
		0xb4, 0x31, 0x62, 0xfa, 0xbb, 0x47, 0x7d, 0x66, 0x1d, 0x96, 0x12, 0xfd, 0x52, 0x82, 0x23, 0xd7,
		0x3a, 0x7e, 0x9c, 0xf8, 0xbe, 0xd6, 0x7b, 0xe1, 0xc4, 0x77, 0xb6, 0x2b, 0x17, 0x27, 0xbe, 0xeb,
		0xf0, 0x59, 0xe8, 0xff, 0xf9, 0xf2, 0xab, 0xa1, 0xff, 0x67, 0x5a, 0x17, 0x44, 0xff, 0xcf, 0x9f,
		0xcd, 0x0e, 0x4e, 0x7c, 0x7f, 0xd1, 0x25, 0x70, 0xe2, 0x3b, 0xff, 0x90, 0x08, 0x27, 0xbe, 0x9b,
		0x17, 0x3d, 0xe3, 0xc4, 0x77, 0x9c, 0xf8, 0x4e, 0x1e, 0x68, 0xe2, 0xc4, 0xf7, 0x54, 0x3f, 0x9f,
		0xec, 0xd4, 0xd9, 0x95, 0xa3, 0x4a, 0x97, 0xfe, 0x6d, 0xf8, 0xc9, 0xef, 0x67, 0xf7, 0xd1, 0xf3,
		0x73, 0x92, 0x9f, 0xfd, 0x13, 0xe7, 0xbf, 0xbf, 0x2c, 0xaa, 0xc1, 0xf9, 0xef, 0x38, 0xff, 0x5d,
		0x2d, 0xf0, 0x31, 0x01, 0x3c, 0xd3, 0xce, 0x81, 0xff, 0x09, 0xc4, 0xe1, 0x34, 0x78, 0xa3, 0x4f,
		0x83, 0x4f, 0xf7, 0x08, 0x71, 0x4d, 0x0b, 0x52, 0xdb, 0xa1, 0xf0, 0x6f, 0x08, 0xd7, 0x5a, 0x5a,
		0x6b, 0x8c, 0x6c, 0x6d, 0x6d, 0xb1, 0x96, 0x28, 0xd6, 0xd0, 0xeb, 0x16, 0xcd, 0xcb, 0x6f, 0xf9,
		0xcb, 0xde, 0xf1, 0xc2, 0xc5, 0xb1, 0xed, 0xa2, 0x20, 0x59, 0x0c, 0xaf, 0x58, 0x08, 0xaa, 0x17,
		0xc0, 0xcb, 0x6e, 0xfe, 0xef, 0xdf, 0xc2, 0x17, 0xdc, 0x3e, 0xab, 0xb3, 0xd8, 0x61, 0x79, 0xd9,
		0x6d, 0x8b, 0xc5, 0xd9, 0xf9, 0xfb, 0x5f, 0xb8, 0x60, 0x5e, 0x77, 0x1a, 0xe6, 0xab, 0xb7, 0x83,
		0xb6, 0xd9, 0xe6, 0x79, 0xbe, 0x7d, 0xe3, 0x89, 0x68, 0xb2, 0xca, 0x5e, 0xb3, 0x94, 0xb6, 0xdc,
		0x96, 0x49, 0x6d, 0xbb, 0x25, 0xb5, 0x6d, 0x94, 0xd5, 0xed, 0x91, 0xc5, 0xdc, 0x30, 0x83, 0xa6,
		0xd7, 0x9e, 0xe6, 0x68, 0x75, 0x45, 0xcf, 0x1d, 0x0d, 0x22, 0xfb, 0x56, 0x44, 0x81, 0xec, 0xbc,
		0xfe, 0xc6, 0x2d, 0x96, 0xcf, 0xca, 0xe7, 0xbd, 0x72, 0xd2, 0xb7, 0x53, 0x3b, 0xb7, 0xde, 0x4f,
		0x4d, 0x63, 0xbf, 0x34, 0x1d, 0x83, 0x4a, 0xcb, 0xb0, 0x52, 0x37, 0xb0, 0xd4, 0x0d, 0x2d, 0x75,
		0x83, 0xd3, 0x43, 0x1c, 0xb7, 0xde, 0x2f, 0x5c, 0xda, 0x0f, 0x3c, 0x2a, 0x6c, 0xb3, 0x66, 0xe6,
		0x56, 0xb4, 0xc5, 0xa9, 0xdc, 0x29, 0xed, 0xe7, 0xa5, 0x10, 0xa4, 0xa5, 0xb9, 0x1f, 0x97, 0xf2,
		0x66, 0x4a, 0xda, 0xfb, 0x69, 0x2a, 0x76, 0x3e, 0x52, 0x90, 0x8a, 0x52, 0xdd, 0xef, 0x52, 0x75,
		0x0b, 0xe2, 0xd2, 0x8e, 0x12, 0xe3, 0x7b, 0xa1, 0x29, 0x82, 0x6e, 0x51, 0x05, 0x61, 0xaf, 0xe0,
		0x8d, 0xc2, 0x73, 0xdb, 0x03, 0xd1, 0xdd, 0x9e, 0x7f, 0x2c, 0x3e, 0x08, 0xc4, 0x03, 0xc4, 0x03,
		0xc4, 0xe3, 0x55, 0xeb, 0xa6, 0xed, 0xfb, 0x03, 0xe1, 0x7a, 0x29, 0x30, 0x8f, 0x7c, 0x9e, 0x31,
		0xe4, 0xc8, 0xae, 0xf0, 0x22, 0xd9, 0x93, 0x22, 0xd8, 0x1e, 0x75, 0x9e, 0x7d, 0x16, 0x80, 0x07,
		0xc0, 0x03, 0xe0, 0xd9, 0xc2, 0x8a, 0xa2, 0x87, 0x40, 0xf4, 0xd2, 0x00, 0x9f, 0x2d, 0x28, 0xa0,
		0x55, 0x9b, 0x0f, 0xe5, 0xbd, 0x1b, 0xa6, 0xb0, 0x04, 0x17, 0x5f, 0xb0, 0x76, 0xd9, 0xbc, 0xae,
		0x9e, 0x9f, 0x3b, 0x57, 0x8d, 0xfa, 0x75, 0xfd, 0x43, 0xfd, 0xdc, 0xb9, 0xfe, 0xf3, 0xea, 0x6c,
		0xdb, 0xe5, 0x38, 0xa5, 0xbe, 0x61, 0x2a, 0x39, 0x97, 0x29, 0x71, 0xfb, 0xc5, 0xd7, 0xfd, 0x58,
		0x6b, 0x9c, 0x7d, 0xb8, 0x3e, 0xff, 0xd3, 0xf9, 0x50, 0xbf, 0xbc, 0x3c, 0xfb, 0x70, 0x7d, 0xf6,
		0xd1, 0xe2, 0x10, 0xc8, 0xa4, 0xfc, 0x2d, 0xdf, 0x7f, 0xbe, 0xca, 0xe2, 0xd7, 0xaa, 0x7d, 0xbe,
		0xc8, 0xe4, 0xf7, 0xba, 0xaa, 0x5d, 0x64, 0xf1, 0x6b, 0x35, 0xaf, 0xab, 0xd7, 0xb5, 0x0f, 0x59,
		0xfc, 0x66, 0xf5, 0xe6, 0xd5, 0xa7, 0xac, 0x7e, 0xaf, 0xa3, 0x4c, 0x22, 0x47, 0xb3, 0xd6, 0xcc,
		0xe2, 0xf7, 0x3a, 0xaf, 0x7f, 0xa8, 0x9e, 0x3b, 0xd5, 0xcf, 0x9f, 0x1b, 0x67, 0x9f, 0xab, 0xd7,
		0x67, 0x96, 0x66, 0x21, 0xa8, 0x45, 0xcd, 0x0f, 0x49, 0xa2, 0xb2, 0xf9, 0x2e, 0xf4, 0x96, 0xf1,
		0xd8, 0xf4, 0x53, 0x10, 0x89, 0x21, 0x12, 0x43, 0x24, 0xf6, 0xaa, 0x75, 0xb3, 0x75, 0xa7, 0xb2,
		0xa7, 0xce, 0x63, 0xc8, 0xfc, 0xa1, 0xc8, 0xfc, 0x79, 0x55, 0x7e, 0xca, 0x9e, 0xea, 0xe4, 0x9f,
		0x39, 0x16, 0x32, 0xc8, 0xff, 0xd9, 0x42, 0xec, 0xdb, 0x5e, 0xe4, 0x7b, 0xa5, 0x4b, 0x41, 0x1e,
		0x10, 0xf2, 0x80, 0x5e, 0x0a, 0x54, 0xaf, 0x76, 0x01, 0xf1, 0x7d, 0x1f, 0x08, 0xb7, 0xf7, 0x3a,
		0x01, 0x2e, 0xc6, 0xfc, 0x57, 0x24, 0x1c, 0x58, 0x57, 0x73, 0x6c, 0x7c, 0xf7, 0x6e, 0x8e, 0x65,
		0xb9, 0x67, 0xe6, 0xc6, 0x01, 0x40, 0xfa, 0xb7, 0xc3, 0x2d, 0xa0, 0x63, 0xf2, 0xee, 0xdd, 0x48,
		0x1e, 0x7c, 0xc5, 0x57, 0xdd, 0x0d, 0xc4, 0x98, 0x4e, 0x4c, 0x56, 0xd2, 0x06, 0xfb, 0x03, 0xbf,
		0xed, 0x0e, 0xb6, 0x0f, 0xd4, 0xe6, 0x9f, 0xb3, 0x5d, 0xa8, 0x96, 0xcf, 0x48, 0xa8, 0xf6, 0x4a,
		0xd3, 0x41, 0x9c, 0xf6, 0x3a, 0xd3, 0xd2, 0x13, 0xa4, 0xbd, 0xd6, 0xe4, 0x9e, 0x08, 0x7b, 0x78,
		0x9b, 0xde, 0x8e, 0xd4, 0xe4, 0xc3, 0xb6, 0xbc, 0x17, 0xdb, 0x19, 0x61, 0x6a, 0xc6, 0x98, 0xa6,
		0x51, 0x2a, 0x30, 0xce, 0xb4, 0x8d, 0x54, 0x99, 0xb1, 0x2a, 0x33, 0x5a, 0x35, 0xc6, 0x9b, 0x8e,
		0x96, 0xba, 0x6d, 0x49, 0xe2, 0xb6, 0x46, 0x1d, 0x7f, 0xd0, 0xad, 0x3b, 0x1c, 0x4a, 0xaf, 0x1f,
		0xa6, 0xb7, 0x3e, 0x16, 0x4b, 0x38, 0xfe, 0xe4, 0xb7, 0xa9, 0x26, 0x70, 0xe6, 0x53, 0xfa, 0xb8,
		0xb4, 0x5b, 0xa0, 0xa9, 0x68, 0x79, 0xa6, 0x00, 0x0e, 0x54, 0xc1, 0x82, 0x72, 0x78, 0x50, 0x0e,
		0x13, 0x6a, 0xe1, 0x22, 0x1d, 0xd8, 0x48, 0x09, 0x3e, 0x52, 0x87, 0x91, 0x55, 0x38, 0x49, 0x7f,
		0x59, 0xad, 0xa0, 0x4a, 0xda, 0x8b, 0x2a, 0x5d, 0x70, 0x51, 0x06, 0x32, 0x2a, 0xc1, 0x86, 0x00,
		0x74, 0x54, 0x83, 0x0f, 0x19, 0x08, 0x91, 0x81, 0x11, 0x0d, 0x28, 0xa5, 0x0b, 0x4e, 0x29, 0x83,
		0x94, 0x32, 0xb0, 0x8a, 0x3f, 0xf8, 0x95, 0xb5, 0xba, 0x2f, 0x36, 0xa8, 0x57, 0xef, 0x99, 0x68,
		0x84, 0x30, 0xe5, 0x50, 0x46, 0x01, 0x69, 0x84, 0xd0, 0x46, 0x05, 0x71, 0xe4, 0x50, 0x47, 0x0e,
		0x79, 0xb4, 0xd0, 0xa7, 0x06, 0x02, 0x15, 0x41, 0xa1, 0x72, 0x48, 0x7c, 0xd2, 0x7e, 0x88, 0x56,
		0x71, 0x2c, 0x0f, 0xcd, 0xae, 0xa7, 0x78, 0x45, 0xd1, 0xf4, 0xb6, 0x54, 0x0e, 0x99, 0x94, 0xd0,
		0xa9, 0x01, 0x42, 0xa9, 0xa1, 0x54, 0x1b, 0xa4, 0x6a, 0x83, 0x56, 0x3d, 0x10, 0xab, 0x16, 0x6a,
		0x15, 0x43, 0x6e, 0x3c, 0x65, 0xca, 0xfb, 0x74, 0x27, 0x2c, 0x4e, 0x0e, 0xef, 0x8a, 0xb6, 0xdb,
		0xed, 0x06, 0x22, 0x0c, 0x09, 0x0f, 0xcf, 0xa2, 0x38, 0xcb, 0x91, 0xfc, 0x0c, 0x47, 0x8b, 0xf2,
		0x4c, 0xf1, 0xfd, 0xff, 0x75, 0xf3, 0xd7, 0x5f, 0xc3, 0x1f, 0x97, 0xe3, 0xc9, 0xff, 0xcf, 0xc7,
		0xad, 0xff, 0x7d, 0xf0, 0x7f, 0x2c, 0x9c, 0x61, 0x43, 0x6f, 0xb7, 0x56, 0x18, 0xde, 0xda, 0x81,
		0xeb, 0xf5, 0x45, 0x48, 0xc8, 0x68, 0x9e, 0xae, 0x09, 0x56, 0x03, 0x56, 0x03, 0x56, 0x03, 0x56,
		0x03, 0x56, 0x93, 0x4a, 0xfa, 0xdf, 0xab, 0x09, 0x4d, 0x85, 0x86, 0xd0, 0xcc, 0x53, 0xaf, 0x3b,
		0xb6, 0xdb, 0x19, 0x9c, 0xba, 0x9d, 0xc1, 0xb3, 0x87, 0x76, 0x28, 0xa2, 0x70, 0xe5, 0xdf, 0x8b,
		0x7f, 0xce, 0xb3, 0x11, 0xe7, 0xff, 0x9a, 0xe6, 0x49, 0x9b, 0xea, 0xca, 0x8d, 0xd2, 0x52, 0x14,
		0x77, 0xe3, 0x7f, 0x22, 0x21, 0xaa, 0x53, 0xf3, 0x27, 0x38, 0x97, 0x9b, 0xe5, 0xb9, 0xe5, 0xc2,
		0xf0, 0x36, 0xb7, 0xd8, 0x88, 0x5f, 0x3c, 0xc8, 0x29, 0xd5, 0xa1, 0xf7, 0x54, 0xe7, 0xf8, 0xd7,
		0xfa, 0xb7, 0x43, 0xe7, 0xf3, 0xf4, 0xeb, 0x39, 0xcd, 0xf0, 0xd6, 0xb9, 0x98, 0x7f, 0xbd, 0xc5,
		0x83, 0x57, 0x15, 0x01, 0xe8, 0x5b, 0xd2, 0x2a, 0x4e, 0xc0, 0x53, 0xac, 0xda, 0xd1, 0xa8, 0x75,
		0x38, 0x03, 0x8f, 0x15, 0x6f, 0xc5, 0x86, 0x86, 0x99, 0xbc, 0x14, 0xa7, 0xdf, 0xe9, 0xe2, 0x9d,
		0x14, 0x7c, 0x73, 0x4d, 0x19, 0xcb, 0x1c, 0x94, 0x77, 0xd9, 0xfd, 0x4d, 0xcf, 0xe5, 0x51, 0xef,
		0xfd, 0x14, 0x9d, 0x6b, 0xb4, 0x47, 0xb9, 0x9b, 0x5f, 0x80, 0xf3, 0x83, 0xf3, 0x83, 0xf3, 0x63,
		0xe1, 0xfc, 0xb0, 0x9b, 0xcf, 0x30, 0x4e, 0x20, 0x8b, 0x17, 0x28, 0xa1, 0x53, 0x03, 0x84, 0x52,
		0x43, 0xa9, 0x36, 0x48, 0xd5, 0x06, 0xad, 0x7a, 0x20, 0x56, 0x2d, 0xd4, 0x2a, 0x86, 0x5c, 0xba,
		0xb8, 0x23, 0x61, 0x71, 0xd8, 0xcd, 0x4f, 0xf1, 0x82, 0xd8, 0xcd, 0x67, 0x6a, 0xbb, 0xd8, 0xcd,
		0x07, 0xab, 0x01, 0xab, 0x01, 0xab, 0x01, 0xab, 0xd9, 0x0d, 0x56, 0x83, 0xdd, 0x7c, 0xec, 0xe6,
		0xb3, 0xd0, 0x52, 0x76, 0x67, 0x37, 0x5f, 0xa5, 0x0c, 0xbd, 0xa7, 0x7d, 0x33, 0x5f, 0xc1, 0x19,
		0xfb, 0xea, 0x16, 0x34, 0xef, 0xfa, 0xc9, 0xf9, 0x19, 0xfc, 0x4a, 0x44, 0x39, 0x35, 0x87, 0xf1,
		0xc7, 0x9f, 0xae, 0xec, 0x50, 0xfe, 0xa7, 0x2b, 0x10, 0x1e, 0xce, 0x1f, 0x5f, 0x54, 0xc9, 0x21,
		0xfd, 0xaa, 0x96, 0x8f, 0x62, 0x44, 0xd5, 0x8f, 0xa4, 0x96, 0x92, 0xad, 0x48, 0x7d, 0xd8, 0x99,
		0x2e, 0x6a, 0x8e, 0x33, 0xda, 0x02, 0x43, 0xd1, 0xb2, 0xd6, 0xb7, 0x9c, 0xd3, 0x6c, 0x12, 0xa3,
		0x63, 0xf9, 0xa6, 0xb3, 0x6c, 0xc7, 0x86, 0x37, 0x78, 0x4a, 0x79, 0x59, 0x92, 0x2f, 0xc7, 0x34,
		0x3a, 0x97, 0x11, 0xae, 0x3e, 0x4b, 0xd3, 0x11, 0x99, 0xb4, 0xad, 0x00, 0x53, 0x5a, 0x54, 0xa4,
		0x8b, 0x69, 0x9b, 0xfe, 0x94, 0x44, 0x0b, 0xc8, 0xe2, 0x7c, 0xe8, 0xa0, 0x17, 0x89, 0xa0, 0xe7,
		0x76, 0xb6, 0x10, 0xc9, 0x9f, 0xb6, 0xac, 0x9e, 0x3e, 0x0b, 0xfd, 0x53, 0xd1, 0x3f, 0x55, 0x9b,
		0x78, 0x6b, 0x58, 0xff, 0xd4, 0xd8, 0x6c, 0xd2, 0xeb, 0xa2, 0xfa, 0xf4, 0x91, 0xe8, 0xa5, 0x4a,
		0x60, 0xa8, 0x69, 0x1b, 0xac, 0x32, 0xc3, 0x55, 0x66, 0xc0, 0x6a, 0x0c, 0x99, 0x07, 0xd5, 0x4e,
		0xad, 0x97, 0x6a, 0xca, 0x7d, 0xc4, 0xd4, 0xf4, 0x0d, 0x43, 0x1f, 0x55, 0xf4, 0x51, 0xdd, 0x43,
		0x1f, 0xd5, 0x74, 0x45, 0xa4, 0xd4, 0xfb, 0xa8, 0x0a, 0xcf, 0x6d, 0x0f, 0x44, 0x57, 0x5d, 0x1f,
		0xd5, 0xc5, 0x05, 0xd2, 0xee, 0xd1, 0x28, 0x7a, 0xee, 0x68, 0x30, 0xbd, 0xe5, 0x3d, 0x77, 0x10,
		0x0a, 0x45, 0x7d, 0x5a, 0x0f, 0xd1, 0xa7, 0x15, 0x7d, 0x5a, 0x39, 0x81, 0x1d, 0x0d, 0xe8, 0xa5,
		0x0b, 0x7e, 0x29, 0x83, 0x60, 0x3c, 0x05, 0xca, 0xb2, 0x4e, 0xe2, 0x15, 0xdf, 0xf6, 0xfd, 0x81,
		0x70, 0x3d, 0x15, 0x2b, 0x7e, 0xc1, 0x8e, 0xf2, 0x5c, 0x37, 0x4f, 0x52, 0xa4, 0x2e, 0x3d, 0x39,
		0x88, 0x44, 0x60, 0xcf, 0x2c, 0x4f, 0x41, 0x16, 0x65, 0x7c, 0xbf, 0x56, 0x2f, 0x04, 0xa7, 0x00,
		0xa7, 0x00, 0xa7, 0x00, 0xa7, 0x90, 0xea, 0x8a, 0xdf, 0xfa, 0x08, 0xd9, 0x5f, 0xfa, 0x84, 0xe3,
		0x1d, 0xf0, 0x09, 0xb1, 0xb2, 0x68, 0x4b, 0x85, 0xd1, 0xc7, 0xd2, 0x55, 0xe0, 0x0d, 0xe0, 0x0d,
		0xe0, 0x0d, 0xe0, 0x0d, 0x4c, 0x41, 0x98, 0x9d, 0xf3, 0x09, 0xff, 0x77, 0x24, 0x82, 0x07, 0x7b,
		0x3a, 0xa3, 0x77, 0x5b, 0x9c, 0xc1, 0xf9, 0xcb, 0x7b, 0xb6, 0x72, 0x1d, 0xf8, 0x05, 0xf8, 0x05,
		0xf8, 0x05, 0xf8, 0x85, 0x74, 0xfd, 0x42, 0xff, 0x76, 0x18, 0x43, 0x8c, 0x1d, 0x4d, 0xae, 0xa7,
		0xce, 0x3b, 0x94, 0x15, 0x7c, 0xf4, 0x17, 0x4f, 0x4e, 0x53, 0xd4, 0xad, 0x50, 0x74, 0x7c, 0xaf,
		0xab, 0xa2, 0x0e, 0xd5, 0x6a, 0xb8, 0x5e, 0x5f, 0x28, 0xab, 0xde, 0x56, 0x58, 0x8d, 0x73, 0x21,
		0x3d, 0x82, 0x1e, 0x3d, 0x34, 0x95, 0xb9, 0x5f, 0xdd, 0xc1, 0x48, 0xa8, 0x6b, 0x01, 0x15, 0x5f,
		0xe7, 0x53, 0xe0, 0x76, 0x22, 0xe9, 0x7b, 0x1f, 0x65, 0x7f, 0xb6, 0xb2, 0x0e, 0x8d, 0xac, 0x06,
		0xbf, 0x70, 0xef, 0xb3, 0x77, 0xeb, 0x0f, 0x0b, 0xc5, 0x0c, 0xdd, 0x7d, 0x43, 0xaa, 0xb8, 0x5a,
		0x3b, 0x40, 0xe9, 0xef, 0x44, 0x10, 0xaa, 0xa8, 0xe4, 0x89, 0xfd, 0xec, 0xe2, 0x02, 0x20, 0xf1,
		0x20, 0xf1, 0x20, 0xf1, 0x20, 0xf1, 0xe9, 0x93, 0x78, 0x35, 0x08, 0xf3, 0x1c, 0x65, 0x4a, 0xa0,
		0xd6, 0xa0, 0xd6, 0xa0, 0xd6, 0x99, 0xa4, 0xd6, 0x47, 0xe0, 0xd5, 0xe0, 0xd5, 0x69, 0x7e, 0x12,
		0xea, 0x91, 0xfb, 0xb7, 0xc3, 0xdc, 0x53, 0x89, 0xd8, 0xd3, 0xc3, 0xf4, 0xcf, 0x1b, 0x51, 0x5f,
		0xd8, 0x57, 0x8b, 0xbf, 0xc7, 0xd3, 0xc3, 0x54, 0x0f, 0x16, 0x49, 0xa1, 0x3e, 0xf9, 0x6d, 0x1a,
		0x15, 0x0b, 0xa3, 0xc9, 0xb7, 0x0b, 0x55, 0xd4, 0x2c, 0xcc, 0x3f, 0x19, 0x55, 0x0b, 0x0c, 0x03,
		0x3c, 0x54, 0x2d, 0xe8, 0x09, 0xe0, 0x32, 0x5e, 0xb5, 0xf0, 0x7f, 0x47, 0x22, 0x90, 0x2a, 0x13,
		0x49, 0x17, 0x17, 0x50, 0xa3, 0x2a, 0xe5, 0xa1, 0x2a, 0x41, 0x55, 0x82, 0xaa, 0xc4, 0x53, 0x55,
		0x52, 0x75, 0x38, 0x82, 0x15, 0x88, 0x8e, 0x90, 0x77, 0x0a, 0x6a, 0xad, 0x12, 0x26, 0x15, 0x5f,
		0xc9, 0xf0, 0x33, 0x63, 0x70, 0x60, 0x1a, 0x07, 0x98, 0x23, 0x87, 0x3b, 0x72, 0xd8, 0xa3, 0x85,
		0x3f, 0xc5, 0x72, 0x8a, 0xb1, 0x67, 0xc6, 0x28, 0x3d, 0x4c, 0x2b, 0x61, 0x97, 0xaa, 0xbb, 0x99,
		0x12, 0x00, 0x65, 0x12, 0x30, 0x0b, 0xe8, 0xad, 0x6e, 0x00, 0x90, 0x6a, 0x03, 0x54, 0x6d, 0xc0,
		0xaa, 0x07, 0x60, 0xd5, 0x02, 0xad, 0x62, 0xc0, 0x25, 0x03, 0xde, 0xf8, 0x42, 0x77, 0x79, 0xba,
		0x95, 0x1f, 0x67, 0x6f, 0xe4, 0xa9, 0x96, 0x3c, 0xcd, 0xb6, 0x0f, 0x19, 0x87, 0xd5, 0x09, 0xcd,
		0x1a, 0x21, 0x5a, 0x17, 0x54, 0x6b, 0x87, 0x6c, 0xed, 0xd0, 0xad, 0x17, 0xc2, 0x69, 0xa0, 0x9c,
		0x08, 0xd2, 0xe3, 0xa9, 0x24, 0x3b, 0x36, 0x23, 0x61, 0xb1, 0x23, 0xe9, 0x45, 0x47, 0x05, 0x4a,
		0x83, 0x9d, 0xe3, 0x6f, 0x85, 0xf0, 0x92, 0x6a, 0x53, 0x60, 0x36, 0xfd, 0xd0, 0x02, 0xd2, 0x1e,
		0x55, 0xca, 0x0c, 0x13, 0xc7, 0x9a, 0xb8, 0xfc, 0x22, 0xcf, 0x42, 0xd7, 0xf5, 0x09, 0xf3, 0x2f,
		0x34, 0xc3, 0xd5, 0xf2, 0x92, 0x73, 0xef, 0x77, 0x7e, 0xc9, 0x15, 0x0b, 0x27, 0xc5, 0x93, 0x72,
		0xa5, 0x70, 0x52, 0xda, 0xe1, 0xb5, 0xf7, 0x26, 0x9b, 0x57, 0x6b, 0xbd, 0xc9, 0xc6, 0xf7, 0x21,
		0xc0, 0x06, 0xeb, 0xae, 0xa0, 0x21, 0x70, 0x2c, 0x20, 0x70, 0x44, 0xe0, 0x88, 0xc0, 0x11, 0x81,
		0x23, 0x02, 0x47, 0x04, 0x8e, 0x08, 0x1c, 0x11, 0x38, 0x22, 0x70, 0x44, 0xe0, 0x88, 0xc0, 0x11,
		0x81, 0x23, 0x02, 0x47, 0x73, 0x02, 0xc7, 0x23, 0x0d, 0x81, 0xe3, 0x11, 0x02, 0x47, 0x04, 0x8e,
		0x08, 0x1c, 0x11, 0x38, 0x22, 0x70, 0x44, 0xe0, 0x88, 0xc0, 0x11, 0x81, 0x23, 0x02, 0x47, 0x04,
		0x8e, 0x08, 0x1c, 0x11, 0x38, 0x22, 0x70, 0x34, 0xe0, 0x0a, 0xaa, 0xb3, 0x6d, 0x15, 0x75, 0x45,
		0xd8, 0x78, 0x3d, 0xad, 0xdd, 0x12, 0x66, 0x95, 0xf3, 0xb9, 0x79, 0xb1, 0x6b, 0x6e, 0x51, 0x36,
		0x96, 0xa3, 0xa8, 0x8d, 0xd8, 0xd3, 0xd9, 0x5e, 0x61, 0xf6, 0xc5, 0x9d, 0xff, 0x77, 0xf6, 0xc5,
		0x9d, 0xc6, 0xfc, 0x8b, 0x3b, 0xcd, 0xe9, 0x17, 0x7f, 0x63, 0xa6, 0x79, 0x98, 0x55, 0x4f, 0x44,
		0x64, 0x68, 0x2c, 0x0d, 0x4c, 0x65, 0x31, 0x20, 0x33, 0x93, 0xb2, 0x0c, 0xe9, 0x19, 0xa4, 0x60,
		0x99, 0x5b, 0xe1, 0x4c, 0xb3, 0x50, 0x5c, 0xec, 0x3b, 0xbd, 0x0a, 0x0a, 0x7d, 0xd7, 0x5e, 0x00,
		0x85, 0xbe, 0xaf, 0xbb, 0xed, 0x28, 0xf4, 0xdd, 0x5d, 0xc7, 0x8c, 0x42, 0x5f, 0x76, 0x40, 0x99,
		0x04, 0x4c, 0x14, 0xfa, 0x9a, 0x00, 0xa4, 0xda, 0x00, 0x55, 0x1b, 0xb0, 0xea, 0x01, 0xd8, 0x6c,
		0x48, 0x0f, 0x28, 0xf4, 0x4d, 0x13, 0x8a, 0xb1, 0xed, 0x6e, 0x34, 0x44, 0xeb, 0x82, 0x6a, 0xed,
		0x90, 0xad, 0x1d, 0xba, 0xf5, 0x42, 0x38, 0x0d, 0x94, 0x13, 0x41, 0x7a, 0x3c, 0x95, 0xd8, 0x76,
		0x57, 0x7a, 0x49, 0x6c, 0xbb, 0x67, 0xcf, 0xb1, 0x26, 0x2e, 0x8f, 0x6d, 0x77, 0x6c, 0xbb, 0x6b,
		0x5a, 0x72, 0xd8, 0x76, 0xc7, 0xb6, 0x3b, 0xf7, 0xef, 0x83, 0x42, 0x5f, 0x04, 0x8e, 0x08, 0x1c,
		0x11, 0x38, 0x22, 0x70, 0x44, 0xe0, 0x88, 0xc0, 0x11, 0x81, 0x23, 0x02, 0x47, 0x04, 0x8e, 0x08,
		0x1c, 0x11, 0x38, 0x22, 0x70, 0x44, 0xe0, 0xa8, 0x3f, 0x70, 0x44, 0xa1, 0x2f, 0x02, 0x47, 0x04,
		0x8e, 0x08, 0x1c, 0x11, 0x38, 0x22, 0x70, 0x44, 0xe0, 0x88, 0xc0, 0x11, 0x81, 0x23, 0x02, 0x47,
		0x04, 0x8e, 0x08, 0x1c, 0x11, 0x38, 0x1a, 0x1c, 0x38, 0xa2, 0xd0, 0xf7, 0x05, 0xd7, 0xe3, 0x54,
		0x87, 0x18, 0x0a, 0x2f, 0xda, 0xb9, 0x22, 0xdf, 0xa6, 0xf0, 0x22, 0x14, 0xf8, 0x92, 0x19, 0xda,
		0x4e, 0x16, 0xf8, 0x2a, 0xac, 0xc5, 0xe4, 0x66, 0x4a, 0xc6, 0x14, 0xf6, 0xb2, 0x3e, 0x6c, 0x58,
		0xb1, 0x91, 0x70, 0x32, 0x0e, 0x15, 0x07, 0x7c, 0xf3, 0xb0, 0x87, 0x74, 0x4d, 0x21, 0xbd, 0x05,
		0x9b, 0xe2, 0x62, 0xb5, 0x02, 0x31, 0xf4, 0x83, 0x48, 0xe1, 0x89, 0xfb, 0x8b, 0x0b, 0xe0, 0xc4,
		0x7d, 0x9c, 0xb8, 0xff, 0x93, 0xdb, 0x89, 0x13, 0xf7, 0xb3, 0xe7, 0x04, 0x95, 0x9d, 0xb8, 0xaf,
		0xb6, 0xd2, 0x9c, 0xa4, 0xc2, 0x9c, 0xac, 0x05, 0x47, 0x01, 0x2d, 0x38, 0x18, 0x00, 0x1c, 0x39,
		0xd0, 0x91, 0x03, 0x1e, 0x2d, 0xf0, 0x99, 0x19, 0x3a, 0x2b, 0x6f, 0xc1, 0x41, 0x50, 0x01, 0x4e,
		0x57, 0xf9, 0x4d, 0xa4, 0xd9, 0x93, 0xe5, 0x5d, 0xa0, 0xf9, 0x86, 0xd9, 0x50, 0xaa, 0x0d, 0x52,
		0xf5, 0x40, 0xab, 0x7a, 0xdd, 0x73, 0x8f, 0x60, 0x3b, 0x80, 0x2c, 0x5f, 0x82, 0x3e, 0x4f, 0x82,
		0x30, 0x3f, 0x82, 0x38, 0x2f, 0x82, 0x30, 0xbb, 0x45, 0x47, 0x1e, 0x84, 0xa6, 0xcd, 0x68, 0x5d,
		0x79, 0x0f, 0x3a, 0xf7, 0x9c, 0x09, 0xf3, 0x1c, 0xb4, 0xe4, 0x37, 0xe8, 0x5e, 0x4a, 0xba, 0xf2,
		0x19, 0xb4, 0xae, 0xa9, 0x8c, 0xec, 0xf3, 0xb7, 0x4c, 0xdd, 0x2e, 0x55, 0x28, 0x03, 0x10, 0x54,
		0x42, 0xd3, 0x55, 0x40, 0x23, 0x80, 0x42, 0x00, 0x85, 0x00, 0x0a, 0x01, 0x14, 0x02, 0x28, 0x04,
		0x50, 0x08, 0xa0, 0x10, 0x40, 0x21, 0x80, 0x42, 0x00, 0x85, 0x00, 0x0a, 0x01, 0x94, 0xd2, 0x00,
		0xea, 0x88, 0x30, 0x80, 0x3a, 0x42, 0x00, 0x85, 0x00, 0x0a, 0x01, 0x14, 0x02, 0x28, 0x04, 0x50,
		0x08, 0xa0, 0x10, 0x40, 0x21, 0x80, 0x42, 0x00, 0x85, 0x00, 0x0a, 0x01, 0x14, 0x02, 0x28, 0xd5,
		0x01, 0x14, 0x0a, 0xf6, 0xd6, 0x5c, 0x87, 0x43, 0x4d, 0xd2, 0xbc, 0xda, 0x44, 0x79, 0x11, 0xac,
		0xee, 0x0a, 0xa5, 0xc6, 0xec, 0x7b, 0xaa, 0xac, 0x7b, 0x45, 0xc9, 0x5e, 0x66, 0xcd, 0x23, 0x83,
		0x25, 0x7b, 0x73, 0x83, 0x60, 0x5b, 0xb2, 0xf7, 0x86, 0xd1, 0x92, 0x57, 0xb5, 0xd4, 0x39, 0x2c,
		0xf1, 0x14, 0x97, 0xb6, 0xe6, 0x25, 0x9d, 0xce, 0x52, 0xde, 0x7e, 0xe1, 0xa5, 0xb0, 0xe8, 0xac,
		0xf8, 0x3e, 0xd9, 0xb2, 0x9b, 0xda, 0x92, 0x8b, 0xf5, 0x8e, 0xa5, 0x4f, 0x4f, 0xc9, 0x44, 0xd2,
		0x8d, 0x6a, 0x52, 0x57, 0x78, 0x55, 0x28, 0xb9, 0x0a, 0x15, 0x5b, 0x55, 0xca, 0xac, 0x72, 0x05,
		0x56, 0xb9, 0xd2, 0xaa, 0x56, 0x51, 0xe5, 0xe5, 0x76, 0x52, 0x57, 0x42, 0xe3, 0x15, 0x3b, 0x10,
		0x6e, 0x2f, 0x10, 0xbd, 0x34, 0x57, 0xec, 0xa2, 0x3e, 0x33, 0x45, 0x6d, 0xd3, 0xba, 0x9a, 0x7b,
		0xc6, 0x77, 0xef, 0x72, 0x33, 0x4f, 0x92, 0x5b, 0x82, 0xae, 0x4c, 0x02, 0xfe, 0xe4, 0xb6, 0x28,
		0x44, 0xfc, 0xf4, 0xee, 0x7a, 0xca, 0x15, 0xb9, 0xe6, 0x41, 0x7e, 0x0f, 0x80, 0xaf, 0x03, 0xf0,
		0x7b, 0x59, 0x85, 0xfb, 0xb4, 0xab, 0x5d, 0xad, 0xce, 0xc2, 0xa2, 0x14, 0xb5, 0x2a, 0x99, 0x7f,
		0x3e, 0x3a, 0x95, 0x90, 0x74, 0x2a, 0xe9, 0xa1, 0x4f, 0x89, 0x46, 0x18, 0xa2, 0x80, 0x23, 0x33,
		0x74, 0x3f, 0x65, 0x5d, 0x4a, 0x62, 0x92, 0xa2, 0xbe, 0x53, 0xc9, 0xd3, 0xa5, 0xd4, 0x76, 0x2b,
		0x39, 0x54, 0xdd, 0xad, 0xe4, 0x30, 0x23, 0xdd, 0x4a, 0x7a, 0xe8, 0x55, 0xc2, 0x18, 0xf4, 0x28,
		0xc1, 0x4f, 0x0d, 0x08, 0x2a, 0x02, 0x43, 0x75, 0xa1, 0x3a, 0x61, 0xe8, 0x4e, 0x11, 0xca, 0x6f,
		0x0c, 0xed, 0x73, 0xd3, 0x65, 0x74, 0xfa, 0x4c, 0xa3, 0x5e, 0x79, 0x62, 0xfe, 0xef, 0xa9, 0xaa,
		0x6c, 0xca, 0xbe, 0x9d, 0x8a, 0xed, 0xa2, 0x51, 0x9b, 0xd0, 0x3f, 0x2e, 0x5d, 0x0d, 0x2e, 0x12,
		0x2e, 0x12, 0x2e, 0x12, 0x2e, 0x12, 0x2e, 0x92, 0xa9, 0x8b, 0xbc, 0x79, 0x72, 0x91, 0xff, 0xbf,
		0xce, 0x28, 0x08, 0x84, 0x17, 0xed, 0x1f, 0xe4, 0xde, 0xbd, 0x7b, 0x52, 0xcb, 0x5b, 0xf3, 0xb7,
		0x3c, 0xc7, 0xf5, 0x70, 0xcd, 0x73, 0xf1, 0x27, 0x77, 0xc5, 0x3d, 0xb2, 0x64, 0xd2, 0xb8, 0x89,
		0x67, 0xf7, 0xd3, 0x5c, 0xc7, 0xf4, 0xb3, 0xb0, 0xd5, 0x0b, 0x36, 0x7e, 0xc7, 0x16, 0xf7, 0xd1,
		0x69, 0x24, 0x06, 0xe2, 0x56, 0x44, 0xc1, 0x83, 0xed, 0x7b, 0x76, 0xe7, 0xdb, 0x34, 0xad, 0x9c,
		0x44, 0xc4, 0xe9, 0xb9, 0x83, 0x90, 0x42, 0xc5, 0xe1, 0x2e, 0xe0, 0xb4, 0x90, 0xb8, 0xf5, 0xbb,
		0x59, 0x2d, 0x4b, 0xfb, 0x5c, 0x39, 0x25, 0xfa, 0xf4, 0x9e, 0xbe, 0x4c, 0x97, 0xf8, 0x51, 0x43,
		0xf4, 0x9c, 0x39, 0xbf, 0xdd, 0x81, 0x96, 0xeb, 0x6a, 0xba, 0x17, 0x2b, 0xed, 0x5a, 0xac, 0x7c,
		0x13, 0xa3, 0x80, 0x4d, 0x0c, 0xb2, 0xe0, 0x05, 0x9b, 0x18, 0xd9, 0xa3, 0x65, 0xd8, 0xc4, 0x80,
		0x42, 0x03, 0x85, 0x06, 0x0a, 0x0d, 0x14, 0x1a, 0x28, 0x34, 0x04, 0x0a, 0x0d, 0x36, 0x31, 0xf6,
		0xb0, 0x89, 0x01, 0x17, 0x09, 0x17, 0x09, 0x17, 0x09, 0x17, 0x09, 0x17, 0x89, 0x4d, 0x0c, 0xb3,
		0xa2, 0xe5, 0x9d, 0x51, 0x8c, 0x55, 0x95, 0xc1, 0x73, 0x10, 0x8c, 0x15, 0x94, 0xbe, 0xa3, 0xde,
		0xd7, 0xcc, 0x75, 0x6e, 0x7e, 0xd1, 0xef, 0xf3, 0x95, 0x9d, 0xa5, 0x3a, 0xb0, 0x5b, 0x71, 0xdb,
		0x16, 0x41, 0xf8, 0x4d, 0x0e, 0xed, 0x7e, 0xe0, 0x8f, 0x86, 0x61, 0xfa, 0xb5, 0x60, 0xc9, 0x4b,
		0xa0, 0x1e, 0x2c, 0x95, 0xd8, 0x06, 0x25, 0xc0, 0x34, 0xd1, 0xca, 0x2e, 0x95, 0x00, 0xa7, 0x5e,
		0x13, 0x36, 0x35, 0x79, 0x75, 0x9b, 0xa9, 0xb3, 0x8f, 0xc7, 0x66, 0x2a, 0xce, 0xae, 0xd6, 0x2f,
		0x9f, 0xe0, 0xec, 0x6a, 0xc2, 0x10, 0x51, 0xd9, 0x86, 0xaa, 0x1a, 0xc0, 0x22, 0x01, 0xae, 0x55,
		0x00, 0x83, 0x4a, 0xac, 0x15, 0xd8, 0xa8, 0x00, 0x8e, 0x1c, 0xe8, 0xc8, 0x01, 0x8f, 0x16, 0xf8,
		0xd4, 0xa9, 0x6e, 0x7b, 0x50, 0x8a, 0x5f, 0xc6, 0xc0, 0x28, 0x94, 0xe2, 0x77, 0xef, 0x66, 0x32,
		0x5c, 0x6e, 0x06, 0xc9, 0xbb, 0xbc, 0x5d, 0xaa, 0x24, 0xf1, 0x31, 0xb1, 0x7e, 0x54, 0xf6, 0xfe,
		0x54, 0xc4, 0xdd, 0x95, 0x73, 0x78, 0xb8, 0x3e, 0xb8, 0x3e, 0xb8, 0x3e, 0x66, 0xb1, 0x00, 0x51,
		0x4c, 0x40, 0x1a, 0x1b, 0x10, 0xc5, 0x08, 0x64, 0xb1, 0x02, 0x25, 0x70, 0x6a, 0x00, 0x50, 0x6a,
		0x20, 0xd5, 0x06, 0xa8, 0xda, 0x80, 0x55, 0x0f, 0xc0, 0xaa, 0x05, 0x5a, 0xc5, 0x80, 0x4b, 0x17,
		0x73, 0x24, 0x2c, 0x4e, 0x0e, 0xef, 0x8a, 0xb6, 0xdb, 0xed, 0x06, 0x22, 0x0c, 0x09, 0x0f, 0xd0,
		0xc9, 0x1f, 0x13, 0x5c, 0xeb, 0xca, 0x8d, 0x22, 0x11, 0x78, 0x64, 0x67, 0xe8, 0x58, 0xfb, 0xfb,
		0x37, 0x87, 0xf6, 0x49, 0xeb, 0xf1, 0x26, 0x6f, 0x9f, 0xb4, 0x66, 0x0f, 0xf3, 0xd3, 0x5f, 0xb3,
		0xc7, 0x85, 0x9b, 0x43, 0xbb, 0xb8, 0x78, 0x5c, 0xba, 0x39, 0xb4, 0x4b, 0xad, 0x83, 0xbf, 0xfe,
		0x7a, 0x77, 0xf0, 0xe3, 0x68, 0xfc, 0xf2, 0x37, 0xee, 0xff, 0xaf, 0x9b, 0xbf, 0xfe, 0x1a, 0xfe,
		0xb8, 0x1c, 0x4f, 0xfe, 0x7f, 0x3e, 0x6e, 0xfd, 0xef, 0x83, 0xff, 0x63, 0xe1, 0xfc, 0x0a, 0x7a,
		0xbb, 0xb5, 0x66, 0x2d, 0xe6, 0x45, 0x40, 0x47, 0x67, 0xe2, 0x2b, 0x82, 0xd1, 0x80, 0xd1, 0x80,
		0xd1, 0x80, 0xd1, 0x80, 0xd1, 0x80, 0xd1, 0x80, 0xd1, 0x80, 0xd1, 0xa4, 0x74, 0xd3, 0x43, 0x22,
		0x8d, 0x31, 0xd6, 0xaf, 0x67, 0xd7, 0x03, 0x9b, 0x01, 0x9b, 0x01, 0x9b, 0x01, 0x9b, 0x01, 0x9b,
		0x01, 0x9b, 0x01, 0x9b, 0xd9, 0x2d, 0x36, 0x83, 0xf3, 0x45, 0xd7, 0xf1, 0x30, 0x7d, 0xd5, 0x26,
		0x89, 0x1a, 0x83, 0x59, 0x32, 0x47, 0x56, 0x8f, 0x19, 0xbd, 0x88, 0xbf, 0xee, 0xe7, 0xe9, 0xb7,
		0x75, 0xa6, 0xbf, 0x70, 0xd8, 0x68, 0xaa, 0xf4, 0x4a, 0x59, 0x7a, 0xf9, 0xb9, 0x0c, 0xa3, 0x6a,
		0x14, 0x29, 0xca, 0x5f, 0xbd, 0x90, 0xde, 0xd9, 0x40, 0x4c, 0x88, 0x52, 0xa8, 0x86, 0xd5, 0x5b,
		0x17, 0xee, 0xfd, 0xb3, 0x2b, 0xe4, 0x8f, 0x8b, 0xc5, 0x72, 0xa5, 0x58, 0x3c, 0xac, 0x1c, 0x55,
		0x0e, 0x4f, 0x4a, 0xa5, 0x7c, 0x39, 0xaf, 0xe0, 0xa4, 0x6f, 0xab, 0x1e, 0x74, 0x45, 0x20, 0xba,
		0xef, 0x27, 0xb7, 0xc5, 0x1b, 0x0d, 0x06, 0xa8, 0x5f, 0x65, 0x85, 0xb4, 0xd9, 0xa9, 0x61, 0x5d,
		0x8f, 0xad, 0xa8, 0x63, 0xd5, 0xb8, 0xee, 0x59, 0xad, 0x77, 0xf3, 0x6b, 0x59, 0x57, 0x57, 0x78,
		0x96, 0xea, 0x59, 0xd3, 0x4d, 0x61, 0x55, 0x92, 0xb2, 0xaa, 0xac, 0x6e, 0xb5, 0x80, 0xba, 0x55,
		0x93, 0x14, 0x36, 0xd4, 0xad, 0x72, 0xae, 0x5b, 0x15, 0x9e, 0xdb, 0x1e, 0x88, 0xae, 0xba, 0xca,
		0xd5, 0xc5, 0x05, 0xd2, 0xae, 0x8b, 0x13, 0x3d, 0x77, 0x34, 0x98, 0xde, 0xf2, 0x69, 0x3f, 0x73,
		0x45, 0xb5, 0xb1, 0x87, 0x38, 0x2d, 0x11, 0xb5, 0xb1, 0x9c, 0xc0, 0x8e, 0x06, 0xf4, 0xcc, 0x10,
		0x2f, 0x94, 0xc9, 0xfe, 0xf1, 0x8a, 0x6f, 0xfb, 0xfe, 0x40, 0xb8, 0x9e, 0x8a, 0x15, 0xbf, 0x60,
		0x47, 0xf9, 0x1d, 0xe8, 0x34, 0xdf, 0x93, 0x83, 0x48, 0x04, 0xf6, 0xcc, 0xf2, 0x44, 0xa8, 0xce,
		0xd9, 0xac, 0x5e, 0x08, 0x4e, 0x01, 0x4e, 0x01, 0x4e, 0x01, 0x4e, 0x21, 0xe5, 0x20, 0x39, 0x90,
		0x5e, 0x5f, 0xa5, 0x4f, 0x38, 0xde, 0x01, 0x9f, 0xf0, 0xd4, 0x38, 0x4d, 0x2a, 0x8c, 0x3e, 0x96,
		0xae, 0x02, 0x6f, 0x00, 0x6f, 0x00, 0x6f, 0x00, 0x6f, 0x60, 0x0a, 0xc2, 0xec, 0x9c, 0x4f, 0xf8,
		0xbf, 0x23, 0x11, 0x3c, 0xd8, 0xe2, 0x7e, 0x28, 0x03, 0x95, 0x51, 0xc2, 0xf2, 0x65, 0xe0, 0x15,
		0xe0, 0x15, 0xe0, 0x15, 0xe0, 0x15, 0x52, 0x5d, 0xf1, 0x91, 0xbc, 0x15, 0x91, 0xec, 0x7c, 0x0f,
		0xcb, 0x45, 0x85, 0x4e, 0x41, 0x41, 0x36, 0xa8, 0xf5, 0xc5, 0x93, 0xd3, 0x7c, 0x17, 0xcb, 0x73,
		0x3d, 0x3f, 0x14, 0x1d, 0xdf, 0xeb, 0xaa, 0xc8, 0x70, 0xb5, 0x1a, 0xd3, 0x03, 0x4f, 0x55, 0xe5,
		0x98, 0x2a, 0x4c, 0xff, 0xbb, 0x90, 0x1e, 0x41, 0x9f, 0x17, 0x9a, 0xaa, 0x88, 0xaf, 0xee, 0x60,
		0x24, 0x08, 0xae, 0xf3, 0x29, 0x70, 0x3b, 0x91, 0xf4, 0xbd, 0x8f, 0xb2, 0x3f, 0x5b, 0x5d, 0x87,
		0x46, 0x56, 0xe0, 0x5c, 0xb8, 0xf7, 0x99, 0xbb, 0xf5, 0x34, 0x79, 0x6d, 0xda, 0x56, 0x83, 0x21,
		0x59, 0xa2, 0xad, 0x9d, 0x61, 0xf7, 0xd3, 0x78, 0xe9, 0xce, 0x1d, 0xa8, 0xa6, 0xf7, 0xf1, 0x75,
		0xc0, 0xef, 0xc1, 0xef, 0xc1, 0xef, 0xc1, 0xef, 0xd3, 0x55, 0x7d, 0xfa, 0xb7, 0xc3, 0x18, 0x62,
		0xec, 0x68, 0x72, 0x3d, 0x75, 0x34, 0xbf, 0xac, 0x92, 0xe6, 0x83, 0xe2, 0xef, 0x06, 0xc5, 0xcf,
		0x83, 0xe2, 0xef, 0x2c, 0xc5, 0x3f, 0x2c, 0x14, 0x41, 0xe9, 0x41, 0xe9, 0xd3, 0xa7, 0xf4, 0x77,
		0x22, 0x08, 0x55, 0x54, 0xff, 0xc4, 0x7e, 0x76, 0x71, 0x01, 0x90, 0x78, 0x90, 0x78, 0x90, 0x78,
		0x90, 0xf8, 0xf4, 0x49, 0xbc, 0x1a, 0x84, 0x79, 0x8e, 0x32, 0x25, 0x50, 0x6b, 0x50, 0x6b, 0x50,
		0xeb, 0x4c, 0x52, 0xeb, 0x23, 0xf0, 0x6a, 0xf0, 0xea, 0x34, 0x3f, 0x09, 0x25, 0xca, 0x1b, 0x4b,
		0x94, 0xd3, 0x6e, 0x72, 0xa2, 0xa9, 0x2c, 0x39, 0xc5, 0xee, 0x25, 0x29, 0xd4, 0x22, 0xbf, 0xd1,
		0xb8, 0x58, 0x17, 0xdd, 0x47, 0x52, 0x4c, 0xa1, 0x4b, 0xb7, 0xe9, 0x48, 0xfa, 0x4d, 0x46, 0x48,
		0x9a, 0x8a, 0xa4, 0xdb, 0x44, 0x64, 0xdb, 0x9b, 0x9c, 0x32, 0x12, 0x69, 0x44, 0x20, 0x2b, 0x95,
		0xc2, 0x7d, 0x0d, 0x98, 0xb3, 0x1d, 0xda, 0xbc, 0x1e, 0x23, 0x5e, 0xf7, 0xce, 0x57, 0x2e, 0xb8,
		0xb4, 0x16, 0x1a, 0xf9, 0x02, 0xdb, 0x62, 0x59, 0x51, 0x2e, 0xa7, 0xd7, 0x2d, 0xa2, 0x97, 0x2f,
		0x81, 0x97, 0xbd, 0xe3, 0x85, 0x8b, 0x65, 0xdb, 0x45, 0x42, 0xb3, 0x38, 0x5e, 0xb1, 0x22, 0x94,
		0xaf, 0x84, 0x97, 0xdd, 0xfe, 0xdf, 0xbf, 0x89, 0x2f, 0xb8, 0x81, 0x96, 0x0c, 0xe5, 0xcb, 0xd3,
		0xc2, 0x9f, 0xe4, 0x9e, 0xc9, 0xbb, 0x5f, 0xb8, 0x5c, 0x5e, 0xd7, 0xc3, 0xe4, 0xd5, 0x42, 0xf0,
		0x36, 0x42, 0xef, 0x92, 0x90, 0xfb, 0xf2, 0xaf, 0x9a, 0x86, 0x50, 0x9b, 0x9a, 0x10, 0x9b, 0x9a,
		0xd0, 0x9a, 0x10, 0x52, 0x27, 0x13, 0xc3, 0x0c, 0x92, 0x5e, 0xdb, 0xd3, 0xc3, 0xea, 0x0f, 0xfc,
		0xf6, 0x16, 0x89, 0x54, 0x4f, 0xe7, 0xb0, 0xcd, 0x3e, 0xe7, 0x95, 0x33, 0xbc, 0x5d, 0x9b, 0x9f,
		0xad, 0xf7, 0x4c, 0xd2, 0xd8, 0x1b, 0x49, 0xc1, 0x74, 0xd2, 0x32, 0xa1, 0xd4, 0x4d, 0x29, 0x75,
		0x93, 0x4a, 0xd7, 0xb4, 0xf4, 0x50, 0xc5, 0x6d, 0xdb, 0xe8, 0x58, 0x6e, 0x4f, 0xda, 0xa1, 0xdb,
		0x93, 0xdb, 0xdf, 0xe7, 0xc5, 0xd2, 0x8b, 0x3f, 0x71, 0xdb, 0x98, 0x3a, 0x95, 0xae, 0x5b, 0xa9,
		0x6d, 0x65, 0xa6, 0xb9, 0x75, 0x99, 0xa2, 0x99, 0xa6, 0x6d, 0xae, 0xca, 0xcc, 0x56, 0x99, 0xf9,
		0xaa, 0x31, 0x63, 0x1e, 0xba, 0x52, 0x5a, 0x5d, 0xb2, 0x2c, 0xb7, 0x97, 0x7e, 0x8f, 0x3d, 0xb7,
		0xc7, 0xbd, 0xc1, 0xde, 0xa1, 0x21, 0x0d, 0xf6, 0xd2, 0x81, 0x00, 0x55, 0x50, 0xa0, 0x1c, 0x12,
		0x94, 0x43, 0x83, 0x5a, 0x88, 0x48, 0x4f, 0xc4, 0xde, 0xe3, 0xdc, 0x60, 0x6f, 0xe2, 0xd7, 0xe7,
		0x51, 0xb9, 0xa2, 0x1c, 0xa9, 0xf8, 0x0a, 0x48, 0x92, 0x22, 0x49, 0x92, 0x4a, 0x17, 0x76, 0x54,
		0xc3, 0x0f, 0x19, 0x0c, 0x91, 0xc1, 0x11, 0x0d, 0x2c, 0xa5, 0x0b, 0x4f, 0x29, 0xc3, 0x54, 0x3c,
		0x05, 0xea, 0x93, 0xa4, 0x06, 0xc2, 0xed, 0x05, 0xa2, 0xa7, 0xb2, 0xb5, 0x45, 0x45, 0xc1, 0x67,
		0x5f, 0xcd, 0x15, 0xda, 0x77, 0xef, 0x72, 0x33, 0x1d, 0x34, 0x17, 0xc3, 0xe4, 0x0e, 0xe4, 0xe5,
		0x76, 0x16, 0x18, 0xab, 0xc8, 0xe5, 0xcc, 0x3f, 0x5f, 0x8d, 0xc3, 0xc9, 0xc3, 0xe1, 0xc0, 0xe1,
		0xc0, 0xe1, 0xf0, 0x74, 0x38, 0x69, 0xf3, 0x63, 0xf5, 0x3c, 0x99, 0x8a, 0x2f, 0x2b, 0xe6, 0xcd,
		0xca, 0xe1, 0x8c, 0x02, 0xd6, 0x08, 0xe1, 0x8d, 0x0a, 0xe6, 0xc8, 0xe1, 0x8e, 0x1c, 0xf6, 0x68,
		0xe1, 0x4f, 0x0d, 0x0c, 0x2a, 0x82, 0x43, 0xf5, 0x3c, 0x3c, 0x61, 0x31, 0xb2, 0x2b, 0xbc, 0x48,
		0x46, 0x0f, 0x6a, 0x38, 0x79, 0x82, 0x8b, 0x29, 0xec, 0x05, 0x62, 0xd5, 0xe6, 0x5f, 0xe5, 0xbd,
		0x1b, 0x12, 0x1e, 0x6b, 0x5c, 0xfd, 0x54, 0x73, 0xae, 0xff, 0xbc, 0x3a, 0xb3, 0x28, 0x52, 0xc4,
		0x43, 0x92, 0x53, 0x34, 0x89, 0xce, 0xe2, 0x5d, 0xcc, 0x60, 0xed, 0xea, 0x6b, 0x99, 0xe0, 0x48,
		0xda, 0xb7, 0x19, 0x9c, 0xb7, 0xa2, 0xe9, 0x47, 0xf9, 0xb6, 0x76, 0xbe, 0xfe, 0x40, 0xc1, 0xba,
		0x54, 0x76, 0x0a, 0x4b, 0x62, 0x09, 0xaa, 0x39, 0x8d, 0x05, 0xd4, 0x17, 0xd4, 0x17, 0xd4, 0x17,
		0xd4, 0x57, 0xb1, 0xc5, 0xa8, 0x3b, 0x8d, 0x25, 0x41, 0x7b, 0xf3, 0x3b, 0xec, 0x8c, 0x6e, 0x45,
		0x14, 0xc8, 0x8e, 0x7a, 0x5f, 0x34, 0xbf, 0x8e, 0xa2, 0x65, 0xf9, 0xec, 0x80, 0xb0, 0xfc, 0x21,
		0xfc, 0x1d, 0xfc, 0x1d, 0xfc, 0x1d, 0xfc, 0x9d, 0x59, 0xfe, 0x6e, 0x24, 0xbd, 0xe8, 0xa8, 0x40,
		0xe0, 0xee, 0x2a, 0x0a, 0x2f, 0xa1, 0xb6, 0x53, 0x05, 0x5d, 0x24, 0x4f, 0xd2, 0xb9, 0x82, 0xc8,
		0xb1, 0x24, 0x2e, 0x47, 0xd4, 0x07, 0x3a, 0xbe, 0x1e, 0x61, 0x5b, 0x03, 0x42, 0x39, 0x89, 0xa4,
		0xc3, 0x85, 0xee, 0x25, 0x52, 0x2c, 0x9c, 0x14, 0x4f, 0xca, 0x95, 0xc2, 0x49, 0x29, 0xc3, 0x6b,
		0xe5, 0x8d, 0x99, 0x9f, 0xde, 0xda, 0xe1, 0xa8, 0x25, 0xa4, 0xdb, 0x40, 0x0e, 0xb1, 0x83, 0x8c,
		0xb0, 0x02, 0x61, 0x05, 0xc2, 0x0a, 0x33, 0xc3, 0x0a, 0xec, 0x20, 0x6f, 0x39, 0x81, 0x4d, 0x6c,
		0x21, 0x6f, 0x3b, 0x85, 0x5f, 0x2e, 0x6b, 0x1f, 0xaa, 0xcd, 0x6b, 0xec, 0x22, 0xbf, 0x7c, 0xea,
		0x2e, 0xbe, 0x9c, 0x5f, 0x53, 0x4d, 0x1e, 0xb6, 0x92, 0xd5, 0xf2, 0x60, 0xd6, 0xa9, 0x9e, 0x8a,
		0x5a, 0xc8, 0x3d, 0x31, 0x76, 0xe5, 0xad, 0x54, 0x42, 0x19, 0xe6, 0x66, 0xcd, 0x0d, 0x72, 0x8b,
		0xf2, 0xea, 0x9c, 0xdb, 0xcb, 0x29, 0xc9, 0x5e, 0xdf, 0x53, 0xde, 0x84, 0x25, 0x94, 0xa1, 0xf3,
		0x79, 0xfa, 0x6d, 0x9c, 0x6a, 0x4f, 0x36, 0xdd, 0x9e, 0x74, 0xaa, 0x3d, 0x67, 0x4e, 0xe6, 0x77,
		0xa0, 0xa8, 0xe1, 0x76, 0x34, 0x88, 0xa4, 0x1d, 0xf9, 0x43, 0x7f, 0xe0, 0xf7, 0x1f, 0xd4, 0x15,
		0x37, 0xac, 0x5c, 0x07, 0x45, 0x0e, 0x28, 0x72, 0xd0, 0x1f, 0xb3, 0xa1, 0xc8, 0x81, 0xd0, 0xf3,
		0x29, 0x2b, 0x72, 0x50, 0x54, 0x97, 0x95, 0x30, 0x28, 0x65, 0x1e, 0x4e, 0x21, 0x84, 0x41, 0x9e,
		0x82, 0x3c, 0x05, 0x79, 0x8a, 0xab, 0x3c, 0xa5, 0x0a, 0x12, 0xe3, 0x0b, 0x28, 0x97, 0xef, 0x13,
		0xa6, 0xa9, 0x58, 0xc5, 0x5f, 0x85, 0x4b, 0xd5, 0x2d, 0xe9, 0x55, 0xc3, 0x26, 0x25, 0x7c, 0x6a,
		0x80, 0x51, 0x6a, 0x38, 0xd5, 0x06, 0xab, 0xda, 0xe0, 0x55, 0x0f, 0xcc, 0xd2, 0x68, 0x59, 0x8a,
		0x65, 0x46, 0xf5, 0xbb, 0x03, 0x09, 0x8b, 0xa3, 0xd9, 0x25, 0x48, 0x70, 0x4a, 0x82, 0xac, 0x02,
		0xda, 0x5d, 0x83, 0xc4, 0xc4, 0x12, 0x6d, 0x1e, 0xc4, 0xd7, 0x25, 0xdc, 0x44, 0x58, 0xfc, 0xfc,
		0x20, 0xbb, 0xd2, 0x1e, 0x7d, 0x5d, 0x1a, 0x91, 0xc9, 0xf3, 0x98, 0xcf, 0x22, 0xe1, 0x7c, 0x92,
		0x5c, 0xa9, 0x85, 0xe4, 0x21, 0xfa, 0xf5, 0x4c, 0x90, 0x9c, 0x93, 0x58, 0xbc, 0x21, 0xe8, 0x3d,
		0xe8, 0x3d, 0xe8, 0x3d, 0xe8, 0x3d, 0xe8, 0x3d, 0xe8, 0x3d, 0x21, 0x69, 0x6a, 0x82, 0xdf, 0xab,
		0x9a, 0x5a, 0xb2, 0xa4, 0xa1, 0xdd, 0xa1, 0xf8, 0x84, 0xc9, 0x44, 0xe0, 0xf9, 0x4c, 0x78, 0xbe,
		0x51, 0xfb, 0x0e, 0x8a, 0x93, 0x90, 0x9e, 0x22, 0x14, 0x5d, 0xc9, 0x48, 0xcb, 0xd9, 0x26, 0x39,
		0xa5, 0x3b, 0xb7, 0x7b, 0x9a, 0x72, 0x94, 0x2e, 0x26, 0xdf, 0xf1, 0x7a, 0xfe, 0x15, 0x95, 0x64,
		0x2c, 0xa9, 0x5b, 0xdc, 0x4a, 0x6a, 0x55, 0xa6, 0x47, 0x80, 0xaa, 0xaf, 0x53, 0x49, 0xf9, 0xc0,
		0xd4, 0xb5, 0x8c, 0x4e, 0x75, 0x12, 0x40, 0x01, 0x49, 0x00, 0x8c, 0xc2, 0x5a, 0x24, 0x01, 0xec,
		0xb2, 0x33, 0x46, 0x12, 0xc0, 0xb6, 0x70, 0x09, 0x95, 0x90, 0x35, 0x8c, 0x52, 0xc3, 0xa9, 0x36,
		0x58, 0xd5, 0x06, 0xaf, 0x7a, 0x60, 0x96, 0x28, 0x66, 0x83, 0x4a, 0x98, 0x0e, 0xa7, 0x44, 0x12,
		0x40, 0xda, 0xd7, 0x45, 0x12, 0x80, 0x91, 0x26, 0xcf, 0x63, 0x3e, 0x91, 0x04, 0xc0, 0xcd, 0xd1,
		0x18, 0x99, 0x04, 0xa0, 0xba, 0xc9, 0x6d, 0x62, 0xe9, 0xaa, 0x6d, 0x76, 0x0b, 0x6a, 0x0f, 0x6a,
		0x0f, 0x6a, 0x0f, 0x6a, 0x6f, 0x28, 0xb5, 0x57, 0xdf, 0x4c, 0x37, 0x41, 0xeb, 0xf3, 0x70, 0x8a,
		0x89, 0xb9, 0x41, 0x66, 0x1c, 0x1c, 0x23, 0x1c, 0x23, 0x1c, 0x23, 0x1c, 0x23, 0x17, 0xc7, 0x08,
		0xcd, 0x4b, 0xd1, 0xc4, 0x22, 0x33, 0x4e, 0xd9, 0xd4, 0x22, 0x33, 0x2e, 0xf5, 0x29, 0x45, 0x66,
		0x1c, 0x57, 0x8f, 0x83, 0xcd, 0xf8, 0xbd, 0x5d, 0xcc, 0x8c, 0x53, 0x99, 0xcd, 0xb4, 0xc7, 0x22,
		0x31, 0xae, 0x39, 0xfd, 0x86, 0xe8, 0x5d, 0xc7, 0xdf, 0x38, 0xb8, 0x18, 0x45, 0x46, 0x7a, 0xd8,
		0x2d, 0x99, 0xc1, 0x2e, 0xb4, 0xb2, 0x53, 0xa7, 0xfa, 0x28, 0x57, 0x79, 0x14, 0xa9, 0x3a, 0x68,
		0x60, 0xa7, 0x47, 0x95, 0x41, 0x03, 0xbb, 0x2c, 0xba, 0x3f, 0x65, 0xaa, 0x49, 0xbc, 0xe2, 0x07,
		0xc2, 0xed, 0xa9, 0x51, 0x48, 0x62, 0x45, 0x44, 0xc1, 0xa9, 0x44, 0xd6, 0xd5, 0xdc, 0x63, 0xbf,
		0x7b, 0x37, 0xaf, 0xb4, 0xc8, 0x3d, 0xe1, 0xe4, 0x2e, 0xf8, 0x1d, 0x25, 0x85, 0x07, 0x4a, 0x0b,
		0x0e, 0x94, 0x37, 0x4c, 0x2d, 0xc0, 0xdf, 0xc0, 0xdf, 0xc0, 0xdf, 0x6c, 0x35, 0x05, 0xca, 0x1a,
		0xa6, 0xd2, 0x1d, 0xea, 0x83, 0x33, 0x7d, 0xb4, 0xc1, 0x1a, 0x21, 0xbc, 0x51, 0xc1, 0x1c, 0x39,
		0xdc, 0x91, 0xc3, 0x1e, 0x2d, 0xfc, 0xa9, 0xd3, 0xb1, 0xf6, 0x70, 0xa6, 0xcf, 0xcb, 0xb9, 0x58,
		0xf6, 0xce, 0xf4, 0xc1, 0x91, 0x3e, 0xdb, 0xce, 0x20, 0x4d, 0xe2, 0x7d, 0xf6, 0xce, 0xf3, 0xa1,
		0x49, 0xb0, 0xc7, 0x51, 0x3e, 0x6a, 0x3f, 0x55, 0x45, 0x9b, 0x00, 0xd5, 0x09, 0xf3, 0x44, 0x89,
		0xf2, 0xa0, 0xbe, 0xa0, 0xbe, 0xa0, 0xbe, 0xa0, 0xbe, 0x8a, 0x2c, 0x46, 0x7d, 0x22, 0xbb, 0xe2,
		0x04, 0x76, 0x33, 0x9c, 0xd1, 0xad, 0x88, 0x02, 0xd9, 0x51, 0xef, 0x8b, 0xe6, 0xd7, 0x51, 0xd5,
		0xc1, 0x42, 0xf4, 0xdc, 0xd1, 0x60, 0x6a, 0xb0, 0xf9, 0x43, 0xf8, 0x3b, 0xf8, 0x3b, 0xf8, 0x3b,
		0xf8, 0x3b, 0xb3, 0xfc, 0xdd, 0x48, 0x7a, 0xd1, 0x51, 0x81, 0xc0, 0xdd, 0x55, 0x14, 0x5e, 0xa2,
		0xe1, 0x7a, 0x7d, 0xa1, 0x5c, 0x05, 0x21, 0xa8, 0x1a, 0xb8, 0x90, 0x1e, 0x61, 0xc5, 0x0c, 0x49,
		0x41, 0x55, 0x7c, 0xb9, 0xa9, 0x56, 0x45, 0x78, 0xbd, 0x4f, 0x81, 0xdb, 0x89, 0xa4, 0xef, 0x7d,
		0x94, 0x7d, 0x19, 0x85, 0x93, 0x0b, 0x67, 0x41, 0x4e, 0xb2, 0x2e, 0xdc, 0xfb, 0xcc, 0x2f, 0x91,
		0x62, 0xe1, 0xa4, 0x78, 0x52, 0xae, 0x14, 0x4e, 0x4a, 0x19, 0x5e, 0x2b, 0x86, 0xa6, 0xb5, 0xb7,
		0x76, 0xb9, 0xd3, 0x26, 0xdd, 0x06, 0x72, 0x88, 0x1d, 0x64, 0x84, 0x15, 0x08, 0x2b, 0x10, 0x56,
		0x98, 0x19, 0x56, 0x60, 0x07, 0x79, 0xcb, 0x09, 0x6c, 0x62, 0x0b, 0x79, 0xdb, 0x29, 0x24, 0x2b,
		0x63, 0xcd, 0xde, 0x2e, 0x32, 0x61, 0xb9, 0x2a, 0xb6, 0x92, 0x15, 0xf3, 0x60, 0x54, 0xd6, 0xe9,
		0xa8, 0xac, 0x53, 0x55, 0x5f, 0xaa, 0xa3, 0xa0, 0x4e, 0x41, 0x25, 0x69, 0x8a, 0x05, 0x0d, 0x6f,
		0x18, 0xad, 0xeb, 0x09, 0xbd, 0x7e, 0x9e, 0xfe, 0xbb, 0x97, 0x76, 0x18, 0x67, 0x9d, 0xcb, 0x30,
		0xaa, 0x46, 0x51, 0xba, 0x09, 0xd2, 0xd6, 0x85, 0xf4, 0xce, 0x06, 0x62, 0xc2, 0x9a, 0xc3, 0x74,
		0x43, 0x36, 0xeb, 0xc2, 0xbd, 0x7f, 0xf6, 0xc9, 0xf9, 0xe3, 0x62, 0xb1, 0x5c, 0x29, 0x16, 0x0f,
		0x2b, 0x47, 0x95, 0xc3, 0x93, 0x52, 0x29, 0x5f, 0x4e, 0x93, 0xba, 0x59, 0xf5, 0xa0, 0x2b, 0x02,
		0xd1, 0x7d, 0x3f, 0xb9, 0x07, 0xde, 0x68, 0x30, 0x60, 0xb5, 0x34, 0x14, 0x41, 0x9d, 0x36, 0x88,
		0xb3, 0x52, 0xad, 0x24, 0xa2, 0x06, 0xb5, 0x74, 0xe0, 0x6c, 0x7b, 0xf0, 0xd9, 0xee, 0x13, 0xb6,
		0x5c, 0x9b, 0x69, 0xaf, 0x49, 0x3d, 0x6b, 0x31, 0x85, 0x85, 0x48, 0xbd, 0x00, 0xb7, 0x5b, 0x7d,
		0xaf, 0x5f, 0x33, 0x5b, 0xac, 0x17, 0xab, 0xb3, 0x50, 0xf4, 0xb6, 0x5b, 0x27, 0x71, 0x8c, 0x91,
		0xca, 0xd9, 0x54, 0x29, 0xd5, 0xf3, 0xa5, 0x26, 0x57, 0xa6, 0x29, 0x4b, 0x2a, 0x90, 0x1f, 0xd3,
		0x96, 0x19, 0x95, 0xc9, 0x89, 0xca, 0x64, 0x43, 0x35, 0xf2, 0xa0, 0x5e, 0x14, 0x4f, 0xab, 0x5e,
		0xce, 0x72, 0x47, 0xd1, 0x37, 0xe1, 0x45, 0xb2, 0x33, 0x75, 0x09, 0x76, 0xe7, 0x9b, 0xe8, 0x7c,
		0x4f, 0x6f, 0xad, 0xc4, 0xb5, 0x71, 0xeb, 0xae, 0x92, 0xd2, 0xdd, 0x7d, 0x96, 0x91, 0x35, 0x59,
		0x33, 0x69, 0x7d, 0x6c, 0xba, 0x9b, 0x25, 0xa9, 0x6f, 0x8e, 0xa8, 0xd8, 0x0c, 0x51, 0xb8, 0xf9,
		0xa1, 0x6a, 0xb3, 0x43, 0xf9, 0xe6, 0x86, 0xf2, 0xcd, 0x0c, 0xb5, 0x9b, 0x17, 0xbc, 0x42, 0xe5,
		0xd4, 0x37, 0x23, 0x14, 0xe6, 0xf0, 0xa6, 0x9c, 0xb3, 0x9b, 0x42, 0xd8, 0x90, 0x02, 0x17, 0xe8,
		0xb9, 0x61, 0x64, 0xf7, 0x06, 0xbe, 0xdf, 0x95, 0x5e, 0x3f, 0x7d, 0x98, 0x5f, 0xfe, 0x78, 0xe0,
		0x3b, 0xf0, 0x1d, 0xf8, 0x0e, 0x7c, 0x07, 0xbe, 0x93, 0xe1, 0xbb, 0x94, 0x5d, 0x3b, 0x1a, 0xdc,
		0xa5, 0x8f, 0xec, 0x8b, 0x0f, 0x4e, 0x1f, 0xd3, 0x7b, 0xee, 0x20, 0x04, 0xa8, 0x03, 0xd4, 0x01,
		0xea, 0x00, 0x75, 0x80, 0xfa, 0x5a, 0x50, 0x9f, 0x0b, 0xcd, 0x0a, 0x50, 0x7d, 0xf1, 0xc9, 0xe9,
		0xc3, 0xfa, 0x21, 0x20, 0x1d, 0x90, 0x0e, 0x48, 0xdf, 0x35, 0x48, 0x0f, 0xa3, 0x20, 0xbd, 0xd0,
		0x7f, 0x09, 0xd1, 0x8f, 0x33, 0x84, 0xe8, 0x03, 0x71, 0x27, 0x06, 0x76, 0xc7, 0x1d, 0xba, 0x6d,
		0x39, 0x90, 0xd1, 0x43, 0xfa, 0xc8, 0x9e, 0xb8, 0x42, 0xfa, 0x08, 0x7f, 0x7e, 0xf6, 0xf5, 0xec,
		0xdc, 0xc9, 0x3b, 0x05, 0x20, 0x3d, 0x90, 0x1e, 0x48, 0xbf, 0x6b, 0x48, 0x3f, 0x43, 0x98, 0x68,
		0xf2, 0xf9, 0x0a, 0xd0, 0xbe, 0x98, 0xe2, 0x67, 0x9e, 0x79, 0xa3, 0xdb, 0xc9, 0x1c, 0x8c, 0x33,
		0xe4, 0x41, 0x6e, 0xdd, 0x7b, 0x5b, 0x74, 0x6e, 0x87, 0xf6, 0xd0, 0x8d, 0xbe, 0x85, 0xe9, 0xfb,
		0x8f, 0x95, 0xcf, 0x07, 0xc2, 0x03, 0xe1, 0x81, 0xf0, 0x3b, 0x86, 0xf0, 0x23, 0xe9, 0x45, 0xc7,
		0x0a, 0xc0, 0x3d, 0xcd, 0xf4, 0x5f, 0x35, 0x6d, 0x20, 0x14, 0x54, 0x25, 0xa8, 0x6c, 0xf3, 0xa0,
		0xba, 0xb0, 0x57, 0x71, 0x1b, 0x07, 0x8a, 0x52, 0x7c, 0x15, 0xa5, 0xe1, 0x2a, 0xdb, 0x32, 0x50,
		0xdd, 0xd2, 0x42, 0xa9, 0x64, 0xf0, 0x4d, 0x65, 0x5a, 0x9f, 0xd2, 0xca, 0x16, 0xd1, 0x94, 0xb7,
		0xa3, 0x5b, 0xdb, 0x0d, 0x84, 0x6b, 0xbb, 0xdd, 0x6e, 0x20, 0xc2, 0x50, 0xa8, 0x21, 0x9c, 0xeb,
		0xae, 0x93, 0xbe, 0x6c, 0x71, 0x04, 0x32, 0x0b, 0x32, 0x0b, 0x32, 0x0b, 0x32, 0x0b, 0x32, 0x0b,
		0x32, 0x0b, 0x32, 0x0b, 0x32, 0x0b, 0x32, 0xbb, 0x33, 0x64, 0xd6, 0x13, 0x51, 0xfa, 0xcc, 0x75,
		0xf2, 0xa1, 0xa0, 0x94, 0xa0, 0x94, 0xa0, 0x94, 0x3b, 0x46, 0x29, 0xd3, 0x33, 0xfc, 0xbd, 0xa5,
		0x44, 0x87, 0x14, 0x3f, 0xf3, 0xca, 0x8d, 0x22, 0x11, 0x78, 0xa9, 0x73, 0x4a, 0xeb, 0xef, 0x1b,
		0xd7, 0xee, 0x55, 0xed, 0x4f, 0x87, 0xf6, 0x49, 0xeb, 0x47, 0x61, 0xbc, 0xff, 0xd7, 0x5f, 0xef,
		0x9e, 0x3f, 0x53, 0x1c, 0x1f, 0xfc, 0x38, 0x7a, 0x7b, 0x32, 0x5e, 0x79, 0xba, 0x30, 0xfe, 0x4f,
		0x7a, 0xcb, 0xac, 0x95, 0xe6, 0x3c, 0xd5, 0x9b, 0xb5, 0x3f, 0x32, 0x3d, 0x59, 0xac, 0x6c, 0x12,
		0x1d, 0x4d, 0x7e, 0x72, 0x31, 0x35, 0x1d, 0x4d, 0x58, 0xf0, 0xaf, 0xa1, 0x2f, 0xd5, 0x94, 0x27,
		0x2c, 0x3e, 0x18, 0xe5, 0x09, 0xe0, 0x77, 0xe0, 0x77, 0xe0, 0x77, 0xa9, 0xac, 0xd8, 0x5d, 0x28,
		0x4f, 0x40, 0x2b, 0xa2, 0xd7, 0xb6, 0x22, 0x4a, 0xa5, 0x97, 0xcd, 0x1e, 0x65, 0x23, 0xa2, 0xb9,
		0xbb, 0x30, 0xb0, 0x0f, 0x51, 0x3f, 0x70, 0x3b, 0xa2, 0x37, 0x1a, 0xd8, 0x81, 0x08, 0x23, 0x37,
		0x88, 0xd2, 0xeb, 0x48, 0x94, 0xf8, 0x64, 0xf4, 0x26, 0x22, 0xf4, 0xe4, 0xe8, 0x4d, 0x84, 0xde,
		0x44, 0x3f, 0xf9, 0xa0, 0x94, 0xda, 0x8f, 0x25, 0x16, 0x70, 0x6a, 0xd0, 0x9d, 0xa2, 0xc9, 0x83,
		0xd4, 0x83, 0xd4, 0x83, 0xd4, 0xa7, 0x0d, 0x21, 0xf1, 0x07, 0xaa, 0x3a, 0x09, 0x59, 0xf1, 0x09,
		0xc8, 0xaa, 0x94, 0x08, 0x45, 0x8a, 0x84, 0x32, 0x10, 0x53, 0x09, 0x66, 0x04, 0xa0, 0xa6, 0x1a,
		0xdc, 0xc8, 0x40, 0x8e, 0x0c, 0xec, 0x68, 0x40, 0x2f, 0x5d, 0xf0, 0x4b, 0x19, 0x04, 0xd5, 0x29,
		0x1c, 0x04, 0x4a, 0x87, 0x22, 0xc5, 0x23, 0xfd, 0x1b, 0x96, 0xe2, 0xcd, 0xb2, 0xbe, 0x89, 0xc1,
		0x50, 0x04, 0xb6, 0xef, 0x0d, 0x1e, 0xd4, 0x39, 0x9a, 0xe7, 0x17, 0x81, 0x33, 0x80, 0x33, 0x80,
		0x33, 0x80, 0x33, 0x80, 0x33, 0xc8, 0x62, 0x10, 0x94, 0x89, 0xd3, 0x23, 0x56, 0x05, 0xd6, 0x5c,
		0xaa, 0xe2, 0xcb, 0x1e, 0xa5, 0x7e, 0xfe, 0x79, 0xfe, 0x55, 0x1a, 0xb3, 0x6f, 0x92, 0x8a, 0x9e,
		0x9e, 0xde, 0xca, 0x1b, 0xa7, 0xb2, 0x13, 0xe1, 0x46, 0x0a, 0xda, 0x4c, 0xa5, 0x79, 0x30, 0x92,
		0x32, 0xb9, 0xad, 0x00, 0xb9, 0x0d, 0x72, 0x1b, 0xe4, 0x36, 0xc8, 0x6d, 0x90, 0xdb, 0x10, 0x61,
		0x21, 0xc2, 0x42, 0x84, 0x85, 0x08, 0x0b, 0x72, 0x1b, 0xe4, 0x36, 0x38, 0x03, 0x38, 0x03, 0x38,
		0x03, 0x38, 0x03, 0xc8, 0x6d, 0x66, 0xca, 0x6d, 0x69, 0x1f, 0x4a, 0xad, 0x4d, 0x6d, 0x4b, 0xf1,
		0x44, 0x6a, 0xe4, 0x4d, 0x33, 0x5a, 0xa1, 0x26, 0x65, 0x50, 0xaf, 0xac, 0x49, 0x13, 0x53, 0xa9,
		0x65, 0x7f, 0x68, 0x87, 0xdf, 0xfc, 0x20, 0xea, 0x8c, 0xa2, 0x30, 0xbd, 0x3c, 0xea, 0xe5, 0x8f,
		0x45, 0x12, 0x35, 0x21, 0xd1, 0x45, 0x12, 0x35, 0x92, 0xa8, 0x7f, 0xf2, 0x41, 0x6e, 0x4f, 0x2a,
		0x38, 0xcf, 0x35, 0x95, 0x23, 0xb8, 0xf7, 0x90, 0x3e, 0x8d, 0xfd, 0x1c, 0xaa, 0xa8, 0x16, 0xfb,
		0x39, 0xdb, 0x81, 0x88, 0x3d, 0xa7, 0x57, 0x8a, 0x74, 0xb6, 0xf8, 0x0a, 0x10, 0xd9, 0x20, 0xb2,
		0x41, 0x64, 0x83, 0xc8, 0x96, 0xea, 0x8a, 0x1f, 0x08, 0xb7, 0x17, 0x88, 0x9e, 0x4a, 0x91, 0xad,
		0xa2, 0xe0, 0xb3, 0xaf, 0xe6, 0x21, 0xf9, 0xbb, 0x77, 0xf3, 0xb4, 0xa9, 0x5c, 0x0c, 0x93, 0x3b,
		0xb0, 0xbf, 0x93, 0x72, 0xf9, 0x5f, 0x62, 0x51, 0xa4, 0x9e, 0x89, 0xa6, 0x80, 0xcf, 0xc2, 0xe1,
		0xc0, 0xe1, 0xc0, 0xe1, 0xa4, 0xed, 0x70, 0xd2, 0xe6, 0xc7, 0xea, 0x79, 0x32, 0x15, 0x5f, 0x56,
		0xcc, 0x9b, 0x95, 0xc3, 0x19, 0x05, 0xac, 0x11, 0xc2, 0x1b, 0x15, 0xcc, 0x91, 0xc3, 0x1d, 0x39,
		0xec, 0xd1, 0xc2, 0x9f, 0x1a, 0x18, 0x54, 0x04, 0x87, 0xea, 0x79, 0x78, 0xc2, 0x62, 0x64, 0x57,
		0x78, 0x91, 0x8c, 0x1e, 0xd4, 0x70, 0xf2, 0x04, 0x17, 0x2b, 0x29, 0xbc, 0x46, 0x6d, 0xfe, 0x55,
		0xde, 0xbb, 0x21, 0x81, 0x7d, 0x2e, 0x26, 0xb0, 0xfa, 0xa9, 0xe6, 0x5c, 0xff, 0x79, 0x75, 0xa6,
		0xda, 0x3c, 0xa7, 0xad, 0xb5, 0xc3, 0xd4, 0x5b, 0x62, 0xae, 0xfb, 0xf9, 0xa1, 0xfc, 0x0a, 0x4b,
		0x33, 0x58, 0xbb, 0xfa, 0x5a, 0xb6, 0x94, 0x5f, 0x72, 0xfc, 0x36, 0x83, 0xf3, 0x56, 0x24, 0x98,
		0x37, 0xa5, 0x57, 0x68, 0x99, 0x06, 0xf8, 0x46, 0x1c, 0x21, 0xe0, 0x7d, 0x9b, 0x1d, 0x07, 0xaa,
		0x9c, 0xfb, 0x2e, 0x2e, 0x04, 0xea, 0x0b, 0xea, 0x0b, 0xea, 0x0b, 0xea, 0x0b, 0xea, 0xbb, 0x4b,
		0xd4, 0xf7, 0xaa, 0x7a, 0xfd, 0xff, 0x77, 0x9a, 0x67, 0xd7, 0x5f, 0xae, 0x9c, 0xab, 0x46, 0xfd,
		0xba, 0xfe, 0xa1, 0x7e, 0x0e, 0x16, 0x9c, 0xc2, 0x64, 0x36, 0x1b, 0xa0, 0xc3, 0x5b, 0x4d, 0xe0,
		0xf9, 0xc7, 0x2b, 0xcc, 0xe0, 0x56, 0x33, 0xd8, 0x68, 0x7e, 0xbd, 0x42, 0x6c, 0x91, 0x0d, 0x8f,
		0xaa, 0xe4, 0x8c, 0x87, 0xc4, 0x55, 0x94, 0x9d, 0xf9, 0x90, 0xbc, 0x12, 0xe1, 0x19, 0x10, 0x89,
		0x8b, 0x2b, 0x39, 0x13, 0x82, 0x20, 0xca, 0x64, 0xbd, 0x0b, 0xa4, 0xa8, 0xe0, 0x23, 0xfe, 0x7c,
		0xd2, 0xb4, 0xfa, 0xa5, 0x04, 0xec, 0x9c, 0xdb, 0x93, 0x39, 0x25, 0xdb, 0xdb, 0x7b, 0x94, 0xe9,
		0xf6, 0xb5, 0xfe, 0xb0, 0xb9, 0xf8, 0x4a, 0x4e, 0xb5, 0x27, 0x53, 0xed, 0xb8, 0x92, 0xfe, 0x1a,
		0x1d, 0xa7, 0x5a, 0x65, 0x93, 0x66, 0x27, 0x96, 0x84, 0xcf, 0x4d, 0xbb, 0x2a, 0x68, 0x8f, 0x22,
		0xf3, 0xa1, 0x80, 0xcc, 0x07, 0x42, 0x5d, 0x04, 0x99, 0x0f, 0x59, 0xf4, 0x79, 0xc8, 0x7c, 0xf8,
		0x5d, 0x18, 0x83, 0xfc, 0xab, 0x15, 0xde, 0xa8, 0x60, 0x8e, 0x1c, 0xee, 0xc8, 0x61, 0x8f, 0x16,
		0xfe, 0xcc, 0x0c, 0x56, 0x21, 0xff, 0xbe, 0xe2, 0x1a, 0xc8, 0x7c, 0x30, 0x53, 0x70, 0x43, 0xe6,
		0xc3, 0xab, 0xe7, 0x0d, 0x99, 0x0f, 0xd4, 0x80, 0x8f, 0xcc, 0x07, 0x64, 0x3e, 0x80, 0xfa, 0x82,
		0xfa, 0x82, 0xfa, 0x82, 0xfa, 0xee, 0x3a, 0xf5, 0x45, 0xe6, 0x83, 0x9a, 0xc9, 0x44, 0xe6, 0xc3,
		0x96, 0x13, 0x88, 0xcc, 0x87, 0x6d, 0x67, 0x10, 0x99, 0x0f, 0xd9, 0xf1, 0xa8, 0xc8, 0x7c, 0x48,
		0xf1, 0xe2, 0xc8, 0x7c, 0x40, 0xe6, 0xc3, 0x4b, 0x33, 0x1f, 0x54, 0xec, 0x6e, 0xef, 0x69, 0x4d,
		0x7c, 0x48, 0xb1, 0xf9, 0x65, 0xfa, 0x2b, 0x94, 0x57, 0xef, 0xa3, 0xff, 0x8a, 0x07, 0x05, 0xbb,
		0x84, 0x6a, 0x40, 0x5d, 0x1d, 0x88, 0x93, 0x82, 0xb6, 0x1a, 0x90, 0x46, 0x5f, 0xdf, 0x9f, 0x81,
		0x9c, 0x89, 0x2d, 0x7d, 0x57, 0x61, 0x0d, 0xdd, 0x7c, 0x8d, 0xef, 0xe6, 0x9b, 0x66, 0xdf, 0x57,
		0x6d, 0x6b, 0xd1, 0xc8, 0x3e, 0xbe, 0x5e, 0x24, 0x02, 0x7b, 0x20, 0xee, 0xc4, 0xc0, 0x1e, 0x06,
		0xfe, 0xd0, 0xed, 0x4f, 0x97, 0x90, 0x3d, 0xf4, 0x07, 0xb2, 0x23, 0x45, 0x9a, 0xad, 0x7d, 0x7f,
		0x75, 0x25, 0x74, 0xfb, 0xfd, 0xe5, 0x1c, 0xa2, 0xdb, 0x2f, 0xba, 0xfd, 0xfe, 0xec, 0x2b, 0xa5,
		0xd6, 0xed, 0x77, 0x6a, 0xa6, 0x79, 0x3b, 0xf2, 0x67, 0x06, 0x5b, 0x48, 0xbf, 0xf5, 0x6f, 0xe2,
		0x0a, 0xe8, 0x03, 0xcc, 0x08, 0x1e, 0x54, 0xc1, 0x84, 0x72, 0xb8, 0x50, 0x0e, 0x1b, 0x6a, 0xe1,
		0x83, 0x67, 0x2c, 0x9c, 0x7a, 0x1f, 0x60, 0xb4, 0x64, 0x54, 0x08, 0x31, 0x2a, 0xa1, 0x86, 0x00,
		0x72, 0x54, 0x43, 0x0f, 0x19, 0x04, 0x91, 0x41, 0x11, 0x0d, 0x24, 0x99, 0x21, 0x49, 0x2b, 0x2b,
		0x4c, 0xe8, 0xce, 0x8e, 0x74, 0xb5, 0xe5, 0xed, 0xd0, 0x0f, 0xa2, 0x59, 0xd4, 0xf2, 0xa0, 0x3e,
		0x53, 0x6b, 0xfd, 0x65, 0x15, 0xad, 0x9f, 0x67, 0xc7, 0xd6, 0x36, 0xce, 0xfe, 0x9f, 0xb3, 0x0f,
		0xd7, 0x4e, 0xa3, 0xfe, 0xe5, 0xfa, 0x0c, 0x69, 0x62, 0xe4, 0xf8, 0xba, 0x0e, 0x67, 0x83, 0xa1,
		0x3f, 0x40, 0x9a, 0x18, 0x63, 0xfc, 0xdd, 0x84, 0xc3, 0xd3, 0x1b, 0x87, 0x4d, 0xed, 0x3d, 0xda,
		0x34, 0xb1, 0x05, 0x72, 0xce, 0x20, 0x53, 0x65, 0xbe, 0xeb, 0x12, 0x39, 0x2c, 0x2a, 0xbc, 0xc6,
		0x99, 0x37, 0xba, 0x9d, 0x4c, 0xde, 0x2e, 0xe7, 0x48, 0x13, 0xfb, 0x5f, 0x12, 0xbf, 0x0b, 0x47,
		0x08, 0x47, 0x08, 0x47, 0x08, 0x47, 0xa8, 0xc6, 0x62, 0xd4, 0x1d, 0x5a, 0x92, 0x70, 0x7e, 0x15,
		0x85, 0xd7, 0xb8, 0x8a, 0x77, 0x22, 0x67, 0x0b, 0xe9, 0x34, 0xf0, 0x47, 0x91, 0xf4, 0xfa, 0x73,
		0x6c, 0x8e, 0x9f, 0x9e, 0xfb, 0xfb, 0xae, 0xe8, 0x49, 0x4f, 0x46, 0xd2, 0xf7, 0xc2, 0xcd, 0x7f,
		0x8a, 0xff, 0x92, 0xfe, 0x59, 0x28, 0xaa, 0xd7, 0x0f, 0xb2, 0x03, 0x53, 0xbc, 0xf8, 0xf3, 0xc4,
		0x13, 0xa2, 0x24, 0xfc, 0x51, 0x28, 0x02, 0xd5, 0x78, 0x4f, 0xe4, 0xc8, 0x56, 0x9d, 0x99, 0x3f,
		0x9b, 0x4d, 0xbb, 0xfd, 0x60, 0xa9, 0xcf, 0xb5, 0x26, 0x77, 0x6a, 0x09, 0xc7, 0x36, 0xbd, 0x93,
		0x4a, 0x2f, 0x39, 0x46, 0xb5, 0x25, 0xf2, 0x60, 0xc9, 0x52, 0x71, 0x7e, 0x91, 0xa7, 0x91, 0x5b,
		0xdd, 0xb9, 0xcd, 0x42, 0x87, 0xb0, 0xc9, 0x77, 0x3e, 0x9f, 0x7c, 0x9b, 0xab, 0xa7, 0x6f, 0x7c,
		0x35, 0xff, 0xc2, 0xce, 0xf4, 0x0f, 0xf9, 0x6b, 0x7f, 0xfa, 0xbb, 0x80, 0xee, 0x61, 0x69, 0xb9,
		0x40, 0x74, 0x0f, 0xc3, 0x26, 0x1d, 0x97, 0x18, 0x19, 0x9b, 0x74, 0x84, 0xfe, 0x12, 0x9b, 0x74,
		0xdb, 0x4c, 0x1e, 0x36, 0xe9, 0xa0, 0x4d, 0x42, 0x9b, 0x84, 0x36, 0x89, 0x4d, 0xba, 0x57, 0x93,
		0x43, 0x6c, 0xd2, 0x29, 0x5d, 0x44, 0xd8, 0xa4, 0x83, 0x23, 0x84, 0x23, 0x84, 0x23, 0x84, 0x23,
		0xfc, 0x6d, 0x8b, 0xc1, 0x26, 0x1d, 0x36, 0xe9, 0x5e, 0x7b, 0x15, 0x6c, 0xd2, 0xa9, 0xb2, 0x4a,
		0x6c, 0xd2, 0x19, 0xea, 0xd4, 0xf6, 0xb0, 0x49, 0xa7, 0x21, 0x92, 0xc0, 0x26, 0x1d, 0xdf, 0x4d,
		0x3a, 0xf3, 0x9b, 0xd9, 0xbc, 0x64, 0x8f, 0x0e, 0x8d, 0x6e, 0x74, 0xdb, 0x05, 0x73, 0x7b, 0x30,
		0xb2, 0xef, 0xc9, 0x0b, 0x2c, 0x80, 0x4d, 0x4f, 0x94, 0xb7, 0x29, 0x15, 0xa3, 0x17, 0xe2, 0x7b,
		0x97, 0x57, 0x54, 0x8c, 0xfe, 0xfc, 0x0a, 0x28, 0x46, 0x4f, 0x43, 0x03, 0x42, 0x31, 0x3a, 0x11,
		0xfd, 0x45, 0x31, 0xfa, 0x16, 0x1f, 0x88, 0x62, 0x74, 0x85, 0x10, 0xa3, 0x12, 0x6a, 0x08, 0x20,
		0x87, 0x2a, 0x4a, 0x47, 0x9e, 0x4b, 0x16, 0x43, 0x4e, 0xe4, 0xb9, 0x6c, 0x33, 0x79, 0xc8, 0x73,
		0x61, 0x82, 0xaf, 0xeb, 0x70, 0x16, 0xdb, 0x7b, 0x86, 0x28, 0xa1, 0xd8, 0xde, 0xdb, 0x3c, 0x35,
		0xc8, 0x73, 0xd9, 0xe2, 0x1a, 0xc8, 0x73, 0x41, 0x9e, 0x0b, 0x1c, 0x21, 0x1c, 0x21, 0x1c, 0x21,
		0x1c, 0xe1, 0xef, 0x5b, 0x0c, 0xf2, 0x5c, 0x90, 0xe7, 0xf2, 0xda, 0xab, 0x20, 0xcf, 0x45, 0x95,
		0x55, 0x22, 0xcf, 0xc5, 0x50, 0xa7, 0xb6, 0x87, 0x3c, 0x17, 0x0d, 0x91, 0x04, 0xf2, 0x5c, 0x78,
		0xed, 0xeb, 0x3f, 0xdb, 0xb9, 0xdd, 0x8d, 0x62, 0xf4, 0xc2, 0x7c, 0x9b, 0x3f, 0x8f, 0x62, 0xf4,
		0xb4, 0x5c, 0x20, 0x8a, 0xd1, 0xb1, 0x49, 0xc7, 0x25, 0x46, 0xc6, 0x26, 0x1d, 0xa1, 0xbf, 0xc4,
		0x26, 0xdd, 0x36, 0x93, 0x87, 0x4d, 0x3a, 0x68, 0x93, 0xd0, 0x26, 0xa1, 0x4d, 0x62, 0x93, 0xee,
		0xd5, 0xe4, 0x10, 0x9b, 0x74, 0x4a, 0x17, 0x11, 0x36, 0xe9, 0xe0, 0x08, 0xe1, 0x08, 0xe1, 0x08,
		0xe1, 0x08, 0x7f, 0xdb, 0x62, 0xb0, 0x49, 0x87, 0x4d, 0xba, 0xd7, 0x5e, 0x05, 0x9b, 0x74, 0xaa,
		0xac, 0x12, 0x9b, 0x74, 0x86, 0x3a, 0xb5, 0x3d, 0x6c, 0xd2, 0x69, 0x88, 0x24, 0xb0, 0x49, 0xc7,
		0x77, 0x93, 0x6e, 0x17, 0x8a, 0xd1, 0x9f, 0xf6, 0xe8, 0x50, 0x8c, 0xae, 0xdb, 0x2e, 0x98, 0xdb,
		0x43, 0x46, 0x8b, 0xd1, 0x63, 0x0b, 0x60, 0x53, 0x8c, 0xae, 0xf5, 0x70, 0xf6, 0x94, 0xd7, 0x36,
		0xaf, 0x35, 0x9d, 0xc2, 0x12, 0xe6, 0xb1, 0x74, 0xb7, 0x5b, 0xab, 0xaf, 0x5f, 0x61, 0x5b, 0xac,
		0x2e, 0x6b, 0x10, 0x0e, 0xed, 0xb6, 0x8c, 0xb6, 0x5e, 0x56, 0x4f, 0x02, 0xc0, 0xfc, 0x03, 0xb7,
		0x5c, 0xf1, 0xe9, 0xa4, 0x3f, 0xa4, 0xa6, 0x46, 0xa6, 0xa9, 0x3a, 0x2a, 0x48, 0x67, 0x48, 0x3b,
		0xf8, 0x52, 0xa6, 0x16, 0x2a, 0x0b, 0xa0, 0xd4, 0xa4, 0x23, 0xe8, 0x45, 0xfd, 0xb4, 0xd2, 0x0b,
		0x2c, 0x37, 0x8a, 0xdc, 0xce, 0xb7, 0x49, 0x90, 0x9c, 0x82, 0xa5, 0x27, 0x96, 0xf1, 0xd2, 0xa7,
		0xa3, 0xfb, 0x09, 0x23, 0x58, 0x50, 0xad, 0xcd, 0xa0, 0xfb, 0x89, 0x49, 0x01, 0x12, 0xba, 0x9f,
		0xec, 0xa1, 0xfb, 0x09, 0x15, 0xe4, 0x50, 0xc9, 0xc2, 0x48, 0xac, 0xcc, 0xa2, 0xc6, 0xa9, 0x2c,
		0xb1, 0x52, 0xf6, 0x3d, 0x3f, 0x10, 0xa9, 0xf2, 0xa0, 0x8d, 0x46, 0xf5, 0xec, 0x5a, 0xea, 0x53,
		0x28, 0x7b, 0xee, 0x20, 0x14, 0x48, 0x19, 0x21, 0x87, 0x50, 0x42, 0x28, 0xa5, 0x82, 0x54, 0x72,
		0x68, 0x25, 0x87, 0x58, 0x5a, 0xa8, 0x55, 0x03, 0xb9, 0x8a, 0xa0, 0x37, 0x9e, 0x1a, 0xba, 0x94,
		0x91, 0xb6, 0xef, 0x0f, 0x84, 0xeb, 0x51, 0xa4, 0x8c, 0xe4, 0x77, 0x38, 0x97, 0x31, 0x1c, 0x0d,
		0x87, 0x81, 0x08, 0x43, 0x1a, 0xe7, 0xb7, 0x74, 0x35, 0xb8, 0x3f, 0xb8, 0x3f, 0xb8, 0x3f, 0xb8,
		0x3f, 0xb8, 0x3f, 0xb8, 0x3f, 0xf3, 0x83, 0xd3, 0x4c, 0x25, 0xe0, 0xcc, 0xb7, 0xeb, 0x72, 0xcf,
		0x45, 0xfc, 0x0c, 0x14, 0xc2, 0x9f, 0x87, 0xc3, 0xf7, 0x32, 0x72, 0xaa, 0xf3, 0x6f, 0x35, 0x79,
		0x8c, 0x72, 0xf7, 0xb4, 0xa8, 0x1d, 0xca, 0xdd, 0xa1, 0xca, 0x32, 0xe1, 0x4e, 0x50, 0x65, 0x09,
		0x1d, 0x1f, 0x54, 0x59, 0x84, 0xa5, 0x08, 0x4b, 0x11, 0x96, 0x22, 0x2c, 0x45, 0x58, 0xba, 0x93,
		0x61, 0x29, 0x54, 0x59, 0xb8, 0x3f, 0xb8, 0x3f, 0xb8, 0x3f, 0xb8, 0x3f, 0xb8, 0xbf, 0x1d, 0x74,
		0x7f, 0x50, 0x65, 0xb5, 0xaa, 0xb2, 0xc6, 0x57, 0x3e, 0xae, 0x11, 0x65, 0x51, 0xdf, 0xa8, 0x7b,
		0x81, 0xeb, 0x5f, 0xd8, 0x26, 0x96, 0x30, 0x26, 0x97, 0x72, 0x96, 0x4e, 0xcd, 0xf5, 0xef, 0x44,
		0x30, 0xf0, 0x5d, 0x45, 0xf5, 0x22, 0x4b, 0x9f, 0x8e, 0x7a, 0x11, 0x86, 0xe4, 0x1e, 0xf5, 0x22,
		0x7a, 0xc8, 0x39, 0xea, 0x45, 0xb6, 0x32, 0x04, 0xd4, 0x8b, 0x60, 0x67, 0x92, 0x8d, 0x7e, 0x80,
		0x9d, 0x49, 0xc2, 0xe0, 0x4f, 0xd9, 0xce, 0xa4, 0xdb, 0xbd, 0x13, 0x41, 0x24, 0x43, 0x61, 0x7f,
		0x93, 0xfd, 0x6f, 0xf6, 0xad, 0x88, 0x02, 0xd9, 0x51, 0xaf, 0xd3, 0xae, 0xbf, 0x2c, 0x04, 0x5b,
		0x1d, 0x80, 0x4a, 0x01, 0xac, 0x84, 0x00, 0x4b, 0x05, 0xb4, 0xe4, 0x80, 0x4b, 0x0e, 0xbc, 0xb4,
		0x00, 0xac, 0x4e, 0xd7, 0xdb, 0x83, 0x60, 0xfb, 0x32, 0x26, 0xb8, 0xd3, 0xfb, 0x95, 0x22, 0x22,
		0xda, 0xaa, 0x9c, 0x5f, 0x08, 0x4e, 0x0f, 0x4e, 0x0f, 0x4e, 0x0f, 0x4e, 0x0f, 0x4e, 0x0f, 0x4e,
		0x4f, 0xb3, 0xd3, 0xb3, 0x7d, 0xcf, 0x6e, 0xfb, 0x3e, 0x9d, 0xf3, 0x8b, 0x2f, 0x08, 0x27, 0x08,
		0x27, 0x08, 0x27, 0x08, 0x27, 0x08, 0x27, 0x08, 0x27, 0x48, 0xff, 0x89, 0x48, 0xd5, 0xf9, 0x8d,
		0x8c, 0x86, 0xe7, 0xbb, 0xda, 0xd9, 0x29, 0xa0, 0xac, 0xcf, 0xbf, 0xd5, 0x6e, 0x15, 0x50, 0x06,
		0x62, 0x42, 0xc0, 0xa2, 0x40, 0xf6, 0xfb, 0x22, 0x08, 0xd5, 0x6d, 0x58, 0xae, 0x5c, 0x07, 0x1b,
		0x97, 0xd8, 0xb8, 0xd4, 0xcf, 0xa6, 0xb0, 0x71, 0x49, 0xe8, 0x0a, 0x95, 0x6d, 0x5c, 0x2e, 0x41,
		0x8b, 0xfa, 0x80, 0x75, 0xf9, 0x72, 0x6a, 0xc3, 0xc8, 0x3c, 0xc2, 0x48, 0x84, 0x91, 0x08, 0x23,
		0x77, 0x23, 0x8c, 0x54, 0x05, 0x90, 0xf1, 0x05, 0x14, 0x25, 0xa5, 0x6d, 0x34, 0x4c, 0x65, 0xa1,
		0x01, 0x21, 0x54, 0x92, 0x41, 0x26, 0x25, 0x74, 0x6a, 0x80, 0x50, 0x6a, 0x28, 0xd5, 0x06, 0xa9,
		0xda, 0xa0, 0x55, 0x0f, 0xc4, 0xaa, 0x85, 0x5a, 0xc5, 0x90, 0x4b, 0x06, 0xbd, 0xf1, 0x85, 0xba,
		0x62, 0xe0, 0x3e, 0xd0, 0x2d, 0xfe, 0xa7, 0x33, 0xdb, 0x27, 0x97, 0x25, 0x5a, 0x7f, 0x6a, 0xb7,
		0x40, 0xb4, 0x01, 0xb3, 0x0e, 0x80, 0xd6, 0x08, 0xd4, 0xba, 0x00, 0x5b, 0x3b, 0x70, 0x6b, 0x07,
		0x70, 0xbd, 0x40, 0x4e, 0x03, 0xe8, 0x44, 0xc0, 0x1e, 0x4f, 0xa5, 0xf2, 0x2d, 0x9a, 0x8d, 0x16,
		0x3b, 0x92, 0x5e, 0x94, 0x2f, 0x53, 0x1a, 0xec, 0x1c, 0x7f, 0xcb, 0x84, 0x97, 0x6c, 0xb8, 0x5e,
		0x7f, 0xf2, 0x6d, 0x6f, 0x48, 0x0d, 0x84, 0x16, 0x90, 0xf6, 0xe6, 0xe7, 0x76, 0x93, 0x23, 0xa1,
		0x26, 0xc7, 0x9a, 0xb8, 0xfc, 0x57, 0x77, 0x30, 0x12, 0x1a, 0xaf, 0xff, 0x29, 0x70, 0x3b, 0x91,
		0xf4, 0xbd, 0x8f, 0xb2, 0x2f, 0x67, 0xc7, 0xa6, 0x93, 0x8f, 0x63, 0xfc, 0x56, 0xc3, 0x92, 0x73,
		0xef, 0x77, 0x7e, 0xc9, 0x95, 0x4b, 0xa5, 0xa3, 0xd2, 0x0e, 0x2f, 0xbb, 0x37, 0xd9, 0xbc, 0x5a,
		0xeb, 0x4d, 0x36, 0xbe, 0x0f, 0x01, 0x2c, 0x10, 0xed, 0x72, 0x6c, 0xa4, 0x31, 0x14, 0xbb, 0x1e,
		0x88, 0x24, 0x11, 0x49, 0x22, 0x92, 0x44, 0x24, 0x89, 0x48, 0x72, 0xad, 0xc5, 0xca, 0xae, 0xf0,
		0x22, 0x19, 0x3d, 0x04, 0xa2, 0xa7, 0x21, 0x9c, 0xcc, 0x13, 0xf2, 0x2f, 0xab, 0x36, 0xff, 0xaa,
		0xef, 0xdd, 0x50, 0x03, 0x5e, 0x2c, 0x26, 0xbc, 0xfe, 0xf5, 0xac, 0x71, 0x5e, 0xaf, 0x7e, 0x74,
		0x1a, 0x67, 0xcd, 0xb3, 0x6b, 0xe7, 0xba, 0x51, 0xfb, 0xfc, 0xf9, 0xac, 0xe1, 0x5c, 0xff, 0x79,
		0x75, 0x46, 0x8d, 0x20, 0x53, 0x22, 0x1c, 0x92, 0x47, 0xd8, 0x7a, 0xa2, 0xec, 0xa5, 0x9b, 0xf0,
		0x3f, 0xd5, 0xda, 0xb5, 0xf3, 0xa9, 0xde, 0x70, 0xde, 0x7f, 0xbe, 0xb2, 0x76, 0x21, 0xe0, 0xe3,
		0x32, 0xdf, 0xcd, 0x3f, 0x9b, 0xd7, 0x67, 0x17, 0x56, 0xc6, 0x83, 0x9d, 0x56, 0xd6, 0xdc, 0x20,
		0x76, 0xfa, 0x7e, 0xce, 0x84, 0xd4, 0x26, 0x64, 0x27, 0xae, 0xa7, 0x3f, 0x41, 0x7b, 0x39, 0xf3,
		0x76, 0xf9, 0x9f, 0x39, 0x92, 0x14, 0x8d, 0x3d, 0xcd, 0xd9, 0xdc, 0x8d, 0xc9, 0x57, 0xbe, 0x9e,
		0x4f, 0xc0, 0xd2, 0xbf, 0x94, 0x24, 0x7a, 0xd3, 0x19, 0x8c, 0x42, 0x63, 0x21, 0xd6, 0x1b, 0xb4,
		0xe8, 0x0c, 0x44, 0xfa, 0x02, 0x52, 0x87, 0xcc, 0xd4, 0x0f, 0x90, 0x3a, 0x84, 0xd4, 0x21, 0x46,
		0x7a, 0x40, 0x6c, 0x71, 0x03, 0xe1, 0xf6, 0x68, 0x34, 0x80, 0x38, 0xf6, 0xaf, 0x10, 0x5c, 0xeb,
		0x6a, 0xce, 0x91, 0xde, 0xbd, 0x9b, 0xb3, 0x92, 0x65, 0xaa, 0x02, 0x1f, 0xbd, 0x8e, 0x53, 0xa9,
		0x38, 0xfd, 0x6e, 0xe3, 0xc2, 0x53, 0xd5, 0x95, 0x7b, 0xed, 0x92, 0xa3, 0xf2, 0xc9, 0x05, 0xf8,
		0x64, 0xf8, 0x64, 0xf8, 0xe4, 0x4c, 0xf9, 0x64, 0xa4, 0xf3, 0x1a, 0x17, 0x24, 0x91, 0x07, 0x4b,
		0x3a, 0x00, 0x5a, 0x23, 0x50, 0xeb, 0x02, 0x6c, 0xed, 0xc0, 0xad, 0x1d, 0xc0, 0xf5, 0x02, 0x39,
		0x0d, 0xa0, 0x13, 0x01, 0x3b, 0x7d, 0xd0, 0x95, 0xb0, 0x58, 0xa4, 0xf3, 0x2a, 0xfb, 0x41, 0x3a,
		0x2f, 0xe9, 0xe5, 0x91, 0xce, 0x8b, 0x74, 0x5e, 0x4d, 0x4b, 0x0e, 0xe9, 0xbc, 0x99, 0xbc, 0x1a,
		0xd2, 0x79, 0x7f, 0x7f, 0x19, 0x22, 0x9d, 0x17, 0x91, 0x24, 0x22, 0x49, 0x44, 0x92, 0x88, 0x24,
		0x77, 0x35, 0x92, 0x44, 0x3a, 0x2f, 0xf1, 0x84, 0x23, 0x9d, 0x77, 0x0f, 0xe9, 0xbc, 0x48, 0xe7,
		0xcd, 0x74, 0xb0, 0x83, 0x74, 0x5e, 0x5e, 0x57, 0x40, 0x3a, 0x2f, 0x69, 0x3a, 0x2f, 0x45, 0x86,
		0xc6, 0x1e, 0xdf, 0x6c, 0x5e, 0x05, 0x47, 0xac, 0xd3, 0x99, 0x8b, 0x59, 0xcd, 0x0a, 0xff, 0x2b,
		0x1e, 0xc8, 0x9a, 0xa1, 0x9e, 0xcb, 0x30, 0xaa, 0x46, 0x91, 0xe2, 0xee, 0x88, 0x17, 0xd2, 0x3b,
		0x1b, 0x88, 0x49, 0x58, 0x15, 0xaa, 0xd5, 0x0c, 0xac, 0x0b, 0xf7, 0xfe, 0xd9, 0x95, 0xf2, 0xc7,
		0xc5, 0x62, 0xb9, 0x52, 0x2c, 0x1e, 0x56, 0x8e, 0x2a, 0x87, 0x27, 0xa5, 0x52, 0xbe, 0xac, 0x92,
		0x9b, 0x5b, 0xf5, 0xa0, 0x2b, 0x02, 0xd1, 0x7d, 0x3f, 0xb9, 0x7d, 0xde, 0x68, 0x30, 0x30, 0x6a,
		0xd5, 0x11, 0xc1, 0x3d, 0x73, 0x98, 0xb7, 0x94, 0xa6, 0x14, 0x32, 0x04, 0x76, 0x0b, 0x67, 0x51,
		0xf0, 0x37, 0x1e, 0x76, 0x46, 0x93, 0xb1, 0x33, 0x29, 0x96, 0xcc, 0x63, 0x17, 0x8e, 0xa6, 0x50,
		0x93, 0xdd, 0xac, 0x34, 0x9b, 0x59, 0xf9, 0x41, 0x14, 0x05, 0x1c, 0x44, 0xf1, 0xfc, 0x12, 0x38,
		0x88, 0xe2, 0xc5, 0x4e, 0x00, 0x07, 0x51, 0xe0, 0x04, 0xfd, 0x6d, 0x26, 0x0f, 0xe7, 0x28, 0xea,
		0x06, 0x56, 0x42, 0x80, 0xa5, 0x02, 0x5a, 0x72, 0xc0, 0x25, 0x07, 0x5e, 0x5a, 0x00, 0x36, 0x53,
		0x53, 0xc2, 0x39, 0x8a, 0x3a, 0x63, 0x57, 0x9c, 0xa0, 0x0f, 0xa7, 0x07, 0xa7, 0x07, 0xa7, 0x07,
		0xa7, 0x07, 0xa7, 0x07, 0xa7, 0xb7, 0xb5, 0xd3, 0xc3, 0x09, 0xfa, 0x70, 0x82, 0x70, 0x82, 0x70,
		0x82, 0x70, 0x82, 0x70, 0x82, 0xcc, 0x9d, 0x20, 0x76, 0x2d, 0xb5, 0xee, 0x5a, 0xaa, 0x4a, 0xda,
		0xd2, 0xb9, 0x59, 0xa9, 0x20, 0x13, 0x2b, 0xc5, 0x4d, 0xca, 0x37, 0x8c, 0x16, 0xba, 0xaa, 0x05,
		0xae, 0x7f, 0x61, 0x5b, 0xa9, 0xee, 0x05, 0xeb, 0x5a, 0xca, 0xe9, 0x2c, 0xe2, 0xed, 0x97, 0xdc,
		0x76, 0x9f, 0xb0, 0xe5, 0x62, 0x4d, 0x7b, 0x91, 0x6a, 0x59, 0x9c, 0x29, 0xac, 0x47, 0xe2, 0x75,
		0xb8, 0xdd, 0xda, 0x7b, 0xfd, 0x8a, 0xd9, 0x62, 0xb5, 0x58, 0xb7, 0xc3, 0x41, 0xb8, 0xf5, 0x1a,
		0x89, 0xe9, 0xda, 0xf4, 0xd3, 0xb6, 0x5c, 0xbb, 0xe9, 0xe4, 0x64, 0xa4, 0x16, 0x38, 0xa6, 0x19,
		0x20, 0x2a, 0x08, 0x04, 0xd3, 0x0e, 0xf8, 0x94, 0x05, 0x76, 0xca, 0x02, 0x38, 0x35, 0x81, 0x9a,
		0x5e, 0xfc, 0x4e, 0x2b, 0xe7, 0xc1, 0x92, 0xfd, 0xa1, 0x3d, 0xe8, 0x0e, 0xed, 0xf0, 0xc1, 0x4b,
		0x2f, 0xb5, 0xe1, 0xa9, 0x26, 0xf2, 0xf9, 0xa7, 0xa7, 0x74, 0x37, 0xd3, 0x4d, 0xc9, 0x4a, 0x5d,
		0x3f, 0x52, 0xa1, 0x17, 0x29, 0xd4, 0x87, 0x54, 0xe9, 0x41, 0xca, 0xf5, 0x1f, 0xe5, 0x7a, 0x8f,
		0x5a, 0x7d, 0x87, 0x57, 0xcc, 0x92, 0x76, 0x0a, 0x95, 0xd5, 0x59, 0x58, 0x95, 0xa2, 0x64, 0x4f,
		0x25, 0xe7, 0x1c, 0x28, 0xcf, 0xf6, 0x3c, 0x44, 0xb6, 0x27, 0x01, 0xf4, 0x90, 0x41, 0x10, 0x19,
		0x14, 0xd1, 0x40, 0x92, 0x19, 0xfa, 0xa1, 0xb2, 0x6c, 0x4f, 0xe1, 0xb9, 0xed, 0x81, 0xe8, 0xaa,
		0xdf, 0xdf, 0x5b, 0x5c, 0x48, 0xfd, 0xbe, 0xde, 0x64, 0x25, 0x62, 0x5b, 0x8f, 0x1c, 0x3b, 0x09,
		0x31, 0x94, 0x0a, 0x4b, 0xc9, 0x31, 0x95, 0x1c, 0x5b, 0x69, 0x31, 0x56, 0x0d, 0xd6, 0x2a, 0xc2,
		0xdc, 0x78, 0x6a, 0xb0, 0xad, 0xa7, 0xf1, 0xc6, 0xaa, 0xc8, 0x6d, 0x19, 0xfa, 0x61, 0x64, 0x87,
		0x22, 0x0c, 0xa5, 0xef, 0xd9, 0xa3, 0xa1, 0xad, 0xb6, 0xff, 0x79, 0x7c, 0x77, 0xd7, 0x5f, 0x16,
		0x8e, 0x0a, 0x8e, 0x0a, 0x8e, 0x0a, 0x8e, 0xca, 0x28, 0x47, 0xa5, 0xbc, 0x7f, 0x38, 0x41, 0xbf,
		0x70, 0xa2, 0xfe, 0xe0, 0x04, 0xed, 0x7c, 0x28, 0xfb, 0x7f, 0x53, 0xb7, 0x3f, 0x25, 0xee, 0xef,
		0xad, 0xa3, 0xb1, 0x32, 0x45, 0xa3, 0x5e, 0xca, 0x7e, 0xdd, 0xba, 0x96, 0x08, 0x61, 0x3f, 0x6e,
		0x2d, 0xcb, 0xc4, 0xd0, 0x8e, 0x50, 0x2d, 0x24, 0x10, 0xa6, 0x41, 0x7b, 0xb2, 0x94, 0x40, 0x78,
		0x3b, 0x1c, 0x84, 0xb9, 0xe7, 0xbb, 0xa4, 0xea, 0x4e, 0x70, 0x26, 0xcb, 0x75, 0xb9, 0x18, 0x0e,
		0x42, 0xa7, 0xd6, 0x1f, 0x9e, 0x77, 0x87, 0xcd, 0x87, 0xff, 0x8f, 0xbd, 0xbf, 0xef, 0x69, 0x23,
		0xd9, 0xba, 0xff, 0xe1, 0xff, 0xf3, 0x2a, 0x90, 0x75, 0x2e, 0x29, 0x9c, 0x33, 0x1d, 0x63, 0x62,
		0x20, 0x20, 0xdd, 0x3a, 0x32, 0xc1, 0xc9, 0xf8, 0x8c, 0x03, 0xc8, 0x38, 0xb9, 0x66, 0xae, 0x84,
		0xb1, 0x1a, 0xbb, 0x0c, 0x7d, 0xd2, 0xb4, 0x7d, 0x77, 0xb7, 0x99, 0xf0, 0xcd, 0xf0, 0xde, 0x7f,
		0xf2, 0x23, 0x18, 0x43, 0xc2, 0x43, 0x57, 0xd5, 0xae, 0xf6, 0x07, 0x8d, 0xc0, 0x78, 0x82, 0xbb,
		0xdc, 0x5e, 0xb5, 0xf6, 0x5a, 0xbb, 0x76, 0xed, 0x8a, 0xda, 0x5a, 0xce, 0x64, 0xa6, 0xc3, 0x49,
		0xd6, 0x69, 0x10, 0x3a, 0x9c, 0xb0, 0xe6, 0x25, 0xd1, 0xee, 0xb2, 0xe6, 0xc5, 0x9a, 0xd7, 0xcf,
		0x6f, 0x10, 0x6b, 0x5e, 0x96, 0xb9, 0xd3, 0x20, 0x87, 0x9a, 0xe2, 0x52, 0xe3, 0x9c, 0x6a, 0x9c,
		0x5b, 0xcd, 0x72, 0xac, 0x5e, 0x83, 0xc5, 0x9a, 0xd7, 0x23, 0xc4, 0x1e, 0x6b, 0x5e, 0xac, 0x79,
		0x11, 0xa8, 0x08, 0x54, 0x04, 0x2a, 0x02, 0xd5, 0xe3, 0x67, 0x0c, 0x6b, 0x5e, 0x0f, 0xfe, 0x62,
		0xcd, 0xeb, 0x59, 0x97, 0x63, 0xcd, 0x2b, 0x1b, 0x88, 0xb0, 0xe6, 0xe5, 0x3c, 0x4c, 0x58, 0xf3,
		0xd2, 0xeb, 0x34, 0x58, 0xf3, 0xb2, 0xb7, 0xe6, 0xe5, 0x7c, 0xc7, 0x8c, 0xdb, 0x4b, 0x5e, 0xb4,
		0xcb, 0xb0, 0x0d, 0x6d, 0xcb, 0x90, 0x76, 0xb1, 0x57, 0xc6, 0x2d, 0x10, 0xd3, 0x28, 0xc3, 0xf9,
		0x46, 0x19, 0x19, 0x74, 0x5b, 0x30, 0x8e, 0x40, 0x17, 0x7b, 0x64, 0x44, 0x49, 0x9c, 0x5d, 0x8b,
		0x8c, 0xe1, 0x8b, 0xd1, 0x21, 0xc3, 0x60, 0xda, 0x8e, 0x0e, 0x19, 0x74, 0xc8, 0xf8, 0xc1, 0x0b,
		0x65, 0xbc, 0x95, 0x5d, 0xcf, 0x16, 0x76, 0xba, 0x62, 0xd0, 0x15, 0x63, 0x85, 0xae, 0x18, 0xd9,
		0x5a, 0x93, 0xcc, 0xbb, 0x62, 0xe8, 0x2a, 0xb7, 0xd1, 0x5c, 0x66, 0xa3, 0xbb, 0x55, 0xb4, 0xa6,
		0x94, 0x21, 0x7d, 0x37, 0xcc, 0x92, 0x9b, 0x31, 0x92, 0x33, 0x46, 0x76, 0x66, 0x48, 0xcf, 0x8d,
		0x14, 0xa4, 0xb6, 0xe5, 0x45, 0x03, 0xf5, 0x2f, 0x9a, 0xea, 0x5e, 0x48, 0xc9, 0x09, 0xce, 0x7d,
		0x44, 0x49, 0x9c, 0xfd, 0x5e, 0x0a, 0x63, 0x99, 0x90, 0xfd, 0x24, 0xce, 0x74, 0xdf, 0x44, 0x06,
		0x69, 0xb8, 0x4c, 0xf2, 0x48, 0x59, 0xee, 0x8f, 0xd0, 0xb2, 0x2f, 0x42, 0x9b, 0x91, 0x5a, 0xc7,
		0x48, 0x61, 0xa4, 0x30, 0x52, 0x18, 0x29, 0x8c, 0x14, 0x46, 0x0a, 0x23, 0x85, 0x91, 0xc2, 0x48,
		0x61, 0xa4, 0x5c, 0x31, 0x52, 0x59, 0x17, 0xe8, 0x18, 0xf5, 0x51, 0x19, 0x16, 0xe3, 0x50, 0xcd,
		0x60, 0x17, 0x88, 0x2e, 0x15, 0x33, 0xec, 0x27, 0xb1, 0x8b, 0xb5, 0x0c, 0xb1, 0xea, 0xaa, 0x58,
		0x45, 0x6d, 0xe5, 0x9d, 0xf8, 0x51, 0xe7, 0xaf, 0xa0, 0x33, 0xfa, 0x6c, 0x33, 0xaa, 0x6d, 0xb8,
		0xeb, 0xc5, 0xa9, 0x75, 0x30, 0x28, 0x61, 0xa9, 0x75, 0xa0, 0xd6, 0xe1, 0x07, 0x2f, 0x44, 0xad,
		0x03, 0x29, 0x3a, 0x52, 0x74, 0xa4, 0xe8, 0x32, 0x78, 0x41, 0x1d, 0x3a, 0xc2, 0xa0, 0xae, 0x20,
		0xb5, 0x46, 0x6a, 0x8d, 0xd4, 0x1a, 0xa9, 0xb5, 0x5b, 0x88, 0x1f, 0x04, 0x51, 0xfa, 0x7a, 0x5d,
		0x63, 0x66, 0x6d, 0x4b, 0xc3, 0x4b, 0xeb, 0xdd, 0xea, 0xac, 0x71, 0xc3, 0xb9, 0x89, 0xad, 0xcd,
		0x86, 0xf6, 0xab, 0x9a, 0xda, 0xca, 0x6c, 0x72, 0x6f, 0xaa, 0xc6, 0xad, 0xcb, 0x46, 0xb6, 0x2c,
		0x9b, 0xfe, 0xe8, 0xcb, 0xeb, 0xdb, 0xe5, 0xed, 0xcd, 0xad, 0xf5, 0xed, 0x8d, 0x1c, 0x61, 0xc0,
		0x91, 0xfd, 0xbd, 0xc7, 0x2c, 0x58, 0x3c, 0x44, 0x43, 0xe4, 0x61, 0xc1, 0xe2, 0x0e, 0x33, 0xe0,
		0x70, 0x25, 0x58, 0x63, 0xfa, 0x6e, 0x76, 0xa7, 0x6f, 0x86, 0xc2, 0xb0, 0x87, 0xaa, 0x35, 0x0a,
		0xc3, 0xc8, 0x3a, 0x91, 0x75, 0x22, 0xeb, 0x44, 0xd6, 0x89, 0xac, 0x13, 0x59, 0x27, 0xb2, 0x4e,
		0x64, 0x9d, 0xc8, 0x3a, 0x91, 0x75, 0x22, 0xeb, 0x44, 0xd6, 0x89, 0xac, 0x13, 0x59, 0x27, 0xb2,
		0x4e, 0xba, 0xb3, 0x4e, 0xce, 0x96, 0xcd, 0xde, 0x91, 0x74, 0xa2, 0x8a, 0x56, 0x17, 0x5e, 0xad,
		0xe3, 0xd4, 0xa5, 0xaa, 0xda, 0x45, 0x64, 0xba, 0x58, 0x64, 0x9b, 0xa8, 0xd3, 0xa1, 0x69, 0xf2,
		0xe2, 0xde, 0x20, 0x0d, 0xa2, 0xd3, 0xec, 0x0a, 0x6c, 0x6f, 0xbf, 0x30, 0xc5, 0xb5, 0x0f, 0x49,
		0x27, 0x64, 0x53, 0x58, 0x4e, 0x69, 0xed, 0xad, 0x64, 0xc0, 0x73, 0x0b, 0xe0, 0x57, 0x28, 0xac,
		0xfd, 0x19, 0x78, 0x29, 0xac, 0x95, 0x46, 0x03, 0xba, 0x73, 0x89, 0xf9, 0x5b, 0xe0, 0xc8, 0x82,
		0x26, 0x64, 0x1a, 0x1b, 0xf6, 0xbd, 0x6b, 0x4d, 0x79, 0x38, 0xbf, 0x8c, 0x91, 0x29, 0xe1, 0xe8,
		0x26, 0x1e, 0x63, 0x04, 0x64, 0x8c, 0x88, 0x4c, 0x10, 0x92, 0x9e, 0xdc, 0x12, 0x7b, 0xd2, 0xef,
		0x50, 0x2d, 0xa5, 0x65, 0x38, 0x61, 0x3a, 0x3e, 0x3d, 0xd1, 0x78, 0xc0, 0xf4, 0xf0, 0xd5, 0xa1,
		0x7e, 0xa8, 0x1f, 0xea, 0x87, 0xfa, 0x33, 0x43, 0x7b, 0xa8, 0xfc, 0x6e, 0xac, 0xba, 0x3a, 0xa9,
		0x5f, 0xc7, 0xfa, 0xf5, 0xe1, 0x24, 0x1f, 0xfb, 0xea, 0x55, 0x71, 0xf1, 0xbf, 0x5b, 0x79, 0xb6,
		0xe2, 0x90, 0x39, 0x93, 0xd1, 0xf7, 0x49, 0xa9, 0x69, 0x31, 0xec, 0xb5, 0xfd, 0xd0, 0x0b, 0x3a,
		0x85, 0xa5, 0x88, 0x4a, 0xa1, 0xd6, 0xa8, 0x14, 0x12, 0x95, 0x88, 0x4a, 0x44, 0x25, 0xa2, 0x12,
		0x51, 0xe9, 0x91, 0x51, 0x29, 0x1c, 0x45, 0xa5, 0xd0, 0x9d, 0xa8, 0x44, 0x61, 0x42, 0xd6, 0x0b,
		0xbe, 0xb7, 0x41, 0xe1, 0xee, 0x56, 0x98, 0xa3, 0xf1, 0x3b, 0x69, 0x8c, 0xdf, 0x08, 0xdb, 0x60,
		0x1e, 0x2c, 0xa0, 0xd8, 0x06, 0x23, 0x53, 0x21, 0xb1, 0x46, 0x64, 0x43, 0x01, 0xb1, 0x46, 0xf4,
		0xbc, 0x59, 0xc0, 0x1a, 0x11, 0x96, 0x0c, 0x4b, 0x86, 0x25, 0xcb, 0x1c, 0xed, 0xac, 0x11, 0x65,
		0x94, 0x8d, 0x63, 0x8d, 0x08, 0xea, 0x87, 0xfa, 0xa1, 0x7e, 0xb2, 0x71, 0xac, 0x11, 0xc9, 0x89,
		0x4a, 0xac, 0x11, 0x11, 0x95, 0x88, 0x4a, 0x44, 0x25, 0xa2, 0x12, 0x6b, 0x44, 0xf6, 0x5f, 0x89,
		0x35, 0xa2, 0x1f, 0xac, 0x11, 0x39, 0xbb, 0x71, 0xf5, 0xd6, 0x12, 0x11, 0x9b, 0x56, 0x75, 0xe1,
		0xd4, 0x2a, 0x3e, 0x5d, 0xda, 0xb0, 0x3a, 0x8f, 0x48, 0x27, 0x37, 0xab, 0x66, 0xb2, 0x2a, 0x99,
		0xe9, 0x6a, 0x64, 0xe6, 0x1b, 0x53, 0xd7, 0x39, 0xf5, 0x45, 0x82, 0x9a, 0xe6, 0xd4, 0x97, 0x47,
		0xbc, 0xa5, 0xcc, 0x36, 0xa7, 0xfa, 0x83, 0xf4, 0x4c, 0x45, 0x69, 0xd0, 0x1e, 0x85, 0x07, 0xaf,
		0x7d, 0xa6, 0xda, 0x5f, 0xb3, 0xaf, 0x42, 0xb8, 0xf3, 0x2a, 0x59, 0x2d, 0xa2, 0x5e, 0x9f, 0xab,
		0x3a, 0xc4, 0x4c, 0xc6, 0xb5, 0x0e, 0x6b, 0x1c, 0x34, 0x23, 0xd9, 0xe3, 0xd3, 0xf2, 0xd3, 0x25,
		0xbf, 0x94, 0xb9, 0x6b, 0xd7, 0xb8, 0x7c, 0x98, 0xf1, 0xb2, 0xa1, 0x8c, 0x22, 0xb3, 0xae, 0x9f,
		0xa4, 0x5e, 0x37, 0xec, 0xf5, 0x3a, 0x59, 0x74, 0x1e, 0x59, 0xf8, 0x14, 0xe6, 0x5f, 0x1e, 0x7e,
		0x87, 0xdf, 0xe1, 0x77, 0xf8, 0x1d, 0x7e, 0x37, 0xc6, 0xef, 0x41, 0xd0, 0xf1, 0xd2, 0xf0, 0x22,
		0x7b, 0x66, 0x9f, 0xbe, 0x70, 0xf6, 0x9c, 0xde, 0xf5, 0xc3, 0x04, 0x52, 0x87, 0xd4, 0x21, 0x75,
		0x48, 0x1d, 0x52, 0xbf, 0x93, 0xd4, 0x27, 0xd9, 0x66, 0x0d, 0xac, 0x3e, 0x7d, 0xe5, 0xec, 0x69,
		0x7d, 0x0d, 0x4a, 0x87, 0xd2, 0xa1, 0xf4, 0x65, 0xa3, 0xf4, 0x24, 0x8d, 0xb3, 0xb3, 0xfe, 0x73,
		0x8c, 0xfe, 0x26, 0x47, 0x8c, 0x1e, 0xaa, 0x0b, 0x15, 0x7a, 0x6d, 0xbf, 0xef, 0x9f, 0x04, 0x61,
		0x90, 0x5e, 0x66, 0xcf, 0xec, 0x0b, 0x57, 0xc8, 0x9e, 0xe1, 0xeb, 0xd5, 0x4f, 0xd5, 0x7a, 0xab,
		0xd4, 0x5a, 0x87, 0xe9, 0x61, 0x7a, 0x98, 0x7e, 0xd9, 0x98, 0x7e, 0xcc, 0x30, 0xe9, 0xf0, 0xf5,
		0x35, 0xb0, 0x7d, 0x39, 0xc3, 0xd7, 0xac, 0x46, 0x83, 0xf3, 0xe1, 0x3d, 0xb8, 0xca, 0x51, 0x04,
		0x39, 0xf7, 0xbf, 0x79, 0xaa, 0x7d, 0xde, 0xf7, 0xfa, 0x7e, 0x7a, 0x96, 0x64, 0x1f, 0x3f, 0x6e,
		0xbd, 0x3e, 0x0c, 0x0f, 0xc3, 0xc3, 0xf0, 0x4b, 0xc6, 0xf0, 0x83, 0x20, 0x4a, 0xdf, 0x68, 0x20,
		0xf7, 0x0c, 0xcf, 0x22, 0xd2, 0x74, 0xd0, 0x98, 0x86, 0xb2, 0x72, 0x9d, 0x07, 0x8b, 0x69, 0x3e,
		0x55, 0x4a, 0xf7, 0x41, 0x62, 0x26, 0x0e, 0x8f, 0xd2, 0x70, 0x70, 0x98, 0xd6, 0x03, 0xc3, 0x4c,
		0x7d, 0xa4, 0xeb, 0x1b, 0x1b, 0x0e, 0x7f, 0xa8, 0x42, 0x37, 0x29, 0x1c, 0xe7, 0x4b, 0x68, 0x06,
		0xe7, 0x83, 0x73, 0xcf, 0x8f, 0x95, 0xef, 0xf9, 0x9d, 0x4e, 0xac, 0x92, 0x44, 0xe9, 0x11, 0x9c,
		0x77, 0x5d, 0x27, 0xfb, 0xb4, 0xc5, 0x6b, 0xc4, 0x2c, 0x62, 0x16, 0x31, 0x8b, 0x98, 0x45, 0xcc,
		0x22, 0x66, 0x11, 0xb3, 0x88, 0x59, 0xc4, 0xec, 0xd2, 0x88, 0xd9, 0x48, 0xa5, 0xd9, 0x2b, 0xd7,
		0xe1, 0x8b, 0x22, 0x29, 0x91, 0x94, 0x48, 0xca, 0x25, 0x93, 0x94, 0xd9, 0x4d, 0xfc, 0x95, 0xb9,
		0x42, 0x87, 0x0c, 0x5f, 0xf3, 0xd0, 0x4f, 0x53, 0x15, 0x47, 0x99, 0x6b, 0xca, 0xc2, 0x9f, 0x9f,
		0x7d, 0xaf, 0x5b, 0xf1, 0xde, 0xad, 0x79, 0xdb, 0xc7, 0xdf, 0xd7, 0xaf, 0x5e, 0x7e, 0xf9, 0xf2,
		0xea, 0xe6, 0x33, 0xe5, 0xab, 0xd5, 0xef, 0xaf, 0x7f, 0xd9, 0xbe, 0xba, 0xf5, 0xf4, 0xfa, 0xd5,
		0x3f, 0xb2, 0x83, 0xd9, 0x71, 0x96, 0xf7, 0xe9, 0xe0, 0xa8, 0xf6, 0x7b, 0xae, 0x6f, 0x96, 0xa8,
		0x39, 0x59, 0x0f, 0x92, 0xb4, 0x92, 0xa6, 0x19, 0x37, 0xbf, 0xfd, 0x10, 0x44, 0xd5, 0x50, 0x0d,
		0x69, 0x2d, 0xc9, 0x56, 0x6c, 0x0e, 0xc5, 0xf1, 0x8d, 0x57, 0x2e, 0xbd, 0x29, 0x97, 0x37, 0xb7,
		0xca, 0xe5, 0xb5, 0xad, 0xd7, 0x5b, 0x6b, 0xdb, 0x1b, 0x1b, 0xa5, 0xcd, 0x52, 0x96, 0x2e, 0xf0,
		0x20, 0xee, 0xa8, 0x58, 0x75, 0x76, 0x2f, 0x0b, 0x3b, 0x2b, 0xd1, 0x20, 0x0c, 0x73, 0xa4, 0xbf,
		0xfa, 0xbd, 0x40, 0xcf, 0xf6, 0x84, 0xe9, 0x0b, 0xb3, 0x3d, 0x01, 0x7d, 0x87, 0xbe, 0x43, 0xdf,
		0x65, 0x82, 0xd8, 0x65, 0xd8, 0x9e, 0x40, 0x5b, 0xa2, 0x27, 0xb7, 0x25, 0xca, 0xa8, 0x4d, 0x96,
		0xb9, 0x66, 0x44, 0xcf, 0xef, 0x87, 0x65, 0xa7, 0x07, 0x51, 0x1a, 0x9c, 0xab, 0x38, 0xc9, 0xae,
		0x09, 0xd1, 0xe4, 0xf5, 0x84, 0x75, 0x21, 0x5a, 0xa3, 0x0b, 0x91, 0x84, 0x18, 0x4d, 0x17, 0xa2,
		0xc7, 0xe8, 0xe4, 0xac, 0xba, 0x10, 0xb5, 0xa7, 0xb3, 0x20, 0x63, 0x5f, 0x90, 0xe9, 0x79, 0x57,
		0xda, 0x8e, 0x3f, 0x42, 0xbe, 0x23, 0xdf, 0x97, 0x55, 0xbe, 0x67, 0x7e, 0x04, 0x52, 0x98, 0xf4,
		0xbd, 0x30, 0xe8, 0xaa, 0x61, 0x94, 0xf7, 0x82, 0x28, 0x55, 0xf1, 0x85, 0x1f, 0xea, 0x6b, 0x3e,
		0x7e, 0xf7, 0xe5, 0x32, 0xc6, 0xc3, 0x8d, 0x7c, 0x44, 0x69, 0x7d, 0x6d, 0x8d, 0x66, 0xe7, 0x46,
		0x9a, 0x9d, 0x67, 0xcc, 0x77, 0xba, 0x79, 0xcf, 0x18, 0xff, 0x19, 0xe3, 0x41, 0x33, 0x7c, 0x98,
		0x2d, 0x2f, 0x66, 0xcc, 0x8f, 0xfa, 0xd2, 0x1c, 0x0b, 0x88, 0x1f, 0x04, 0x51, 0x5a, 0xda, 0xd4,
		0xd8, 0xef, 0x7c, 0x53, 0xc3, 0x4b, 0xeb, 0x29, 0x99, 0x9a, 0x7e, 0xe9, 0x99, 0xa0, 0x2b, 0xba,
		0x4b, 0xa8, 0x34, 0x13, 0xfb, 0xc2, 0x65, 0x34, 0x97, 0x54, 0xcd, 0xae, 0x63, 0xa0, 0x0a, 0x47,
		0xd3, 0xf4, 0x9d, 0xff, 0xe8, 0x35, 0x96, 0x5a, 0xd9, 0xfa, 0xe8, 0x37, 0x37, 0x36, 0x5e, 0x6f,
		0xe4, 0xe8, 0xe3, 0x7f, 0xe1, 0xc6, 0xab, 0x1e, 0x2f, 0xc1, 0xe1, 0x41, 0x43, 0x85, 0x1d, 0xab,
		0x6e, 0xac, 0x92, 0x33, 0x43, 0x7a, 0x7e, 0xe1, 0x6a, 0xe8, 0x6d, 0xf4, 0x36, 0x7a, 0x1b, 0xbd,
		0x8d, 0xde, 0x46, 0x6f, 0xa3, 0xb7, 0xd1, 0xdb, 0xe8, 0x6d, 0xf4, 0xb6, 0x2c, 0xbd, 0xcd, 0xb1,
		0x68, 0x59, 0xd7, 0x77, 0x8c, 0xab, 0x04, 0x8a, 0x99, 0xae, 0x20, 0xae, 0x98, 0xac, 0xf7, 0x68,
		0x8e, 0xde, 0x40, 0x6b, 0xe2, 0x0a, 0xf2, 0xd4, 0x3d, 0x2f, 0xe9, 0x7b, 0xa7, 0x2a, 0x52, 0x71,
		0xb6, 0x10, 0x9b, 0xb3, 0x80, 0x37, 0x5e, 0x9f, 0xc5, 0x63, 0x81, 0xe6, 0x8e, 0xc5, 0x63, 0x3b,
		0xe6, 0x2d, 0xe7, 0x8b, 0xc7, 0x19, 0xd7, 0xa1, 0x2c, 0x4c, 0x84, 0xcc, 0xa3, 0x89, 0x06, 0x6a,
		0x21, 0x9f, 0x44, 0x3e, 0x89, 0x7c, 0x52, 0xd6, 0xf9, 0xa4, 0xac, 0xa9, 0x6a, 0x4e, 0x0d, 0x75,
		0x83, 0x38, 0x49, 0xbd, 0xbf, 0xfc, 0x20, 0xd5, 0x97, 0x21, 0xbf, 0x53, 0x26, 0xdd, 0x75, 0xe1,
		0x5f, 0x9c, 0xec, 0x21, 0xa0, 0x8b, 0xec, 0x4c, 0x90, 0x9e, 0x41, 0xf2, 0x33, 0x45, 0x82, 0xc6,
		0xc9, 0xd0, 0x38, 0x29, 0x9a, 0x25, 0x47, 0xcd, 0x89, 0x16, 0x4d, 0x73, 0x46, 0x5b, 0x12, 0x7e,
		0x61, 0xc6, 0x0c, 0x82, 0x28, 0xdd, 0x2c, 0xeb, 0x9c, 0x30, 0x13, 0xfe, 0x7a, 0xa3, 0xf1, 0x12,
		0x7a, 0x93, 0xf3, 0xd3, 0x2f, 0xbd, 0x13, 0x7e, 0xc5, 0x54, 0xb2, 0xde, 0x50, 0x60, 0x59, 0xb8,
		0x9c, 0xa1, 0xe4, 0xfd, 0xec, 0x7a, 0x06, 0xb3, 0xb8, 0x9a, 0xe9, 0x60, 0x1e, 0x22, 0x06, 0x92,
		0xfa, 0xb6, 0x21, 0xa2, 0x77, 0xa3, 0xb9, 0x38, 0xd4, 0xbc, 0x70, 0xf3, 0xd5, 0x8f, 0x1d, 0x59,
		0xbb, 0xd0, 0xd1, 0x35, 0x6c, 0xe8, 0x01, 0xce, 0xfd, 0x6f, 0x36, 0xac, 0xc7, 0xe2, 0x65, 0x31,
		0x1e, 0x18, 0x0f, 0x8c, 0x07, 0xc6, 0x03, 0xe3, 0x81, 0xf1, 0xc0, 0x78, 0x60, 0x3c, 0x30, 0x1e,
		0x18, 0x0f, 0x8c, 0x47, 0x7e, 0x8d, 0x47, 0xa2, 0xda, 0xbd, 0xa8, 0x63, 0xc3, 0x7b, 0xdc, 0x79,
		0x65, 0xec, 0x07, 0xf6, 0x03, 0xfb, 0x81, 0xfd, 0xc0, 0x7e, 0x60, 0x3f, 0xb0, 0x1f, 0xd8, 0x0f,
		0xec, 0x07, 0xf6, 0x03, 0xfb, 0x21, 0xc0, 0x7e, 0x88, 0xae, 0x0b, 0xd3, 0xb4, 0x57, 0x62, 0xf6,
		0xfa, 0x36, 0xf6, 0x4c, 0xcc, 0x17, 0xd0, 0x17, 0xb5, 0x14, 0xbd, 0xae, 0x58, 0xd8, 0x4a, 0x51,
		0x4f, 0xfa, 0xef, 0x67, 0x6f, 0x2b, 0xd3, 0x8d, 0x15, 0xd9, 0x63, 0xf5, 0x2a, 0xd3, 0x1d, 0x2b,
		0x7e, 0xaa, 0xf4, 0x15, 0x45, 0x67, 0xd5, 0x49, 0xf5, 0xae, 0xd0, 0xa5, 0xad, 0x26, 0x7a, 0x9d,
		0x9a, 0x68, 0x83, 0xb6, 0x98, 0x9a, 0xe8, 0x3c, 0xc6, 0x3e, 0x6d, 0x35, 0xd1, 0x7e, 0xc7, 0xef,
		0xa7, 0xc1, 0x85, 0xf2, 0x46, 0x01, 0x49, 0x7f, 0x4e, 0xf0, 0xd6, 0xf5, 0xc8, 0x04, 0x9a, 0xa6,
		0x38, 0x83, 0x54, 0x67, 0x8a, 0xf2, 0x8c, 0x53, 0x9f, 0x71, 0x0a, 0x34, 0x4b, 0x85, 0x7a, 0x0d,
		0x91, 0xfb, 0x99, 0xc0, 0x79, 0x0e, 0xf3, 0xd2, 0xe1, 0x85, 0xf5, 0xa7, 0x05, 0x4b, 0x65, 0x8d,
		0xd7, 0xa8, 0x46, 0x83, 0xf3, 0xe1, 0xcd, 0xbb, 0x5a, 0xf2, 0x85, 0x32, 0xb6, 0x07, 0x11, 0x1c,
		0x09, 0x8e, 0x04, 0x47, 0x82, 0xe3, 0x53, 0x67, 0x0c, 0xcb, 0x64, 0x0f, 0xfe, 0x62, 0x99, 0xec,
		0x59, 0x97, 0x63, 0x99, 0x2c, 0x1b, 0x88, 0xb0, 0x4c, 0x96, 0x37, 0xd4, 0xb0, 0x4c, 0xe6, 0xa4,
		0xf9, 0x60, 0x7b, 0x10, 0xc6, 0x03, 0xe3, 0x81, 0xf1, 0xc0, 0x78, 0x60, 0x3c, 0x30, 0x1e, 0x18,
		0x0f, 0x8c, 0x07, 0xc6, 0x03, 0xe3, 0x81, 0xf1, 0xd0, 0x6e, 0x3c, 0xd8, 0x1e, 0x84, 0xfd, 0xc0,
		0x7e, 0x60, 0x3f, 0xb0, 0x1f, 0xd8, 0x0f, 0xec, 0x07, 0xf6, 0x03, 0xfb, 0x81, 0xfd, 0xc0, 0x7e,
		0x60, 0x3f, 0xb4, 0xbe, 0x22, 0xdb, 0x83, 0x1e, 0xbd, 0x3d, 0x48, 0xc7, 0xf6, 0x8f, 0x15, 0xeb,
		0xbb, 0x83, 0x8e, 0x46, 0xef, 0x8a, 0xe3, 0x82, 0xec, 0x61, 0x5c, 0x00, 0xb6, 0x1d, 0x3e, 0x36,
		0x68, 0x0e, 0xcd, 0x79, 0x3a, 0x3d, 0x28, 0xe9, 0x77, 0xb3, 0x3f, 0x32, 0x68, 0xf8, 0xa2, 0x9c,
		0x13, 0x24, 0x30, 0x41, 0xc3, 0x39, 0x41, 0x76, 0x12, 0x2c, 0x9c, 0x13, 0xf4, 0xac, 0x89, 0xc0,
		0x39, 0x41, 0xec, 0x89, 0xb5, 0x4e, 0x41, 0xc6, 0xa8, 0xc8, 0x0c, 0x25, 0xb9, 0x61, 0xf8, 0xb4,
		0xed, 0x89, 0x4d, 0xfa, 0xdd, 0xc9, 0x7e, 0x1c, 0x73, 0x8b, 0x61, 0x77, 0x5c, 0x93, 0x65, 0x30,
		0xd3, 0x54, 0x67, 0x90, 0xf2, 0x4c, 0x51, 0x9f, 0x71, 0x0a, 0x34, 0x4e, 0x85, 0x66, 0x29, 0x51,
		0x6f, 0x36, 0x90, 0x65, 0xb0, 0x07, 0xf3, 0x17, 0xcb, 0x60, 0x0f, 0x78, 0x23, 0x2c, 0x83, 0x65,
		0x77, 0x3d, 0x96, 0xc1, 0x9c, 0x85, 0x08, 0xcb, 0x60, 0x2e, 0xbc, 0xfa, 0x32, 0x57, 0xe1, 0x0d,
		0xe5, 0xff, 0x59, 0x2f, 0xec, 0x18, 0x76, 0x1c, 0xf3, 0x97, 0xd4, 0x24, 0x3e, 0xf6, 0x54, 0xd7,
		0x1f, 0x84, 0x23, 0x59, 0xb6, 0xb1, 0xb6, 0xb6, 0x86, 0xaf, 0xc1, 0xd7, 0xe0, 0x6b, 0xf0, 0x35,
		0xf8, 0x1a, 0x7c, 0x0d, 0xbe, 0x06, 0x5f, 0x83, 0xaf, 0xc1, 0xd7, 0xe0, 0x6b, 0x72, 0xec, 0x6b,
		0x26, 0x7b, 0x7c, 0xcc, 0x3a, 0x9b, 0xdb, 0x17, 0xc5, 0x74, 0x60, 0x3a, 0x30, 0x1d, 0x98, 0x0e,
		0x4c, 0x07, 0xa6, 0x03, 0xd3, 0x81, 0xe9, 0xc0, 0x74, 0x60, 0x3a, 0x30, 0x1d, 0x02, 0x4c, 0x07,
		0x7b, 0x8a, 0x0c, 0xef, 0xbb, 0x48, 0xfa, 0xdd, 0xfc, 0x9c, 0x33, 0x74, 0xd4, 0xef, 0x72, 0xba,
		0x50, 0x66, 0xbe, 0x99, 0xd3, 0x85, 0xa8, 0xa4, 0x16, 0xe2, 0x7c, 0xa9, 0xa4, 0x36, 0x18, 0xe6,
		0x38, 0x5d, 0x48, 0x90, 0xf0, 0x26, 0xe9, 0x27, 0x8b, 0xf2, 0x8c, 0x53, 0x9f, 0x71, 0x0a, 0x34,
		0x4b, 0x85, 0x7a, 0xbd, 0x0f, 0xa7, 0x0b, 0x3d, 0x51, 0x9f, 0x71, 0xba, 0x90, 0x56, 0x10, 0xb1,
		0xa9, 0x88, 0x90, 0x48, 0x48, 0x24, 0x24, 0x12, 0x12, 0x9f, 0x30, 0x63, 0x58, 0x07, 0x7b, 0xf0,
		0x17, 0xeb, 0x60, 0xcf, 0xba, 0x1c, 0xeb, 0x60, 0xd9, 0x40, 0x84, 0x75, 0xb0, 0xbc, 0xa1, 0x86,
		0x75, 0x30, 0x27, 0x2d, 0x07, 0x9b, 0x8a, 0xf0, 0x35, 0xf8, 0x1a, 0x7c, 0x0d, 0xbe, 0x06, 0x5f,
		0x83, 0xaf, 0xc1, 0xd7, 0xe0, 0x6b, 0xf0, 0x35, 0xf8, 0x1a, 0x7c, 0x8d, 0xeb, 0xbe, 0x86, 0x4d,
		0x45, 0x98, 0x0e, 0x4c, 0x07, 0xa6, 0x03, 0xd3, 0x81, 0xe9, 0xc0, 0x74, 0x60, 0x3a, 0x30, 0x1d,
		0x98, 0x0e, 0x4c, 0x07, 0xa6, 0x43, 0xc3, 0x2b, 0xb2, 0xa9, 0xe8, 0x61, 0x9b, 0x8a, 0xf2, 0x72,
		0x3a, 0xd1, 0x51, 0xbf, 0xcb, 0x99, 0x44, 0xd6, 0xe1, 0x6c, 0x0b, 0xc6, 0x0e, 0x1f, 0x44, 0x74,
		0xd4, 0xef, 0xe6, 0xea, 0xf8, 0xa1, 0x4c, 0x77, 0xbb, 0x69, 0xd9, 0xe5, 0xa6, 0xed, 0x08, 0xa2,
		0x75, 0x8e, 0x20, 0x72, 0x29, 0xb5, 0xc2, 0x11, 0x44, 0x92, 0x8f, 0x20, 0x0a, 0x93, 0xbe, 0x17,
		0x06, 0x5d, 0x35, 0x24, 0x79, 0x7d, 0x19, 0xe3, 0xb9, 0x73, 0xed, 0x17, 0x2f, 0x97, 0xf5, 0x96,
		0xbd, 0xeb, 0xfa, 0x97, 0xd2, 0x7a, 0xe6, 0xf5, 0x2f, 0x9a, 0x6c, 0x20, 0xe7, 0x1f, 0x99, 0xe5,
		0x3d, 0x63, 0xfc, 0x67, 0x8c, 0x07, 0xcd, 0xf0, 0xa1, 0x1b, 0x3e, 0x52, 0x5b, 0xca, 0x78, 0x2e,
		0x55, 0x5c, 0xda, 0xd4, 0x01, 0xf8, 0x09, 0xbf, 0x6c, 0x6a, 0x78, 0x69, 0xbd, 0xa9, 0x61, 0x8d,
		0x09, 0x7a, 0x13, 0xa9, 0x60, 0x43, 0xf9, 0x3d, 0x53, 0xa9, 0x5f, 0x93, 0xc9, 0x3b, 0x8d, 0xa9,
		0x5e, 0x23, 0x29, 0x5e, 0xd3, 0x1f, 0xfd, 0xe6, 0xc6, 0xc6, 0xeb, 0x8d, 0x1c, 0x7d, 0xfc, 0x8e,
		0xe4, 0x3e, 0x8f, 0x97, 0xa0, 0x0f, 0xce, 0x50, 0x61, 0xc7, 0xaa, 0x1b, 0xab, 0xe4, 0xcc, 0x90,
		0x9e, 0x5f, 0xb8, 0x1a, 0x7a, 0x1b, 0xbd, 0x8d, 0xde, 0x46, 0x6f, 0xa3, 0xb7, 0xd1, 0xdb, 0xe8,
		0x6d, 0xf4, 0x36, 0x7a, 0x1b, 0xbd, 0x2d, 0x4b, 0x6f, 0xb3, 0x48, 0xac, 0x6b, 0x91, 0x38, 0xe3,
		0x3a, 0x07, 0xe3, 0xcb, 0xc4, 0xd9, 0xd5, 0x36, 0x64, 0xb0, 0x50, 0xfc, 0xc2, 0x22, 0x3c, 0xb3,
		0x86, 0xa5, 0x0d, 0x38, 0x16, 0x32, 0x59, 0x69, 0x37, 0x09, 0xc0, 0xe7, 0x41, 0xef, 0xe9, 0x80,
		0x79, 0x06, 0x58, 0x0a, 0x69, 0xec, 0x47, 0x49, 0xbf, 0x17, 0xa7, 0xcf, 0xc6, 0xc9, 0x4c, 0xec,
		0x5f, 0xbf, 0xe4, 0x33, 0x41, 0x9c, 0x4d, 0x0d, 0x42, 0x66, 0xb9, 0x82, 0x2c, 0x73, 0x03, 0x1a,
		0x72, 0x01, 0x59, 0x7b, 0x7f, 0x6d, 0x5e, 0x5f, 0x9b, 0xb7, 0xd7, 0xe3, 0xe5, 0xed, 0x12, 0x79,
		0x56, 0x35, 0x03, 0x85, 0xf6, 0x74, 0x16, 0x64, 0x5c, 0x75, 0x94, 0x69, 0xc7, 0x75, 0x6d, 0x65,
		0x47, 0x6b, 0x94, 0x1d, 0xb9, 0x94, 0x06, 0xa4, 0xec, 0x48, 0x7a, 0xd9, 0xd1, 0x79, 0x3a, 0xf0,
		0x92, 0xe0, 0xff, 0x29, 0xbd, 0xab, 0x13, 0xb3, 0xab, 0xb0, 0x2a, 0xc1, 0xaa, 0x84, 0x3d, 0x3a,
		0x32, 0x46, 0x4b, 0x66, 0xe8, 0x49, 0x4f, 0xce, 0x88, 0x55, 0x89, 0x05, 0x7e, 0x61, 0x55, 0xe2,
		0xc6, 0xc0, 0x59, 0x95, 0x78, 0xfc, 0x75, 0x58, 0x95, 0x10, 0xfb, 0xd1, 0xb3, 0x2a, 0x61, 0xe5,
		0x55, 0x59, 0x95, 0x78, 0x90, 0x7c, 0xc8, 0xc5, 0xaa, 0xc4, 0x34, 0x8f, 0x98, 0xfd, 0xa9, 0x6e,
		0xe6, 0x12, 0xc3, 0xd3, 0xf7, 0x90, 0xe9, 0x61, 0x6e, 0x6c, 0x63, 0xb3, 0x9d, 0x4f, 0x62, 0x1b,
		0x1b, 0xf9, 0x24, 0xf2, 0x49, 0xe4, 0x93, 0xc8, 0x27, 0x91, 0x4f, 0x22, 0x9f, 0x44, 0x3e, 0x89,
		0x7c, 0x12, 0xf9, 0x24, 0xf2, 0x49, 0xe4, 0x93, 0xc8, 0x27, 0x91, 0x4f, 0x22, 0x9f, 0x24, 0x3d,
		0x9f, 0xe4, 0x6e, 0xa1, 0xeb, 0x2c, 0x9d, 0x44, 0xad, 0xab, 0x2e, 0x70, 0x5a, 0x02, 0xa5, 0x53,
		0xe5, 0xae, 0xb3, 0x41, 0xdb, 0xaa, 0x78, 0x7d, 0x61, 0x10, 0x68, 0x59, 0x01, 0xcc, 0x28, 0xb0,
		0x9e, 0x01, 0x27, 0x53, 0x30, 0x7a, 0x1a, 0x78, 0x1e, 0xff, 0xd1, 0x3f, 0xe1, 0x63, 0x2f, 0x8c,
		0xb6, 0x43, 0x77, 0xfd, 0xb6, 0x4a, 0x9e, 0xfc, 0x91, 0xcf, 0x6c, 0xe1, 0x8d, 0xd7, 0x7a, 0x22,
		0x00, 0x9f, 0x97, 0xc5, 0x7e, 0x76, 0x1a, 0x29, 0x8b, 0x74, 0x51, 0x86, 0x69, 0xa1, 0xac, 0xd2,
		0x3f, 0x99, 0xa7, 0x79, 0x32, 0x4f, 0xe7, 0x64, 0x9b, 0xb6, 0x31, 0x4b, 0x9a, 0xcf, 0xcd, 0x12,
		0x5f, 0x4f, 0x9b, 0xec, 0x76, 0x26, 0x5c, 0xbf, 0x24, 0x3b, 0x13, 0x0c, 0xe6, 0x6f, 0xd9, 0x99,
		0xc0, 0xce, 0x84, 0x1f, 0xbc, 0x90, 0xdf, 0x0d, 0xbc, 0xc4, 0xef, 0x06, 0xd9, 0x2f, 0x25, 0xcf,
		0x5e, 0x99, 0xdd, 0x09, 0x82, 0xe8, 0x40, 0x17, 0x2d, 0x68, 0xa7, 0x07, 0xed, 0x34, 0xa1, 0x97,
		0x2e, 0x64, 0xa6, 0x96, 0x32, 0x5f, 0x4d, 0xf6, 0xbb, 0xfa, 0xd6, 0x90, 0xfd, 0xae, 0xa6, 0x95,
		0xe3, 0x12, 0x2b, 0xc7, 0xac, 0x1c, 0x4b, 0xa2, 0x20, 0x33, 0x54, 0x94, 0x2d, 0x25, 0x65, 0x4c,
		0x4d, 0xda, 0x28, 0x6a, 0x4e, 0xf9, 0x4c, 0xd2, 0x2c, 0x9a, 0x0f, 0xf9, 0x9b, 0x5d, 0x89, 0x93,
		0xfd, 0x4c, 0xd3, 0x9a, 0x41, 0x7a, 0x33, 0x45, 0x73, 0xc6, 0xe9, 0xce, 0x38, 0xed, 0x99, 0xa5,
		0x3f, 0x3d, 0x34, 0xa8, 0x89, 0x0e, 0x67, 0xb7, 0xc6, 0xdc, 0xc9, 0x7e, 0xa1, 0xf2, 0xbb, 0xb1,
		0xea, 0x1a, 0x38, 0xda, 0xaf, 0xb4, 0xa5, 0xf1, 0x1a, 0x87, 0x93, 0xcc, 0xff, 0xab, 0x57, 0x93,
		0x8a, 0xf6, 0xe2, 0x8c, 0x96, 0x97, 0xf8, 0xd0, 0xdb, 0x8c, 0x1b, 0x13, 0xdc, 0x0b, 0xa2, 0xcc,
		0x37, 0x11, 0x18, 0xd0, 0xf1, 0x04, 0x40, 0x02, 0x20, 0x01, 0x50, 0x6a, 0x00, 0xd4, 0xe5, 0x0b,
		0xcc, 0xf9, 0x03, 0xd3, 0x3e, 0xc1, 0x90, 0x5f, 0x30, 0x46, 0x9b, 0x26, 0xe9, 0xd3, 0x02, 0x8d,
		0x9a, 0xa6, 0x53, 0x6b, 0xb4, 0x6a, 0x8d, 0x5e, 0xed, 0xd0, 0xac, 0x5e, 0xba, 0xd5, 0x4c, 0xbb,
		0xe6, 0xfc, 0xc7, 0xc2, 0x8c, 0x0b, 0x3a, 0x2a, 0x4a, 0x83, 0xf4, 0x52, 0xaf, 0x17, 0x59, 0xd0,
		0x94, 0x06, 0x0e, 0x0c, 0x2e, 0xd4, 0x26, 0x6f, 0x6d, 0xd7, 0x4f, 0x0c, 0xce, 0xf3, 0xe9, 0x8d,
		0xad, 0xbc, 0xab, 0xb5, 0x9a, 0x7f, 0x1c, 0x56, 0x0b, 0x26, 0x4f, 0x67, 0x4e, 0xb4, 0x1f, 0xb3,
		0x7e, 0xf3, 0xeb, 0xbb, 0xb1, 0x2b, 0xcd, 0xdd, 0xd9, 0xda, 0xe1, 0xa7, 0xcd, 0x82, 0xb1, 0x4b,
		0x5f, 0xfd, 0xb2, 0x04, 0xf7, 0xb3, 0x6c, 0xf0, 0x7e, 0x1a, 0xb9, 0xd2, 0x31, 0xe7, 0x82, 0x9b,
		0xc7, 0x73, 0x41, 0x45, 0xfe, 0x49, 0xa8, 0x3a, 0xe6, 0xb4, 0xfd, 0xf4, 0x82, 0x48, 0x7b, 0xa4,
		0x3d, 0xd2, 0x1e, 0x69, 0x8f, 0xb4, 0xbf, 0x31, 0xe3, 0x4e, 0x7a, 0xbd, 0x50, 0xf9, 0x91, 0x49,
		0x59, 0x5f, 0x22, 0x28, 0x2e, 0xdc, 0x9b, 0xc4, 0x7c, 0xca, 0x2b, 0x21, 0xe7, 0x45, 0x60, 0x24,
		0x30, 0x12, 0x18, 0x09, 0x8c, 0x77, 0xcd, 0x38, 0x72, 0x5e, 0x9a, 0x6e, 0xec, 0x11, 0x49, 0x2f,
		0x5d, 0xb7, 0xf6, 0xe3, 0x7e, 0xed, 0x6d, 0xe5, 0xa8, 0x49, 0xde, 0x2b, 0xbb, 0x5b, 0xfa, 0xe1,
		0x63, 0xbd, 0x69, 0xfa, 0xa6, 0x92, 0xfc, 0xb2, 0xab, 0xf3, 0x9d, 0x5a, 0x8c, 0xd7, 0xd4, 0xa2,
		0x62, 0xd1, 0xa1, 0x18, 0xd9, 0xc4, 0x7d, 0xbd, 0x67, 0xf8, 0xfa, 0x61, 0x71, 0xba, 0x9d, 0xa9,
		0xe8, 0x77, 0x8b, 0x5a, 0xab, 0x99, 0x56, 0x8c, 0xec, 0x02, 0xaf, 0xcd, 0xde, 0xe3, 0xf5, 0xc3,
		0x56, 0xa5, 0x1b, 0x1c, 0xf9, 0xdd, 0xa0, 0x55, 0xe9, 0x66, 0xda, 0x31, 0x55, 0x3f, 0xb6, 0x75,
		0x94, 0xc6, 0x25, 0xe6, 0x0a, 0xc4, 0x13, 0x2a, 0xc4, 0xad, 0xbb, 0x5d, 0x0a, 0xe4, 0x1c, 0x74,
		0xb3, 0x14, 0xc8, 0x59, 0x74, 0xab, 0xf9, 0xaf, 0x10, 0x4f, 0x28, 0x11, 0xcf, 0xba, 0xd3, 0xf8,
		0xfd, 0x31, 0x30, 0xe3, 0xb6, 0x60, 0x77, 0xc2, 0x47, 0x77, 0xfc, 0x5b, 0x27, 0xfe, 0x11, 0xff,
		0x88, 0x7f, 0x22, 0xe2, 0x1f, 0x05, 0xe2, 0x42, 0xed, 0x82, 0x31, 0xdb, 0x60, 0x92, 0x3e, 0x2d,
		0xd0, 0xa8, 0x69, 0x3a, 0xb5, 0x46, 0xab, 0xd6, 0xe8, 0xd5, 0x0e, 0xcd, 0xea, 0xa5, 0x5b, 0xcd,
		0xb4, 0x6b, 0xce, 0x7e, 0x2c, 0xcc, 0x38, 0x16, 0xcb, 0x34, 0xdd, 0x58, 0xd6, 0xca, 0x74, 0xdd,
		0x59, 0x0a, 0xc4, 0x33, 0xbf, 0x9f, 0x14, 0x88, 0x4b, 0x0b, 0x34, 0x14, 0x88, 0x3f, 0x04, 0xba,
		0x14, 0x88, 0x23, 0xed, 0x91, 0xf6, 0x48, 0x7b, 0xa4, 0xfd, 0x1d, 0x33, 0x8e, 0x02, 0x71, 0x11,
		0x41, 0x91, 0x02, 0x71, 0x02, 0x23, 0x81, 0x91, 0xc0, 0x48, 0x60, 0x94, 0x12, 0x18, 0xc9, 0x79,
		0x69, 0xba, 0xb1, 0x14, 0x88, 0x6b, 0xbb, 0xb5, 0x14, 0x88, 0x67, 0x7e, 0x4b, 0x29, 0x10, 0x97,
		0x1a, 0x71, 0x58, 0x8c, 0x5f, 0x59, 0xc2, 0x02, 0x71, 0x9d, 0xc5, 0x4c, 0x2b, 0x22, 0xea, 0xc3,
		0x33, 0x3c, 0x02, 0x51, 0x3f, 0xb2, 0x65, 0x77, 0x38, 0xff, 0x4d, 0x5d, 0xde, 0x2c, 0xee, 0x58,
		0xd1, 0x65, 0x79, 0x0b, 0xf5, 0x20, 0x49, 0x2b, 0x69, 0xaa, 0xa9, 0x9f, 0xfa, 0x87, 0x20, 0xaa,
		0x86, 0x6a, 0xe8, 0x18, 0x12, 0x3d, 0xf6, 0xb6, 0xf0, 0xc1, 0xff, 0x76, 0xe3, 0x0a, 0xa5, 0x37,
		0xe5, 0xf2, 0xe6, 0x56, 0xb9, 0xbc, 0xb6, 0xf5, 0x7a, 0x6b, 0x6d, 0x7b, 0x63, 0xa3, 0xb4, 0xa9,
		0x43, 0x96, 0x16, 0x0e, 0xe2, 0x8e, 0x8a, 0x55, 0x67, 0x77, 0xf8, 0x19, 0x45, 0x83, 0x30, 0x14,
		0x0d, 0x25, 0xcd, 0x34, 0x2b, 0x84, 0x5e, 0x0b, 0x5a, 0xaa, 0x5c, 0xed, 0x12, 0x6a, 0x81, 0xa3,
		0x90, 0xed, 0xe1, 0x5b, 0x02, 0xae, 0x9d, 0x3a, 0x11, 0xf9, 0x47, 0x60, 0x16, 0x73, 0x2e, 0x72,
		0x06, 0x67, 0xe7, 0xf9, 0x83, 0xf4, 0x4c, 0x45, 0x69, 0xd0, 0xce, 0x16, 0x73, 0xd7, 0x05, 0x9d,
		0xf3, 0xaf, 0xcf, 0x49, 0x69, 0xcf, 0xbe, 0xa3, 0x9c, 0x94, 0x76, 0x7d, 0x01, 0x4e, 0x4a, 0x13,
		0x7c, 0x52, 0x9a, 0xa6, 0x93, 0x17, 0xf4, 0x9e, 0xb8, 0xc0, 0x89, 0x69, 0x46, 0x28, 0x47, 0x37,
		0xf5, 0x18, 0xa3, 0x20, 0x63, 0x54, 0x64, 0x86, 0x92, 0xdc, 0xc8, 0x27, 0x68, 0x3b, 0x31, 0xed,
		0x4c, 0x85, 0x61, 0xcf, 0xd3, 0xa4, 0x89, 0xee, 0x9d, 0x5e, 0x77, 0x5e, 0x55, 0xd7, 0x9e, 0x21,
		0xd5, 0xf5, 0x07, 0xe1, 0x08, 0x3c, 0x5d, 0x3f, 0x4c, 0xd8, 0x8f, 0x6f, 0x9e, 0x56, 0x0d, 0xd2,
		0xab, 0x29, 0x9a, 0x35, 0x4e, 0xb7, 0xc6, 0x69, 0xd7, 0x2c, 0xfd, 0xea, 0xa1, 0x61, 0x4d, 0x74,
		0x3c, 0xbb, 0x35, 0xe6, 0xf6, 0xe3, 0xeb, 0xaf, 0x96, 0xd3, 0x5c, 0x25, 0xb7, 0x6c, 0x2b, 0x00,
		0x79, 0x4e, 0xdb, 0xce, 0xc5, 0x6d, 0x7d, 0x9d, 0x93, 0x6c, 0xe5, 0xbc, 0xe6, 0xde, 0x9e, 0x96,
		0xae, 0x49, 0x19, 0xe6, 0x72, 0x33, 0x4c, 0x8a, 0x7c, 0x1d, 0x2d, 0x5a, 0x69, 0xf2, 0xae, 0xc3,
		0x17, 0xc7, 0xb8, 0x62, 0x5c, 0x31, 0xae, 0x18, 0x57, 0xc1, 0xb9, 0x36, 0x33, 0x39, 0x37, 0xcd,
		0x14, 0x86, 0x69, 0xc4, 0x34, 0x62, 0x1a, 0xa5, 0x9a, 0x46, 0xfd, 0x4d, 0x6c, 0x06, 0xe9, 0x99,
		0xd7, 0xf7, 0x93, 0x64, 0x82, 0x31, 0x53, 0x9d, 0x6c, 0xe6, 0x2e, 0xcb, 0xd6, 0x1e, 0x69, 0x44,
		0x6a, 0x81, 0x50, 0x4d, 0x13, 0xab, 0x35, 0x82, 0xb5, 0x46, 0xb4, 0x76, 0x08, 0x57, 0x2f, 0xf1,
		0x6a, 0x26, 0x60, 0x73, 0xd9, 0xbb, 0x85, 0x19, 0x17, 0xf7, 0x06, 0x69, 0x10, 0x9d, 0x9a, 0x62,
		0xc9, 0x39, 0x89, 0xf9, 0x86, 0xa2, 0x78, 0x03, 0xc1, 0x7d, 0x19, 0x8a, 0xe2, 0xe7, 0xd3, 0x7f,
		0x5f, 0xd5, 0x65, 0x7e, 0x9b, 0xa7, 0xcf, 0xa7, 0x02, 0x7f, 0x53, 0x97, 0x34, 0x51, 0xa7, 0x79,
		0xec, 0x23, 0x64, 0x23, 0xcd, 0x63, 0xf1, 0xdd, 0xf8, 0x6e, 0x7c, 0x37, 0xbe, 0x1b, 0xdf, 0x8d,
		0xef, 0xc6, 0x77, 0xe3, 0xbb, 0xf1, 0xdd, 0xf8, 0x6e, 0x7c, 0x77, 0x46, 0xbe, 0x3b, 0xaf, 0x7b,
		0xd2, 0x17, 0x6d, 0x37, 0x7b, 0xd3, 0x5d, 0x99, 0x2a, 0xb2, 0xa6, 0x48, 0x6e, 0xcb, 0xd2, 0x7e,
		0x53, 0x97, 0x4b, 0x52, 0x93, 0xd6, 0x3e, 0xf3, 0x83, 0x48, 0x6b, 0x61, 0xda, 0xf8, 0x0a, 0x54,
		0xa7, 0x51, 0x9d, 0x66, 0xdf, 0xd9, 0x50, 0x9d, 0x46, 0x28, 0xd4, 0x13, 0x0a, 0x75, 0xb0, 0x9c,
		0xa8, 0x78, 0x38, 0x7e, 0x83, 0x4b, 0x10, 0x14, 0xf5, 0xac, 0xc0, 0x68, 0x5d, 0x79, 0xd1, 0x1e,
		0x0e, 0xd7, 0x09, 0x87, 0x84, 0x43, 0xc2, 0xe1, 0xb3, 0x6e, 0x01, 0xbb, 0x8c, 0x9f, 0x7e, 0xeb,
		0xd8, 0x65, 0x6c, 0x9b, 0x56, 0x0d, 0xd2, 0xab, 0x29, 0x9a, 0x35, 0x4e, 0xb7, 0xc6, 0x69, 0xd7,
		0x2c, 0xfd, 0xea, 0x4b, 0xf9, 0xad, 0xb0, 0xcb, 0xf8, 0x71, 0x3a, 0x90, 0x5d, 0xc6, 0x18, 0xd8,
		0xc7, 0x18, 0x58, 0x5d, 0x4b, 0x1d, 0x32, 0xdc, 0xab, 0x86, 0xe5, 0x0d, 0xfa, 0x45, 0x3a, 0x0a,
		0xf5, 0x1c, 0x74, 0x8d, 0x9c, 0x7f, 0x3f, 0x39, 0x6a, 0x1e, 0x79, 0xd2, 0xed, 0x64, 0xdf, 0x31,
		0x72, 0xf8, 0xa2, 0xb4, 0x89, 0x14, 0x28, 0xf7, 0x69, 0x13, 0x69, 0x47, 0xae, 0xd3, 0x26, 0xf2,
		0x59, 0x13, 0x81, 0x36, 0x91, 0x24, 0x70, 0xc5, 0x64, 0x14, 0x48, 0xe0, 0x1a, 0xb4, 0x83, 0xda,
		0x12, 0xb8, 0x27, 0xdd, 0x8e, 0x97, 0x86, 0x17, 0xfa, 0x73, 0xb6, 0xd3, 0x0b, 0x91, 0x3e, 0x35,
		0x4d, 0x6a, 0x06, 0xc9, 0xcd, 0x14, 0xc9, 0x19, 0x27, 0x3b, 0xe3, 0xa4, 0x67, 0x96, 0xfc, 0xf4,
		0x65, 0xd9, 0x56, 0x48, 0x9f, 0x3e, 0x4e, 0x85, 0x91, 0x3e, 0x15, 0x9c, 0x4b, 0x92, 0x90, 0x53,
		0x3a, 0xe9, 0x76, 0x72, 0xd7, 0x99, 0x71, 0xb7, 0xdb, 0x59, 0xa2, 0x76, 0x8c, 0x54, 0xf9, 0x2c,
		0xea, 0x2a, 0xaa, 0x7c, 0x30, 0x89, 0x98, 0x44, 0x4c, 0x22, 0x26, 0x11, 0x93, 0x88, 0x49, 0xc4,
		0x24, 0x62, 0x12, 0x31, 0x89, 0x98, 0xc4, 0x67, 0x99, 0xc4, 0x9c, 0x15, 0xd6, 0x0c, 0x3d, 0x22,
		0xd5, 0x34, 0xb6, 0xc1, 0x6d, 0x19, 0xd4, 0xee, 0x97, 0xd0, 0xec, 0x76, 0x3b, 0x79, 0xaa, 0x9b,
		0x69, 0x07, 0x71, 0x7b, 0x10, 0xa4, 0x5e, 0xbb, 0x37, 0x18, 0xbe, 0xc5, 0x24, 0xfb, 0x22, 0x9a,
		0x85, 0x2b, 0x50, 0x51, 0x23, 0x50, 0xdc, 0x53, 0x51, 0x63, 0x47, 0x9c, 0xe7, 0xbc, 0xa2, 0x86,
		0x54, 0xe9, 0x22, 0xc1, 0x90, 0x2a, 0x35, 0x99, 0x45, 0x20, 0x55, 0x9a, 0x47, 0xeb, 0xa7, 0x2d,
		0x55, 0xea, 0x77, 0xfe, 0xeb, 0xb5, 0xcf, 0xfc, 0xe8, 0x54, 0x25, 0xfa, 0xd3, 0xa5, 0x37, 0x2f,
		0x46, 0xca, 0xd4, 0x34, 0xb9, 0x19, 0x24, 0x39, 0x53, 0x64, 0x67, 0x9c, 0xf4, 0x8c, 0x93, 0x9f,
		0x59, 0x12, 0xd4, 0x97, 0x59, 0x5b, 0xc9, 0x45, 0xca, 0x74, 0xe2, 0xe9, 0x5e, 0xaf, 0x1b, 0x48,
		0x9a, 0x6e, 0x69, 0xbc, 0x44, 0x63, 0xc8, 0xc1, 0x85, 0x9d, 0x95, 0xcf, 0x5a, 0x31, 0x6b, 0xa0,
		0xaf, 0xe6, 0x87, 0x20, 0x32, 0xd8, 0x53, 0xd6, 0x48, 0xcb, 0xe1, 0xd9, 0xe5, 0x3e, 0xf9, 0xe1,
		0x40, 0x19, 0xbc, 0xde, 0xbb, 0xd8, 0x6f, 0xa7, 0x41, 0x2f, 0xda, 0x0b, 0x4e, 0x83, 0x74, 0xa8,
		0x06, 0xd6, 0xf4, 0xb7, 0x8f, 0x35, 0xd0, 0xfe, 0xf4, 0x83, 0xff, 0x2d, 0xf7, 0x10, 0x29, 0xaf,
		0x6f, 0x97, 0xb7, 0x37, 0xb7, 0xd6, 0xb7, 0x37, 0x72, 0x8c, 0x15, 0x47, 0xdb, 0xd7, 0x1e, 0x2f,
		0xf1, 0x09, 0x1d, 0x43, 0xc1, 0x1f, 0x0d, 0xce, 0x4f, 0x54, 0x6c, 0xc6, 0x5c, 0x4c, 0xae, 0x85,
		0xb7, 0xc0, 0x5b, 0xe0, 0x2d, 0xf0, 0x16, 0x4e, 0x79, 0x8b, 0x41, 0x10, 0xa5, 0x18, 0x0b, 0x8c,
		0x05, 0xc6, 0x02, 0x63, 0x81, 0xb1, 0xc0, 0x58, 0x60, 0x2c, 0x7e, 0x64, 0x2c, 0x06, 0xe9, 0x99,
		0xd7, 0xf5, 0x83, 0xd0, 0xc4, 0xaa, 0xc5, 0xf5, 0xb5, 0x30, 0x16, 0x18, 0x0b, 0x8c, 0x05, 0xc6,
		0xc2, 0x29, 0x63, 0xc1, 0xa2, 0x05, 0xde, 0x02, 0x6f, 0x81, 0xb7, 0xc0, 0x5b, 0xe0, 0x2d, 0xf0,
		0x16, 0x0f, 0xf4, 0x16, 0xe9, 0x65, 0x5f, 0x19, 0x35, 0x18, 0x37, 0x2e, 0x88, 0xcb, 0xc0, 0x65,
		0xe0, 0x32, 0x70, 0x19, 0xb8, 0x0c, 0x5c, 0x06, 0x2e, 0x03, 0x97, 0x81, 0xcb, 0xc0, 0x65, 0xe0,
		0x32, 0x72, 0xe6, 0x32, 0x82, 0x8e, 0xd7, 0x0d, 0x54, 0xd8, 0xf1, 0x42, 0x15, 0x79, 0xe7, 0x41,
		0x72, 0xee, 0xa7, 0xed, 0x33, 0x13, 0x9b, 0x30, 0xee, 0xbb, 0x30, 0xae, 0x03, 0xd7, 0x81, 0xeb,
		0xc0, 0x75, 0xe0, 0x3a, 0x70, 0x1d, 0xb8, 0x0e, 0x5c, 0x07, 0xae, 0x03, 0xd7, 0x81, 0xeb, 0xc8,
		0x9b, 0xeb, 0x88, 0x82, 0xd4, 0xd4, 0xb2, 0xc6, 0x8d, 0x6b, 0xe1, 0x2d, 0xf0, 0x16, 0x78, 0x0b,
		0xbc, 0x05, 0xde, 0x02, 0x6f, 0x81, 0xb7, 0xc0, 0x5b, 0xe0, 0x2d, 0xf0, 0x16, 0x78, 0x8b, 0x9c,
		0x79, 0x8b, 0xd0, 0x8f, 0xbc, 0x4e, 0x90, 0x98, 0x6b, 0x27, 0x75, 0xfb, 0x82, 0xb8, 0x0c, 0x5c,
		0x06, 0x2e, 0x03, 0x97, 0x81, 0xcb, 0xc0, 0x65, 0xe0, 0x32, 0x70, 0x19, 0xb8, 0x0c, 0x5c, 0x06,
		0x2e, 0x23, 0x67, 0x2e, 0xe3, 0xdc, 0xff, 0xe6, 0xf9, 0xb1, 0xf2, 0x3d, 0xbf, 0xd3, 0x89, 0x55,
		0x92, 0x18, 0xad, 0x9d, 0xfa, 0xd1, 0xc5, 0x71, 0x1f, 0xb8, 0x0f, 0xdc, 0x07, 0xee, 0x03, 0xf7,
		0x81, 0xfb, 0xc0, 0x7d, 0xe0, 0x3e, 0x70, 0x1f, 0xb8, 0x0f, 0xdc, 0x47, 0xce, 0xdc, 0x47, 0xac,
		0xfe, 0xab, 0xda, 0xa9, 0xea, 0x78, 0x7e, 0xe7, 0xbf, 0xfa, 0xed, 0xc6, 0xdc, 0xd5, 0xf0, 0x17,
		0xf8, 0x0b, 0xfc, 0x05, 0xfe, 0x02, 0x7f, 0x81, 0xbf, 0xc0, 0x5f, 0xe0, 0x2f, 0xf0, 0x17, 0xf8,
		0x0b, 0xfc, 0x85, 0x4d, 0x7f, 0xc1, 0x61, 0xf1, 0x76, 0xce, 0xd5, 0xbe, 0x7d, 0xc2, 0x72, 0xde,
		0x4e, 0x8e, 0x7f, 0x3b, 0x7e, 0x7f, 0x6f, 0x27, 0x6f, 0x8f, 0x53, 0xe4, 0xad, 0xa3, 0x5e, 0x12,
		0xda, 0xdd, 0x3f, 0x52, 0xfe, 0x16, 0xbe, 0x73, 0x75, 0xbc, 0xfc, 0x34, 0xdd, 0x91, 0xf5, 0xa1,
		0xf2, 0xe3, 0xd7, 0xe5, 0x28, 0x79, 0x81, 0x39, 0x1c, 0x8e, 0x92, 0xb7, 0x93, 0x83, 0xc9, 0xf9,
		0x51, 0xf2, 0x53, 0xde, 0x4f, 0x75, 0x24, 0x6b, 0xae, 0x89, 0xe5, 0xe6, 0x55, 0xf4, 0x1c, 0x2c,
		0xbf, 0xa6, 0xeb, 0x60, 0xf9, 0x35, 0x0e, 0x96, 0x37, 0x40, 0x43, 0xc6, 0xe8, 0xc8, 0x18, 0x2d,
		0x99, 0xa1, 0x27, 0x37, 0x6c, 0xa2, 0xb6, 0x54, 0xb0, 0x09, 0x86, 0x99, 0x13, 0x33, 0x65, 0x0d,
		0xaf, 0x5d, 0x8d, 0x06, 0xe7, 0xc3, 0xbb, 0x73, 0x25, 0xd5, 0x7c, 0x65, 0xa8, 0x62, 0x54, 0xe4,
		0x9f, 0x84, 0xaa, 0xa3, 0x2f, 0xd4, 0x4c, 0x2f, 0x90, 0x31, 0x82, 0xf7, 0x54, 0xd7, 0x1f, 0x84,
		0xa3, 0x39, 0xdc, 0xf5, 0xc3, 0x84, 0x28, 0x46, 0x14, 0x23, 0x8a, 0x11, 0xc5, 0x32, 0x46, 0xfc,
		0x49, 0xaf, 0x17, 0x2a, 0x3f, 0xd2, 0x19, 0xc0, 0x4a, 0x4b, 0x10, 0x64, 0xce, 0x54, 0x18, 0xf6,
		0xbc, 0xbe, 0xdf, 0xe9, 0x04, 0xd1, 0xa9, 0xbe, 0x50, 0x33, 0x7f, 0x19, 0x02, 0x02, 0x01, 0x81,
		0x80, 0x40, 0x40, 0xd0, 0x47, 0x31, 0x98, 0x1b, 0xe1, 0x71, 0x67, 0xb6, 0x9c, 0xe2, 0x05, 0x1a,
		0x1d, 0xce, 0xdc, 0x55, 0x88, 0x3a, 0x44, 0x1d, 0xa2, 0x0e, 0x51, 0xc7, 0x15, 0x86, 0x99, 0x8b,
		0x37, 0x6f, 0x96, 0x20, 0x26, 0xf4, 0xfd, 0x24, 0x09, 0x2e, 0x34, 0xae, 0xad, 0x4c, 0x2f, 0x40,
		0xc2, 0x8b, 0x48, 0x43, 0xa4, 0x21, 0xd2, 0x90, 0xf0, 0x72, 0x24, 0xe1, 0x45, 0x49, 0x9b, 0xe6,
		0x92, 0xb6, 0x2c, 0xab, 0x99, 0x56, 0x2c, 0x16, 0xb2, 0x8d, 0xdf, 0x47, 0x8e, 0xea, 0xd7, 0xc6,
		0x6b, 0x74, 0xde, 0x49, 0xb7, 0x93, 0x7d, 0x0d, 0xdb, 0x8d, 0xd7, 0xa6, 0x8e, 0x2d, 0x0b, 0x45,
		0x92, 0xdd, 0x9d, 0x5c, 0xa1, 0x8c, 0xed, 0x11, 0x82, 0x63, 0x78, 0xdf, 0xa9, 0x62, 0x7b, 0xd8,
		0x0b, 0x66, 0x5c, 0x10, 0xbb, 0x30, 0x0d, 0x32, 0x0f, 0x25, 0x1a, 0x88, 0x25, 0x37, 0x16, 0x28,
		0x5b, 0xc2, 0xc1, 0x01, 0x89, 0x24, 0x24, 0x37, 0x0c, 0x50, 0xd6, 0x44, 0x75, 0x4b, 0x01, 0x75,
		0xf4, 0x37, 0x77, 0xd0, 0x53, 0x0e, 0xa5, 0x39, 0x8b, 0xa3, 0x9d, 0xca, 0x4c, 0x50, 0x9a, 0x39,
		0x6a, 0x33, 0x45, 0x71, 0xc6, 0xa9, 0xce, 0x38, 0xe5, 0x19, 0xa5, 0x3e, 0x3d, 0x14, 0xa8, 0x89,
		0x0a, 0xf5, 0xe7, 0x84, 0x0c, 0xe6, 0x86, 0x34, 0xe7, 0x88, 0xf4, 0x7d, 0xb0, 0x6c, 0x06, 0xb6,
		0x94, 0x4b, 0xba, 0xce, 0x2a, 0x14, 0xb5, 0x78, 0x01, 0x8b, 0xe9, 0xa5, 0xea, 0xe8, 0xad, 0xed,
		0x76, 0x3b, 0x99, 0x26, 0x9a, 0xb2, 0x47, 0xec, 0x55, 0xa6, 0x89, 0x3c, 0x3f, 0xd5, 0xb8, 0x24,
		0xa7, 0x63, 0xa7, 0xb8, 0x76, 0xb7, 0xb8, 0x8e, 0x5b, 0xc4, 0x2d, 0xe2, 0x16, 0x71, 0x8b, 0xb8,
		0x45, 0xdc, 0x22, 0x6e, 0x11, 0xb7, 0x88, 0x5b, 0xc4, 0x2d, 0xe2, 0x16, 0x9f, 0xe9, 0x16, 0x73,
		0xd6, 0x34, 0xea, 0xda, 0x2c, 0xd2, 0x2e, 0xca, 0x36, 0xd2, 0x65, 0x20, 0xdc, 0xfd, 0xfa, 0x9a,
		0x19, 0xa6, 0xf3, 0x54, 0x62, 0xa3, 0x65, 0x2b, 0x8a, 0xce, 0x02, 0xf1, 0x8c, 0xcd, 0x01, 0xed,
		0xa2, 0xa8, 0xb3, 0x79, 0x98, 0x5a, 0xcf, 0x73, 0xbb, 0xa8, 0xcc, 0xe5, 0xf7, 0xf5, 0xa9, 0xc8,
		0xca, 0xef, 0xc6, 0xaa, 0x9b, 0x25, 0x62, 0xa7, 0xf2, 0x3a, 0xc3, 0x0e, 0xdb, 0x85, 0xc3, 0x49,
		0x70, 0x7c, 0xf5, 0x6a, 0x92, 0xb7, 0x2f, 0xce, 0x51, 0x57, 0x2e, 0x09, 0x7f, 0xf8, 0xb1, 0x68,
		0x64, 0xfc, 0xec, 0x3e, 0xf5, 0xa5, 0xef, 0x10, 0xd8, 0x85, 0xf0, 0x6d, 0x10, 0x7e, 0x97, 0xba,
		0xca, 0x07, 0xbe, 0x20, 0x75, 0x95, 0x1a, 0xe9, 0x45, 0x27, 0xcd, 0x68, 0xa7, 0x1b, 0xdd, 0xb4,
		0x63, 0x8c, 0x7e, 0x8c, 0xd1, 0x90, 0x09, 0x3a, 0x72, 0x23, 0xf3, 0xa7, 0x6d, 0x9d, 0x6c, 0x26,
		0x52, 0xf4, 0xaf, 0x94, 0x5d, 0x5f, 0x8a, 0xb5, 0x32, 0xd3, 0xa4, 0x66, 0x8c, 0xdc, 0x4c, 0x91,
		0x9c, 0x71, 0xb2, 0x33, 0x4e, 0x7a, 0x26, 0xc9, 0x4f, 0x0f, 0x09, 0x6a, 0x22, 0x43, 0x7d, 0x56,
		0xdd, 0xa0, 0x75, 0x37, 0x61, 0xe5, 0xef, 0xb5, 0xf6, 0xc5, 0x11, 0x8c, 0x76, 0x6e, 0xa4, 0xa9,
		0x6f, 0x3d, 0x31, 0xf9, 0x7d, 0x94, 0x56, 0x5e, 0xe2, 0x43, 0x25, 0x93, 0xc1, 0x89, 0xc1, 0xf8,
		0x38, 0x77, 0x35, 0x42, 0x24, 0x21, 0x92, 0x10, 0x49, 0x88, 0x24, 0x44, 0x0a, 0x0d, 0x91, 0x9f,
		0xaf, 0x43, 0xe4, 0xff, 0xaf, 0x3d, 0x88, 0x63, 0x15, 0xa5, 0x2f, 0x57, 0x8b, 0xaf, 0x5e, 0x5d,
		0x67, 0xcb, 0x8f, 0x27, 0x7f, 0x72, 0x93, 0xd7, 0x93, 0x3b, 0x9e, 0x9b, 0xbd, 0x72, 0x47, 0x7d,
		0x2b, 0x50, 0x27, 0x93, 0xc1, 0x87, 0x58, 0xfd, 0x36, 0x3a, 0xc9, 0x2f, 0xfb, 0x33, 0x41, 0xf5,
		0x27, 0x6c, 0x7a, 0x6d, 0x4f, 0x7d, 0x4b, 0x77, 0x52, 0x15, 0xaa, 0x73, 0x95, 0xc6, 0x97, 0x5e,
		0x2f, 0xf2, 0xda, 0x67, 0xa3, 0x43, 0x4e, 0x8d, 0x24, 0x71, 0x46, 0x8d, 0xab, 0x0c, 0x64, 0x71,
		0xa4, 0x27, 0x70, 0x8e, 0x29, 0xdd, 0x7a, 0x68, 0x61, 0xcb, 0xdc, 0x3a, 0x57, 0xee, 0xf6, 0xfa,
		0xcc, 0x1e, 0x35, 0x54, 0x97, 0xed, 0x3e, 0x99, 0x79, 0x1d, 0xb6, 0xfb, 0xb0, 0x88, 0x21, 0xc2,
		0xb4, 0xb0, 0x88, 0x61, 0x4c, 0x96, 0xb1, 0x88, 0x41, 0x86, 0x86, 0x0c, 0x0d, 0x19, 0x1a, 0x32,
		0x34, 0x64, 0x68, 0x0c, 0x64, 0x68, 0x58, 0xc4, 0x58, 0x61, 0x11, 0x83, 0x10, 0x49, 0x88, 0x24,
		0x44, 0x12, 0x22, 0x09, 0x91, 0x2c, 0x62, 0xb8, 0xe5, 0x96, 0x97, 0x26, 0x63, 0x9c, 0xb3, 0xfd,
		0xbe, 0x73, 0x09, 0x63, 0xb6, 0xfc, 0xda, 0xc6, 0xbb, 0x18, 0x9c, 0xbb, 0xbf, 0xeb, 0xf7, 0x26,
		0xb2, 0xf3, 0xb4, 0x0f, 0x2c, 0x54, 0x17, 0x2a, 0x4c, 0xb2, 0xdf, 0x00, 0x36, 0x79, 0x5d, 0x76,
		0x7e, 0x65, 0xe2, 0x62, 0xd8, 0xec, 0x6b, 0xc6, 0x97, 0x2c, 0xd3, 0x66, 0xdf, 0xcc, 0x77, 0x7f,
		0x8d, 0xa6, 0xbc, 0xbe, 0x65, 0xd3, 0xf1, 0xcb, 0xb3, 0xf7, 0x8b, 0x63, 0xc5, 0xec, 0x27, 0x4a,
		0x38, 0x56, 0xcc, 0xa0, 0x19, 0xd4, 0xb6, 0x74, 0xea, 0x77, 0xfe, 0xeb, 0xb7, 0x55, 0xd4, 0x0e,
		0x54, 0xa2, 0x3f, 0x39, 0x7c, 0xf3, 0x62, 0x7a, 0x73, 0xc3, 0x25, 0xdd, 0xb9, 0xe1, 0xf5, 0x9c,
		0xe4, 0x86, 0xf5, 0x90, 0x9c, 0x29, 0xb2, 0x33, 0x4e, 0x7a, 0xc6, 0xc9, 0xcf, 0x2c, 0x09, 0xea,
		0xcb, 0xb5, 0xad, 0x68, 0xcc, 0x0f, 0xeb, 0x22, 0xc7, 0x05, 0x92, 0xbc, 0xd4, 0x0f, 0xe4, 0xdb,
		0x54, 0x79, 0xa9, 0x1b, 0xc8, 0x7a, 0x09, 0x53, 0xbb, 0x1a, 0xb4, 0x41, 0xa0, 0x16, 0x88, 0xd4,
		0x34, 0xa1, 0x5a, 0x23, 0x56, 0x6b, 0x04, 0x6b, 0x87, 0x68, 0xf5, 0x12, 0xae, 0x66, 0xe2, 0x35,
		0x46, 0xc0, 0xb3, 0x0b, 0xe9, 0xa9, 0x4a, 0xfe, 0xe9, 0xfc, 0xd6, 0xb5, 0x42, 0x61, 0x91, 0x90,
		0x8d, 0x13, 0xb3, 0x0d, 0x82, 0xb6, 0x48, 0xd4, 0xb6, 0x08, 0xdb, 0x3a, 0x71, 0x5b, 0x27, 0x70,
		0xbb, 0x44, 0x6e, 0x86, 0xd0, 0x0d, 0x11, 0xbb, 0x71, 0x82, 0x5f, 0x54, 0xdc, 0x9e, 0x59, 0xca,
		0xbf, 0x5f, 0x87, 0x7b, 0x26, 0x83, 0xc0, 0xed, 0x60, 0xb0, 0x66, 0xf8, 0xb2, 0xa6, 0x83, 0x82,
		0xcd, 0xe0, 0x20, 0x20, 0x48, 0xd8, 0x0e, 0x16, 0x62, 0x82, 0x86, 0x98, 0xe0, 0x21, 0x23, 0x88,
		0x98, 0x0d, 0x26, 0x86, 0x83, 0xca, 0xec, 0x16, 0x6b, 0x2f, 0xef, 0xfb, 0xe9, 0x8c, 0x1f, 0x7e,
		0xaa, 0xde, 0x75, 0xb1, 0x86, 0xdf, 0xf9, 0xaf, 0x15, 0xb6, 0x9f, 0x93, 0xff, 0x65, 0x0b, 0xd7,
		0xae, 0x46, 0x83, 0xf3, 0xe1, 0x27, 0x61, 0x18, 0x6f, 0x2f, 0x72, 0x88, 0xec, 0x1b, 0xc2, 0x21,
		0xb5, 0x81, 0xef, 0x3b, 0x04, 0xcc, 0x68, 0x1c, 0xe8, 0x17, 0xf4, 0x0b, 0xfa, 0x05, 0xfd, 0x82,
		0x7e, 0xc9, 0x91, 0x7e, 0x19, 0x95, 0x05, 0xd9, 0xe0, 0x77, 0x14, 0x4b, 0x9e, 0x14, 0x4b, 0xac,
		0x7c, 0xcf, 0xef, 0x74, 0x62, 0x95, 0x24, 0x16, 0xf5, 0xca, 0xcd, 0x51, 0xa0, 0x56, 0x50, 0x2b,
		0xa8, 0x15, 0xd4, 0x0a, 0x6a, 0x25, 0x47, 0x6a, 0xc5, 0x22, 0xc3, 0xcf, 0xe9, 0x95, 0x37, 0x16,
		0xae, 0x7d, 0xe8, 0xa7, 0xa9, 0x8a, 0x23, 0x2d, 0xcd, 0x09, 0x1f, 0x34, 0x80, 0x3f, 0x3f, 0xaf,
		0x79, 0xdb, 0x15, 0xef, 0x9d, 0xef, 0x75, 0x8f, 0xbf, 0xaf, 0x5f, 0x7d, 0xf9, 0xf2, 0xea, 0xe5,
		0xcd, 0x67, 0xca, 0xc3, 0x67, 0x56, 0xbf, 0xaf, 0xfd, 0xf2, 0xfa, 0xea, 0x1f, 0xe6, 0x67, 0xde,
		0xb1, 0x8d, 0x4f, 0xe4, 0xe0, 0xa8, 0xf6, 0x3b, 0x1f, 0xcb, 0x0f, 0x3f, 0x96, 0x5c, 0x13, 0x62,
		0x3d, 0x48, 0xd2, 0x4a, 0x9a, 0xc6, 0x76, 0x48, 0xf1, 0x43, 0x10, 0x55, 0x43, 0x35, 0x8c, 0x79,
		0x89, 0x79, 0x01, 0x38, 0x1e, 0x81, 0xff, 0xed, 0xc6, 0x08, 0x4a, 0x6f, 0xca, 0xe5, 0xcd, 0xad,
		0x72, 0x79, 0x6d, 0xeb, 0xf5, 0xd6, 0xda, 0xf6, 0xc6, 0x46, 0x69, 0xb3, 0xb4, 0x61, 0x61, 0x50,
		0x07, 0x71, 0x47, 0xc5, 0xaa, 0xb3, 0x7b, 0x59, 0xd8, 0x59, 0x89, 0x06, 0x61, 0x88, 0xbd, 0x7b,
		0xf6, 0x2d, 0xed, 0x04, 0x89, 0x97, 0x5c, 0x26, 0xa9, 0x3a, 0xcf, 0xf2, 0x7c, 0xd3, 0x47, 0x47,
		0xff, 0xf9, 0x61, 0x60, 0xf0, 0x30, 0x78, 0x18, 0x3c, 0x0c, 0x1e, 0x06, 0x2f, 0x47, 0x06, 0xcf,
		0x16, 0xbd, 0xe3, 0xee, 0xfe, 0x5c, 0x30, 0x0d, 0x3f, 0x79, 0x02, 0x93, 0xc7, 0xa7, 0x63, 0xd3,
		0xeb, 0xe5, 0x52, 0x69, 0x87, 0xbd, 0xb6, 0x1f, 0x7a, 0xea, 0x5b, 0xaa, 0xa2, 0x8e, 0xea, 0x78,
		0xed, 0x20, 0x6e, 0x0f, 0x82, 0xd4, 0xaa, 0xea, 0xbe, 0x7f, 0x48, 0x28, 0x70, 0x14, 0x38, 0x0a,
		0x1c, 0x05, 0x8e, 0x02, 0xcf, 0x91, 0x02, 0xb7, 0x4f, 0xf4, 0x37, 0xc9, 0x7e, 0xcb, 0xc2, 0xa5,
		0x1b, 0xa3, 0x23, 0x93, 0x6c, 0x49, 0x3d, 0x3b, 0x6c, 0xb7, 0x32, 0x49, 0x28, 0x5b, 0xa3, 0x5b,
		0xcb, 0x51, 0x7e, 0x61, 0x18, 0x9f, 0xfc, 0x70, 0xa0, 0x04, 0x8c, 0xe3, 0x5d, 0xec, 0xb7, 0xd3,
		0xa0, 0x17, 0xed, 0x05, 0xa7, 0xc1, 0x38, 0xcf, 0x6f, 0x6d, 0x3c, 0x57, 0xbf, 0x58, 0x84, 0xa6,
		0xff, 0x0d, 0x68, 0xde, 0x82, 0x66, 0x79, 0x7d, 0xbb, 0xbc, 0xbd, 0xb9, 0xb5, 0xbe, 0xbd, 0x01,
		0x46, 0xed, 0xa8, 0x03, 0x7b, 0x57, 0xc5, 0x6b, 0x3f, 0x1f, 0xb6, 0xe7, 0x83, 0x30, 0x0d, 0xbc,
		0xb4, 0xd7, 0xef, 0x85, 0xbd, 0xd3, 0x4b, 0x7b, 0x06, 0xfb, 0xd6, 0x38, 0x70, 0xd5, 0xb8, 0x6a,
		0x5c, 0x35, 0xae, 0x1a, 0x57, 0x9d, 0x23, 0x57, 0x7d, 0xd2, 0xeb, 0x85, 0xca, 0x8f, 0x6c, 0xae,
		0x6a, 0x95, 0x90, 0x0c, 0xcf, 0xbe, 0x97, 0x91, 0x0a, 0x4e, 0xcf, 0x4e, 0x7a, 0xf1, 0x2c, 0x39,
		0x62, 0x77, 0x83, 0xe6, 0xdd, 0xc3, 0x41, 0x40, 0x20, 0x20, 0x10, 0x10, 0x08, 0x08, 0x04, 0x44,
		0x8e, 0x04, 0x04, 0xfb, 0x34, 0xd9, 0xa7, 0x99, 0xa1, 0x7e, 0x11, 0x55, 0x61, 0xf0, 0xc3, 0x51,
		0xa1, 0x66, 0x50, 0x33, 0xa8, 0x19, 0xd4, 0x0c, 0x6a, 0x26, 0x47, 0x6a, 0x86, 0x22, 0x03, 0x8a,
		0x0c, 0x2c, 0x7e, 0x51, 0x64, 0x30, 0x3f, 0x0e, 0x8a, 0x0c, 0x56, 0x28, 0x32, 0xb8, 0x1b, 0x9a,
		0x14, 0x19, 0xd8, 0x56, 0x07, 0xf6, 0xae, 0x4a, 0x91, 0x41, 0x86, 0x8e, 0x3b, 0xe8, 0x5f, 0x94,
		0xed, 0xb7, 0x48, 0xba, 0x7b, 0x38, 0x78, 0x6c, 0x3c, 0x36, 0x1e, 0x1b, 0x8f, 0x8d, 0xc7, 0xce,
		0x91, 0xc7, 0xbe, 0xc9, 0xf0, 0x5e, 0xd4, 0xf3, 0xfe, 0x5f, 0x2f, 0x52, 0xec, 0xaa, 0x35, 0x3c,
		0x80, 0x97, 0xa3, 0x5e, 0x3c, 0xc7, 0x7f, 0x7f, 0x2e, 0x79, 0xdb, 0xc7, 0xe3, 0x87, 0xa5, 0xd1,
		0x8f, 0xf1, 0xe3, 0xf5, 0xcf, 0x6b, 0x5e, 0x79, 0xfa, 0x78, 0xe3, 0xf3, 0x9a, 0xb7, 0x71, 0xbc,
		0x3a, 0x6a, 0xd7, 0xf3, 0xfa, 0xea, 0xf1, 0x7f, 0xf8, 0xf2, 0x7f, 0x3e, 0x7f, 0xf9, 0xd2, 0xff,
		0xbe, 0x7f, 0x35, 0xfc, 0x5e, 0xbf, 0x3a, 0xfe, 0xd7, 0xea, 0xbf, 0x6d, 0x31, 0xdd, 0x70, 0x60,
		0x5f, 0xbe, 0xbc, 0x3a, 0xfe, 0x27, 0xbb, 0x50, 0x5d, 0x17, 0xad, 0x9b, 0xb2, 0x44, 0xeb, 0x26,
		0xa2, 0x15, 0xd1, 0x8a, 0x68, 0x45, 0xb4, 0x22, 0x5a, 0x73, 0x2a, 0x5a, 0x37, 0x11, 0xad, 0xd6,
		0x45, 0xeb, 0xce, 0xdf, 0x43, 0x05, 0xe7, 0x7b, 0xdd, 0x8a, 0xf7, 0xee, 0xf8, 0xfb, 0xda, 0x2f,
		0xe5, 0xab, 0xd5, 0x9d, 0xd5, 0x97, 0xb7, 0x9f, 0xdb, 0x59, 0xfd, 0xbe, 0xf6, 0xcb, 0xc6, 0xd5,
		0xcb, 0x97, 0x77, 0xfc, 0x9f, 0x7f, 0xdf, 0xf5, 0x1a, 0xab, 0x7f, 0xbf, 0x7c, 0xf9, 0x72, 0x22,
		0x57, 0xe7, 0x24, 0xec, 0xe7, 0xb5, 0xd2, 0xf1, 0xbf, 0x47, 0x0f, 0xc7, 0xdf, 0x67, 0x22, 0xf8,
		0x41, 0xff, 0x78, 0x55, 0x92, 0xf4, 0x7d, 0xf9, 0xf2, 0xf3, 0x9f, 0x3b, 0xc7, 0xff, 0xda, 0x59,
		0xfd, 0xbe, 0x79, 0x35, 0x7d, 0x3c, 0xfa, 0xbe, 0xfa, 0xf7, 0xcb, 0x57, 0xff, 0xfc, 0xf2, 0xe5,
		0xd5, 0xab, 0x7f, 0xae, 0x8e, 0x6f, 0xc4, 0xe4, 0xdf, 0xfd, 0x73, 0xfc, 0x7f, 0xff, 0xbd, 0xb3,
		0xb3, 0xf0, 0xd4, 0xea, 0xcb, 0xff, 0x79, 0x65, 0x59, 0xc5, 0x8f, 0x3f, 0xbf, 0x1d, 0xc4, 0xbc,
		0xfb, 0x62, 0x3e, 0x89, 0xfa, 0xbe, 0x00, 0x11, 0x3f, 0x1a, 0x06, 0xe2, 0x1d, 0xf1, 0x8e, 0x78,
		0x47, 0xbc, 0x23, 0xde, 0x73, 0x24, 0xde, 0x2d, 0x30, 0xbb, 0x75, 0xb1, 0x5e, 0x57, 0xd1, 0x69,
		0x7a, 0x46, 0x21, 0x97, 0xa5, 0x41, 0x50, 0xc8, 0x35, 0x37, 0x0e, 0x0a, 0xb9, 0x56, 0x28, 0xe4,
		0xba, 0x1b, 0x9a, 0xeb, 0x60, 0xd3, 0x92, 0x10, 0xb0, 0x77, 0x55, 0xec, 0x73, 0x06, 0xf6, 0x39,
		0xec, 0x5b, 0xdd, 0x1b, 0x35, 0xba, 0x3c, 0x76, 0x19, 0xbb, 0x8c, 0x5d, 0xc6, 0x2e, 0x63, 0x97,
		0x73, 0x64, 0x97, 0x55, 0x34, 0x38, 0x57, 0xb1, 0x3f, 0xd4, 0x44, 0xec, 0xe9, 0xce, 0x23, 0xc4,
		0x38, 0x1e, 0x8c, 0xe3, 0xc1, 0x96, 0x41, 0x22, 0xf7, 0xe3, 0xa0, 0x17, 0x07, 0xa9, 0xc5, 0x16,
		0x8a, 0xb3, 0x11, 0x20, 0x94, 0x11, 0xca, 0x08, 0x65, 0x84, 0x32, 0x42, 0x39, 0x47, 0x42, 0x79,
		0x10, 0x44, 0xe9, 0x1b, 0x8b, 0x12, 0x79, 0x83, 0xfe, 0x00, 0x46, 0x65, 0x2b, 0xb9, 0xfb, 0xc9,
		0x30, 0x58, 0x56, 0xb2, 0xcd, 0x7e, 0xb7, 0xfd, 0x0c, 0xd0, 0xbc, 0x05, 0xcd, 0xd2, 0xfa, 0x16,
		0xe0, 0xb4, 0x23, 0x04, 0xec, 0x5d, 0x95, 0x75, 0xa5, 0xe7, 0xc3, 0x36, 0x56, 0xe7, 0x7e, 0x10,
		0x05, 0xd1, 0xa9, 0x77, 0xd6, 0x0b, 0x3b, 0x5e, 0x1a, 0x9c, 0x5b, 0x6c, 0x24, 0x7c, 0xd7, 0x60,
		0xb0, 0xd2, 0x58, 0x69, 0xac, 0x34, 0x56, 0x1a, 0x2b, 0x9d, 0x33, 0x2b, 0x5d, 0xda, 0xb4, 0xe8,
		0xa5, 0x37, 0xf1, 0xd2, 0x78, 0x69, 0xbc, 0x34, 0x5e, 0x1a, 0x2f, 0xbd, 0x00, 0xcd, 0xcd, 0x8d,
		0x8d, 0xd7, 0xb4, 0xd9, 0xc3, 0x4d, 0xe3, 0xa6, 0x9f, 0xe0, 0xa6, 0x93, 0xd4, 0x8f, 0x53, 0x2f,
		0x49, 0xfd, 0x74, 0x90, 0xd8, 0x34, 0xd2, 0x73, 0xe3, 0xc0, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78,
		0x68, 0x3c, 0x74, 0x8e, 0x3c, 0x34, 0x67, 0xf9, 0xe5, 0x4b, 0x32, 0x0c, 0xfa, 0xfd, 0x5e, 0x9c,
		0x0a, 0xd0, 0x0c, 0x93, 0x81, 0x20, 0x1a, 0x10, 0x0d, 0x88, 0x06, 0x44, 0x03, 0xa2, 0x01, 0xd1,
		0x80, 0x68, 0x90, 0x2b, 0x1a, 0xec, 0x36, 0x45, 0x5d, 0x18, 0x09, 0xb2, 0x01, 0xd9, 0x80, 0x6c,
		0x40, 0x36, 0x20, 0x1b, 0x90, 0x0d, 0xc8, 0x06, 0x59, 0xb2, 0x21, 0xb9, 0x4c, 0x52, 0x75, 0x6e,
		0xf5, 0x90, 0xdd, 0xeb, 0x21, 0x20, 0x14, 0x10, 0x0a, 0x08, 0x05, 0x84, 0x02, 0x42, 0x21, 0x47,
		0x42, 0xc1, 0x16, 0xbd, 0xaf, 0x2c, 0x7d, 0xb7, 0xf4, 0x3f, 0x3f, 0xaf, 0x79, 0xdb, 0x15, 0xef,
		0x9d, 0xef, 0x75, 0x8f, 0xbf, 0x97, 0xaf, 0xbe, 0x7c, 0x79, 0xf5, 0x93, 0x27, 0xfe, 0x61, 0xa1,
		0x8f, 0xb6, 0x8d, 0x0f, 0xe6, 0xe0, 0xa8, 0xf6, 0x3b, 0x9f, 0xce, 0x43, 0x3e, 0x1d, 0x14, 0xf6,
		0xb3, 0x3f, 0xe7, 0xb4, 0xd7, 0xef, 0x85, 0xbd, 0x53, 0x8b, 0x3d, 0x28, 0x66, 0x23, 0x40, 0x5f,
		0xa3, 0xaf, 0xd1, 0xd7, 0xe8, 0x6b, 0xf4, 0x75, 0x8e, 0xf4, 0x75, 0xd0, 0x51, 0x51, 0x1a, 0xa4,
		0x97, 0xb1, 0xea, 0xda, 0x54, 0xd8, 0x36, 0x5a, 0x51, 0xd4, 0x26, 0x6f, 0x7d, 0xd7, 0x4f, 0x2c,
		0xf2, 0xce, 0xf4, 0x83, 0xa8, 0xbc, 0xab, 0xb5, 0x8e, 0x86, 0xdf, 0x9a, 0x7f, 0x1c, 0x56, 0x6d,
		0x71, 0xcf, 0xa8, 0x62, 0x3f, 0xb1, 0xa6, 0x6a, 0x57, 0xac, 0x6e, 0x2b, 0x9a, 0xfb, 0x38, 0x6a,
		0x87, 0x9f, 0xca, 0xad, 0x8f, 0xfb, 0xb5, 0xb7, 0x95, 0xa3, 0x66, 0x61, 0x19, 0x77, 0xb2, 0xc8,
		0xf9, 0x1c, 0x36, 0x5b, 0x1f, 0x3e, 0xd6, 0x9b, 0x7c, 0x12, 0x12, 0x66, 0x04, 0x9f, 0x84, 0x94,
		0x39, 0x61, 0x9f, 0x9b, 0xac, 0x5c, 0xf9, 0x18, 0x05, 0x9a, 0x29, 0xa6, 0xe8, 0xe5, 0x4a, 0x2f,
		0x57, 0x5b, 0x78, 0x37, 0x99, 0x47, 0x1b, 0xf4, 0x2d, 0xb7, 0xa2, 0x99, 0x0e, 0x80, 0x2c, 0x9a,
		0xd6, 0x0b, 0x93, 0x45, 0x23, 0x8b, 0x46, 0x16, 0x6d, 0xb9, 0x34, 0x8c, 0xfd, 0x2c, 0xda, 0x90,
		0xd9, 0x93, 0xd4, 0x3f, 0xef, 0x5b, 0xcc, 0xa1, 0x6d, 0xd1, 0x81, 0xc6, 0xa8, 0x70, 0xa5, 0xcd,
		0xc7, 0x64, 0x18, 0x74, 0xa0, 0x91, 0x94, 0xa3, 0xa0, 0x03, 0xcd, 0x1d, 0xd0, 0x2c, 0xaf, 0x6f,
		0x97, 0xb7, 0x37, 0xb7, 0xd6, 0xb7, 0x69, 0x43, 0x63, 0x39, 0x7f, 0x43, 0x1b, 0x1a, 0xb7, 0xae,
		0x64, 0x88, 0xc9, 0x0a, 0x95, 0x28, 0xea, 0xa5, 0xe3, 0x33, 0xa3, 0x4c, 0x92, 0x57, 0x21, 0x69,
		0x9f, 0xa9, 0x73, 0xbf, 0xef, 0x8f, 0xce, 0x3a, 0x2e, 0x14, 0x7b, 0x7d, 0x15, 0xb5, 0x47, 0xde,
		0xd5, 0x8b, 0x54, 0xfa, 0x57, 0x2f, 0xfe, 0xea, 0x05, 0x51, 0x92, 0xfa, 0x51, 0x5b, 0x15, 0x6f,
		0x3f, 0x91, 0x2c, 0x3c, 0x53, 0xec, 0xc7, 0xbd, 0xb4, 0xd7, 0xee, 0x85, 0xc9, 0xec, 0x51, 0x71,
		0x28, 0xf8, 0x8b, 0x41, 0x94, 0xaa, 0xb8, 0xeb, 0x0f, 0xff, 0x66, 0xf6, 0xb0, 0x18, 0xaa, 0x0b,
		0x15, 0x26, 0xe3, 0x1f, 0x45, 0xbf, 0xf3, 0x5f, 0xbf, 0xad, 0xa2, 0x76, 0xa0, 0x92, 0xd9, 0xe3,
		0xcb, 0x62, 0x92, 0xfa, 0xa9, 0xc9, 0x94, 0x41, 0x21, 0x49, 0xe3, 0x41, 0x3b, 0x8d, 0x26, 0xb2,
		0xf6, 0x60, 0x76, 0x37, 0xf6, 0xc7, 0xef, 0xb4, 0x36, 0x79, 0xa3, 0xad, 0x5b, 0xbf, 0x27, 0xb7,
		0x9f, 0x68, 0x1d, 0x4e, 0xef, 0xc4, 0xec, 0x51, 0xab, 0x96, 0x04, 0x49, 0xab, 0x36, 0xbb, 0x13,
		0xd7, 0x0f, 0x5b, 0xf5, 0xd1, 0x9d, 0x18, 0xff, 0x68, 0x55, 0xae, 0xef, 0xc4, 0xec, 0xf1, 0x65,
		0xeb, 0x68, 0x74, 0x27, 0x5e, 0xe4, 0x63, 0x62, 0x19, 0x98, 0x54, 0x16, 0xb6, 0x66, 0x58, 0xab,
		0xd9, 0x35, 0xac, 0x36, 0x8c, 0x27, 0xb7, 0x6c, 0x24, 0xb5, 0x2c, 0x26, 0xb3, 0x6c, 0x25, 0xb1,
		0xac, 0x27, 0xaf, 0xac, 0x27, 0xad, 0xec, 0x26, 0xab, 0xf2, 0x25, 0x68, 0x8c, 0x27, 0xa5, 0x66,
		0x33, 0x36, 0x54, 0x7e, 0xd7, 0x6c, 0x39, 0xd7, 0xac, 0x8c, 0xcb, 0x60, 0x0e, 0xaa, 0x70, 0x38,
		0xd1, 0x6c, 0xaf, 0x5e, 0x8d, 0x65, 0x52, 0xf1, 0x3a, 0xec, 0xe4, 0x45, 0x26, 0xbc, 0x70, 0x78,
		0x22, 0x0c, 0xd9, 0xd4, 0xa4, 0x18, 0x30, 0xbb, 0x92, 0x6d, 0x7e, 0xe5, 0x5a, 0xc4, 0x4a, 0xb5,
		0xd9, 0x95, 0x69, 0xdd, 0x08, 0x35, 0xec, 0x39, 0x65, 0x7b, 0xcd, 0x82, 0x09, 0x4f, 0x22, 0xd4,
		0x5d, 0xea, 0x0d, 0x18, 0xfa, 0x68, 0x5c, 0xcf, 0x2b, 0x6b, 0x9a, 0x76, 0xa6, 0xa6, 0x9b, 0xc4,
		0x69, 0xa6, 0x71, 0x72, 0x09, 0x9b, 0x54, 0x7a, 0xa6, 0x52, 0xf6, 0x40, 0xd7, 0x00, 0xf2, 0x82,
		0xdf, 0x0d, 0xbc, 0xc4, 0xef, 0x06, 0xda, 0xe0, 0x3d, 0x93, 0xf8, 0xb3, 0x2b, 0x69, 0x9a, 0xaa,
		0x53, 0x3d, 0xaf, 0xe9, 0xe5, 0x75, 0x27, 0x50, 0x4c, 0x24, 0x4c, 0x0c, 0x26, 0x48, 0x4c, 0x25,
		0x44, 0x8c, 0x27, 0x40, 0x8c, 0x27, 0x3c, 0xcc, 0x26, 0x38, 0xdc, 0x0a, 0xcf, 0x7b, 0x81, 0x5e,
		0xeb, 0x54, 0xf0, 0xbb, 0xfa, 0x11, 0x7c, 0x4d, 0x90, 0xba, 0xa1, 0xab, 0x97, 0x22, 0x8d, 0x51,
		0xa5, 0x49, 0xca, 0xb4, 0x40, 0x9d, 0xa6, 0x29, 0xd4, 0x1a, 0x95, 0x5a, 0xa3, 0x54, 0x3b, 0xd4,
		0x9a, 0x8f, 0x14, 0x99, 0x6e, 0xca, 0x9d, 0x53, 0xa6, 0x13, 0x87, 0x60, 0x78, 0x2d, 0x70, 0x76,
		0x65, 0x96, 0x02, 0x5d, 0xa3, 0x69, 0x8b, 0x74, 0x6d, 0x8b, 0xb6, 0xad, 0xd3, 0xb7, 0x75, 0x1a,
		0xb7, 0x4b, 0xe7, 0x66, 0x68, 0xdd, 0x10, 0xbd, 0xcf, 0x6e, 0x25, 0x4b, 0x81, 0xba, 0x49, 0xf1,
		0x7a, 0x29, 0x70, 0x9c, 0xfb, 0x2a, 0xce, 0xc2, 0x0e, 0x15, 0x43, 0x0f, 0xbe, 0x8b, 0xed, 0x69,
		0x2c, 0x33, 0x2c, 0x11, 0x26, 0xd7, 0x35, 0x2b, 0x10, 0x4a, 0x08, 0x04, 0x04, 0x02, 0x02, 0x01,
		0x81, 0x20, 0x41, 0x20, 0x98, 0xf2, 0x81, 0xf6, 0xfc, 0xa0, 0x6d, 0x5f, 0x68, 0xc9, 0x1f, 0x5a,
		0x0b, 0x03, 0x36, 0xc3, 0x81, 0x80, 0xb0, 0x60, 0x3b, 0x3c, 0x88, 0x09, 0x13, 0x62, 0xc2, 0x85,
		0x8c, 0xb0, 0x61, 0x36, 0x7c, 0x18, 0x0e, 0x23, 0xf6, 0xfc, 0xe6, 0xc2, 0x8c, 0xa7, 0xab, 0xa0,
		0xa0, 0xae, 0x82, 0x34, 0x14, 0xb4, 0xf8, 0x35, 0xd7, 0xb4, 0x8b, 0xa6, 0x69, 0x56, 0xef, 0x7f,
		0x99, 0x66, 0x69, 0x39, 0x0b, 0xac, 0xb9, 0x6c, 0x55, 0xa5, 0x22, 0xff, 0x24, 0x54, 0x16, 0x8f,
		0x54, 0x9a, 0x0e, 0x00, 0x6b, 0x86, 0x35, 0xc3, 0x9a, 0x61, 0xcd, 0xb0, 0x66, 0x39, 0xb2, 0x66,
		0x9c, 0xbc, 0x98, 0x0b, 0x91, 0x70, 0xae, 0xd2, 0x38, 0x68, 0xdb, 0xd3, 0x08, 0x93, 0xeb, 0x1b,
		0x9e, 0x3e, 0x7b, 0xaa, 0xeb, 0x0f, 0xc2, 0x11, 0x41, 0x95, 0xd6, 0xd0, 0x27, 0xe8, 0x13, 0xf4,
		0x09, 0xfa, 0x04, 0x7d, 0x92, 0x27, 0x7d, 0x32, 0x08, 0xa2, 0xf4, 0xf5, 0x3a, 0x7d, 0x34, 0x0d,
		0x7e, 0xd1, 0x47, 0x93, 0x3e, 0x9a, 0x37, 0xc6, 0x41, 0x1f, 0xcd, 0x15, 0xfa, 0x68, 0xde, 0x0d,
		0x4d, 0xfa, 0x68, 0xda, 0x16, 0x04, 0xf6, 0xae, 0xca, 0x69, 0xae, 0xcf, 0x87, 0x6d, 0x62, 0xbf,
		0xf0, 0x2a, 0xa1, 0xf2, 0x0a, 0xfb, 0x8c, 0x7d, 0xc6, 0x3e, 0x63, 0x9f, 0xf3, 0x68, 0x9f, 0xa9,
		0xbc, 0x12, 0x52, 0x79, 0xc5, 0x59, 0xae, 0x62, 0x4a, 0x7f, 0x38, 0xc6, 0xd5, 0xfa, 0x47, 0x20,
		0xe1, 0xdc, 0x50, 0x4a, 0xb0, 0xdc, 0xf6, 0x69, 0x9c, 0x77, 0x90, 0x85, 0x03, 0x95, 0xd2, 0x1c,
		0x6f, 0xd2, 0xc1, 0xac, 0xe8, 0x77, 0x8b, 0x46, 0x37, 0x80, 0xae, 0x48, 0xe9, 0x99, 0xd7, 0x0d,
		0x8e, 0xfc, 0x6e, 0xd0, 0xaa, 0x74, 0x5b, 0x13, 0x8b, 0xca, 0x56, 0x65, 0xc1, 0x79, 0x14, 0x6b,
		0xf9, 0x13, 0x3a, 0x9a, 0xe4, 0x2a, 0x3f, 0xc2, 0x86, 0x65, 0x36, 0x2c, 0xbb, 0xaf, 0x5e, 0xe8,
		0x68, 0xa2, 0x9b, 0x14, 0x17, 0x3a, 0x9a, 0x24, 0xb4, 0x34, 0x79, 0x82, 0x4e, 0x50, 0xa7, 0xc3,
		0x19, 0xef, 0xc5, 0xbd, 0x41, 0x1a, 0x44, 0x16, 0x7a, 0x9b, 0xdc, 0x1e, 0x00, 0x4d, 0x4e, 0xf2,
		0xa0, 0x19, 0x92, 0x18, 0xc5, 0xb0, 0x84, 0x8a, 0x21, 0x89, 0xd1, 0x0b, 0x4f, 0xbb, 0x91, 0xe6,
		0x1b, 0x9c, 0x4c, 0x8f, 0x76, 0xf0, 0x92, 0xa0, 0x93, 0x58, 0x6c, 0x73, 0x32, 0x3f, 0x0e, 0x3b,
		0x4b, 0xee, 0x25, 0x96, 0xdc, 0xf3, 0x1b, 0x1e, 0x6c, 0x87, 0x09, 0x31, 0xe1, 0x42, 0x4c, 0xd8,
		0x90, 0x10, 0x3e, 0xcc, 0x86, 0x11, 0xc3, 0xe1, 0xc4, 0x5a, 0x58, 0xb9, 0x3b, 0xbc, 0xd8, 0x5f,
		0x6b, 0x9e, 0x1f, 0x8e, 0x25, 0xb4, 0xdb, 0x09, 0x36, 0xd6, 0x83, 0x8e, 0x84, 0xe0, 0x23, 0x26,
		0x08, 0x49, 0x09, 0x46, 0xe2, 0x82, 0x92, 0xb8, 0xe0, 0x24, 0x29, 0x48, 0xd9, 0x09, 0x56, 0x96,
		0x82, 0x96, 0xf5, 0xe0, 0x35, 0x1b, 0x80, 0xe1, 0x7e, 0xbf, 0x3f, 0x25, 0x2d, 0xe3, 0xcb, 0xc0,
		0x02, 0xc3, 0x98, 0x98, 0x70, 0x26, 0x29, 0xac, 0x89, 0x0b, 0x6f, 0xd2, 0xc2, 0x9c, 0xd8, 0x70,
		0x27, 0x36, 0xec, 0x49, 0x0c, 0x7f, 0x76, 0xc3, 0xa0, 0xe5, 0x70, 0x28, 0x26, 0x2c, 0xce, 0x06,
		0x72, 0x1a, 0xf7, 0x06, 0x7d, 0x39, 0x53, 0x7b, 0xca, 0x7d, 0xe3, 0x61, 0x09, 0x99, 0x3d, 0x37,
		0xfa, 0x71, 0x74, 0xfd, 0x30, 0x51, 0x52, 0xc6, 0x25, 0x63, 0xdb, 0xa4, 0xb8, 0x60, 0x2e, 0x31,
		0xa8, 0x8b, 0x0d, 0xee, 0x52, 0x83, 0xbc, 0xf8, 0x60, 0x2f, 0x3e, 0xe8, 0x4b, 0x0e, 0xfe, 0x32,
		0x44, 0x80, 0x10, 0x31, 0x30, 0xfb, 0xa0, 0xac, 0xed, 0xab, 0xfa, 0x29, 0x5b, 0xd9, 0x6b, 0xa7,
		0xf6, 0x53, 0x07, 0x5b, 0x7a, 0x01, 0x90, 0x85, 0x80, 0xb8, 0x10, 0xa9, 0xe0, 0xf4, 0xec, 0xa4,
		0x17, 0xcb, 0xd3, 0x93, 0xb3, 0x91, 0x21, 0xdd, 0x90, 0x6e, 0x48, 0x37, 0xa4, 0x1b, 0xd2, 0x0d,
		0xe9, 0xb6, 0x14, 0xd2, 0x2d, 0xe8, 0x7b, 0x7e, 0xa7, 0x13, 0xab, 0x24, 0x91, 0xa8, 0xde, 0xb6,
		0x05, 0x8d, 0x69, 0xf2, 0x19, 0x7e, 0x16, 0x45, 0x01, 0xb2, 0x28, 0xfd, 0x16, 0xb2, 0x2e, 0xca,
		0x02, 0xb1, 0xb5, 0x80, 0xb1, 0x37, 0x02, 0xc7, 0x76, 0xe8, 0xa7, 0xa9, 0x8a, 0x23, 0x71, 0x70,
		0x9b, 0x0d, 0xf0, 0xe5, 0xcb, 0xcf, 0x6b, 0xde, 0xf6, 0xf1, 0xdf, 0x9f, 0x4b, 0xde, 0xf6, 0xf1,
		0xf8, 0x61, 0x69, 0xf4, 0x63, 0xfc, 0x78, 0xfd, 0xf3, 0x9a, 0x57, 0x9e, 0x3e, 0xde, 0xf8, 0xbc,
		0xe6, 0x6d, 0x1c, 0xaf, 0x7e, 0xf9, 0xf2, 0x6a, 0xf5, 0xfb, 0xeb, 0xab, 0xc7, 0xff, 0xe1, 0xcb,
		0xff, 0xf9, 0xfc, 0xe5, 0x4b, 0xff, 0xfb, 0xfe, 0xd5, 0xf0, 0x7b, 0xfd, 0xea, 0xf8, 0x5f, 0xab,
		0xff, 0x2e, 0x88, 0xbb, 0x2b, 0xc7, 0xa2, 0x46, 0x74, 0xf5, 0x0b, 0x2c, 0xf5, 0x60, 0x96, 0xda,
		0x84, 0xa5, 0x72, 0xcb, 0x52, 0x3b, 0x7f, 0x0f, 0xb9, 0xc4, 0xf7, 0xba, 0x15, 0xef, 0xdd, 0xf1,
		0xf7, 0xb5, 0x5f, 0xca, 0x57, 0xab, 0x3b, 0xab, 0x2f, 0x6f, 0x3f, 0xb7, 0xb3, 0xfa, 0x7d, 0xed,
		0x97, 0x8d, 0xab, 0x97, 0x2f, 0xef, 0xf8, 0x3f, 0xff, 0xbe, 0xeb, 0x35, 0x56, 0xff, 0x7e, 0xf9,
		0xf2, 0xe5, 0x84, 0x9f, 0xe6, 0x38, 0xeb, 0xf3, 0x5a, 0xe9, 0xf8, 0xdf, 0xa3, 0x87, 0xe3, 0xef,
		0x33, 0xd6, 0x7b, 0xd0, 0x3f, 0x5e, 0xbd, 0x93, 0xeb, 0x7e, 0x11, 0x1b, 0x02, 0xfe, 0xdc, 0x39,
		0xfe, 0xd7, 0xce, 0xea, 0xf7, 0xcd, 0xab, 0xe9, 0xe3, 0xd1, 0xf7, 0xd5, 0xbf, 0x5f, 0xbe, 0xfa,
		0xe7, 0x97, 0x2f, 0xaf, 0x5e, 0xfd, 0x73, 0x75, 0x7c, 0xa3, 0x26, 0xff, 0xee, 0x9f, 0xe3, 0xff,
		0xfb, 0xef, 0x9d, 0x9d, 0x85, 0xa7, 0x56, 0x5f, 0xfe, 0xcf, 0x2b, 0x68, 0xdd, 0x11, 0x53, 0x25,
		0xe7, 0xbe, 0x90, 0x56, 0x1d, 0x4e, 0xc4, 0x7e, 0xdc, 0x4b, 0xd5, 0xa8, 0x11, 0xac, 0xa7, 0xc2,
		0xe0, 0x34, 0x38, 0x09, 0x95, 0xbc, 0x0c, 0xeb, 0x5d, 0x83, 0x94, 0xb7, 0x7e, 0x9f, 0xc6, 0x03,
		0x96, 0xef, 0xef, 0x1e, 0x0e, 0x39, 0xe0, 0x47, 0xa0, 0x9d, 0x1c, 0xf0, 0x43, 0x41, 0x4e, 0x0e,
		0xf8, 0x99, 0x03, 0x24, 0x07, 0xec, 0x86, 0x17, 0x66, 0xf9, 0xfe, 0x29, 0xb6, 0x97, 0xe5, 0x7b,
		0x39, 0x3a, 0x33, 0x09, 0x3a, 0x9e, 0xc5, 0x8d, 0x7e, 0xf7, 0xc2, 0x77, 0x32, 0x2e, 0x64, 0x1b,
		0xb2, 0x0d, 0xd9, 0x86, 0x6c, 0x43, 0xb6, 0x21, 0xdb, 0x96, 0x42, 0xb6, 0x0d, 0xa2, 0xa0, 0x17,
		0xb1, 0x6a, 0xff, 0xa0, 0x8f, 0x8f, 0x55, 0xfb, 0x87, 0x8a, 0xa9, 0xd8, 0x1b, 0xea, 0xa9, 0x74,
		0x78, 0xdb, 0x04, 0x2f, 0x87, 0x6d, 0x0b, 0x1c, 0x9b, 0x48, 0xa8, 0xc9, 0x85, 0xdc, 0x02, 0xf4,
		0xce, 0xfb, 0x61, 0xe2, 0x85, 0xfe, 0x89, 0x0a, 0x85, 0x2e, 0x79, 0x49, 0x47, 0xa0, 0x1b, 0x48,
		0x94, 0x8f, 0xc8, 0xc5, 0x48, 0x6b, 0xeb, 0x38, 0xd6, 0xa7, 0xa2, 0x73, 0xcb, 0x81, 0xa1, 0xda,
		0x3d, 0xee, 0x35, 0x7f, 0x68, 0x9d, 0xdd, 0x58, 0x09, 0xc7, 0xc9, 0x3a, 0x9e, 0x36, 0x79, 0xf0,
		0xb0, 0xa7, 0x67, 0x82, 0x96, 0x36, 0x1d, 0x1b, 0xb8, 0xa0, 0xb3, 0x43, 0x1d, 0x75, 0x86, 0x0f,
		0x9b, 0x8b, 0xfe, 0x37, 0xe6, 0xa2, 0xe9, 0xb9, 0xb8, 0x56, 0x7e, 0xb3, 0xb1, 0xb5, 0xc1, 0x84,
		0x34, 0x36, 0x21, 0x5f, 0x30, 0xca, 0x2c, 0xbe, 0x8e, 0x5f, 0x40, 0xbb, 0xcb, 0x60, 0x27, 0x54,
		0x34, 0x38, 0x57, 0xf1, 0xf8, 0xdc, 0x2b, 0x77, 0x3c, 0x45, 0xa9, 0xec, 0xc0, 0x58, 0xab, 0xd1,
		0xe0, 0x7c, 0x18, 0x70, 0x65, 0x4f, 0x76, 0xb9, 0xa3, 0x93, 0x49, 0x41, 0x42, 0xa9, 0xc7, 0x81,
		0x9c, 0x9a, 0xf0, 0xed, 0x0d, 0x0b, 0x1c, 0xf3, 0x46, 0xf0, 0x18, 0xa5, 0x6f, 0x77, 0x98, 0x0d,
		0x74, 0x7e, 0x1b, 0x43, 0x69, 0xbc, 0xc1, 0x61, 0xeb, 0xea, 0xf6, 0x93, 0x7f, 0xdf, 0xf5, 0xcf,
		0x4a, 0xbf, 0x6c, 0x5d, 0xed, 0xdc, 0xf3, 0x7f, 0x36, 0xaf, 0x76, 0x1e, 0xf8, 0x1a, 0x1b, 0x57,
		0x2f, 0x17, 0xfe, 0xe9, 0xf0, 0xf9, 0xf5, 0xfb, 0xfe, 0xa0, 0x7c, 0xcf, 0x1f, 0xbc, 0xbe, 0xef,
		0x0f, 0x5e, 0xdf, 0xf3, 0x07, 0xf7, 0x0e, 0x69, 0xfd, 0x9e, 0x3f, 0xd8, 0xb8, 0xfa, 0x7b, 0xe1,
		0xdf, 0xbf, 0xbc, 0xfb, 0x9f, 0x6e, 0x5e, 0xad, 0xfe, 0x7d, 0xdf, 0xff, 0xdb, 0xba, 0xfa, 0x7b,
		0x67, 0x75, 0xb5, 0x20, 0x97, 0xd8, 0x25, 0x4f, 0xac, 0x83, 0xa3, 0xda, 0xef, 0xce, 0xcc, 0xae,
		0x3f, 0x99, 0x5e, 0xb6, 0xa6, 0xd7, 0x3f, 0x0a, 0x08, 0x27, 0xc7, 0x85, 0x26, 0xfb, 0x64, 0x9d,
		0x12, 0x94, 0x8e, 0x78, 0x56, 0xc9, 0x1e, 0x55, 0xa8, 0x27, 0x65, 0x2f, 0xa1, 0xb4, 0xfb, 0xb1,
		0xdc, 0x2d, 0x8f, 0x2d, 0x9d, 0x05, 0x7f, 0xef, 0x78, 0x24, 0x9e, 0x11, 0x7f, 0xeb, 0x20, 0xcd,
		0xe2, 0xfc, 0xc1, 0x6a, 0xf3, 0xbf, 0x16, 0x45, 0x9c, 0x24, 0xb0, 0x22, 0xef, 0xa0, 0xf9, 0xa3,
		0xf1, 0x4d, 0x6c, 0x8c, 0xef, 0x61, 0xab, 0x32, 0xbd, 0x69, 0x47, 0x41, 0x27, 0x99, 0xfb, 0xcd,
		0xe8, 0x91, 0xf4, 0xf2, 0x48, 0xc1, 0x22, 0x21, 0xc8, 0xe9, 0x14, 0x29, 0xad, 0x43, 0xa4, 0x90,
		0xb5, 0x59, 0x4e, 0xe6, 0xf8, 0x11, 0x56, 0x38, 0x99, 0xe3, 0x3e, 0xf0, 0x72, 0x32, 0xc7, 0x63,
		0x55, 0x11, 0x27, 0x73, 0xc8, 0x92, 0xa9, 0x62, 0xb6, 0x83, 0xcc, 0xd8, 0x26, 0x54, 0x7e, 0x37,
		0x56, 0x5d, 0x09, 0x7c, 0x33, 0x75, 0xe1, 0x02, 0xca, 0x4f, 0x0b, 0x87, 0x13, 0xe5, 0xfe, 0xea,
		0xd5, 0x44, 0x09, 0x17, 0x67, 0x21, 0x1c, 0x41, 0x67, 0xde, 0x02, 0xc8, 0xd8, 0x3b, 0x2c, 0x6b,
		0xcf, 0x30, 0x62, 0x0e, 0x31, 0x87, 0x98, 0x43, 0xcc, 0x21, 0xe6, 0x10, 0x73, 0x88, 0xb9, 0xc7,
		0x89, 0xb9, 0x49, 0x00, 0x47, 0xca, 0x99, 0x97, 0x72, 0xa9, 0x9f, 0x2a, 0x41, 0x4a, 0x6e, 0x34,
		0x1c, 0xce, 0xcb, 0x9d, 0x13, 0x72, 0xeb, 0x08, 0x39, 0x84, 0x1c, 0x42, 0x0e, 0x21, 0xb7, 0x24,
		0x42, 0x4e, 0xcc, 0x79, 0xb9, 0x7e, 0x18, 0xf6, 0xda, 0x7e, 0xaa, 0x3a, 0x5e, 0xe7, 0x32, 0xf2,
		0xcf, 0x83, 0xb6, 0x37, 0xfc, 0x3d, 0x94, 0xd7, 0x34, 0xed, 0xbe, 0x81, 0xd2, 0x45, 0x4d, 0x72,
		0x86, 0x44, 0x62, 0x80, 0x15, 0x1b, 0x68, 0xa5, 0x06, 0x5c, 0xf1, 0x81, 0x57, 0x7c, 0x00, 0x96,
		0x1c, 0x88, 0x65, 0x04, 0x64, 0x21, 0x81, 0x59, 0x5e, 0xa6, 0x65, 0xd1, 0x3f, 0x8a, 0x6c, 0x78,
		0x45, 0x2f, 0xb5, 0x87, 0x7e, 0x09, 0xae, 0x99, 0x16, 0xdd, 0xd0, 0x8a, 0x56, 0x6a, 0xf9, 0x41,
		0xdc, 0x02, 0xf2, 0xc4, 0x37, 0xac, 0x72, 0xa0, 0x51, 0x95, 0x23, 0x0d, 0xaa, 0x1c, 0xe8, 0x7b,
		0xe0, 0x52, 0x43, 0x2a, 0xc7, 0x9a, 0xdf, 0x38, 0xd7, 0x80, 0xca, 0xc5, 0x3e, 0x37, 0x0e, 0x34,
		0x9c, 0x72, 0xaa, 0xd1, 0x94, 0xb3, 0x73, 0xcc, 0xa5, 0xc6, 0x52, 0x4e, 0x4e, 0x34, 0xba, 0xb6,
		0x3c, 0xe9, 0x8b, 0xae, 0x2d, 0xf9, 0x92, 0xef, 0x6e, 0x34, 0x88, 0x72, 0xa1, 0x31, 0x94, 0xf0,
		0x86, 0x50, 0xec, 0xcf, 0x77, 0x8a, 0x42, 0x38, 0xc7, 0xfa, 0xd9, 0x5c, 0xc1, 0x39, 0xd6, 0x4f,
		0x18, 0x20, 0x1d, 0x67, 0x68, 0xe8, 0x34, 0x23, 0x68, 0x89, 0x13, 0xc8, 0x85, 0x06, 0x4e, 0x34,
		0x6e, 0xa2, 0x71, 0x93, 0x5c, 0xa1, 0x43, 0x37, 0x16, 0x61, 0xf7, 0x43, 0xc2, 0x89, 0x9b, 0xa7,
		0x71, 0x6f, 0xd0, 0x97, 0x57, 0x3b, 0x36, 0x1e, 0x96, 0xbc, 0xd3, 0xdb, 0xbb, 0x7e, 0x98, 0x70,
		0x7c, 0xfb, 0xdd, 0xc3, 0xa1, 0x82, 0xed, 0x11, 0x00, 0xa7, 0x82, 0xed, 0xa1, 0x20, 0xa7, 0x82,
		0xed, 0x99, 0x03, 0xa4, 0x82, 0xcd, 0x8d, 0x14, 0x10, 0xc7, 0xb7, 0x3f, 0x25, 0xdb, 0xc3, 0xf1,
		0xed, 0x72, 0xc4, 0xa4, 0x98, 0x9e, 0x5a, 0x0b, 0x00, 0x16, 0xd2, 0x5b, 0x0b, 0xe9, 0x86, 0x74,
		0x43, 0xba, 0x21, 0xdd, 0x90, 0x6e, 0x48, 0x37, 0x43, 0x6c, 0x15, 0xf4, 0x05, 0xae, 0xd9, 0xb1,
		0xf7, 0xe0, 0xa1, 0x5f, 0xb2, 0xd7, 0x83, 0xcb, 0xac, 0x07, 0x3f, 0x51, 0xdf, 0xb8, 0xb1, 0x1e,
		0x7c, 0xfc, 0xf7, 0xe7, 0x92, 0xb7, 0x7d, 0x3c, 0x7e, 0x58, 0x1a, 0xfd, 0x18, 0x3f, 0x5e, 0xff,
		0xbc, 0xe6, 0x95, 0xa7, 0x8f, 0x37, 0x3e, 0xaf, 0x79, 0x1b, 0xc7, 0xab, 0x5f, 0xbe, 0xbc, 0x5a,
		0xfd, 0xfe, 0xfa, 0xea, 0xf1, 0x7f, 0xf8, 0xf2, 0x7f, 0x3e, 0x7f, 0xf9, 0xd2, 0xff, 0xbe, 0x7f,
		0x35, 0xfc, 0x5e, 0xbf, 0x3a, 0xfe, 0xd7, 0xea, 0xbf, 0x59, 0xcc, 0x71, 0x22, 0xee, 0xb9, 0xc1,
		0x52, 0x54, 0xad, 0xe4, 0x97, 0xa5, 0x76, 0xe6, 0x96, 0x90, 0xd7, 0x7e, 0x29, 0x5f, 0xad, 0xee,
		0xac, 0xbe, 0xbc, 0xfd, 0xdc, 0xce, 0xea, 0xf7, 0xb5, 0x5f, 0x36, 0xae, 0x5e, 0xbe, 0xbc, 0xe3,
		0xff, 0xfc, 0xfb, 0xae, 0xd7, 0x58, 0xfd, 0xfb, 0xe5, 0xcb, 0x97, 0x13, 0x7e, 0x9a, 0xe3, 0xac,
		0xcf, 0x6b, 0xa5, 0xe3, 0x7f, 0x8f, 0x1e, 0x8e, 0xbf, 0xcf, 0x58, 0xef, 0x41, 0xff, 0x78, 0xf5,
		0x4e, 0xae, 0xfb, 0x45, 0x6c, 0x08, 0xf8, 0x73, 0xe7, 0xf8, 0x5f, 0x3b, 0xab, 0xdf, 0x37, 0xaf,
		0xa6, 0x8f, 0x47, 0xdf, 0x57, 0xff, 0x7e, 0xf9, 0xea, 0x9f, 0x5f, 0xbe, 0xbc, 0x7a, 0xf5, 0xcf,
		0xd5, 0xf1, 0x8d, 0x9a, 0xfc, 0xbb, 0x7f, 0x8e, 0xff, 0xef, 0xbf, 0x77, 0x76, 0x16, 0x9e, 0x5a,
		0x7d, 0xf9, 0x3f, 0xaf, 0xa0, 0x75, 0x47, 0x4c, 0xd5, 0x0a, 0x6b, 0xf4, 0x92, 0x02, 0x6d, 0xa1,
		0x1f, 0xf7, 0x52, 0x35, 0xda, 0x68, 0xe1, 0xa9, 0x30, 0x38, 0x0d, 0x4e, 0x42, 0x25, 0x2f, 0xc3,
		0x7a, 0xd7, 0x20, 0xe5, 0xad, 0xdf, 0xa7, 0xf1, 0x80, 0xe5, 0xfb, 0xbb, 0x87, 0x43, 0x0e, 0xf8,
		0x11, 0x68, 0x27, 0x07, 0xfc, 0x50, 0x90, 0x93, 0x03, 0x7e, 0xe6, 0x00, 0xc9, 0x01, 0xbb, 0xe1,
		0x85, 0x59, 0xbe, 0x7f, 0x8a, 0xed, 0x65, 0xf9, 0x5e, 0x8e, 0xce, 0x14, 0x72, 0x82, 0xc2, 0x02,
		0x7c, 0x45, 0x9c, 0xa4, 0x80, 0x6c, 0x43, 0xb6, 0x21, 0xdb, 0x90, 0x6d, 0xc8, 0x36, 0x64, 0x9b,
		0x21, 0xb6, 0x1a, 0x44, 0xb2, 0x76, 0xe7, 0xb3, 0x6a, 0xff, 0xd0, 0x2f, 0xc1, 0xeb, 0x61, 0x32,
		0x9b, 0x51, 0x4a, 0x86, 0x98, 0x6c, 0xa8, 0xc9, 0x85, 0xdc, 0x02, 0xf4, 0x44, 0x37, 0xab, 0x74,
		0x01, 0x81, 0x6e, 0x20, 0x51, 0x3e, 0x22, 0x17, 0x23, 0xad, 0xf4, 0x66, 0x96, 0xb7, 0xd1, 0xb9,
		0xe5, 0xc0, 0x50, 0xdd, 0x68, 0x6e, 0xe9, 0x0e, 0x5a, 0x67, 0x37, 0xd6, 0xa5, 0x66, 0x97, 0x42,
		0xd3, 0x26, 0x0f, 0x1e, 0xb6, 0x6b, 0xcd, 0x2f, 0x67, 0x03, 0x77, 0xb0, 0x37, 0x9f, 0x30, 0x67,
		0xf8, 0xb0, 0xb9, 0xe8, 0x50, 0x53, 0xcc, 0xdc, 0xcc, 0x45, 0x97, 0x9a, 0x64, 0xe6, 0x62, 0x42,
		0xbe, 0x60, 0x94, 0x59, 0x7c, 0x1d, 0xbf, 0x80, 0x76, 0x97, 0xc1, 0x4e, 0xb8, 0xd1, 0x5c, 0x73,
		0xc1, 0xf1, 0x96, 0x1d, 0x18, 0xab, 0xec, 0x66, 0x9b, 0xf2, 0xa9, 0x88, 0x3e, 0xbe, 0xb9, 0xa0,
		0x1c, 0x57, 0xb6, 0x37, 0x2c, 0x70, 0xcc, 0x1b, 0xc1, 0x63, 0x94, 0xbe, 0xdd, 0x61, 0x36, 0x50,
		0xba, 0x0c, 0xd2, 0xac, 0x73, 0x81, 0xd8, 0x25, 0x4f, 0x2c, 0x17, 0x9a, 0x77, 0xce, 0x46, 0x4b,
		0x13, 0x4f, 0x9a, 0x78, 0x3a, 0x23, 0x9c, 0xd8, 0x50, 0xe5, 0x92, 0xb0, 0x14, 0x5c, 0x17, 0x20,
		0xdb, 0xb3, 0x4a, 0xf6, 0xa8, 0x42, 0x3d, 0x29, 0x7b, 0x09, 0xa5, 0xdd, 0x8f, 0xe5, 0x3e, 0x40,
		0xbf, 0x12, 0x45, 0xbd, 0x74, 0xcc, 0x2f, 0x22, 0xce, 0xd1, 0x4f, 0xda, 0x67, 0xea, 0xdc, 0xef,
		0xfb, 0xe9, 0xd9, 0x90, 0xfe, 0x8a, 0xbd, 0xbe, 0x8a, 0xda, 0xa3, 0x5a, 0x6a, 0x2f, 0x52, 0xe9,
		0x5f, 0xbd, 0xf8, 0xab, 0x17, 0x44, 0x49, 0xea, 0x47, 0x6d, 0x55, 0xbc, 0xfd, 0x44, 0xb2, 0xf0,
		0x4c, 0xb1, 0x1f, 0xf7, 0xd2, 0x5e, 0xbb, 0x17, 0x26, 0xb3, 0x47, 0xc5, 0x20, 0x09, 0x92, 0x62,
		0x10, 0xa5, 0x2a, 0xee, 0xfa, 0xc3, 0xbf, 0x99, 0x3d, 0x2c, 0x86, 0xea, 0x42, 0x85, 0xc9, 0xf8,
		0x47, 0xd1, 0xef, 0x06, 0x5e, 0xe2, 0x77, 0x83, 0xa2, 0xdf, 0x2d, 0x26, 0xea, 0xf4, 0x5c, 0x45,
		0xa9, 0x17, 0xf7, 0x06, 0x69, 0x10, 0x9d, 0x16, 0xfd, 0xce, 0x7f, 0xfd, 0xb6, 0x8a, 0xda, 0x97,
		0x5e, 0x12, 0x74, 0x92, 0xf9, 0x5f, 0x8b, 0x49, 0xea, 0xa7, 0x12, 0x6a, 0xb8, 0x0a, 0x49, 0x1a,
		0x0f, 0xda, 0x69, 0x34, 0x09, 0x24, 0x07, 0xb3, 0x1b, 0xb9, 0x3f, 0xbe, 0x49, 0xb5, 0xc9, 0x3d,
		0x6a, 0xdd, 0xfa, 0x3d, 0xb9, 0xfd, 0x44, 0xeb, 0x70, 0x7a, 0x13, 0x67, 0x8f, 0x5a, 0xb5, 0x24,
		0x48, 0x5a, 0xb5, 0xd9, 0x4d, 0xbc, 0x7e, 0xd8, 0xaa, 0x8f, 0x6e, 0xe2, 0xf8, 0x47, 0xab, 0xd2,
		0x0d, 0x8e, 0xfc, 0x6e, 0xd0, 0xaa, 0x74, 0x5b, 0x47, 0xe3, 0x7b, 0xd8, 0x18, 0xdf, 0xc2, 0x56,
		0x65, 0x7a, 0xcf, 0x8e, 0x82, 0x4e, 0x32, 0xf7, 0x5b, 0xeb, 0x68, 0x74, 0x03, 0x5f, 0x2c, 0x27,
		0x25, 0xd8, 0xb9, 0xb2, 0x25, 0x12, 0x2a, 0xfc, 0xa6, 0x2e, 0x6f, 0xb6, 0x81, 0x5c, 0xb1, 0xba,
		0xa5, 0xa4, 0x50, 0x0f, 0x92, 0xb4, 0x92, 0xa6, 0x76, 0xfb, 0x64, 0x16, 0x3e, 0x04, 0x51, 0x35,
		0x54, 0xc3, 0xb9, 0x92, 0xd8, 0x5d, 0x0c, 0x2e, 0x7c, 0xf0, 0xbf, 0xdd, 0x18, 0x49, 0xe9, 0x4d,
		0xb9, 0xbc, 0xb9, 0x55, 0x2e, 0xaf, 0x6d, 0xbd, 0xde, 0x5a, 0xdb, 0xde, 0xd8, 0x28, 0x6d, 0x96,
		0x2c, 0xae, 0xf5, 0x16, 0x0e, 0xe2, 0x8e, 0x8a, 0x55, 0x67, 0x77, 0x08, 0xa0, 0x68, 0x10, 0x86,
		0x4b, 0x35, 0x6f, 0x84, 0x04, 0x6d, 0xe7, 0x83, 0xb5, 0xc5, 0x30, 0xed, 0x6a, 0x78, 0xb6, 0x13,
		0x98, 0xcd, 0x87, 0x45, 0xb3, 0x57, 0x34, 0x4c, 0x24, 0xb6, 0x09, 0xc4, 0x41, 0xe2, 0xb0, 0x40,
		0x15, 0x0e, 0x51, 0x84, 0x59, 0x56, 0x30, 0x37, 0x37, 0x0d, 0xce, 0xcb, 0xc9, 0x8e, 0xce, 0x31,
		0xd8, 0x4c, 0x4f, 0xca, 0x1b, 0xfd, 0x82, 0xae, 0x07, 0x61, 0x98, 0x93, 0xa6, 0xb9, 0x44, 0xc3,
		0x97, 0xb5, 0xb5, 0x53, 0xdb, 0xe6, 0x8e, 0x6c, 0xeb, 0x3b, 0xaf, 0x6d, 0xef, 0xb0, 0x16, 0xb3,
		0x93, 0x5a, 0xcc, 0x8e, 0x69, 0x09, 0x3b, 0xa3, 0xf3, 0xad, 0xb9, 0xf6, 0x02, 0x3b, 0x99, 0x85,
		0x1b, 0x9c, 0x6e, 0x6f, 0xbe, 0x2d, 0xc6, 0x17, 0x5b, 0x13, 0xce, 0x4e, 0x98, 0xb1, 0x1e, 0x6e,
		0x24, 0x84, 0x1d, 0x31, 0xe1, 0x47, 0x4a, 0x18, 0x12, 0x17, 0x8e, 0xc4, 0x85, 0x25, 0x49, 0xe1,
		0xc9, 0x5e, 0x32, 0xc2, 0x66, 0xae, 0xd1, 0x56, 0xd8, 0x9a, 0x0d, 0xa0, 0x3d, 0x65, 0x4c, 0xcb,
		0x73, 0x74, 0x4a, 0x5a, 0x93, 0xf1, 0x58, 0x9e, 0x0f, 0x76, 0xc3, 0x98, 0x98, 0x70, 0x26, 0x29,
		0xac, 0x89, 0x0b, 0x6f, 0xd2, 0xc2, 0x9c, 0xd8, 0x70, 0x27, 0x36, 0xec, 0x49, 0x0c, 0x7f, 0x76,
		0xc3, 0xa0, 0xe5, 0x70, 0x28, 0x26, 0x2c, 0xce, 0x06, 0x32, 0xea, 0xdc, 0xe2, 0xf5, 0xfa, 0x69,
		0xd0, 0x8b, 0x12, 0x79, 0x5d, 0x22, 0xe7, 0x87, 0x47, 0xb3, 0x48, 0xc9, 0x41, 0x54, 0x62, 0x30,
		0x15, 0x1b, 0x54, 0xa5, 0x06, 0x57, 0xf1, 0x41, 0x56, 0x7c, 0xb0, 0x95, 0x1c, 0x74, 0x65, 0x04,
		0x5f, 0x21, 0x41, 0x78, 0xf6, 0x41, 0xc9, 0x6d, 0x16, 0x29, 0xb3, 0x7e, 0x5f, 0x62, 0xdd, 0xbe,
		0xb0, 0x7a, 0x7d, 0x7a, 0x8f, 0x5f, 0x2f, 0x1d, 0x48, 0x3c, 0xd6, 0x46, 0x92, 0x6b, 0x44, 0x4e,
		0x22, 0x27, 0x91, 0x93, 0xc8, 0x49, 0xe4, 0x24, 0x72, 0x52, 0x2f, 0x5b, 0x05, 0x7d, 0x4f, 0xdc,
		0xe4, 0xa3, 0xff, 0xf8, 0x43, 0xbf, 0xa4, 0x9f, 0x1a, 0x2e, 0x92, 0xd7, 0x57, 0x38, 0x8e, 0xf7,
		0x99, 0x03, 0x34, 0x79, 0x68, 0x78, 0x71, 0x72, 0xb1, 0xd5, 0xbf, 0x5f, 0x7e, 0x2e, 0x79, 0xeb,
		0xc7, 0xd3, 0x5f, 0x5e, 0x7f, 0x5e, 0xf3, 0xd6, 0x8f, 0x25, 0x76, 0x6a, 0xa1, 0x33, 0x82, 0xb3,
		0x8c, 0xb5, 0x09, 0x63, 0xe5, 0x95, 0xb1, 0x9c, 0x3b, 0x40, 0xfc, 0x26, 0xf1, 0x0d, 0x7f, 0x7e,
		0x5f, 0xbf, 0x5a, 0xfd, 0xfb, 0xe5, 0x90, 0x2e, 0x4b, 0x33, 0x12, 0x2c, 0x0d, 0x5f, 0xe4, 0xcd,
		0xf0, 0x9f, 0x2f, 0xc7, 0xe1, 0xe2, 0xc5, 0x57, 0xff, 0x82, 0xf0, 0x9d, 0x70, 0x5e, 0x2b, 0xf4,
		0x03, 0x91, 0x14, 0x82, 0x39, 0xf3, 0xf1, 0x31, 0x31, 0x96, 0xbc, 0xeb, 0x7d, 0x71, 0x9e, 0xbc,
		0xeb, 0xc3, 0x07, 0x46, 0xde, 0xf5, 0x89, 0x03, 0x24, 0xef, 0xea, 0x7a, 0xf4, 0x27, 0xef, 0xfa,
		0xd3, 0xb8, 0x27, 0xf2, 0x78, 0x3e, 0x32, 0xaf, 0x39, 0xc8, 0x63, 0x88, 0x3e, 0x7e, 0x8f, 0x83,
		0x1f, 0xf3, 0x83, 0xb8, 0x05, 0xe4, 0x89, 0x3f, 0x5e, 0xcf, 0x81, 0x63, 0xf5, 0x1c, 0x39, 0x4e,
		0xcf, 0x81, 0x53, 0x5a, 0x5c, 0x3a, 0x3e, 0xcf, 0xb1, 0xa3, 0xba, 0x9c, 0x3b, 0x2e, 0xcf, 0xc5,
		0x53, 0xb9, 0x1c, 0x38, 0x1e, 0xcf, 0xa9, 0x63, 0xf1, 0x9c, 0x9d, 0x63, 0x2e, 0x1d, 0x83, 0xe7,
		0xe4, 0x44, 0xe3, 0x8c, 0xa9, 0x27, 0x7d, 0x71, 0xc6, 0x54, 0xbe, 0xe4, 0xbb, 0x1b, 0xc7, 0xd9,
		0xb9, 0x70, 0x8c, 0x9d, 0xf0, 0xe3, 0xeb, 0x38, 0x4d, 0xc4, 0x29, 0x0a, 0x91, 0x5e, 0x33, 0x23,
		0xf7, 0x58, 0x3a, 0x8a, 0x66, 0x9e, 0x33, 0x40, 0xce, 0xc7, 0xe2, 0xf8, 0xb9, 0x19, 0x41, 0x4b,
		0x9c, 0x40, 0x2e, 0x1c, 0x37, 0xc7, 0x31, 0x73, 0x1c, 0x33, 0x27, 0x57, 0xe8, 0x50, 0x2b, 0x26,
		0xec, 0x7e, 0x70, 0x76, 0x14, 0x67, 0x47, 0x3d, 0xae, 0xab, 0xfc, 0x8d, 0x06, 0xdb, 0x37, 0x1e,
		0x17, 0x45, 0x34, 0x95, 0x5b, 0x11, 0xdf, 0x74, 0x7e, 0x5c, 0xd1, 0x36, 0x3a, 0x94, 0x62, 0xf6,
		0xb0, 0x35, 0xa9, 0xbb, 0x5b, 0xd6, 0x13, 0xa3, 0x2c, 0xb6, 0x4f, 0x15, 0xd2, 0x1e, 0x40, 0x56,
		0x5b, 0x00, 0x21, 0x0b, 0x17, 0xb4, 0x66, 0xfc, 0x11, 0x52, 0x68, 0xcd, 0x78, 0x1f, 0x78, 0x69,
		0xcd, 0xf8, 0x58, 0x15, 0x44, 0x6b, 0x46, 0x59, 0xb2, 0x54, 0x4c, 0x19, 0xe9, 0x75, 0x13, 0x44,
		0xe5, 0x77, 0x63, 0xd5, 0x95, 0xc0, 0x37, 0xd3, 0x14, 0xab, 0x80, 0x9a, 0xaa, 0xc2, 0xe1, 0x44,
		0xa9, 0xbf, 0x7a, 0x35, 0xd1, 0xbf, 0x13, 0x45, 0x8c, 0x94, 0xb3, 0x21, 0xfb, 0xfd, 0x54, 0xc9,
		0x51, 0x72, 0x12, 0x4e, 0xd1, 0x15, 0xd7, 0x63, 0x7b, 0x1d, 0x21, 0x87, 0x90, 0x43, 0xc8, 0x21,
		0xe4, 0x96, 0x44, 0xc8, 0xd1, 0x63, 0xfb, 0x81, 0xf2, 0x92, 0x1e, 0xdb, 0xce, 0x64, 0x43, 0x24,
		0x06, 0x53, 0xb1, 0x41, 0x55, 0x6a, 0x70, 0x15, 0x1f, 0x64, 0xc5, 0x07, 0x5b, 0xc9, 0x41, 0x57,
		0x46, 0xf0, 0x15, 0x12, 0x84, 0xe5, 0x65, 0x55, 0x16, 0xd8, 0x8a, 0x1e, 0xdb, 0x0f, 0x1e, 0x13,
		0x3d, 0xb6, 0xc5, 0x4d, 0x2e, 0x7a, 0x6c, 0x23, 0x27, 0x91, 0x93, 0xc8, 0x49, 0xe4, 0x24, 0x72,
		0x12, 0x39, 0x29, 0x80, 0xad, 0xe8, 0xb1, 0xfd, 0xb8, 0x8f, 0x90, 0x4e, 0x2f, 0x0f, 0x06, 0x16,
		0x3d, 0xb6, 0x9f, 0xaa, 0x6e, 0xe8, 0xb1, 0x4d, 0x8f, 0xed, 0x9c, 0x85, 0x40, 0x37, 0x18, 0x8b,
		0x1e, 0xdb, 0xb9, 0x65, 0x2c, 0x7a, 0x6c, 0xdb, 0x0a, 0x15, 0xf4, 0xd8, 0x5e, 0x42, 0xe7, 0xb5,
		0xc2, 0xbe, 0x29, 0x49, 0x21, 0x98, 0x1e, 0xdb, 0x8f, 0x89, 0xb1, 0xe4, 0x5d, 0xef, 0x8b, 0xf3,
		0xe4, 0x5d, 0x1f, 0x3e, 0x30, 0xf2, 0xae, 0x4f, 0x1c, 0x20, 0x79, 0x57, 0xd7, 0xa3, 0x3f, 0x79,
		0xd7, 0x9f, 0xc6, 0x3d, 0x7a, 0x6c, 0x3f, 0xf2, 0x43, 0x24, 0xf3, 0xfa, 0x40, 0x68, 0xd1, 0x63,
		0x3b, 0x57, 0x48, 0x93, 0x8b, 0xb8, 0x05, 0xe4, 0xd1, 0x63, 0x3b, 0x83, 0x21, 0xd2, 0x63, 0x3b,
		0xa3, 0x1b, 0x49, 0x8f, 0x6d, 0x7d, 0xc3, 0xa5, 0xc7, 0xf6, 0xd2, 0x88, 0xe8, 0x1f, 0xcf, 0x31,
		0x7a, 0x6c, 0xeb, 0x9f, 0x63, 0xf4, 0xd8, 0x5e, 0x06, 0xcf, 0xec, 0xde, 0xe8, 0xe8, 0xb1, 0x9d,
		0x2f, 0xf9, 0x4e, 0x8f, 0xed, 0xcc, 0xc6, 0x48, 0x8f, 0x6d, 0x97, 0xa9, 0x84, 0x9a, 0x99, 0x87,
		0x52, 0x06, 0x3d, 0xb6, 0x9f, 0x3e, 0x36, 0x7a, 0x6c, 0xd3, 0x1c, 0x98, 0x1e, 0xdb, 0xcf, 0x99,
		0x40, 0xf4, 0xd8, 0x66, 0x1a, 0xd1, 0x63, 0x3b, 0x17, 0x42, 0x90, 0x5a, 0x31, 0x09, 0x23, 0xa0,
		0xc7, 0xf6, 0xfc, 0x78, 0x1c, 0xee, 0xb1, 0x2d, 0xa1, 0xa7, 0xdc, 0x8a, 0x9b, 0x2d, 0xb6, 0x8f,
		0x46, 0xb7, 0x6e, 0x59, 0xdb, 0x32, 0xbe, 0x58, 0x22, 0xe2, 0x29, 0xfc, 0xa6, 0x2e, 0xad, 0xd7,
		0xc1, 0x15, 0xea, 0x41, 0x92, 0x56, 0xd2, 0xd4, 0x6e, 0xfb, 0xaf, 0xc2, 0x87, 0x20, 0xaa, 0x86,
		0x6a, 0x38, 0x39, 0x12, 0xbb, 0x8b, 0x24, 0x85, 0x0f, 0xfe, 0xb7, 0x1b, 0x23, 0x29, 0xbd, 0x29,
		0x97, 0x37, 0xb7, 0xca, 0xe5, 0xb5, 0xad, 0xd7, 0x5b, 0x6b, 0xdb, 0x1b, 0x1b, 0xa5, 0xcd, 0x92,
		0xc5, 0xb5, 0x90, 0xc2, 0x41, 0xdc, 0x51, 0xb1, 0xea, 0xec, 0x0e, 0x71, 0x13, 0x0d, 0xc2, 0x70,
		0xa9, 0xa6, 0x8b, 0x90, 0xf8, 0xec, 0x70, 0x5c, 0x2e, 0x58, 0xed, 0x7a, 0xeb, 0x58, 0x24, 0xb6,
		0x13, 0x83, 0xcd, 0x47, 0x40, 0xb3, 0x57, 0x34, 0x4c, 0x1e, 0xb6, 0x49, 0xc3, 0x35, 0xb2, 0xb0,
		0xc0, 0x10, 0xae, 0x30, 0x83, 0x59, 0x3e, 0x30, 0x37, 0x2b, 0xcd, 0x5c, 0xc9, 0xd0, 0xbc, 0xb7,
		0x35, 0xdf, 0x5d, 0x98, 0xe7, 0x06, 0xe7, 0xb6, 0xe8, 0x39, 0x6d, 0x66, 0x22, 0xeb, 0x9f, 0x56,
		0x06, 0xa6, 0x94, 0xe1, 0xb3, 0x0a, 0xac, 0x9c, 0x49, 0x60, 0xf8, 0xec, 0x01, 0xe3, 0x67, 0x0c,
		0xd8, 0xd8, 0x37, 0x79, 0x73, 0x5f, 0xe4, 0x90, 0xb8, 0x4c, 0x52, 0x8f, 0xa5, 0x9d, 0x8f, 0xd6,
		0x77, 0x36, 0x5a, 0xdf, 0xb9, 0x78, 0x7b, 0x67, 0xe2, 0xe8, 0x83, 0x47, 0xc6, 0x3c, 0xe9, 0x56,
		0x9a, 0xee, 0xc7, 0x5f, 0x18, 0xea, 0x86, 0x49, 0xb8, 0x36, 0x3c, 0x6f, 0xa6, 0x54, 0x31, 0x1b,
		0x81, 0x61, 0xd4, 0xda, 0x29, 0xcc, 0xb6, 0xb6, 0xbd, 0xde, 0xe6, 0x36, 0x7a, 0x8b, 0x61, 0xc1,
		0x76, 0x78, 0x10, 0x13, 0x26, 0xc4, 0x84, 0x0b, 0x19, 0x61, 0x63, 0x39, 0xb2, 0x60, 0xd6, 0xb6,
		0xa2, 0x5f, 0xd7, 0x6a, 0x76, 0x54, 0x94, 0x06, 0xe9, 0xa5, 0x9d, 0xb3, 0xf9, 0x66, 0x1a, 0xdf,
		0xc2, 0xe2, 0x4d, 0xa1, 0x36, 0x79, 0xeb, 0xbb, 0x7e, 0x62, 0x91, 0x77, 0xa6, 0x1f, 0x44, 0xe5,
		0x5d, 0xad, 0xd5, 0xfc, 0xe3, 0xb0, 0x6a, 0x8b, 0x76, 0x46, 0x1b, 0x8b, 0x12, 0xab, 0x15, 0x73,
		0x42, 0x0e, 0xde, 0xab, 0x1d, 0x7e, 0xda, 0x2c, 0x2c, 0xe3, 0x09, 0x88, 0x72, 0xee, 0x7f, 0xb9,
		0xb0, 0x64, 0xa5, 0x0e, 0xc7, 0x79, 0x0f, 0xac, 0x2f, 0x72, 0x38, 0x7f, 0x0a, 0x2a, 0xf2, 0x4f,
		0x42, 0xd5, 0xb1, 0xe7, 0xcd, 0xa6, 0x03, 0xc0, 0x9a, 0x61, 0xcd, 0xb0, 0x66, 0x58, 0x33, 0xac,
		0x59, 0x8e, 0xac, 0xd9, 0x49, 0xaf, 0x17, 0x2a, 0x3f, 0xb2, 0x69, 0xcb, 0x4a, 0x88, 0x84, 0x67,
		0xdf, 0xcb, 0x73, 0x95, 0xc6, 0x41, 0xdb, 0x9e, 0x46, 0x98, 0x5c, 0xdf, 0xf0, 0xf4, 0xd9, 0x53,
		0x5d, 0x7f, 0x10, 0x8e, 0x08, 0xaa, 0xb4, 0x86, 0x3e, 0x41, 0x9f, 0xa0, 0x4f, 0xd0, 0x27, 0xe8,
		0x93, 0x3c, 0xe9, 0x13, 0x6b, 0x8d, 0xfd, 0x2c, 0x36, 0xec, 0xb3, 0xdc, 0x88, 0xcf, 0xee, 0x4e,
		0x10, 0xeb, 0xdb, 0xef, 0x84, 0x34, 0xeb, 0x9a, 0x35, 0xe1, 0xb2, 0x3d, 0x0e, 0x41, 0x6d, 0xb5,
		0xae, 0xec, 0x6e, 0x0d, 0x02, 0x9a, 0xb7, 0xa0, 0x59, 0x5e, 0xdf, 0x2e, 0x6f, 0x6f, 0x6e, 0xad,
		0x6f, 0x6f, 0x80, 0x51, 0x3b, 0x82, 0xc0, 0xde, 0x55, 0x8f, 0x71, 0xed, 0xcf, 0x86, 0x6d, 0x62,
		0xbf, 0xf0, 0x2a, 0xa1, 0xf2, 0x0a, 0xfb, 0x8c, 0x7d, 0xc6, 0x3e, 0x63, 0x9f, 0xf3, 0x68, 0x9f,
		0xa9, 0xbc, 0x12, 0x52, 0x79, 0x75, 0x44, 0xe9, 0x95, 0x94, 0xd2, 0x9f, 0x8f, 0xfb, 0xb5, 0xb7,
		0x95, 0xa3, 0x26, 0xd5, 0x57, 0xf6, 0x3e, 0x82, 0x0f, 0x1f, 0xeb, 0x4d, 0xdb, 0x1f, 0x02, 0x25,
		0x58, 0x6e, 0xfb, 0x34, 0x76, 0x2e, 0x67, 0xe1, 0x40, 0x25, 0xee, 0x5c, 0x36, 0xdc, 0x3f, 0x4c,
		0xda, 0x7e, 0x65, 0x73, 0x3d, 0xc0, 0x0c, 0x6c, 0x53, 0x7e, 0xe1, 0xf0, 0xec, 0x9c, 0xf6, 0xe8,
		0x9a, 0xa6, 0x48, 0x56, 0x4c, 0x25, 0x4b, 0xcc, 0xf6, 0xe5, 0x32, 0xdf, 0x7f, 0x4b, 0x44, 0x9f,
		0x2d, 0xb3, 0xfd, 0xb4, 0x74, 0x43, 0xd5, 0x70, 0x00, 0x91, 0x18, 0x38, 0x0a, 0x46, 0x5a, 0x22,
		0x08, 0x0a, 0x15, 0x7a, 0x83, 0x84, 0x3e, 0xea, 0xd6, 0xf3, 0xca, 0x9a, 0x66, 0x98, 0xa9, 0x99,
		0x25, 0x6e, 0x46, 0x69, 0x9c, 0x4e, 0x82, 0xa6, 0x91, 0x9e, 0x39, 0x94, 0x3d, 0xc2, 0x35, 0xa0,
		0xbb, 0xd0, 0x9e, 0xae, 0x85, 0xe8, 0x41, 0xf5, 0xcc, 0xed, 0x4f, 0xae, 0xa3, 0x69, 0x7e, 0xea,
		0xed, 0xe0, 0xa2, 0x7d, 0xc1, 0xc8, 0xc4, 0xc2, 0x90, 0xc1, 0x05, 0x20, 0x53, 0x0b, 0x3d, 0xc6,
		0x17, 0x74, 0x8c, 0x2f, 0xdc, 0x98, 0x5d, 0xa0, 0x71, 0x2b, 0x26, 0xeb, 0xee, 0x90, 0x62, 0x6c,
		0xd3, 0x9d, 0xe1, 0x4d, 0x76, 0x37, 0x2b, 0xe6, 0xbb, 0x7e, 0x98, 0x68, 0x37, 0xb2, 0x66, 0x56,
		0xf9, 0x8d, 0xad, 0xea, 0x9b, 0x5c, 0xc5, 0xb7, 0xb0, 0x6a, 0x6f, 0x7a, 0x95, 0xde, 0xda, 0xaa,
		0xbc, 0xb5, 0x55, 0x78, 0x3b, 0xab, 0xee, 0x6e, 0x67, 0xe1, 0x8c, 0xad, 0xa2, 0x5b, 0xd8, 0x14,
		0x67, 0x68, 0x13, 0x9c, 0x46, 0x2f, 0xaf, 0x51, 0x4a, 0x8e, 0xfc, 0xa8, 0x17, 0x0d, 0xce, 0x4f,
		0x54, 0x6c, 0x2e, 0x12, 0xcf, 0x5d, 0x95, 0xf0, 0x48, 0x78, 0x24, 0x3c, 0x12, 0x1e, 0x09, 0x8f,
		0x76, 0x18, 0xf2, 0x26, 0x4b, 0x9a, 0x58, 0x13, 0x32, 0xbb, 0xf3, 0xca, 0xe0, 0x42, 0xbf, 0x8d,
		0x9d, 0x55, 0xb6, 0x6a, 0xbc, 0xa7, 0xdb, 0x53, 0x4a, 0x86, 0xaf, 0x6b, 0x71, 0x17, 0x8a, 0xc9,
		0x5d, 0x0b, 0x36, 0x76, 0x42, 0xd9, 0x86, 0xd2, 0xfa, 0x12, 0x41, 0x29, 0x27, 0xa5, 0x27, 0xc7,
		0x38, 0xaa, 0x05, 0x58, 0xf5, 0xfd, 0x24, 0x09, 0x2e, 0x94, 0x39, 0x33, 0x35, 0xbd, 0x20, 0x69,
		0x4d, 0x7c, 0x1b, 0xbe, 0x0d, 0xdf, 0x86, 0x6f, 0xb3, 0xe8, 0xdb, 0x48, 0x6b, 0xca, 0x08, 0xc2,
		0x71, 0xd0, 0x8b, 0x83, 0xf4, 0xd2, 0x60, 0x14, 0x9e, 0x5e, 0x91, 0xb0, 0x48, 0x58, 0x24, 0x2c,
		0x12, 0x16, 0x09, 0x8b, 0xb7, 0x5a, 0x4c, 0xbd, 0x21, 0x8f, 0xf9, 0x8c, 0x2f, 0xf2, 0x98, 0x5a,
		0x93, 0x4f, 0x6b, 0xe4, 0x31, 0xb5, 0x40, 0x69, 0x09, 0xf3, 0x98, 0xa5, 0xf5, 0x2d, 0x32, 0x99,
		0xae, 0x5d, 0xe5, 0x98, 0x7d, 0x1e, 0xfa, 0x29, 0x62, 0xe9, 0xf6, 0x79, 0x68, 0xad, 0xca, 0x5f,
		0x11, 0xb2, 0xcb, 0x63, 0x62, 0x15, 0x97, 0x78, 0x93, 0xc7, 0x99, 0x0a, 0xc3, 0x9e, 0xe7, 0x0f,
		0xd2, 0x33, 0x15, 0xa5, 0x41, 0x5b, 0x2f, 0xc0, 0x67, 0x9a, 0xfa, 0xce, 0xab, 0xb2, 0x01, 0xc4,
		0x56, 0x96, 0x81, 0x0d, 0x20, 0x0e, 0x66, 0x11, 0xd8, 0x00, 0x72, 0xff, 0xad, 0xd1, 0xbe, 0x01,
		0x44, 0xf3, 0xde, 0xb8, 0x85, 0x89, 0xa9, 0x3d, 0x1a, 0xaf, 0x98, 0x3b, 0xed, 0x9c, 0x04, 0xad,
		0x5b, 0x54, 0x6a, 0x8d, 0x52, 0xad, 0x51, 0xab, 0x1d, 0x8a, 0x35, 0xe3, 0x18, 0x75, 0x27, 0x68,
		0x4d, 0x9d, 0x4e, 0x6e, 0x56, 0xb9, 0x4a, 0x50, 0xb2, 0x8b, 0xb7, 0xda, 0x6c, 0x59, 0x8b, 0xa5,
		0x24, 0x95, 0xf1, 0x9e, 0xbc, 0x36, 0x7a, 0xf1, 0x5a, 0xec, 0xc1, 0x6b, 0xab, 0xf7, 0xae, 0xf5,
		0x9e, 0xbb, 0xd6, 0x7b, 0xed, 0xda, 0xed, 0xb1, 0x9b, 0xaf, 0x0e, 0x79, 0xc6, 0x7b, 0xe9, 0x5a,
		0x3c, 0x22, 0xcf, 0xf0, 0xd1, 0x78, 0xb4, 0x81, 0xfb, 0xc9, 0x2c, 0x5e, 0xd2, 0xde, 0x5a, 0x77,
		0x49, 0x9f, 0xa2, 0x11, 0xa3, 0xba, 0x22, 0x24, 0x7d, 0xfc, 0xeb, 0xf0, 0x0e, 0x54, 0xe6, 0x6e,
		0x80, 0xd6, 0x94, 0xb2, 0xfe, 0xf9, 0xa2, 0xb3, 0xb0, 0xed, 0xab, 0x32, 0x58, 0xd3, 0x36, 0xbc,
		0x18, 0xd9, 0x12, 0xb2, 0x25, 0x64, 0x4b, 0xc8, 0x96, 0x90, 0x2d, 0x31, 0x96, 0xb0, 0x5e, 0x98,
		0xe0, 0xc6, 0xf4, 0x80, 0x41, 0x4a, 0x26, 0x33, 0x41, 0x66, 0x82, 0xcc, 0x04, 0x99, 0x09, 0x59,
		0x14, 0x3f, 0xbb, 0xe0, 0xd0, 0x91, 0x79, 0x7d, 0x3f, 0x49, 0x26, 0x18, 0xb6, 0x74, 0x74, 0xdc,
		0xfc, 0x30, 0x38, 0x3e, 0x2e, 0x6f, 0x81, 0x41, 0x40, 0x80, 0xb0, 0x1d, 0x28, 0xc4, 0x04, 0x0c,
		0x31, 0x81, 0x43, 0x46, 0x00, 0x31, 0x1b, 0x48, 0x0c, 0x07, 0x94, 0xd9, 0x2d, 0xb6, 0x7f, 0x7c,
		0x5c, 0xdc, 0x1b, 0xa4, 0x41, 0x74, 0x6a, 0x8b, 0xe5, 0xe7, 0x24, 0xff, 0x1b, 0x0e, 0x32, 0x72,
		0x40, 0x0c, 0x2d, 0xfb, 0x41, 0x46, 0x77, 0xe6, 0xcc, 0xbf, 0xaa, 0xcb, 0xa2, 0x51, 0x9f, 0xbc,
		0x22, 0x38, 0x7f, 0xfe, 0x9b, 0xba, 0x34, 0x92, 0x43, 0x37, 0x37, 0xbf, 0xae, 0x8c, 0x2c, 0x86,
		0xf8, 0xa9, 0x32, 0x9f, 0xdd, 0x31, 0x79, 0x16, 0x97, 0xb5, 0xe4, 0xce, 0x3a, 0xc9, 0x1d, 0x92,
		0x3b, 0x24, 0x77, 0xd0, 0x33, 0x24, 0x77, 0x48, 0xee, 0x90, 0xdc, 0x21, 0xb9, 0x43, 0x72, 0x87,
		0xe4, 0x0e, 0xc9, 0x1d, 0x92, 0x3b, 0x88, 0x21, 0x92, 0x3b, 0x0f, 0x4a, 0xee, 0x2c, 0xe3, 0x91,
		0xd5, 0xf7, 0xe5, 0x76, 0x38, 0xbf, 0x5a, 0xca, 0xbc, 0xa5, 0x70, 0xf9, 0xd6, 0x3c, 0x5d, 0xe2,
		0xaa, 0xe5, 0xdf, 0xd4, 0x25, 0x25, 0xcb, 0x8b, 0x9f, 0xd6, 0x57, 0x75, 0xd9, 0x3e, 0xf3, 0x0d,
		0xf4, 0x14, 0xbb, 0x59, 0xb7, 0x3c, 0xbe, 0x22, 0xc5, 0xcb, 0x52, 0x3d, 0x32, 0xc5, 0xcb, 0x39,
		0xf4, 0xb8, 0x14, 0x2f, 0xa3, 0x1f, 0x9e, 0xab, 0x1f, 0x4c, 0x10, 0xb7, 0x70, 0x11, 0x31, 0xbe,
		0x05, 0x28, 0x89, 0x3b, 0x3e, 0x32, 0x13, 0x0b, 0xb4, 0x46, 0x17, 0x66, 0x8d, 0x6b, 0x88, 0x75,
		0x34, 0x04, 0x1a, 0x02, 0x0d, 0x91, 0x2b, 0x0d, 0x41, 0xbb, 0x18, 0xda, 0xc5, 0xb8, 0x69, 0x39,
		0x6d, 0x84, 0x0d, 0x8b, 0xe1, 0xc3, 0x56, 0x18, 0xb1, 0x1e, 0x4e, 0xac, 0x87, 0x15, 0xbb, 0xe1,
		0xc5, 0x4c, 0x98, 0x31, 0x14, 0x6e, 0x66, 0xb7, 0x92, 0x76, 0x31, 0x0e, 0x03, 0x85, 0xac, 0x49,
		0x6e, 0xb2, 0x26, 0xa6, 0x56, 0x46, 0xa5, 0xa6, 0x4c, 0x0c, 0xac, 0x86, 0xd2, 0xc0, 0xdf, 0xe8,
		0xbc, 0x13, 0x3d, 0xdf, 0x72, 0xde, 0xce, 0xff, 0x8e, 0x19, 0xb6, 0xcc, 0xbd, 0xfd, 0xe7, 0x0e,
		0xe2, 0xd7, 0xde, 0xd3, 0xdf, 0xc0, 0xb1, 0xff, 0x9a, 0xad, 0x24, 0xbd, 0xfc, 0x65, 0x5a, 0x41,
		0x7a, 0xf9, 0x2f, 0x73, 0xdc, 0xd6, 0x6e, 0xd5, 0x6e, 0x30, 0x98, 0xdf, 0x8d, 0x55, 0x57, 0xe7,
		0x8c, 0x99, 0x5a, 0x31, 0x8d, 0xc7, 0x6c, 0x15, 0x0e, 0x27, 0xd2, 0xe3, 0xd5, 0xab, 0xc9, 0xae,
		0xd2, 0xe2, 0x1c, 0x35, 0x2f, 0x71, 0x40, 0xec, 0xfb, 0xed, 0xaf, 0x2a, 0xf5, 0xda, 0xbd, 0xc1,
		0x50, 0x3f, 0x24, 0xfa, 0x63, 0xe2, 0xed, 0x0b, 0x72, 0xc4, 0x0d, 0x61, 0x91, 0xb0, 0x48, 0x58,
		0xcc, 0xe0, 0xd6, 0xe8, 0x3f, 0xe2, 0x26, 0x89, 0xfa, 0x06, 0x0f, 0xb8, 0x19, 0x5e, 0x8d, 0x9a,
		0x47, 0x69, 0xb4, 0x69, 0x81, 0x3e, 0x4d, 0xd3, 0xa8, 0x35, 0x3a, 0xb5, 0x46, 0xab, 0x76, 0xe8,
		0x55, 0x2f, 0xcd, 0x6a, 0xa6, 0x5b, 0x63, 0xb4, 0x7b, 0x23, 0x9d, 0x46, 0x47, 0x0f, 0x5d, 0xc4,
		0x4c, 0x47, 0x8f, 0x3c, 0x10, 0xb6, 0x75, 0xe2, 0xb6, 0x4e, 0xe0, 0x76, 0x89, 0xdc, 0x0c, 0xa1,
		0x1b, 0x22, 0x76, 0xe3, 0x04, 0x3f, 0xbb, 0x60, 0x27, 0xee, 0xf5, 0xfb, 0xca, 0x62, 0x2f, 0x8f,
		0xe9, 0x00, 0xe8, 0xe2, 0x91, 0xb7, 0x60, 0x20, 0x20, 0x28, 0xd8, 0x0e, 0x0e, 0x62, 0x82, 0x84,
		0x98, 0x60, 0x21, 0x23, 0x68, 0x98, 0x0d, 0x1e, 0x86, 0x83, 0xc8, 0xec, 0x16, 0xdb, 0xef, 0xe2,
		0x31, 0x49, 0x3d, 0xbf, 0x5e, 0xb7, 0xd8, 0xbe, 0x63, 0xcb, 0xc2, 0xa5, 0x1b, 0x7e, 0x74, 0x3a,
		0xbc, 0x01, 0x9f, 0xad, 0xcc, 0x2d, 0x3b, 0x1c, 0x37, 0x7a, 0xe3, 0x1f, 0x82, 0xc8, 0x1a, 0xc9,
		0x5a, 0x8e, 0xed, 0x0b, 0xc3, 0xf8, 0xe4, 0x87, 0x03, 0x25, 0x60, 0x1c, 0xef, 0x62, 0xbf, 0x9d,
		0x06, 0xbd, 0x68, 0x2f, 0x38, 0x0d, 0xd2, 0x64, 0x38, 0x20, 0x6b, 0xe3, 0xb9, 0xfa, 0xc5, 0x22,
		0x34, 0xfd, 0x6f, 0x40, 0xf3, 0x16, 0x34, 0xcb, 0xeb, 0xdb, 0xe5, 0xed, 0xcd, 0xad, 0xf5, 0xed,
		0x0d, 0x30, 0x6a, 0x47, 0x13, 0xd8, 0xbb, 0xea, 0x71, 0x5e, 0xbb, 0x5a, 0x19, 0xcc, 0x39, 0xf5,
		0xe3, 0x5e, 0x5b, 0x25, 0x89, 0x4d, 0xff, 0x7c, 0x3d, 0x04, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d,
		0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d, 0x83,
		0xc6, 0x41, 0xe3, 0xa0, 0xc5, 0x3a, 0xe8, 0x58, 0xb5, 0x55, 0x70, 0x61, 0xd3, 0x40, 0xcf, 0x46,
		0x80, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc, 0x33, 0xfe, 0x19, 0xff, 0x8c,
		0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc, 0xb3, 0x60, 0xff, 0x9c, 0xc6, 0x7e,
		0x94, 0x9c, 0x07, 0xa9, 0x4d, 0x07, 0x3d, 0x1b, 0x03, 0x1e, 0x1a, 0x0f, 0x8d, 0x87, 0xc6, 0x43,
		0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87, 0xc6, 0x43, 0xe3,
		0xa1, 0xf1, 0xd0, 0x62, 0x3d, 0x74, 0x32, 0x16, 0xb0, 0x96, 0xdc, 0xf3, 0xe8, 0xea, 0xf8, 0x66,
		0x7c, 0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66, 0x7c,
		0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0x0b, 0xbc, 0x92, 0xa9, 0x76, 0x68, 0x86, 0x4f,
		0xab, 0xba, 0xce, 0x08, 0x08, 0x39, 0x45, 0xe7, 0x56, 0x07, 0xf7, 0x62, 0x3b, 0x89, 0xfa, 0x45,
		0x93, 0x4d, 0x32, 0x57, 0x84, 0x9c, 0xad, 0x73, 0x38, 0xba, 0x11, 0x6f, 0x27, 0xf7, 0xa1, 0xf5,
		0x36, 0x89, 0xfa, 0x26, 0x4e, 0xaf, 0x32, 0x37, 0xab, 0x38, 0x55, 0x2e, 0x2f, 0xf3, 0x73, 0x49,
		0xce, 0x93, 0xbb, 0x63, 0x46, 0x72, 0xf2, 0xfe, 0xe2, 0x27, 0xa5, 0x92, 0x33, 0x73, 0x6d, 0xec,
		0x87, 0x17, 0xa3, 0x8b, 0xfd, 0xa3, 0x2e, 0x44, 0x17, 0xfb, 0x6c, 0xe1, 0x41, 0x17, 0x7b, 0xba,
		0xd8, 0xff, 0xec, 0x96, 0xd1, 0xc5, 0xde, 0x39, 0x42, 0x5e, 0x24, 0x66, 0xba, 0xd8, 0xe7, 0x81,
		0xb0, 0xad, 0x13, 0xb7, 0x75, 0x02, 0xb7, 0x4b, 0xe4, 0xf9, 0x4c, 0xdb, 0xd0, 0xc5, 0xde, 0xd4,
		0xac, 0xa5, 0x8e, 0x63, 0x09, 0x82, 0x82, 0xed, 0xe0, 0x20, 0x26, 0x48, 0x88, 0x09, 0x16, 0x32,
		0x82, 0x86, 0xd9, 0xe0, 0x61, 0x38, 0x88, 0xcc, 0x6e, 0x31, 0x75, 0x1c, 0xd4, 0x71, 0x18, 0x7e,
		0xe3, 0xd4, 0x71, 0x5c, 0x0f, 0x83, 0x3a, 0x0e, 0xdb, 0x0c, 0x38, 0x0f, 0x4d, 0xea, 0x38, 0x16,
		0xa0, 0x49, 0x1d, 0x87, 0x6d, 0x4d, 0x60, 0xef, 0xaa, 0xec, 0x7f, 0x78, 0x3e, 0x6c, 0xe9, 0x62,
		0x8f, 0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d,
		0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0xf4, 0x43, 0x60, 0x4b, 0x17, 0x7b,
		0xfc, 0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc,
		0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0x1f, 0xe2, 0x9f, 0xe9, 0x62, 0x8f,
		0x87, 0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87,
		0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0xf4, 0x43, 0x60, 0x4b, 0x17, 0x7b, 0x7c,
		0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66, 0x7c, 0x33,
		0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0x3b, 0xe7, 0x9b, 0xe9, 0x62, 0x9f, 0x45, 0x46, 0x40,
		0x68, 0x97, 0x6c, 0x95, 0x9c, 0xd1, 0xc4, 0x3e, 0x69, 0x55, 0x93, 0x33, 0x7a, 0xd8, 0x8b, 0x99,
		0xad, 0xf4, 0xb0, 0xbf, 0x9e, 0x9d, 0xcb, 0xd9, 0xc2, 0xbe, 0x9a, 0x9c, 0xd1, 0xc1, 0x7e, 0xf1,
		0x83, 0x0a, 0x02, 0x83, 0x1d, 0xec, 0x87, 0x17, 0xa3, 0x83, 0xfd, 0xa3, 0x2e, 0x44, 0x07, 0xfb,
		0x6c, 0xe1, 0x41, 0x07, 0x7b, 0x3a, 0xd8, 0xff, 0xec, 0x96, 0xd1, 0xc1, 0xde, 0x39, 0x42, 0x5e,
		0x24, 0x66, 0x3a, 0xd8, 0xe7, 0x81, 0xb0, 0xad, 0x13, 0xb7, 0x75, 0x02, 0xb7, 0x4b, 0xe4, 0xf9,
		0x4c, 0xd9, 0xd0, 0xc1, 0xde, 0xd4, 0xac, 0xa5, 0x86, 0x63, 0x09, 0x82, 0x82, 0xed, 0xe0, 0x20,
		0x26, 0x48, 0x88, 0x09, 0x16, 0x32, 0x82, 0x86, 0xd9, 0xe0, 0x61, 0x38, 0x88, 0xcc, 0x6e, 0x31,
		0x35, 0x1c, 0xd4, 0x70, 0x18, 0x7e, 0xe3, 0xd4, 0x70, 0x5c, 0x0f, 0x83, 0x1a, 0x0e, 0xdb, 0x0c,
		0x38, 0x0f, 0x4d, 0x6a, 0x38, 0x16, 0xa0, 0x49, 0x0d, 0x87, 0x6d, 0x4d, 0x60, 0xef, 0xaa, 0xec,
		0x7d, 0x78, 0x3e, 0x6c, 0xe9, 0x60, 0x8f, 0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68,
		0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d, 0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c,
		0xf4, 0x43, 0x60, 0x4b, 0x07, 0x7b, 0xfc, 0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3,
		0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc, 0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f,
		0x1f, 0xe2, 0x9f, 0xe9, 0x60, 0x8f, 0x87, 0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c,
		0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87, 0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0xf4,
		0x43, 0x60, 0x4b, 0x07, 0x7b, 0x7c, 0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b,
		0xf1, 0xcd, 0xf8, 0x66, 0x7c, 0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0x3b, 0xe7, 0x9b,
		0xe9, 0x60, 0x9f, 0x45, 0x46, 0x40, 0x68, 0x8f, 0xec, 0x20, 0xa0, 0x83, 0x7d, 0x9c, 0xb4, 0x6a,
		0x01, 0x1d, 0xec, 0xe5, 0xcc, 0x56, 0x3a, 0xd8, 0x5f, 0xcf, 0xce, 0xe5, 0xec, 0x60, 0x5f, 0x0b,
		0xe8, 0x60, 0x7f, 0xc7, 0x07, 0x15, 0x24, 0x26, 0x3b, 0xd8, 0x27, 0x74, 0xb0, 0x7f, 0xe4, 0x85,
		0xe8, 0x60, 0x9f, 0x2d, 0x3c, 0xe8, 0x60, 0x4f, 0x07, 0xfb, 0x9f, 0xdd, 0x32, 0x3a, 0xd8, 0x3b,
		0x47, 0xc8, 0x8b, 0xc4, 0x4c, 0x07, 0xfb, 0x3c, 0x10, 0xb6, 0x75, 0xe2, 0xb6, 0x4e, 0xe0, 0x76,
		0x89, 0x3c, 0x9f, 0x29, 0x1b, 0x3a, 0xd8, 0x9b, 0x9a, 0xb5, 0xd4, 0x70, 0x2c, 0x41, 0x50, 0xb0,
		0x1d, 0x1c, 0xc4, 0x04, 0x09, 0x31, 0xc1, 0x42, 0x46, 0xd0, 0x30, 0x1b, 0x3c, 0x0c, 0x07, 0x91,
		0xd9, 0x2d, 0xa6, 0x86, 0x83, 0x1a, 0x0e, 0xc3, 0x6f, 0x9c, 0x1a, 0x8e, 0xeb, 0x61, 0x50, 0xc3,
		0x61, 0x9b, 0x01, 0xe7, 0xa1, 0x49, 0x0d, 0xc7, 0x02, 0x34, 0xa9, 0xe1, 0xb0, 0xad, 0x09, 0xec,
		0x5d, 0x95, 0xbd, 0x0f, 0xcf, 0x87, 0x2d, 0x1d, 0xec, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e,
		0x1a, 0x07, 0x8d, 0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a,
		0x07, 0x8d, 0x83, 0x7e, 0x08, 0x6c, 0xe9, 0x60, 0x8f, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf,
		0xf8, 0x67, 0xfc, 0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8,
		0x67, 0xfc, 0xf3, 0x43, 0xfc, 0x33, 0x1d, 0xec, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a,
		0x0f, 0x8d, 0x87, 0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f,
		0x8d, 0x87, 0x7e, 0x08, 0x6c, 0xe9, 0x60, 0x8f, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8,
		0x66, 0x7c, 0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66,
		0xe7, 0x7c, 0x33, 0x1d, 0xec, 0xb3, 0xc8, 0x08, 0x48, 0xed, 0x91, 0x9d, 0xd0, 0xc1, 0x3e, 0x4e,
		0x5a, 0xb5, 0x84, 0x0e, 0xf6, 0x72, 0x66, 0x2b, 0x1d, 0xec, 0xaf, 0x67, 0xe7, 0x92, 0x76, 0xb0,
		0x4f, 0xe8, 0x60, 0x7f, 0xc7, 0x07, 0x15, 0x26, 0x7d, 0x73, 0x1d, 0xec, 0x87, 0x17, 0xa3, 0x83,
		0xfd, 0xa3, 0x2e, 0x44, 0x07, 0xfb, 0x6c, 0xe1, 0x41, 0x07, 0x7b, 0x3a, 0xd8, 0xff, 0xec, 0x96,
		0xd1, 0xc1, 0xde, 0x39, 0x42, 0x5e, 0x24, 0x66, 0x3a, 0xd8, 0xe7, 0x81, 0xb0, 0xad, 0x13, 0xb7,
		0x75, 0x02, 0xb7, 0x4b, 0xe4, 0xf9, 0x4c, 0xd9, 0xd0, 0xc1, 0xde, 0xd4, 0xac, 0xa5, 0x86, 0x63,
		0x09, 0x82, 0x82, 0xed, 0xe0, 0x20, 0x26, 0x48, 0x88, 0x09, 0x16, 0x32, 0x82, 0x86, 0xd9, 0xe0,
		0x61, 0x38, 0x88, 0xcc, 0x6e, 0x31, 0x35, 0x1c, 0xd4, 0x70, 0x18, 0x7e, 0xe3, 0xd4, 0x70, 0x5c,
		0x0f, 0x83, 0x1a, 0x0e, 0xdb, 0x0c, 0x38, 0x0f, 0x4d, 0x6a, 0x38, 0x16, 0xa0, 0x49, 0x0d, 0x87,
		0x6d, 0x4d, 0x60, 0xef, 0xaa, 0xec, 0x7d, 0x78, 0x3e, 0x6c, 0xe9, 0x60, 0x8f, 0x83, 0xc6, 0x41,
		0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d, 0x83, 0xc6, 0x41, 0xe3,
		0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0xf4, 0x43, 0x60, 0x4b, 0x07, 0x7b, 0xfc, 0x33, 0xfe, 0x19,
		0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc, 0x33, 0xfe, 0x19, 0xff,
		0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0x1f, 0xe2, 0x9f, 0xe9, 0x60, 0x8f, 0x87, 0xc6, 0x43, 0xe3,
		0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87, 0xc6, 0x43, 0xe3, 0xa1,
		0xf1, 0xd0, 0x78, 0x68, 0x3c, 0xf4, 0x43, 0x60, 0x4b, 0x07, 0x7b, 0x7c, 0x33, 0xbe, 0x19, 0xdf,
		0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66, 0x7c, 0x33, 0xbe, 0x19, 0xdf, 0x8c,
		0x6f, 0xc6, 0x37, 0x3b, 0xe7, 0x9b, 0xe9, 0x60, 0x9f, 0x45, 0x46, 0x40, 0x68, 0x8f, 0xec, 0x30,
		0xe9, 0xd3, 0xc1, 0x3e, 0x69, 0xd5, 0x93, 0x3e, 0x1d, 0xec, 0xc5, 0xcc, 0x56, 0x3a, 0xd8, 0x5f,
		0xcf, 0xce, 0xe5, 0xec, 0x60, 0x5f, 0x4f, 0xfa, 0x74, 0xb0, 0x5f, 0xfc, 0xa0, 0xfa, 0x49, 0x64,
		0xb0, 0x85, 0xfd, 0xe8, 0x6a, 0xf4, 0xb0, 0x7f, 0xd4, 0x85, 0xe8, 0x61, 0x9f, 0x2d, 0x3c, 0xe8,
		0x61, 0x4f, 0x0f, 0xfb, 0x9f, 0xdd, 0x32, 0x7a, 0xd8, 0x3b, 0x47, 0xc8, 0x8b, 0xc4, 0x4c, 0x0f,
		0xfb, 0x3c, 0x10, 0xb6, 0x75, 0xe2, 0xb6, 0x4e, 0xe0, 0x76, 0x89, 0x3c, 0x9f, 0x49, 0x1b, 0x7a,
		0xd8, 0x9b, 0x9a, 0xb5, 0x54, 0x71, 0x2c, 0x41, 0x50, 0xb0, 0x1d, 0x1c, 0xc4, 0x04, 0x09, 0x31,
		0xc1, 0x42, 0x46, 0xd0, 0x30, 0x1b, 0x3c, 0x0c, 0x07, 0x91, 0xd9, 0x2d, 0xa6, 0x8a, 0x83, 0x2a,
		0x0e, 0xc3, 0x6f, 0x9c, 0x2a, 0x8e, 0xeb, 0x61, 0x50, 0xc5, 0x61, 0x9b, 0x01, 0xe7, 0xa1, 0x49,
		0x15, 0xc7, 0x02, 0x34, 0xa9, 0xe2, 0xb0, 0xad, 0x09, 0xec, 0x5d, 0x95, 0xdd, 0x0f, 0xcf, 0x87,
		0x2d, 0x3d, 0xec, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d, 0x83, 0xc6, 0x41,
		0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d, 0x83, 0x7e, 0x08, 0x6c,
		0xe9, 0x61, 0x8f, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc, 0x33, 0xfe, 0x19,
		0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc, 0xf3, 0x43, 0xfc, 0x33,
		0x3d, 0xec, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87, 0xc6, 0x43, 0xe3,
		0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87, 0x7e, 0x08, 0x6c, 0xe9,
		0x61, 0x8f, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66, 0x7c, 0x33, 0xbe, 0x19, 0xdf,
		0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66, 0xe7, 0x7c, 0x33, 0x3d, 0xec, 0xb3,
		0xc8, 0x08, 0x08, 0xed, 0x92, 0xdd, 0x4f, 0x22, 0x9a, 0xd8, 0xc7, 0x49, 0xeb, 0x30, 0x89, 0xe8,
		0x62, 0x2f, 0x67, 0xbe, 0xd2, 0xc5, 0xfe, 0xc6, 0xfc, 0x5c, 0xce, 0x36, 0xf6, 0xc3, 0x19, 0x49,
		0x1f, 0xfb, 0xc5, 0x4f, 0x6a, 0x10, 0x7d, 0x8d, 0x7a, 0x7f, 0x45, 0xe6, 0x5a, 0xd9, 0x4f, 0x2f,
		0x48, 0x37, 0xfb, 0x47, 0x5d, 0x88, 0x6e, 0xf6, 0xd9, 0xc2, 0x83, 0x6e, 0xf6, 0x74, 0xb3, 0xff,
		0xd9, 0x2d, 0xa3, 0x9b, 0xbd, 0x73, 0x84, 0xbc, 0x48, 0xcc, 0x74, 0xb3, 0xcf, 0x03, 0x61, 0x5b,
		0x27, 0x6e, 0xeb, 0x04, 0x6e, 0x97, 0xc8, 0xf3, 0x99, 0xbe, 0xa1, 0x9b, 0xbd, 0xa9, 0x59, 0x4b,
		0x3d, 0xc7, 0x12, 0x04, 0x05, 0xdb, 0xc1, 0x41, 0x4c, 0x90, 0x10, 0x13, 0x2c, 0x64, 0x04, 0x0d,
		0xb3, 0xc1, 0xc3, 0x70, 0x10, 0x99, 0xdd, 0x62, 0xea, 0x39, 0xa8, 0xe7, 0x30, 0xfc, 0xc6, 0xa9,
		0xe7, 0xb8, 0x1e, 0x06, 0xf5, 0x1c, 0xb6, 0x19, 0x70, 0x1e, 0x9a, 0xd4, 0x73, 0x2c, 0x40, 0x93,
		0x7a, 0x0e, 0xdb, 0x9a, 0xc0, 0xde, 0x55, 0xd9, 0x07, 0xf1, 0x7c, 0xd8, 0xd2, 0xcd, 0x1e, 0x07,
		0x8d, 0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0x68, 0x1c, 0x34, 0x0e, 0x1a, 0x07, 0x8d,
		0x83, 0xc6, 0x41, 0xe3, 0xa0, 0x71, 0xd0, 0x38, 0xe8, 0x87, 0xc0, 0x96, 0x6e, 0xf6, 0xf8, 0x67,
		0xfc, 0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0xe3, 0x9f, 0xf1, 0xcf, 0xf8, 0x67, 0xfc,
		0x33, 0xfe, 0x19, 0xff, 0x8c, 0x7f, 0xc6, 0x3f, 0x3f, 0xc4, 0x3f, 0xd3, 0xcd, 0x1e, 0x0f, 0x8d,
		0x87, 0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0x68, 0x3c, 0x34, 0x1e, 0x1a, 0x0f, 0x8d, 0x87,
		0xc6, 0x43, 0xe3, 0xa1, 0xf1, 0xd0, 0x78, 0xe8, 0x87, 0xc0, 0x96, 0x6e, 0xf6, 0xf8, 0x66, 0x7c,
		0x33, 0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0xc6, 0x37, 0xe3, 0x9b, 0xf1, 0xcd, 0xf8, 0x66, 0x7c, 0x33,
		0xbe, 0x19, 0xdf, 0x8c, 0x6f, 0x76, 0xce, 0x37, 0xd3, 0xcd, 0x3e, 0x8b, 0x8c, 0x80, 0xd0, 0x6e,
		0xd9, 0x93, 0x56, 0xc5, 0x34, 0xb4, 0x4f, 0x5a, 0x1f, 0xc7, 0xb7, 0x82, 0x9e, 0xf6, 0x62, 0x66,
		0x2d, 0x3d, 0xed, 0xe7, 0x67, 0xe9, 0x72, 0xb6, 0xb5, 0x9f, 0xcc, 0x4b, 0x67, 0x3b, 0xdb, 0xbf,
		0x70, 0x68, 0xe6, 0x99, 0x9a, 0x71, 0x52, 0x67, 0x9a, 0xc6, 0x19, 0x26, 0x6f, 0x66, 0xe9, 0x99,
		0x51, 0xd9, 0xe3, 0x5d, 0x03, 0xd6, 0x35, 0xb7, 0x23, 0x37, 0xd2, 0x7e, 0x5c, 0x73, 0xbb, 0x71,
		0xed, 0xed, 0xc5, 0x4d, 0xac, 0xa1, 0x18, 0x5c, 0x2b, 0x31, 0xb5, 0x26, 0x62, 0x7c, 0xed, 0xc3,
		0xf8, 0x1a, 0x87, 0xd9, 0xb5, 0x0c, 0xb7, 0xe2, 0xb3, 0xee, 0x76, 0xde, 0x05, 0x15, 0xf9, 0x27,
		0xa1, 0x81, 0xdd, 0xd3, 0xb3, 0x99, 0x39, 0xbd, 0xa0, 0xee, 0x83, 0x2e, 0x54, 0xd7, 0x1f, 0x84,
		0x23, 0x48, 0x75, 0xfd, 0x30, 0x51, 0x86, 0x0e, 0xe7, 0x59, 0xe3, 0x70, 0x1e, 0xc9, 0xa4, 0x6d,
		0x9a, 0xbc, 0xad, 0x91, 0xb8, 0x35, 0x32, 0xb7, 0x43, 0xea, 0xf9, 0x48, 0x7f, 0x18, 0x5b, 0x70,
		0x9e, 0xcd, 0xb8, 0x93, 0x5e, 0x2f, 0x54, 0xbe, 0x91, 0x44, 0xc3, 0x54, 0xbd, 0x96, 0x38, 0xb1,
		0x6e, 0xe1, 0xde, 0x8c, 0xbc, 0xa9, 0x17, 0x0d, 0xce, 0x4f, 0x54, 0x6c, 0x2e, 0x12, 0xcf, 0x5d,
		0x95, 0xf0, 0x48, 0x78, 0x24, 0x3c, 0x12, 0x1e, 0x09, 0x8f, 0x76, 0x18, 0xf2, 0x26, 0x4b, 0x1a,
		0xa8, 0x26, 0x30, 0x5c, 0x62, 0x65, 0x70, 0xe5, 0xd5, 0x46, 0x09, 0x95, 0xad, 0x72, 0xe8, 0x69,
		0x1d, 0x4a, 0xc9, 0xf0, 0x75, 0x2d, 0x96, 0x9b, 0x98, 0x2c, 0xeb, 0xb7, 0x51, 0xf2, 0x64, 0x1b,
		0x4a, 0xeb, 0x4b, 0x04, 0xa5, 0x9c, 0xac, 0xf9, 0x1f, 0xe3, 0xa8, 0x16, 0x60, 0xd5, 0xf7, 0x93,
		0x24, 0xb8, 0x50, 0xe6, 0xcc, 0xd4, 0xf4, 0x82, 0xa4, 0x35, 0xf1, 0x6d, 0xf8, 0x36, 0x7c, 0x1b,
		0xbe, 0xcd, 0xa2, 0x6f, 0x23, 0xad, 0x29, 0x23, 0x08, 0xc7, 0x41, 0x2f, 0x0e, 0xd2, 0x4b, 0x83,
		0x51, 0x78, 0x7a, 0x45, 0xc2, 0x22, 0x61, 0x91, 0xb0, 0x48, 0x58, 0x24, 0x2c, 0xde, 0x98, 0x71,
		0x83, 0x20, 0x4a, 0xdf, 0x90, 0xc7, 0x7c, 0xc6, 0x17, 0x79, 0x4c, 0xad, 0xc9, 0xa7, 0x35, 0xf2,
		0x98, 0x5a, 0xa0, 0xb4, 0x84, 0x79, 0xcc, 0xd2, 0xfa, 0x16, 0x99, 0x4c, 0xd7, 0xae, 0x72, 0xcc,
		0x9e, 0x0f, 0xfd, 0x14, 0xb1, 0x74, 0x7b, 0x3e, 0x74, 0xef, 0x75, 0x94, 0xb0, 0xd3, 0x43, 0xe3,
		0x26, 0x46, 0x37, 0x36, 0x78, 0xa4, 0xc1, 0xb9, 0x8a, 0x13, 0xfd, 0x3b, 0x3c, 0x26, 0xd7, 0x71,
		0x7c, 0x8b, 0xc7, 0x1a, 0x5b, 0x3c, 0x04, 0xe5, 0x0d, 0xd8, 0xe2, 0xb1, 0xcc, 0xe1, 0x58, 0xfb,
		0x16, 0x8f, 0xf6, 0x74, 0xd6, 0x1b, 0x4a, 0xc2, 0x4e, 0xae, 0x67, 0x26, 0x05, 0x5b, 0x22, 0x05,
		0x2b, 0x99, 0x42, 0x4d, 0x53, 0xa9, 0x35, 0x4a, 0xb5, 0x46, 0xad, 0x76, 0x28, 0xd6, 0x8c, 0x27,
		0xd4, 0x9d, 0x82, 0xd5, 0x4d, 0xbd, 0xb3, 0x0b, 0x9d, 0xa9, 0x30, 0xec, 0x79, 0x23, 0x7f, 0x72,
		0xe1, 0x87, 0xe6, 0x66, 0xc1, 0x74, 0xa2, 0xdf, 0xba, 0xbe, 0x21, 0x44, 0x9a, 0x4d, 0x01, 0x19,
		0x6f, 0x0e, 0x6b, 0xa3, 0x29, 0xac, 0xc5, 0x66, 0xb0, 0xb6, 0x9a, 0xc0, 0x5a, 0x6f, 0xfe, 0x6a,
		0xbd, 0xe9, 0xab, 0xdd, 0x66, 0xaf, 0xf9, 0x6a, 0x08, 0x66, 0xbc, 0xa9, 0xeb, 0xdc, 0xea, 0x9b,
		0xd1, 0x4e, 0xae, 0x16, 0x3a, 0xb8, 0x5a, 0xea, 0xdc, 0x6a, 0xa1, 0x45, 0xaf, 0xcd, 0x4e, 0xad,
		0x96, 0xdb, 0x60, 0xda, 0xee, 0xcc, 0x2a, 0xa1, 0xdb, 0xa5, 0x85, 0x4e, 0xac, 0x56, 0x3b, 0xb0,
		0x4a, 0x81, 0x9c, 0xed, 0x8e, 0xab, 0x22, 0xb0, 0x97, 0xd3, 0xce, 0xa3, 0xc7, 0x79, 0xe9, 0xc1,
		0xf8, 0x8b, 0x29, 0x43, 0x79, 0x3e, 0x08, 0xd3, 0xa0, 0x1f, 0x06, 0x2a, 0xb6, 0x65, 0x29, 0x6f,
		0x8c, 0x00, 0x53, 0x89, 0xa9, 0xc4, 0x54, 0x62, 0x2a, 0x31, 0x95, 0x86, 0x4d, 0xe5, 0x1b, 0x0b,
		0x9e, 0x72, 0x03, 0x4f, 0x89, 0xa7, 0xc4, 0x53, 0xe2, 0x29, 0x73, 0x00, 0xb9, 0xf5, 0x0d, 0xcc,
		0x24, 0x66, 0x52, 0xaa, 0x99, 0xa4, 0xa1, 0xff, 0x23, 0xae, 0x27, 0xa5, 0xe4, 0x74, 0x5c, 0x25,
		0x58, 0x34, 0x52, 0x09, 0xb3, 0x22, 0xa4, 0x04, 0xb5, 0x39, 0x7a, 0xcf, 0xad, 0x89, 0x61, 0x66,
		0x3b, 0xec, 0x1d, 0x9f, 0x91, 0xce, 0x1e, 0xe4, 0x0b, 0xd6, 0xc0, 0xc4, 0x11, 0x2f, 0xc6, 0xab,
		0xb0, 0xd6, 0xa9, 0xc2, 0x72, 0x28, 0xdb, 0x42, 0x15, 0x16, 0x55, 0x58, 0x3f, 0xbf, 0x65, 0x54,
		0x61, 0xe5, 0xc8, 0x65, 0x91, 0x30, 0xcf, 0x17, 0x85, 0x5b, 0xa7, 0x72, 0xeb, 0x94, 0x6e, 0x97,
		0xda, 0xcd, 0x3a, 0x67, 0xaa, 0xb0, 0xb4, 0xf1, 0x2f, 0x55, 0x58, 0x1a, 0xde, 0x28, 0x19, 0x73,
		0x32, 0xe6, 0xa6, 0x21, 0x47, 0xc6, 0x9c, 0x2a, 0x2c, 0x12, 0xe7, 0xe2, 0xdf, 0x0f, 0x55, 0x58,
		0x98, 0x4a, 0x4c, 0x25, 0xa6, 0x12, 0x53, 0x89, 0xa9, 0x34, 0x61, 0x2a, 0xa9, 0xc2, 0xc2, 0x53,
		0xe2, 0x29, 0xf1, 0x94, 0x78, 0xca, 0xa7, 0x41, 0x8e, 0x2a, 0x2c, 0xcc, 0xa4, 0x5c, 0x33, 0x49,
		0x15, 0xd6, 0x23, 0xae, 0x27, 0xac, 0x0a, 0xcb, 0x44, 0x21, 0xcc, 0x8a, 0xac, 0x22, 0x2c, 0x8d,
		0xed, 0x00, 0xf5, 0x4f, 0x09, 0xba, 0x69, 0xca, 0x9f, 0x54, 0x39, 0x6f, 0xa7, 0x39, 0x9e, 0x46,
		0xce, 0xf4, 0xd3, 0x7c, 0x21, 0x78, 0xa2, 0x14, 0x7e, 0x53, 0x97, 0x9a, 0xcf, 0xd2, 0x2c, 0xd4,
		0x83, 0x24, 0xad, 0xa4, 0xa9, 0x9e, 0xfc, 0xeb, 0xd0, 0x10, 0x56, 0x43, 0x75, 0xae, 0xa2, 0xb1,
		0x38, 0xd4, 0xd0, 0xbc, 0xf4, 0x83, 0xff, 0xed, 0xc6, 0x15, 0x4a, 0x6f, 0xca, 0xe5, 0xcd, 0xad,
		0x72, 0x79, 0x6d, 0xeb, 0xf5, 0xd6, 0xda, 0xf6, 0xc6, 0x46, 0x69, 0xb3, 0xa4, 0x41, 0x1a, 0x17,
		0x0e, 0xe2, 0x8e, 0x8a, 0x55, 0x67, 0x77, 0xf8, 0xe9, 0x44, 0x83, 0x30, 0x14, 0x0d, 0x22, 0xcd,
		0x2c, 0x2b, 0x85, 0x5d, 0x35, 0xd0, 0xaa, 0x00, 0x3a, 0xcd, 0x96, 0x47, 0xb3, 0x63, 0xbb, 0x6c,
		0x5e, 0x29, 0x23, 0xa8, 0xeb, 0x82, 0xb8, 0x7d, 0x68, 0x67, 0x08, 0x6a, 0xab, 0x60, 0xce, 0x06,
		0xc6, 0xcf, 0x07, 0x5d, 0x06, 0x80, 0x2b, 0x9c, 0xf7, 0xc3, 0xec, 0x9a, 0x65, 0xcf, 0xf2, 0xe0,
		0xa3, 0x57, 0xcd, 0x68, 0x3a, 0x64, 0xbb, 0xb3, 0x20, 0xf3, 0x15, 0x44, 0x1d, 0x2b, 0x84, 0x1a,
		0x57, 0x00, 0x75, 0xad, 0xf0, 0x69, 0x5f, 0xc1, 0xd3, 0xbe, 0x42, 0xa7, 0x77, 0x05, 0x4e, 0x56,
		0x88, 0xc9, 0xba, 0xd2, 0xbe, 0x10, 0x9c, 0xf6, 0xbd, 0xb0, 0xd3, 0xf7, 0x92, 0xcb, 0xa8, 0x9d,
		0x3d, 0xb6, 0xa6, 0xd3, 0x61, 0xee, 0x2a, 0x59, 0xbb, 0x13, 0x2d, 0x1b, 0x98, 0xb4, 0x15, 0x2c,
		0xe8, 0x2c, 0x4c, 0x30, 0x50, 0x80, 0xa0, 0xbb, 0xd0, 0xc0, 0x58, 0x41, 0x81, 0xb1, 0xc2, 0x01,
		0x33, 0x05, 0x02, 0xb2, 0x33, 0x08, 0xba, 0x36, 0x08, 0xe9, 0xee, 0x8c, 0x6f, 0xa6, 0x23, 0x3e,
		0x87, 0x86, 0x88, 0xa0, 0x36, 0x53, 0x14, 0x67, 0x9c, 0xea, 0x8c, 0x53, 0x9e, 0x59, 0xea, 0xd3,
		0x43, 0x81, 0x9a, 0xa8, 0x50, 0x3b, 0x25, 0xce, 0x2e, 0xa0, 0x22, 0xff, 0x24, 0x54, 0x1d, 0x73,
		0xdb, 0xd5, 0xa7, 0x17, 0xd4, 0xbd, 0xd9, 0x54, 0x75, 0xfd, 0x41, 0x38, 0x82, 0xd4, 0x10, 0xc1,
		0x1c, 0x14, 0x2d, 0x8e, 0xab, 0x2d, 0x70, 0xb6, 0x69, 0xee, 0xb6, 0xc6, 0xe1, 0xd6, 0xb8, 0xdc,
		0x0e, 0xa7, 0xeb, 0xe5, 0x76, 0xcd, 0x1c, 0x3f, 0xbb, 0x65, 0xe6, 0x0f, 0x8a, 0x3e, 0xe9, 0xf5,
		0x42, 0xe5, 0x47, 0x06, 0x8f, 0x8a, 0x2e, 0x95, 0x68, 0x18, 0xb3, 0x70, 0x6f, 0xfa, 0xbd, 0x24,
		0xf5, 0x12, 0x95, 0x24, 0x41, 0x2f, 0xf2, 0x06, 0x7d, 0xaf, 0xa3, 0x42, 0xff, 0xd2, 0x5c, 0x44,
		0xbe, 0xfb, 0xf2, 0x04, 0x4c, 0x02, 0x26, 0x01, 0x93, 0x80, 0x49, 0xc0, 0xbc, 0xb5, 0x01, 0xa4,
		0xb4, 0x69, 0x30, 0x5e, 0x6e, 0x1a, 0xb8, 0x94, 0xd9, 0x1d, 0x1f, 0x06, 0xb7, 0xed, 0xd8, 0xd8,
		0xe1, 0x61, 0xfb, 0x3c, 0xfc, 0xb5, 0x25, 0x3a, 0x0d, 0xdf, 0xe0, 0xae, 0x28, 0x1b, 0x3b, 0x37,
		0x6c, 0x43, 0x69, 0x73, 0x63, 0xe3, 0xf5, 0xc6, 0x12, 0xc1, 0x29, 0x27, 0x7b, 0x18, 0x8e, 0x29,
		0x07, 0xd7, 0x4f, 0x12, 0xcb, 0x50, 0x0e, 0x7e, 0xde, 0x0f, 0x93, 0xe2, 0xcd, 0x35, 0x79, 0xfd,
		0x7d, 0x6e, 0x2d, 0xd5, 0x7d, 0x7d, 0xe8, 0x87, 0x49, 0xab, 0x76, 0xda, 0xaf, 0x77, 0xfa, 0x47,
		0x97, 0x51, 0x5b, 0x6b, 0x6f, 0x5b, 0x0d, 0x65, 0xe1, 0x5a, 0x8a, 0x49, 0x75, 0xf6, 0xb0, 0x35,
		0xd2, 0xbb, 0xd6, 0xd8, 0x7a, 0xe9, 0x3a, 0xeb, 0xa5, 0x82, 0x52, 0x08, 0xac, 0x97, 0x2e, 0x73,
		0x58, 0x66, 0xbd, 0xf4, 0xa9, 0x37, 0x8e, 0xf5, 0x52, 0xe1, 0x5c, 0x6d, 0x81, 0xb3, 0x4d, 0x73,
		0xb7, 0x35, 0x0e, 0xb7, 0xc6, 0xe5, 0x76, 0x38, 0xdd, 0x8c, 0x19, 0x65, 0xbd, 0x34, 0x03, 0xf1,
		0xca, 0x7a, 0xe9, 0xe2, 0xbd, 0x61, 0xbd, 0x94, 0x80, 0x49, 0xc0, 0x24, 0x60, 0x12, 0x30, 0xa5,
		0x07, 0x4c, 0xd6, 0x4b, 0x9f, 0xfd, 0xc5, 0x7a, 0xa9, 0x96, 0xcb, 0xb2, 0x5e, 0xaa, 0x17, 0x4a,
		0xac, 0x97, 0xe6, 0x1e, 0x4e, 0xac, 0x97, 0xda, 0x75, 0x58, 0xac, 0x97, 0xde, 0x71, 0x1d, 0x51,
		0xeb, 0xa5, 0xba, 0x3b, 0xd2, 0x09, 0x59, 0x2e, 0xd5, 0xd8, 0x85, 0x6e, 0xd9, 0x9a, 0x68, 0xe5,
		0xb8, 0xff, 0xd1, 0xc2, 0xf4, 0xc8, 0x4f, 0x13, 0xa4, 0x5b, 0x13, 0x82, 0x3e, 0x48, 0x16, 0xa1,
		0x6e, 0x1b, 0xe2, 0xee, 0x77, 0x41, 0x1a, 0xa2, 0x39, 0x4f, 0x3d, 0x90, 0xb2, 0xad, 0x65, 0xd1,
		0x52, 0xbb, 0xa2, 0xad, 0x0b, 0xd2, 0x3a, 0x5d, 0x90, 0x32, 0x75, 0x98, 0x74, 0x41, 0x72, 0x27,
		0xc0, 0x64, 0xde, 0x05, 0xa9, 0x1d, 0xc4, 0xed, 0x41, 0x90, 0x7a, 0xa9, 0x8e, 0x3c, 0xea, 0x75,
		0x13, 0x91, 0x9b, 0x57, 0xd1, 0xd3, 0x05, 0x69, 0x8d, 0x2e, 0x48, 0x74, 0x41, 0x92, 0x44, 0x4b,
		0x66, 0xe8, 0xc9, 0x0d, 0x0b, 0xa8, 0x6d, 0x95, 0xc6, 0x04, 0xc3, 0xcc, 0x89, 0x99, 0xb2, 0x86,
		0xd7, 0xae, 0x46, 0x83, 0xf3, 0xe1, 0xdd, 0xb9, 0x92, 0xea, 0xb1, 0x32, 0x54, 0x31, 0xba, 0x6a,
		0x0d, 0x35, 0xd7, 0x16, 0xde, 0xac, 0x25, 0xec, 0xfa, 0x61, 0x42, 0x14, 0x23, 0x8a, 0x11, 0xc5,
		0x88, 0x62, 0x19, 0x23, 0x5e, 0x5f, 0x31, 0x9e, 0xa6, 0xe2, 0x3b, 0x99, 0x41, 0x66, 0x7c, 0xb2,
		0x6c, 0xdf, 0xef, 0x74, 0x82, 0xe8, 0x54, 0x5f, 0xa8, 0x99, 0xbf, 0x0c, 0x01, 0x81, 0x80, 0x40,
		0x40, 0x20, 0x20, 0xe8, 0xa3, 0x18, 0xcc, 0x8d, 0xf0, 0xb8, 0x33, 0x5b, 0x35, 0xf1, 0x02, 0x8d,
		0x0e, 0x67, 0xee, 0x2a, 0x44, 0x1d, 0xa2, 0x0e, 0x51, 0x87, 0xa8, 0xe3, 0x0a, 0xc3, 0xcc, 0xc5,
		0x9b, 0x37, 0x4b, 0x10, 0x13, 0xfa, 0x7e, 0x92, 0x04, 0x17, 0x1a, 0xd7, 0x56, 0xa6, 0x17, 0x20,
		0xe1, 0x45, 0xa4, 0x21, 0xd2, 0x10, 0x69, 0x48, 0x78, 0x39, 0x92, 0xf0, 0xa2, 0x72, 0x4d, 0x6f,
		0xe5, 0x5a, 0xd6, 0x95, 0xca, 0x96, 0x4a, 0xd7, 0x32, 0xac, 0x44, 0x96, 0x51, 0xbb, 0x36, 0x39,
		0x85, 0x39, 0xf3, 0xe2, 0xb5, 0x4c, 0x4f, 0x77, 0xe6, 0x0c, 0x3f, 0xaa, 0xd7, 0x56, 0xa8, 0x5e,
		0xcb, 0x36, 0xc8, 0x64, 0x5f, 0xbd, 0xa6, 0xe7, 0x10, 0x2c, 0xbd, 0x87, 0x5f, 0x71, 0x6e, 0x1f,
		0xd6, 0x07, 0xeb, 0xb3, 0xb4, 0xe7, 0xf6, 0x25, 0x51, 0xdf, 0x1b, 0x89, 0xd4, 0x0b, 0x3f, 0x34,
		0x70, 0x7c, 0xdf, 0xdc, 0xe5, 0xf4, 0x76, 0xa5, 0x5c, 0xe3, 0x14, 0x3f, 0x9b, 0x44, 0x67, 0x8a,
		0xf0, 0x8c, 0x13, 0x9f, 0x71, 0x02, 0x34, 0x4b, 0x84, 0x7a, 0x08, 0x51, 0x13, 0x31, 0xea, 0xcf,
		0x0d, 0x2d, 0xcc, 0x18, 0xed, 0x0d, 0x57, 0x0c, 0x34, 0x5a, 0x31, 0xd4, 0x60, 0xc5, 0x40, 0x1b,
		0x1c, 0x93, 0x0d, 0x55, 0x0c, 0x77, 0xbf, 0x30, 0xdd, 0x40, 0xc5, 0x46, 0xa7, 0x0b, 0x03, 0x0d,
		0x53, 0x8c, 0x36, 0x4a, 0xb1, 0x05, 0x11, 0x83, 0x8d, 0x51, 0xac, 0xc0, 0xc4, 0xd1, 0x06, 0x22,
		0xc7, 0x4b, 0xdc, 0xdf, 0x3e, 0x4c, 0xfa, 0x5e, 0xdf, 0x6f, 0x07, 0xd1, 0xa9, 0x41, 0x7f, 0x71,
		0xd7, 0x45, 0x71, 0x19, 0xb8, 0x0c, 0x5c, 0x06, 0x2e, 0xc3, 0x39, 0x97, 0xb1, 0x59, 0x36, 0xe0,
		0x32, 0xde, 0xe0, 0x32, 0x70, 0x19, 0xb8, 0x0c, 0x5c, 0xc6, 0x03, 0x20, 0x52, 0x7a, 0x53, 0x2e,
		0x6f, 0x6e, 0x95, 0xcb, 0x6b, 0x5b, 0xaf, 0xb7, 0xd6, 0xb6, 0x37, 0x36, 0x4a, 0x9b, 0x25, 0x4c,
		0x07, 0xa6, 0x43, 0xc4, 0x2b, 0xd2, 0x26, 0xee, 0xc1, 0x95, 0x48, 0xe3, 0xca, 0x14, 0x7d, 0x47,
		0xcd, 0x59, 0xaa, 0x4c, 0x6a, 0x8e, 0xde, 0x96, 0x96, 0x93, 0xe5, 0x64, 0xd6, 0x72, 0xeb, 0x39,
		0x41, 0x4e, 0xeb, 0xc9, 0x71, 0xda, 0x8b, 0x0d, 0xd6, 0x29, 0x36, 0x30, 0xe8, 0x8a, 0x29, 0x36,
		0xc8, 0x63, 0xe8, 0xa3, 0xd8, 0x40, 0x8c, 0x14, 0x27, 0x0d, 0x28, 0x8b, 0xf0, 0x8c, 0x13, 0x9f,
		0x71, 0x02, 0x34, 0x4b, 0x84, 0x7a, 0xdd, 0x10, 0xc5, 0x06, 0x0f, 0xe6, 0x2f, 0x8a, 0x0d, 0x1e,
		0x92, 0xe3, 0x21, 0x0d, 0xe8, 0x74, 0x42, 0x87, 0x34, 0x60, 0x26, 0x10, 0xa1, 0xd8, 0x40, 0xe4,
		0xab, 0x53, 0x6c, 0x40, 0xb1, 0x01, 0x2e, 0x03, 0x97, 0x81, 0xcb, 0xc0, 0x65, 0x3c, 0xde, 0x65,
		0x50, 0x6c, 0x80, 0xcb, 0xc0, 0x65, 0xe0, 0x32, 0xc4, 0x40, 0x84, 0x62, 0x03, 0x4c, 0x87, 0xd4,
		0x57, 0xa4, 0xd8, 0xe0, 0xb1, 0xc5, 0x06, 0xba, 0xce, 0x69, 0xb4, 0x5b, 0x6b, 0xa0, 0xe1, 0x58,
		0x46, 0x3a, 0xfa, 0x38, 0x06, 0x6d, 0xf7, 0x5b, 0xfa, 0x8c, 0xc1, 0x2c, 0xa6, 0xa7, 0xcf, 0x0b,
		0x8b, 0x70, 0x1d, 0x3a, 0xee, 0x8c, 0x5b, 0x4e, 0x16, 0xea, 0x41, 0x92, 0x56, 0xd2, 0x34, 0x9b,
		0x35, 0xf5, 0xa1, 0x3b, 0xa8, 0x86, 0x6a, 0x68, 0x99, 0x93, 0x6c, 0x44, 0xd9, 0x50, 0x4c, 0xde,
		0x78, 0x45, 0x3d, 0xb2, 0xab, 0x70, 0x10, 0x77, 0x54, 0xac, 0x3a, 0xbb, 0xc3, 0xbb, 0x1b, 0x0d,
		0xc2, 0xd0, 0xea, 0x87, 0x9c, 0x31, 0x17, 0x59, 0xe4, 0xa0, 0x42, 0x26, 0x87, 0x37, 0x5a, 0x20,
		0x9d, 0xe7, 0xb1, 0xcd, 0xd3, 0x39, 0xe2, 0x69, 0x7f, 0xf9, 0x44, 0xc0, 0x65, 0x05, 0x34, 0xe3,
		0x00, 0x7b, 0x06, 0xac, 0x4c, 0xc2, 0xe9, 0x69, 0x20, 0x7a, 0x3c, 0x04, 0x9e, 0xf0, 0xf1, 0x17,
		0x42, 0x75, 0xa1, 0xc2, 0xa7, 0xb7, 0x95, 0xbb, 0x5e, 0x64, 0x18, 0xbf, 0xce, 0x13, 0x01, 0xf8,
		0xbc, 0x72, 0xcb, 0x67, 0xaf, 0x0b, 0x64, 0x91, 0xf7, 0xcf, 0x30, 0xaf, 0x9f, 0x55, 0xde, 0x3e,
		0xf3, 0xbc, 0x7c, 0xe6, 0x79, 0xf7, 0x6c, 0xf3, 0xea, 0x66, 0x49, 0xf3, 0xb9, 0xe5, 0x87, 0xe3,
		0x29, 0xf3, 0xfc, 0x0f, 0x79, 0x6e, 0x06, 0x3e, 0xf7, 0x03, 0xce, 0xa6, 0xee, 0x39, 0xb3, 0x85,
		0xba, 0x2c, 0x17, 0xe4, 0x34, 0x2c, 0xbc, 0x65, 0xbd, 0xc0, 0xa6, 0x6d, 0x21, 0x4d, 0xdb, 0x82,
		0x99, 0x9e, 0x85, 0x31, 0xbb, 0xde, 0x2a, 0xab, 0xba, 0xe2, 0x82, 0x3f, 0x48, 0xcf, 0x54, 0x94,
		0x06, 0xed, 0x6c, 0xf3, 0x09, 0x33, 0x20, 0xdf, 0x7a, 0x7d, 0x5a, 0xb8, 0x0a, 0xa2, 0x06, 0x5d,
		0x14, 0xa1, 0x9d, 0x2a, 0xb4, 0x53, 0x86, 0x5e, 0xea, 0x90, 0x99, 0x55, 0xa4, 0x85, 0xeb, 0x0a,
		0x2d, 0x5c, 0x4d, 0x51, 0x8e, 0x6e, 0xea, 0x31, 0x46, 0x41, 0xc6, 0xa8, 0xc8, 0x0c, 0x25, 0x65,
		0x4b, 0x4d, 0x19, 0x53, 0x94, 0x36, 0xaa, 0xba, 0xa6, 0xac, 0x24, 0xea, 0x7b, 0x9a, 0x24, 0xd1,
		0xfd, 0x3c, 0x76, 0xc7, 0x45, 0x35, 0x61, 0x47, 0xf3, 0xd1, 0x3f, 0xb7, 0x49, 0x94, 0x1a, 0x4b,
		0xab, 0xe4, 0x6a, 0x8a, 0x64, 0x8d, 0x93, 0xad, 0x71, 0xd2, 0x35, 0x4b, 0xbe, 0x7a, 0x48, 0x58,
		0x13, 0x19, 0xcf, 0x6e, 0x8d, 0xb9, 0x1a, 0x4b, 0x7d, 0x47, 0x0b, 0x2d, 0xa8, 0xc0, 0xd2, 0x92,
		0x6f, 0x04, 0x30, 0x1d, 0x0b, 0xef, 0xb8, 0x26, 0xa1, 0x90, 0x50, 0x48, 0x28, 0x24, 0x14, 0x12,
		0x0a, 0x09, 0x85, 0xb6, 0x42, 0x61, 0xdf, 0x86, 0x2f, 0xec, 0xe3, 0x0b, 0x09, 0x86, 0x04, 0x43,
		0x82, 0x21, 0xc1, 0x90, 0x60, 0x28, 0xe2, 0x15, 0xd9, 0xab, 0x71, 0x57, 0xad, 0xdf, 0xb8, 0xac,
		0x6c, 0xfc, 0xa3, 0x38, 0x1f, 0xaf, 0x5d, 0x6e, 0x0c, 0x59, 0x1f, 0xbd, 0xad, 0xf1, 0x8f, 0x56,
		0x65, 0xee, 0x6d, 0x2d, 0x51, 0x63, 0xc8, 0xaf, 0xa3, 0x22, 0x76, 0x4d, 0x2b, 0x98, 0xc3, 0x17,
		0x67, 0xf9, 0x92, 0xe5, 0x4b, 0xfb, 0xca, 0x89, 0xe5, 0x4b, 0x83, 0x61, 0x4f, 0xdf, 0xf2, 0xa5,
		0x9e, 0x8a, 0x8b, 0x85, 0x09, 0xa5, 0x2d, 0xaa, 0x69, 0xa4, 0x30, 0x4c, 0x22, 0x26, 0x11, 0x93,
		0x28, 0xd5, 0x24, 0xea, 0xa2, 0xc4, 0xd9, 0x05, 0x86, 0xba, 0xdc, 0xeb, 0xfb, 0x49, 0x32, 0xc1,
		0x98, 0x66, 0x30, 0xdf, 0x2c, 0x7f, 0xbd, 0xbe, 0xac, 0x66, 0x7c, 0x99, 0xe9, 0x2e, 0xa1, 0x9d,
		0x40, 0x4d, 0x12, 0xa9, 0x05, 0x42, 0x35, 0x4d, 0xac, 0xd6, 0x08, 0xd6, 0x1a, 0xd1, 0xda, 0x21,
		0x5c, 0xbd, 0xc4, 0xab, 0x99, 0x80, 0xcd, 0x65, 0xeb, 0x16, 0x66, 0x5c, 0xdc, 0x1b, 0xa4, 0x41,
		0x74, 0x6a, 0x8a, 0x25, 0xe7, 0x24, 0xe6, 0x1b, 0x47, 0x5b, 0xc5, 0xb8, 0x15, 0xdc, 0x35, 0xa7,
		0xf9, 0x04, 0xa5, 0xfb, 0xbe, 0xaa, 0xcb, 0xa2, 0x56, 0x73, 0x64, 0x3f, 0xf5, 0xf7, 0x9b, 0xba,
		0xd4, 0x92, 0xfe, 0xd3, 0x07, 0xed, 0x2b, 0x2d, 0xd9, 0x57, 0x1d, 0xe7, 0xc5, 0x2c, 0x70, 0xa3,
		0xae, 0x56, 0x3f, 0x46, 0x7d, 0xf6, 0x3a, 0x3e, 0x1b, 0x9f, 0x8d, 0xcf, 0xc6, 0x67, 0xe3, 0xb3,
		0xf1, 0xd9, 0xf8, 0x6c, 0x7c, 0x36, 0x3e, 0x1b, 0x9f, 0x8d, 0xcf, 0xc6, 0x67, 0x3f, 0xcf, 0x67,
		0xeb, 0xf4, 0x46, 0x32, 0x6c, 0xb6, 0x86, 0x96, 0xa8, 0x1a, 0x5d, 0x36, 0x95, 0x66, 0xb6, 0xa7,
		0x44, 0xee, 0xca, 0xcc, 0x7e, 0x53, 0x97, 0x4b, 0x52, 0x63, 0xd6, 0x3e, 0xf3, 0x35, 0x1c, 0x55,
		0x70, 0xb3, 0xd0, 0x6c, 0x7c, 0x05, 0xaa, 0xcd, 0xa8, 0x36, 0xb3, 0xef, 0x5c, 0xa8, 0x36, 0x23,
		0xf4, 0x65, 0x1b, 0xfa, 0x74, 0xb0, 0x9b, 0x88, 0xf8, 0x37, 0x7e, 0x63, 0x9c, 0xc0, 0xff, 0x5c,
		0x56, 0xe6, 0x04, 0x7e, 0xc2, 0x1f, 0xe1, 0x8f, 0x62, 0xeb, 0xec, 0x5e, 0x98, 0x5e, 0x51, 0x99,
		0x92, 0x28, 0x7b, 0x82, 0xad, 0x92, 0xab, 0x29, 0x92, 0x35, 0x4e, 0xb6, 0xc6, 0x49, 0xd7, 0x2c,
		0xf9, 0xea, 0x4b, 0xe8, 0xad, 0xb0, 0x27, 0xf8, 0x71, 0x2a, 0x90, 0x5e, 0x51, 0xf4, 0x8a, 0x22,
		0x14, 0x12, 0x0a, 0x09, 0x85, 0x84, 0x42, 0x42, 0xe1, 0xd2, 0x86, 0x42, 0x7a, 0x45, 0x11, 0x0c,
		0x09, 0x86, 0x04, 0x43, 0x82, 0x21, 0xc1, 0x90, 0x5e, 0x51, 0xd9, 0xcd, 0x9a, 0xdc, 0x2f, 0x63,
		0xba, 0x7b, 0xae, 0xf7, 0x8f, 0xd6, 0x30, 0x39, 0xd7, 0xdb, 0x36, 0xc4, 0xed, 0x43, 0xdb, 0xa9,
		0x73, 0xbd, 0x7f, 0x00, 0x66, 0x31, 0xe7, 0x7a, 0x67, 0x70, 0x2c, 0x60, 0xc6, 0xbd, 0x82, 0xf4,
		0xf4, 0x06, 0xe2, 0xa0, 0x37, 0x0e, 0x7a, 0x5b, 0xe1, 0xa0, 0xb7, 0x6c, 0xc3, 0x4c, 0xe6, 0x07,
		0xbd, 0xcd, 0x93, 0xbd, 0xd7, 0x3e, 0x53, 0xed, 0xaf, 0xfa, 0x2a, 0x79, 0xee, 0xbc, 0x5a, 0xd6,
		0x45, 0x03, 0xd7, 0x39, 0x8e, 0x21, 0xd6, 0x34, 0xd5, 0x0d, 0xad, 0x51, 0x36, 0x4b, 0xdd, 0x90,
		0xc4, 0x54, 0x05, 0x75, 0x43, 0x1a, 0x53, 0x11, 0x06, 0x52, 0x10, 0x9a, 0x52, 0x0f, 0x32, 0x0b,
		0x47, 0x55, 0xe4, 0x9f, 0x84, 0xaa, 0xa3, 0x2f, 0xe0, 0x4c, 0x2f, 0xa0, 0x2f, 0xc6, 0xe8, 0xc8,
		0xa3, 0x13, 0x64, 0x08, 0x32, 0x04, 0x19, 0x82, 0x0c, 0x41, 0x26, 0x8b, 0xf7, 0x3a, 0xca, 0x6a,
		0x79, 0xd1, 0xe0, 0xfc, 0x44, 0xc5, 0xfa, 0x22, 0xcd, 0xdc, 0x55, 0x08, 0x07, 0x84, 0x03, 0xc2,
		0x01, 0xe1, 0xc0, 0x15, 0x86, 0xb9, 0xc9, 0x32, 0x1b, 0x1a, 0x5e, 0xba, 0xe1, 0x47, 0xa7, 0xc3,
		0xf7, 0xf0, 0x59, 0x0b, 0xfc, 0x34, 0x2e, 0x39, 0x7f, 0x08, 0x22, 0x03, 0x65, 0x13, 0x66, 0x7a,
		0x52, 0x7d, 0xf2, 0xc3, 0x81, 0xd2, 0xd7, 0x34, 0x70, 0x76, 0x9d, 0x77, 0xb1, 0xdf, 0x4e, 0x83,
		0x5e, 0xb4, 0x17, 0x9c, 0x06, 0x69, 0x32, 0x7c, 0x63, 0xfa, 0x2a, 0x24, 0x34, 0x96, 0x00, 0x7c,
		0xf0, 0xbf, 0xe5, 0xee, 0xa3, 0x5f, 0xcf, 0xd1, 0x47, 0xef, 0x48, 0x65, 0xc6, 0xf1, 0x12, 0x28,
		0xec, 0x73, 0x95, 0xc6, 0x41, 0xdb, 0x4b, 0xd2, 0xcb, 0x50, 0xe3, 0x36, 0xe0, 0xb9, 0xab, 0xa0,
		0xb0, 0x51, 0xd8, 0x28, 0x6c, 0x14, 0xb6, 0x2b, 0x0c, 0x33, 0x97, 0x75, 0x29, 0x6b, 0x78, 0xed,
		0x6a, 0x34, 0x38, 0x1f, 0xde, 0x9d, 0x2b, 0xca, 0xb5, 0x1e, 0x32, 0x9d, 0xf2, 0x53, 0xae, 0x95,
		0x79, 0xcf, 0x7a, 0xc3, 0x65, 0x5a, 0x59, 0x36, 0xa4, 0x97, 0x51, 0x9e, 0xa5, 0x25, 0xe1, 0xa8,
		0x33, 0x0d, 0x90, 0xb1, 0xfc, 0xa1, 0x54, 0x8b, 0x52, 0x2d, 0x1b, 0x32, 0x46, 0x56, 0x88, 0xc9,
		0x5c, 0xae, 0xdc, 0x60, 0x00, 0xbf, 0x1b, 0xab, 0x6e, 0x96, 0x88, 0x9d, 0x2a, 0x93, 0xad, 0x0c,
		0x5f, 0xf3, 0x70, 0x12, 0x05, 0x5f, 0xbd, 0x9a, 0xc4, 0xa8, 0xe2, 0x1c, 0x75, 0xe5, 0x89, 0xf0,
		0x83, 0xe8, 0xab, 0x37, 0xda, 0x02, 0xe0, 0x75, 0xfc, 0xd4, 0x3f, 0xf1, 0x13, 0xa5, 0x81, 0xf7,
		0xef, 0xb8, 0x88, 0xf0, 0x4a, 0xdd, 0x75, 0xe8, 0x1f, 0xfa, 0x5f, 0x52, 0xfa, 0xcf, 0xbc, 0x52,
		0x37, 0x4c, 0xfa, 0x1a, 0x57, 0xaf, 0x93, 0x3e, 0xfd, 0x65, 0x49, 0xa9, 0x91, 0x52, 0x5b, 0xae,
		0x94, 0x9a, 0xb6, 0x06, 0x7b, 0x61, 0xd2, 0xf7, 0x82, 0x8e, 0x99, 0x3e, 0x42, 0x41, 0x87, 0x36,
		0x06, 0xc6, 0x29, 0xcd, 0x20, 0xb5, 0x99, 0xa2, 0x38, 0xe3, 0x54, 0x67, 0x9c, 0xf2, 0xcc, 0x52,
		0x9f, 0x1e, 0x0a, 0xd4, 0x44, 0x85, 0xfa, 0x6c, 0xbb, 0x41, 0x1b, 0x6f, 0xc2, 0xd6, 0xff, 0xc8,
		0xe6, 0x8f, 0xdc, 0x69, 0x71, 0xc2, 0xc9, 0x9c, 0x30, 0xca, 0x09, 0xa3, 0xc4, 0x3e, 0x62, 0x1f,
		0xb1, 0xcf, 0x99, 0xd8, 0xa7, 0xfd, 0x84, 0xd1, 0xd1, 0x86, 0xdf, 0x64, 0xbc, 0x50, 0x6d, 0xe6,
		0x70, 0xd1, 0xd9, 0x15, 0x39, 0x57, 0x54, 0x1a, 0x7d, 0x5a, 0xa0, 0x51, 0xd3, 0x74, 0x6a, 0x8d,
		0x56, 0xad, 0xd1, 0xab, 0x1d, 0x9a, 0xd5, 0x4b, 0xb7, 0x9a, 0x69, 0xd7, 0x9c, 0xf5, 0x58, 0x98,
		0x71, 0x83, 0x20, 0x4a, 0x4b, 0x9b, 0x06, 0x4f, 0x13, 0xdd, 0x34, 0x70, 0x29, 0xbd, 0x9b, 0x0d,
		0x6e, 0x7f, 0x99, 0x21, 0x90, 0x15, 0x53, 0x9b, 0x11, 0x2c, 0x05, 0xb6, 0x85, 0xcb, 0x4e, 0x2b,
		0xd6, 0x4d, 0x5f, 0xd7, 0x60, 0x05, 0xbb, 0x61, 0x7a, 0x99, 0x87, 0x92, 0xff, 0x6d, 0xe9, 0xa0,
		0xb4, 0xb9, 0xb1, 0xf1, 0x7a, 0x63, 0x89, 0xe0, 0xf4, 0x22, 0x1f, 0x57, 0x39, 0x76, 0xf5, 0xfc,
		0x69, 0x8d, 0xd9, 0x80, 0x6e, 0xe8, 0x9f, 0x26, 0xe6, 0x4c, 0xd4, 0xf8, 0x72, 0x38, 0x28, 0x1c,
		0x14, 0x0e, 0x0a, 0x07, 0x85, 0x83, 0x9a, 0x6b, 0x30, 0x34, 0x38, 0x57, 0xb1, 0xce, 0xa6, 0xfd,
		0x77, 0x91, 0xa4, 0x8e, 0x1d, 0x24, 0x0b, 0xd7, 0xd2, 0xb3, 0xa3, 0xc4, 0x34, 0x24, 0xea, 0x41,
		0x92, 0x56, 0xd2, 0x34, 0x36, 0x03, 0x8b, 0x0f, 0x41, 0x54, 0x0d, 0xd5, 0x70, 0xd6, 0x26, 0x66,
		0x94, 0xee, 0x50, 0xc9, 0xdf, 0xb8, 0x62, 0xe9, 0x4d, 0xb9, 0xbc, 0xb9, 0x55, 0x2e, 0xaf, 0x6d,
		0xbd, 0xde, 0x5a, 0xdb, 0xde, 0xd8, 0x28, 0x6d, 0x96, 0x0c, 0x48, 0xde, 0xc2, 0x41, 0xdc, 0x51,
		0xb1, 0xea, 0xec, 0x5e, 0x16, 0x76, 0x56, 0xa2, 0x41, 0x18, 0x22, 0xd9, 0x16, 0x6e, 0x51, 0xd0,
		0xf1, 0x42, 0x15, 0x9d, 0x8e, 0xd6, 0x4a, 0x0d, 0xc9, 0xb6, 0xeb, 0x4b, 0x22, 0xdd, 0x90, 0x6e,
		0x48, 0x37, 0xa4, 0x1b, 0xd2, 0xed, 0x56, 0xf2, 0xfb, 0x8d, 0x41, 0xd1, 0xb6, 0x41, 0xee, 0xfb,
		0x59, 0xc2, 0x8a, 0xdc, 0xb7, 0xe6, 0xeb, 0x92, 0xfb, 0xce, 0x2d, 0x94, 0xd6, 0x37, 0xc8, 0x7c,
		0x3b, 0x77, 0x15, 0x32, 0xdf, 0x77, 0xd8, 0xa8, 0xc4, 0x4b, 0x4d, 0x28, 0x85, 0x6b, 0x13, 0x35,
		0xb9, 0x20, 0x16, 0x0a, 0x0b, 0x85, 0x85, 0xc2, 0x42, 0x61, 0xa1, 0xcc, 0xb5, 0x24, 0xc5, 0x49,
		0xe1, 0xa4, 0x32, 0x91, 0xbf, 0x25, 0x9c, 0x14, 0x4e, 0x2a, 0x23, 0x27, 0x85, 0x8f, 0xc2, 0x47,
		0xb9, 0xef, 0xa3, 0x34, 0x6f, 0xd0, 0x5e, 0x54, 0x0a, 0x3a, 0x37, 0x6a, 0xe3, 0xa2, 0x70, 0x51,
		0xb8, 0x28, 0x5c, 0x94, 0xab, 0x2e, 0xca, 0x04, 0x37, 0xde, 0xe4, 0xc7, 0xd2, 0x1b, 0x03, 0xd7,
		0x3a, 0xf4, 0xd3, 0x54, 0xc5, 0x91, 0x31, 0x0b, 0x55, 0xf8, 0xf3, 0xf3, 0x9a, 0xb7, 0x5d, 0xf1,
		0xde, 0xf9, 0x5e, 0xf7, 0xf8, 0x7b, 0xf9, 0xea, 0xcb, 0x97, 0x57, 0x0f, 0x7b, 0xe2, 0x78, 0xf4,
		0xcd, 0xbb, 0x7e, 0xf8, 0x0f, 0xfd, 0x53, 0xe4, 0xd8, 0xc4, 0x07, 0x70, 0x70, 0x54, 0xfb, 0x9d,
		0x4f, 0x01, 0x61, 0xf8, 0xa8, 0xcf, 0xef, 0xdc, 0xff, 0x16, 0x9c, 0x0f, 0xce, 0x3d, 0x3f, 0x56,
		0xbe, 0xe7, 0x77, 0x3a, 0xb1, 0x4a, 0x12, 0x65, 0xb0, 0xd6, 0xfc, 0x9e, 0xeb, 0x23, 0x1c, 0x11,
		0x8e, 0x08, 0x47, 0x84, 0x23, 0xc2, 0x91, 0x0a, 0xa6, 0x0c, 0xbf, 0xc8, 0xbb, 0x6b, 0xb9, 0x2c,
		0x15, 0x4c, 0x7a, 0xa1, 0x44, 0x05, 0x53, 0xce, 0xc1, 0x44, 0xe6, 0x3d, 0xb7, 0x06, 0xab, 0xdf,
		0x19, 0x18, 0xdf, 0x09, 0x72, 0xe3, 0x9a, 0x18, 0x29, 0x8c, 0x14, 0x46, 0x0a, 0x23, 0x85, 0x91,
		0xa2, 0x0f, 0x12, 0x4e, 0x0a, 0x27, 0x85, 0x93, 0xa2, 0x0f, 0x12, 0x5e, 0x0a, 0x2f, 0xe5, 0xac,
		0x97, 0x32, 0xbb, 0x1d, 0x64, 0x76, 0x45, 0x7c, 0x14, 0x3e, 0x0a, 0x1f, 0x85, 0x8f, 0xc2, 0x47,
		0xd1, 0x0d, 0x69, 0xd9, 0xc3, 0x70, 0xac, 0xce, 0xfd, 0x20, 0x0a, 0xa2, 0x53, 0x2f, 0x0c, 0xba,
		0x2a, 0x0d, 0xce, 0x0d, 0x06, 0xe4, 0x3b, 0xae, 0x4d, 0x68, 0x26, 0x34, 0x13, 0x9a, 0x09, 0xcd,
		0x84, 0x66, 0x52, 0x9c, 0x59, 0x7e, 0x91, 0xe2, 0xd4, 0x9a, 0x97, 0x22, 0xc5, 0xa9, 0x07, 0x4a,
		0xa4, 0x38, 0x73, 0x0f, 0x27, 0x52, 0x9c, 0xb9, 0xf5, 0x56, 0x89, 0xfa, 0xff, 0x0f, 0x54, 0xd4,
		0x56, 0xd3, 0x2e, 0x0b, 0xc6, 0x8c, 0xd5, 0xed, 0x0b, 0xe3, 0xaa, 0x70, 0x55, 0xb8, 0x2a, 0x5c,
		0x15, 0xae, 0xea, 0x96, 0xab, 0x7a, 0xbd, 0x6e, 0xd0, 0x55, 0x6d, 0xe1, 0xaa, 0x70, 0x55, 0xb8,
		0x2a, 0x5c, 0x95, 0x05, 0x28, 0x95, 0xd7, 0xb7, 0xcb, 0xdb, 0x9b, 0x5b, 0xeb, 0xdb, 0x58, 0x2b,
		0xac, 0x55, 0x0e, 0xac, 0xd5, 0x85, 0x8a, 0x93, 0xa0, 0x17, 0x99, 0xb3, 0x54, 0xd3, 0x0b, 0x6a,
		0x96, 0x41, 0x7b, 0xaa, 0xeb, 0x0f, 0xc2, 0x91, 0x70, 0x2c, 0x61, 0xdb, 0xb0, 0x6d, 0xd8, 0x36,
		0x6c, 0x1b, 0xb6, 0x8d, 0x8d, 0xd3, 0xb8, 0x36, 0x5c, 0x1b, 0xae, 0x8d, 0x8d, 0xd3, 0xd8, 0x35,
		0xec, 0x9a, 0xbb, 0x76, 0x6d, 0xdd, 0xb8, 0x5f, 0x5b, 0xc7, 0xb0, 0x61, 0xd8, 0x30, 0x6c, 0x18,
		0x36, 0x0c, 0x1b, 0x86, 0x0d, 0xc3, 0x86, 0x61, 0xc3, 0xb0, 0x61, 0xd8, 0x30, 0x6c, 0x18, 0xb6,
		0x3c, 0x18, 0xb6, 0x17, 0x0e, 0x51, 0x44, 0xa1, 0x12, 0x45, 0xbd, 0x74, 0xbc, 0xbd, 0x50, 0x27,
		0x2b, 0x14, 0x92, 0xf6, 0x99, 0x3a, 0xf7, 0xfb, 0xfe, 0xa8, 0x47, 0x57, 0xa1, 0xd8, 0xeb, 0xab,
		0xa8, 0x3d, 0x32, 0x34, 0x5e, 0xa4, 0xd2, 0xbf, 0x7a, 0xf1, 0x57, 0x2f, 0x88, 0x92, 0xd4, 0x8f,
		0xda, 0xaa, 0x78, 0xfb, 0x89, 0x64, 0xe1, 0x99, 0x62, 0x3f, 0xee, 0xa5, 0xbd, 0x76, 0x2f, 0x4c,
		0x66, 0x8f, 0x8a, 0x43, 0x95, 0x59, 0x1c, 0x9d, 0x9e, 0x35, 0xf9, 0x51, 0x0c, 0x83, 0xe8, 0xab,
		0x97, 0xa4, 0x7e, 0xaa, 0xbc, 0x8e, 0x9f, 0xfa, 0x27, 0x7e, 0xa2, 0x8a, 0x61, 0xd2, 0x2f, 0x8e,
		0x9e, 0x2a, 0xe8, 0x2c, 0x30, 0x4d, 0xe3, 0x41, 0x3b, 0x8d, 0x26, 0x42, 0xeb, 0x60, 0xf6, 0x56,
		0xf7, 0xc7, 0x6f, 0xa3, 0x36, 0x79, 0x17, 0xad, 0x5b, 0xbf, 0x27, 0xb7, 0x9f, 0x68, 0x1d, 0x4e,
		0xdf, 0xe6, 0xec, 0x51, 0xab, 0x96, 0x04, 0x49, 0xab, 0x3e, 0x7a, 0x9b, 0xe3, 0x1f, 0xad, 0x7a,
		0x10, 0x7d, 0x3d, 0x1a, 0xbe, 0xa5, 0xbd, 0xc9, 0x9b, 0x6c, 0xd5, 0x93, 0x7e, 0x6b, 0xf4, 0x8c,
		0x1e, 0xd5, 0x9d, 0x3d, 0xc0, 0x35, 0x80, 0xbb, 0x90, 0x86, 0x17, 0xfa, 0x7a, 0x6c, 0xcf, 0x54,
		0xf4, 0xe8, 0x2a, 0x9a, 0xa6, 0xe6, 0x74, 0x2f, 0xae, 0xa6, 0x97, 0xd7, 0x9d, 0x4f, 0x30, 0x91,
		0x47, 0x30, 0x98, 0x3f, 0x30, 0x95, 0x37, 0x30, 0x9e, 0x2f, 0x30, 0x9e, 0x27, 0x30, 0x9b, 0x1f,
		0x70, 0x2b, 0x1c, 0xef, 0x05, 0x7a, 0xf7, 0x23, 0x0c, 0x09, 0xcb, 0x5c, 0xb6, 0x77, 0x78, 0x31,
		0x33, 0xc9, 0xd7, 0x12, 0xc9, 0x57, 0xc9, 0xe4, 0x69, 0x9a, 0x44, 0xad, 0x91, 0xa9, 0x35, 0x52,
		0xb5, 0x43, 0xae, 0x66, 0xdc, 0xa0, 0xee, 0xe4, 0xab, 0x6e, 0xd2, 0x9d, 0x5d, 0xe8, 0xe6, 0x09,
		0x2c, 0xe6, 0xe6, 0xc0, 0x74, 0x9a, 0xcf, 0x5d, 0xdd, 0x10, 0x1a, 0xcd, 0xd0, 0xb3, 0x71, 0x9a,
		0xb6, 0x41, 0xd7, 0x16, 0x69, 0xdb, 0x16, 0x7d, 0x5b, 0xa7, 0x71, 0xeb, 0x74, 0x6e, 0x97, 0xd6,
		0xcd, 0xd0, 0xbb, 0x21, 0x9a, 0x37, 0x4e, 0xf7, 0x37, 0xf2, 0x41, 0x7e, 0x6a, 0x61, 0xd2, 0xcc,
		0xb6, 0x1d, 0x6b, 0xce, 0x77, 0x09, 0x20, 0x7e, 0x6b, 0x01, 0xc0, 0x66, 0x20, 0x10, 0x10, 0x10,
		0x6c, 0x07, 0x06, 0x31, 0x01, 0x42, 0x4c, 0xa0, 0x90, 0x11, 0x30, 0xcc, 0x06, 0x0e, 0xc3, 0x01,
		0xc4, 0x5a, 0x20, 0xb9, 0xf6, 0x11, 0x86, 0x2d, 0xc4, 0xfd, 0x96, 0xc2, 0xa8, 0x9b, 0xb8, 0x2f,
		0xc8, 0xac, 0x59, 0xba, 0xbc, 0xad, 0x60, 0x23, 0x21, 0xe8, 0x08, 0x0a, 0x3e, 0x52, 0x82, 0x90,
		0xb8, 0x60, 0x24, 0x2e, 0x28, 0xc9, 0x0a, 0x4e, 0x76, 0x82, 0x94, 0xa5, 0x60, 0x35, 0xbb, 0xf5,
		0xc6, 0x2a, 0x0d, 0x7f, 0x1e, 0x3c, 0xcc, 0xe7, 0xa3, 0x7e, 0x68, 0x55, 0xde, 0x58, 0x1c, 0x83,
		0xe9, 0x43, 0xc5, 0xef, 0x1d, 0xc8, 0xdc, 0x61, 0xe3, 0xeb, 0x57, 0x5f, 0xbe, 0xbc, 0x7a, 0xb9,
		0x70, 0xb8, 0xf8, 0xea, 0xf7, 0xb5, 0x5f, 0x5e, 0x5f, 0xfd, 0xc3, 0xde, 0x8c, 0x3d, 0xb6, 0xf9,
		0x49, 0xd9, 0x38, 0x03, 0xde, 0xf1, 0x8f, 0x6b, 0xa9, 0x08, 0xb6, 0x1e, 0x24, 0x69, 0x25, 0x4d,
		0x63, 0xbb, 0x24, 0xfb, 0x21, 0x88, 0xaa, 0xa1, 0x1a, 0xc6, 0xd8, 0xc4, 0x9e, 0x40, 0x5d, 0x99,
		0x14, 0x9c, 0xde, 0x18, 0x49, 0xe9, 0x4d, 0xb9, 0xbc, 0xb9, 0x55, 0x2e, 0xaf, 0x6d, 0xbd, 0xde,
		0x5a, 0xdb, 0xde, 0xd8, 0x28, 0x6d, 0x96, 0x36, 0x2c, 0x0e, 0xee, 0x20, 0xee, 0xa8, 0x58, 0x75,
		0x76, 0x2f, 0x0b, 0x3b, 0x2b, 0xd1, 0x20, 0x0c, 0x5f, 0x2c, 0x87, 0x00, 0xc9, 0xb7, 0x2f, 0x37,
		0x54, 0xd3, 0x78, 0xef, 0xf5, 0x05, 0xd5, 0x3a, 0xa6, 0xe1, 0x45, 0x32, 0xfc, 0x56, 0xbc, 0x29,
		0xb6, 0x8a, 0x36, 0x32, 0xc2, 0x2b, 0x52, 0x2a, 0x23, 0x9b, 0xe1, 0x45, 0x32, 0xfc, 0xd6, 0xaa,
		0xc4, 0xca, 0xaf, 0x8c, 0xef, 0x88, 0xce, 0x72, 0x49, 0xfb, 0x73, 0x30, 0x5f, 0xcb, 0x37, 0x96,
		0x66, 0xb7, 0xf8, 0x59, 0x6d, 0x72, 0x1d, 0x58, 0xea, 0x3c, 0x2e, 0xe4, 0x64, 0xef, 0x83, 0x81,
		0xb9, 0x54, 0xf0, 0x07, 0xe9, 0x99, 0x8a, 0xd2, 0xa0, 0x6d, 0x76, 0x2e, 0x5d, 0xdb, 0xff, 0xf9,
		0xeb, 0x53, 0x90, 0x92, 0x8d, 0x3d, 0xa5, 0x20, 0xc5, 0x08, 0x8c, 0x28, 0x48, 0xa1, 0x20, 0x25,
		0xab, 0x5b, 0x49, 0x41, 0x4a, 0xee, 0x88, 0xdf, 0x5a, 0x00, 0xb0, 0x19, 0x08, 0x04, 0x04, 0x04,
		0xdb, 0x81, 0x41, 0x4c, 0x80, 0x10, 0x13, 0x28, 0x64, 0x04, 0x8c, 0xe5, 0x48, 0x7c, 0xd9, 0x2b,
		0x48, 0x99, 0xd3, 0xf2, 0xde, 0x57, 0x75, 0x29, 0xa0, 0x36, 0x65, 0x71, 0x4c, 0x94, 0xa9, 0x58,
		0x19, 0x00, 0x65, 0x2a, 0x92, 0x42, 0x93, 0xb8, 0x10, 0x25, 0x2e, 0x54, 0xc9, 0x0a, 0x59, 0x76,
		0x42, 0x97, 0xa5, 0x10, 0x36, 0xbb, 0xf5, 0x72, 0xca, 0x54, 0x92, 0x34, 0x0e, 0xa2, 0x53, 0x11,
		0x05, 0x2a, 0xcb, 0xb2, 0x3a, 0x69, 0xc1, 0x2f, 0xb4, 0xe3, 0xcb, 0x7e, 0xda, 0xf3, 0x52, 0x9b,
		0xb0, 0x9b, 0x41, 0xee, 0xe6, 0x60, 0xd0, 0x2c, 0x68, 0x16, 0x34, 0x0b, 0x9a, 0x05, 0xcd, 0x82,
		0x66, 0x79, 0x30, 0x63, 0xa8, 0x68, 0x70, 0xae, 0x62, 0x93, 0x0b, 0x6b, 0x3f, 0x14, 0x2e, 0x65,
		0x8b, 0x63, 0xa8, 0x46, 0x83, 0xf3, 0xe1, 0x87, 0x72, 0x45, 0x69, 0x97, 0xfb, 0x53, 0x8d, 0xd2,
		0xae, 0xbb, 0x8a, 0x40, 0xe6, 0x12, 0x5d, 0x14, 0x77, 0x8d, 0x8b, 0x42, 0xe6, 0x6e, 0x0a, 0xf5,
		0x5d, 0xce, 0x4c, 0x75, 0xea, 0xbb, 0xee, 0x9d, 0xda, 0xcb, 0x5b, 0xe1, 0x35, 0x7f, 0x1b, 0x28,
		0xf2, 0x7a, 0xf0, 0xc7, 0xa8, 0xbe, 0xa5, 0x2a, 0xea, 0xa8, 0x8e, 0x17, 0xf4, 0x2f, 0xca, 0x5e,
		0xac, 0xfc, 0xf6, 0x99, 0x7f, 0x12, 0x84, 0x41, 0x7a, 0x69, 0xbe, 0xe0, 0xeb, 0x07, 0x63, 0xa1,
		0xf8, 0xcb, 0xd5, 0xa4, 0x05, 0xc5, 0x5f, 0x14, 0x7f, 0x51, 0xfc, 0xf5, 0x8c, 0x5b, 0x69, 0xbc,
		0xf8, 0x6b, 0x0c, 0x59, 0x95, 0xd8, 0xab, 0xff, 0x9a, 0x8d, 0x80, 0x12, 0xb0, 0xbc, 0x85, 0x03,
		0x01, 0x61, 0xc1, 0x76, 0x78, 0x10, 0x13, 0x26, 0xc4, 0x84, 0x0b, 0x19, 0x61, 0x63, 0x39, 0x12,
		0x64, 0xd6, 0x4a, 0xc0, 0xfa, 0x76, 0x17, 0xcc, 0x6e, 0x05, 0x17, 0xcb, 0xcb, 0xa6, 0x25, 0x96,
		0x4d, 0x59, 0x36, 0x65, 0xd9, 0x54, 0x7e, 0x48, 0x92, 0x15, 0x9a, 0xec, 0x84, 0x28, 0x4b, 0xa1,
		0xca, 0x7a, 0xc8, 0x92, 0x12, 0xba, 0x64, 0x85, 0xb0, 0xdb, 0xa1, 0x6c, 0xcd, 0xf2, 0x30, 0x6c,
		0x87, 0x34, 0x49, 0xa1, 0x4d, 0x60, 0x88, 0x93, 0x16, 0xea, 0xc4, 0x86, 0x3c, 0xb1, 0xa1, 0x4f,
		0x66, 0x08, 0xb4, 0x1b, 0x0a, 0x2d, 0x87, 0xc4, 0xd9, 0x47, 0x62, 0xbd, 0xa2, 0x68, 0x81, 0x71,
		0x42, 0xe5, 0x77, 0x63, 0xd5, 0x95, 0xc0, 0x38, 0x53, 0xaf, 0xb5, 0x25, 0x60, 0x2c, 0x87, 0x93,
		0x65, 0xe3, 0x57, 0xaf, 0xc6, 0xf5, 0x17, 0xc5, 0x09, 0xe7, 0xbc, 0x58, 0xce, 0xb9, 0x63, 0x71,
		0xde, 0x58, 0xda, 0xdc, 0x7c, 0xef, 0x84, 0xb1, 0x55, 0x8e, 0x23, 0x28, 0x2d, 0x81, 0x96, 0x43,
		0xcb, 0xa1, 0xe5, 0xd0, 0x72, 0xcb, 0xad, 0xe5, 0x6c, 0xa7, 0x39, 0x66, 0x03, 0x39, 0x57, 0x69,
		0x1c, 0xb4, 0xe5, 0xcc, 0xee, 0x29, 0x01, 0x4e, 0xc6, 0x25, 0x64, 0x06, 0xc9, 0x48, 0x7f, 0x88,
		0x0b, 0x9d, 0x12, 0x43, 0xa8, 0xe0, 0x50, 0x2a, 0x35, 0xa4, 0x8a, 0x0f, 0xad, 0xe2, 0x43, 0xac,
		0xec, 0x50, 0x2b, 0x23, 0xe4, 0x0a, 0x09, 0xbd, 0xf2, 0xd2, 0x29, 0x0b, 0x8c, 0xf5, 0x57, 0xd0,
		0x51, 0x9e, 0xa8, 0x00, 0x78, 0x33, 0x08, 0x6e, 0x09, 0x1a, 0x52, 0xc3, 0x8f, 0x4e, 0x95, 0xf5,
		0xc6, 0xfb, 0xb7, 0xbf, 0x64, 0xb1, 0xfa, 0xca, 0xa4, 0x03, 0xbc, 0xb8, 0x70, 0x23, 0x54, 0x5d,
		0x2d, 0x0c, 0xef, 0x93, 0x1f, 0x0e, 0x94, 0xfd, 0x84, 0xc9, 0xbd, 0xe3, 0x7b, 0x17, 0xfb, 0xed,
		0x34, 0xe8, 0x45, 0x7b, 0xc1, 0x69, 0x30, 0x6e, 0xf0, 0x2f, 0x6e, 0x9c, 0x57, 0xbf, 0x08, 0x9c,
		0x12, 0xfe, 0x37, 0xa6, 0xc4, 0x73, 0xa7, 0xc4, 0xe6, 0xd6, 0xd6, 0xd6, 0xba, 0xcd, 0x43, 0x1b,
		0x9c, 0x9f, 0x19, 0x2f, 0x18, 0xcd, 0x5d, 0x5f, 0xc7, 0x2f, 0xb8, 0x1f, 0x42, 0x98, 0x53, 0x4a,
		0x49, 0xcc, 0x82, 0x4e, 0x96, 0x95, 0xfe, 0x25, 0x47, 0xf4, 0xe3, 0x01, 0x91, 0x23, 0x7a, 0xd4,
		0xd0, 0xc8, 0x11, 0x3d, 0x71, 0x80, 0xe4, 0x88, 0xdc, 0x57, 0x00, 0xe4, 0x88, 0x7e, 0xc6, 0x58,
		0xa3, 0x6d, 0xd3, 0xe2, 0x26, 0xa0, 0x84, 0xe3, 0x33, 0x17, 0x03, 0x8f, 0x90, 0xf3, 0x19, 0x17,
		0x06, 0xf6, 0x72, 0x74, 0x3c, 0xe3, 0xf1, 0xdf, 0x9f, 0x4b, 0xde, 0xf6, 0xf1, 0xf8, 0x61, 0x69,
		0xf4, 0x63, 0xfc, 0x78, 0xfd, 0xf3, 0x9a, 0x57, 0x9e, 0x3e, 0xde, 0xf8, 0xbc, 0xe6, 0x6d, 0x1c,
		0xaf, 0x8e, 0x4e, 0x70, 0x7c, 0x7d, 0xf5, 0xf8, 0x3f, 0x2c, 0x4e, 0x2e, 0xb6, 0xfa, 0xf7, 0xcb,
		0xcf, 0x25, 0x6f, 0xfd, 0x78, 0xfa, 0xcb, 0xeb, 0xcf, 0x6b, 0xde, 0xfa, 0xf1, 0xea, 0xaa, 0x1c,
		0x06, 0x3a, 0x96, 0x04, 0x1d, 0x49, 0xe7, 0x7b, 0x2e, 0x8c, 0xee, 0x4f, 0x49, 0x00, 0xfa, 0x47,
		0x01, 0xef, 0x88, 0x77, 0x5c, 0xc0, 0x68, 0xe2, 0x9d, 0x04, 0xa9, 0x3c, 0xeb, 0x38, 0x1e, 0x16,
		0xce, 0x11, 0xe7, 0x88, 0x73, 0xc4, 0x39, 0xe2, 0x1c, 0x71, 0x8e, 0x4b, 0xe3, 0x1c, 0x4f, 0x7a,
		0xbd, 0x50, 0xf9, 0x91, 0x44, 0xd7, 0x58, 0x42, 0xb8, 0x89, 0x11, 0x6e, 0x83, 0xbe, 0xd7, 0xe9,
		0xfd, 0x15, 0xc9, 0x93, 0x6e, 0xd3, 0x81, 0x21, 0xde, 0x10, 0x6f, 0x88, 0x37, 0xc4, 0x1b, 0xe2,
		0x0d, 0xf1, 0x86, 0x78, 0x43, 0xbc, 0x89, 0x11, 0x6f, 0x4b, 0xbd, 0xb1, 0xc9, 0x72, 0x4f, 0xfe,
		0x85, 0xf1, 0x48, 0x6c, 0xe4, 0x7d, 0x7f, 0xef, 0xe3, 0xe2, 0xb4, 0x1b, 0xe6, 0xe4, 0x41, 0x51,
		0xc2, 0x86, 0xe1, 0x15, 0x71, 0x2d, 0xc0, 0xab, 0x93, 0x1b, 0x58, 0xeb, 0x5f, 0x94, 0x1b, 0x37,
		0x6e, 0x5f, 0xeb, 0x70, 0x72, 0xfb, 0x26, 0x0f, 0x6c, 0x74, 0xfa, 0x97, 0x43, 0x07, 0x56, 0xf7,
		0xdd, 0x0f, 0x4e, 0x86, 0x70, 0x17, 0xb4, 0xf3, 0x7e, 0x32, 0x20, 0xf6, 0xde, 0xb3, 0xf7, 0xde,
		0x19, 0x57, 0xc8, 0xde, 0x7b, 0xd7, 0xdd, 0x1f, 0x7b, 0xef, 0xe5, 0x49, 0x54, 0x31, 0x7b, 0xef,
		0xc7, 0x31, 0x49, 0xe0, 0xe2, 0xf8, 0x78, 0x5c, 0xb2, 0x12, 0xac, 0x25, 0x12, 0xac, 0xe2, 0x43,
		0xa8, 0xe0, 0x50, 0x2a, 0x35, 0xa4, 0x8a, 0x0f, 0xad, 0xe2, 0x43, 0xac, 0xec, 0x50, 0x2b, 0x27,
		0x2f, 0xb5, 0x22, 0x28, 0xc1, 0x2a, 0x25, 0x04, 0xcf, 0x06, 0xd4, 0x0d, 0xfd, 0xd3, 0x44, 0x1e,
		0x29, 0x4c, 0x79, 0x74, 0x3c, 0x3c, 0x61, 0xf3, 0x4d, 0x56, 0x60, 0x16, 0x1b, 0xa0, 0x25, 0x07,
		0x6a, 0x07, 0x02, 0xb6, 0xf4, 0xc0, 0xed, 0x4c, 0x00, 0x77, 0x26, 0x90, 0xbb, 0x11, 0xd0, 0x65,
		0x05, 0x76, 0x61, 0x01, 0x5e, 0x6c, 0xa0, 0xbf, 0xf6, 0xde, 0x22, 0x1a, 0xc3, 0xfe, 0xdc, 0x8a,
		0x0b, 0x59, 0xff, 0x71, 0x48, 0x00, 0x88, 0x17, 0x02, 0x2e, 0x08, 0x02, 0x87, 0x84, 0x81, 0x2b,
		0x02, 0xc1, 0x39, 0xa1, 0xe0, 0x9c, 0x60, 0x70, 0x4b, 0x38, 0xc8, 0x14, 0x10, 0x42, 0x85, 0x84,
		0x78, 0x41, 0x21, 0x3c, 0x93, 0xe0, 0x54, 0x66, 0xe1, 0x3e, 0xa1, 0xb1, 0x26, 0x7c, 0x98, 0xd2,
		0x05, 0x87, 0x4b, 0xc2, 0xc3, 0x41, 0x01, 0xe2, 0x9a, 0x10, 0x71, 0x56, 0x90, 0x38, 0x2b, 0x4c,
		0xdc, 0x14, 0x28, 0xb2, 0x85, 0x8a, 0x70, 0xc1, 0x32, 0xfb, 0xc8, 0xc5, 0xd5, 0x94, 0xff, 0x94,
		0x71, 0x55, 0x34, 0x38, 0x57, 0xf1, 0xb8, 0x96, 0xd7, 0x01, 0xd6, 0x9d, 0x66, 0x23, 0xca, 0x0e,
		0x8c, 0xb5, 0x1a, 0x0d, 0xce, 0x87, 0x60, 0x60, 0x4a, 0x3d, 0xe7, 0x2e, 0xd6, 0x83, 0x24, 0xad,
		0xa4, 0x69, 0xec, 0xc6, 0xb4, 0xfa, 0x10, 0x44, 0xd5, 0x50, 0x0d, 0x59, 0x3f, 0x91, 0x2f, 0x11,
		0x57, 0x26, 0x1d, 0x72, 0x6f, 0x8c, 0xb8, 0xf4, 0xa6, 0x5c, 0xde, 0xdc, 0x2a, 0x97, 0xd7, 0xb6,
		0x5e, 0x6f, 0xad, 0x6d, 0x6f, 0x6c, 0x94, 0x36, 0xa5, 0xf6, 0x7d, 0x9d, 0x7b, 0x13, 0x07, 0x71,
		0x47, 0xc5, 0xaa, 0xb3, 0x7b, 0x59, 0xd8, 0x59, 0x89, 0x06, 0x61, 0xf8, 0x82, 0x10, 0x9b, 0x33,
		0x2e, 0x28, 0xa4, 0x2e, 0x84, 0xd6, 0x59, 0x58, 0x1d, 0x8d, 0x16, 0xc3, 0x8d, 0xe1, 0xc6, 0x70,
		0x63, 0xb8, 0x31, 0xdc, 0x18, 0x6e, 0x0c, 0x37, 0x86, 0x7b, 0xdc, 0xd3, 0xb5, 0xa3, 0xa2, 0x34,
		0x48, 0x2f, 0x65, 0x1c, 0xa9, 0xfc, 0x60, 0xc3, 0xed, 0x82, 0x0b, 0xa8, 0x4d, 0x6e, 0xed, 0xae,
		0x9f, 0x38, 0x14, 0x27, 0xa6, 0xc0, 0xa8, 0x1d, 0xd5, 0x8e, 0x5a, 0x47, 0x1f, 0x77, 0x9b, 0xf5,
		0x4f, 0xad, 0xe6, 0x1f, 0x87, 0x55, 0x57, 0xc2, 0xc5, 0xe8, 0x98, 0x90, 0x44, 0x5c, 0xe3, 0xd4,
		0x1f, 0x7d, 0x7d, 0x77, 0x66, 0xa4, 0xb7, 0x10, 0xd2, 0x6a, 0x54, 0x2b, 0x6f, 0x7f, 0xad, 0xec,
		0xd6, 0xea, 0xb5, 0xe6, 0x1f, 0x13, 0xb0, 0x1c, 0xb9, 0x84, 0x16, 0x97, 0x51, 0xe3, 0x26, 0x7a,
		0x7e, 0x8a, 0xa2, 0xdd, 0xca, 0xfe, 0xde, 0xff, 0xd6, 0xf6, 0x9a, 0xbf, 0xb6, 0xde, 0x1e, 0xec,
		0x1f, 0x35, 0x1b, 0x95, 0xda, 0x7e, 0xf3, 0xa8, 0xe0, 0xdc, 0x7b, 0xbc, 0xfa, 0x05, 0x20, 0xd9,
		0x05, 0xd2, 0xc7, 0x66, 0xad, 0x5e, 0xfb, 0xbf, 0xea, 0xde, 0x35, 0xa2, 0x40, 0x11, 0x28, 0x7a,
		0x2c, 0x8a, 0x2a, 0x7b, 0xff, 0x69, 0x1d, 0xd5, 0xf6, 0x80, 0x0e, 0xd0, 0x79, 0x34, 0x74, 0x3e,
		0x55, 0x6a, 0xf5, 0xca, 0x6e, 0xbd, 0x0a, 0x03, 0x01, 0xa3, 0xa7, 0xc3, 0xa8, 0x76, 0xf8, 0x69,
		0xb3, 0xb5, 0x5f, 0xad, 0xbd, 0xff, 0x75, 0xf7, 0xa0, 0xd1, 0xaa, 0xec, 0xed, 0x35, 0xaa, 0x47,
		0x08, 0x22, 0x80, 0xf4, 0x78, 0x41, 0xb4, 0x3f, 0x53, 0xd4, 0xd5, 0xbd, 0x56, 0xfd, 0xe8, 0x10,
		0x10, 0x01, 0xa2, 0xc7, 0x82, 0xa8, 0x5e, 0xdb, 0xff, 0xad, 0x55, 0x69, 0x36, 0x1b, 0xb5, 0xdd,
		0x8f, 0xcd, 0x2a, 0x3c, 0x04, 0x84, 0x9e, 0x06, 0xa1, 0xc3, 0xc6, 0x41, 0xb3, 0xfa, 0xb6, 0x59,
		0x3b, 0xd8, 0x1f, 0xe7, 0x8b, 0xc0, 0x11, 0x38, 0x7a, 0xb4, 0x35, 0xfb, 0x50, 0xdb, 0x6f, 0xbd,
		0x6f, 0x1c, 0x7c, 0x24, 0x92, 0x01, 0x9f, 0xa7, 0xe9, 0xea, 0xda, 0x7e, 0xb3, 0xda, 0x78, 0x57,
		0x79, 0x5b, 0x45, 0x58, 0x83, 0xa4, 0xa7, 0x22, 0xe9, 0x43, 0xe5, 0xf7, 0x71, 0x50, 0xc3, 0xe7,
		0x83, 0xa2, 0x67, 0x84, 0xb3, 0xff, 0xb4, 0xea, 0x95, 0x7d, 0xb2, 0x8d, 0xc0, 0xe7, 0xc9, 0xaa,
		0x1a, 0xe8, 0x00, 0x9d, 0x27, 0x29, 0xa1, 0x32, 0x19, 0x46, 0x80, 0x94, 0x0d, 0x90, 0x90, 0xd4,
		0x20, 0x29, 0x13, 0x49, 0xdd, 0xa8, 0x1e, 0x55, 0x1b, 0x9f, 0x58, 0x40, 0x03, 0x4b, 0xcf, 0xc3,
		0x52, 0xb3, 0xda, 0xda, 0xab, 0xbe, 0xab, 0x7c, 0xac, 0x37, 0x5b, 0x1f, 0xaa, 0xcd, 0x46, 0xed,
		0x2d, 0x20, 0x02, 0x44, 0x8f, 0x05, 0xd1, 0xc7, 0xfd, 0x31, 0x1d, 0x51, 0x4f, 0x04, 0x8e, 0x9e,
		0x6d, 0xd3, 0xf6, 0xaa, 0xf5, 0xca, 0x1f, 0xad, 0x4f, 0x95, 0x46, 0xad, 0xd2, 0xac, 0x1d, 0xec,
		0x83, 0x23, 0x70, 0xf4, 0x58, 0x1c, 0x55, 0x7f, 0x6f, 0x56, 0xf7, 0xf7, 0xaa, 0x7b, 0xac, 0x82,
		0x80, 0xa3, 0x67, 0x09, 0xed, 0xda, 0xfe, 0x75, 0xfe, 0x7a, 0xc4, 0x4b, 0xa0, 0x08, 0x14, 0x3d,
		0x29, 0xaa, 0xd5, 0x0f, 0xf0, 0xfa, 0x80, 0xe7, 0x39, 0x92, 0x08, 0xf4, 0x80, 0x9e, 0xc7, 0xa2,
		0xa7, 0x51, 0x3d, 0xaa, 0xed, 0x7d, 0xac, 0xd4, 0x9d, 0xb6, 0x65, 0x4e, 0x8d, 0xf8, 0xf8, 0x05,
		0xb3, 0x73, 0xc9, 0x67, 0x65, 0x5e, 0x77, 0xef, 0x01, 0x18, 0xd3, 0x80, 0x71, 0x79, 0x97, 0x1e,
		0x68, 0x31, 0x8d, 0x16, 0xe7, 0x76, 0xe3, 0x01, 0x11, 0xe3, 0x10, 0x71, 0x79, 0xd7, 0x1d, 0x70,
		0x31, 0x0d, 0x17, 0xc7, 0x77, 0xd7, 0x01, 0x18, 0xe3, 0x82, 0xc5, 0xdd, 0x5d, 0x74, 0x80, 0xc5,
		0x34, 0x58, 0x9c, 0xdd, 0x2d, 0x07, 0x54, 0xac, 0x40, 0xc5, 0xd9, 0x5d, 0x71, 0xe0, 0xc5, 0xbc,
		0x15, 0x72, 0x70, 0xdd, 0x17, 0x98, 0x58, 0xd1, 0xb7, 0x0e, 0x97, 0xe4, 0x82, 0x18, 0xd3, 0x88,
		0x71, 0x79, 0x37, 0x1b, 0x68, 0x31, 0x1f, 0x86, 0x1c, 0xdc, 0xb5, 0x06, 0x4c, 0xac, 0xa8, 0x5b,
		0x20, 0x02, 0x44, 0x72, 0xbb, 0x0b, 0x0d, 0xc0, 0x58, 0x01, 0x0c, 0xd2, 0x16, 0xc4, 0x3c, 0x4a,
		0xda, 0xba, 0xbd, 0xab, 0x0c, 0xcc, 0x98, 0xc6, 0x8c, 0xc3, 0xbb, 0xc7, 0x00, 0x8b, 0x69, 0xb0,
		0xb8, 0xbd, 0x4b, 0x0c, 0xbc, 0x58, 0xb1, 0x45, 0xce, 0xee, 0x06, 0x03, 0x2f, 0xa6, 0xf1, 0xe2,
		0xf6, 0xae, 0x2f, 0xf0, 0x62, 0x5c, 0xf0, 0x3a, 0xbc, 0xbb, 0x0b, 0xb4, 0x58, 0x89, 0x46, 0x6e,
		0xed, 0xe2, 0x02, 0x24, 0xf6, 0x24, 0x0b, 0x28, 0x01, 0x25, 0x79, 0xdc, 0x95, 0x05, 0x5a, 0xb4,
		0xa3, 0xe5, 0x90, 0x93, 0xe3, 0x40, 0x4f, 0xd6, 0x28, 0x6a, 0x56, 0xde, 0x6f, 0x96, 0xd9, 0x42,
		0x0c, 0x70, 0x1e, 0x0b, 0x9c, 0xc3, 0x46, 0xf5, 0x5d, 0xed, 0x77, 0x1a, 0xef, 0x82, 0x9e, 0xa7,
		0xa0, 0x67, 0x54, 0x61, 0xd7, 0x38, 0xf8, 0xd8, 0xac, 0x36, 0xe8, 0xbf, 0x0b, 0x82, 0x9e, 0x16,
		0xb8, 0x80, 0x0d, 0xb0, 0x79, 0x62, 0xd8, 0x7a, 0x57, 0xaf, 0xbc, 0xa7, 0xef, 0x0e, 0xf8, 0x79,
		0x4a, 0xe0, 0x2a, 0x3b, 0x1d, 0xb8, 0xe8, 0x9a, 0x42, 0xfe, 0x03, 0xe7, 0x0a, 0x40, 0xf2, 0x0f,
		0x10, 0x17, 0x1d, 0x2a, 0x28, 0xc1, 0x89, 0x82, 0x14, 0x1c, 0x27, 0xf0, 0xc0, 0x59, 0x82, 0x93,
		0xbc, 0x06, 0x9c, 0x32, 0x01, 0x07, 0xa4, 0x2c, 0x22, 0x65, 0x02, 0x8a, 0xb7, 0x95, 0x43, 0xd6,
		0x78, 0xc1, 0x4f, 0xa6, 0x38, 0x6a, 0xb4, 0x2a, 0xf5, 0xf7, 0x07, 0x8d, 0x5a, 0xf3, 0xd7, 0x0f,
		0x64, 0x3d, 0x41, 0xd0, 0x93, 0x10, 0x74, 0xfd, 0x1b, 0x69, 0x4f, 0xbd, 0x5f, 0xa4, 0x3d, 0x11,
		0x05, 0x79, 0x23, 0x73, 0x90, 0x02, 0x69, 0xe7, 0x8a, 0xac, 0xe5, 0x93, 0xb4, 0xec, 0xfb, 0x28,
		0x77, 0x74, 0x32, 0x47, 0x26, 0x94, 0x40, 0x0b, 0x95, 0x28, 0xea, 0xa5, 0x7e, 0x1a, 0xf4, 0xa2,
		0xc2, 0x8e, 0x60, 0xea, 0x2c, 0x24, 0xed, 0x33, 0x75, 0xee, 0xf7, 0xfd, 0xf4, 0x6c, 0x48, 0x96,
		0xc5, 0x5e, 0x5f, 0x45, 0xed, 0x5e, 0xd4, 0x0d, 0x4e, 0xbd, 0x48, 0xa5, 0x7f, 0xf5, 0xe2, 0xaf,
		0x5e, 0x10, 0x25, 0xa9, 0x1f, 0xb5, 0x55, 0xf1, 0xf6, 0x13, 0xc9, 0xc2, 0x33, 0xc5, 0x7e, 0xdc,
		0x4b, 0x7b, 0xed, 0x5e, 0x98, 0xcc, 0x1e, 0x15, 0x83, 0x24, 0x48, 0x8a, 0xa1, 0xba, 0x50, 0xe1,
		0xe4, 0x47, 0x31, 0x0c, 0xa2, 0xaf, 0x5e, 0x92, 0xfa, 0xa9, 0xf2, 0x3a, 0x7e, 0xea, 0x9f, 0xf8,
		0x89, 0x2a, 0x86, 0x49, 0xbf, 0x98, 0x86, 0x17, 0xc9, 0xf0, 0x5b, 0x51, 0x7d, 0x4b, 0x55, 0xd4,
		0x51, 0x1d, 0x2f, 0xe8, 0x5f, 0x94, 0xbd, 0x58, 0xf9, 0xed, 0x33, 0xff, 0x24, 0x08, 0x83, 0xf4,
		0xb2, 0xd8, 0x8f, 0x55, 0x37, 0xf8, 0xa6, 0x92, 0xc9, 0x83, 0x62, 0x32, 0x38, 0x19, 0xfd, 0xd9,
		0xf8, 0x67, 0xb1, 0x1b, 0xfa, 0xa7, 0x49, 0x71, 0xf4, 0xda, 0x82, 0x13, 0x03, 0x85, 0x24, 0x8d,
		0x07, 0xed, 0x34, 0x9a, 0x44, 0xa8, 0x83, 0xd9, 0x3d, 0xdf, 0x1f, 0xdf, 0xcf, 0xda, 0xe4, 0x76,
		0xb6, 0x6e, 0xfd, 0x9e, 0xdc, 0x7e, 0xa2, 0x75, 0x38, 0xbd, 0xdf, 0xb3, 0x47, 0xad, 0x5a, 0x12,
		0x24, 0xad, 0xfa, 0xe8, 0x7e, 0x8f, 0x7f, 0xb4, 0xea, 0x41, 0xf4, 0xf5, 0x68, 0x78, 0x4b, 0xf6,
		0x26, 0x77, 0xbb, 0x55, 0x4f, 0xfa, 0xad, 0x66, 0x78, 0x91, 0x0c, 0xbf, 0xb5, 0xaa, 0x93, 0xbb,
		0x5d, 0xeb, 0x5f, 0x94, 0x1b, 0x37, 0xee, 0x75, 0xeb, 0x70, 0x72, 0xaf, 0x27, 0x0f, 0x5a, 0x47,
		0xe3, 0x7b, 0x3d, 0xf9, 0xd9, 0x7a, 0x37, 0xbc, 0xd7, 0xad, 0xd1, 0x0b, 0xcb, 0x0c, 0xa2, 0xf2,
		0x08, 0x4b, 0xd6, 0x88, 0x84, 0x51, 0xa7, 0x74, 0xca, 0xcc, 0x23, 0x55, 0x0a, 0x24, 0xc9, 0x1c,
		0x91, 0xa3, 0x2c, 0x5a, 0x94, 0x43, 0x3e, 0x82, 0x88, 0xa7, 0x30, 0x9a, 0x37, 0x49, 0x6f, 0x10,
		0xb7, 0x95, 0x17, 0xf7, 0x06, 0xa9, 0x8a, 0xbd, 0xa0, 0x23, 0x8e, 0x7f, 0x66, 0x6e, 0xf6, 0xee,
		0xe1, 0x0a, 0x23, 0xf2, 0xdf, 0x82, 0x68, 0x78, 0x0b, 0x4b, 0xc2, 0x86, 0xf5, 0x76, 0x44, 0x23,
		0x85, 0x9d, 0x95, 0x35, 0x61, 0x03, 0x1b, 0x53, 0x88, 0xcc, 0xa0, 0x37, 0x05, 0x5e, 0xaf, 0xed,
		0x0d, 0xc3, 0x93, 0xc4, 0x80, 0x71, 0x34, 0x9a, 0x0e, 0x62, 0x6d, 0x56, 0xe1, 0x37, 0x75, 0xf9,
		0x57, 0x2f, 0x1e, 0xce, 0x88, 0xc2, 0x38, 0x14, 0x0b, 0xb5, 0x26, 0x85, 0x5f, 0xfd, 0xa4, 0x12,
		0x9f, 0x0e, 0xce, 0x55, 0x94, 0x16, 0x76, 0x56, 0xd2, 0x78, 0xa0, 0xa4, 0x9a, 0xeb, 0xeb, 0x51,
		0xce, 0x80, 0x89, 0xd8, 0x77, 0x4a, 0xec, 0xef, 0x05, 0xb1, 0x50, 0x95, 0x3f, 0x32, 0xb4, 0x62,
		0xc9, 0x64, 0xca, 0xc7, 0x92, 0x73, 0x1c, 0x42, 0x05, 0x80, 0x78, 0x21, 0xe0, 0x82, 0x20, 0x70,
		0x48, 0x18, 0xb8, 0x22, 0x10, 0x9c, 0x13, 0x0a, 0xce, 0x09, 0x06, 0xb7, 0x84, 0x83, 0x4c, 0x01,
		0x21, 0x54, 0x48, 0x88, 0x17, 0x14, 0xb3, 0x01, 0xca, 0xcd, 0x2e, 0xdc, 0xcb, 0xed, 0x52, 0x33,
		0x0c, 0xf7, 0x09, 0x8e, 0x35, 0xe1, 0xc3, 0x94, 0x2e, 0x3c, 0x5c, 0x12, 0x20, 0x0e, 0x0a, 0x11,
		0xd7, 0x04, 0x89, 0xb3, 0xc2, 0xc4, 0x59, 0x81, 0xe2, 0xa6, 0x50, 0x91, 0x2d, 0x58, 0x84, 0x0b,
		0x97, 0xd9, 0x47, 0xde, 0xbc, 0xec, 0x2b, 0xb7, 0x18, 0x77, 0xb4, 0x18, 0xe1, 0x77, 0x3a, 0xb1,
		0x4a, 0x9c, 0xa0, 0xdd, 0x69, 0x5a, 0xe2, 0x8d, 0x03, 0x63, 0x3d, 0xf4, 0xd3, 0x54, 0xc5, 0x91,
		0x33, 0x1b, 0x45, 0x0a, 0x2f, 0x5f, 0x7e, 0x5e, 0xf3, 0xb6, 0x8f, 0xff, 0xfe, 0x5c, 0xf2, 0xb6,
		0x8f, 0xc7, 0x0f, 0x4b, 0xa3, 0x1f, 0xe3, 0xc7, 0xeb, 0x9f, 0xd7, 0xbc, 0xf2, 0xf4, 0xf1, 0xc6,
		0xe7, 0x35, 0x6f, 0xe3, 0x78, 0xf5, 0xcb, 0x97, 0x57, 0xab, 0xdf, 0x5f, 0x5f, 0x3d, 0xfe, 0x0f,
		0xe5, 0x53, 0xe1, 0xb1, 0x0b, 0x10, 0x3b, 0x38, 0xaa, 0xfd, 0xee, 0x1c, 0xce, 0xfe, 0x34, 0x09,
		0xb4, 0x7f, 0x38, 0x80, 0x34, 0xca, 0x59, 0xf3, 0x26, 0x07, 0x0a, 0xa9, 0x0b, 0x52, 0x60, 0x26,
		0x03, 0x46, 0xa3, 0x25, 0x41, 0x40, 0x82, 0x80, 0x04, 0x01, 0x09, 0x02, 0x12, 0x04, 0x24, 0x08,
		0x48, 0x10, 0x90, 0x20, 0x18, 0x27, 0x08, 0x3a, 0x2a, 0x4a, 0x83, 0xf4, 0x32, 0x56, 0x5d, 0x97,
		0xf2, 0x03, 0x1b, 0x0e, 0x8c, 0xb5, 0x36, 0xb9, 0xb5, 0xbb, 0x7e, 0xe2, 0x50, 0x9c, 0xb8, 0x3e,
		0xe3, 0xa3, 0x76, 0x34, 0x69, 0xe3, 0xe1, 0x52, 0x17, 0x0f, 0x17, 0xbb, 0x77, 0xe4, 0xe4, 0x14,
		0x18, 0x7a, 0xbe, 0x80, 0x9e, 0xe7, 0xa3, 0x68, 0x76, 0x84, 0x50, 0xeb, 0xed, 0xc1, 0xfe, 0x51,
		0xb3, 0x51, 0xa9, 0xed, 0x37, 0x69, 0x78, 0x0d, 0x90, 0x1e, 0x0d, 0xa4, 0x8f, 0xcd, 0x5a, 0xbd,
		0xf6, 0x7f, 0x6e, 0x9e, 0xcd, 0x0b, 0x8a, 0xa4, 0xa0, 0xa8, 0xb2, 0xf7, 0x1f, 0x8e, 0x8a, 0x01,
		0x3a, 0x4f, 0x82, 0xce, 0xa7, 0x4a, 0xad, 0x5e, 0xd9, 0xad, 0x57, 0x61, 0x20, 0x60, 0xf4, 0x74,
		0x18, 0x8d, 0xfa, 0x3c, 0xef, 0x57, 0x6b, 0xef, 0x7f, 0xdd, 0x3d, 0x68, 0xb4, 0x2a, 0x7b, 0x7b,
		0x8d, 0xea, 0x11, 0x82, 0x08, 0x20, 0x3d, 0x5e, 0x10, 0xed, 0xcf, 0x14, 0x75, 0x75, 0xaf, 0x55,
		0x3f, 0x3a, 0x04, 0x44, 0x80, 0xe8, 0xb1, 0x20, 0x1a, 0x1d, 0x08, 0x5c, 0x69, 0x36, 0x1b, 0xb5,
		0xdd, 0x8f, 0xcd, 0x2a, 0x3c, 0x04, 0x84, 0x9e, 0x06, 0xa1, 0xc3, 0xc6, 0x41, 0xb3, 0xfa, 0xb6,
		0x59, 0x3b, 0xd8, 0x1f, 0xe7, 0x8b, 0xc0, 0x11, 0x38, 0x7a, 0xb4, 0x35, 0xfb, 0x50, 0xdb, 0x6f,
		0xbd, 0x6f, 0x1c, 0x7c, 0x24, 0x92, 0x01, 0x9f, 0xa7, 0xe9, 0xea, 0xda, 0x7e, 0xb3, 0xda, 0x78,
		0x57, 0x79, 0x5b, 0x45, 0x58, 0x83, 0xa4, 0xa7, 0x22, 0xe9, 0x43, 0xe5, 0xf7, 0x71, 0x50, 0xc3,
		0xe7, 0x83, 0xa2, 0x67, 0x84, 0xb3, 0xff, 0xb4, 0xea, 0x95, 0x7d, 0xb2, 0x8d, 0xc0, 0xe7, 0xc9,
		0xaa, 0x1a, 0xe8, 0x00, 0x9d, 0x27, 0x29, 0xa1, 0x32, 0x19, 0x46, 0x80, 0x94, 0x0d, 0x90, 0x90,
		0xd4, 0x20, 0x29, 0x13, 0x49, 0xdd, 0xa8, 0x1e, 0x55, 0x1b, 0x9f, 0x58, 0x40, 0x03, 0x4b, 0xcf,
		0xc3, 0x52, 0xb3, 0xda, 0xda, 0xab, 0xbe, 0xab, 0x7c, 0xac, 0x37, 0x5b, 0x1f, 0xaa, 0xcd, 0x46,
		0xed, 0x2d, 0x20, 0x02, 0x44, 0x8f, 0x05, 0xd1, 0xc7, 0xfd, 0x31, 0x1d, 0x51, 0x4f, 0x04, 0x8e,
		0x9e, 0x6d, 0xd3, 0xf6, 0xaa, 0xf5, 0xca, 0x1f, 0xad, 0x4f, 0x95, 0x46, 0xad, 0xd2, 0xac, 0x1d,
		0xec, 0x83, 0x23, 0x70, 0xf4, 0x58, 0x1c, 0x55, 0x7f, 0x6f, 0x56, 0xf7, 0xf7, 0xaa, 0x7b, 0xac,
		0x82, 0x80, 0xa3, 0x67, 0x09, 0xed, 0xda, 0xfe, 0x75, 0xfe, 0x7a, 0xc4, 0x4b, 0xa0, 0x08, 0x14,
		0x3d, 0x29, 0xaa, 0xd5, 0x0f, 0xf0, 0xfa, 0x80, 0xe7, 0x39, 0x92, 0x08, 0xf4, 0x80, 0x9e, 0xc7,
		0xa2, 0xa7, 0x51, 0x3d, 0xaa, 0xed, 0x7d, 0xac, 0xd4, 0x9d, 0xb6, 0x65, 0x1c, 0xf2, 0xbb, 0xec,
		0xb3, 0x33, 0x27, 0x7b, 0x40, 0x1d, 0xdf, 0xbd, 0x07, 0x60, 0x4c, 0x03, 0xc6, 0xe5, 0x5d, 0x7a,
		0xa0, 0xc5, 0x34, 0x5a, 0x9c, 0xdb, 0x8d, 0x07, 0x44, 0x8c, 0x43, 0xc4, 0xe5, 0x5d, 0x77, 0xc0,
		0xc5, 0x34, 0x5c, 0x1c, 0xdf, 0x5d, 0x07, 0x60, 0x8c, 0x0b, 0x16, 0x77, 0x77, 0xd1, 0x01, 0x16,
		0xd3, 0x60, 0x71, 0x76, 0xb7, 0x1c, 0x50, 0xb1, 0x02, 0x15, 0x67, 0x77, 0xc5, 0x81, 0x17, 0xf3,
		0x56, 0xc8, 0xc1, 0x75, 0x5f, 0x60, 0x62, 0x45, 0xdf, 0x3a, 0x5c, 0x92, 0x0b, 0x62, 0x4c, 0x23,
		0xc6, 0xe5, 0xdd, 0x6c, 0xa0, 0xc5, 0x7c, 0x18, 0x72, 0x70, 0xd7, 0x1a, 0x30, 0xb1, 0xa2, 0x6e,
		0x81, 0x08, 0x10, 0xc9, 0xed, 0x2e, 0x34, 0x00, 0x63, 0x05, 0x30, 0x48, 0x5b, 0x10, 0xf3, 0x28,
		0x69, 0xeb, 0xf6, 0xae, 0x32, 0x30, 0x63, 0x1a, 0x33, 0x0e, 0xef, 0x1e, 0x03, 0x2c, 0xa6, 0xc1,
		0xe2, 0xf6, 0x2e, 0x31, 0xf0, 0x62, 0xc5, 0x16, 0x39, 0xbb, 0x1b, 0x0c, 0xbc, 0x98, 0xc6, 0x8b,
		0xdb, 0xbb, 0xbe, 0xc0, 0x8b, 0x71, 0xc1, 0xeb, 0xf0, 0xee, 0x2e, 0xd0, 0x62, 0x25, 0x1a, 0xb9,
		0xb5, 0x8b, 0x0b, 0x90, 0xd8, 0x93, 0x2c, 0xa0, 0x04, 0x94, 0xe4, 0x71, 0x57, 0x16, 0x68, 0xd1,
		0x8e, 0x96, 0x43, 0x4e, 0x8e, 0x03, 0x3d, 0x59, 0xa3, 0xa8, 0x59, 0x79, 0xbf, 0x59, 0x66, 0x0b,
		0x31, 0xc0, 0x79, 0x2c, 0x70, 0x0e, 0x1b, 0xd5, 0x77, 0xb5, 0xdf, 0x69, 0xbc, 0x0b, 0x7a, 0x9e,
		0x82, 0x9e, 0x51, 0x85, 0x5d, 0xe3, 0xe0, 0x63, 0xb3, 0xda, 0xa0, 0xff, 0x2e, 0x08, 0x7a, 0x5a,
		0xe0, 0x02, 0x36, 0xc0, 0xe6, 0x89, 0x61, 0xeb, 0x5d, 0xbd, 0xf2, 0x9e, 0xbe, 0x3b, 0xe0, 0xe7,
		0x29, 0x81, 0xab, 0xec, 0x74, 0xe0, 0xa2, 0x6b, 0x0a, 0xf9, 0x0f, 0x9c, 0x2b, 0x00, 0xc9, 0x3f,
		0x40, 0x5c, 0x74, 0xa8, 0xa0, 0x04, 0x27, 0x0a, 0x52, 0x70, 0x9c, 0xc0, 0x03, 0x67, 0x09, 0x4e,
		0xf2, 0x1a, 0x70, 0xca, 0x04, 0x1c, 0x90, 0xb2, 0x88, 0x94, 0x09, 0x28, 0xde, 0x56, 0x0e, 0x59,
		0xe3, 0x05, 0x3f, 0x99, 0xe2, 0xa8, 0xd1, 0xaa, 0xd4, 0xdf, 0x1f, 0x34, 0x6a, 0xcd, 0x5f, 0x3f,
		0x90, 0xf5, 0x04, 0x41, 0x4f, 0x42, 0xd0, 0xf5, 0x6f, 0xa4, 0x3d, 0xf5, 0x7e, 0x91, 0xf6, 0x44,
		0x14, 0xe4, 0x8d, 0xcc, 0x41, 0x0a, 0xa4, 0x9d, 0x2b, 0xb2, 0x96, 0x4f, 0xd2, 0xb2, 0xef, 0xa3,
		0xdc, 0xd1, 0xc9, 0x1c, 0x99, 0x50, 0x02, 0x2d, 0x54, 0xa2, 0xa8, 0x97, 0xfa, 0x69, 0xd0, 0x8b,
		0x0a, 0x3b, 0x82, 0xa9, 0xb3, 0x90, 0xb4, 0xcf, 0xd4, 0xb9, 0xdf, 0xf7, 0xd3, 0xb3, 0x21, 0x59,
		0x16, 0x7b, 0x7d, 0x15, 0xb5, 0x7b, 0x51, 0x37, 0x38, 0xf5, 0x22, 0x95, 0xfe, 0xd5, 0x8b, 0xbf,
		0x7a, 0x41, 0x94, 0xa4, 0x7e, 0xd4, 0x56, 0xc5, 0xdb, 0x4f, 0x24, 0x0b, 0xcf, 0x14, 0xfb, 0x71,
		0x2f, 0xed, 0xb5, 0x7b, 0x61, 0x32, 0x7b, 0x54, 0x0c, 0x92, 0x20, 0x29, 0x86, 0xea, 0x42, 0x85,
		0x93, 0x1f, 0xc5, 0x30, 0x88, 0xbe, 0x7a, 0x49, 0xea, 0xa7, 0xca, 0xeb, 0xf8, 0xa9, 0x7f, 0xe2,
		0x27, 0xaa, 0x18, 0x26, 0xfd, 0x62, 0x1a, 0x5e, 0x24, 0xc3, 0x6f, 0x45, 0xf5, 0x2d, 0x55, 0x51,
		0x47, 0x75, 0xbc, 0xa0, 0x7f, 0x51, 0xf6, 0x62, 0xe5, 0xb7, 0xcf, 0xfc, 0x93, 0x20, 0x0c, 0xd2,
		0xcb, 0x62, 0x3f, 0x56, 0xdd, 0xe0, 0x9b, 0x4a, 0x26, 0x0f, 0x8a, 0xc9, 0xe0, 0x64, 0xf4, 0x67,
		0xe3, 0x9f, 0xc5, 0xd1, 0x1f, 0x24, 0xbd, 0x41, 0xdc, 0x56, 0x5e, 0xdc, 0x1b, 0xa4, 0x2a, 0xf6,
		0x82, 0x4e, 0x71, 0x74, 0x2d, 0xc1, 0x89, 0x82, 0x42, 0x92, 0xc6, 0x83, 0x76, 0x1a, 0x4d, 0x22,
		0xd6, 0xc1, 0xec, 0x33, 0xd8, 0x1f, 0xdf, 0xdf, 0xda, 0xe4, 0xf6, 0xb6, 0x6e, 0xfd, 0x9e, 0xdc,
		0x7e, 0xa2, 0x75, 0x38, 0xbd, 0xff, 0xb3, 0x47, 0xad, 0x5a, 0x12, 0x24, 0xad, 0xfa, 0xe8, 0xfe,
		0x8f, 0x7f, 0xb4, 0xea, 0x41, 0xf4, 0xf5, 0x68, 0x78, 0x4b, 0xf6, 0x26, 0x77, 0xbf, 0x55, 0x4f,
		0xfa, 0xad, 0x66, 0x78, 0x91, 0x0c, 0xbf, 0xb5, 0xaa, 0x93, 0xbb, 0x5f, 0xeb, 0x5f, 0x94, 0x1b,
		0x37, 0xee, 0x7d, 0xeb, 0x70, 0x72, 0xef, 0x27, 0x0f, 0x5a, 0x47, 0xe3, 0x7b, 0x3f, 0xf9, 0xd9,
		0x1a, 0xfe, 0xfb, 0xa3, 0xd1, 0xad, 0x6f, 0x8c, 0xee, 0x7c, 0xad, 0xd3, 0x1a, 0x5d, 0x45, 0x66,
		0x84, 0x95, 0xc7, 0x66, 0xb2, 0x46, 0x24, 0x8c, 0x57, 0xa5, 0xf3, 0xe9, 0x32, 0xf0, 0xa8, 0x40,
		0x06, 0xcd, 0x2b, 0x73, 0xca, 0xe2, 0x4c, 0x39, 0xcc, 0x24, 0x88, 0x95, 0x0a, 0x41, 0xff, 0x62,
		0x73, 0x71, 0x8e, 0x48, 0x23, 0xa7, 0x99, 0x0f, 0xbe, 0x7b, 0xb8, 0xc2, 0x58, 0xfe, 0xb7, 0x20,
		0x1a, 0xde, 0xc2, 0x92, 0xb0, 0x61, 0xbd, 0x1d, 0x71, 0x4a, 0x61, 0x67, 0x65, 0x4d, 0xd8, 0xc0,
		0xc6, 0x7c, 0x22, 0x33, 0x22, 0x4e, 0x81, 0xd7, 0x6b, 0x7b, 0xc3, 0xd8, 0x25, 0x31, 0x7a, 0x8c,
		0x49, 0x57, 0xac, 0x41, 0x2b, 0xfc, 0xa6, 0x2e, 0xff, 0xea, 0xc5, 0xc3, 0x19, 0x51, 0x18, 0xc7,
		0x69, 0xa1, 0x26, 0xa6, 0xf0, 0xab, 0x9f, 0x54, 0xe2, 0xd3, 0xc1, 0xb9, 0x8a, 0xd2, 0xc2, 0xce,
		0x4a, 0x1a, 0x0f, 0x94, 0x54, 0x5b, 0x7e, 0x3d, 0xca, 0x19, 0x30, 0x71, 0x02, 0x4e, 0x39, 0x81,
		0xbd, 0x20, 0x16, 0x6a, 0x01, 0x46, 0x6e, 0x57, 0x2c, 0x99, 0x4c, 0xf9, 0x58, 0x72, 0x36, 0x44,
		0xa8, 0x00, 0x10, 0x2f, 0x04, 0x5c, 0x10, 0x04, 0x0e, 0x09, 0x03, 0x57, 0x04, 0x82, 0x73, 0x42,
		0xc1, 0x39, 0xc1, 0xe0, 0x96, 0x70, 0x90, 0x29, 0x20, 0x84, 0x0a, 0x09, 0xf1, 0x82, 0x62, 0x36,
		0x40, 0xb9, 0xd9, 0x85, 0x7b, 0xb9, 0x5d, 0x72, 0xd2, 0xf0, 0x2e, 0xc1, 0xb1, 0x26, 0x7c, 0x98,
		0xd2, 0x85, 0x87, 0x4b, 0x02, 0xc4, 0x41, 0x21, 0xe2, 0x9a, 0x20, 0x71, 0x56, 0x98, 0x38, 0x2b,
		0x50, 0xdc, 0x14, 0x2a, 0xb2, 0x05, 0x8b, 0x70, 0xe1, 0x32, 0xfb, 0xc8, 0x9b, 0x97, 0x7d, 0xe5,
		0x16, 0xe3, 0x8e, 0x16, 0x23, 0xfc, 0x4e, 0x27, 0x56, 0x89, 0x13, 0xb4, 0x3b, 0x4d, 0x4b, 0xbc,
		0x71, 0x60, 0xac, 0x87, 0x7e, 0x9a, 0xaa, 0x38, 0x72, 0x66, 0x8b, 0x49, 0xe1, 0xe5, 0xcb, 0xcf,
		0x6b, 0xde, 0xb6, 0xef, 0x75, 0x2b, 0xde, 0xbb, 0xe3, 0xef, 0xa5, 0x5f, 0xca, 0x57, 0x3b, 0xab,
		0xdf, 0xb7, 0xae, 0x6e, 0x3f, 0xf9, 0xf7, 0x5d, 0xff, 0xac, 0xf4, 0xcb, 0xd6, 0xd5, 0xce, 0x3d,
		0xff, 0x67, 0xf3, 0x6a, 0xe7, 0x81, 0xaf, 0xb1, 0x71, 0xf5, 0x72, 0xe1, 0x9f, 0x0e, 0x9f, 0x5f,
		0xbf, 0xef, 0x0f, 0xca, 0xf7, 0xfc, 0xc1, 0xeb, 0xfb, 0xfe, 0xe0, 0xf5, 0x3d, 0x7f, 0x70, 0xef,
		0x90, 0xd6, 0xef, 0xf9, 0x83, 0x8d, 0xab, 0xbf, 0x17, 0xfe, 0xfd, 0xcb, 0xbb, 0xff, 0xe9, 0xe6,
		0xd5, 0xea, 0xdf, 0xf7, 0xfd, 0xbf, 0xad, 0xab, 0xbf, 0x77, 0x56, 0x57, 0xe5, 0x07, 0x86, 0x63,
		0x17, 0x26, 0xdc, 0xc1, 0x51, 0xed, 0x77, 0xe7, 0x66, 0xdd, 0x9f, 0x4c, 0x3b, 0x5b, 0xd3, 0xee,
		0x1f, 0x0e, 0xcc, 0x3b, 0x8a, 0xa4, 0xf3, 0x26, 0x15, 0x0b, 0xa9, 0x0b, 0x32, 0x71, 0x26, 0x11,
		0x47, 0xa3, 0x25, 0x79, 0x44, 0xf2, 0x88, 0xe4, 0x11, 0xc9, 0x23, 0x92, 0x47, 0x24, 0x8f, 0x48,
		0x1e, 0x91, 0x3c, 0x1a, 0x27, 0x8f, 0x3a, 0x2a, 0x4a, 0x83, 0xf4, 0x32, 0x56, 0x5d, 0x97, 0x72,
		0x47, 0x1b, 0x0e, 0x8c, 0xb5, 0x36, 0xb9, 0xb5, 0xbb, 0x7e, 0xe2, 0x50, 0x9c, 0xb8, 0x3e, 0x39,
		0xa6, 0x76, 0x34, 0x69, 0x0e, 0xe3, 0x52, 0x6f, 0x18, 0x17, 0x7b, 0xc2, 0xe4, 0xe4, 0x6c, 0x21,
		0x3a, 0x09, 0x81, 0x9e, 0xe7, 0xa3, 0x68, 0x76, 0x30, 0x55, 0xeb, 0xed, 0xc1, 0xfe, 0x51, 0xb3,
		0x51, 0xa9, 0xed, 0x37, 0x69, 0xa3, 0x0e, 0x90, 0x1e, 0x0d, 0xa4, 0x8f, 0xcd, 0x5a, 0xbd, 0xf6,
		0x7f, 0x6e, 0x9e, 0xf8, 0x0c, 0x8a, 0xa4, 0xa0, 0xa8, 0xb2, 0xf7, 0x1f, 0x0e, 0x20, 0x02, 0x3a,
		0x4f, 0x82, 0xce, 0xa7, 0x4a, 0xad, 0x5e, 0xd9, 0xad, 0x57, 0x61, 0x20, 0x60, 0xf4, 0x74, 0x18,
		0x8d, 0xba, 0x87, 0xef, 0x57, 0x6b, 0xef, 0x7f, 0xdd, 0x3d, 0x68, 0xb4, 0x2a, 0x7b, 0x7b, 0x8d,
		0xea, 0x11, 0x82, 0x08, 0x20, 0x3d, 0x5e, 0x10, 0xed, 0xcf, 0x14, 0x75, 0x75, 0xaf, 0x55, 0x3f,
		0x3a, 0x04, 0x44, 0x80, 0xe8, 0xb1, 0x20, 0x1a, 0x1d, 0x33, 0x5d, 0x69, 0x36, 0x1b, 0xb5, 0xdd,
		0x8f, 0xcd, 0x2a, 0x3c, 0x04, 0x84, 0x9e, 0x06, 0xa1, 0xc3, 0xc6, 0x41, 0xb3, 0xfa, 0xb6, 0x59,
		0x3b, 0xd8, 0x1f, 0xe7, 0x8b, 0xc0, 0x11, 0x38, 0x7a, 0xb4, 0x35, 0xfb, 0x50, 0xdb, 0x6f, 0xbd,
		0x6f, 0x1c, 0x7c, 0x24, 0x92, 0x01, 0x9f, 0xa7, 0xe9, 0xea, 0xda, 0x7e, 0xb3, 0xda, 0x78, 0x57,
		0x79, 0x5b, 0x45, 0x58, 0x83, 0xa4, 0xa7, 0x22, 0xe9, 0x43, 0xe5, 0xf7, 0x71, 0x50, 0xc3, 0xe7,
		0x83, 0xa2, 0x67, 0x84, 0xb3, 0xff, 0xb4, 0xea, 0x95, 0x7d, 0xb2, 0x8d, 0xc0, 0xe7, 0xc9, 0xaa,
		0x1a, 0xe8, 0x00, 0x9d, 0x27, 0x29, 0xa1, 0x32, 0x19, 0x46, 0x80, 0x94, 0x0d, 0x90, 0x90, 0xd4,
		0x20, 0x29, 0x13, 0x49, 0xdd, 0xa8, 0x1e, 0x55, 0x1b, 0x9f, 0x58, 0x40, 0x03, 0x4b, 0xcf, 0xc3,
		0x52, 0xb3, 0xda, 0xda, 0xab, 0xbe, 0xab, 0x7c, 0xac, 0x37, 0x5b, 0x1f, 0xaa, 0xcd, 0x46, 0xed,
		0x2d, 0x20, 0x02, 0x44, 0x8f, 0x05, 0xd1, 0xc7, 0xfd, 0x31, 0x1d, 0x51, 0x4f, 0x04, 0x8e, 0x9e,
		0x6d, 0xd3, 0xf6, 0xaa, 0xf5, 0xca, 0x1f, 0xad, 0x4f, 0x95, 0x46, 0xad, 0xd2, 0xac, 0x1d, 0xec,
		0x83, 0x23, 0x70, 0xf4, 0x58, 0x1c, 0x55, 0x7f, 0x6f, 0x56, 0xf7, 0xf7, 0xaa, 0x7b, 0xac, 0x82,
		0x80, 0xa3, 0x67, 0x09, 0xed, 0xda, 0xfe, 0x75, 0xfe, 0x7a, 0xc4, 0x4b, 0xa0, 0x08, 0x14, 0x3d,
		0x29, 0xaa, 0xd5, 0x0f, 0xf0, 0xfa, 0x80, 0xe7, 0x39, 0x92, 0x08, 0xf4, 0x80, 0x9e, 0xc7, 0xa2,
		0xa7, 0x51, 0x3d, 0xaa, 0xed, 0x7d, 0xac, 0xd4, 0x9d, 0xb6, 0x65, 0x1c, 0x1d, 0xbd, 0xec, 0xb3,
		0x33, 0x27, 0x7b, 0x40, 0x1d, 0xdf, 0xbd, 0x07, 0x60, 0x4c, 0x03, 0xc6, 0xe5, 0x5d, 0x7a, 0xa0,
		0xc5, 0x34, 0x5a, 0x9c, 0xdb, 0x8d, 0x07, 0x44, 0x8c, 0x43, 0xc4, 0xe5, 0x5d, 0x77, 0xc0, 0xc5,
		0x34, 0x5c, 0x1c, 0xdf, 0x5d, 0x07, 0x60, 0x8c, 0x0b, 0x16, 0x77, 0x77, 0xd1, 0x01, 0x16, 0xd3,
		0x60, 0x71, 0x76, 0xb7, 0x1c, 0x50, 0xb1, 0x02, 0x15, 0x67, 0x77, 0xc5, 0x81, 0x17, 0xf3, 0x56,
		0xc8, 0xc1, 0x75, 0x5f, 0x60, 0x62, 0x45, 0xdf, 0x3a, 0x5c, 0x92, 0x0b, 0x62, 0x4c, 0x23, 0xc6,
		0xe5, 0xdd, 0x6c, 0xa0, 0xc5, 0x7c, 0x18, 0x72, 0x70, 0xd7, 0x1a, 0x30, 0xb1, 0xa2, 0x6e, 0x81,
		0x08, 0x10, 0xc9, 0xed, 0x2e, 0x34, 0x00, 0x63, 0x05, 0x30, 0x48, 0x5b, 0x10, 0xf3, 0x28, 0x69,
		0xeb, 0xf6, 0xae, 0x32, 0x30, 0x63, 0x1a, 0x33, 0x0e, 0xef, 0x1e, 0x03, 0x2c, 0xa6, 0xc1, 0xe2,
		0xf6, 0x2e, 0x31, 0xf0, 0x62, 0xc5, 0x16, 0x39, 0xbb, 0x1b, 0x0c, 0xbc, 0x98, 0xc6, 0x8b, 0xdb,
		0xbb, 0xbe, 0xc0, 0x8b, 0x71, 0xc1, 0xeb, 0xf0, 0xee, 0x2e, 0xd0, 0x62, 0x25, 0x1a, 0xb9, 0xb5,
		0x8b, 0x0b, 0x90, 0xd8, 0x93, 0x2c, 0xa0, 0x04, 0x94, 0xe4, 0x71, 0x57, 0x16, 0x68, 0xd1, 0x8e,
		0x96, 0x43, 0x4e, 0x8e, 0x03, 0x3d, 0x59, 0xa3, 0xa8, 0x59, 0x79, 0xbf, 0x59, 0x66, 0x0b, 0x31,
		0xc0, 0x79, 0x2c, 0x70, 0x0e, 0x1b, 0xd5, 0x77, 0xb5, 0xdf, 0x69, 0xbc, 0x0b, 0x7a, 0x9e, 0x82,
		0x9e, 0x51, 0x85, 0x5d, 0xe3, 0xe0, 0x63, 0xb3, 0xda, 0xa0, 0xff, 0x2e, 0x08, 0x7a, 0x5a, 0xe0,
		0x02, 0x36, 0xc0, 0xe6, 0x89, 0x61, 0xeb, 0x5d, 0xbd, 0xf2, 0x9e, 0xbe, 0x3b, 0xe0, 0xe7, 0x29,
		0x81, 0xab, 0xec, 0x74, 0xe0, 0xa2, 0x6b, 0x0a, 0xf9, 0x0f, 0x9c, 0x2b, 0x00, 0xc9, 0x3f, 0x40,
		0x5c, 0x74, 0xa8, 0xa0, 0x04, 0x27, 0x0a, 0x52, 0x70, 0x9c, 0xc0, 0x03, 0x67, 0x09, 0x4e, 0xf2,
		0x1a, 0x70, 0xca, 0x04, 0x1c, 0x90, 0xb2, 0x88, 0x94, 0x09, 0x28, 0xde, 0x56, 0x0e, 0x59, 0xe3,
		0x05, 0x3f, 0x99, 0xe2, 0xa8, 0xd1, 0xaa, 0xd4, 0xdf, 0x1f, 0x34, 0x6a, 0xcd, 0x5f, 0x3f, 0x90,
		0xf5, 0x04, 0x41, 0x4f, 0x42, 0xd0, 0xf5, 0x6f, 0xa4, 0x3d, 0xf5, 0x7e, 0x91, 0xf6, 0x44, 0x14,
		0xe4, 0x8d, 0xcc, 0x41, 0x0a, 0xa4, 0x9d, 0x2b, 0xb2, 0x96, 0x4f, 0xd2, 0xb2, 0xef, 0xa3, 0xdc,
		0xd1, 0xc9, 0x1c, 0x99, 0x50, 0x02, 0x2d, 0x54, 0xa2, 0xa8, 0x97, 0xfa, 0x69, 0xd0, 0x8b, 0x0a,
		0x3b, 0x82, 0xa9, 0xb3, 0x90, 0xb4, 0xcf, 0xd4, 0xb9, 0xdf, 0xf7, 0xd3, 0xb3, 0x21, 0x59, 0x16,
		0x7b, 0x7d, 0x15, 0xb5, 0x7b, 0x51, 0x37, 0x38, 0xf5, 0x22, 0x95, 0xfe, 0xd5, 0x8b, 0xbf, 0x7a,
		0x41, 0x94, 0xa4, 0x7e, 0xd4, 0x56, 0xc5, 0xdb, 0x4f, 0x24, 0x0b, 0xcf, 0x14, 0xfb, 0x71, 0x2f,
		0xed, 0xb5, 0x7b, 0x61, 0x32, 0x7b, 0x54, 0x0c, 0x92, 0x20, 0x29, 0x86, 0xea, 0x42, 0x85, 0x93,
		0x1f, 0xc5, 0x30, 0x88, 0xbe, 0x7a, 0x49, 0xea, 0xa7, 0xca, 0xeb, 0xf8, 0xa9, 0x7f, 0xe2, 0x27,
		0xaa, 0x18, 0x26, 0xfd, 0x62, 0x1a, 0x5e, 0x24, 0xc3, 0x6f, 0x45, 0xf5, 0x2d, 0x55, 0x51, 0x47,
		0x75, 0xbc, 0xa0, 0x7f, 0x51, 0xf6, 0x62, 0xe5, 0xb7, 0xcf, 0xfc, 0x93, 0x20, 0x0c, 0xd2, 0xcb,
		0x62, 0x3f, 0x56, 0xdd, 0xe0, 0x9b, 0x4a, 0x26, 0x0f, 0x8a, 0xc9, 0xe0, 0x64, 0xf4, 0x67, 0xe3,
		0x9f, 0xc5, 0xa0, 0x7f, 0xb1, 0xe9, 0x25, 0xbd, 0x41, 0xdc, 0x56, 0x5e, 0xdc, 0x1b, 0xa4, 0x2a,
		0xf6, 0x82, 0x4e, 0x71, 0x74, 0x2d, 0xc1, 0x89, 0x82, 0x42, 0x92, 0xc6, 0x83, 0x76, 0x1a, 0x4d,
		0x22, 0xd6, 0xc1, 0xec, 0x33, 0xd8, 0x1f, 0xdf, 0xdf, 0xda, 0xe4, 0xf6, 0xb6, 0x6e, 0xfd, 0x9e,
		0xdc, 0x7e, 0xa2, 0x75, 0x38, 0xbd, 0xff, 0xb3, 0x47, 0xad, 0x5a, 0x12, 0x24, 0xad, 0xfa, 0xe8,
		0xfe, 0x8f, 0x7f, 0xb4, 0xea, 0x41, 0xf4, 0xf5, 0x68, 0x78, 0x4b, 0xf6, 0x26, 0x77, 0xbf, 0x55,
		0x4f, 0xfa, 0xad, 0x66, 0x78, 0x91, 0x0c, 0xbf, 0xb5, 0xaa, 0x93, 0xbb, 0x5f, 0xeb, 0x5f, 0x94,
		0x1b, 0x37, 0xee, 0x7d, 0xeb, 0x70, 0x72, 0xef, 0x27, 0x0f, 0x5a, 0x47, 0xe3, 0x7b, 0x3f, 0xf9,
		0xd9, 0xaa, 0xf5, 0x2f, 0x36, 0x8f, 0x46, 0xb7, 0xbe, 0x31, 0xba, 0xf3, 0xb5, 0x4e, 0x6b, 0x74,
		0x15, 0x99, 0x11, 0x56, 0x1e, 0x9b, 0xc9, 0x1a, 0x91, 0x30, 0x5e, 0x95, 0xce, 0xa7, 0xcb, 0xc0,
		0xa3, 0x02, 0x19, 0x34, 0xaf, 0xcc, 0x29, 0x8b, 0x33, 0xe5, 0x30, 0x93, 0x20, 0x56, 0x2a, 0x8c,
		0x67, 0x8e, 0x97, 0x04, 0x9d, 0x44, 0x1c, 0x25, 0xcd, 0xdc, 0xef, 0xcd, 0x41, 0x0a, 0x63, 0xf4,
		0xdf, 0x82, 0xa8, 0x53, 0xd8, 0x59, 0x29, 0x09, 0x1b, 0xd6, 0xdb, 0x11, 0x7f, 0x14, 0x76, 0x56,
		0xd6, 0x84, 0x0d, 0x6c, 0xcc, 0x1d, 0x32, 0xa3, 0xdf, 0x14, 0x6e, 0xbd, 0xb6, 0x37, 0x8c, 0x53,
		0x12, 0x23, 0xc5, 0x98, 0x60, 0xc5, 0x9a, 0xb1, 0xc2, 0x6f, 0xea, 0xf2, 0xaf, 0x5e, 0xdc, 0xb9,
		0x9e, 0xb4, 0x42, 0x0d, 0x4b, 0xe1, 0x57, 0x3f, 0xa9, 0xc4, 0xa7, 0x83, 0x73, 0x15, 0xa5, 0x85,
		0x9d, 0x95, 0x34, 0x1e, 0x28, 0xa9, 0x16, 0xfc, 0x7a, 0x94, 0x33, 0x60, 0xa2, 0xfa, 0x9d, 0x52,
		0xfd, 0x7b, 0x41, 0x2c, 0x93, 0xf0, 0xae, 0xe3, 0xaa, 0x5c, 0x46, 0x59, 0xd4, 0x00, 0x52, 0x29,
		0x45, 0xa6, 0x14, 0x10, 0x2f, 0x09, 0x5c, 0x90, 0x06, 0x0e, 0x49, 0x04, 0x57, 0xa4, 0x82, 0x73,
		0x92, 0xc1, 0x39, 0xe9, 0xe0, 0x96, 0x84, 0x90, 0x29, 0x25, 0x84, 0x4a, 0x0a, 0xf1, 0xd2, 0x62,
		0x36, 0xc0, 0xf1, 0xaa, 0x85, 0x78, 0x12, 0x9a, 0xf2, 0xba, 0xf4, 0x45, 0x16, 0x07, 0x84, 0x86,
		0x33, 0x82, 0xc3, 0x25, 0xe1, 0xe1, 0xa0, 0x00, 0x71, 0x4d, 0x88, 0x38, 0x2b, 0x48, 0x9c, 0x15,
		0x26, 0x6e, 0x0a, 0x14, 0xd9, 0x42, 0x45, 0xb8, 0x60, 0x71, 0x46, 0xb8, 0xcc, 0x06, 0xea, 0x87,
		0xa7, 0xbd, 0x38, 0x48, 0xcf, 0xce, 0xdd, 0x21, 0xb0, 0x69, 0x8c, 0xb8, 0x1e, 0xba, 0x23, 0x3c,
		0x30, 0x11, 0x36, 0x6b, 0x8e, 0x0c, 0xd7, 0x15, 0x81, 0xe3, 0xa2, 0xd0, 0x71, 0x58, 0xf0, 0xb8,
		0x2a, 0x7c, 0x9c, 0x17, 0x40, 0xce, 0x0b, 0x21, 0xb7, 0x05, 0x91, 0x1b, 0xc2, 0xc8, 0x11, 0x81,
		0x34, 0x83, 0x42, 0xf3, 0xb2, 0xaf, 0xdc, 0x64, 0xec, 0x41, 0x10, 0xa5, 0x6f, 0x5c, 0xe2, 0xeb,
		0x89, 0xfc, 0xd8, 0x70, 0x68, 0xc8, 0x0d, 0x3f, 0x3a, 0x55, 0xce, 0xed, 0xc3, 0x75, 0x6f, 0x07,
		0x65, 0xe1, 0x43, 0x10, 0x39, 0x17, 0xc8, 0x1d, 0xd5, 0xd5, 0x0b, 0xc3, 0x1f, 0xed, 0x36, 0x77,
		0x78, 0xfc, 0xef, 0x62, 0xbf, 0x9d, 0x06, 0xbd, 0x68, 0x2f, 0x38, 0x0d, 0xd2, 0x64, 0xf8, 0x46,
		0xd8, 0xa6, 0x6d, 0x62, 0xca, 0xfa, 0xdf, 0x98, 0xb2, 0x96, 0xa7, 0xec, 0xfa, 0xc6, 0x06, 0x93,
		0x16, 0x21, 0x9e, 0xaf, 0xd1, 0xba, 0xb1, 0x85, 0x5f, 0xfe, 0xfd, 0x74, 0x20, 0xa8, 0x14, 0xba,
		0xa1, 0x7f, 0x9a, 0xb8, 0x97, 0xfa, 0x1d, 0x0f, 0x9b, 0xb4, 0xaf, 0x8e, 0xe1, 0x92, 0xf6, 0x35,
		0x08, 0x64, 0xd2, 0xbe, 0xe6, 0xa6, 0x21, 0x69, 0x5f, 0xcb, 0x6f, 0x80, 0xb4, 0x2f, 0x9a, 0x63,
		0x02, 0x05, 0x77, 0xd3, 0xbe, 0x2a, 0x1a, 0x9c, 0xab, 0x78, 0xbc, 0xc9, 0xd9, 0xbd, 0xe4, 0x6f,
		0xa9, 0xec, 0xd0, 0x98, 0xab, 0xd1, 0x60, 0x54, 0x96, 0xc0, 0xd4, 0xcb, 0xf2, 0xae, 0xd6, 0x83,
		0x24, 0xad, 0xa4, 0x69, 0xec, 0xd6, 0xf4, 0xfb, 0x10, 0x44, 0xd5, 0x50, 0x0d, 0xa3, 0x47, 0xe2,
		0x56, 0xde, 0xa8, 0xf0, 0xc1, 0xff, 0x76, 0x63, 0xe4, 0xa5, 0x37, 0xe5, 0xf2, 0xe6, 0x56, 0xb9,
		0xbc, 0xb6, 0xf5, 0x7a, 0x6b, 0x6d, 0x7b, 0x63, 0xa3, 0xb4, 0x59, 0x72, 0x69, 0x41, 0xe6, 0x20,
		0xee, 0xa8, 0x58, 0x75, 0x76, 0x2f, 0x0b, 0x3b, 0x2b, 0xd1, 0x20, 0x0c, 0x49, 0x15, 0x2c, 0x4d,
		0xaa, 0xe0, 0x62, 0x92, 0xf3, 0x74, 0x2c, 0x55, 0x30, 0x1e, 0x36, 0xa9, 0x02, 0x52, 0x05, 0xa4,
		0x0a, 0x48, 0x15, 0x90, 0x2a, 0x20, 0x55, 0x80, 0xde, 0x20, 0x55, 0x60, 0x84, 0xb1, 0x07, 0x41,
		0x94, 0xbe, 0x5e, 0x77, 0x30, 0x4b, 0xb0, 0x45, 0x89, 0x98, 0xe6, 0x2f, 0x4a, 0xc4, 0x10, 0xd6,
		0x8f, 0x18, 0x3e, 0x25, 0x62, 0x84, 0xcb, 0xa7, 0x4c, 0x59, 0x4a, 0xc4, 0xac, 0x4f, 0xd9, 0xf2,
		0xfa, 0x76, 0x79, 0x7b, 0x73, 0x6b, 0x7d, 0x9b, 0x4a, 0x31, 0x04, 0x79, 0xce, 0x46, 0x4b, 0xa5,
		0xd8, 0x32, 0x8c, 0x50, 0xfa, 0x5e, 0x6b, 0x47, 0xba, 0xf8, 0xcf, 0xc6, 0x9b, 0xaf, 0x2e, 0xd4,
		0x37, 0x9a, 0xd7, 0xde, 0x78, 0x5c, 0x74, 0xa1, 0xd3, 0xcc, 0x4a, 0x6e, 0x9a, 0x53, 0x8f, 0x9f,
		0x3d, 0x0a, 0x3a, 0xc9, 0xf5, 0x43, 0xc9, 0x8d, 0xfd, 0xe5, 0x13, 0x9f, 0x60, 0xd2, 0x73, 0x64,
		0x25, 0xce, 0xa9, 0x15, 0x38, 0x47, 0xdc, 0x06, 0x4d, 0xa7, 0x74, 0x02, 0x95, 0xa6, 0x53, 0xfa,
		0xa6, 0x17, 0x4d, 0xa7, 0x4c, 0xab, 0x62, 0x9a, 0x4e, 0x2d, 0x9b, 0x11, 0x72, 0x66, 0xa5, 0x6c,
		0xc6, 0xb8, 0xa1, 0xf2, 0xbb, 0xb1, 0xea, 0xba, 0xc0, 0xb8, 0xd3, 0x02, 0x5a, 0x07, 0xd6, 0xc6,
		0x0a, 0x87, 0x13, 0x6f, 0xf9, 0xea, 0xd5, 0xd8, 0x87, 0x15, 0xc7, 0x12, 0x0c, 0x2b, 0x90, 0xa3,
		0x91, 0x49, 0x6d, 0xd9, 0xfb, 0x9b, 0xba, 0x94, 0x2e, 0xfa, 0xdd, 0x28, 0x81, 0x76, 0xa7, 0xe4,
		0xd9, 0xe9, 0x12, 0x67, 0x37, 0x4a, 0x9a, 0x39, 0x41, 0xf5, 0x79, 0xe3, 0x5c, 0x86, 0x9c, 0x2b,
		0x87, 0xa7, 0x5a, 0xc8, 0xb2, 0x72, 0x70, 0xaa, 0x8b, 0x23, 0xe2, 0xe0, 0x54, 0xe8, 0x53, 0xe2,
		0x79, 0x8b, 0x79, 0xe4, 0x4a, 0x8e, 0x49, 0x15, 0xcf, 0x41, 0x42, 0x8f, 0x31, 0x11, 0x7d, 0x6c,
		0x09, 0x47, 0xa3, 0x3e, 0x36, 0x29, 0xc5, 0xd1, 0xa8, 0xcf, 0x19, 0x22, 0x47, 0xa3, 0x66, 0x34,
		0x50, 0x8e, 0x46, 0x45, 0xd7, 0x9b, 0xfa, 0x08, 0xc5, 0x1e, 0x8d, 0x9a, 0x4a, 0x5e, 0x2a, 0x9a,
		0xd1, 0xf1, 0x68, 0x94, 0xb2, 0x8f, 0x43, 0x5d, 0xe3, 0x38, 0xd4, 0xdc, 0xc9, 0x01, 0x87, 0x64,
		0x81, 0x2b, 0xf2, 0xc0, 0x39, 0x99, 0xe0, 0x9c, 0x5c, 0x70, 0x4b, 0x36, 0xc8, 0x94, 0x0f, 0x42,
		0x65, 0xc4, 0xec, 0xa3, 0x15, 0x5f, 0xe0, 0x31, 0x63, 0xcc, 0xa0, 0xa3, 0xa2, 0x34, 0x48, 0x2f,
		0x65, 0x17, 0x77, 0xcc, 0x3c, 0xbc, 0xe4, 0xf5, 0xc9, 0xda, 0xe4, 0x56, 0xee, 0xfa, 0x89, 0x43,
		0x45, 0xbf, 0xb5, 0xa3, 0xda, 0x51, 0xeb, 0xe8, 0xe3, 0x6e, 0xb3, 0xfe, 0xa9, 0xd5, 0xfc, 0xe3,
		0xb0, 0x2a, 0x9d, 0xe6, 0x47, 0xdb, 0xf5, 0x12, 0x27, 0xf6, 0x91, 0x3b, 0xd6, 0x80, 0xa9, 0x76,
		0xd4, 0x6a, 0x54, 0x2b, 0x6f, 0x7f, 0xad, 0xec, 0xd6, 0xea, 0xb5, 0xe6, 0x1f, 0x13, 0x50, 0x1c,
		0xb9, 0x80, 0x0a, 0x17, 0xd1, 0xe1, 0x16, 0x4a, 0x7e, 0x8a, 0x96, 0xdd, 0xca, 0xfe, 0xde, 0xff,
		0xd6, 0xf6, 0x9a, 0xbf, 0xb6, 0xde, 0x1e, 0xec, 0x1f, 0x35, 0x1b, 0x95, 0xda, 0x7e, 0xf3, 0xc8,
		0xa1, 0x56, 0x30, 0xbf, 0x00, 0x18, 0xb3, 0x80, 0xf9, 0xd8, 0xac, 0xd5, 0x6b, 0xff, 0x57, 0xdd,
		0xbb, 0x46, 0x0e, 0x68, 0x01, 0x2d, 0xf7, 0xa1, 0xa5, 0xb2, 0xf7, 0x9f, 0xd6, 0x51, 0x6d, 0x0f,
		0x88, 0x00, 0x91, 0x7b, 0x21, 0xf2, 0xa9, 0x52, 0xab, 0x57, 0x76, 0xeb, 0x55, 0x18, 0x05, 0xb8,
		0xfc, 0x1c, 0x2e, 0xb5, 0xc3, 0x4f, 0x9b, 0xad, 0xfd, 0x6a, 0xed, 0xfd, 0xaf, 0xbb, 0x07, 0x8d,
		0x56, 0x65, 0x6f, 0xaf, 0x51, 0x3d, 0x42, 0xb0, 0x00, 0x98, 0xfb, 0x05, 0xcb, 0xfe, 0x4c, 0xd9,
		0x56, 0xf7, 0x5a, 0xf5, 0xa3, 0x43, 0xc0, 0x02, 0x58, 0xee, 0x03, 0x4b, 0xbd, 0xb6, 0xff, 0x5b,
		0xab, 0xd2, 0x6c, 0x36, 0x6a, 0xbb, 0x1f, 0x9b, 0x55, 0x78, 0x05, 0xa8, 0xfc, 0x18, 0x2a, 0x87,
		0x8d, 0x83, 0x66, 0xf5, 0x6d, 0xb3, 0x76, 0xb0, 0x3f, 0xce, 0xb7, 0x80, 0x17, 0xf0, 0x72, 0xaf,
		0x15, 0xfa, 0x50, 0xdb, 0x6f, 0xbd, 0x6f, 0x1c, 0x7c, 0x24, 0x02, 0x01, 0x93, 0x1f, 0xeb, 0xdb,
		0xda, 0x7e, 0xb3, 0xda, 0x78, 0x57, 0x79, 0x5b, 0x45, 0xe0, 0x82, 0x98, 0x9f, 0x21, 0xe6, 0x43,
		0xe5, 0xf7, 0x71, 0x30, 0xc2, 0x3f, 0x83, 0x96, 0x07, 0x84, 0xa1, 0xff, 0xb4, 0xea, 0x95, 0x7d,
		0xb2, 0x72, 0xc0, 0xe4, 0xa7, 0xea, 0x16, 0x88, 0x00, 0x91, 0x1f, 0x2a, 0x95, 0x32, 0x99, 0x38,
		0x00, 0xf3, 0x38, 0xc0, 0x20, 0x6d, 0x41, 0xcc, 0xa3, 0xa4, 0x6d, 0xa3, 0x7a, 0x54, 0x6d, 0x7c,
		0x62, 0x81, 0x08, 0xcc, 0x3c, 0x0c, 0x33, 0xcd, 0x6a, 0x6b, 0xaf, 0xfa, 0xae, 0xf2, 0xb1, 0xde,
		0x6c, 0x7d, 0xa8, 0x36, 0x1b, 0xb5, 0xb7, 0x80, 0x05, 0xb0, 0xdc, 0xbf, 0x38, 0x34, 0xa6, 0x17,
		0xea, 0x59, 0xc0, 0xcb, 0x83, 0x6d, 0xd1, 0x5e, 0xb5, 0x5e, 0xf9, 0xa3, 0xf5, 0xa9, 0xd2, 0xa8,
		0x55, 0x9a, 0xb5, 0x83, 0x7d, 0xf0, 0x02, 0x5e, 0xee, 0xc3, 0x4b, 0xf5, 0xf7, 0x66, 0x75, 0x7f,
		0xaf, 0xba, 0x47, 0xf6, 0x1f, 0xbc, 0x3c, 0x48, 0xf0, 0xd6, 0xf6, 0xaf, 0xf3, 0xb9, 0x23, 0x9e,
		0x01, 0x2d, 0xa0, 0xe5, 0x87, 0xd1, 0xa8, 0x7e, 0x80, 0x87, 0x06, 0x24, 0x0f, 0x91, 0x2c, 0xa0,
		0x04, 0x94, 0xdc, 0x87, 0x92, 0x46, 0xf5, 0xa8, 0xb6, 0xf7, 0xb1, 0x52, 0x77, 0xd2, 0x06, 0x39,
		0x31, 0x52, 0xf9, 0x87, 0x79, 0x39, 0x30, 0xeb, 0x1c, 0xdf, 0x9b, 0xe7, 0xe8, 0x6e, 0x2b, 0x80,
		0xa1, 0x1b, 0x18, 0x2e, 0xee, 0xaa, 0x02, 0x15, 0xba, 0x51, 0xe1, 0xcc, 0xee, 0x29, 0xa0, 0xa0,
		0x1d, 0x0a, 0x2e, 0xee, 0x92, 0x02, 0x16, 0xba, 0x61, 0xe1, 0xe8, 0x6e, 0x28, 0x80, 0xa1, 0x5d,
		0x50, 0xb8, 0xb7, 0xeb, 0x09, 0x50, 0xe8, 0x06, 0x85, 0x73, 0xbb, 0x9b, 0x80, 0x84, 0x11, 0x48,
		0x38, 0xb7, 0x8b, 0x09, 0x5c, 0xe8, 0xb7, 0x1e, 0x0e, 0xad, 0x57, 0x02, 0x07, 0x23, 0x3a, 0xd3,
		0xc1, 0xd2, 0x4d, 0x90, 0xa1, 0x1b, 0x19, 0x2e, 0xee, 0x3e, 0x02, 0x15, 0xfa, 0xc3, 0x87, 0x43,
		0xbb, 0x8c, 0x80, 0x83, 0x11, 0x95, 0x09, 0x14, 0x80, 0x82, 0xb3, 0xbb, 0x86, 0x00, 0x86, 0x11,
		0x60, 0x20, 0x31, 0x41, 0x46, 0x8e, 0x76, 0x01, 0x81, 0x0d, 0xdd, 0xd8, 0x70, 0x70, 0xb7, 0x0f,
		0xa0, 0xd0, 0x0d, 0x0a, 0x37, 0x77, 0xf5, 0x80, 0x0b, 0x23, 0x36, 0xc4, 0xb9, 0xdd, 0x3b, 0xe0,
		0x42, 0x37, 0x2e, 0xdc, 0xdc, 0xa5, 0x03, 0x2e, 0xb4, 0x0b, 0x4f, 0x07, 0x77, 0xe3, 0x80, 0x0a,
		0x23, 0x51, 0xc4, 0x8d, 0x5d, 0x37, 0x80, 0xc1, 0x9c, 0xa4, 0x00, 0x0d, 0xa0, 0xc1, 0xc5, 0x5d,
		0x34, 0xa0, 0x22, 0x73, 0x54, 0x1c, 0x72, 0x22, 0x13, 0x28, 0x79, 0x2a, 0x5a, 0x9a, 0x95, 0xf7,
		0x9b, 0x65, 0xb6, 0x6a, 0x02, 0x90, 0xfb, 0x00, 0x72, 0xd8, 0xa8, 0xbe, 0xab, 0xfd, 0x4e, 0x03,
		0x4f, 0x50, 0xf2, 0x23, 0x94, 0x8c, 0x2a, 0xb6, 0x1a, 0x07, 0x1f, 0x9b, 0xd5, 0x06, 0x7d, 0x3c,
		0x41, 0xca, 0x8f, 0x03, 0x0e, 0xf0, 0x00, 0x1e, 0x3f, 0x09, 0x37, 0xef, 0xea, 0x95, 0xf7, 0xf4,
		0x19, 0x01, 0x27, 0x3f, 0x0a, 0x38, 0x65, 0x27, 0x03, 0x0e, 0xdd, 0x23, 0xc8, 0x23, 0xe0, 0x0c,
		0x01, 0x02, 0x0e, 0x10, 0x34, 0xe0, 0xf4, 0x40, 0x44, 0x2e, 0x02, 0x05, 0x30, 0x00, 0x06, 0x6e,
		0x39, 0x37, 0xf0, 0x80, 0x43, 0x03, 0x11, 0x7a, 0x11, 0x31, 0xf9, 0xf0, 0xdf, 0x56, 0x0e, 0x59,
		0x9b, 0x04, 0x27, 0x4f, 0xc2, 0x4b, 0xa3, 0x55, 0xa9, 0xbf, 0x3f, 0x68, 0xd4, 0x9a, 0xbf, 0x7e,
		0x20, 0x1b, 0x08, 0x52, 0x7e, 0x88, 0x94, 0xeb, 0xdf, 0x48, 0x07, 0x66, 0xfb, 0x45, 0x3a, 0x90,
		0xe0, 0xed, 0x1a, 0x19, 0x83, 0x08, 0x48, 0xd7, 0x29, 0xb2, 0x95, 0x4b, 0xb2, 0x32, 0xef, 0x9b,
		0xbc, 0x51, 0xc9, 0x1a, 0x91, 0x30, 0x02, 0x2c, 0x54, 0xa2, 0xa8, 0x97, 0xfa, 0x69, 0xd0, 0x8b,
		0x0a, 0x3b, 0x02, 0xa9, 0xaf, 0x90, 0xb4, 0xcf, 0xd4, 0xb9, 0xdf, 0xf7, 0xd3, 0xb3, 0x21, 0xd9,
		0x15, 0x7b, 0x7d, 0x15, 0xb5, 0x7b, 0x51, 0x37, 0x38, 0xf5, 0x22, 0x95, 0xfe, 0xd5, 0x8b, 0xbf,
		0x7a, 0x41, 0x94, 0xa4, 0x7e, 0xd4, 0x56, 0xc5, 0xdb, 0x4f, 0x24, 0x0b, 0xcf, 0x14, 0xfb, 0x71,
		0x2f, 0xed, 0xb5, 0x7b, 0x61, 0x32, 0x7b, 0x54, 0x0c, 0x92, 0x20, 0x29, 0x86, 0xea, 0x42, 0x85,
		0x93, 0x1f, 0xc5, 0x30, 0x88, 0xbe, 0x7a, 0x49, 0xea, 0xa7, 0xca, 0xeb, 0xf8, 0xa9, 0x7f, 0xe2,
		0x27, 0xaa, 0x18, 0x26, 0xfd, 0x62, 0x1a, 0x5e, 0x24, 0xc3, 0x6f, 0x45, 0xf5, 0x2d, 0x55, 0x51,
		0x47, 0x75, 0xbc, 0xa0, 0x7f, 0x51, 0xf6, 0x62, 0xe5, 0xb7, 0xcf, 0xfc, 0x93, 0x20, 0x0c, 0xd2,
		0xcb, 0x62, 0x3f, 0x56, 0xdd, 0xe0, 0x9b, 0x4a, 0x26, 0x0f, 0x8a, 0xc9, 0xe0, 0x64, 0xf4, 0x67,
		0xe3, 0x9f, 0xc5, 0xd1, 0xab, 0x0a, 0xb4, 0xd8, 0x85, 0x24, 0x8d, 0x07, 0xed, 0x34, 0x9a, 0xc4,
		0x94, 0x83, 0xd9, 0x5d, 0xde, 0x1f, 0xdf, 0xc1, 0xda, 0xe4, 0x06, 0xb6, 0x6e, 0xfd, 0x9e, 0xdc,
		0x7e, 0xa2, 0x75, 0x38, 0xbd, 0xc3, 0xb3, 0x47, 0xad, 0x5a, 0x12, 0x24, 0xad, 0xfa, 0xe8, 0x0e,
		0x8f, 0x7f, 0xb4, 0xea, 0x41, 0xf4, 0xf5, 0x68, 0x78, 0x2b, 0xf6, 0x26, 0xf7, 0xb7, 0x55, 0x4f,
		0xfa, 0xad, 0x66, 0x78, 0x91, 0x0c, 0xbf, 0xb5, 0xaa, 0x93, 0xfb, 0x5b, 0xeb, 0x5f, 0x94, 0x1b,
		0x37, 0xee, 0x6e, 0xeb, 0x70, 0x72, 0x77, 0x27, 0x0f, 0x5a, 0x47, 0xe3, 0xbb, 0x3b, 0xf9, 0xd9,
		0x1a, 0xbd, 0xa4, 0xac, 0x80, 0x27, 0x87, 0x7c, 0x04, 0x11, 0x4f, 0x21, 0xf5, 0x4f, 0xc5, 0xb1,
		0xcd, 0x4c, 0x50, 0x0d, 0x07, 0x27, 0x8c, 0xa4, 0x7f, 0x0b, 0xa2, 0x4e, 0x61, 0x67, 0xa5, 0x24,
		0x6c, 0x58, 0x6f, 0x47, 0x14, 0x51, 0xd8, 0x59, 0x59, 0x13, 0x36, 0xb0, 0x31, 0x3d, 0xc8, 0x0c,
		0x68, 0x53, 0x98, 0xf5, 0xda, 0xde, 0x30, 0xf4, 0x48, 0x0c, 0x06, 0x47, 0xbd, 0x41, 0xdc, 0x56,
		0x22, 0x6f, 0xdf, 0x78, 0x3a, 0xa8, 0xcb, 0xbf, 0x7a, 0xf1, 0x70, 0x46, 0x14, 0xc6, 0x61, 0x56,
		0x68, 0xd2, 0xba, 0xf0, 0xab, 0x9f, 0x54, 0xe2, 0xd3, 0xc1, 0xb9, 0x8a, 0xd2, 0xc2, 0xce, 0x4a,
		0x1a, 0x0f, 0x94, 0xd0, 0x81, 0xde, 0x18, 0xe5, 0x0c, 0x98, 0x08, 0x79, 0xa7, 0x84, 0xfc, 0x5e,
		0x10, 0x0b, 0x55, 0xf0, 0x23, 0x55, 0x26, 0x96, 0x4c, 0xa6, 0x7c, 0x2c, 0x55, 0x9a, 0x0b, 0x16,
		0x00, 0xe2, 0x85, 0x80, 0x0b, 0x82, 0xc0, 0x21, 0x61, 0xe0, 0x8a, 0x40, 0x70, 0x4e, 0x28, 0x38,
		0x27, 0x18, 0xdc, 0x12, 0x0e, 0x32, 0x05, 0x84, 0x50, 0x21, 0x21, 0x5e, 0x50, 0xdc, 0xcc, 0x22,
		0xbc, 0x5e, 0x97, 0x4f, 0x42, 0x37, 0xf2, 0x0a, 0xaf, 0xd7, 0xa5, 0x13, 0xd0, 0x44, 0x68, 0xac,
		0x09, 0x1f, 0xa6, 0x74, 0xc1, 0xe1, 0x92, 0xf0, 0x70, 0x50, 0x80, 0xb8, 0x26, 0x44, 0x9c, 0x15,
		0x24, 0xce, 0x0a, 0x13, 0x37, 0x05, 0x8a, 0x6c, 0xa1, 0x22, 0x5c, 0xb0, 0xcc, 0x3e, 0xf2, 0xe6,
		0x65, 0x5f, 0xb9, 0xc5, 0xb8, 0x83, 0x20, 0x4a, 0xc5, 0x6b, 0x83, 0x9b, 0xfa, 0x60, 0xcb, 0x81,
		0xa1, 0x36, 0xfc, 0xe8, 0x54, 0x39, 0x53, 0x20, 0xec, 0x4e, 0xc9, 0x67, 0xe1, 0x43, 0x10, 0x39,
		0x13, 0x71, 0x1d, 0x13, 0xb6, 0x0b, 0xc3, 0x1e, 0x95, 0xb9, 0x3b, 0x38, 0xee, 0x77, 0xb1, 0xdf,
		0x4e, 0x83, 0x5e, 0xb4, 0x17, 0x9c, 0x06, 0x69, 0x32, 0x7c, 0x03, 0xd4, 0x89, 0xeb, 0x98, 0x8a,
		0xfe, 0x37, 0xa6, 0xa2, 0xe1, 0xa9, 0x58, 0x5e, 0xdf, 0x2e, 0x6f, 0x6f, 0x6e, 0xad, 0x6f, 0x6f,
		0x30, 0x27, 0x11, 0xc4, 0x6e, 0x8d, 0xf2, 0x18, 0x63, 0xf1, 0x8c, 0x09, 0x54, 0x0f, 0x92, 0xb4,
		0x92, 0xa6, 0xb1, 0x1b, 0xe6, 0xe2, 0x43, 0x10, 0x55, 0x43, 0x35, 0xf4, 0xbe, 0x89, 0x1b, 0x6c,
		0x3b, 0x8c, 0x66, 0x37, 0x46, 0x5c, 0x7a, 0x53, 0x2e, 0x6f, 0x6e, 0x95, 0xcb, 0x6b, 0x5b, 0xaf,
		0xb7, 0xd6, 0xb6, 0x37, 0x36, 0x4a, 0x9b, 0x25, 0x07, 0x18, 0xb7, 0x70, 0x10, 0x77, 0x54, 0xac,
		0x3a, 0xbb, 0x97, 0x85, 0x9d, 0x95, 0x68, 0x10, 0x86, 0x2f, 0x60, 0xac, 0xfc, 0x8c, 0x4c, 0xea,
		0x5a, 0x8d, 0xf0, 0x2a, 0xee, 0xd9, 0x38, 0xf3, 0x55, 0xcd, 0x9d, 0xfa, 0xa7, 0x45, 0xc9, 0x65,
		0x23, 0x2b, 0xb9, 0xa9, 0xec, 0x6e, 0xfa, 0xa7, 0x12, 0xab, 0xbb, 0xe5, 0x92, 0x15, 0xb5, 0x72,
		0x0e, 0xd3, 0x65, 0xfe, 0x68, 0x92, 0x2d, 0x2f, 0xfa, 0x88, 0x91, 0x0d, 0x2f, 0xe2, 0x49, 0xa7,
		0x90, 0xfa, 0xa7, 0x9b, 0x65, 0xd1, 0x5b, 0x5e, 0x36, 0xcb, 0x6c, 0x7a, 0x79, 0xd0, 0xb0, 0xd8,
		0xf4, 0xf2, 0x0c, 0xa0, 0xb1, 0xe9, 0xe5, 0xe9, 0xd3, 0x81, 0x4d, 0x2f, 0x59, 0xab, 0x40, 0x36,
		0xbd, 0xb8, 0x2e, 0xe4, 0xd9, 0xf4, 0xf2, 0x3c, 0x3e, 0x66, 0xd3, 0x4b, 0xfe, 0x84, 0x80, 0x0b,
		0x82, 0xc0, 0x21, 0x61, 0xe0, 0x8a, 0x40, 0x70, 0x4e, 0x28, 0x38, 0x27, 0x18, 0xdc, 0x12, 0x0e,
		0x32, 0x05, 0x84, 0x50, 0x21, 0x21, 0x5e, 0x50, 0x08, 0xcf, 0x24, 0x38, 0x95, 0x59, 0xb8, 0x4f,
		0x68, 0xb0, 0xe9, 0x65, 0x79, 0x84, 0x87, 0x83, 0x02, 0xc4, 0x35, 0x21, 0xe2, 0xac, 0x20, 0x71,
		0x56, 0x98, 0xb8, 0x29, 0x50, 0x64, 0x0b, 0x15, 0xe1, 0x82, 0x65, 0xf6, 0x91, 0xbb, 0xb9, 0xe9,
		0x45, 0xbc, 0x36, 0xb8, 0xa9, 0x0f, 0xde, 0xb0, 0xe9, 0x25, 0xe3, 0x2f, 0x36, 0xbd, 0x20, 0x6c,
		0xef, 0x18, 0x36, 0x9b, 0x5e, 0x08, 0x6f, 0x3f, 0x9a, 0x8a, 0x6c, 0x7a, 0x31, 0x3e, 0x15, 0xdd,
		0x2c, 0xc6, 0xce, 0xcd, 0xec, 0x64, 0xfb, 0x4b, 0x26, 0x5f, 0x6c, 0x7f, 0x79, 0xce, 0x04, 0x62,
		0xfb, 0x8b, 0xf6, 0xb8, 0xc6, 0xf6, 0x17, 0x18, 0x4b, 0xf0, 0xc8, 0xd8, 0xfe, 0xf2, 0xbc, 0x71,
		0xe6, 0xae, 0xae, 0x7b, 0xb3, 0xcc, 0x06, 0x18, 0x53, 0x75, 0xde, 0x9b, 0x65, 0xb6, 0xc0, 0xb8,
		0x3b, 0x22, 0xb6, 0xc0, 0x2c, 0x3d, 0x55, 0xb2, 0x09, 0x46, 0x27, 0x39, 0xb2, 0x0d, 0x46, 0x3c,
		0xf1, 0x14, 0x52, 0x89, 0x8b, 0x54, 0xd7, 0xb5, 0x2a, 0xc3, 0xd1, 0xc9, 0xdc, 0x04, 0xb3, 0xc6,
		0x26, 0x98, 0x87, 0x0d, 0x8c, 0x4d, 0x30, 0xcf, 0x1a, 0x22, 0x9b, 0x60, 0x32, 0x1a, 0x28, 0x9b,
		0x60, 0x90, 0xf2, 0xa6, 0x3e, 0x42, 0xb1, 0xa5, 0x1f, 0x33, 0xc6, 0x0b, 0x95, 0xdf, 0x8d, 0x55,
		0x57, 0x22, 0xe3, 0x4d, 0x37, 0x99, 0x08, 0xec, 0x68, 0x5a, 0x38, 0x9c, 0xb8, 0x9f, 0x57, 0xaf,
		0xc6, 0x59, 0x96, 0xe2, 0x48, 0xa1, 0xa0, 0x73, 0x05, 0x8f, 0x44, 0x08, 0x37, 0x0c, 0x03, 0xa5,
		0x30, 0x49, 0x2b, 0x73, 0xf9, 0x48, 0xee, 0x32, 0x91, 0x53, 0xcb, 0x41, 0x32, 0x97, 0x7d, 0xa4,
		0x4c, 0x46, 0xa1, 0xb9, 0xb6, 0x7c, 0xe5, 0xd8, 0x04, 0x89, 0x8b, 0x5c, 0x64, 0xd5, 0x64, 0xe8,
		0x0c, 0xfb, 0x51, 0xdd, 0xee, 0x08, 0x2c, 0x53, 0x98, 0x34, 0xea, 0xca, 0x09, 0x65, 0x09, 0xe0,
		0x2a, 0xb7, 0x39, 0xca, 0x2e, 0x39, 0xd9, 0xa3, 0x04, 0x8b, 0x74, 0x50, 0x18, 0x44, 0x1d, 0xd5,
		0x0d, 0x22, 0xd5, 0xf1, 0xa6, 0x28, 0xb6, 0xcd, 0x08, 0xd7, 0x5b, 0x49, 0x16, 0x86, 0x66, 0x99,
		0x36, 0x65, 0xb4, 0xae, 0x10, 0x93, 0xa6, 0x97, 0x94, 0x96, 0x17, 0x98, 0x86, 0x97, 0x96, 0x76,
		0x17, 0x9b, 0x66, 0x17, 0x9b, 0x56, 0x97, 0x99, 0x46, 0x5f, 0x6e, 0xe9, 0x2a, 0xa5, 0x95, 0xc3,
		0x42, 0x74, 0x92, 0x33, 0xcf, 0xef, 0x8b, 0x9f, 0x52, 0xa6, 0xbb, 0xac, 0x0e, 0x50, 0xe2, 0x56,
		0xbd, 0x25, 0xae, 0x76, 0x0b, 0x5e, 0xe5, 0x96, 0xba, 0xba, 0x2d, 0x7e, 0x55, 0x5b, 0xfc, 0x6a,
		0xb6, 0xec, 0x55, 0x6c, 0x56, 0xa6, 0x24, 0x86, 0xe5, 0x1b, 0x89, 0x10, 0x89, 0xad, 0x1a, 0x45,
		0xb7, 0x68, 0xa4, 0x37, 0xb3, 0xfb, 0x81, 0xda, 0x81, 0x80, 0x2d, 0x3d, 0x70, 0x3b, 0x13, 0xc0,
		0x9d, 0x09, 0xe4, 0x6e, 0x04, 0x74, 0x59, 0x81, 0x5d, 0x58, 0x80, 0x17, 0x1b, 0xe8, 0x67, 0x03,
		0x0b, 0x55, 0x74, 0x3a, 0x5a, 0x3f, 0x12, 0xde, 0x9c, 0x79, 0x32, 0x4e, 0xd9, 0xdd, 0x99, 0xd7,
		0xe8, 0xce, 0x9c, 0x3b, 0x49, 0xe0, 0x90, 0x34, 0x70, 0x45, 0x22, 0x38, 0x27, 0x15, 0x9c, 0x93,
		0x0c, 0x6e, 0x49, 0x07, 0x99, 0x12, 0x42, 0xa8, 0x94, 0x98, 0x7d, 0xb4, 0xe2, 0x9b, 0x1c, 0xce,
		0x35, 0x37, 0x7c, 0x23, 0x99, 0x2f, 0x27, 0xe1, 0x5b, 0x70, 0x4b, 0x11, 0x47, 0x7a, 0x19, 0xba,
		0xd1, 0x0a, 0xc7, 0xa1, 0x6e, 0xc1, 0x4e, 0x35, 0x4a, 0x73, 0xad, 0x57, 0xa1, 0x8b, 0x5d, 0xd0,
		0xae, 0xdc, 0xe8, 0xdd, 0xc4, 0x14, 0xd3, 0x3c, 0xc5, 0xd6, 0x37, 0x36, 0x98, 0x64, 0xcb, 0x25,
		0x44, 0xe5, 0x8f, 0xee, 0x98, 0x6e, 0x3c, 0xae, 0x92, 0xb8, 0xcc, 0x76, 0x14, 0x0b, 0x56, 0x42,
		0x60, 0x5b, 0x0a, 0x47, 0x22, 0x09, 0x49, 0xc0, 0x2c, 0x71, 0x48, 0x12, 0x30, 0xbb, 0x69, 0x43,
		0x12, 0x50, 0xf3, 0x80, 0x49, 0x02, 0xe6, 0xd5, 0x76, 0x91, 0x04, 0xcc, 0x3c, 0x7c, 0x93, 0x04,
		0x7c, 0xee, 0x17, 0x49, 0x40, 0x32, 0x14, 0x24, 0x01, 0x97, 0x30, 0x1a, 0xcd, 0x4f, 0x31, 0x92,
		0x80, 0xda, 0xa7, 0x18, 0x49, 0xc0, 0xa5, 0x13, 0xa2, 0xf2, 0x47, 0x47, 0x12, 0xd0, 0x59, 0x12,
		0x2f, 0x5c, 0x4c, 0x88, 0x45, 0x78, 0x16, 0x70, 0x3c, 0x4c, 0xd2, 0x80, 0x4f, 0x19, 0x1e, 0x69,
		0xc0, 0x0c, 0x81, 0x48, 0x1a, 0x30, 0xbb, 0x69, 0x43, 0x1a, 0x50, 0xf3, 0x80, 0x49, 0x03, 0xe6,
		0xd5, 0x78, 0x39, 0x94, 0x06, 0x3c, 0x09, 0x22, 0x3f, 0xbe, 0x74, 0x20, 0x0f, 0xb8, 0x8d, 0x8c,
		0x75, 0x70, 0x44, 0x9c, 0x2c, 0xf3, 0xb8, 0xf1, 0x39, 0xde, 0x42, 0x6e, 0xa1, 0xd7, 0xd5, 0xc2,
		0x33, 0x62, 0x8f, 0xe4, 0x72, 0xb4, 0xe7, 0xdc, 0xc7, 0xe9, 0xfd, 0x9d, 0x36, 0xc8, 0xbc, 0xf5,
		0x84, 0xc4, 0x63, 0xb9, 0x38, 0x7f, 0xe6, 0x2e, 0xfc, 0x71, 0xfe, 0x4c, 0x3e, 0x9c, 0x3d, 0x1b,
		0xfd, 0xf3, 0xe9, 0xe0, 0xd9, 0xe8, 0xbf, 0x6c, 0x4e, 0x9d, 0x8d, 0xfe, 0xee, 0x0b, 0x7e, 0xce,
		0x9f, 0x79, 0x7e, 0x80, 0xe5, 0xfc, 0x19, 0xe7, 0x75, 0x2e, 0x5d, 0xbe, 0xe6, 0x03, 0x25, 0xe7,
		0xcf, 0x3c, 0x64, 0x54, 0x9c, 0x3f, 0x93, 0xc9, 0x60, 0x39, 0x7f, 0xe6, 0x47, 0x1a, 0x8b, 0xf3,
		0x67, 0xec, 0x64, 0xe2, 0x38, 0x93, 0x46, 0x77, 0xee, 0x8d, 0x53, 0x6a, 0x24, 0x8c, 0x80, 0x53,
		0x6a, 0xf2, 0x4d, 0x6c, 0x9c, 0x57, 0x93, 0x15, 0x7f, 0x2d, 0xed, 0xc1, 0x35, 0x2f, 0x96, 0x88,
		0x97, 0xa6, 0xee, 0xc7, 0x6a, 0x8a, 0x50, 0x86, 0xdf, 0x91, 0xe3, 0x6f, 0x44, 0xfb, 0x19, 0x19,
		0xfe, 0xc5, 0xd6, 0x74, 0x11, 0x12, 0xbe, 0x1d, 0x0f, 0xdb, 0x16, 0x83, 0xb4, 0x9b, 0xc1, 0xd9,
		0x4e, 0x2c, 0x36, 0x1f, 0x09, 0xcd, 0x5e, 0xd1, 0x30, 0x89, 0xd8, 0x26, 0x0f, 0x57, 0x49, 0xc3,
		0x02, 0x5b, 0x38, 0xc6, 0x12, 0x66, 0xe9, 0xc1, 0xdc, 0x24, 0x35, 0x73, 0x25, 0x43, 0x34, 0x60,
		0x6b, 0xfa, 0x3b, 0x36, 0xed, 0x0d, 0xce, 0x76, 0x37, 0x66, 0xb9, 0x99, 0xc9, 0xad, 0x7f, 0xaa,
		0x19, 0x98, 0x66, 0x85, 0x6b, 0x58, 0x25, 0xf3, 0xa0, 0x32, 0x35, 0xe1, 0x66, 0xeb, 0xf8, 0xf7,
		0x8e, 0xc4, 0x10, 0xd9, 0x98, 0x3d, 0xf6, 0xc6, 0x78, 0x95, 0x9b, 0x8d, 0xea, 0x35, 0x8b, 0x55,
		0x69, 0xb6, 0xaa, 0xcd, 0xac, 0x57, 0x91, 0x59, 0xaf, 0x0e, 0xb3, 0x5b, 0xf5, 0x95, 0x2f, 0x01,
		0x64, 0xfa, 0x98, 0x95, 0x42, 0xa4, 0x82, 0xd3, 0xb3, 0x93, 0x5e, 0x6c, 0xfe, 0xfc, 0xef, 0x19,
		0x57, 0x5c, 0x0f, 0xc1, 0x30, 0x6e, 0xed, 0x9c, 0x7b, 0x66, 0xad, 0xdc, 0xd9, 0x66, 0x39, 0xb3,
		0x80, 0x72, 0x65, 0xdb, 0xe5, 0xc8, 0x62, 0xca, 0x8d, 0xc5, 0x94, 0x13, 0xcb, 0x28, 0x17, 0xce,
		0x77, 0x42, 0xcd, 0xd6, 0xb9, 0x5d, 0x33, 0x56, 0xb7, 0x37, 0xdf, 0x6e, 0xc7, 0x17, 0x5b, 0xd3,
		0xcd, 0xee, 0xf1, 0x9a, 0xd6, 0x77, 0xd7, 0x48, 0xd8, 0x45, 0x23, 0x68, 0xb7, 0x8c, 0x94, 0x5d,
		0x31, 0xe2, 0x76, 0xbf, 0x88, 0xdb, 0xe5, 0x22, 0x6b, 0x37, 0xcb, 0x72, 0xd5, 0x5c, 0xd8, 0x3e,
		0x6e, 0xb2, 0x30, 0x4b, 0xef, 0xda, 0x9f, 0xa8, 0x53, 0xee, 0xba, 0x1e, 0x92, 0xe5, 0x79, 0x21,
		0xe3, 0xbc, 0x68, 0x31, 0xdb, 0x46, 0x25, 0x6d, 0x13, 0x15, 0xb8, 0x2d, 0x54, 0xda, 0x36, 0x50,
		0xb1, 0xdb, 0x3e, 0xc5, 0x6e, 0xf3, 0x94, 0xb9, 0xad, 0x73, 0xb9, 0x8b, 0xa4, 0xa5, 0x9c, 0xc7,
		0x3c, 0x8b, 0x4a, 0x72, 0xe6, 0xf7, 0xed, 0x78, 0x29, 0x65, 0x7a, 0xcb, 0x08, 0x9b, 0xe2, 0xc2,
		0xa7, 0xc4, 0x30, 0x2a, 0x38, 0x9c, 0x4a, 0x0d, 0xab, 0xe2, 0xc3, 0xab, 0xf8, 0x30, 0x2b, 0x3b,
		0xdc, 0xca, 0x08, 0xbb, 0x42, 0xc2, 0xaf, 0xb8, 0x30, 0x7c, 0x1d, 0x8e, 0x3b, 0x72, 0x5b, 0x22,
		0x05, 0x1d, 0x1a, 0x22, 0x39, 0x19, 0x9a, 0x25, 0x87, 0x68, 0x07, 0x42, 0xb5, 0xf4, 0x90, 0xed,
		0x4c, 0xe8, 0x76, 0x26, 0x84, 0xbb, 0x11, 0xca, 0x65, 0x85, 0x74, 0x61, 0xa1, 0x7d, 0xf6, 0x11,
		0xd2, 0x10, 0x29, 0x03, 0xcf, 0xeb, 0x44, 0x43, 0xa4, 0xa0, 0x43, 0x3b, 0x24, 0xf1, 0x73, 0xb2,
		0x30, 0xee, 0x87, 0x2b, 0x56, 0xe4, 0x4a, 0x6c, 0xd7, 0x2b, 0x2c, 0xf5, 0x84, 0xce, 0x45, 0xe7,
		0xa2, 0x73, 0xd1, 0xb9, 0xe8, 0x5c, 0x49, 0x1f, 0xa1, 0xb4, 0x54, 0xd6, 0x6c, 0x60, 0x02, 0x53,
		0x5a, 0x0b, 0x64, 0x2c, 0x2e, 0xb5, 0x75, 0x3b, 0xf4, 0x73, 0x9a, 0x57, 0xfe, 0xa4, 0x80, 0x43,
		0x92, 0xc0, 0x15, 0x69, 0xe0, 0x9c, 0x44, 0x70, 0x4e, 0x2a, 0xb8, 0x25, 0x19, 0x64, 0x4a, 0x07,
		0xa1, 0x12, 0x62, 0xf6, 0xd1, 0xba, 0x75, 0xa8, 0xff, 0x66, 0xd9, 0x81, 0xd3, 0xbc, 0xde, 0x70,
		0xaa, 0xff, 0x33, 0xbf, 0x38, 0xd5, 0x7f, 0x99, 0x84, 0xe5, 0xc2, 0x70, 0x39, 0xd5, 0x7f, 0x59,
		0xc3, 0xd1, 0xfc, 0x14, 0xe3, 0x54, 0x7f, 0xed, 0x53, 0x4c, 0x76, 0x77, 0xf9, 0xdc, 0xcd, 0x3a,
		0x8e, 0xf9, 0x7f, 0xd2, 0x17, 0xc7, 0xfc, 0x3b, 0xcb, 0xea, 0x85, 0x73, 0x95, 0xc6, 0x41, 0x5b,
		0x7e, 0x5a, 0x70, 0x32, 0x4e, 0x52, 0x83, 0x4f, 0x19, 0x1e, 0xa9, 0xc1, 0x0c, 0x91, 0x48, 0x6a,
		0x30, 0xbb, 0x69, 0x43, 0x6a, 0x50, 0xf3, 0x80, 0x49, 0x0d, 0xe6, 0xd5, 0x8b, 0x39, 0x94, 0x1a,
		0xfc, 0x2b, 0xe8, 0x28, 0x4f, 0x74, 0x00, 0xbf, 0x19, 0xc4, 0xb7, 0xc8, 0x0f, 0x3e, 0xf3, 0x8b,
		0xfc, 0x20, 0xc9, 0x0b, 0x79, 0x35, 0x72, 0xb9, 0xca, 0x54, 0x90, 0x1f, 0x64, 0x8a, 0x0d, 0xa7,
		0xd8, 0xe6, 0xd6, 0xd6, 0xd6, 0x3a, 0x39, 0xc1, 0x65, 0xd3, 0xa4, 0xf2, 0x47, 0x47, 0x4e, 0xd0,
		0xc5, 0x11, 0x49, 0xab, 0xa4, 0x14, 0x7a, 0x42, 0xeb, 0x6c, 0x7c, 0xb2, 0x4f, 0x3b, 0x98, 0x6f,
		0x06, 0x5f, 0x9c, 0x75, 0x07, 0x9e, 0x3d, 0x2a, 0x5e, 0x0f, 0x66, 0x36, 0x08, 0x89, 0xbb, 0x2e,
		0x56, 0xe4, 0x9e, 0x9f, 0x90, 0xcc, 0x9d, 0x91, 0xb2, 0x3f, 0xbd, 0xc5, 0xb3, 0x47, 0xad, 0xeb,
		0x71, 0xcc, 0x06, 0x30, 0x7a, 0x5d, 0x36, 0x48, 0x89, 0xa7, 0xa0, 0xc2, 0xf4, 0x98, 0x4f, 0xb9,
		0x5b, 0xa4, 0xc4, 0x9c, 0x43, 0x7a, 0x97, 0x9a, 0x66, 0x93, 0xd4, 0x03, 0x07, 0xc6, 0x26, 0xa9,
		0x67, 0x0d, 0x91, 0x4d, 0x52, 0x19, 0x0d, 0x94, 0x4d, 0x52, 0x48, 0x7b, 0x53, 0x1f, 0xa1, 0xd8,
		0x4d, 0x52, 0xe3, 0x98, 0x2a, 0xbf, 0x22, 0x62, 0x32, 0x4e, 0xd9, 0x15, 0x11, 0x25, 0x2a, 0x22,
		0x72, 0x27, 0x09, 0x1c, 0x92, 0x06, 0xae, 0x48, 0x04, 0xe7, 0xa4, 0x82, 0x73, 0x92, 0xc1, 0x2d,
		0xe9, 0x20, 0x53, 0x42, 0x08, 0x95, 0x12, 0xe2, 0x25, 0xc5, 0x6c, 0x80, 0x7e, 0xe7, 0xbf, 0x7e,
		0x5b, 0x45, 0xed, 0x4b, 0x2f, 0x09, 0x3a, 0x89, 0x7c, 0x36, 0x9a, 0x12, 0xfc, 0xad, 0x71, 0x0b,
		0x9f, 0xe1, 0xb2, 0xa5, 0x87, 0x33, 0x12, 0xc4, 0x25, 0x29, 0xe2, 0xa0, 0x24, 0x71, 0x4d, 0x9a,
		0x38, 0x2b, 0x51, 0x9c, 0x95, 0x2a, 0x6e, 0x4a, 0x16, 0xd9, 0xd2, 0x45, 0xb8, 0x84, 0x71, 0x46,
		0xca, 0xdc, 0x2d, 0x69, 0xdc, 0x21, 0xb1, 0x3b, 0x95, 0x8d, 0x2b, 0x44, 0xe6, 0x86, 0xc0, 0x71,
		0x4e, 0xe8, 0xb8, 0x28, 0x78, 0x1c, 0x16, 0x3e, 0xae, 0x0a, 0x20, 0xe7, 0x85, 0x90, 0xf3, 0x82,
		0xc8, 0x6d, 0x61, 0xe4, 0x86, 0x40, 0x72, 0x44, 0x28, 0x39, 0x27, 0x98, 0x66, 0x03, 0x96, 0xd9,
		0x7c, 0xf7, 0xc1, 0x71, 0x46, 0x6a, 0x99, 0x58, 0x8e, 0x84, 0x93, 0xb3, 0x02, 0xca, 0x65, 0x21,
		0x95, 0x03, 0x41, 0xe5, 0xba, 0xb0, 0xca, 0x8d, 0xc0, 0xca, 0x8d, 0xd0, 0xca, 0x87, 0xe0, 0x72,
		0x4b, 0x78, 0x39, 0x26, 0xc0, 0x9c, 0x15, 0x62, 0xb3, 0x81, 0x77, 0x43, 0xff, 0x34, 0x71, 0x97,
		0x2c, 0xa7, 0xf1, 0x6a, 0xfc, 0x36, 0x1c, 0xe5, 0x17, 0xb7, 0xb6, 0xe1, 0xe5, 0x46, 0xa8, 0xe5,
		0x41, 0xb0, 0xe5, 0x48, 0xb8, 0xe5, 0x45, 0xc0, 0xe5, 0x4e, 0xc8, 0xe5, 0x4e, 0xd0, 0xe5, 0x4b,
		0xd8, 0xb9, 0x29, 0xf0, 0x1c, 0x15, 0x7a, 0x33, 0xe8, 0x88, 0xef, 0x43, 0xf3, 0xe0, 0x88, 0xa1,
		0xa2, 0xc1, 0xb9, 0x8a, 0xc7, 0xdb, 0x4d, 0x1d, 0x8e, 0x1a, 0xd3, 0x2c, 0x57, 0xd9, 0xe1, 0xf7,
		0x50, 0x8d, 0x06, 0xe7, 0x43, 0x50, 0x31, 0x95, 0x4d, 0xde, 0xf5, 0x7a, 0x90, 0xa4, 0x95, 0x34,
		0x8d, 0xdd, 0x9e, 0xce, 0x1f, 0x82, 0xa8, 0x1a, 0xaa, 0x61, 0x34, 0x4b, 0xdc, 0x95, 0xe2, 0x2b,
		0x93, 0x16, 0x2a, 0x37, 0xde, 0x89, 0xbb, 0xcd, 0x80, 0xef, 0x7c, 0x73, 0x07, 0x71, 0x47, 0xc5,
		0xaa, 0xb3, 0x7b, 0x59, 0xd8, 0x59, 0x89, 0x06, 0x61, 0xf8, 0x02, 0xa9, 0x01, 0x37, 0xdd, 0x0d,
		0x95, 0x8b, 0x49, 0xbb, 0x1b, 0xc7, 0x53, 0x33, 0xe3, 0xb7, 0x41, 0x6a, 0xc6, 0xc6, 0xf0, 0x49,
		0xcd, 0x08, 0x9a, 0x08, 0xa4, 0x66, 0xe4, 0x4c, 0x6b, 0x52, 0x33, 0xc2, 0xdf, 0x10, 0xa9, 0x19,
		0x34, 0xd3, 0x13, 0xa1, 0x93, 0x9f, 0xd4, 0xcc, 0x20, 0x88, 0xd2, 0xd7, 0xeb, 0x39, 0xc8, 0xca,
		0x6c, 0x39, 0xfc, 0x16, 0xdc, 0xe8, 0x3e, 0xfc, 0xb3, 0x2f, 0xb7, 0x03, 0xf6, 0x8a, 0x6b, 0xdd,
		0x8b, 0x73, 0x6e, 0x2c, 0x16, 0xde, 0x8e, 0x63, 0xa7, 0xa3, 0xfd, 0xf4, 0xfd, 0x38, 0xd8, 0xb3,
		0x35, 0xa7, 0xe1, 0x7c, 0x9e, 0x02, 0xfc, 0x6f, 0x50, 0x80, 0x70, 0x0a, 0x28, 0xaf, 0x6f, 0x97,
		0xb7, 0x37, 0xb7, 0xd6, 0xb7, 0x37, 0xe0, 0x02, 0x0c, 0x09, 0xa3, 0xbf, 0xf9, 0x75, 0x4c, 0xba,
		0x9f, 0x58, 0x77, 0x0f, 0xcd, 0xfc, 0xa5, 0x82, 0xd3, 0xb3, 0xd4, 0xfd, 0x7c, 0xff, 0xe4, 0x7d,
		0x90, 0xf0, 0xb7, 0x31, 0x7c, 0x12, 0xfe, 0x82, 0x66, 0x02, 0x09, 0x7f, 0x39, 0xd3, 0x9a, 0x84,
		0xbf, 0xf0, 0x37, 0x44, 0xc2, 0x1f, 0xd5, 0xf4, 0x44, 0xe8, 0xe4, 0x2b, 0xe1, 0xff, 0x26, 0x07,
		0xf9, 0xfe, 0x0d, 0xf2, 0xfd, 0x96, 0xbf, 0xc8, 0xf7, 0xe3, 0x2b, 0x34, 0xbe, 0x1d, 0xf2, 0xfd,
		0x44, 0x73, 0x13, 0x14, 0x40, 0xbe, 0x5f, 0x3c, 0x05, 0xac, 0x6f, 0x90, 0xe8, 0xc7, 0x88, 0x30,
		0xfa, 0xb9, 0x2f, 0x12, 0xfd, 0x8c, 0xd8, 0xf9, 0x90, 0x2c, 0xfd, 0x20, 0xca, 0x9f, 0x8e, 0x3f,
		0x8f, 0x07, 0x55, 0x8e, 0xcf, 0xbe, 0x9b, 0xfc, 0x2c, 0xce, 0xf7, 0xa8, 0x9f, 0xff, 0xb5, 0xe8,
		0x62, 0xb7, 0xb2, 0x95, 0x9c, 0x1d, 0x7a, 0x39, 0xfe, 0xb8, 0x26, 0x3f, 0x5b, 0x95, 0xe9, 0xe7,
		0x73, 0x14, 0x74, 0x92, 0xb9, 0xdf, 0x24, 0x1e, 0x8f, 0x99, 0x1f, 0xf2, 0x75, 0x88, 0x78, 0x1d,
		0xdd, 0xf6, 0xe5, 0xf4, 0x76, 0x2f, 0x47, 0xad, 0x19, 0x2d, 0x12, 0x6d, 0x02, 0x9d, 0x16, 0x89,
		0xf6, 0xa6, 0x2b, 0x2d, 0x12, 0xa5, 0x39, 0x05, 0x5a, 0x24, 0xa2, 0x69, 0x7e, 0x0c, 0x11, 0x67,
		0x57, 0x69, 0x67, 0x8c, 0x1f, 0x2a, 0xbf, 0x1b, 0xab, 0xae, 0x8b, 0x8c, 0x3f, 0xed, 0x8e, 0xe3,
		0xe0, 0x46, 0xac, 0xc2, 0xe1, 0xc4, 0xbf, 0xbf, 0x7a, 0x35, 0x76, 0xb4, 0xc5, 0xb1, 0xc4, 0xc4,
		0x2a, 0x2d, 0xf1, 0x48, 0x5d, 0x69, 0xd0, 0xff, 0x9b, 0xba, 0x74, 0xcd, 0x14, 0xb9, 0xd9, 0x0f,
		0xc9, 0xdd, 0xfe, 0x47, 0xb9, 0xea, 0x77, 0xe4, 0x66, 0x7f, 0x23, 0x57, 0xd8, 0xc4, 0xd1, 0x7c,
		0xfc, 0x92, 0xe7, 0xe1, 0x5d, 0x3a, 0x95, 0x6a, 0x09, 0x33, 0xef, 0x6e, 0x08, 0xc9, 0x2b, 0x8e,
		0xbe, 0xcc, 0x33, 0xc5, 0xbb, 0x46, 0xed, 0x4b, 0x47, 0xe9, 0x2e, 0x9c, 0xa9, 0xbc, 0x1c, 0xe4,
		0x2d, 0x9b, 0xaf, 0xe5, 0xb2, 0xa0, 0x60, 0x06, 0x2c, 0xf8, 0x9d, 0xf3, 0x20, 0xf2, 0x4e, 0xe3,
		0xde, 0xa0, 0x2f, 0x9e, 0xfe, 0x6e, 0x9c, 0xa2, 0x7b, 0x3d, 0x68, 0xe1, 0xd1, 0xc5, 0x8d, 0x23,
		0xe0, 0x9c, 0x59, 0xcf, 0x74, 0x69, 0xfd, 0xd2, 0xc1, 0xf5, 0x4a, 0xd7, 0xd6, 0x27, 0x9d, 0x5d,
		0x8f, 0x74, 0x76, 0xfd, 0xd1, 0xcd, 0xf5, 0x46, 0x1c, 0xd2, 0x73, 0x3e, 0x72, 0x57, 0x8e, 0x58,
		0x73, 0xec, 0x8c, 0x5b, 0x27, 0xcf, 0xb6, 0x75, 0xec, 0x4c, 0x5b, 0xe7, 0x0a, 0xb5, 0x5c, 0x2c,
		0xd0, 0x72, 0xb8, 0x30, 0xcb, 0xd5, 0x82, 0x2c, 0xe7, 0x0b, 0xb1, 0x9c, 0x2f, 0xc0, 0x72, 0xbb,
		0xf0, 0x8a, 0x5a, 0x83, 0x65, 0x14, 0x48, 0xb3, 0x01, 0xbb, 0x94, 0xf5, 0xb9, 0x37, 0xda, 0xb8,
		0x93, 0x05, 0xba, 0x4f, 0x44, 0x51, 0xf5, 0x8e, 0xa8, 0xca, 0xb1, 0xb8, 0x72, 0x5d, 0x64, 0xe5,
		0x46, 0x6c, 0xe5, 0x46, 0x74, 0xe5, 0x43, 0x7c, 0xb9, 0x25, 0xc2, 0x1c, 0x13, 0x63, 0x33, 0x88,
		0xb8, 0x5f, 0xf5, 0xee, 0xec, 0x21, 0x24, 0x0e, 0x1f, 0x3e, 0xe2, 0x78, 0x13, 0x32, 0xb7, 0x8f,
		0x51, 0xcd, 0x41, 0xb7, 0xd3, 0x5c, 0x74, 0x1a, 0xca, 0x4b, 0x93, 0xb1, 0x3c, 0xf5, 0x15, 0xba,
		0x72, 0xfb, 0x5c, 0x61, 0xa6, 0xb6, 0xb0, 0xa9, 0x9d, 0x97, 0xc3, 0x42, 0x72, 0x35, 0xc7, 0xe9,
		0x5d, 0x65, 0xe4, 0xeb, 0x18, 0xe3, 0xa5, 0x71, 0x42, 0x3a, 0x7d, 0xaa, 0xbf, 0xfb, 0xa7, 0xf9,
		0xe7, 0xf2, 0x14, 0x7f, 0xb7, 0x4f, 0xef, 0x67, 0x0f, 0xf2, 0x52, 0x32, 0x22, 0xbb, 0x06, 0x05,
		0x6f, 0x31, 0x99, 0xad, 0x1d, 0x3a, 0xd7, 0xac, 0x2f, 0xcf, 0xbb, 0x4d, 0xce, 0x83, 0xe8, 0xfd,
		0xf0, 0x43, 0x71, 0xa9, 0x29, 0x1f, 0x1b, 0x04, 0x73, 0xcd, 0xe6, 0x6c, 0x10, 0x94, 0xcc, 0xde,
		0xec, 0x0e, 0x14, 0xc1, 0xd7, 0x6c, 0x0d, 0xcc, 0x1d, 0xf7, 0x15, 0xfc, 0x0b, 0x3f, 0x08, 0xfd,
		0x93, 0x50, 0x79, 0x27, 0x7e, 0xd4, 0xf9, 0x2b, 0xe8, 0x8c, 0x08, 0xc5, 0x95, 0x2d, 0x82, 0x77,
		0x0c, 0x9e, 0xad, 0x82, 0x59, 0x0c, 0x93, 0xad, 0x82, 0x1a, 0x61, 0xcb, 0x56, 0x41, 0x7d, 0xd3,
		0x8b, 0xad, 0x82, 0xa6, 0x85, 0x33, 0x5b, 0x05, 0x97, 0xcd, 0x2b, 0xb1, 0x55, 0x50, 0x6f, 0x7c,
		0x60, 0xab, 0x20, 0xc2, 0xc6, 0x45, 0x81, 0xe3, 0xb0, 0xd0, 0x71, 0x55, 0xf0, 0x38, 0x2f, 0x7c,
		0x9c, 0x17, 0x40, 0x6e, 0x0b, 0x21, 0x37, 0x04, 0x91, 0x23, 0xc2, 0xc8, 0x39, 0x81, 0x34, 0x1b,
		0xb0, 0x3b, 0xb9, 0x9f, 0x7b, 0x63, 0x8d, 0x2b, 0x19, 0xa0, 0xfb, 0x04, 0x14, 0xdb, 0x04, 0x11,
		0x54, 0x39, 0x16, 0x56, 0xae, 0x0b, 0xac, 0xdc, 0x08, 0xad, 0xdc, 0x08, 0xae, 0x7c, 0x08, 0x2f,
		0xb7, 0x04, 0x98, 0x63, 0x42, 0x6c, 0x06, 0x11, 0xf7, 0xb7, 0x09, 0x06, 0x4a, 0xa9, 0x6e, 0xd8,
		0xf3, 0xdd, 0xde, 0x2b, 0xb8, 0xed, 0xe0, 0xd0, 0xeb, 0x2a, 0x3a, 0x1d, 0x09, 0x63, 0x36, 0x0b,
		0x1a, 0xbe, 0xf3, 0x6c, 0x16, 0x94, 0xf3, 0x36, 0x66, 0x3b, 0x8a, 0xd8, 0x48, 0x44, 0x10, 0xce,
		0x60, 0x6a, 0xb3, 0x59, 0x90, 0xa9, 0xcd, 0xd4, 0xce, 0x87, 0x1b, 0x70, 0x77, 0xd4, 0xc7, 0xec,
		0x30, 0x5a, 0xf6, 0xd0, 0x54, 0x48, 0x5d, 0xf4, 0x86, 0x33, 0x5f, 0x38, 0x1a, 0x3d, 0x19, 0x6f,
		0x13, 0xc3, 0x26, 0xe3, 0x6d, 0x11, 0xe7, 0x64, 0xbc, 0xed, 0x4d, 0x57, 0x32, 0xde, 0xc2, 0xde,
		0x08, 0x19, 0x6f, 0x14, 0xcd, 0x4f, 0x20, 0x92, 0x83, 0x8c, 0x77, 0x47, 0x45, 0x69, 0x90, 0x5e,
		0x3a, 0x7e, 0x24, 0xbc, 0x8b, 0x7d, 0x18, 0x6a, 0x93, 0x5b, 0xbf, 0xeb, 0x27, 0x0e, 0xc7, 0xad,
		0x29, 0x90, 0x6a, 0x47, 0xb5, 0xa3, 0xd6, 0xd1, 0xc7, 0xdd, 0x66, 0xfd, 0x53, 0xab, 0xf9, 0xc7,
		0x61, 0xd5, 0xd5, 0xf0, 0x35, 0xca, 0xd3, 0x24, 0xce, 0x2e, 0x44, 0xac, 0x38, 0xbd, 0x18, 0x71,
		0x0b, 0x51, 0xad, 0x46, 0xb5, 0xf2, 0xf6, 0xd7, 0xca, 0x6e, 0xad, 0x5e, 0x6b, 0xfe, 0x31, 0x01,
		0xd7, 0x91, 0xcb, 0xe8, 0xca, 0x13, 0xca, 0xf2, 0x81, 0xb6, 0x9f, 0xa2, 0x6e, 0xb7, 0xb2, 0xbf,
		0xf7, 0xbf, 0xb5, 0xbd, 0xe6, 0xaf, 0xad, 0xb7, 0x07, 0xfb, 0x47, 0xcd, 0x46, 0xa5, 0xb6, 0xdf,
		0x3c, 0x2a, 0x38, 0xff, 0x9e, 0xaf, 0x7e, 0x01, 0x78, 0xb2, 0x81, 0xf7, 0xb1, 0x59, 0xab, 0xd7,
		0xfe, 0xaf, 0xba, 0x77, 0x8d, 0x40, 0x50, 0x07, 0xea, 0x74, 0xa3, 0xae, 0xb2, 0xf7, 0x9f, 0xd6,
		0x51, 0x6d, 0x0f, 0xa8, 0x01, 0x35, 0xed, 0x50, 0xfb, 0x54, 0xa9, 0xd5, 0x2b, 0xbb, 0xf5, 0x2a,
		0x0c, 0x07, 0xec, 0xcc, 0xc1, 0xae, 0x76, 0xf8, 0x69, 0xb3, 0xb5, 0x5f, 0xad, 0xbd, 0xff, 0x75,
		0xf7, 0xa0, 0xd1, 0xaa, 0xec, 0xed, 0x35, 0xaa, 0x47, 0x08, 0x3a, 0x80, 0xa7, 0x5f, 0xd0, 0xed,
		0xcf, 0x1c, 0x44, 0x75, 0xaf, 0x55, 0x3f, 0x3a, 0x04, 0x74, 0x80, 0x4e, 0x37, 0xe8, 0xea, 0xb5,
		0xfd, 0xdf, 0x5a, 0x95, 0x66, 0xb3, 0x51, 0xdb, 0xfd, 0xd8, 0xac, 0xc2, 0x73, 0x40, 0xce, 0x0c,
		0xe4, 0x0e, 0x1b, 0x07, 0xcd, 0xea, 0xdb, 0x66, 0xed, 0x60, 0x7f, 0x9c, 0xaf, 0x03, 0x77, 0xe0,
		0x4e, 0xbb, 0x75, 0xfd, 0x50, 0xdb, 0x6f, 0xbd, 0x6f, 0x1c, 0x7c, 0x24, 0xb2, 0x02, 0x37, 0x33,
		0x3e, 0xa2, 0xb6, 0xdf, 0xac, 0x36, 0xde, 0x55, 0xde, 0x56, 0x31, 0x12, 0x20, 0xcf, 0x14, 0xf2,
		0x3e, 0x54, 0x7e, 0x1f, 0x07, 0x59, 0xf2, 0x26, 0xa0, 0xce, 0x60, 0x78, 0xfd, 0x4f, 0xab, 0x5e,
		0xd9, 0x27, 0x3b, 0x0c, 0xdc, 0x8c, 0xb9, 0x08, 0xa0, 0x06, 0xd4, 0x8c, 0x28, 0xb9, 0x32, 0x19,
		0x61, 0x80, 0x67, 0x07, 0x78, 0x58, 0x08, 0x90, 0x67, 0xc5, 0x42, 0x34, 0xaa, 0x47, 0xd5, 0xc6,
		0x27, 0x16, 0x60, 0xc1, 0x9e, 0x59, 0xec, 0x35, 0xab, 0xad, 0xbd, 0xea, 0xbb, 0xca, 0xc7, 0x7a,
		0xb3, 0xf5, 0xa1, 0xda, 0x6c, 0xd4, 0xde, 0x02, 0x3a, 0x40, 0xa7, 0x1b, 0x74, 0x1f, 0xf7, 0xc7,
		0x74, 0x47, 0x3d, 0x1d, 0xb8, 0x33, 0x6e, 0x63, 0xf7, 0xaa, 0xf5, 0xca, 0x1f, 0xad, 0x4f, 0x95,
		0x46, 0xad, 0xd2, 0xac, 0x1d, 0xec, 0x83, 0x3b, 0x70, 0xa7, 0x1b, 0x77, 0xd5, 0xdf, 0x9b, 0xd5,
		0xfd, 0xbd, 0xea, 0x1e, 0xab, 0x62, 0xe0, 0xce, 0xa8, 0xb1, 0xa8, 0xed, 0x5f, 0xaf, 0x4f, 0x8c,
		0x78, 0x0f, 0xd4, 0x81, 0x3a, 0x23, 0x51, 0xb6, 0x7e, 0x40, 0xee, 0x04, 0xb0, 0x99, 0x94, 0x74,
		0xa0, 0x0d, 0xb4, 0xe9, 0x46, 0x5b, 0xa3, 0x7a, 0x54, 0xdb, 0xfb, 0x58, 0xa9, 0xe7, 0xca, 0xb6,
		0x3a, 0xfd, 0x0e, 0x8e, 0xe9, 0x65, 0xc9, 0x2c, 0xcf, 0x68, 0x76, 0xe7, 0x6c, 0x77, 0x31, 0x00,
		0x93, 0x06, 0xb0, 0x3c, 0xed, 0x22, 0x06, 0x5d, 0xd2, 0xd0, 0xe5, 0xfc, 0x6e, 0x61, 0x20, 0x25,
		0x0e, 0x52, 0x79, 0xda, 0x15, 0x0c, 0xbc, 0xa4, 0xc1, 0x2b, 0x67, 0xbb, 0x7f, 0x01, 0x98, 0x38,
		0xc1, 0x95, 0x9f, 0x5d, 0xbe, 0x80, 0x4b, 0x1a, 0xb8, 0x72, 0xb3, 0x9b, 0x17, 0x68, 0x89, 0x84,
		0x56, 0x6e, 0x76, 0xed, 0x82, 0x2f, 0x79, 0x56, 0x31, 0x07, 0x75, 0x08, 0xc0, 0x4a, 0xa4, 0x9e,
		0xcf, 0x51, 0x09, 0x3d, 0x08, 0x93, 0x86, 0xb0, 0x3c, 0xed, 0xb6, 0x05, 0x5d, 0xf2, 0xc2, 0x62,
		0x0e, 0x76, 0xd5, 0x02, 0x2b, 0x91, 0x6a, 0x1e, 0x48, 0x01, 0xa9, 0x4c, 0x95, 0x56, 0x99, 0xcc,
		0x29, 0x00, 0xd3, 0x0b, 0x30, 0xa4, 0x3c, 0x08, 0xd3, 0x2a, 0xe5, 0xf3, 0xb5, 0xeb, 0x15, 0x8c,
		0x49, 0xc3, 0x58, 0x8e, 0x76, 0xb7, 0x02, 0x2e, 0x69, 0xe0, 0xca, 0xd7, 0x2e, 0x56, 0xf0, 0x25,
		0xd2, 0x36, 0xe6, 0x66, 0xb7, 0x2a, 0xf8, 0x92, 0x86, 0xaf, 0x7c, 0xed, 0x4a, 0x05, 0x5f, 0xe2,
		0x04, 0x7e, 0x8e, 0x76, 0x9f, 0x82, 0x2e, 0x91, 0xd1, 0xd1, 0xed, 0x5d, 0xa6, 0x80, 0x4a, 0xae,
		0xe4, 0x02, 0x55, 0xa0, 0x2a, 0x2b, 0x54, 0xe5, 0x69, 0xd7, 0x28, 0xe8, 0xb2, 0x8e, 0xae, 0x43,
		0x4e, 0xe2, 0x05, 0x6d, 0xb6, 0x51, 0xd7, 0xac, 0xbc, 0xdf, 0x2c, 0xd3, 0x72, 0x01, 0xa0, 0xe9,
		0x06, 0xda, 0x61, 0xa3, 0xfa, 0xae, 0xf6, 0x3b, 0x8d, 0xee, 0x41, 0x9b, 0x09, 0xb4, 0x8d, 0x2a,
		0x58, 0x1b, 0x07, 0x1f, 0x9b, 0xd5, 0x06, 0xfd, 0xee, 0x41, 0x9c, 0x99, 0x40, 0x0a, 0xcc, 0x80,
		0x99, 0xa1, 0x30, 0xfa, 0xae, 0x5e, 0x79, 0x4f, 0x5f, 0x36, 0xf0, 0x66, 0x22, 0x90, 0x96, 0x73,
		0x15, 0x48, 0xe9, 0x92, 0xc5, 0x4c, 0x5f, 0xa6, 0x19, 0x9e, 0x57, 0xe7, 0x0f, 0xa0, 0x70, 0xf8,
		0xa0, 0x2a, 0xff, 0xa8, 0xca, 0x8b, 0x93, 0x07, 0x59, 0x38, 0x76, 0xe0, 0x94, 0xff, 0xf0, 0xe7,
		0xb8, 0x33, 0x07, 0x57, 0x38, 0x70, 0x90, 0x95, 0x4f, 0x64, 0x4d, 0x40, 0xf4, 0xb6, 0x72, 0x48,
		0xcd, 0x01, 0x78, 0xb3, 0x8a, 0xbb, 0x46, 0xab, 0x52, 0x7f, 0x7f, 0xd0, 0xa8, 0x35, 0x7f, 0xfd,
		0x40, 0x16, 0x1b, 0xc4, 0x19, 0x41, 0xdc, 0xf5, 0x6f, 0xa4, 0xb1, 0xed, 0x7e, 0x91, 0xc6, 0x66,
		0x8a, 0x13, 0x4c, 0x40, 0x16, 0x41, 0x83, 0x60, 0x91, 0xa3, 0x20, 0xe1, 0xd6, 0x7d, 0x76, 0x67,
		0xb4, 0x6e, 0x8c, 0xd4, 0x11, 0x02, 0x2f, 0x54, 0xa2, 0xa8, 0x97, 0xfa, 0x69, 0xd0, 0x8b, 0x0a,
		0x3b, 0x0e, 0x51, 0x77, 0x21, 0x69, 0x9f, 0xa9, 0x73, 0xbf, 0xef, 0xa7, 0x67, 0x43, 0xb2, 0x2e,
		0xf6, 0xfa, 0x2a, 0x6a, 0xf7, 0xa2, 0x6e, 0x70, 0xea, 0x45, 0x2a, 0xfd, 0xab, 0x17, 0x7f, 0xf5,
		0x82, 0x28, 0x49, 0xfd, 0xa8, 0xad, 0x8a, 0xb7, 0x9f, 0x48, 0x16, 0x9e, 0x29, 0xf6, 0xe3, 0x5e,
		0xda, 0x6b, 0xf7, 0xc2, 0x64, 0xf6, 0xa8, 0x18, 0x24, 0x41, 0x52, 0x0c, 0xd5, 0x85, 0x0a, 0x27,
		0x3f, 0x8a, 0x61, 0x10, 0x7d, 0xf5, 0x92, 0xd4, 0x4f, 0x95, 0xd7, 0xf1, 0x53, 0xff, 0xc4, 0x4f,
		0x54, 0x31, 0x4c, 0xfa, 0xc5, 0x34, 0xbc, 0x48, 0x86, 0xdf, 0x8a, 0xea, 0x5b, 0xaa, 0xa2, 0x8e,
		0xea, 0x78, 0x41, 0xe2, 0xc5, 0xca, 0x6f, 0x9f, 0xf9, 0x27, 0x41, 0x18, 0xa4, 0x97, 0xc5, 0x48,
		0x05, 0xa7, 0x67, 0x27, 0xbd, 0x38, 0x99, 0x3d, 0x2a, 0x5e, 0x0f, 0x66, 0x36, 0x88, 0x64, 0x70,
		0x32, 0x7a, 0xa9, 0xf1, 0xcf, 0xa2, 0x7f, 0xe1, 0x07, 0xa1, 0x7f, 0x12, 0x2a, 0xef, 0xc4, 0x8f,
		0x3a, 0x7f, 0x05, 0x9d, 0xf4, 0xac, 0x38, 0xba, 0xfa, 0xff, 0xc7, 0xde, 0xfb, 0x75, 0xa5, 0xad,
		0x75, 0xdf, 0xe3, 0xf7, 0xe7, 0x55, 0x38, 0x32, 0x9e, 0x8b, 0x76, 0x8c, 0x52, 0xd4, 0xa2, 0x56,
		0xef, 0xa2, 0xc4, 0x36, 0xa7, 0x08, 0x0c, 0xc0, 0x7e, 0x7a, 0x9e, 0x1e, 0x9f, 0x8c, 0x08, 0x5b,
		0x9b, 0x5f, 0x31, 0x30, 0x92, 0x60, 0xeb, 0xf7, 0x1c, 0xdf, 0xfb, 0x6f, 0x40, 0x20, 0xfe, 0x41,
		0x6a, 0x55, 0xc8, 0x9e, 0x6b, 0x67, 0x72, 0x51, 0x29, 0xd5, 0xba, 0x92, 0xcc, 0xbd, 0xd6, 0x5c,
		0x6b, 0xaf, 0xb9, 0xb6, 0xa0, 0xd2, 0x8c, 0x15, 0x27, 0xd1, 0xa8, 0x9b, 0x84, 0xd3, 0x98, 0xda,
		0xc8, 0x9e, 0x52, 0x3d, 0x7d, 0x02, 0xee, 0xf4, 0xda, 0xbd, 0x7b, 0x7f, 0x8f, 0xef, 0x7f, 0xe0,
		0x35, 0x67, 0x4f, 0x28, 0x7b, 0xe7, 0xb9, 0x71, 0x10, 0x7b, 0xb5, 0xc9, 0x13, 0x4a, 0xbf, 0x78,
		0xb5, 0x20, 0xfc, 0xde, 0x1e, 0xdf, 0xa2, 0xea, 0xf4, 0xf9, 0x78, 0xb5, 0x78, 0xe8, 0x75, 0xfa,
		0x97, 0xf1, 0xf8, 0x0f, 0xcf, 0x99, 0x3e, 0x1f, 0x37, 0x6e, 0xdd, 0x7a, 0x3a, 0x5e, 0x7d, 0xf6,
		0x74, 0xb2, 0x77, 0xde, 0x8d, 0x1d, 0x99, 0x01, 0xed, 0xf4, 0xe9, 0x4c, 0xbf, 0x7a, 0xf6, 0xec,
		0xe9, 0xec, 0xcf, 0x1e, 0x8e, 0x37, 0xf9, 0xcd, 0x32, 0x78, 0x01, 0xbe, 0x0f, 0xc5, 0xb6, 0x10,
		0xdc, 0xbb, 0x4b, 0xf3, 0xea, 0xc5, 0xf4, 0xe6, 0x02, 0xfc, 0x78, 0x91, 0xfc, 0x37, 0xb6, 0xe7,
		0xc6, 0xf5, 0x87, 0xc0, 0xbe, 0xd0, 0xca, 0xd6, 0x5a, 0xa9, 0x3b, 0x08, 0xe3, 0x24, 0xf2, 0x83,
		0x30, 0x89, 0xe1, 0x5d, 0x62, 0x56, 0x83, 0x78, 0xd8, 0x7c, 0xf0, 0xd8, 0xf3, 0x29, 0x08, 0x7b,
		0xd6, 0xde, 0xda, 0x06, 0xb8, 0x99, 0x07, 0x13, 0x3f, 0x66, 0xed, 0xad, 0xad, 0x83, 0x1b, 0xda,
		0x8c, 0xd4, 0x59, 0xf0, 0x53, 0x46, 0x1c, 0x9f, 0x01, 0x77, 0xd0, 0x2d, 0x8d, 0x23, 0xae, 0x84,
		0x08, 0xd7, 0x1e, 0x8c, 0xa2, 0xae, 0x12, 0x93, 0xfc, 0x5a, 0x9f, 0xd4, 0xd5, 0x8f, 0x41, 0x34,
		0x5e, 0x61, 0xd6, 0x30, 0x45, 0x86, 0x90, 0x4a, 0xc3, 0x47, 0x3f, 0xb6, 0xa3, 0xf3, 0xd1, 0x85,
		0x0a, 0x13, 0x6b, 0x6f, 0x2d, 0x89, 0x46, 0x4a, 0x4a, 0x89, 0xe4, 0xc6, 0xea, 0x0c, 0xd8, 0xcc,
		0x9f, 0x8c, 0xce, 0x9f, 0xaa, 0x41, 0x24, 0xc3, 0xe1, 0x3e, 0xc4, 0x10, 0xe4, 0xf8, 0xb2, 0x5f,
		0xf1, 0x1c, 0x29, 0x6e, 0x4d, 0x06, 0xdd, 0x11, 0x47, 0x7b, 0x24, 0xd2, 0x1f, 0xc1, 0x34, 0x48,
		0x2a, 0x1d, 0x12, 0x4f, 0x8b, 0xc4, 0xd3, 0x23, 0xd9, 0x34, 0x49, 0x06, 0x5d, 0x12, 0x42, 0x9b,
		0xc4, 0xd1, 0xa7, 0xcc, 0x60, 0x49, 0xd5, 0xa1, 0x85, 0xd1, 0x46, 0x4e, 0x8d, 0x48, 0x38, 0x89,
		0x12, 0x4b, 0xa6, 0x24, 0x93, 0x2a, 0x03, 0xc8, 0x95, 0x74, 0x92, 0x65, 0x0c, 0xd9, 0x32, 0x86,
		0x74, 0x99, 0x41, 0xbe, 0x64, 0x91, 0x30, 0x61, 0x64, 0x4c, 0x2c, 0x29, 0x7b, 0x80, 0x9c, 0xc9,
		0xf5, 0x98, 0xf3, 0x1c, 0x4d, 0xaa, 0xcb, 0x94, 0x49, 0xd5, 0xc4, 0x53, 0x36, 0x13, 0xa8, 0x9b,
		0x41, 0x14, 0xce, 0x14, 0x2a, 0x67, 0x1c, 0xa5, 0x33, 0x8e, 0xda, 0x99, 0x45, 0xf1, 0x64, 0x52,
		0x3d, 0xa1, 0x94, 0x4f, 0x3c, 0xf5, 0x7b, 0x80, 0x02, 0x96, 0x82, 0x9e, 0x7c, 0x67, 0x3b, 0xcf,
		0x06, 0xc7, 0x97, 0x25, 0xdc, 0x3f, 0x4d, 0x89, 0xe1, 0xba, 0xf0, 0xcb, 0x90, 0x4e, 0x10, 0x4d,
		0x22, 0x8a, 0x06, 0x12, 0x46, 0xd3, 0x88, 0xa3, 0xb1, 0x04, 0xd2, 0x58, 0x22, 0x69, 0x26, 0xa1,
		0x94, 0x4d, 0x2c, 0x85, 0x13, 0xcc, 0x0c, 0x52, 0x9d, 0xab, 0xa1, 0x32, 0x2b, 0xe2, 0xf4, 0x95,
		0x7f, 0x16, 0xa9, 0x33, 0x13, 0x22, 0xce, 0xac, 0x72, 0xb7, 0x63, 0xc0, 0xb5, 0x34, 0xa7, 0x52,
		0xb1, 0xb7, 0x6f, 0x53, 0x4d, 0x6c, 0xf9, 0x2e, 0x95, 0xfe, 0x83, 0x2e, 0x8c, 0xee, 0xeb, 0x69,
		0x88, 0x4a, 0xa5, 0xd5, 0xc6, 0xa4, 0x96, 0xd2, 0x94, 0xe2, 0xbf, 0xf4, 0x58, 0x4c, 0x29, 0x99,
		0x52, 0x32, 0xa5, 0x64, 0x4a, 0xc9, 0x94, 0x92, 0x29, 0x25, 0xf9, 0x58, 0xb1, 0x52, 0x4a, 0xe9,
		0x7b, 0x17, 0xd9, 0x85, 0xdc, 0xcc, 0x7d, 0xd8, 0x33, 0x6d, 0xc0, 0xaa, 0xa4, 0x91, 0x16, 0x4f,
		0x21, 0x9e, 0xeb, 0x86, 0x5c, 0x8e, 0x29, 0x04, 0xd4, 0x44, 0x22, 0x6a, 0x30, 0x21, 0x35, 0x95,
		0x98, 0x1a, 0x4f, 0x50, 0x8d, 0x27, 0xaa, 0x66, 0x13, 0x56, 0x33, 0x88, 0xab, 0x21, 0x04, 0x36,
		0x83, 0x9a, 0x31, 0x7b, 0x23, 0x73, 0x11, 0x2b, 0x50, 0x4a, 0x9d, 0xf5, 0x07, 0x7e, 0xf2, 0x6e,
		0xd3, 0xa4, 0xa8, 0x35, 0x25, 0x81, 0xbb, 0x06, 0x5d, 0x52, 0x4d, 0x85, 0xe7, 0x93, 0x04, 0xe4,
		0xab, 0x51, 0x6e, 0xdc, 0x2c, 0x5a, 0x31, 0x79, 0x52, 0x47, 0x41, 0x68, 0x1c, 0x5f, 0x32, 0x34,
		0xbd, 0x9a, 0xbb, 0xbc, 0xc9, 0xd9, 0x43, 0xd6, 0xde, 0x5a, 0xc5, 0xd0, 0xeb, 0x3b, 0x8c, 0xfc,
		0x6e, 0x12, 0x0c, 0xc2, 0x6a, 0x70, 0x1e, 0x4c, 0x04, 0xd3, 0xeb, 0xc6, 0x5d, 0xe7, 0xf5, 0x1b,
		0x03, 0x5d, 0x8a, 0xff, 0x93, 0x2e, 0x85, 0x2e, 0x85, 0x2e, 0x85, 0xd9, 0x18, 0xaf, 0xe6, 0xe6,
		0x75, 0xf2, 0x07, 0x9f, 0x07, 0x43, 0xee, 0x72, 0xdc, 0x98, 0x59, 0x3a, 0x95, 0xb9, 0x44, 0xdf,
		0x24, 0xbd, 0x8a, 0xa1, 0xcc, 0x81, 0x7b, 0x3d, 0x92, 0x16, 0x14, 0xf7, 0x7a, 0xe4, 0xb8, 0x09,
		0xee, 0xf5, 0x08, 0xbf, 0x40, 0xee, 0xf5, 0x90, 0x03, 0xe6, 0x04, 0x35, 0x73, 0xf7, 0x7a, 0x46,
		0x41, 0x68, 0xe6, 0x36, 0xcf, 0x8e, 0x41, 0x97, 0xd4, 0xf2, 0xc3, 0x73, 0xc5, 0x5d, 0x1e, 0xfc,
		0x07, 0xc5, 0x5d, 0x1e, 0xb9, 0x97, 0x37, 0x2b, 0xc9, 0xae, 0xb3, 0x24, 0x4b, 0xba, 0x01, 0xe4,
		0x52, 0xb8, 0xcb, 0x23, 0xde, 0xa5, 0x54, 0x36, 0x77, 0x2b, 0xbb, 0xdb, 0x3b, 0x9b, 0xbb, 0x5b,
		0xf4, 0x2d, 0x4c, 0xc8, 0x78, 0x35, 0xcb, 0x7c, 0x71, 0xbb, 0x87, 0x57, 0x50, 0x78, 0xe6, 0x20,
		0xf5, 0xd8, 0xf7, 0x85, 0xd7, 0x63, 0xfe, 0x01, 0xc2, 0x0f, 0x9e, 0x05, 0xfa, 0xe0, 0xa7, 0xe5,
		0xdb, 0xdf, 0x70, 0xeb, 0x63, 0x13, 0x46, 0x02, 0xac, 0x19, 0x7d, 0x28, 0x71, 0x76, 0x16, 0xf1,
		0xc1, 0xcd, 0x13, 0x7c, 0xe8, 0x43, 0xef, 0xf6, 0xbf, 0xdf, 0xfa, 0x58, 0xd0, 0x09, 0xf4, 0xe6,
		0x85, 0x05, 0x8e, 0x34, 0xcd, 0x35, 0x13, 0x54, 0x57, 0xa6, 0x74, 0x24, 0x58, 0xb5, 0x20, 0x4e,
		0xec, 0x24, 0x11, 0x3e, 0xa3, 0xf5, 0x28, 0x08, 0x9d, 0xbe, 0xba, 0x50, 0xe9, 0x19, 0x4a, 0x82,
		0x53, 0x74, 0xeb, 0xc8, 0xff, 0x79, 0xeb, 0x4a, 0x36, 0xde, 0x57, 0x2a, 0xdb, 0x3b, 0x95, 0xca,
		0xfa, 0xce, 0xbb, 0x9d, 0xf5, 0xdd, 0xad, 0xad, 0x8d, 0xed, 0x0d, 0xc1, 0x69, 0xb9, 0xd5, 0x88,
		0x7a, 0x2a, 0x52, 0xbd, 0xfd, 0xf1, 0xf2, 0x09, 0x47, 0xfd, 0x3e, 0xbd, 0x16, 0x69, 0x37, 0xe9,
		0xf6, 0xf2, 0xe9, 0xb6, 0x25, 0x7a, 0x16, 0x1a, 0x09, 0xf6, 0x43, 0x04, 0x5b, 0x26, 0xb5, 0xbe,
		0xe6, 0x41, 0x50, 0x0c, 0x46, 0xe6, 0x04, 0x21, 0x06, 0x9f, 0x05, 0xc1, 0x47, 0xe2, 0x49, 0x88,
		0x8c, 0x34, 0xb7, 0xfe, 0x5d, 0x56, 0x78, 0x91, 0xe3, 0xa4, 0x05, 0x39, 0x68, 0xeb, 0x62, 0xd0,
		0x53, 0x7d, 0x89, 0xe2, 0x91, 0xac, 0x43, 0x30, 0xbb, 0x02, 0x99, 0x67, 0x10, 0xaf, 0xf3, 0x0c,
		0xe2, 0x7c, 0x0c, 0xe7, 0x19, 0xc4, 0x5a, 0x2f, 0x81, 0x67, 0x10, 0x83, 0x5c, 0x08, 0xcf, 0x20,
		0x26, 0xab, 0x29, 0x4a, 0xea, 0x29, 0x56, 0x17, 0x61, 0xc0, 0x79, 0x20, 0x92, 0xcf, 0xff, 0x98,
		0x3f, 0xef, 0x23, 0x63, 0x99, 0xcc, 0x99, 0x0a, 0x9f, 0x33, 0xc9, 0x3c, 0xba, 0x43, 0xf4, 0x51,
		0x1d, 0x42, 0x8f, 0xe6, 0x60, 0xb6, 0xc4, 0x6c, 0x89, 0xd9, 0x12, 0xb3, 0x25, 0x66, 0x4b, 0xcc,
		0x96, 0xf0, 0x21, 0x22, 0xf5, 0xe8, 0x0b, 0xb9, 0x45, 0xec, 0xb9, 0x90, 0x25, 0xb4, 0x98, 0x7d,
		0x9f, 0xa6, 0x09, 0xed, 0xc6, 0x13, 0x3f, 0xcc, 0xc8, 0x84, 0xe1, 0x45, 0x06, 0x0d, 0x2b, 0x32,
		0x65, 0x38, 0x91, 0x71, 0xc3, 0x88, 0x8c, 0x1b, 0x3e, 0x64, 0xd6, 0xb0, 0x21, 0x4a, 0x1b, 0xf2,
		0x84, 0x8e, 0xf8, 0xe1, 0x41, 0x77, 0x86, 0x05, 0xbd, 0x97, 0x1c, 0x2f, 0xa6, 0xf4, 0x49, 0x72,
		0xbf, 0xbf, 0x19, 0xb3, 0x80, 0x0c, 0x90, 0xa8, 0x9a, 0x34, 0xeb, 0xc7, 0xb4, 0xa1, 0xa9, 0x86,
		0xcd, 0xf2, 0x31, 0x71, 0xbe, 0x86, 0x09, 0xe3, 0xa1, 0x4d, 0x9a, 0xcd, 0x63, 0xaa, 0x0b, 0xd8,
		0xdc, 0xda, 0xa2, 0x13, 0x60, 0x22, 0x42, 0xeb, 0x6f, 0xbf, 0x4e, 0x28, 0x7c, 0xa2, 0xc5, 0xd2,
		0x43, 0x32, 0x85, 0x4f, 0x26, 0x09, 0x9f, 0xa4, 0x4e, 0xb3, 0xa1, 0xe4, 0x49, 0xe2, 0x98, 0x1a,
		0x41, 0x8d, 0x7b, 0x7f, 0x30, 0x74, 0x2c, 0x31, 0xc9, 0x49, 0xc7, 0xcc, 0x08, 0xdb, 0x06, 0x96,
		0x39, 0x51, 0x46, 0xee, 0x04, 0x19, 0xa3, 0x26, 0xc6, 0xc8, 0x9c, 0x10, 0x23, 0xc5, 0xa1, 0x08,
		0xe5, 0xa0, 0xe4, 0x9e, 0x25, 0x91, 0xa3, 0x5d, 0xc8, 0x36, 0x65, 0xf0, 0x4c, 0x7c, 0xd6, 0x86,
		0x6d, 0x21, 0xb8, 0xfb, 0x97, 0xe6, 0xf6, 0x8b, 0xea, 0xee, 0x05, 0x78, 0xf6, 0x62, 0x79, 0x74,
		0x6c, 0xef, 0x8d, 0xeb, 0x13, 0x81, 0xfd, 0xa1, 0x95, 0xad, 0x63, 0xbf, 0x77, 0x11, 0x84, 0xa5,
		0xf3, 0x68, 0x30, 0x1a, 0xc2, 0x7b, 0xc5, 0xac, 0xa7, 0xe9, 0x41, 0xeb, 0xc1, 0xa3, 0x8f, 0x0c,
		0xb1, 0x9e, 0x98, 0x6e, 0x6f, 0x49, 0x5d, 0xdd, 0x02, 0xbb, 0xb7, 0xa5, 0x75, 0x69, 0x8b, 0xed,
		0xc6, 0x16, 0xdb, 0x75, 0x2d, 0xb3, 0xbb, 0x9a, 0x19, 0xd4, 0x4b, 0x1e, 0xb9, 0x14, 0x31, 0x9c,
		0xb0, 0x69, 0x04, 0x22, 0xa7, 0x10, 0x08, 0x9b, 0x3e, 0x20, 0x4e, 0xc6, 0x26, 0x51, 0xb6, 0x26,
		0x58, 0xa6, 0x26, 0x55, 0x96, 0x26, 0x5e, 0x86, 0x26, 0x5e, 0x76, 0x26, 0x5b, 0x66, 0xc6, 0x56,
		0x85, 0x22, 0x12, 0xa4, 0xcc, 0x60, 0x91, 0x75, 0xa0, 0x85, 0x61, 0x47, 0x60, 0x5d, 0x68, 0x11,
		0xad, 0xe2, 0x08, 0x5c, 0xd2, 0x2c, 0x83, 0xe9, 0x96, 0x74, 0xda, 0x65, 0x0c, 0xfd, 0x32, 0x86,
		0x86, 0x99, 0x41, 0xc7, 0x64, 0xd1, 0x32, 0x61, 0xf4, 0x2c, 0x83, 0x88, 0xfc, 0x11, 0xb8, 0xa3,
		0x20, 0x4c, 0xde, 0x6d, 0x0a, 0x9e, 0x80, 0x2b, 0x71, 0x00, 0xae, 0x6c, 0x19, 0xbf, 0xec, 0x63,
		0x2d, 0x0d, 0x98, 0x17, 0x64, 0x84, 0x56, 0xd7, 0x14, 0x99, 0xbe, 0x49, 0xca, 0xdc, 0x6b, 0xd9,
		0xe7, 0xbc, 0x72, 0x69, 0x83, 0x2d, 0xed, 0xca, 0xe6, 0x6e, 0x65, 0x77, 0x7b, 0x67, 0x73, 0x77,
		0x8b, 0x6b, 0x9c, 0x09, 0x41, 0xb1, 0xac, 0x3e, 0x61, 0xe2, 0xb5, 0xc2, 0x05, 0x29, 0xfa, 0x94,
		0x75, 0xf9, 0xa7, 0xab, 0x1b, 0x79, 0xaa, 0xba, 0xec, 0xd3, 0xd4, 0x29, 0x6a, 0x2e, 0xa4, 0x47,
		0xa4, 0x06, 0x11, 0x56, 0x94, 0xf2, 0xd0, 0x26, 0xa2, 0xb8, 0x49, 0x17, 0xe6, 0x2a, 0x54, 0x66,
		0xff, 0x97, 0x3d, 0x7e, 0x3a, 0x1f, 0xc6, 0x0f, 0x47, 0xd2, 0x2c, 0x0b, 0x6a, 0x0c, 0x8d, 0x76,
		0xef, 0xd4, 0x18, 0x8a, 0x70, 0xe7, 0x94, 0x18, 0x42, 0x39, 0x70, 0x0a, 0x0c, 0x8d, 0x73, 0x86,
		0x56, 0x30, 0xbc, 0xac, 0x94, 0x82, 0x30, 0x51, 0xd1, 0x99, 0xdf, 0x55, 0x25, 0xbf, 0xd7, 0x8b,
		0x54, 0x1c, 0xcb, 0x91, 0x18, 0x2e, 0xb0, 0x9f, 0x22, 0xc3, 0x65, 0x98, 0x49, 0x91, 0xe1, 0x0a,
		0x91, 0x4b, 0x91, 0xe1, 0xea, 0x96, 0x17, 0x45, 0x86, 0x79, 0xf3, 0x69, 0x8a, 0x0c, 0x8b, 0x96,
		0x42, 0x51, 0x64, 0xb8, 0xda, 0xf8, 0x40, 0x91, 0x21, 0x89, 0x8d, 0x44, 0x82, 0x23, 0x98, 0xe8,
		0x48, 0x25, 0x3c, 0xe2, 0x89, 0x8f, 0x78, 0x02, 0x24, 0x9b, 0x08, 0xc9, 0x20, 0x44, 0x42, 0x88,
		0x91, 0x38, 0x82, 0x94, 0x19, 0x2c, 0xa5, 0xf8, 0xb3, 0x30, 0xd2, 0xc8, 0xa8, 0xfe, 0x2c, 0x22,
		0x4f, 0x94, 0x12, 0x92, 0x4c, 0x19, 0x4c, 0xaa, 0xa4, 0x93, 0x2b, 0x63, 0x48, 0x96, 0x31, 0x64,
		0xcb, 0x0c, 0xd2, 0x25, 0x8b, 0x7c, 0x09, 0x23, 0x61, 0x19, 0x44, 0xe4, 0x4b, 0x09, 0x27, 0x3b,
		0x5d, 0x32, 0x19, 0xce, 0x6d, 0x96, 0xb3, 0xf1, 0x5e, 0xa0, 0xed, 0x4d, 0x3f, 0x49, 0x54, 0x14,
		0x8a, 0xd5, 0x14, 0x5a, 0xaf, 0x5e, 0x7d, 0x5d, 0x2f, 0xed, 0x9e, 0xfc, 0xfb, 0x75, 0xa3, 0xb4,
		0x7b, 0x92, 0xbe, 0xdd, 0x98, 0x7c, 0x49, 0xdf, 0x6f, 0x7e, 0x5d, 0x2f, 0x55, 0x66, 0xef, 0xb7,
		0xbe, 0xae, 0x97, 0xb6, 0x4e, 0x5e, 0xff, 0xfd, 0xf7, 0xdb, 0xd7, 0xff, 0xbc, 0xbb, 0x7e, 0xfa,
		0x0f, 0xca, 0x73, 0xbd, 0x27, 0x12, 0x21, 0xd9, 0x68, 0xbb, 0x5f, 0xc4, 0xe3, 0xf2, 0x7f, 0x79,
		0x02, 0xf3, 0x3f, 0x16, 0x65, 0x2e, 0x24, 0x05, 0xb7, 0xd0, 0x47, 0x99, 0x8b, 0xe6, 0x2b, 0xa0,
		0xcc, 0x85, 0x49, 0x88, 0xd1, 0x96, 0x52, 0xe6, 0xb2, 0x5a, 0xbb, 0xcd, 0xef, 0x8b, 0x7e, 0xb8,
		0xc1, 0x91, 0x42, 0x17, 0x98, 0x3e, 0x69, 0x77, 0x78, 0x59, 0x71, 0x67, 0xcf, 0xc7, 0x4e, 0x1f,
		0x0f, 0xa5, 0x2e, 0xc5, 0xb1, 0x90, 0x52, 0x17, 0xba, 0xf4, 0x65, 0xb8, 0x74, 0x8a, 0x5d, 0xc0,
		0x9c, 0x38, 0xe5, 0x2e, 0xc6, 0x39, 0xc4, 0xb4, 0x88, 0x3e, 0x5b, 0xaa, 0x42, 0xd5, 0x2e, 0x73,
		0xe6, 0x53, 0xec, 0xb2, 0x0c, 0x33, 0x29, 0x76, 0x59, 0x21, 0x70, 0x29, 0x76, 0x59, 0xdd, 0xf2,
		0xa2, 0xd8, 0x25, 0x6f, 0x46, 0x4d, 0xb1, 0x4b, 0xd1, 0x92, 0x28, 0x8a, 0x5d, 0x56, 0x1b, 0x1f,
		0x28, 0x76, 0x21, 0xb1, 0x91, 0x48, 0x70, 0x04, 0x13, 0x1d, 0xa9, 0x84, 0x47, 0x3c, 0xf1, 0x11,
		0x4f, 0x80, 0x64, 0x13, 0x21, 0x19, 0x84, 0x48, 0x08, 0x31, 0x12, 0x47, 0x90, 0x32, 0x83, 0x29,
		0x76, 0xd1, 0x4a, 0x9e, 0x28, 0x76, 0x21, 0x99, 0x32, 0x98, 0x54, 0x49, 0x27, 0x57, 0xc6, 0x90,
		0x2c, 0x63, 0xc8, 0x96, 0x19, 0xa4, 0x4b, 0x16, 0xf9, 0x12, 0x46, 0xc2, 0x32, 0x88, 0x50, 0xec,
		0x02, 0xc2, 0x72, 0x28, 0x76, 0xd1, 0x71, 0x01, 0x14, 0xbb, 0xfc, 0xea, 0x45, 0xb1, 0x8b, 0xae,
		0xab, 0xa0, 0xd8, 0xe5, 0x11, 0x64, 0x92, 0x14, 0xac, 0x10, 0x7d, 0x14, 0xbb, 0x68, 0xbe, 0x02,
		0x8a, 0x5d, 0x98, 0x84, 0x18, 0x6d, 0x29, 0xc5, 0x2e, 0xab, 0xb5, 0xbb, 0x20, 0x9d, 0xd1, 0xf7,
		0xfb, 0x1b, 0xa9, 0x75, 0x81, 0x6a, 0x93, 0x9e, 0x7d, 0x3b, 0xa5, 0x2e, 0x85, 0xb3, 0x90, 0x52,
		0x17, 0x3a, 0xf4, 0x25, 0x38, 0x74, 0x2a, 0x5d, 0xb0, 0x5c, 0x38, 0x85, 0x2e, 0xc6, 0xb9, 0x43,
		0x2b, 0x18, 0x5e, 0x6e, 0x0b, 0x3f, 0xd7, 0x65, 0x9b, 0xe7, 0xba, 0xac, 0xc8, 0x4c, 0x4a, 0x5d,
		0x56, 0x88, 0x5c, 0x4a, 0x5d, 0x56, 0xb7, 0xbc, 0x28, 0x75, 0xc9, 0x9b, 0x51, 0x53, 0xea, 0x52,
		0xb4, 0x24, 0x8a, 0x52, 0x97, 0xd5, 0xc6, 0x07, 0x4a, 0x5d, 0x48, 0x6c, 0x24, 0x12, 0x1c, 0xc1,
		0x44, 0x47, 0x2a, 0xe1, 0x11, 0x4f, 0x7c, 0xc4, 0x13, 0x20, 0xd9, 0x44, 0x48, 0x06, 0x21, 0x12,
		0x42, 0x8c, 0xc4, 0x11, 0xa4, 0xcc, 0x60, 0x4a, 0x5d, 0xb4, 0x92, 0x27, 0x4a, 0x5d, 0x48, 0xa6,
		0x0c, 0x26, 0x55, 0xd2, 0xc9, 0x95, 0x31, 0x24, 0xcb, 0x18, 0xb2, 0x65, 0x06, 0xe9, 0x92, 0x45,
		0xbe, 0x84, 0x91, 0xb0, 0x0c, 0x22, 0x46, 0x48, 0x5d, 0xb6, 0x29, 0x75, 0xd1, 0xc4, 0x18, 0xcc,
		0x90, 0xba, 0xf8, 0xa5, 0x33, 0xbb, 0x74, 0x78, 0xf2, 0xcf, 0xc6, 0x9b, 0xca, 0xf5, 0xde, 0xeb,
		0x7f, 0x76, 0xae, 0xef, 0x7f, 0xf8, 0xef, 0x43, 0xdf, 0xb6, 0xf1, 0x66, 0xe7, 0x7a, 0x6f, 0xc1,
		0xbf, 0x6c, 0x5f, 0xef, 0xfd, 0xe6, 0xff, 0xb1, 0x75, 0xfd, 0x6a, 0xee, 0x5b, 0xc7, 0x9f, 0x6f,
		0x2e, 0xfa, 0x81, 0xca, 0x82, 0x1f, 0x78, 0xb7, 0xe8, 0x07, 0xde, 0x2d, 0xf8, 0x81, 0x85, 0x26,
		0x6d, 0x2e, 0xf8, 0x81, 0xad, 0xeb, 0x7f, 0xe7, 0xbe, 0xff, 0xd5, 0xc3, 0xdf, 0xba, 0x7d, 0xfd,
		0xfa, 0xdf, 0x45, 0xff, 0xb6, 0x73, 0xfd, 0xef, 0xde, 0x6b, 0x0a, 0x7f, 0xf2, 0x59, 0xa0, 0x26,
		0x09, 0x7f, 0xb8, 0x4c, 0xf3, 0x5f, 0xa6, 0x94, 0x41, 0x91, 0x30, 0xde, 0x59, 0x8b, 0x94, 0x41,
		0x69, 0xbe, 0x02, 0xca, 0xa0, 0x98, 0xa0, 0x1a, 0x6d, 0x29, 0x65, 0x50, 0xab, 0xb5, 0xbb, 0x10,
		0x5d, 0xf3, 0xdb, 0x3c, 0xf3, 0x07, 0xbb, 0x89, 0x7e, 0x9b, 0x67, 0xfe, 0x14, 0xd7, 0x42, 0x0a,
		0xa1, 0xe8, 0xd2, 0x97, 0xe1, 0xd2, 0xa9, 0x84, 0x02, 0x73, 0xe2, 0x94, 0x42, 0x19, 0xe7, 0x10,
		0xd3, 0x0d, 0x16, 0xd1, 0x67, 0xfe, 0x6c, 0xf3, 0xcc, 0x9f, 0xd5, 0x98, 0x49, 0x21, 0xd4, 0x0a,
		0x81, 0x4b, 0x21, 0xd4, 0xea, 0x96, 0x17, 0x85, 0x50, 0x79, 0x33, 0x6a, 0x0a, 0xa1, 0x8a, 0x96,
		0x44, 0x51, 0x08, 0xb5, 0xda, 0xf8, 0x40, 0x21, 0x14, 0x89, 0x8d, 0x44, 0x82, 0x23, 0x98, 0xe8,
		0x48, 0x25, 0x3c, 0xe2, 0x89, 0x8f, 0x78, 0x02, 0x24, 0x9b, 0x08, 0xc9, 0x20, 0x44, 0x42, 0x88,
		0x91, 0x38, 0x82, 0x94, 0x19, 0x4c, 0x21, 0x94, 0x56, 0xf2, 0x44, 0x21, 0x14, 0xc9, 0x94, 0xc1,
		0xa4, 0x4a, 0x3a, 0xb9, 0x32, 0x86, 0x64, 0x19, 0x43, 0xb6, 0xcc, 0x20, 0x5d, 0xb2, 0xc8, 0x97,
		0x30, 0x12, 0x96, 0x41, 0x84, 0x42, 0x28, 0x10, 0x96, 0x43, 0x21, 0x94, 0x8e, 0x0b, 0xa0, 0xc2,
		0x82, 0x42, 0xa8, 0xdf, 0x7d, 0x51, 0x08, 0xa5, 0xeb, 0x2a, 0x28, 0x84, 0xa2, 0x10, 0xea, 0x09,
		0xeb, 0x94, 0x84, 0x71, 0x85, 0x6b, 0x91, 0x42, 0x28, 0xcd, 0x57, 0x40, 0x21, 0x14, 0x13, 0x54,
		0xa3, 0x2d, 0xa5, 0x10, 0x6a, 0xb5, 0x76, 0x17, 0xa4, 0x6b, 0x9e, 0xe7, 0x41, 0x41, 0xb7, 0xd0,
		0xf3, 0x3c, 0xa8, 0xc2, 0x5a, 0x48, 0x19, 0x14, 0x1d, 0xfa, 0x12, 0x1c, 0x3a, 0x55, 0x50, 0x58,
		0x2e, 0x9c, 0x22, 0x28, 0xe3, 0xdc, 0xa1, 0xd5, 0xf7, 0xc3, 0x92, 0xdf, 0xfb, 0xff, 0xfc, 0xae,
		0x0a, 0xbb, 0x57, 0xa5, 0x38, 0xe8, 0x09, 0x52, 0x40, 0x3d, 0x60, 0x3b, 0xe5, 0x4f, 0xcb, 0x30,
		0x93, 0xf2, 0xa7, 0x15, 0xa2, 0x96, 0xf2, 0xa7, 0xd5, 0x2d, 0x2f, 0xca, 0x9f, 0xf2, 0x66, 0xd2,
		0x94, 0x3f, 0x15, 0x2d, 0x79, 0x12, 0x23, 0x7f, 0x9a, 0xa3, 0x07, 0xf2, 0xa4, 0x50, 0xf3, 0x97,
		0x40, 0x59, 0x54, 0x91, 0x09, 0x8f, 0x44, 0xe2, 0x23, 0x98, 0x00, 0x49, 0x25, 0x42, 0xe2, 0x09,
		0x91, 0x78, 0x62, 0x24, 0x9b, 0x20, 0xc9, 0x20, 0x4a, 0x42, 0x08, 0x93, 0x38, 0xe2, 0x94, 0x19,
		0x2c, 0x4b, 0x3f, 0x3e, 0x17, 0x67, 0xa4, 0x6d, 0x07, 0x0a, 0x24, 0x4e, 0x62, 0x09, 0x94, 0x64,
		0x22, 0x65, 0x00, 0xa1, 0x92, 0x4e, 0xac, 0x8c, 0x21, 0x58, 0xc6, 0x10, 0x2d, 0x33, 0x08, 0x97,
		0x2c, 0xe2, 0x25, 0x8c, 0x80, 0x89, 0x25, 0x62, 0x99, 0xe1, 0x67, 0x7d, 0xff, 0x3c, 0x96, 0xeb,
		0x2c, 0x67, 0xf1, 0x2a, 0xbd, 0x0c, 0xa1, 0xfe, 0x45, 0xa6, 0x66, 0x5d, 0x3c, 0x51, 0x33, 0x81,
		0xb0, 0x19, 0x44, 0xdc, 0x4c, 0x21, 0x70, 0xc6, 0x11, 0x39, 0xe3, 0x08, 0x9d, 0x59, 0xc4, 0x4e,
		0x26, 0xc1, 0x13, 0x4a, 0xf4, 0x32, 0xe8, 0x88, 0xd5, 0xc0, 0xcf, 0x45, 0x0c, 0x15, 0x8e, 0x2e,
		0x54, 0x94, 0xb6, 0xae, 0x0a, 0x8e, 0x1a, 0xb3, 0x2a, 0x57, 0x45, 0xf0, 0x35, 0x38, 0xe1, 0xe8,
		0x62, 0x0c, 0x2a, 0x2e, 0xe5, 0x3c, 0xef, 0xba, 0x68, 0x75, 0x62, 0x76, 0x15, 0xe2, 0x55, 0x8a,
		0x37, 0x57, 0x62, 0xa0, 0x5a, 0x31, 0xbb, 0x38, 0xd1, 0xaa, 0x45, 0xb9, 0x54, 0x43, 0xa0, 0x6f,
		0xb2, 0x32, 0xed, 0x82, 0xa0, 0x36, 0xa3, 0x85, 0x2c, 0xe3, 0xf6, 0xc5, 0xb0, 0x4c, 0xa3, 0xc3,
		0x7c, 0x96, 0x69, 0x80, 0x96, 0x03, 0xcb, 0x34, 0x38, 0xcb, 0x9a, 0x65, 0x1a, 0xf0, 0x0b, 0x62,
		0x99, 0x86, 0xfc, 0xe9, 0x99, 0xd0, 0x31, 0xa7, 0x4c, 0x13, 0x5f, 0xc5, 0x89, 0xba, 0x90, 0x4b,
		0x9f, 0xd6, 0x84, 0xcf, 0x2d, 0xbc, 0xa1, 0x21, 0xc2, 0x27, 0xa3, 0x65, 0x17, 0xf2, 0xbf, 0xaf,
		0xeb, 0xa5, 0x5d, 0xbb, 0x74, 0xe8, 0x97, 0xce, 0x4e, 0xfe, 0xa9, 0x5c, 0xff, 0xfd, 0xf7, 0xdb,
		0x47, 0x3e, 0xf8, 0x8f, 0x5c, 0xaf, 0x7b, 0x22, 0x19, 0x70, 0x26, 0xcc, 0xe3, 0x2b, 0x26, 0xea,
		0x58, 0xdd, 0x21, 0x3b, 0x59, 0xb0, 0x0e, 0x2e, 0xfd, 0xfe, 0x48, 0xc9, 0xaf, 0xeb, 0xa4, 0x97,
		0xc1, 0x8a, 0x8e, 0x0e, 0xf3, 0x59, 0xd1, 0x01, 0x5a, 0x08, 0xac, 0xe8, 0xe0, 0x2c, 0x6b, 0x56,
		0x74, 0xc0, 0x2f, 0x88, 0x15, 0x1d, 0x72, 0xa6, 0x67, 0x42, 0xc7, 0x9c, 0x8a, 0xce, 0x28, 0x08,
		0x93, 0x77, 0x9b, 0x06, 0x94, 0x73, 0x76, 0x04, 0x5f, 0x42, 0xcb, 0x0f, 0xcf, 0x95, 0xf8, 0xac,
		0x5a, 0x76, 0xc0, 0x5e, 0x9b, 0xf6, 0xaf, 0x88, 0x67, 0x1e, 0x86, 0x24, 0x16, 0x73, 0x97, 0xf3,
		0x79, 0x9a, 0xab, 0x9a, 0x72, 0x3d, 0x87, 0x91, 0xdf, 0x4d, 0x82, 0x41, 0x58, 0x0d, 0xce, 0x83,
		0xb4, 0x5d, 0x4a, 0xfc, 0x75, 0x5d, 0xbf, 0x31, 0xc0, 0x05, 0xf8, 0x3f, 0xe9, 0x02, 0xc0, 0x5d,
		0x40, 0x65, 0x73, 0xb7, 0xb2, 0xbb, 0xbd, 0xb3, 0xb9, 0xbb, 0x45, 0x5f, 0xc0, 0x84, 0x84, 0xd6,
		0xdf, 0x7e, 0xb1, 0xdc, 0xcf, 0x58, 0xb7, 0xc8, 0xcd, 0xfc, 0x50, 0xc1, 0xf9, 0xb7, 0x44, 0x7e,
		0xbd, 0x7f, 0x7a, 0x1d, 0x2c, 0xf8, 0xeb, 0x30, 0x9f, 0x05, 0x7f, 0xa0, 0x95, 0xc0, 0x82, 0x3f,
		0xce, 0xb2, 0x66, 0xc1, 0x1f, 0xfc, 0x82, 0x58, 0xf0, 0x27, 0x6b, 0x7a, 0x26, 0x74, 0xcc, 0x2a,
		0xf8, 0xbf, 0x37, 0xa0, 0xde, 0xbf, 0xc5, 0x7a, 0xbf, 0xe6, 0x17, 0xeb, 0xfd, 0xcc, 0x2b, 0x56,
		0x78, 0x39, 0xac, 0xf7, 0x33, 0x9a, 0xe7, 0xe1, 0x02, 0x58, 0xef, 0x87, 0x77, 0x01, 0x9b, 0x5b,
		0x2c, 0xf4, 0x33, 0x11, 0xa1, 0xf5, 0x77, 0x5e, 0x2c, 0xf4, 0xd3, 0x62, 0xf1, 0x21, 0x59, 0xea,
		0x59, 0xd4, 0x99, 0xfd, 0xe6, 0x1f, 0x61, 0x3a, 0x7f, 0x1a, 0xe1, 0xfc, 0x47, 0x65, 0x89, 0x33,
		0xe9, 0xd7, 0x8c, 0x3e, 0xe7, 0xb4, 0xe6, 0x87, 0xf6, 0xec, 0x11, 0xb5, 0x83, 0x5e, 0x7c, 0xff,
		0x03, 0x49, 0xe7, 0x56, 0xcb, 0x73, 0xc5, 0x82, 0xdc, 0xb0, 0x50, 0x11, 0x98, 0x68, 0xf1, 0x97,
		0xd0, 0x44, 0x8d, 0xc7, 0x61, 0xe8, 0x04, 0x3a, 0x8f, 0xc3, 0xd0, 0xb7, 0x5c, 0x79, 0x1c, 0x06,
		0x5a, 0xde, 0xc0, 0xe3, 0x30, 0xc8, 0x69, 0x7e, 0x0d, 0x11, 0xb1, 0x7b, 0xb6, 0x37, 0xc7, 0xa4,
		0x2a, 0xff, 0x2c, 0x52, 0x67, 0x12, 0x3d, 0xfe, 0x6c, 0xc8, 0x8e, 0x40, 0x59, 0x96, 0xd5, 0x9c,
		0x66, 0xf3, 0x6f, 0xdf, 0xa6, 0x79, 0x6d, 0x39, 0xa5, 0x98, 0x4c, 0x95, 0x0a, 0x6c, 0xa9, 0x94,
		0xc3, 0x18, 0x3f, 0xa9, 0x2b, 0x69, 0x49, 0x91, 0xcc, 0xd9, 0xd7, 0x72, 0x67, 0x5d, 0x1b, 0x35,
		0xdb, 0x5a, 0xe6, 0x2c, 0x6b, 0x29, 0xde, 0x44, 0x68, 0x75, 0x9e, 0x55, 0x79, 0x49, 0x87, 0xea,
		0xaf, 0x15, 0xba, 0x0e, 0x2f, 0x83, 0x56, 0xe2, 0x93, 0x34, 0x6c, 0x0b, 0xc1, 0x1d, 0xbe, 0x34,
		0x47, 0x5f, 0x48, 0x07, 0x2f, 0xc0, 0x9d, 0x17, 0xc7, 0x8d, 0x63, 0xbb, 0x6d, 0x5c, 0x67, 0x08,
		0xec, 0x08, 0xad, 0xc9, 0x0a, 0xf7, 0x93, 0x24, 0x0a, 0x4e, 0x47, 0x89, 0xc2, 0x3f, 0x90, 0xf6,
		0xa6, 0x4e, 0x78, 0xcf, 0x70, 0xf0, 0x60, 0x33, 0xab, 0x0d, 0x82, 0x9b, 0x29, 0x65, 0xb3, 0x53,
		0xd2, 0xe6, 0xa6, 0xc0, 0xcd, 0x4c, 0x69, 0x9b, 0x97, 0x62, 0x37, 0x2b, 0xc5, 0x6e, 0x4e, 0xca,
		0xdc, 0x8c, 0x64, 0xc2, 0xf4, 0x92, 0x47, 0x2e, 0xe5, 0xac, 0x7d, 0x2b, 0xed, 0xcc, 0x14, 0xe3,
		0xbc, 0xb2, 0x93, 0x46, 0x04, 0x35, 0x94, 0x0a, 0x21, 0x34, 0xe2, 0x88, 0x8d, 0x44, 0x82, 0x23,
		0x98, 0xe8, 0x48, 0x25, 0x3c, 0xe2, 0x89, 0x8f, 0x78, 0x02, 0x24, 0x9b, 0x08, 0xc9, 0x20, 0x44,
		0x42, 0x88, 0x91, 0x38, 0x82, 0x94, 0x19, 0xdc, 0x1f, 0x74, 0xfd, 0x7e, 0x69, 0x18, 0x0d, 0x12,
		0xd5, 0x15, 0xa9, 0x47, 0xba, 0x29, 0x07, 0xdd, 0xbf, 0x12, 0x36, 0xc7, 0x93, 0x56, 0x99, 0x45,
		0xaf, 0x0c, 0xa0, 0x59, 0xd2, 0xe9, 0x96, 0x31, 0xb4, 0xcb, 0x18, 0xfa, 0x65, 0x06, 0x0d, 0x93,
		0x45, 0xc7, 0x84, 0xd1, 0xb2, 0x0c, 0x22, 0xf2, 0x9b, 0xe3, 0x55, 0x38, 0xba, 0x50, 0x91, 0x2f,
		0x90, 0xe0, 0xdc, 0x26, 0x39, 0x1b, 0x15, 0x81, 0xb6, 0x3b, 0xe1, 0xe8, 0x62, 0x0c, 0x1e, 0x2e,
		0xd1, 0x55, 0xde, 0x65, 0x91, 0x6d, 0xd1, 0x99, 0xf5, 0x62, 0xdb, 0xa3, 0x6f, 0xae, 0xc0, 0xa0,
		0x36, 0xe9, 0xec, 0xa2, 0x44, 0xb6, 0x4b, 0xcb, 0xa3, 0x04, 0xac, 0x25, 0x2d, 0x95, 0xcf, 0xb2,
		0x0d, 0x1d, 0xb5, 0x4b, 0xf1, 0x6e, 0xe7, 0x91, 0xb8, 0x39, 0x30, 0x06, 0x37, 0x2c, 0x06, 0xe1,
		0x77, 0x3b, 0x7b, 0x30, 0x92, 0xa6, 0xbd, 0xb0, 0xd7, 0xdc, 0x68, 0xaf, 0xce, 0x5e, 0x73, 0x74,
		0x2f, 0xce, 0x46, 0x73, 0x18, 0xbf, 0xcd, 0x36, 0x73, 0xe3, 0x7c, 0x60, 0xda, 0xad, 0xdd, 0x53,
		0x7d, 0xff, 0x4a, 0x58, 0x87, 0x79, 0x6a, 0x33, 0x9b, 0xcb, 0x97, 0x61, 0x26, 0x9b, 0xcb, 0x57,
		0x88, 0x56, 0x36, 0x97, 0xaf, 0x6e, 0x79, 0xb1, 0xb9, 0x3c, 0x6f, 0xba, 0xcc, 0xe6, 0xf2, 0xa2,
		0x65, 0x48, 0x6c, 0x2e, 0x5f, 0x6d, 0x7c, 0x60, 0x73, 0x39, 0x89, 0x8d, 0x44, 0x82, 0x23, 0x98,
		0xe8, 0x48, 0x25, 0x3c, 0xe2, 0x89, 0x8f, 0x78, 0x02, 0x24, 0x9b, 0x08, 0xc9, 0x20, 0x44, 0x42,
		0x88, 0x91, 0x38, 0x82, 0x94, 0x19, 0xec, 0x97, 0x4e, 0x83, 0x44, 0x6e, 0x47, 0x79, 0x6a, 0x3e,
		0xdb, 0xc8, 0x49, 0xa0, 0xcc, 0x22, 0x52, 0x06, 0x10, 0x2a, 0xe9, 0xc4, 0xca, 0x18, 0x82, 0x65,
		0x0c, 0xd1, 0x32, 0x83, 0x70, 0xc9, 0x22, 0x5e, 0xc2, 0x08, 0x58, 0x06, 0x11, 0xf9, 0x6d, 0xe4,
		0xa7, 0x83, 0x41, 0x5f, 0xf9, 0xa2, 0x5b, 0xc8, 0x37, 0xd8, 0xc4, 0x59, 0xf4, 0xc5, 0x68, 0xc9,
		0xd8, 0x4f, 0x5e, 0xb8, 0x0a, 0x25, 0x6c, 0x2d, 0x33, 0xc1, 0x60, 0x82, 0xc1, 0x04, 0x83, 0x09,
		0x06, 0x13, 0x0c, 0x26, 0x18, 0x4c, 0x30, 0x98, 0x60, 0xfc, 0xa6, 0xc7, 0x1f, 0x05, 0x61, 0xf2,
		0x6e, 0x53, 0x70, 0x7e, 0x21, 0xf1, 0x08, 0xa7, 0x96, 0x1f, 0x9e, 0x8f, 0xef, 0xfe, 0x57, 0x91,
		0x8e, 0xf1, 0x1f, 0xb1, 0x87, 0xd2, 0x5b, 0x47, 0x41, 0x28, 0x96, 0x21, 0x08, 0x27, 0xf6, 0x73,
		0x97, 0xf1, 0x79, 0x7a, 0xb0, 0xaf, 0xf4, 0xeb, 0x38, 0x8c, 0xfc, 0xc9, 0x1c, 0xa3, 0x6a, 0x70,
		0x1e, 0xa4, 0x6a, 0x62, 0xb1, 0xd7, 0x73, 0xfd, 0x46, 0xf0, 0xd2, 0xf6, 0x7f, 0x72, 0x69, 0x83,
		0x2d, 0xed, 0xca, 0xe6, 0x6e, 0x65, 0x77, 0x7b, 0x67, 0x73, 0x77, 0x8b, 0x6b, 0x9c, 0x09, 0x41,
		0xb1, 0xac, 0x3e, 0x61, 0xd9, 0xbb, 0xc0, 0x96, 0x72, 0x76, 0xc1, 0x6a, 0xed, 0x2e, 0x88, 0xea,
		0x75, 0xb2, 0xf1, 0xc0, 0xb1, 0x05, 0x50, 0xf2, 0xd7, 0xea, 0xf8, 0x99, 0x70, 0x62, 0x41, 0x71,
		0x2c, 0xe4, 0xc4, 0x02, 0xfa, 0xee, 0xe7, 0xfa, 0x6e, 0x0e, 0x2b, 0x40, 0xf0, 0xd6, 0x9c, 0x53,
		0x60, 0x9c, 0xe7, 0xbb, 0xa5, 0xf9, 0x2f, 0x5d, 0xfa, 0x51, 0x20, 0xc3, 0xff, 0x3d, 0x30, 0xb1,
		0xe0, 0x96, 0xf5, 0x9c, 0x5d, 0xb0, 0x0c, 0x33, 0x39, 0xbb, 0x60, 0x85, 0xb8, 0xe5, 0xec, 0x82,
		0xd5, 0x2d, 0x2f, 0xce, 0x2e, 0xc8, 0x9b, 0x38, 0x73, 0x76, 0x41, 0xd1, 0x72, 0x25, 0xce, 0x2e,
		0x58, 0x6d, 0x7c, 0xe0, 0xec, 0x02, 0x12, 0x1b, 0x89, 0x04, 0x47, 0x30, 0xd1, 0x91, 0x4a, 0x78,
		0xc4, 0x13, 0x1f, 0xf1, 0x04, 0x48, 0x36, 0x11, 0x92, 0x41, 0x88, 0x84, 0x10, 0x23, 0x71, 0x04,
		0x29, 0x33, 0x98, 0xd2, 0x22, 0x6d, 0xc4, 0x89, 0xd2, 0x22, 0x12, 0x29, 0x83, 0x09, 0x95, 0x74,
		0x62, 0x65, 0x0c, 0xc1, 0x32, 0x86, 0x68, 0x99, 0x41, 0xb8, 0x64, 0x11, 0x2f, 0x61, 0x04, 0x2c,
		0x83, 0x08, 0xa5, 0x45, 0xda, 0xf9, 0x0d, 0xa5, 0x45, 0x79, 0xbf, 0x28, 0x2d, 0x22, 0xb1, 0x5f,
		0xc2, 0x65, 0x50, 0x5a, 0xc4, 0xf0, 0xbb, 0xcc, 0xa5, 0x4d, 0x69, 0x11, 0xdc, 0xd2, 0xa6, 0xb4,
		0x88, 0x09, 0x41, 0x51, 0xad, 0xa6, 0xb4, 0xa8, 0xc8, 0x96, 0x52, 0x5a, 0xb4, 0x5a, 0xbb, 0x8b,
		0xd4, 0x9e, 0x7e, 0xd3, 0x7c, 0x4a, 0x91, 0x11, 0x5e, 0xdb, 0xfa, 0xe7, 0xd9, 0xc3, 0xa1, 0xda,
		0xa8, 0x38, 0x16, 0x52, 0x6d, 0x44, 0x77, 0xfe, 0x72, 0x77, 0x4e, 0xdd, 0x11, 0x94, 0x03, 0xa7,
		0x00, 0xc9, 0x38, 0x67, 0x98, 0x4a, 0x78, 0x82, 0x9e, 0x30, 0xcd, 0x51, 0xd0, 0xa3, 0xcc, 0x68,
		0x29, 0x66, 0x52, 0x66, 0xb4, 0x42, 0xa8, 0x52, 0x66, 0xb4, 0xba, 0xe5, 0x45, 0x99, 0x51, 0xde,
		0x8c, 0x99, 0x32, 0xa3, 0xa2, 0x25, 0x49, 0x94, 0x19, 0xad, 0x36, 0x3e, 0x50, 0x66, 0x44, 0x62,
		0x23, 0x91, 0xe0, 0x08, 0x26, 0x3a, 0x52, 0x09, 0x8f, 0x78, 0xe2, 0x23, 0x9e, 0x00, 0xc9, 0x26,
		0x42, 0x32, 0x08, 0x91, 0x10, 0x62, 0x24, 0x8e, 0x20, 0x65, 0x06, 0xf7, 0x07, 0x5d, 0xbf, 0x2f,
		0x57, 0x66, 0x94, 0x9a, 0x4f, 0x99, 0x11, 0x09, 0x94, 0x59, 0x44, 0xca, 0x00, 0x42, 0x25, 0x9d,
		0x58, 0x19, 0x43, 0xb0, 0x8c, 0x21, 0x5a, 0x66, 0x10, 0x2e, 0x59, 0xc4, 0x4b, 0x18, 0x01, 0xcb,
		0x20, 0x42, 0x99, 0x91, 0x76, 0x7e, 0x43, 0x99, 0x51, 0xde, 0x2f, 0xca, 0x8c, 0x48, 0xec, 0x97,
		0x70, 0x19, 0x94, 0x19, 0x31, 0xfc, 0x2e, 0x73, 0x69, 0x53, 0x66, 0x04, 0xb7, 0xb4, 0x29, 0x33,
		0x62, 0x42, 0x50, 0x54, 0xab, 0x29, 0x33, 0x2a, 0x7c, 0x8c, 0xb2, 0x22, 0x75, 0x31, 0x48, 0x94,
		0xdc, 0xba, 0xf7, 0xd4, 0x7e, 0x16, 0xbe, 0xf3, 0x30, 0x9b, 0x85, 0x6f, 0x8d, 0x48, 0x67, 0xe1,
		0x5b, 0xdf, 0x72, 0x65, 0xe1, 0x1b, 0xec, 0x42, 0x58, 0xf8, 0x26, 0xab, 0x79, 0x04, 0x22, 0x2c,
		0x7c, 0x6b, 0xe7, 0x37, 0x2c, 0x7c, 0xe7, 0xfd, 0x62, 0xe1, 0x9b, 0xc4, 0x7e, 0x09, 0x97, 0xc1,
		0xc2, 0x37, 0xc3, 0xef, 0x32, 0x97, 0x36, 0x0b, 0xdf, 0x70, 0x4b, 0x9b, 0x85, 0x6f, 0x26, 0x04,
		0x45, 0xb5, 0x9a, 0x85, 0xef, 0x22, 0x5b, 0xca, 0xf9, 0x5a, 0xab, 0xb5, 0xbb, 0x20, 0x03, 0x59,
		0x82, 0x1e, 0x47, 0x6a, 0x41, 0x4d, 0x64, 0x71, 0x7b, 0x1c, 0xa3, 0x55, 0x1c, 0x0b, 0x39, 0x46,
		0x8b, 0x5e, 0xfb, 0x59, 0x5e, 0x9b, 0x93, 0xb3, 0xb4, 0xfb, 0x69, 0x4e, 0xcb, 0x32, 0xce, 0xe7,
		0xa5, 0xc3, 0xa7, 0xfa, 0x83, 0x38, 0x16, 0x36, 0x2f, 0x6b, 0x62, 0x32, 0x27, 0x66, 0x2d, 0xc3,
		0x4c, 0x4e, 0xcc, 0x5a, 0x21, 0x58, 0x39, 0x31, 0x6b, 0x75, 0xcb, 0x8b, 0x13, 0xb3, 0xf2, 0x26,
		0xc7, 0x9c, 0x98, 0x55, 0xb4, 0x7c, 0x88, 0x13, 0xb3, 0x56, 0x1b, 0x1f, 0x38, 0x31, 0x8b, 0xc4,
		0x46, 0x22, 0xc1, 0x11, 0x4c, 0x74, 0xa4, 0x12, 0x1e, 0xf1, 0xc4, 0x47, 0x3c, 0x01, 0x92, 0x4d,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0x58, 0x19, 0x43, 0xb0, 0x8c, 0x21, 0x5a, 0x66, 0x10, 0x2e, 0x59, 0xc4, 0x4b, 0x18, 0x01, 0xcb,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0x98, 0x18, 0xfe, 0xc0, 0xea, 0x12, 0x6c, 0xa4, 0x46, 0x4a, 0xa7, 0x46, 0xed, 0x20, 0x61, 0x92,
		0x13, 0x65, 0x8a, 0x95, 0x8d, 0xf3, 0x9a, 0xc5, 0x07, 0x2e, 0x99, 0x0e, 0x23, 0x41, 0xc3, 0x4e,
		0xd8, 0x70, 0x14, 0x38, 0x8c, 0x85, 0x0e, 0x57, 0xc1, 0xc3, 0x5e, 0xf8, 0xb0, 0x17, 0x40, 0xbc,
		0x85, 0x10, 0x0f, 0x41, 0xc4, 0x44, 0x18, 0xb1, 0x13, 0x48, 0xa5, 0xc1, 0x4c, 0xca, 0x3e, 0x73,
		0x03, 0x0d, 0x8b, 0xda, 0xcf, 0x3c, 0xe9, 0xb4, 0xc9, 0xcc, 0x6c, 0x6e, 0x12, 0x8a, 0xb3, 0x94,
		0x52, 0x40, 0x52, 0x71, 0x97, 0x56, 0xca, 0x48, 0x2c, 0x65, 0xa4, 0x96, 0x1a, 0x92, 0x8b, 0x97,
		0xf4, 0x62, 0x26, 0xc1, 0x4a, 0x44, 0xdc, 0xdb, 0xb1, 0xe0, 0xed, 0xf1, 0x27, 0x41, 0x24, 0xdf,
		0x6c, 0x73, 0x74, 0xf8, 0x85, 0xbe, 0xd9, 0x65, 0x68, 0xba, 0xe3, 0x47, 0x57, 0x82, 0x6d, 0x13,
		0x02, 0xdf, 0x6d, 0xe2, 0xda, 0x69, 0x10, 0xb1, 0x55, 0x08, 0xcc, 0x85, 0xfd, 0x93, 0xb7, 0x91,
		0xb5, 0xe2, 0x28, 0xf0, 0x3e, 0x8e, 0x12, 0x7f, 0x28, 0x83, 0x38, 0x6a, 0x07, 0x57, 0x81, 0x4c,
		0xa7, 0x6f, 0x08, 0xbd, 0x2b, 0x75, 0x2c, 0x6d, 0xff, 0x2b, 0x96, 0x36, 0xb1, 0xa5, 0xdd, 0xdc,
		0xde, 0x6b, 0xee, 0xb5, 0x76, 0xb7, 0xf7, 0x76, 0xb0, 0xc6, 0x91, 0x10, 0xac, 0x97, 0xd5, 0xbc,
		0xda, 0x9e, 0xee, 0x70, 0x2f, 0x61, 0x1d, 0x23, 0x29, 0xb7, 0x7d, 0xe8, 0xa5, 0xdd, 0xca, 0xef,
		0x47, 0x7f, 0xb2, 0xf5, 0xb4, 0xc1, 0x69, 0xdf, 0xc6, 0x86, 0xca, 0x3b, 0xd5, 0x5d, 0xd1, 0xce,
		0x3f, 0x99, 0xd3, 0xec, 0x83, 0xe1, 0xb0, 0x73, 0x9d, 0x8f, 0xf3, 0xc4, 0xde, 0xb9, 0x35, 0x72,
		0xe7, 0x6b, 0xe8, 0xc6, 0xd1, 0x62, 0x44, 0xc6, 0x71, 0xa3, 0xd9, 0x48, 0x39, 0x27, 0xa8, 0x49,
		0x0e, 0x37, 0x64, 0xee, 0xfb, 0x8b, 0xa6, 0xd6, 0xf2, 0x68, 0x29, 0xda, 0x44, 0x4b, 0xd1, 0x72,
		0x0c, 0x45, 0x4b, 0xd1, 0x4a, 0x4d, 0x46, 0x4b, 0x51, 0x45, 0x86, 0xa3, 0xa5, 0x08, 0x6a, 0x80,
		0x4b, 0x5a, 0xc4, 0x66, 0x9b, 0x46, 0xe9, 0x71, 0x43, 0xe1, 0x5f, 0x26, 0xe2, 0x92, 0x83, 0xc7,
		0x9d, 0xb5, 0xe8, 0x30, 0xd8, 0x88, 0xa1, 0xf5, 0x8a, 0x4c, 0xf3, 0x8f, 0x3f, 0xf2, 0x72, 0x5a,
		0x23, 0x53, 0x60, 0xc8, 0x03, 0x94, 0xcb, 0x03, 0x26, 0xd3, 0x94, 0x35, 0x95, 0x89, 0x1f, 0x44,
		0x62, 0xa4, 0x87, 0xe9, 0x98, 0x4f, 0x52, 0xf0, 0xd4, 0x74, 0x0c, 0x1d, 0x40, 0x86, 0x80, 0x0c,
		0x01, 0x19, 0x02, 0x32, 0x04, 0x64, 0x08, 0xc8, 0x10, 0x56, 0xf2, 0x91, 0x63, 0xe8, 0xc0, 0x6a,
		0xe3, 0x03, 0x86, 0x0e, 0x40, 0xd8, 0x70, 0x14, 0x38, 0x8c, 0x85, 0x0e, 0x57, 0xc1, 0xc3, 0x5e,
		0xf8, 0xb0, 0x17, 0x40, 0xbc, 0x85, 0x10, 0x0f, 0x41, 0xc4, 0x44, 0x18, 0xb1, 0x13, 0x48, 0xa5,
		0xc1, 0xc3, 0x78, 0x92, 0x81, 0xcb, 0x74, 0xe6, 0x40, 0x6e, 0x3e, 0x46, 0x0e, 0x40, 0x40, 0xa9,
		0x25, 0xa4, 0x14, 0x10, 0x54, 0xdc, 0x85, 0x95, 0x32, 0x02, 0x4b, 0x19, 0xa1, 0xa5, 0x86, 0xe0,
		0xe2, 0x25, 0xbc, 0x98, 0x09, 0xb0, 0x12, 0x11, 0x35, 0x46, 0x0e, 0x6c, 0xb5, 0x18, 0x8f, 0x1c,
		0x68, 0x61, 0xe4, 0x40, 0xc5, 0x5f, 0x18, 0x39, 0x00, 0x61, 0xbf, 0x84, 0xb7, 0x81, 0x91, 0x03,
		0x08, 0xbf, 0xcb, 0x5c, 0xda, 0x18, 0x39, 0x40, 0x6e, 0x69, 0xb7, 0x76, 0x76, 0xde, 0x60, 0xda,
		0x00, 0x72, 0x81, 0x35, 0xb3, 0x1a, 0xd3, 0x06, 0xd6, 0x3e, 0x3c, 0xf1, 0xe8, 0x7d, 0x9a, 0x9b,
		0x15, 0x32, 0xe8, 0x85, 0x52, 0x24, 0x76, 0xa2, 0xde, 0x5d, 0x27, 0xe7, 0xa8, 0x77, 0xd7, 0xb7,
		0x5c, 0x51, 0xef, 0x26, 0xf6, 0x46, 0x50, 0xef, 0x86, 0xa2, 0xf9, 0x09, 0x22, 0xfc, 0xeb, 0xdd,
		0xc1, 0x48, 0x44, 0x32, 0x90, 0xb7, 0x3c, 0xfa, 0xb9, 0xe6, 0x89, 0x9c, 0x2d, 0x86, 0x59, 0xb5,
		0x66, 0x15, 0x97, 0xfe, 0xc0, 0x4f, 0x19, 0xc7, 0xad, 0x19, 0x48, 0x56, 0xdf, 0xea, 0x7b, 0xfd,
		0xc1, 0x81, 0x6b, 0x9f, 0x79, 0xee, 0x87, 0x9e, 0xc9, 0x35, 0x7c, 0x65, 0xb5, 0x9a, 0x94, 0xed,
		0xcd, 0x88, 0x0d, 0xd6, 0x37, 0x24, 0x1e, 0x11, 0xe5, 0x39, 0xa6, 0x71, 0x78, 0x62, 0x1c, 0x58,
		0xb6, 0xe5, 0x7e, 0x28, 0xe0, 0xea, 0x73, 0xa6, 0x4b, 0x25, 0xca, 0xd4, 0xa0, 0xed, 0xa7, 0xd4,
		0x1d, 0x18, 0x9d, 0xf6, 0x7f, 0xad, 0xb6, 0x7b, 0xe2, 0x1d, 0x76, 0x3b, 0x7d, 0xd7, 0x31, 0xac,
		0x8e, 0xdb, 0xd7, 0xd8, 0xbf, 0xe7, 0xbb, 0xdf, 0x01, 0x1e, 0x6d, 0xf0, 0x06, 0xae, 0x65, 0x5b,
		0x7f, 0x99, 0xed, 0x7b, 0x02, 0x41, 0x1d, 0xa8, 0x5b, 0x35, 0x75, 0x46, 0xfb, 0x4f, 0xaf, 0x6f,
		0xb5, 0x81, 0x1a, 0x50, 0x5b, 0x39, 0x6a, 0x67, 0x86, 0x65, 0x1b, 0x07, 0xb6, 0x09, 0x0f, 0x07,
		0xec, 0xaa, 0xc3, 0xce, 0xea, 0x9d, 0xb5, 0xbc, 0x8e, 0x69, 0x1d, 0x9f, 0x1c, 0x74, 0x1d, 0xcf,
		0x68, 0xb7, 0x1d, 0xb3, 0x0f, 0x41, 0x07, 0xf0, 0x56, 0x2f, 0xe8, 0x3a, 0x65, 0x06, 0x61, 0xb6,
		0x3d, 0xbb, 0xdf, 0x03, 0x74, 0x80, 0x6e, 0xd5, 0xd0, 0xd9, 0x56, 0xe7, 0x9d, 0x67, 0xb8, 0xae,
		0x63, 0x1d, 0x0c, 0x5c, 0x13, 0x7e, 0x0e, 0xc8, 0x55, 0x83, 0x5c, 0xcf, 0xe9, 0xba, 0xe6, 0xa1,
		0x6b, 0x75, 0x3b, 0x79, 0xbd, 0x0e, 0xdc, 0x81, 0xbb, 0x95, 0xa7, 0xae, 0xa7, 0x56, 0xc7, 0x3b,
		0x76, 0xba, 0x03, 0x44, 0x56, 0xe0, 0x56, 0x4d, 0x1e, 0x61, 0x75, 0x5c, 0xd3, 0x39, 0x32, 0x0e,
		0x4d, 0x24, 0x12, 0x20, 0xaf, 0x2a, 0xf2, 0x4e, 0x8d, 0xf7, 0x79, 0x90, 0x45, 0xdd, 0x04, 0xd4,
		0x55, 0x18, 0x5e, 0xff, 0xf4, 0x6c, 0xa3, 0x83, 0xea, 0x30, 0x70, 0xab, 0x2c, 0x8b, 0x00, 0x6a,
		0x40, 0xad, 0x12, 0x25, 0xd7, 0x44, 0x45, 0x18, 0xe0, 0xd5, 0x03, 0x1e, 0x52, 0x08, 0x90, 0x57,
		0x4b, 0x0a, 0xe1, 0x98, 0x7d, 0xd3, 0x39, 0xc3, 0x0d, 0x58, 0xb0, 0x57, 0x2d, 0x7b, 0xae, 0xe9,
		0xb5, 0xcd, 0x23, 0x63, 0x60, 0xbb, 0xde, 0xa9, 0xe9, 0x3a, 0xd6, 0x21, 0xa0, 0x03, 0x74, 0xab,
		0x86, 0x6e, 0xd0, 0xc9, 0xdd, 0x1d, 0xf6, 0xd3, 0x81, 0xbb, 0xca, 0xd3, 0xd8, 0xb6, 0x69, 0x1b,
		0x1f, 0xbc, 0x33, 0xc3, 0xb1, 0x0c, 0xd7, 0xea, 0x76, 0xc0, 0x1d, 0xb8, 0x5b, 0x35, 0x77, 0xe6,
		0x7b, 0xd7, 0xec, 0xb4, 0xcd, 0x36, 0xee, 0x8a, 0x81, 0xbb, 0x4a, 0x13, 0x0b, 0xab, 0x73, 0x7f,
		0x7f, 0x22, 0xf3, 0x7b, 0xa0, 0x0e, 0xd4, 0x55, 0x12, 0x65, 0xed, 0x2e, 0x6a, 0x27, 0x80, 0xad,
		0x4a, 0x49, 0x07, 0xda, 0x40, 0xdb, 0xaa, 0x69, 0x73, 0xcc, 0xbe, 0xd5, 0x1e, 0x18, 0xb6, 0x52,
		0x69, 0x2b, 0xeb, 0x77, 0x70, 0x8e, 0x79, 0x96, 0x58, 0xe5, 0x4b, 0x5a, 0xdd, 0x8a, 0x75, 0x17,
		0x03, 0x30, 0x6a, 0x80, 0xa9, 0xd4, 0x45, 0x0c, 0xba, 0xa8, 0xd1, 0xc5, 0xbe, 0x5b, 0x18, 0x48,
		0x91, 0x43, 0x4a, 0xa5, 0xae, 0x60, 0xe0, 0x45, 0x0d, 0x2f, 0xc5, 0xba, 0x7f, 0x01, 0x18, 0x39,
		0xc1, 0xa5, 0x4e, 0x97, 0x2f, 0xe0, 0xa2, 0x06, 0x97, 0x32, 0xdd, 0xbc, 0x40, 0x8b, 0x24, 0x5a,
		0xca, 0x74, 0xed, 0x82, 0x2f, 0x7a, 0xa9, 0xa2, 0x02, 0xfb, 0x10, 0x80, 0x15, 0x49, 0x3d, 0xaf,
		0xd0, 0x16, 0x7a, 0x10, 0x46, 0x8d, 0x30, 0x95, 0xba, 0x6d, 0x41, 0x17, 0xbd, 0xb0, 0xa8, 0x40,
		0x57, 0x2d, 0xb0, 0x22, 0xa9, 0xe6, 0x81, 0x14, 0x90, 0x5a, 0xaa, 0xd2, 0x6a, 0xa2, 0x72, 0x0a,
		0xc0, 0x56, 0x0b, 0x18, 0xa4, 0x3c, 0x08, 0x5b, 0xa9, 0x94, 0x57, 0xab, 0xeb, 0x15, 0x8c, 0x51,
		0x63, 0x4c, 0xa1, 0xee, 0x56, 0xc0, 0x45, 0x0d, 0x2e, 0xb5, 0xba, 0x58, 0xc1, 0x17, 0xc9, 0xb4,
		0x51, 0x99, 0x6e, 0x55, 0xf0, 0x45, 0x8d, 0x2f, 0xb5, 0xba, 0x52, 0xc1, 0x17, 0x39, 0x81, 0xaf,
		0x50, 0xf7, 0x29, 0xe8, 0x22, 0x19, 0x1d, 0x79, 0x77, 0x99, 0x02, 0x2a, 0xba, 0x92, 0x0b, 0x54,
		0x81, 0xaa, 0x65, 0x51, 0xa5, 0x52, 0xd7, 0x28, 0xe8, 0xaa, 0x9d, 0xae, 0x1e, 0x4e, 0xe2, 0x05,
		0x6d, 0x75, 0x53, 0xe7, 0x1a, 0xc7, 0xad, 0x26, 0x46, 0x2e, 0x00, 0xb4, 0x55, 0x83, 0xd6, 0x73,
		0xcc, 0x23, 0xeb, 0x3d, 0x06, 0xdd, 0x83, 0xb6, 0x2a, 0x68, 0xcb, 0x76, 0xb0, 0x3a, 0xdd, 0x81,
		0x6b, 0x3a, 0x98, 0x77, 0x0f, 0xe2, 0xaa, 0x09, 0xa4, 0xc0, 0x0c, 0x98, 0x55, 0x14, 0x46, 0x8f,
		0x6c, 0xe3, 0x18, 0x73, 0xd9, 0xc0, 0x5b, 0x15, 0x81, 0xb4, 0xa9, 0x54, 0x20, 0xc5, 0x94, 0x2c,
		0xac, 0xf4, 0x75, 0x5a, 0xe1, 0xaa, 0x66, 0xfe, 0x00, 0x0a, 0x19, 0x3e, 0xa8, 0x52, 0x9f, 0x2a,
		0x55, 0x32, 0x79, 0x90, 0x85, 0x8c, 0x1d, 0x38, 0xa9, 0x1f, 0xfe, 0x98, 0x67, 0xe6, 0xe0, 0x0a,
		0x19, 0x38, 0xc8, 0x52, 0x93, 0xac, 0x02, 0xa2, 0x43, 0xa3, 0x87, 0x3d, 0x07, 0xe0, 0xad, 0x56,
		0xee, 0x1c, 0xcf, 0xb0, 0x8f, 0xbb, 0x8e, 0xe5, 0x9e, 0x9c, 0xa2, 0x8a, 0x0d, 0xe2, 0x2a, 0x21,
		0xee, 0xfe, 0x4f, 0x28, 0x63, 0xd7, 0xfb, 0x85, 0x32, 0x36, 0x96, 0x38, 0x82, 0x09, 0xc8, 0x42,
		0xd0, 0x40, 0xb0, 0x50, 0x28, 0x48, 0xf0, 0xba, 0xce, 0x7c, 0xac, 0xe5, 0x61, 0x29, 0x13, 0x07,
		0xae, 0x19, 0x51, 0x14, 0x4b, 0x5f, 0x06, 0x71, 0xa4, 0xed, 0x33, 0x72, 0xdd, 0x5a, 0x3a, 0xfc,
		0x24, 0xae, 0xfd, 0xb1, 0x2f, 0x3f, 0x4d, 0x9d, 0x75, 0x23, 0x1e, 0x8b, 0x68, 0x18, 0x47, 0x97,
		0xc1, 0x95, 0x1e, 0x09, 0xf9, 0x25, 0x4e, 0x3e, 0xeb, 0x41, 0x94, 0x4a, 0x3f, 0x1a, 0x8a, 0xc6,
		0xe3, 0x17, 0xd2, 0x27, 0xaf, 0x34, 0xc6, 0x49, 0x2c, 0xe3, 0x61, 0x1c, 0xa6, 0xe5, 0xb3, 0x46,
		0x90, 0x06, 0x69, 0x23, 0x14, 0x37, 0x22, 0x2c, 0x1e, 0x1a, 0x61, 0x10, 0x7d, 0xd6, 0x53, 0xe9,
		0x4b, 0xa1, 0x8f, 0x7c, 0xe9, 0x5f, 0xf8, 0xa9, 0x68, 0x84, 0xe9, 0xb8, 0x21, 0xc3, 0x9b, 0x74,
		0xfa, 0x2d, 0xfb, 0x11, 0x3d, 0x12, 0xc1, 0xd5, 0xa7, 0x8b, 0x38, 0xd1, 0x7d, 0x29, 0x93, 0xe0,
		0x62, 0x22, 0xa7, 0x06, 0xe4, 0x2f, 0xa5, 0xe5, 0xb3, 0xc6, 0xbd, 0x2d, 0xa5, 0x0d, 0xe9, 0xe4,
		0x22, 0xfb, 0x9f, 0xf2, 0xc7, 0xc6, 0x64, 0xfa, 0x7e, 0x52, 0x99, 0xf8, 0x41, 0x24, 0x46, 0xfa,
		0xf4, 0xf7, 0x64, 0xbf, 0x9a, 0x51, 0x5d, 0x46, 0x4b, 0x65, 0x32, 0x19, 0xca, 0xa8, 0x08, 0xa8,
		0xdd, 0xf2, 0x23, 0xea, 0xe4, 0x97, 0xdf, 0x2a, 0xde, 0xb9, 0xf7, 0xe8, 0xcf, 0xe9, 0xe3, 0x17,
		0xbc, 0xde, 0xec, 0xe3, 0x29, 0x9f, 0x79, 0x56, 0x1a, 0xa4, 0x9e, 0x9d, 0x7d, 0x3c, 0xf9, 0x83,
		0x67, 0x07, 0xd1, 0xe7, 0xfe, 0xf4, 0x12, 0xb5, 0x8b, 0x0f, 0xc7, 0xb3, 0xd3, 0xb1, 0xe7, 0x86,
		0x37, 0xe9, 0xf4, 0x5b, 0xf6, 0x03, 0x9d, 0xe2, 0xf2, 0x1b, 0xb3, 0x8f, 0xc6, 0x9b, 0xbd, 0x92,
		0x96, 0xcf, 0xbc, 0x7b, 0x33, 0xca, 0xdf, 0xdf, 0xcf, 0x3f, 0x9a, 0xe2, 0xd1, 0x1b, 0x3c, 0xfc,
		0x68, 0xa6, 0xbf, 0x24, 0xfb, 0xb5, 0x3c, 0x14, 0x01, 0x7d, 0xef, 0x49, 0xdb, 0x42, 0xe2, 0x7e,
		0x9d, 0x9b, 0x3f, 0x5f, 0x43, 0x3f, 0xce, 0xc0, 0x83, 0xaf, 0x8d, 0xe7, 0xa6, 0xed, 0xb3, 0xe9,
		0x7a, 0x42, 0xc2, 0x5e, 0x50, 0x9b, 0x44, 0x89, 0x48, 0x45, 0x72, 0x23, 0x46, 0xfa, 0x85, 0x1f,
		0x8d, 0xbe, 0x04, 0xa3, 0xcc, 0xb7, 0xd0, 0xf6, 0x85, 0x65, 0xd9, 0xe1, 0xbb, 0xd6, 0x13, 0x8f,
		0x39, 0xef, 0x82, 0x68, 0xa4, 0xed, 0x6f, 0x6c, 0x11, 0x37, 0xf3, 0x30, 0x73, 0x61, 0xda, 0xfe,
		0xc6, 0x26, 0x71, 0x43, 0x7b, 0x89, 0xb8, 0x0c, 0xbe, 0xf2, 0x88, 0xdf, 0x33, 0x6e, 0xe3, 0xa1,
		0x3e, 0x0d, 0x9b, 0x1c, 0x82, 0x5b, 0x3f, 0x9e, 0x24, 0x43, 0xc1, 0x26, 0xdd, 0xd5, 0xde, 0x89,
		0xdb, 0x2f, 0x71, 0x32, 0x5d, 0x61, 0xda, 0x38, 0x27, 0x83, 0x49, 0x6d, 0xe1, 0xc4, 0x4f, 0x8d,
		0xe4, 0x6a, 0x72, 0x2d, 0x22, 0xa9, 0xed, 0x6f, 0xc8, 0x64, 0x22, 0xb8, 0x14, 0x45, 0xee, 0xad,
		0x2e, 0xc1, 0x46, 0xde, 0xa4, 0x74, 0xde, 0xd4, 0x0e, 0x12, 0x26, 0x09, 0x93, 0x90, 0x93, 0xb1,
		0x3e, 0x4e, 0x82, 0x38, 0x09, 0xe4, 0x2d, 0x1f, 0x2f, 0x36, 0x0b, 0x14, 0x8f, 0xec, 0x67, 0xe2,
		0x11, 0x78, 0x48, 0x1c, 0x76, 0x52, 0x87, 0xa3, 0xe4, 0x61, 0x2c, 0x7d, 0xb8, 0x4a, 0x20, 0xf6,
		0x52, 0x88, 0xbd, 0x24, 0xe2, 0x2d, 0x8d, 0x78, 0x48, 0x24, 0x26, 0x52, 0x89, 0x9d, 0x64, 0x2a,
		0x0d, 0x66, 0x27, 0x9a, 0x9e, 0x84, 0x1a, 0x66, 0xb2, 0xe9, 0xb1, 0x7c, 0xda, 0x64, 0x66, 0x36,
		0x37, 0x19, 0xc5, 0x59, 0x4e, 0x29, 0x20, 0xab, 0xb8, 0xcb, 0x2b, 0x65, 0x64, 0x96, 0x32, 0x72,
		0x4b, 0x0d, 0xd9, 0xc5, 0x4b, 0x7e, 0x31, 0x93, 0x61, 0x25, 0x22, 0xee, 0xed, 0x58, 0xf0, 0xf6,
		0xf8, 0xa1, 0xf0, 0x2f, 0x13, 0x71, 0xc9, 0xd1, 0xe3, 0xcf, 0xea, 0x43, 0xbb, 0x0c, 0x6d, 0xef,
		0x15, 0x9b, 0x2f, 0xfe, 0xf8, 0x23, 0xdf, 0x62, 0xd6, 0x28, 0x55, 0x26, 0x76, 0xb0, 0xae, 0xbb,
		0x67, 0xd1, 0xf2, 0x4d, 0x87, 0x6c, 0x13, 0x26, 0x6e, 0x7b, 0x26, 0x37, 0xf8, 0x15, 0x9b, 0x91,
		0x2d, 0x21, 0x5b, 0x42, 0xb6, 0x84, 0x6c, 0x09, 0xd9, 0x12, 0xb2, 0x25, 0x3e, 0x88, 0x70, 0x2b,
		0x5e, 0x97, 0x86, 0xf3, 0xd9, 0xd3, 0xf8, 0xd3, 0x98, 0xc5, 0x65, 0x83, 0xe3, 0xcf, 0x84, 0xda,
		0x26, 0x53, 0xf3, 0xb9, 0x0a, 0x36, 0x15, 0x84, 0x9b, 0x42, 0x02, 0x4e, 0x15, 0x21, 0xa7, 0x9c,
		0xa0, 0x53, 0x4e, 0xd8, 0xa9, 0x25, 0xf0, 0x78, 0x0a, 0x3d, 0xa6, 0x82, 0xaf, 0x44, 0x87, 0x6d,
		0x99, 0xfc, 0x49, 0xc4, 0x08, 0x84, 0x10, 0x97, 0x61, 0xec, 0xcb, 0x37, 0xdb, 0x9c, 0xa3, 0x46,
		0x21, 0xa2, 0xf6, 0x18, 0xbf, 0x05, 0x5b, 0x44, 0x57, 0x99, 0x20, 0xe7, 0x3d, 0x6c, 0x8e, 0xff,
		0xd8, 0x2f, 0xed, 0x34, 0x88, 0xd8, 0xeb, 0x0f, 0x45, 0xd2, 0x8b, 0x27, 0x6f, 0x27, 0x1b, 0xc9,
		0xa8, 0xed, 0x6f, 0x34, 0x15, 0x79, 0x3f, 0x47, 0x89, 0x3f, 0x94, 0x41, 0x1c, 0xb5, 0x83, 0xab,
		0x40, 0xa6, 0xd3, 0x0f, 0x0a, 0xb3, 0x0b, 0x29, 0xb8, 0x00, 0xff, 0x2b, 0x5c, 0x00, 0x5c, 0x00,
		0x5c, 0xc0, 0x3a, 0x65, 0x23, 0xfc, 0xad, 0xe7, 0x39, 0x05, 0x93, 0xdf, 0xf5, 0x66, 0x18, 0xe2,
		0xf8, 0x6e, 0x5c, 0x7f, 0x92, 0xb3, 0x32, 0xdd, 0xc0, 0xae, 0x48, 0x3c, 0x46, 0xc5, 0x9f, 0xd2,
		0x5a, 0x40, 0xc5, 0x9f, 0xce, 0xb2, 0x46, 0xc5, 0x9f, 0xf8, 0x1b, 0x42, 0xc5, 0x1f, 0xca, 0x69,
		0x41, 0x74, 0xd4, 0xa9, 0xf8, 0x4f, 0x82, 0x48, 0xbe, 0x55, 0xa0, 0xd6, 0xbf, 0xc3, 0xf8, 0x2d,
		0x38, 0x7e, 0x74, 0x25, 0x50, 0xea, 0xaf, 0xff, 0x83, 0x40, 0xa9, 0x9f, 0xee, 0xdb, 0x99, 0xd5,
		0xf9, 0x36, 0x51, 0xe7, 0x43, 0x34, 0x5f, 0xa1, 0x0b, 0x40, 0xa9, 0x9f, 0xbc, 0x0b, 0xd8, 0x85,
		0x0b, 0x40, 0x1a, 0x02, 0xeb, 0x1f, 0x7e, 0xa1, 0xd4, 0x0f, 0x8b, 0xd9, 0x07, 0x64, 0xae, 0x27,
		0x87, 0x94, 0xf6, 0xaf, 0xc1, 0xe4, 0xf9, 0xa7, 0xa3, 0xa4, 0x1b, 0xff, 0x1e, 0xbf, 0xd8, 0xe0,
		0xd8, 0x1f, 0xbb, 0xa1, 0xf6, 0x84, 0xfa, 0xd9, 0x87, 0x76, 0x30, 0xfb, 0xcc, 0xbc, 0xfe, 0xf4,
		0x33, 0xeb, 0x15, 0x1f, 0x19, 0xa7, 0xc3, 0x46, 0xf8, 0x39, 0x62, 0x4c, 0x88, 0x5b, 0x6a, 0x4a,
		0x23, 0x6e, 0x19, 0xde, 0xf4, 0xd5, 0xec, 0x20, 0x95, 0xd3, 0x65, 0xcc, 0x6b, 0xba, 0xdd, 0x69,
		0x10, 0x99, 0xa1, 0xb8, 0x16, 0x51, 0x9e, 0x9d, 0x30, 0x9a, 0x31, 0x71, 0xea, 0x7f, 0x7d, 0x60,
		0xf9, 0xd6, 0xdb, 0x66, 0xb3, 0xb5, 0xdb, 0x6c, 0x6e, 0xee, 0xbe, 0xd9, 0xdd, 0xdc, 0xdb, 0xd9,
		0xd9, 0x6a, 0x6d, 0x31, 0xaa, 0x17, 0x6b, 0xdd, 0x64, 0x24, 0x12, 0x31, 0x3a, 0x98, 0x92, 0x1f,
		0x4d, 0xc2, 0x10, 0x0e, 0x05, 0x9a, 0x13, 0x5a, 0x93, 0xd7, 0x96, 0x9f, 0xf5, 0x55, 0x97, 0x38,
		0xc4, 0x6e, 0x1d, 0x2c, 0xc4, 0x21, 0x76, 0x70, 0xef, 0x2f, 0x76, 0xef, 0x38, 0xc7, 0x8e, 0x94,
		0x1f, 0xc7, 0x51, 0x76, 0xca, 0xf9, 0x42, 0x6d, 0x22, 0x83, 0x30, 0xf8, 0x3f, 0xa6, 0x07, 0xd9,
		0x3d, 0xb5, 0x1d, 0xc7, 0xd8, 0x2d, 0xc3, 0x4c, 0x1c, 0x63, 0xb7, 0x42, 0x6a, 0x71, 0x8c, 0xdd,
		0x2a, 0x8b, 0x81, 0x38, 0xc6, 0xae, 0x5a, 0x19, 0x8d, 0x63, 0xec, 0xd6, 0x2d, 0x73, 0xe2, 0x73,
		0x8c, 0x1d, 0xab, 0xb9, 0xc2, 0x2c, 0xe7, 0x09, 0xe3, 0xd0, 0x3a, 0x08, 0x1c, 0x05, 0x84, 0x0e,
		0x57, 0xc1, 0xc3, 0x5e, 0xf8, 0xb0, 0x17, 0x40, 0xbc, 0x85, 0x10, 0x0f, 0x41, 0xc4, 0x44, 0x18,
		0xb1, 0x13, 0x48, 0xa5, 0xc1, 0x7c, 0xe7, 0xfd, 0xb2, 0x9f, 0xf3, 0x8b, 0x63, 0xeb, 0x20, 0xa8,
		0xd6, 0x40, 0x58, 0x71, 0x17, 0x58, 0xca, 0x08, 0x2d, 0x65, 0x04, 0x97, 0x1a, 0xc2, 0x8b, 0x97,
		0x00, 0x63, 0x26, 0xc4, 0x4a, 0x44, 0xf8, 0x1f, 0x5b, 0xc7, 0x7b, 0x0e, 0x2f, 0xe3, 0xf9, 0xbb,
		0xdc, 0xe7, 0xee, 0x32, 0x9e, 0x48, 0xa1, 0x42, 0xf3, 0xbd, 0x22, 0x1d, 0xb7, 0xaa, 0x0c, 0xd5,
		0x54, 0xa9, 0xc3, 0x96, 0x71, 0x73, 0xbd, 0x12, 0x4d, 0xf5, 0x58, 0xda, 0x58, 0xda, 0xc8, 0x06,
		0x58, 0x5b, 0x7d, 0x8e, 0x0e, 0xc7, 0x75, 0x0f, 0x4d, 0x9a, 0xe4, 0x98, 0x1b, 0x96, 0x79, 0x61,
		0x66, 0x3d, 0x2a, 0xde, 0x55, 0x98, 0x8d, 0x8a, 0x77, 0x8d, 0x9c, 0xa3, 0xe2, 0x5d, 0xdf, 0x72,
		0x45, 0xc5, 0x9b, 0xd8, 0x1b, 0x41, 0xc5, 0x1b, 0x8a, 0xe6, 0x27, 0x88, 0x28, 0x50, 0xf1, 0x1e,
		0x89, 0x48, 0x06, 0xf2, 0x36, 0x11, 0x97, 0x8c, 0x2b, 0xde, 0x5b, 0x0c, 0xc7, 0xd0, 0x6a, 0x56,
		0x71, 0xe9, 0x0f, 0xfc, 0x54, 0xf0, 0x3f, 0x0e, 0xc2, 0xea, 0x5b, 0x7d, 0xaf, 0x3f, 0x38, 0x70,
		0xed, 0x33, 0xcf, 0xfd, 0xd0, 0x33, 0xb9, 0x86, 0xaf, 0xac, 0x4e, 0x93, 0xb2, 0x9e, 0x0a, 0xcc,
		0xbc, 0xe0, 0x77, 0x4f, 0x94, 0xe7, 0x98, 0xc6, 0xe1, 0x89, 0x71, 0x60, 0xd9, 0x96, 0xfb, 0xa1,
		0x80, 0xab, 0xcf, 0x99, 0x2e, 0x95, 0x28, 0x53, 0x83, 0xb6, 0x9f, 0x52, 0x77, 0x60, 0x74, 0xda,
		0xff, 0xb5, 0xda, 0xee, 0x89, 0x77, 0xd8, 0xed, 0xf4, 0x5d, 0xc7, 0xb0, 0x3a, 0x6e, 0x5f, 0xc3,
		0xcc, 0x60, 0x80, 0xb7, 0x62, 0xf0, 0x06, 0xae, 0x65, 0x5b, 0x7f, 0x99, 0xed, 0x7b, 0x02, 0x41,
		0x1d, 0xa8, 0x5b, 0x35, 0x75, 0x46, 0xfb, 0x4f, 0xaf, 0x6f, 0xb5, 0x81, 0x1a, 0x50, 0x5b, 0x39,
		0x6a, 0x67, 0x86, 0x65, 0x1b, 0x07, 0xb6, 0x09, 0x0f, 0x07, 0xec, 0xaa, 0xc3, 0xce, 0xea, 0x9d,
		0xb5, 0xbc, 0x8e, 0x69, 0x1d, 0x9f, 0x1c, 0x74, 0x1d, 0xcf, 0x68, 0xb7, 0x1d, 0xb3, 0x0f, 0x41,
		0x07, 0xf0, 0x56, 0x2f, 0xe8, 0x3a, 0x65, 0x06, 0x61, 0xb6, 0x3d, 0xbb, 0xdf, 0x03, 0x74, 0x80,
		0x6e, 0xd5, 0xd0, 0xd9, 0x56, 0xe7, 0x9d, 0x67, 0xb8, 0xae, 0x63, 0x1d, 0x0c, 0x5c, 0x13, 0x7e,
		0x0e, 0xc8, 0x55, 0x83, 0x5c, 0xcf, 0xe9, 0xba, 0xe6, 0xa1, 0x6b, 0x75, 0x3b, 0x79, 0xbd, 0x0e,
		0xdc, 0x81, 0xbb, 0x95, 0xa7, 0xae, 0xa7, 0x56, 0xc7, 0x3b, 0x76, 0xba, 0x03, 0x44, 0x56, 0xe0,
		0x56, 0x4d, 0x1e, 0x61, 0x75, 0x5c, 0xd3, 0x39, 0x32, 0x0e, 0x4d, 0x24, 0x12, 0x20, 0xaf, 0x2a,
		0xf2, 0x4e, 0x8d, 0xf7, 0x79, 0x90, 0x45, 0xdd, 0x04, 0xd4, 0x55, 0x18, 0x5e, 0xff, 0xf4, 0x6c,
		0xa3, 0x83, 0xea, 0x30, 0x70, 0xab, 0x2c, 0x8b, 0x00, 0x6a, 0x40, 0xad, 0x12, 0x25, 0xd7, 0x44,
		0x45, 0x18, 0xe0, 0xd5, 0x03, 0x1e, 0x52, 0x08, 0x90, 0x57, 0x4b, 0x0a, 0xe1, 0x98, 0x7d, 0xd3,
		0x39, 0xc3, 0x0d, 0x58, 0xb0, 0x57, 0x2d, 0x7b, 0xae, 0xe9, 0xb5, 0xcd, 0x23, 0x63, 0x60, 0xbb,
		0xde, 0xa9, 0xe9, 0x3a, 0xd6, 0x21, 0xa0, 0x03, 0x74, 0xab, 0x86, 0x6e, 0xd0, 0xc9, 0xdd, 0x1d,
		0xf6, 0xd3, 0x81, 0xbb, 0xca, 0xd3, 0xd8, 0xb6, 0x69, 0x1b, 0x1f, 0xbc, 0x33, 0xc3, 0xb1, 0x0c,
		0xd7, 0xea, 0x76, 0xc0, 0x1d, 0xb8, 0x5b, 0x35, 0x77, 0xe6, 0x7b, 0xd7, 0xec, 0xb4, 0xcd, 0x36,
		0xee, 0x8a, 0x81, 0xbb, 0x4a, 0x13, 0x0b, 0xab, 0x73, 0x7f, 0x7f, 0x22, 0xf3, 0x7b, 0xa0, 0x0e,
		0xd4, 0x55, 0x12, 0x65, 0xed, 0x2e, 0x6a, 0x27, 0x80, 0xad, 0x4a, 0x49, 0x07, 0xda, 0x40, 0xdb,
		0xaa, 0x69, 0x73, 0xcc, 0xbe, 0xd5, 0x1e, 0x18, 0xb6, 0x52, 0x69, 0x2b, 0xeb, 0x77, 0x70, 0x8e,
		0x59, 0x96, 0x58, 0xe5, 0x4b, 0x5a, 0xdd, 0x8a, 0x75, 0x17, 0x03, 0x30, 0x6a, 0x80, 0xa9, 0xd4,
		0x45, 0x0c, 0xba, 0xa8, 0xd1, 0xc5, 0xbe, 0x5b, 0x18, 0x48, 0x91, 0x43, 0x4a, 0xa5, 0xae, 0x60,
		0xe0, 0x45, 0x0d, 0x2f, 0xc5, 0xba, 0x7f, 0x01, 0x18, 0x39, 0xc1, 0xa5, 0x4e, 0x97, 0x2f, 0xe0,
		0xa2, 0x06, 0x97, 0x32, 0xdd, 0xbc, 0x40, 0x8b, 0x24, 0x5a, 0xca, 0x74, 0xed, 0x82, 0x2f, 0x7a,
		0xa9, 0xa2, 0x02, 0xfb, 0x10, 0x80, 0x15, 0x49, 0x3d, 0xaf, 0xd0, 0x16, 0x7a, 0x10, 0x46, 0x8d,
		0x30, 0x95, 0xba, 0x6d, 0x41, 0x17, 0xbd, 0xb0, 0xa8, 0x40, 0x57, 0x2d, 0xb0, 0x22, 0xa9, 0xe6,
		0x81, 0x14, 0x90, 0x5a, 0xaa, 0xd2, 0x6a, 0xa2, 0x72, 0x0a, 0xc0, 0x56, 0x0b, 0x18, 0xa4, 0x3c,
		0x08, 0x5b, 0xa9, 0x94, 0x57, 0xab, 0xeb, 0x15, 0x8c, 0x51, 0x63, 0x4c, 0xa1, 0xee, 0x56, 0xc0,
		0x45, 0x0d, 0x2e, 0xb5, 0xba, 0x58, 0xc1, 0x17, 0xc9, 0xb4, 0x51, 0x99, 0x6e, 0x55, 0xf0, 0x45,
		0x8d, 0x2f, 0xb5, 0xba, 0x52, 0xc1, 0x17, 0x39, 0x81, 0xaf, 0x50, 0xf7, 0x29, 0xe8, 0x22, 0x19,
		0x1d, 0x79, 0x77, 0x99, 0x02, 0x2a, 0xba, 0x92, 0x0b, 0x54, 0x81, 0xaa, 0x65, 0x51, 0xa5, 0x52,
		0xd7, 0x28, 0xe8, 0xaa, 0x9d, 0xae, 0x1e, 0x4e, 0xe2, 0x05, 0x6d, 0x75, 0x53, 0xe7, 0x1a, 0xc7,
		0xad, 0x26, 0x46, 0x2e, 0x00, 0xb4, 0x55, 0x83, 0xd6, 0x73, 0xcc, 0x23, 0xeb, 0x3d, 0x06, 0xdd,
		0x83, 0xb6, 0x2a, 0x68, 0xcb, 0x76, 0xb0, 0x3a, 0xdd, 0x81, 0x6b, 0x3a, 0x98, 0x77, 0x0f, 0xe2,
		0xaa, 0x09, 0xa4, 0xc0, 0x0c, 0x98, 0x55, 0x14, 0x46, 0x8f, 0x6c, 0xe3, 0x18, 0x73, 0xd9, 0xc0,
		0x5b, 0x15, 0x81, 0xb4, 0xa9, 0x54, 0x20, 0xc5, 0x94, 0x2c, 0xac, 0xf4, 0x75, 0x5a, 0xe1, 0xaa,
		0x66, 0xfe, 0x00, 0x0a, 0x19, 0x3e, 0xa8, 0x52, 0x9f, 0x2a, 0x55, 0x32, 0x79, 0x90, 0x85, 0x8c,
		0x1d, 0x38, 0xa9, 0x1f, 0xfe, 0x98, 0x67, 0xe6, 0xe0, 0x0a, 0x19, 0x38, 0xc8, 0x52, 0x93, 0xac,
		0x02, 0xa2, 0x43, 0xa3, 0x87, 0x3d, 0x07, 0xe0, 0xad, 0x56, 0xee, 0x1c, 0xcf, 0xb0, 0x8f, 0xbb,
		0x8e, 0xe5, 0x9e, 0x9c, 0xa2, 0x8a, 0x0d, 0xe2, 0x2a, 0x21, 0xee, 0xfe, 0x4f, 0x28, 0x63, 0xd7,
		0xfb, 0x85, 0x32, 0x36, 0x96, 0x38, 0x82, 0x09, 0xc8, 0x42, 0xd0, 0x40, 0xb0, 0x50, 0x28, 0x48,
		0xf0, 0xba, 0xce, 0x7c, 0xac, 0xe5, 0x61, 0x29, 0x13, 0x07, 0xae, 0x19, 0x51, 0x14, 0x4b, 0x5f,
		0x06, 0x71, 0xa4, 0xed, 0x33, 0x72, 0xdd, 0x5a, 0x3a, 0xfc, 0x24, 0xae, 0xfd, 0xb1, 0x2f, 0x3f,
		0x4d, 0x9d, 0x75, 0x23, 0x1e, 0x8b, 0x68, 0x18, 0x47, 0x97, 0xc1, 0x95, 0x1e, 0x09, 0xf9, 0x25,
		0x4e, 0x3e, 0xeb, 0x41, 0x94, 0x4a, 0x3f, 0x1a, 0x8a, 0xc6, 0xe3, 0x17, 0xd2, 0x27, 0xaf, 0x34,
		0xc6, 0x49, 0x2c, 0xe3, 0x61, 0x1c, 0xa6, 0xe5, 0xb3, 0x46, 0x90, 0x06, 0x69, 0x23, 0x14, 0x37,
		0x22, 0x2c, 0x1e, 0x1a, 0x61, 0x10, 0x7d, 0xd6, 0x53, 0xe9, 0x4b, 0xa1, 0x8f, 0x7c, 0xe9, 0x5f,
		0xf8, 0xa9, 0x68, 0x84, 0xe9, 0xb8, 0x21, 0xc3, 0x9b, 0x74, 0xfa, 0x2d, 0xfb, 0x11, 0x3d, 0x12,
		0xc1, 0xd5, 0xa7, 0x8b, 0x38, 0xd1, 0x7d, 0x29, 0x93, 0xe0, 0x62, 0x22, 0xa7, 0x06, 0xe4, 0x2f,
		0xa5, 0xe5, 0xb3, 0xc6, 0xbd, 0x2d, 0xa5, 0x0d, 0xe9, 0xe4, 0x22, 0xfb, 0x9f, 0xf2, 0xc7, 0xc6,
		0x44, 0x06, 0x61, 0xf0, 0x7f, 0x62, 0xa4, 0x5f, 0xf8, 0xd1, 0xe8, 0x4b, 0x30, 0x92, 0x9f, 0x1a,
		0xd9, 0xef, 0x66, 0x54, 0x98, 0xd1, 0x52, 0x99, 0x4c, 0x86, 0x32, 0x2a, 0x22, 0x6a, 0xb7, 0xfc,
		0x8c, 0x3a, 0xf9, 0xf5, 0xb7, 0x8a, 0xb7, 0xee, 0x3d, 0xfa, 0x73, 0xfa, 0xf8, 0x05, 0xaf, 0x37,
		0xfb, 0x7c, 0xca, 0x67, 0x9e, 0x95, 0x06, 0xa9, 0x67, 0x67, 0x9f, 0x4f, 0xfe, 0xe0, 0xd9, 0x41,
		0xf4, 0xb9, 0x3f, 0xbd, 0x44, 0xed, 0xe2, 0xd3, 0xf1, 0xec, 0x74, 0xec, 0xb9, 0xe1, 0x4d, 0x3a,
		0xfd, 0x96, 0xfd, 0x40, 0xa7, 0xb8, 0xfe, 0xc6, 0xec, 0xb3, 0xf1, 0x66, 0xaf, 0xa4, 0xe5, 0x33,
		0xef, 0xde, 0x8c, 0xf2, 0xf7, 0xf7, 0xf3, 0xcf, 0xa6, 0x78, 0xf4, 0x06, 0xc5, 0x67, 0x73, 0x30,
		0xfb, 0x68, 0xbc, 0xec, 0xf7, 0xf2, 0xd0, 0x04, 0xf4, 0xfd, 0x27, 0x6d, 0x0b, 0x89, 0x7b, 0x76,
		0x6e, 0x1e, 0x7d, 0x1d, 0x3d, 0x39, 0x03, 0x1f, 0xbe, 0x3e, 0xbe, 0x9b, 0xb6, 0xd7, 0xa6, 0xeb,
		0x0b, 0x69, 0x5a, 0x46, 0xd4, 0x3b, 0x6b, 0xef, 0xc4, 0xed, 0x74, 0x1d, 0xc9, 0xdb, 0x31, 0x55,
		0x05, 0xa7, 0xd9, 0x41, 0x2a, 0xa7, 0x8b, 0x8b, 0x74, 0xd8, 0xd0, 0x4e, 0x83, 0xc8, 0x0c, 0xc5,
		0xb5, 0x88, 0x64, 0xaa, 0xed, 0x6f, 0x6c, 0xfe, 0x4e, 0xd8, 0x52, 0xff, 0xeb, 0x03, 0x4b, 0xb7,
		0xde, 0x36, 0x9b, 0xad, 0xdd, 0x66, 0x73, 0x73, 0xf7, 0xcd, 0xee, 0xe6, 0xde, 0xce, 0xce, 0x56,
		0x6b, 0x6b, 0x87, 0xb0, 0xf1, 0xdd, 0x64, 0x24, 0x12, 0x31, 0x3a, 0x98, 0x52, 0x1b, 0x4d, 0xc2,
		0x10, 0x8b, 0x5d, 0x3d, 0x09, 0xa6, 0xbc, 0xf4, 0x22, 0xac, 0xb3, 0x54, 0xd5, 0x57, 0x34, 0xd5,
		0x14, 0x3d, 0xad, 0x42, 0xcb, 0x22, 0x62, 0x8e, 0x94, 0xba, 0x03, 0x55, 0xd7, 0x71, 0x12, 0xf4,
		0x98, 0xca, 0x79, 0x4a, 0x5a, 0x2e, 0x92, 0x8e, 0x23, 0x22, 0xe4, 0x84, 0xb4, 0x49, 0x34, 0x12,
		0x97, 0x41, 0x24, 0x46, 0xfa, 0x6c, 0x61, 0x50, 0xf3, 0x43, 0xe5, 0x8d, 0xea, 0xa7, 0xa6, 0x12,
		0x73, 0xe6, 0xef, 0x82, 0x68, 0x34, 0x4d, 0x80, 0x88, 0x99, 0x75, 0x98, 0x39, 0x11, 0x7a, 0x39,
		0xa4, 0xd6, 0x4b, 0xc4, 0x65, 0xf0, 0x95, 0x66, 0xe0, 0x9b, 0x41, 0x17, 0x0f, 0xf5, 0x69, 0xbc,
		0xa1, 0x18, 0x2e, 0xfa, 0xf1, 0x24, 0x19, 0x0a, 0xb2, 0x89, 0x97, 0xf6, 0x4e, 0xdc, 0x7e, 0x89,
		0x93, 0xe9, 0x8a, 0xd0, 0xc6, 0xf9, 0x27, 0x4d, 0x34, 0x8b, 0x3d, 0xf1, 0x53, 0x23, 0xb9, 0x9a,
		0x5c, 0x8b, 0x48, 0x6a, 0xfb, 0x1b, 0x32, 0x99, 0x08, 0xaa, 0xe9, 0xf6, 0xbd, 0x95, 0x25, 0x98,
		0x10, 0xfc, 0xac, 0x04, 0x7f, 0x3b, 0xa0, 0x59, 0x76, 0x7c, 0x12, 0x5d, 0xe9, 0xfa, 0x95, 0x79,
		0x7a, 0x80, 0xaa, 0x7b, 0xa1, 0x29, 0x0b, 0xc8, 0xcb, 0x03, 0x0e, 0x32, 0x81, 0x91, 0x5c, 0xe0,
		0x22, 0x1b, 0xd8, 0xc9, 0x07, 0x76, 0x32, 0x82, 0x97, 0x9c, 0xa0, 0x29, 0x2b, 0x88, 0xca, 0x0b,
		0xf2, 0x32, 0xa3, 0x34, 0x30, 0xdf, 0xe2, 0x47, 0xde, 0x09, 0xcd, 0xfc, 0x3a, 0x87, 0x1d, 0x89,
		0xc4, 0x85, 0x06, 0x1b, 0xc1, 0xc1, 0x49, 0x78, 0x30, 0x14, 0x20, 0xdc, 0x84, 0x08, 0x5b, 0x41,
		0xc2, 0x56, 0x98, 0xf0, 0x14, 0x28, 0xb4, 0x85, 0x0a, 0x71, 0xc1, 0xc2, 0x46, 0xb8, 0x94, 0x86,
		0x86, 0x22, 0xba, 0xca, 0xee, 0x8a, 0x32, 0xf1, 0x5e, 0xb3, 0x00, 0x51, 0xd8, 0xcd, 0xc4, 0x03,
		0x14, 0x92, 0x66, 0x93, 0x89, 0xb9, 0x5c, 0xa4, 0x0d, 0x47, 0x89, 0xc3, 0x58, 0xea, 0x70, 0x95,
		0x3c, 0xec, 0xa5, 0x0f, 0x7b, 0x09, 0xc4, 0x5b, 0x0a, 0xf1, 0x90, 0x44, 0x4c, 0xa4, 0x51, 0x89,
		0x82, 0x7b, 0x3b, 0x16, 0x3c, 0x3d, 0xf6, 0x24, 0x88, 0xe4, 0x5b, 0x4e, 0xfe, 0xba, 0x90, 0x1f,
		0x3b, 0x8c, 0x4c, 0x76, 0xfc, 0xe8, 0x4a, 0xb0, 0x1b, 0x07, 0xc6, 0x6f, 0x96, 0x86, 0x76, 0x1a,
		0x44, 0xec, 0x02, 0x39, 0x53, 0x5d, 0xfd, 0xc4, 0xfc, 0x6c, 0xe8, 0x1d, 0x63, 0xfb, 0x8f, 0x12,
		0x7f, 0x28, 0x83, 0x38, 0x6a, 0x07, 0x57, 0x41, 0xde, 0xde, 0xc3, 0x6f, 0xea, 0xc7, 0xef, 0x0c,
		0x97, 0xac, 0xff, 0x15, 0x4b, 0xb6, 0xe6, 0x25, 0xbb, 0xbd, 0xb3, 0x83, 0x45, 0x0b, 0x21, 0xae,
		0x96, 0xb5, 0xe7, 0x18, 0x88, 0xb1, 0x2e, 0x41, 0x25, 0xef, 0x6c, 0x66, 0x57, 0xf6, 0x25, 0xdc,
		0x8f, 0xcd, 0x3c, 0xd2, 0xa1, 0xe8, 0x5b, 0x25, 0xc7, 0x28, 0xfa, 0x56, 0xb7, 0x0c, 0x51, 0xf4,
		0xad, 0xf9, 0x0d, 0xa0, 0xe8, 0x0b, 0xc5, 0x51, 0xa0, 0x80, 0xa2, 0x6f, 0xd5, 0xf2, 0x03, 0x45,
		0xdf, 0x55, 0x7f, 0xa1, 0xe8, 0x0b, 0x5d, 0xfd, 0x0c, 0xf3, 0x51, 0xf4, 0x45, 0xb4, 0x5c, 0x64,
		0xc9, 0xa2, 0xe8, 0x5b, 0xfb, 0x92, 0x45, 0xd1, 0x17, 0x42, 0x5c, 0x39, 0x6b, 0x51, 0xf4, 0x5d,
		0x9b, 0xa0, 0xa2, 0xdd, 0x14, 0x8e, 0x8c, 0x59, 0xd5, 0x37, 0x37, 0x1b, 0x65, 0xdf, 0x55, 0x98,
		0x8b, 0xb2, 0x6f, 0x85, 0x20, 0xa3, 0xec, 0x5b, 0xdd, 0x32, 0x44, 0xd9, 0xb7, 0xe6, 0x37, 0x80,
		0xb2, 0x2f, 0x34, 0x47, 0x81, 0x02, 0xdf, 0xb2, 0xef, 0x45, 0x10, 0xf9, 0xc9, 0x2d, 0xc3, 0xba,
		0xef, 0x1e, 0x64, 0xfd, 0x1a, 0x58, 0x88, 0xc3, 0x4d, 0x96, 0x6b, 0xaf, 0x7a, 0x83, 0x62, 0x9f,
		0x8c, 0x9b, 0x7c, 0xf2, 0x0a, 0x9b, 0x73, 0xaa, 0xd4, 0x99, 0x2c, 0x3b, 0x98, 0x7d, 0x04, 0xb3,
		0x61, 0xdc, 0x8f, 0x5e, 0xe0, 0x70, 0x3e, 0x15, 0xe1, 0x93, 0x4e, 0x08, 0x8f, 0xad, 0x62, 0xb1,
		0xed, 0x8e, 0xd3, 0x76, 0x3b, 0x26, 0xf5, 0x16, 0x8c, 0x8b, 0x41, 0x5d, 0x65, 0x03, 0xe3, 0x62,
		0x50, 0x3f, 0x51, 0xb4, 0x6e, 0x82, 0x34, 0x69, 0x2d, 0xea, 0x23, 0x0f, 0xe6, 0xaf, 0xf8, 0x97,
		0x89, 0xb8, 0xe4, 0xe0, 0x71, 0x67, 0xf3, 0xe4, 0x76, 0x19, 0xd8, 0xda, 0x2b, 0x32, 0xcf, 0x3f,
		0xfe, 0xc8, 0xb3, 0xb2, 0x46, 0xa6, 0xc0, 0x90, 0x07, 0x28, 0x64, 0x19, 0x4e, 0x3c, 0x5c, 0xd8,
		0x44, 0x9c, 0x78, 0xb8, 0x64, 0x4b, 0x71, 0xe2, 0xe1, 0x9a, 0x2e, 0x76, 0x9c, 0x78, 0x48, 0xb7,
		0x1e, 0x8b, 0x53, 0x10, 0x09, 0x54, 0x60, 0x71, 0x2e, 0x22, 0x47, 0x8b, 0x70, 0x2e, 0x22, 0xdc,
		0x2b, 0xed, 0xd3, 0xd5, 0xd4, 0xf6, 0xa2, 0x38, 0x2a, 0x91, 0xb2, 0x25, 0x44, 0xbc, 0xe3, 0x2c,
		0xd3, 0x0c, 0x46, 0x44, 0xd6, 0x26, 0xcd, 0xbc, 0x92, 0x6e, 0x1e, 0xc9, 0x2a, 0x6f, 0xa4, 0x99,
		0x27, 0x52, 0x59, 0x8a, 0x44, 0x05, 0x8a, 0x7a, 0xc2, 0x84, 0x90, 0x0c, 0x51, 0x46, 0x7e, 0xd0,
		0x50, 0x1b, 0xf5, 0xc7, 0xf6, 0x7a, 0x2d, 0xa8, 0xd9, 0x95, 0x51, 0x73, 0x61, 0xca, 0xb8, 0x2e,
		0x02, 0x1e, 0x8b, 0xbb, 0xa7, 0xaa, 0xd7, 0x41, 0xd5, 0xe7, 0x16, 0x6a, 0x74, 0x09, 0x44, 0x4e,
		0x64, 0x23, 0x75, 0xe2, 0x1a, 0x91, 0x13, 0xd5, 0xc8, 0x6c, 0x81, 0xa3, 0xb4, 0xc5, 0x8d, 0xe0,
		0x16, 0x36, 0x6a, 0x5b, 0xd4, 0xc8, 0x6e, 0x41, 0x23, 0xbb, 0xc5, 0x8c, 0xe6, 0x16, 0xb2, 0xf5,
		0x96, 0xa9, 0x54, 0x4e, 0x04, 0xd3, 0xd2, 0xdb, 0x54, 0x8a, 0x6b, 0x3d, 0x18, 0xd1, 0x59, 0xe0,
		0x65, 0xb0, 0x2c, 0x4d, 0xa3, 0x52, 0xa9, 0x24, 0xb5, 0xb7, 0x9c, 0xdc, 0x1e, 0x72, 0x8a, 0x7b,
		0xc5, 0x09, 0xef, 0x09, 0xa7, 0xba, 0xf7, 0x9b, 0xfc, 0x1e, 0x6f, 0xf2, 0x7b, 0xb9, 0x69, 0xef,
		0xd9, 0xc6, 0xdd, 0xa7, 0x87, 0x1f, 0x15, 0xb9, 0xbd, 0xd6, 0x64, 0xc3, 0xdf, 0xbf, 0x72, 0xc7,
		0xb7, 0x84, 0x6c, 0xea, 0xf9, 0x52, 0x8a, 0x24, 0x22, 0x37, 0x29, 0x54, 0xfb, 0xdf, 0xc7, 0x4d,
		0x7d, 0xcf, 0xd0, 0x8f, 0x7c, 0xfd, 0xf2, 0xfc, 0x9f, 0xe6, 0xdd, 0xdf, 0x7f, 0xff, 0xf1, 0x93,
		0x17, 0xfe, 0x43, 0xc7, 0x4b, 0x9c, 0x53, 0xfa, 0x80, 0xbb, 0x7d, 0xeb, 0x3d, 0x3e, 0xe5, 0x55,
		0x7c, 0xca, 0xb8, 0x67, 0x82, 0x64, 0x14, 0xf7, 0x4c, 0x96, 0x7b, 0xcf, 0x84, 0xca, 0x00, 0x05,
		0xa6, 0xf7, 0x4b, 0x08, 0x0c, 0x3b, 0x58, 0xd3, 0x7b, 0x25, 0x64, 0x4a, 0x41, 0xe4, 0x34, 0x30,
		0x91, 0xd2, 0x0f, 0xee, 0x99, 0xf0, 0x28, 0xf1, 0xe0, 0x9e, 0x09, 0xf7, 0x52, 0x0e, 0xee, 0x99,
		0xd0, 0x93, 0xa9, 0x64, 0x4a, 0x35, 0x04, 0xdb, 0xde, 0x29, 0xb5, 0xb5, 0x3f, 0x6d, 0x5b, 0xbf,
		0x0f, 0xe3, 0xeb, 0x2a, 0xeb, 0x7e, 0x5b, 0xa3, 0x05, 0x3b, 0xdb, 0xd1, 0x5f, 0xb7, 0x78, 0xa3,
		0xb1, 0x91, 0x9f, 0xce, 0xc6, 0x7d, 0xd2, 0x1b, 0xf5, 0x69, 0x6c, 0xcc, 0xaf, 0x6b, 0xc5, 0x10,
		0xa9, 0xc0, 0x30, 0xaf, 0xbc, 0x68, 0xb5, 0x6e, 0x34, 0x64, 0x58, 0x6b, 0xa9, 0x27, 0x1c, 0x57,
		0x1f, 0x0c, 0xab, 0xfd, 0x8d, 0x15, 0x3b, 0x91, 0xba, 0x9d, 0x07, 0x4f, 0xa7, 0x51, 0x83, 0xaf,
		0x60, 0xe5, 0x23, 0xaa, 0x75, 0x0d, 0xd5, 0x2d, 0xd0, 0x6a, 0x7e, 0x53, 0x45, 0x2e, 0xa0, 0xae,
		0xa5, 0xcf, 0x69, 0xc9, 0x57, 0xb8, 0xd0, 0x19, 0x2c, 0xf0, 0x6a, 0x96, 0xf5, 0xea, 0x17, 0x59,
		0x05, 0x0b, 0x4c, 0x0b, 0xd3, 0xb1, 0x7e, 0x31, 0xb9, 0xbc, 0x14, 0x89, 0x9e, 0x06, 0xff, 0x57,
		0x5d, 0xe9, 0xe9, 0xbe, 0xbc, 0xf4, 0xc8, 0x80, 0x8a, 0x9c, 0x4a, 0xb5, 0xfd, 0x21, 0x95, 0xdf,
		0xd3, 0xa8, 0xe3, 0xde, 0x45, 0x8d, 0xf7, 0x28, 0xea, 0xba, 0x17, 0x51, 0xfb, 0x3d, 0x87, 0xda,
		0xef, 0x2d, 0xd4, 0x7b, 0x0f, 0x41, 0x2d, 0xa1, 0x53, 0x75, 0xbf, 0x44, 0x4d, 0x8d, 0x83, 0xb5,
		0x36, 0x0a, 0xd6, 0xd4, 0x18, 0x58, 0xdb, 0x4d, 0xed, 0x3a, 0x6f, 0x62, 0x13, 0xb8, 0x69, 0x5d,
		0xf7, 0x4d, 0x6a, 0x32, 0x37, 0xa5, 0xc9, 0xdc, 0x84, 0xa6, 0x71, 0xd3, 0x59, 0xed, 0x62, 0x59,
		0x5d, 0x8d, 0x77, 0x5a, 0xa5, 0x29, 0xc4, 0xfc, 0xb8, 0x52, 0x5d, 0x1e, 0x31, 0x2f, 0xbc, 0xd4,
		0x74, 0x07, 0xac, 0xf6, 0xbd, 0x53, 0x14, 0xf6, 0x4c, 0x11, 0xda, 0x2b, 0x45, 0x65, 0x8f, 0x14,
		0xb9, 0xbd, 0x51, 0xe4, 0xf6, 0x44, 0xd1, 0xda, 0x0b, 0xb5, 0x5e, 0x5b, 0x29, 0x6a, 0xdf, 0xf3,
		0x54, 0x7a, 0x8c, 0x49, 0x10, 0xc9, 0xad, 0x56, 0x9d, 0x0e, 0xa3, 0x88, 0x1f, 0xad, 0x1a, 0x4d,
		0x70, 0xfc, 0xe8, 0x4a, 0xd4, 0xde, 0x82, 0x44, 0x60, 0x07, 0xdc, 0x69, 0x10, 0x11, 0xda, 0xdd,
		0x4a, 0xab, 0x2f, 0xff, 0xcc, 0x0f, 0x27, 0x82, 0x90, 0x3d, 0x47, 0x89, 0x3f, 0x94, 0x41, 0x1c,
		0xb5, 0x83, 0xab, 0x20, 0xdf, 0x83, 0x54, 0xff, 0x46, 0x56, 0x02, 0xbb, 0x14, 0x4f, 0xfd, 0xaf,
		0x40, 0xf8, 0x27, 0x08, 0xb7, 0x76, 0x76, 0xde, 0xec, 0x00, 0x63, 0x5a, 0x5a, 0xa4, 0xfe, 0xdf,
		0x7e, 0x8e, 0x7d, 0x43, 0x0a, 0x94, 0x42, 0xb0, 0x6f, 0xe8, 0xe9, 0x26, 0x82, 0x47, 0xb7, 0x5c,
		0x6b, 0xeb, 0xe5, 0xa4, 0xb5, 0x95, 0xc0, 0x4e, 0xc7, 0x07, 0xd9, 0x45, 0xe9, 0x07, 0xff, 0x27,
		0xea, 0x68, 0xd0, 0xc4, 0xfe, 0x20, 0x56, 0x4b, 0x9c, 0xc3, 0xd2, 0x5e, 0xdb, 0x7d, 0x41, 0xff,
		0x5a, 0xcc, 0xd8, 0x0f, 0xf4, 0xeb, 0x9f, 0xe2, 0xb5, 0xd4, 0x83, 0xf1, 0x4d, 0x53, 0x4f, 0x84,
		0x3f, 0xfc, 0xe4, 0x5f, 0x04, 0x61, 0x20, 0x6f, 0xab, 0xdf, 0x14, 0xf4, 0x5d, 0x2b, 0xb0, 0x33,
		0x68, 0x29, 0xbf, 0x10, 0x3b, 0x83, 0xaa, 0xc1, 0x08, 0x3b, 0x83, 0xb0, 0x33, 0x68, 0x59, 0x97,
		0xb2, 0xf2, 0x9d, 0x41, 0x39, 0xb2, 0x22, 0xad, 0x6f, 0x73, 0x50, 0x69, 0x01, 0xf6, 0x07, 0xa9,
		0x16, 0x0e, 0x08, 0x84, 0x85, 0xba, 0xc3, 0x03, 0x99, 0x30, 0x41, 0x26, 0x5c, 0xd0, 0x08, 0x1b,
		0xeb, 0x51, 0x14, 0xab, 0x6d, 0x7f, 0xd0, 0xb8, 0xde, 0xdd, 0x21, 0x8f, 0x82, 0x4b, 0xcd, 0x7b,
		0x84, 0xb6, 0xb0, 0x47, 0x08, 0x7b, 0x84, 0xb0, 0x47, 0x88, 0x7e, 0x48, 0xa2, 0x15, 0x9a, 0xea,
		0x09, 0x51, 0x35, 0x85, 0xaa, 0xda, 0x43, 0x56, 0x69, 0xc0, 0xb5, 0x24, 0x35, 0x34, 0x30, 0x37,
		0x07, 0x03, 0x03, 0x31, 0x30, 0x90, 0x7c, 0x80, 0xa3, 0x16, 0xe8, 0xc8, 0x06, 0x3c, 0xb2, 0x81,
		0x8f, 0x66, 0x00, 0xac, 0x37, 0x10, 0xd6, 0x1c, 0x10, 0xcb, 0x8f, 0x04, 0x03, 0x03, 0x7f, 0x21,
		0xd3, 0x22, 0x39, 0x30, 0x30, 0x0f, 0xe1, 0x98, 0x01, 0xbd, 0x6e, 0x55, 0x08, 0x5a, 0xd5, 0x08,
		0x88, 0x39, 0x88, 0x39, 0x88, 0x39, 0x88, 0x39, 0x88, 0x39, 0x88, 0x39, 0x88, 0xb9, 0x85, 0xc5,
		0x5c, 0xe1, 0x73, 0xa0, 0xe6, 0x2a, 0xff, 0x28, 0x70, 0xfa, 0xf9, 0xfc, 0xa5, 0x02, 0x2d, 0x07,
		0x2d, 0x07, 0x2d, 0x07, 0x2d, 0x07, 0x2d, 0x57, 0xfd, 0x47, 0x42, 0xe6, 0xf4, 0xf3, 0x6b, 0x21,
		0x93, 0x60, 0x48, 0xef, 0xe8, 0xf3, 0xc2, 0x2e, 0x9c, 0x7b, 0x4e, 0x39, 0x74, 0x52, 0x0c, 0xa1,
		0x84, 0x43, 0x29, 0xd5, 0x90, 0x4a, 0x3e, 0xb4, 0x92, 0x0f, 0xb1, 0xb4, 0x43, 0x2d, 0x8d, 0x90,
		0x4b, 0x24, 0xf4, 0xd2, 0x2b, 0xa7, 0x3c, 0xf1, 0x58, 0x5f, 0x82, 0x91, 0xd0, 0x49, 0x05, 0xc0,
		0x87, 0x41, 0x70, 0x97, 0x90, 0x49, 0x34, 0xa6, 0xd1, 0x3c, 0xfe, 0xa2, 0xe5, 0xd5, 0x37, 0xa8,
		0x4d, 0xab, 0x21, 0xae, 0xae, 0x9e, 0x98, 0x37, 0x1b, 0x05, 0xb2, 0x45, 0xd4, 0x3e, 0x82, 0x63,
		0x41, 0x88, 0xfa, 0xfc, 0x7f, 0x2f, 0x09, 0xff, 0x2b, 0x96, 0xc4, 0x4b, 0x97, 0x44, 0x6b, 0x77,
		0x77, 0x77, 0x7b, 0x6b, 0x07, 0x2b, 0x83, 0xb7, 0x26, 0xa3, 0x67, 0xcd, 0xf9, 0x6f, 0xb8, 0x1e,
		0x44, 0x3c, 0x27, 0x91, 0xdd, 0xcd, 0x4f, 0x64, 0x32, 0x85, 0x5d, 0xce, 0x44, 0x1d, 0x36, 0x2a,
		0x44, 0xcf, 0x01, 0x09, 0x15, 0xa2, 0x5f, 0xc7, 0x1c, 0x15, 0xa2, 0x17, 0x1a, 0x88, 0x0a, 0x11,
		0x97, 0x6c, 0x81, 0x70, 0x85, 0xa8, 0xf6, 0x51, 0xc4, 0xf3, 0xe2, 0x5f, 0x0b, 0xc5, 0xa1, 0x9f,
		0x7c, 0xa1, 0x38, 0xa4, 0x64, 0x26, 0xbc, 0x89, 0x14, 0x98, 0xb9, 0xbb, 0xff, 0xf7, 0x92, 0x40,
		0x71, 0xe8, 0xc5, 0x4b, 0xa2, 0xb9, 0xb9, 0x87, 0xc2, 0x90, 0x02, 0xa5, 0x98, 0x0d, 0x14, 0x86,
		0x08, 0x5e, 0x0f, 0x0a, 0x85, 0xa1, 0x31, 0xad, 0xa4, 0x9e, 0x56, 0xcf, 0x14, 0x51, 0x77, 0x8d,
		0xd2, 0xd0, 0x73, 0x48, 0x42, 0x69, 0xe8, 0xd7, 0x31, 0x47, 0x69, 0xe8, 0x85, 0x06, 0xa2, 0x34,
		0xc4, 0x25, 0x57, 0x20, 0x5c, 0x1a, 0xca, 0x46, 0x23, 0x93, 0x5b, 0x80, 0x65, 0xd3, 0xc9, 0x5b,
		0x42, 0x36, 0xf5, 0x7c, 0x29, 0x45, 0x12, 0x91, 0x2b, 0x11, 0x69, 0xaf, 0x5e, 0x7d, 0xdc, 0xd4,
		0xf7, 0xce, 0xbf, 0x7d, 0xdc, 0xd2, 0xf7, 0xce, 0xf3, 0xa7, 0x5b, 0xd9, 0x43, 0xfe, 0x7c, 0xfb,
		0xe3, 0xa6, 0xde, 0x9c, 0x3d, 0xdf, 0xf9, 0xb8, 0xa9, 0xef, 0x9c, 0xbf, 0xfe, 0xfb, 0xef, 0x3f,
		0x5e, 0xff, 0xf3, 0xe6, 0xee, 0xf9, 0x3f, 0xd8, 0x28, 0x7e, 0xd9, 0xeb, 0x6f, 0xaf, 0x3e, 0x6e,
		0xe9, 0xdb, 0xe7, 0xb3, 0x3f, 0xbc, 0xf9, 0xb8, 0xa9, 0x6f, 0x9f, 0xbf, 0x7e, 0x4d, 0xc7, 0x03,
		0x9d, 0x53, 0x42, 0xa7, 0xdb, 0xb7, 0xde, 0x93, 0xe5, 0xe7, 0x7f, 0x94, 0x00, 0xfa, 0x8f, 0x86,
		0xdc, 0x11, 0xb9, 0xe3, 0x13, 0x46, 0x53, 0xfd, 0x22, 0x90, 0xf4, 0x52, 0xc7, 0xdc, 0x2c, 0x64,
		0x8e, 0xc8, 0x1c, 0x91, 0x39, 0x22, 0x73, 0x44, 0xe6, 0x88, 0xcc, 0x71, 0x6d, 0x32, 0xc7, 0x8b,
		0x38, 0x0e, 0x85, 0x1f, 0x51, 0xcc, 0x1a, 0xb7, 0x20, 0xdc, 0xc8, 0x08, 0xb7, 0xc9, 0x58, 0x1f,
		0xc5, 0x5f, 0x22, 0x7a, 0xd2, 0x6d, 0x66, 0x18, 0xc4, 0x1b, 0xc4, 0x1b, 0xc4, 0x1b, 0xc4, 0x1b,
		0xc4, 0x1b, 0xc4, 0x1b, 0xc4, 0x1b, 0xc4, 0x1b, 0x19, 0xf1, 0xb6, 0xd6, 0x13, 0x6f, 0x6a, 0x3e,
		0x6b, 0xfb, 0x89, 0x3d, 0x14, 0x0f, 0xe8, 0xfd, 0xde, 0xc9, 0xa6, 0x8d, 0xd9, 0x59, 0x77, 0xc5,
		0x93, 0x06, 0x85, 0x19, 0x72, 0x1b, 0xe4, 0xce, 0xf4, 0x3d, 0x95, 0xd6, 0xf8, 0xa6, 0xe9, 0x3c,
		0xb8, 0x70, 0x5e, 0xaf, 0xb8, 0x70, 0xc5, 0x93, 0x3a, 0x4e, 0xed, 0xa6, 0xe3, 0x02, 0x6a, 0x1d,
		0xc2, 0x38, 0xb9, 0x98, 0x22, 0x4e, 0x68, 0x0c, 0x63, 0x61, 0x10, 0x06, 0x31, 0x62, 0x10, 0x23,
		0x9b, 0x4c, 0x10, 0x83, 0x18, 0xb9, 0x67, 0x7c, 0x18, 0xc4, 0x48, 0x4f, 0x96, 0x92, 0x19, 0xc4,
		0x98, 0xc7, 0x24, 0x82, 0x37, 0xc4, 0x73, 0xbb, 0x68, 0x15, 0x55, 0xb7, 0x50, 0x54, 0x25, 0x1f,
		0x42, 0x09, 0x87, 0x52, 0xaa, 0x21, 0x95, 0x7c, 0x68, 0x25, 0x1f, 0x62, 0x69, 0x87, 0x5a, 0x3a,
		0xb5, 0xa8, 0x0d, 0x42, 0x45, 0x55, 0x2a, 0x21, 0xb8, 0x34, 0xe8, 0x32, 0xf4, 0xaf, 0x52, 0x7a,
		0x4e, 0x61, 0xe6, 0x47, 0x73, 0xf3, 0x88, 0xad, 0x37, 0x5a, 0x81, 0x99, 0x6c, 0x80, 0xa6, 0x1c,
		0xa8, 0x19, 0x04, 0x6c, 0xea, 0x81, 0x9b, 0x4d, 0x00, 0x67, 0x13, 0xc8, 0x79, 0x04, 0x74, 0x5a,
		0x81, 0x9d, 0x58, 0x80, 0x27, 0x1b, 0xe8, 0xef, 0x73, 0x6f, 0x12, 0xa7, 0x04, 0xfd, 0x3c, 0x15,
		0x27, 0x72, 0xe7, 0x87, 0x91, 0x00, 0x20, 0x2f, 0x04, 0x38, 0x08, 0x02, 0x46, 0xc2, 0x80, 0x8b,
		0x40, 0x60, 0x27, 0x14, 0xd8, 0x09, 0x06, 0x5e, 0xc2, 0x81, 0xa6, 0x80, 0x20, 0x2a, 0x24, 0xc8,
		0x0b, 0x0a, 0xe2, 0x95, 0x04, 0x56, 0x95, 0x85, 0x79, 0x42, 0x63, 0x93, 0xb8, 0x99, 0xd4, 0x05,
		0x07, 0x27, 0xe1, 0xc1, 0x50, 0x80, 0x70, 0x13, 0x22, 0x6c, 0x05, 0x09, 0x5b, 0x61, 0xc2, 0x53,
		0xa0, 0xd0, 0x16, 0x2a, 0xc4, 0x05, 0x4b, 0xf9, 0x91, 0x93, 0xdb, 0x47, 0xfe, 0x53, 0x8f, 0x2b,
		0xa2, 0xc9, 0xb5, 0x48, 0xf2, 0xfd, 0xbb, 0x0c, 0xbc, 0xee, 0xac, 0x1a, 0xd1, 0x64, 0x60, 0xab,
		0x19, 0x4d, 0xae, 0xa7, 0x30, 0x60, 0x49, 0xbd, 0xe4, 0x2a, 0xda, 0x41, 0x2a, 0x0d, 0x29, 0x13,
		0x1e, 0xcb, 0xea, 0x34, 0x88, 0xcc, 0x50, 0x4c, 0xbd, 0x7e, 0x4a, 0x5f, 0x22, 0x6e, 0x14, 0x13,
		0x71, 0x1f, 0x58, 0xbc, 0xf5, 0xb6, 0xd9, 0x6c, 0xed, 0x36, 0x9b, 0x9b, 0xbb, 0x6f, 0x76, 0x37,
		0xf7, 0x76, 0x76, 0xb6, 0x5a, 0x54, 0x0f, 0x01, 0xfa, 0xd7, 0x9b, 0xe8, 0x26, 0x23, 0x91, 0x88,
		0xd1, 0xc1, 0xad, 0xb6, 0xbf, 0x11, 0x4d, 0xc2, 0xf0, 0x37, 0x84, 0x58, 0xc5, 0x7c, 0x81, 0x26,
		0x39, 0x84, 0xd6, 0x32, 0xac, 0x66, 0xd6, 0x22, 0xe1, 0x46, 0xc2, 0x8d, 0x84, 0x1b, 0x09, 0x37,
		0x12, 0x6e, 0x24, 0xdc, 0x48, 0xb8, 0x91, 0x70, 0xe7, 0x73, 0x5c, 0x47, 0x22, 0x92, 0x81, 0xbc,
		0x4d, 0xc4, 0x25, 0xa7, 0x84, 0x9b, 0x43, 0x16, 0x60, 0x15, 0x97, 0xf6, 0xc0, 0x4f, 0x19, 0xc5,
		0x89, 0x19, 0x18, 0x56, 0xdf, 0xea, 0x7b, 0xfd, 0xc1, 0x81, 0x6b, 0x9f, 0x79, 0xee, 0x87, 0x9e,
		0xc9, 0x25, 0x5c, 0x64, 0xc7, 0x82, 0xa4, 0xe4, 0x86, 0xa5, 0xfe, 0xe8, 0xeb, 0x1f, 0x36, 0x96,
		0x3e, 0x22, 0xc4, 0x73, 0x4c, 0xe3, 0xf0, 0xc4, 0x38, 0xb0, 0x6c, 0xcb, 0xfd, 0x50, 0xc0, 0xd2,
		0xe7, 0x44, 0x0b, 0x67, 0x6a, 0x78, 0xd2, 0xf3, 0x53, 0x8a, 0x0e, 0x8c, 0x4e, 0xfb, 0xbf, 0x56,
		0xdb, 0x3d, 0xf1, 0x0e, 0xbb, 0x9d, 0xbe, 0xeb, 0x18, 0x56, 0xc7, 0xed, 0x6b, 0xec, 0xde, 0xe3,
		0xdd, 0xef, 0x00, 0xa9, 0x5e, 0x90, 0x06, 0xae, 0x65, 0x5b, 0x7f, 0x99, 0xed, 0x7b, 0xa2, 0x40,
		0x11, 0x28, 0x7a, 0x2e, 0x45, 0x46, 0xfb, 0x4f, 0xaf, 0x6f, 0xb5, 0x81, 0x0e, 0xd0, 0x79, 0x36,
		0x3a, 0x67, 0x86, 0x65, 0x1b, 0x07, 0xb6, 0x09, 0x0f, 0x04, 0x8c, 0x16, 0xc7, 0xc8, 0xea, 0x9d,
		0xb5, 0xbc, 0x8e, 0x69, 0x1d, 0x9f, 0x1c, 0x74, 0x1d, 0xcf, 0x68, 0xb7, 0x1d, 0xb3, 0x0f, 0x41,
		0x04, 0x90, 0x9e, 0x2f, 0x88, 0x3a, 0xa5, 0xa2, 0x36, 0xdb, 0x9e, 0xdd, 0xef, 0x01, 0x22, 0x40,
		0xf4, 0x5c, 0x88, 0x6c, 0xab, 0xf3, 0xce, 0x33, 0x5c, 0xd7, 0xb1, 0x0e, 0x06, 0xae, 0x09, 0x3f,
		0x04, 0x84, 0x16, 0x43, 0xa8, 0xe7, 0x74, 0x5d, 0xf3, 0xd0, 0xb5, 0xba, 0x9d, 0xbc, 0x5e, 0x04,
		0x8e, 0xc0, 0xd1, 0xb3, 0x53, 0xb3, 0x53, 0xab, 0xe3, 0x1d, 0x3b, 0xdd, 0x01, 0x22, 0x19, 0xf0,
		0x59, 0x4c, 0x57, 0x5b, 0x1d, 0xd7, 0x74, 0x8e, 0x8c, 0x43, 0x13, 0xc2, 0x1a, 0x24, 0x2d, 0x4a,
		0xd2, 0xa9, 0xf1, 0x3e, 0x0f, 0x6a, 0xc8, 0xf3, 0x41, 0xd1, 0x0b, 0xc2, 0xd9, 0x9f, 0x9e, 0x6d,
		0x74, 0x50, 0x6d, 0x04, 0x3e, 0x0b, 0xab, 0x6a, 0xa0, 0x03, 0x74, 0x16, 0x52, 0x42, 0x4d, 0x54,
		0x18, 0x01, 0xd2, 0x72, 0x40, 0x82, 0xa4, 0x06, 0x49, 0x4b, 0x91, 0xd4, 0x8e, 0xd9, 0x37, 0x9d,
		0x33, 0xdc, 0x40, 0x03, 0x4b, 0x2f, 0x63, 0xc9, 0x35, 0xbd, 0xb6, 0x79, 0x64, 0x0c, 0x6c, 0xd7,
		0x3b, 0x35, 0x5d, 0xc7, 0x3a, 0x04, 0x44, 0x80, 0xe8, 0xb9, 0x10, 0x0d, 0x3a, 0xb9, 0x3b, 0xc2,
		0x7e, 0x22, 0x70, 0xf4, 0xe2, 0x34, 0xad, 0x6d, 0xda, 0xc6, 0x07, 0xef, 0xcc, 0x70, 0x2c, 0xc3,
		0xb5, 0xba, 0x1d, 0x70, 0x04, 0x8e, 0x9e, 0xcb, 0x91, 0xf9, 0xde, 0x35, 0x3b, 0x6d, 0xb3, 0x8d,
		0xbb, 0x20, 0xe0, 0xe8, 0x45, 0x42, 0xdb, 0xea, 0xdc, 0xd7, 0xaf, 0x33, 0xbf, 0x04, 0x8a, 0x40,
		0xd1, 0x42, 0x51, 0xcd, 0xee, 0x22, 0xd7, 0x07, 0x3c, 0x2f, 0x91, 0x44, 0xa0, 0x07, 0xf4, 0x3c,
		0x97, 0x1e, 0xc7, 0xec, 0x5b, 0xed, 0x81, 0x61, 0xb3, 0x4e, 0xcb, 0x58, 0x59, 0x7c, 0xfe, 0x1b,
		0x56, 0xe7, 0x9a, 0xaf, 0x4a, 0x55, 0xbb, 0xf7, 0x00, 0x4c, 0xd5, 0xc0, 0x70, 0xee, 0xd2, 0x03,
		0x2d, 0x55, 0xd3, 0xc2, 0xae, 0x1b, 0x0f, 0x88, 0x54, 0x8e, 0x08, 0xe7, 0xae, 0x3b, 0xe0, 0x52,
		0x35, 0x2e, 0xcc, 0xbb, 0xeb, 0x00, 0x4c, 0xe5, 0x82, 0x85, 0x6f, 0x17, 0x1d, 0x60, 0xa9, 0x1a,
		0x16, 0xb6, 0xdd, 0x72, 0x40, 0xa5, 0x16, 0x54, 0xd8, 0x76, 0xc5, 0x81, 0x97, 0xea, 0x53, 0x21,
		0x86, 0xf7, 0x7d, 0x81, 0x49, 0x2d, 0xfa, 0x96, 0xf1, 0x96, 0x5c, 0x10, 0x53, 0x35, 0x31, 0x9c,
		0xbb, 0xd9, 0x40, 0x4b, 0xf5, 0x61, 0x88, 0x61, 0xd7, 0x1a, 0x30, 0xa9, 0x45, 0xdd, 0x02, 0x11,
		0x20, 0xa2, 0x6c, 0x17, 0x1a, 0x80, 0xa9, 0x05, 0x18, 0x48, 0x5b, 0x10, 0xf3, 0x2c, 0x69, 0xcb,
		0xbb, 0xab, 0x0c, 0xcc, 0x54, 0xcd, 0x0c, 0xe3, 0xee, 0x31, 0xc0, 0x52, 0x35, 0x2c, 0xbc, 0xbb,
		0xc4, 0xc0, 0x4b, 0x2d, 0x69, 0x11, 0xdb, 0x6e, 0x30, 0xf0, 0x52, 0x35, 0x2f, 0xbc, 0xbb, 0xbe,
		0xc0, 0x4b, 0xe5, 0x82, 0x97, 0x71, 0x77, 0x17, 0x68, 0xa9, 0x25, 0x1a, 0xf1, 0xea, 0xe2, 0x02,
		0x24, 0xf5, 0x49, 0x16, 0x50, 0x02, 0x4a, 0x54, 0xec, 0xca, 0x02, 0x2d, 0x2b, 0xa7, 0xa5, 0x87,
		0x93, 0xe3, 0x40, 0xcf, 0xb2, 0x29, 0x72, 0x8d, 0xe3, 0x56, 0x13, 0x2d, 0xc4, 0x00, 0xe7, 0xb9,
		0xe0, 0xf4, 0x1c, 0xf3, 0xc8, 0x7a, 0x8f, 0xc1, 0xbb, 0xa0, 0x67, 0x11, 0x7a, 0xb2, 0x1d, 0x76,
		0x4e, 0x77, 0xe0, 0x9a, 0x0e, 0xe6, 0xef, 0x82, 0xa0, 0xc5, 0x02, 0x17, 0xb0, 0x01, 0x36, 0x0b,
		0x86, 0xad, 0x23, 0xdb, 0x38, 0xc6, 0xdc, 0x1d, 0xf0, 0xb3, 0x48, 0xe0, 0x6a, 0xb2, 0x0e, 0x5c,
		0x98, 0x9a, 0x82, 0xfa, 0x07, 0x32, 0x57, 0x00, 0xa2, 0x3e, 0x20, 0x1c, 0x33, 0x54, 0x50, 0x82,
		0x4c, 0x14, 0xa4, 0x20, 0xe3, 0x04, 0x1e, 0xc8, 0x2c, 0xc1, 0x89, 0xaa, 0x01, 0xa7, 0x89, 0x80,
		0x03, 0x52, 0x9e, 0x92, 0x52, 0x40, 0x71, 0x68, 0xf4, 0x70, 0x8f, 0x17, 0xfc, 0x2c, 0x95, 0x23,
		0xc7, 0x33, 0xec, 0xe3, 0xae, 0x63, 0xb9, 0x27, 0xa7, 0xa8, 0x7a, 0x82, 0xa0, 0x85, 0x08, 0xba,
		0xff, 0x13, 0xca, 0x9e, 0xab, 0xfd, 0x42, 0xd9, 0x13, 0xa2, 0x40, 0x35, 0x67, 0x0e, 0x52, 0xe0,
		0xb4, 0x95, 0x72, 0xd6, 0xf4, 0x9d, 0x34, 0xed, 0xeb, 0x48, 0xd7, 0x3a, 0x9a, 0x96, 0x11, 0x75,
		0xa0, 0x9a, 0x11, 0x45, 0xb1, 0xf4, 0x65, 0x10, 0x47, 0xda, 0x3e, 0x61, 0xd7, 0xa9, 0xa5, 0xc3,
		0x4f, 0xe2, 0xda, 0x1f, 0xfb, 0xf2, 0xd3, 0xd4, 0x59, 0x36, 0xe2, 0xb1, 0x88, 0x86, 0x71, 0x74,
		0x19, 0x5c, 0xe9, 0x91, 0x90, 0x5f, 0xe2, 0xe4, 0xb3, 0x1e, 0x44, 0xa9, 0xf4, 0xa3, 0xa1, 0x68,
		0x3c, 0x7e, 0x21, 0x7d, 0xf2, 0x4a, 0x63, 0x9c, 0xc4, 0x32, 0x1e, 0xc6, 0x61, 0x5a, 0x3e, 0x6b,
		0x04, 0x69, 0x90, 0x36, 0x42, 0x71, 0x23, 0xc2, 0xe2, 0xa1, 0x11, 0x06, 0xd1, 0x67, 0x3d, 0x95,
		0xbe, 0x14, 0xfa, 0xc8, 0x97, 0xfe, 0x85, 0x9f, 0x8a, 0x46, 0x98, 0x8e, 0x1b, 0x32, 0xbc, 0x49,
		0xa7, 0xdf, 0x1a, 0xd7, 0x52, 0x0f, 0xc6, 0x37, 0x4d, 0x3d, 0x11, 0xfe, 0xf0, 0x93, 0x7f, 0x11,
		0x84, 0x81, 0xbc, 0x6d, 0x8c, 0x13, 0x71, 0x19, 0x7c, 0x15, 0x69, 0xf1, 0xa4, 0x91, 0x4e, 0x2e,
		0xb2, 0x1f, 0xc8, 0x1f, 0x1b, 0x97, 0xa1, 0x7f, 0x95, 0x36, 0xb2, 0xff, 0x95, 0x70, 0x49, 0x40,
		0x4b, 0x65, 0x32, 0x19, 0xca, 0xa8, 0x88, 0x4d, 0xdd, 0xf2, 0x6a, 0x77, 0xf2, 0x2b, 0x69, 0x15,
		0x17, 0xd2, 0x7b, 0xf4, 0xe7, 0xf4, 0xf1, 0x0b, 0x5e, 0x6f, 0x76, 0xa5, 0xcb, 0x67, 0x9e, 0x95,
		0x06, 0xa9, 0x67, 0x67, 0x57, 0x3a, 0x7f, 0xf0, 0xec, 0x20, 0xfa, 0xdc, 0x9f, 0x5e, 0x92, 0x76,
		0x71, 0x9d, 0x3d, 0x3b, 0x1d, 0x7b, 0x6e, 0x78, 0x93, 0x4e, 0xbf, 0x79, 0xa7, 0xd2, 0x1a, 0xdf,
		0x34, 0x9d, 0x07, 0x57, 0xd9, 0xeb, 0x15, 0x57, 0xb9, 0x78, 0xe2, 0xf5, 0xf3, 0xab, 0x5c, 0x3c,
		0x7a, 0x47, 0xd3, 0xab, 0xec, 0x65, 0xff, 0x25, 0xcd, 0xc0, 0x49, 0xcf, 0x49, 0xd1, 0xb2, 0x88,
		0x98, 0xbb, 0xa4, 0xee, 0x26, 0xd5, 0x72, 0x8f, 0x04, 0x1d, 0xa3, 0x12, 0x0e, 0x91, 0x96, 0x2b,
		0xa4, 0xe3, 0x70, 0x08, 0x39, 0x1b, 0x2d, 0x5b, 0x31, 0x69, 0x3c, 0x49, 0x86, 0x42, 0x4f, 0xe2,
		0x89, 0x14, 0x89, 0x1e, 0x8c, 0xc8, 0xf9, 0x9c, 0x32, 0x6b, 0xfd, 0xbe, 0xb9, 0xc4, 0x9c, 0xf7,
		0xbb, 0x20, 0x9a, 0x5e, 0xc2, 0x2d, 0x62, 0x66, 0x1d, 0x66, 0x0e, 0x44, 0xdb, 0xdf, 0xd8, 0x24,
		0x66, 0x58, 0xee, 0x42, 0x68, 0x06, 0xba, 0x19, 0x78, 0xf1, 0x50, 0x9f, 0x86, 0x24, 0x8a, 0xa1,
		0xa2, 0x9f, 0x2d, 0x07, 0xb2, 0xe9, 0x94, 0xf6, 0x4e, 0xdc, 0x7e, 0x89, 0x93, 0xe9, 0x8a, 0xd0,
		0xf2, 0x20, 0x4c, 0x34, 0x11, 0xd1, 0x4e, 0xfc, 0xd4, 0x48, 0xae, 0x26, 0xd7, 0x22, 0x92, 0xda,
		0xfe, 0x86, 0x4c, 0x26, 0x82, 0x6a, 0x12, 0x7d, 0x6f, 0x65, 0x09, 0x26, 0x04, 0x3e, 0x2b, 0x81,
		0xdf, 0x0e, 0x12, 0xa2, 0xca, 0x3e, 0x4b, 0x62, 0xc9, 0x3a, 0x93, 0x99, 0x3f, 0xa6, 0x5c, 0xd1,
		0x20, 0x2a, 0x00, 0xc8, 0x0b, 0x01, 0x0e, 0x82, 0x80, 0x91, 0x30, 0xe0, 0x22, 0x10, 0xd8, 0x09,
		0x05, 0x76, 0x82, 0x81, 0x97, 0x70, 0xa0, 0x29, 0x20, 0x88, 0x0a, 0x09, 0xf2, 0x82, 0xa2, 0x34,
		0x90, 0x6e, 0x75, 0x61, 0xae, 0x6f, 0xa7, 0x5a, 0x61, 0x98, 0x27, 0x38, 0x36, 0x89, 0x9b, 0x49,
		0x5d, 0x78, 0x70, 0x12, 0x20, 0x0c, 0x85, 0x08, 0x37, 0x41, 0xc2, 0x56, 0x98, 0xb0, 0x15, 0x28,
		0x3c, 0x85, 0x0a, 0x6d, 0xc1, 0x42, 0x5c, 0xb8, 0x94, 0x1f, 0xb9, 0x7b, 0x3b, 0x16, 0xbc, 0x3c,
		0x6e, 0x76, 0x33, 0xc2, 0x1f, 0x8d, 0x12, 0x91, 0xb2, 0x70, 0xbb, 0xb3, 0xb2, 0xc4, 0x5b, 0x06,
		0xb6, 0xf6, 0x7c, 0x29, 0x45, 0x12, 0xb1, 0x69, 0x08, 0xd1, 0x5e, 0xbd, 0xfa, 0xb8, 0xa9, 0xef,
		0x9d, 0x7f, 0xfb, 0xb8, 0xa5, 0xef, 0x9d, 0xe7, 0x4f, 0xb7, 0xb2, 0x87, 0xfc, 0xf9, 0xf6, 0xc7,
		0x4d, 0xbd, 0x39, 0x7b, 0xbe, 0xf3, 0x71, 0x53, 0xdf, 0x39, 0x7f, 0xfd, 0xf7, 0xdf, 0x7f, 0xbc,
		0xfe, 0xe7, 0xcd, 0xdd, 0xf3, 0x7f, 0x90, 0xbe, 0x2b, 0x3c, 0xe7, 0x80, 0x58, 0xb7, 0x6f, 0xbd,
		0x67, 0xc7, 0xd9, 0xff, 0xaa, 0x04, 0xed, 0x3f, 0x0c, 0x48, 0xc3, 0xb6, 0x55, 0xd5, 0xe4, 0x80,
		0x26, 0x39, 0x48, 0x81, 0x52, 0x06, 0x64, 0xd6, 0xa2, 0x40, 0x80, 0x02, 0x01, 0x0a, 0x04, 0x28,
		0x10, 0xa0, 0x40, 0x80, 0x02, 0x01, 0x0a, 0x04, 0x28, 0x10, 0xe4, 0x05, 0x82, 0x91, 0x88, 0x64,
		0x20, 0x6f, 0x13, 0x71, 0xc9, 0xa9, 0x3e, 0xb0, 0xc3, 0xc0, 0x56, 0xab, 0xb8, 0xb4, 0x07, 0x7e,
		0xca, 0x28, 0x4e, 0xdc, 0x9f, 0xe5, 0x61, 0xf5, 0x8b, 0x71, 0x1d, 0x9c, 0xa6, 0x75, 0x70, 0x9c,
		0xd2, 0xa1, 0xc8, 0x69, 0x2f, 0x98, 0xed, 0x02, 0x7a, 0x5e, 0x4e, 0x51, 0x79, 0x54, 0x90, 0x77,
		0xd8, 0xed, 0xf4, 0x5d, 0xc7, 0xb0, 0x3a, 0x2e, 0x06, 0x5b, 0x03, 0xa4, 0x67, 0x83, 0x34, 0x70,
		0x2d, 0xdb, 0xfa, 0x8b, 0xe7, 0x19, 0xbc, 0xa0, 0x88, 0x0a, 0x45, 0x46, 0xfb, 0x4f, 0x1c, 0x09,
		0x03, 0x74, 0x16, 0x42, 0xe7, 0xcc, 0xb0, 0x6c, 0xe3, 0xc0, 0x36, 0xe1, 0x81, 0x80, 0xd1, 0xe2,
		0x18, 0x65, 0xf3, 0x9c, 0x3b, 0xa6, 0x75, 0x7c, 0x72, 0xd0, 0x75, 0x3c, 0xa3, 0xdd, 0x76, 0xcc,
		0x3e, 0x04, 0x11, 0x40, 0x7a, 0xbe, 0x20, 0xea, 0x94, 0x8a, 0xda, 0x6c, 0x7b, 0x76, 0xbf, 0x07,
		0x88, 0x00, 0xd1, 0x73, 0x21, 0xca, 0x0e, 0xfe, 0x35, 0x5c, 0xd7, 0xb1, 0x0e, 0x06, 0xae, 0x09,
		0x3f, 0x04, 0x84, 0x16, 0x43, 0xa8, 0xe7, 0x74, 0x5d, 0xf3, 0xd0, 0xb5, 0xba, 0x9d, 0xbc, 0x5e,
		0x04, 0x8e, 0xc0, 0xd1, 0xb3, 0x53, 0xb3, 0x53, 0xab, 0xe3, 0x1d, 0x3b, 0xdd, 0x01, 0x22, 0x19,
		0xf0, 0x59, 0x4c, 0x57, 0x5b, 0x1d, 0xd7, 0x74, 0x8e, 0x8c, 0x43, 0x13, 0xc2, 0x1a, 0x24, 0x2d,
		0x4a, 0xd2, 0xa9, 0xf1, 0x3e, 0x0f, 0x6a, 0xc8, 0xf3, 0x41, 0xd1, 0x0b, 0xc2, 0xd9, 0x9f, 0x9e,
		0x6d, 0x74, 0x50, 0x6d, 0x04, 0x3e, 0x0b, 0xab, 0x6a, 0xa0, 0x03, 0x74, 0x16, 0x52, 0x42, 0x4d,
		0x54, 0x18, 0x01, 0xd2, 0x72, 0x40, 0x82, 0xa4, 0x06, 0x49, 0x4b, 0x91, 0xd4, 0x8e, 0xd9, 0x37,
		0x9d, 0x33, 0xdc, 0x40, 0x03, 0x4b, 0x2f, 0x63, 0xc9, 0x35, 0xbd, 0xb6, 0x79, 0x64, 0x0c, 0x6c,
		0xd7, 0x3b, 0x35, 0x5d, 0xc7, 0x3a, 0x04, 0x44, 0x80, 0xe8, 0xb9, 0x10, 0x0d, 0x3a, 0xb9, 0x3b,
		0xc2, 0x7e, 0x22, 0x70, 0xf4, 0xe2, 0x34, 0xad, 0x6d, 0xda, 0xc6, 0x07, 0xef, 0xcc, 0x70, 0x2c,
		0xc3, 0xb5, 0xba, 0x1d, 0x70, 0x04, 0x8e, 0x9e, 0xcb, 0x91, 0xf9, 0xde, 0x35, 0x3b, 0x6d, 0xb3,
		0x8d, 0xbb, 0x20, 0xe0, 0xe8, 0x45, 0x42, 0xdb, 0xea, 0xdc, 0xd7, 0xaf, 0x33, 0xbf, 0x04, 0x8a,
		0x40, 0xd1, 0x42, 0x51, 0xcd, 0xee, 0x22, 0xd7, 0x07, 0x3c, 0x2f, 0x91, 0x44, 0xa0, 0x07, 0xf4,
		0x3c, 0x97, 0x1e, 0xc7, 0xec, 0x5b, 0xed, 0x81, 0x61, 0xb3, 0x4e, 0xcb, 0x70, 0x98, 0xef, 0xba,
		0xaf, 0x4e, 0x45, 0x7a, 0x40, 0x99, 0x77, 0xef, 0x01, 0x98, 0xaa, 0x81, 0xe1, 0xdc, 0xa5, 0x07,
		0x5a, 0xaa, 0xa6, 0x85, 0x5d, 0x37, 0x1e, 0x10, 0xa9, 0x1c, 0x11, 0xce, 0x5d, 0x77, 0xc0, 0xa5,
		0x6a, 0x5c, 0x98, 0x77, 0xd7, 0x01, 0x98, 0xca, 0x05, 0x0b, 0xdf, 0x2e, 0x3a, 0xc0, 0x52, 0x35,
		0x2c, 0x6c, 0xbb, 0xe5, 0x80, 0x4a, 0x2d, 0xa8, 0xb0, 0xed, 0x8a, 0x03, 0x2f, 0xd5, 0xa7, 0x42,
		0x0c, 0xef, 0xfb, 0x02, 0x93, 0x5a, 0xf4, 0x2d, 0xe3, 0x2d, 0xb9, 0x20, 0xa6, 0x6a, 0x62, 0x38,
		0x77, 0xb3, 0x81, 0x96, 0xea, 0xc3, 0x10, 0xc3, 0xae, 0x35, 0x60, 0x52, 0x8b, 0xba, 0x05, 0x22,
		0x40, 0x44, 0xd9, 0x2e, 0x34, 0x00, 0x53, 0x0b, 0x30, 0x90, 0xb6, 0x20, 0xe6, 0x59, 0xd2, 0x96,
		0x77, 0x57, 0x19, 0x98, 0xa9, 0x9a, 0x19, 0xc6, 0xdd, 0x63, 0x80, 0xa5, 0x6a, 0x58, 0x78, 0x77,
		0x89, 0x81, 0x97, 0x5a, 0xd2, 0x22, 0xb6, 0xdd, 0x60, 0xe0, 0xa5, 0x6a, 0x5e, 0x78, 0x77, 0x7d,
		0x81, 0x97, 0xca, 0x05, 0x2f, 0xe3, 0xee, 0x2e, 0xd0, 0x52, 0x4b, 0x34, 0xe2, 0xd5, 0xc5, 0x05,
		0x48, 0xea, 0x93, 0x2c, 0xa0, 0x04, 0x94, 0xa8, 0xd8, 0x95, 0x05, 0x5a, 0x56, 0x4e, 0x4b, 0x0f,
		0x27, 0xc7, 0x81, 0x9e, 0x65, 0x53, 0xe4, 0x1a, 0xc7, 0xad, 0x26, 0x5a, 0x88, 0x01, 0xce, 0x73,
		0xc1, 0xe9, 0x39, 0xe6, 0x91, 0xf5, 0x1e, 0x83, 0x77, 0x41, 0xcf, 0x22, 0xf4, 0x64, 0x3b, 0xec,
		0x9c, 0xee, 0xc0, 0x35, 0x1d, 0xcc, 0xdf, 0x05, 0x41, 0x8b, 0x05, 0x2e, 0x60, 0x03, 0x6c, 0x16,
		0x0c, 0x5b, 0x47, 0xb6, 0x71, 0x8c, 0xb9, 0x3b, 0xe0, 0x67, 0x91, 0xc0, 0xd5, 0x64, 0x1d, 0xb8,
		0x30, 0x35, 0x05, 0xf5, 0x0f, 0x64, 0xae, 0x00, 0x44, 0x7d, 0x40, 0x38, 0x66, 0xa8, 0xa0, 0x04,
		0x99, 0x28, 0x48, 0x41, 0xc6, 0x09, 0x3c, 0x90, 0x59, 0x82, 0x13, 0x55, 0x03, 0x4e, 0x13, 0x01,
		0x07, 0xa4, 0x3c, 0x25, 0xa5, 0x80, 0xe2, 0xd0, 0xe8, 0xe1, 0x1e, 0x2f, 0xf8, 0x59, 0x2a, 0x47,
		0x8e, 0x67, 0xd8, 0xc7, 0x5d, 0xc7, 0x72, 0x4f, 0x4e, 0x51, 0xf5, 0x04, 0x41, 0x0b, 0x11, 0x74,
		0xff, 0x27, 0x94, 0x3d, 0x57, 0xfb, 0x85, 0xb2, 0x27, 0x44, 0x81, 0x6a, 0xce, 0x1c, 0xa4, 0xc0,
		0x69, 0x2b, 0xe5, 0xac, 0xe9, 0x3b, 0x69, 0xda, 0xd7, 0x91, 0xae, 0x75, 0x34, 0x2d, 0x23, 0xea,
		0x40, 0x35, 0x23, 0x8a, 0x62, 0xe9, 0xcb, 0x20, 0x8e, 0xb4, 0x7d, 0xc2, 0xae, 0x53, 0x4b, 0x87,
		0x9f, 0xc4, 0xb5, 0x3f, 0xf6, 0xe5, 0xa7, 0xa9, 0xb3, 0x6c, 0xc4, 0x63, 0x11, 0x0d, 0xe3, 0xe8,
		0x32, 0xb8, 0xd2, 0x23, 0x21, 0xbf, 0xc4, 0xc9, 0x67, 0x3d, 0x88, 0x52, 0xe9, 0x47, 0x43, 0xd1,
		0x78, 0xfc, 0x42, 0xfa, 0xe4, 0x95, 0xc6, 0x38, 0x89, 0x65, 0x3c, 0x8c, 0xc3, 0xb4, 0x7c, 0xd6,
		0x08, 0xd2, 0x20, 0x6d, 0x84, 0xe2, 0x46, 0x84, 0xc5, 0x43, 0x23, 0x0c, 0xa2, 0xcf, 0x7a, 0x2a,
		0x7d, 0x29, 0xf4, 0x91, 0x2f, 0xfd, 0x0b, 0x3f, 0x15, 0x8d, 0x30, 0x1d, 0x37, 0x64, 0x78, 0x93,
		0x4e, 0xbf, 0x35, 0xae, 0xa5, 0x1e, 0x8c, 0x6f, 0x9a, 0x7a, 0x22, 0xfc, 0xe1, 0x27, 0xff, 0x22,
		0x08, 0x03, 0x79, 0xdb, 0x18, 0x27, 0xe2, 0x32, 0xf8, 0x2a, 0xd2, 0xe2, 0x49, 0x23, 0x9d, 0x5c,
		0x64, 0x3f, 0x90, 0x3f, 0x36, 0xb2, 0x1f, 0x48, 0xe3, 0x49, 0x32, 0x14, 0x7a, 0x12, 0x4f, 0xa4,
		0x48, 0xf4, 0x60, 0xd4, 0xc8, 0x7e, 0x0b, 0xe1, 0x12, 0x81, 0x96, 0xca, 0x64, 0x32, 0x94, 0x51,
		0x11, 0xab, 0xba, 0xe5, 0xd5, 0xef, 0xe4, 0x57, 0xd6, 0x2a, 0x2e, 0xac, 0xf7, 0xe8, 0xcf, 0xe9,
		0xe3, 0x17, 0xbc, 0xde, 0xec, 0xca, 0x97, 0xcf, 0x3c, 0x2b, 0x0d, 0x52, 0xcf, 0xce, 0xae, 0x7c,
		0xfe, 0xe0, 0xd9, 0x41, 0xf4, 0xb9, 0x3f, 0xbd, 0x24, 0xed, 0xe2, 0xba, 0x7b, 0x76, 0x3a, 0xf6,
		0xdc, 0xf0, 0x26, 0x9d, 0x7e, 0xf3, 0x4e, 0xa5, 0x35, 0xbe, 0x69, 0x3a, 0x0f, 0xae, 0xba, 0xd7,
		0x2b, 0xae, 0x7a, 0xf1, 0xc4, 0xeb, 0xe7, 0x57, 0xbd, 0x78, 0xf4, 0xa6, 0xff, 0xbe, 0x9f, 0x5d,
		0x74, 0x27, 0xbb, 0xe6, 0xd6, 0xc8, 0xcb, 0xfe, 0x7f, 0x9a, 0x51, 0x95, 0x9e, 0x07, 0xa3, 0x65,
		0x11, 0x31, 0x5f, 0x4a, 0xdd, 0x87, 0xaa, 0xed, 0x3b, 0x09, 0x7a, 0x4d, 0xf5, 0xbc, 0x25, 0x2d,
		0x3f, 0x49, 0xc7, 0x1b, 0x11, 0xf2, 0x44, 0x5a, 0x30, 0xbe, 0x69, 0x3d, 0x5d, 0x1d, 0xd4, 0x1c,
		0x52, 0x99, 0xef, 0x7e, 0xdf, 0x5c, 0x62, 0x9e, 0xfd, 0x5d, 0x10, 0x4d, 0x2f, 0xe1, 0x16, 0x31,
		0xb3, 0x0e, 0x33, 0x6f, 0xa2, 0xed, 0x6f, 0x6c, 0x12, 0x33, 0x2c, 0xf7, 0x27, 0x34, 0xa3, 0xe0,
		0x0c, 0xbc, 0x78, 0xa8, 0x4f, 0xe3, 0x15, 0xc5, 0xb8, 0x91, 0x3b, 0x5d, 0xb2, 0x89, 0x98, 0xf6,
		0x4e, 0xdc, 0x7e, 0x89, 0x93, 0xe9, 0x8a, 0xd0, 0xf2, 0x08, 0x4d, 0x34, 0x65, 0xd1, 0x4e, 0xfc,
		0xd4, 0x48, 0xae, 0x26, 0xd7, 0x22, 0x92, 0xda, 0xfe, 0x86, 0x4c, 0x26, 0x82, 0x6a, 0xfa, 0x7d,
		0x6f, 0x65, 0x09, 0x26, 0xd4, 0x3f, 0x2b, 0xf5, 0xdf, 0x0e, 0x12, 0xa2, 0xb2, 0x3f, 0xcb, 0x70,
		0xc9, 0x3a, 0x93, 0x99, 0x3f, 0xa6, 0x5c, 0xfb, 0x20, 0x2a, 0x00, 0xc8, 0x0b, 0x01, 0x0e, 0x82,
		0x80, 0x91, 0x30, 0xe0, 0x22, 0x10, 0xd8, 0x09, 0x05, 0x76, 0x82, 0x81, 0x97, 0x70, 0xa0, 0x29,
		0x20, 0x88, 0x0a, 0x09, 0xf2, 0x82, 0xa2, 0x34, 0x90, 0x6e, 0x75, 0x61, 0xae, 0x6f, 0xa7, 0x5c,
		0x2e, 0xfc, 0x9e, 0xe0, 0xd8, 0x24, 0x6e, 0x26, 0x75, 0xe1, 0xc1, 0x49, 0x80, 0x30, 0x14, 0x22,
		0xdc, 0x04, 0x09, 0x5b, 0x61, 0xc2, 0x56, 0xa0, 0xf0, 0x14, 0x2a, 0xb4, 0x05, 0x0b, 0x71, 0xe1,
		0x52, 0x7e, 0xe4, 0xee, 0xed, 0x58, 0xf0, 0xf2, 0xb8, 0xd9, 0xcd, 0x08, 0x7f, 0x34, 0x4a, 0x44,
		0xca, 0xc2, 0xed, 0xce, 0xca, 0x12, 0x6f, 0x19, 0xd8, 0xda, 0xf3, 0xa5, 0x14, 0x49, 0xc4, 0xa6,
		0x95, 0x44, 0x7b, 0xf5, 0xea, 0xe3, 0xa6, 0xbe, 0xe7, 0xeb, 0x97, 0x86, 0x7e, 0x74, 0xfe, 0xcf,
		0xd6, 0xef, 0xcd, 0xbb, 0xfd, 0xd7, 0xff, 0xec, 0xde, 0x3d, 0x7e, 0xf1, 0xdb, 0xf7, 0xfe, 0xd9,
		0xd6, 0xef, 0xbb, 0x77, 0xfb, 0x73, 0xfe, 0xa6, 0x75, 0xb7, 0xff, 0x8b, 0xff, 0xc7, 0xce, 0xdd,
		0xab, 0x27, 0xff, 0x74, 0xfa, 0xfa, 0xf6, 0xbc, 0x1f, 0x68, 0xce, 0xf9, 0x81, 0x37, 0xf3, 0x7e,
		0xe0, 0xcd, 0x9c, 0x1f, 0x98, 0x6b, 0xd2, 0xf6, 0x9c, 0x1f, 0xd8, 0xb9, 0xfb, 0xf6, 0xe4, 0xdf,
		0xbf, 0xfa, 0xfe, 0x3f, 0x6d, 0xdd, 0xbd, 0xfe, 0x36, 0xef, 0xef, 0x76, 0xef, 0xbe, 0xed, 0xbf,
		0x7e, 0x4d, 0x3f, 0x30, 0x9c, 0x73, 0x58, 0x70, 0xdd, 0xbe, 0xf5, 0x9e, 0xdd, 0xaa, 0xfb, 0x1f,
		0x96, 0x5d, 0x5d, 0xcb, 0xee, 0x3f, 0x0c, 0xd6, 0x1d, 0x36, 0x43, 0xab, 0x26, 0x15, 0x35, 0xc9,
		0x41, 0x26, 0x96, 0x12, 0x31, 0xb3, 0x16, 0xc5, 0x23, 0x14, 0x8f, 0x50, 0x3c, 0x42, 0xf1, 0x08,
		0xc5, 0x23, 0x14, 0x8f, 0x50, 0x3c, 0x42, 0xf1, 0x28, 0x2f, 0x1e, 0x8d, 0x44, 0x24, 0x03, 0x79,
		0x9b, 0x88, 0x4b, 0x4e, 0xb5, 0xa3, 0x1d, 0x06, 0xb6, 0x5a, 0xc5, 0xa5, 0x3d, 0xf0, 0x53, 0x46,
		0x71, 0xe2, 0xfe, 0x84, 0x18, 0xab, 0x5f, 0x0c, 0x81, 0xe1, 0x34, 0x03, 0x86, 0xe3, 0xec, 0x17,
		0x45, 0xce, 0x10, 0xc2, 0xc4, 0x20, 0xd0, 0xf3, 0x72, 0x8a, 0xca, 0x03, 0xa8, 0xbc, 0xc3, 0x6e,
		0xa7, 0xef, 0x3a, 0x86, 0xd5, 0x71, 0x31, 0x2e, 0x1d, 0x20, 0x3d, 0x1b, 0xa4, 0x81, 0x6b, 0xd9,
		0xd6, 0x5f, 0x3c, 0x4f, 0x76, 0x06, 0x45, 0x54, 0x28, 0x32, 0xda, 0x7f, 0xe2, 0xa0, 0x21, 0xa0,
		0xb3, 0x10, 0x3a, 0x67, 0x86, 0x65, 0x1b, 0x07, 0xb6, 0x09, 0x0f, 0x04, 0x8c, 0x16, 0xc7, 0x28,
		0x9b, 0x12, 0xde, 0x31, 0xad, 0xe3, 0x93, 0x83, 0xae, 0xe3, 0x19, 0xed, 0xb6, 0x63, 0xf6, 0x21,
		0x88, 0x00, 0xd2, 0xf3, 0x05, 0x51, 0xa7, 0x54, 0xd4, 0x66, 0xdb, 0xb3, 0xfb, 0x3d, 0x40, 0x04,
		0x88, 0x9e, 0x0b, 0x51, 0x76, 0x9c, 0xb4, 0xe1, 0xba, 0x8e, 0x75, 0x30, 0x70, 0x4d, 0xf8, 0x21,
		0x20, 0xb4, 0x18, 0x42, 0x3d, 0xa7, 0xeb, 0x9a, 0x87, 0xae, 0xd5, 0xed, 0xe4, 0xf5, 0x22, 0x70,
		0x04, 0x8e, 0x9e, 0x9d, 0x9a, 0x9d, 0x5a, 0x1d, 0xef, 0xd8, 0xe9, 0x0e, 0x10, 0xc9, 0x80, 0xcf,
		0x62, 0xba, 0xda, 0xea, 0xb8, 0xa6, 0x73, 0x64, 0x1c, 0x9a, 0x10, 0xd6, 0x20, 0x69, 0x51, 0x92,
		0x4e, 0x8d, 0xf7, 0x79, 0x50, 0x43, 0x9e, 0x0f, 0x8a, 0x5e, 0x10, 0xce, 0xfe, 0xf4, 0x6c, 0xa3,
		0x83, 0x6a, 0x23, 0xf0, 0x59, 0x58, 0x55, 0x03, 0x1d, 0xa0, 0xb3, 0x90, 0x12, 0x6a, 0xa2, 0xc2,
		0x08, 0x90, 0x96, 0x03, 0x12, 0x24, 0x35, 0x48, 0x5a, 0x8a, 0xa4, 0x76, 0xcc, 0xbe, 0xe9, 0x9c,
		0xe1, 0x06, 0x1a, 0x58, 0x7a, 0x19, 0x4b, 0xae, 0xe9, 0xb5, 0xcd, 0x23, 0x63, 0x60, 0xbb, 0xde,
		0xa9, 0xe9, 0x3a, 0xd6, 0x21, 0x20, 0x02, 0x44, 0xcf, 0x85, 0x68, 0xd0, 0xc9, 0xdd, 0x11, 0xf6,
		0x13, 0x81, 0xa3, 0x17, 0xa7, 0x69, 0x6d, 0xd3, 0x36, 0x3e, 0x78, 0x67, 0x86, 0x63, 0x19, 0xae,
		0xd5, 0xed, 0x80, 0x23, 0x70, 0xf4, 0x5c, 0x8e, 0xcc, 0xf7, 0xae, 0xd9, 0x69, 0x9b, 0x6d, 0xdc,
		0x05, 0x01, 0x47, 0x2f, 0x12, 0xda, 0x56, 0xe7, 0xbe, 0x7e, 0x9d, 0xf9, 0x25, 0x50, 0x04, 0x8a,
		0x16, 0x8a, 0x6a, 0x76, 0x17, 0xb9, 0x3e, 0xe0, 0x79, 0x89, 0x24, 0x02, 0x3d, 0xa0, 0xe7, 0xb9,
		0xf4, 0x38, 0x66, 0xdf, 0x6a, 0x0f, 0x0c, 0x9b, 0x75, 0x5a, 0x86, 0x23, 0xa2, 0xd7, 0x7d, 0x75,
		0x2a, 0xd2, 0x03, 0xca, 0xbc, 0x7b, 0x0f, 0xc0, 0x54, 0x0d, 0x0c, 0xe7, 0x2e, 0x3d, 0xd0, 0x52,
		0x35, 0x2d, 0xec, 0xba, 0xf1, 0x80, 0x48, 0xe5, 0x88, 0x70, 0xee, 0xba, 0x03, 0x2e, 0x55, 0xe3,
		0xc2, 0xbc, 0xbb, 0x0e, 0xc0, 0x54, 0x2e, 0x58, 0xf8, 0x76, 0xd1, 0x01, 0x96, 0xaa, 0x61, 0x61,
		0xdb, 0x2d, 0x07, 0x54, 0x6a, 0x41, 0x85, 0x6d, 0x57, 0x1c, 0x78, 0xa9, 0x3e, 0x15, 0x62, 0x78,
		0xdf, 0x17, 0x98, 0xd4, 0xa2, 0x6f, 0x19, 0x6f, 0xc9, 0x05, 0x31, 0x55, 0x13, 0xc3, 0xb9, 0x9b,
		0x0d, 0xb4, 0x54, 0x1f, 0x86, 0x18, 0x76, 0xad, 0x01, 0x93, 0x5a, 0xd4, 0x2d, 0x10, 0x01, 0x22,
		0xca, 0x76, 0xa1, 0x01, 0x98, 0x5a, 0x80, 0x81, 0xb4, 0x05, 0x31, 0xcf, 0x92, 0xb6, 0xbc, 0xbb,
		0xca, 0xc0, 0x4c, 0xd5, 0xcc, 0x30, 0xee, 0x1e, 0x03, 0x2c, 0x55, 0xc3, 0xc2, 0xbb, 0x4b, 0x0c,
		0xbc, 0xd4, 0x92, 0x16, 0xb1, 0xed, 0x06, 0x03, 0x2f, 0x55, 0xf3, 0xc2, 0xbb, 0xeb, 0x0b, 0xbc,
		0x54, 0x2e, 0x78, 0x19, 0x77, 0x77, 0x81, 0x96, 0x5a, 0xa2, 0x11, 0xaf, 0x2e, 0x2e, 0x40, 0x52,
		0x9f, 0x64, 0x01, 0x25, 0xa0, 0x44, 0xc5, 0xae, 0x2c, 0xd0, 0xb2, 0x72, 0x5a, 0x7a, 0x38, 0x39,
		0x0e, 0xf4, 0x2c, 0x9b, 0x22, 0xd7, 0x38, 0x6e, 0x35, 0xd1, 0x42, 0x0c, 0x70, 0x9e, 0x0b, 0x4e,
		0xcf, 0x31, 0x8f, 0xac, 0xf7, 0x18, 0xbc, 0x0b, 0x7a, 0x16, 0xa1, 0x27, 0xdb, 0x61, 0xe7, 0x74,
		0x07, 0xae, 0xe9, 0x60, 0xfe, 0x2e, 0x08, 0x5a, 0x2c, 0x70, 0x01, 0x1b, 0x60, 0xb3, 0x60, 0xd8,
		0x3a, 0xb2, 0x8d, 0x63, 0xcc, 0xdd, 0x01, 0x3f, 0x8b, 0x04, 0xae, 0x26, 0xeb, 0xc0, 0x85, 0xa9,
		0x29, 0xa8, 0x7f, 0x20, 0x73, 0x05, 0x20, 0xea, 0x03, 0xc2, 0x31, 0x43, 0x05, 0x25, 0xc8, 0x44,
		0x41, 0x0a, 0x32, 0x4e, 0xe0, 0x81, 0xcc, 0x12, 0x9c, 0xa8, 0x1a, 0x70, 0x9a, 0x08, 0x38, 0x20,
		0xe5, 0x29, 0x29, 0x05, 0x14, 0x87, 0x46, 0x0f, 0xf7, 0x78, 0xc1, 0xcf, 0x52, 0x39, 0x72, 0x3c,
		0xc3, 0x3e, 0xee, 0x3a, 0x96, 0x7b, 0x72, 0x8a, 0xaa, 0x27, 0x08, 0x5a, 0x88, 0xa0, 0xfb, 0x3f,
		0xa1, 0xec, 0xb9, 0xda, 0x2f, 0x94, 0x3d, 0x21, 0x0a, 0x54, 0x73, 0xe6, 0x20, 0x05, 0x4e, 0x5b,
		0x29, 0x67, 0x4d, 0xdf, 0x49, 0xd3, 0xbe, 0x8e, 0x74, 0xad, 0xa3, 0x69, 0x19, 0x51, 0x07, 0xaa,
		0x19, 0x51, 0x14, 0x4b, 0x5f, 0x06, 0x71, 0xa4, 0xed, 0x13, 0x76, 0x9d, 0x5a, 0x3a, 0xfc, 0x24,
		0xae, 0xfd, 0xb1, 0x2f, 0x3f, 0x4d, 0x9d, 0x65, 0x23, 0x1e, 0x8b, 0x68, 0x18, 0x47, 0x97, 0xc1,
		0x95, 0x1e, 0x09, 0xf9, 0x25, 0x4e, 0x3e, 0xeb, 0x41, 0x94, 0x4a, 0x3f, 0x1a, 0x8a, 0xc6, 0xe3,
		0x17, 0xd2, 0x27, 0xaf, 0x34, 0xc6, 0x49, 0x2c, 0xe3, 0x61, 0x1c, 0xa6, 0xe5, 0xb3, 0x46, 0x90,
		0x06, 0x69, 0x23, 0x14, 0x37, 0x22, 0x2c, 0x1e, 0x1a, 0x61, 0x10, 0x7d, 0xd6, 0x53, 0xe9, 0x4b,
		0xa1, 0x8f, 0x7c, 0xe9, 0x5f, 0xf8, 0xa9, 0x68, 0x84, 0xe9, 0xb8, 0x21, 0xc3, 0x9b, 0x74, 0xfa,
		0xad, 0x71, 0x2d, 0xf5, 0x60, 0x7c, 0xd3, 0xd4, 0x13, 0xe1, 0x0f, 0x3f, 0xf9, 0x17, 0x41, 0x18,
		0xc8, 0xdb, 0xc6, 0x38, 0x11, 0x97, 0xc1, 0x57, 0x91, 0x16, 0x4f, 0x1a, 0xe9, 0xe4, 0x22, 0xfb,
		0x81, 0xfc, 0xb1, 0x11, 0x8c, 0x6f, 0x5a, 0x7a, 0x1a, 0x4f, 0x92, 0xa1, 0xd0, 0x93, 0x78, 0x22,
		0x45, 0xa2, 0x07, 0xa3, 0x46, 0xf6, 0x5b, 0x08, 0x97, 0x08, 0xb4, 0x54, 0x26, 0x93, 0xa1, 0x8c,
		0x8a, 0x58, 0xd5, 0x2d, 0xaf, 0x7e, 0x27, 0xbf, 0xb2, 0x56, 0x71, 0x61, 0xbd, 0x47, 0x7f, 0x4e,
		0x1f, 0xbf, 0xe0, 0xf5, 0x66, 0x57, 0xbe, 0x7c, 0xe6, 0x59, 0x69, 0x90, 0x7a, 0x76, 0x76, 0xe5,
		0xf3, 0x07, 0xcf, 0x0e, 0xa2, 0xcf, 0xfd, 0xe9, 0x25, 0x69, 0x17, 0xd7, 0xdd, 0xb3, 0xd3, 0xb1,
		0xe7, 0x86, 0x37, 0xe9, 0xf4, 0x9b, 0x77, 0x2a, 0xad, 0xf1, 0x4d, 0xd3, 0x79, 0x70, 0xd5, 0xbd,
		0x5e, 0x71, 0xd5, 0x8b, 0x27, 0x5e, 0x3f, 0xbf, 0xea, 0xc5, 0xa3, 0x67, 0x8d, 0x6f, 0x5a, 0xfd,
		0xec, 0xa2, 0x3b, 0xd9, 0x35, 0xb7, 0x46, 0x5e, 0xf6, 0xff, 0xd3, 0x8c, 0xaa, 0xf4, 0x3c, 0x18,
		0x2d, 0x8b, 0x88, 0xf9, 0x52, 0xea, 0x3e, 0x54, 0x6d, 0xdf, 0x49, 0xd0, 0x6b, 0xaa, 0xe7, 0x2d,
		0x69, 0xf9, 0x49, 0x3a, 0xde, 0x88, 0x90, 0x27, 0xd2, 0xf2, 0x35, 0xa3, 0xa7, 0xc1, 0x28, 0x25,
		0xe7, 0x86, 0xca, 0x2c, 0xf7, 0xa1, 0x91, 0xc4, 0xbc, 0xf8, 0xbb, 0x20, 0x1a, 0x69, 0xfb, 0x1b,
		0x5b, 0xc4, 0xcc, 0x3a, 0xcc, 0x3c, 0x87, 0xb6, 0xbf, 0xb1, 0x49, 0xcc, 0xb0, 0xdc, 0x77, 0xd0,
		0x8c, 0x78, 0x33, 0xdc, 0xe2, 0xa1, 0x3e, 0x8d, 0x4d, 0x14, 0x63, 0x44, 0xee, 0x60, 0xc9, 0x26,
		0x5d, 0xda, 0x3b, 0x71, 0xfb, 0x25, 0x4e, 0x46, 0xf7, 0x8b, 0x96, 0x68, 0x7a, 0xa2, 0x9d, 0xf8,
		0xa9, 0x91, 0x5c, 0x4d, 0xae, 0x45, 0x24, 0xb5, 0xfd, 0x0d, 0x99, 0x4c, 0x04, 0xd5, 0x54, 0xfb,
		0xde, 0xca, 0x12, 0x4c, 0x28, 0x7d, 0x56, 0x4a, 0xbf, 0x1d, 0x24, 0x34, 0x1d, 0xde, 0x7d, 0x5c,
		0xa5, 0xeb, 0x51, 0x9e, 0x6a, 0x00, 0xaa, 0x2e, 0x85, 0xa6, 0x14, 0x20, 0x2f, 0x09, 0x38, 0x48,
		0x03, 0x46, 0x12, 0x81, 0x8b, 0x54, 0x60, 0x27, 0x19, 0xd8, 0x49, 0x07, 0x5e, 0x12, 0x82, 0xa6,
		0x94, 0x20, 0x2a, 0x29, 0xc8, 0x4b, 0x8b, 0xd2, 0xc0, 0xfc, 0x1e, 0x05, 0x79, 0x27, 0x34, 0xf3,
		0xeb, 0xd4, 0x6f, 0xa9, 0x30, 0x10, 0x1a, 0x6c, 0x04, 0x07, 0x27, 0xe1, 0xc1, 0x50, 0x80, 0x70,
		0x13, 0x22, 0x6c, 0x05, 0x09, 0x5b, 0x61, 0xc2, 0x53, 0xa0, 0xd0, 0x16, 0x2a, 0xc4, 0x05, 0x0b,
		0x1b, 0xe1, 0x52, 0x1a, 0xea, 0x87, 0x57, 0x71, 0x12, 0xc8, 0x4f, 0xd7, 0x7c, 0x1c, 0xd8, 0x2c,
		0x46, 0xdc, 0x9b, 0xce, 0xc4, 0x0f, 0x14, 0xc2, 0x66, 0x93, 0x89, 0xb9, 0x5c, 0x04, 0x0e, 0x47,
		0xa1, 0xc3, 0x58, 0xf0, 0x70, 0x15, 0x3e, 0xec, 0x05, 0x10, 0x7b, 0x21, 0xc4, 0x5b, 0x10, 0xf1,
		0x10, 0x46, 0x4c, 0x04, 0x52, 0x89, 0x82, 0x7b, 0x3b, 0x16, 0x3c, 0x3d, 0xf6, 0x24, 0x88, 0xe4,
		0x5b, 0x4e, 0xfe, 0xba, 0x90, 0x1f, 0x3b, 0x8c, 0x4c, 0x76, 0xfc, 0xe8, 0x4a, 0xb0, 0xeb, 0xb7,
		0xe5, 0xd7, 0x29, 0xa9, 0x9d, 0x06, 0x11, 0xbb, 0x40, 0xce, 0x54, 0x57, 0x3f, 0x31, 0x3f, 0xeb,
		0x2a, 0x67, 0x6c, 0xff, 0x51, 0xe2, 0x0f, 0x65, 0x10, 0x47, 0xed, 0xe0, 0x2a, 0x90, 0xe9, 0xf4,
		0x8d, 0xa0, 0x1d, 0xbb, 0x8a, 0x25, 0xeb, 0x7f, 0xc5, 0x92, 0xad, 0x79, 0xc9, 0x6e, 0xef, 0xec,
		0x60, 0xd1, 0x42, 0x88, 0xab, 0x65, 0x2d, 0x8f, 0x56, 0x7d, 0xfa, 0xd7, 0x93, 0x41, 0x50, 0xd1,
		0x2e, 0x43, 0xff, 0x2a, 0xe5, 0x57, 0xfa, 0xcd, 0xcd, 0x46, 0xd9, 0x77, 0x15, 0xe6, 0xa2, 0xec,
		0x5b, 0x21, 0xc8, 0x28, 0xfb, 0x56, 0xb7, 0x0c, 0x51, 0xf6, 0xad, 0xf9, 0x0d, 0xa0, 0xec, 0x0b,
		0xcd, 0x51, 0xa0, 0xc0, 0xb7, 0xec, 0x2b, 0xa2, 0xc9, 0xb5, 0x48, 0xf2, 0xc6, 0x66, 0x7e, 0xc5,
		0xdf, 0xad, 0x26, 0x23, 0x9b, 0xcd, 0x68, 0x92, 0x6d, 0x4b, 0xc0, 0xd2, 0x5b, 0xe6, 0x55, 0xb5,
		0x83, 0x54, 0x1a, 0x52, 0x26, 0xbc, 0x96, 0xdf, 0x69, 0x10, 0x99, 0xa1, 0x98, 0x46, 0x8f, 0x94,
		0x57, 0xdd, 0x48, 0x3b, 0xf5, 0xbf, 0x3e, 0xb0, 0x7c, 0xeb, 0x6d, 0xb3, 0xd9, 0xda, 0x6d, 0x36,
		0x37, 0x77, 0xdf, 0xec, 0x6e, 0xee, 0xed, 0xec, 0x6c, 0xb5, 0xb6, 0x38, 0xdd, 0x90, 0xe9, 0x26,
		0x23, 0x91, 0x88, 0xd1, 0xc1, 0xad, 0xb6, 0xbf, 0x11, 0x4d, 0xc2, 0x10, 0xa5, 0x82, 0xb5, 0x29,
		0x15, 0xdc, 0x14, 0x35, 0x4f, 0x66, 0xa5, 0x82, 0xdc, 0x6c, 0x94, 0x0a, 0x50, 0x2a, 0x40, 0xa9,
		0x00, 0xa5, 0x02, 0x94, 0x0a, 0x50, 0x2a, 0x80, 0xde, 0x40, 0xa9, 0xa0, 0x12, 0x8f, 0x3d, 0x09,
		0x22, 0xf9, 0x66, 0x9b, 0x61, 0x95, 0x60, 0x17, 0x5b, 0xc4, 0x56, 0xfc, 0x85, 0x2d, 0x62, 0x10,
		0xd6, 0xcf, 0x30, 0x1f, 0x5b, 0xc4, 0x10, 0x2e, 0x17, 0x59, 0xb2, 0xd8, 0x22, 0x56, 0xfb, 0x92,
		0x6d, 0x6e, 0xef, 0x35, 0xf7, 0x5a, 0xbb, 0xdb, 0x7b, 0xd8, 0x29, 0x06, 0x41, 0xae, 0x98, 0xb5,
		0xd8, 0x29, 0xb6, 0x0e, 0x16, 0x52, 0xef, 0xb5, 0x66, 0x32, 0xad, 0xbf, 0xb4, 0x57, 0x95, 0xc9,
		0xd3, 0x0f, 0xc6, 0xd6, 0x3e, 0x78, 0xde, 0xe0, 0x30, 0x63, 0x66, 0x43, 0x81, 0x81, 0xd4, 0xf9,
		0xab, 0xfd, 0x60, 0x94, 0xde, 0x3f, 0xa5, 0x3c, 0xc0, 0x9f, 0xbe, 0xb3, 0x23, 0xec, 0xe8, 0x98,
		0xdc, 0x7d, 0x63, 0x75, 0xd7, 0x8d, 0x49, 0x86, 0x81, 0x41, 0x53, 0xab, 0x04, 0x15, 0x83, 0xa6,
		0x56, 0xb7, 0xbc, 0x30, 0x68, 0xaa, 0x6a, 0x25, 0x8c, 0x41, 0x53, 0xeb, 0x96, 0xfc, 0xb0, 0xb9,
		0x3b, 0x56, 0x7a, 0xdc, 0x50, 0xf8, 0x97, 0x89, 0xb8, 0xe4, 0xe0, 0x71, 0x67, 0x9b, 0x66, 0x19,
		0xdc, 0x0f, 0xd3, 0x7a, 0x45, 0x3e, 0xf9, 0xc7, 0x1f, 0x79, 0x06, 0xd6, 0xc8, 0x25, 0x18, 0x52,
		0x01, 0x85, 0x2c, 0xa3, 0x3a, 0xa6, 0xf7, 0x9d, 0xb8, 0xa5, 0x2e, 0xfa, 0x79, 0x6c, 0x7b, 0xe6,
		0xb3, 0xcd, 0x99, 0xf5, 0xb6, 0x66, 0x1e, 0xdb, 0x98, 0x71, 0x3a, 0xea, 0xcb, 0xec, 0x54, 0xbb,
		0xce, 0x8a, 0x83, 0x51, 0x2b, 0xad, 0xac, 0xe2, 0x50, 0x54, 0x8e, 0x16, 0xe1, 0x50, 0xd4, 0xb5,
		0x77, 0x99, 0x38, 0x0a, 0x75, 0x85, 0xfe, 0x11, 0x47, 0xa0, 0x92, 0xf7, 0x3b, 0x44, 0x8f, 0x28,
		0x21, 0x7d, 0x24, 0x09, 0x8e, 0x3d, 0x7d, 0x6e, 0xf1, 0x09, 0xc7, 0x9e, 0xbe, 0xc4, 0x44, 0x1c,
		0x7b, 0xba, 0x24, 0x43, 0x71, 0xec, 0x29, 0xb4, 0x7c, 0x55, 0x1f, 0x21, 0xd9, 0x63, 0x4f, 0x25,
		0xe5, 0x5b, 0x42, 0xa5, 0x3b, 0xce, 0xac, 0xa4, 0x7d, 0xd4, 0xe9, 0x26, 0x8e, 0x3a, 0x55, 0x4e,
		0x0e, 0x30, 0x92, 0x05, 0x5c, 0xe4, 0x01, 0x3b, 0x99, 0xc0, 0x4e, 0x2e, 0xf0, 0x92, 0x0d, 0x34,
		0xe5, 0x03, 0x51, 0x19, 0x51, 0x7e, 0xb4, 0xe4, 0x37, 0x72, 0x94, 0x1e, 0x33, 0x18, 0x89, 0x48,
		0x06, 0xf2, 0x96, 0xf6, 0x26, 0x8e, 0x32, 0x87, 0xa7, 0x7c, 0x1f, 0xd2, 0x2a, 0x2e, 0xe5, 0x81,
		0x9f, 0x32, 0xda, 0xdc, 0x6b, 0xf5, 0xad, 0xbe, 0xd7, 0x1f, 0x1c, 0xb8, 0xf6, 0x99, 0xe7, 0x7e,
		0xe8, 0x99, 0xd4, 0xdd, 0x7c, 0xd6, 0x8a, 0x97, 0xb2, 0xe8, 0x11, 0x67, 0x36, 0x5c, 0xc9, 0xea,
		0x7b, 0x8e, 0x69, 0x1c, 0x9e, 0x18, 0x07, 0x96, 0x6d, 0xb9, 0x1f, 0x0a, 0x28, 0xfa, 0x1c, 0xa8,
		0xe0, 0x48, 0x07, 0x2f, 0x4a, 0x7e, 0x4a, 0xcb, 0x81, 0xd1, 0x69, 0xff, 0xd7, 0x6a, 0xbb, 0x27,
		0xde, 0x61, 0xb7, 0xd3, 0x77, 0x1d, 0xc3, 0xea, 0xb8, 0x7d, 0x46, 0x63, 0x5e, 0x7e, 0x07, 0x30,
		0xd5, 0x02, 0x33, 0x70, 0x2d, 0xdb, 0xfa, 0xcb, 0x6c, 0xdf, 0x93, 0x03, 0x5a, 0x40, 0xcb, 0x3c,
		0x5a, 0x8c, 0xf6, 0x9f, 0x5e, 0xdf, 0x6a, 0x03, 0x11, 0x20, 0x32, 0x17, 0x91, 0x33, 0xc3, 0xb2,
		0x8d, 0x03, 0xdb, 0x84, 0x47, 0x01, 0x2e, 0x3f, 0xc7, 0xc5, 0xea, 0x9d, 0xb5, 0xbc, 0x8e, 0x69,
		0x1d, 0x9f, 0x1c, 0x74, 0x1d, 0xcf, 0x68, 0xb7, 0x1d, 0xb3, 0x0f, 0xc1, 0x02, 0x60, 0xe6, 0x0b,
		0x96, 0x4e, 0xa9, 0x6c, 0xcd, 0xb6, 0x67, 0xf7, 0x7b, 0x80, 0x05, 0xb0, 0xcc, 0x83, 0xc5, 0xb6,
		0x3a, 0xef, 0x3c, 0xc3, 0x75, 0x1d, 0xeb, 0x60, 0xe0, 0x9a, 0xf0, 0x2b, 0x40, 0xe5, 0xc7, 0xa8,
		0xf4, 0x9c, 0xae, 0x6b, 0x1e, 0xba, 0x56, 0xb7, 0x93, 0xd7, 0x5b, 0xc0, 0x0b, 0x78, 0x99, 0x9b,
		0x0a, 0x9d, 0x5a, 0x1d, 0xef, 0xd8, 0xe9, 0x0e, 0x10, 0x81, 0x80, 0xc9, 0x8f, 0xf5, 0xad, 0xd5,
		0x71, 0x4d, 0xe7, 0xc8, 0x38, 0x34, 0x21, 0x70, 0x41, 0xcc, 0xcf, 0x88, 0x39, 0x35, 0xde, 0xe7,
		0xc1, 0x08, 0xf9, 0x33, 0x68, 0xf9, 0x85, 0x30, 0xf4, 0xa7, 0x67, 0x1b, 0x1d, 0x54, 0xe5, 0x80,
		0xc9, 0x4f, 0xd5, 0x2d, 0x10, 0x01, 0x22, 0x3f, 0x54, 0x2a, 0x4d, 0x54, 0xe2, 0x00, 0xcc, 0xf3,
		0x80, 0x81, 0xb4, 0x05, 0x31, 0xcf, 0x92, 0xb6, 0x8e, 0xd9, 0x37, 0x9d, 0x33, 0xdc, 0x20, 0x02,
		0x33, 0xbf, 0xc6, 0x8c, 0x6b, 0x7a, 0x6d, 0xf3, 0xc8, 0x18, 0xd8, 0xae, 0x77, 0x6a, 0xba, 0x8e,
		0x75, 0x08, 0x58, 0x00, 0xcb, 0xfc, 0x9b, 0x43, 0xb9, 0x7b, 0xc1, 0x7e, 0x16, 0xf0, 0xf2, 0xcb,
		0x69, 0x51, 0xdb, 0xb4, 0x8d, 0x0f, 0xde, 0x99, 0xe1, 0x58, 0x86, 0x6b, 0x75, 0x3b, 0xe0, 0x05,
		0xbc, 0xcc, 0xe3, 0xc5, 0x7c, 0xef, 0x9a, 0x9d, 0xb6, 0xd9, 0x46, 0xf5, 0x1f, 0xbc, 0xfc, 0x92,
		0xe0, 0xb5, 0x3a, 0xf7, 0xf5, 0xdc, 0xcc, 0xcf, 0x80, 0x16, 0xd0, 0xf2, 0xc3, 0x68, 0x64, 0x77,
		0x91, 0x43, 0x03, 0x92, 0x5f, 0x91, 0x2c, 0xa0, 0x04, 0x94, 0xcc, 0xa3, 0xc4, 0x31, 0xfb, 0x56,
		0x7b, 0x60, 0xd8, 0x2c, 0xd3, 0x20, 0x16, 0x96, 0xd2, 0x3f, 0xa8, 0x8b, 0xc1, 0xaa, 0x63, 0xde,
		0x9b, 0xc7, 0xb4, 0xdb, 0x0a, 0x60, 0xac, 0x1a, 0x0c, 0x8e, 0x5d, 0x55, 0xa0, 0x62, 0xd5, 0x54,
		0xb0, 0xe9, 0x9e, 0x02, 0x0a, 0x2b, 0x47, 0x81, 0x63, 0x97, 0x14, 0xb0, 0x58, 0x35, 0x16, 0x4c,
		0xbb, 0xa1, 0x00, 0xc6, 0xca, 0x05, 0x05, 0xbf, 0xae, 0x27, 0x40, 0xb1, 0x6a, 0x28, 0xd8, 0x75,
		0x37, 0x01, 0x89, 0x4a, 0x90, 0x60, 0xd7, 0xc5, 0x04, 0x2e, 0x56, 0x9f, 0x7a, 0x30, 0xba, 0x5f,
		0x09, 0x1c, 0x2a, 0xd1, 0x99, 0x0c, 0xb7, 0x6e, 0x82, 0x8c, 0x55, 0x93, 0xc1, 0xb1, 0xfb, 0x08,
		0x54, 0xac, 0x3e, 0x7c, 0x30, 0xea, 0x32, 0x02, 0x0e, 0x95, 0xa8, 0x4c, 0xa0, 0x00, 0x14, 0xd8,
		0x76, 0x0d, 0x01, 0x8c, 0x4a, 0xc0, 0x80, 0xc4, 0x04, 0x19, 0x0a, 0x75, 0x01, 0x81, 0x8d, 0x55,
		0xb3, 0xc1, 0xb0, 0xdb, 0x07, 0x50, 0xac, 0x1a, 0x0a, 0x9e, 0x5d, 0x3d, 0xe0, 0xa2, 0x92, 0x34,
		0x84, 0x5d, 0xf7, 0x0e, 0xb8, 0x58, 0x35, 0x17, 0x3c, 0xbb, 0x74, 0xc0, 0xc5, 0xca, 0x85, 0x27,
		0xc3, 0x6e, 0x1c, 0x50, 0x51, 0x49, 0x14, 0xe1, 0xd1, 0x75, 0x03, 0x18, 0xaa, 0x93, 0x14, 0xa0,
		0x01, 0x34, 0x70, 0xec, 0xa2, 0x01, 0x15, 0x4b, 0xa7, 0xa2, 0x87, 0x13, 0x99, 0x40, 0xc9, 0xa2,
		0xb4, 0xb8, 0xc6, 0x71, 0xab, 0x89, 0x56, 0x4d, 0x00, 0x32, 0x0f, 0x90, 0x9e, 0x63, 0x1e, 0x59,
		0xef, 0x31, 0xc0, 0x13, 0x94, 0xfc, 0x88, 0x92, 0x6c, 0xc7, 0x96, 0xd3, 0x1d, 0xb8, 0xa6, 0x83,
		0x39, 0x9e, 0x20, 0xe5, 0xc7, 0x01, 0x07, 0x78, 0x00, 0x8f, 0x9f, 0x84, 0x9b, 0x23, 0xdb, 0x38,
		0xc6, 0x9c, 0x11, 0x70, 0xf2, 0xa3, 0x80, 0xd3, 0x64, 0x19, 0x70, 0x30, 0x3d, 0x02, 0x75, 0x04,
		0x64, 0x86, 0x00, 0x01, 0x19, 0x20, 0x68, 0x40, 0xa6, 0x07, 0x22, 0x94, 0x08, 0x14, 0xc0, 0x00,
		0x18, 0xf0, 0xca, 0xdc, 0xc0, 0x03, 0x32, 0x34, 0x10, 0xb1, 0x5a, 0x22, 0x8a, 0x0f, 0xff, 0xd0,
		0xe8, 0xe1, 0xde, 0x24, 0x38, 0x59, 0x88, 0x17, 0xc7, 0x33, 0xec, 0xe3, 0xae, 0x63, 0xb9, 0x27,
		0xa7, 0xa8, 0x06, 0x82, 0x94, 0x1f, 0x92, 0x72, 0xff, 0x27, 0x94, 0x03, 0x97, 0xfb, 0x85, 0x72,
		0x20, 0x82, 0x37, 0x37, 0x67, 0x0c, 0x22, 0xe0, 0x74, 0x59, 0x39, 0x5b, 0xba, 0x4e, 0x96, 0xe6,
		0x75, 0xa3, 0x67, 0x15, 0x2d, 0x8b, 0x88, 0x39, 0x40, 0xcd, 0x88, 0xa2, 0x58, 0xfa, 0x32, 0x88,
		0x23, 0x6d, 0x9f, 0xa0, 0xeb, 0xd3, 0xd2, 0xe1, 0x27, 0x71, 0xed, 0x8f, 0x7d, 0xf9, 0x69, 0xea,
		0xec, 0x1a, 0xf1, 0x58, 0x44, 0xc3, 0x38, 0xba, 0x0c, 0xae, 0xf4, 0x48, 0xc8, 0x2f, 0x71, 0xf2,
		0x59, 0x0f, 0xa2, 0x54, 0xfa, 0xd1, 0x50, 0x34, 0x1e, 0xbf, 0x90, 0x3e, 0x79, 0xa5, 0x31, 0x4e,
		0x62, 0x19, 0x0f, 0xe3, 0x30, 0x2d, 0x9f, 0x35, 0x82, 0x34, 0x48, 0x1b, 0xa1, 0xb8, 0x11, 0x61,
		0xf1, 0xd0, 0x08, 0x83, 0xe8, 0xb3, 0x9e, 0x4a, 0x5f, 0x0a, 0x7d, 0xe4, 0x4b, 0xff, 0xc2, 0x4f,
		0x45, 0x23, 0x4c, 0xc7, 0x0d, 0x19, 0xde, 0xa4, 0xd3, 0x6f, 0x8d, 0x6b, 0xa9, 0x07, 0xe3, 0x9b,
		0xa6, 0x9e, 0x08, 0x7f, 0xf8, 0xc9, 0xbf, 0x08, 0xc2, 0x40, 0xde, 0x36, 0xc6, 0x89, 0xb8, 0x0c,
		0xbe, 0x8a, 0xb4, 0x78, 0xd2, 0x48, 0x27, 0x17, 0xd9, 0x0f, 0xe4, 0x8f, 0x8d, 0xec, 0xff, 0x23,
		0x98, 0x5c, 0x6b, 0xa9, 0x4c, 0x26, 0x43, 0x19, 0x15, 0xd1, 0xa4, 0x5b, 0x5e, 0xdf, 0x4e, 0x7e,
		0xed, 0xac, 0xe2, 0xd2, 0x79, 0x8f, 0xfe, 0x9c, 0x3e, 0x7e, 0xc1, 0xeb, 0xcd, 0xae, 0x6d, 0xf9,
		0xcc, 0xb3, 0xd2, 0x20, 0xf5, 0xec, 0xec, 0xda, 0xe6, 0x0f, 0x9e, 0x1d, 0x44, 0x9f, 0xfb, 0xd3,
		0x4b, 0xd1, 0x2e, 0xae, 0xac, 0x67, 0xa7, 0x63, 0xcf, 0x0d, 0x6f, 0xd2, 0xe9, 0x37, 0xef, 0x54,
		0x5a, 0xe3, 0x9b, 0xa6, 0xf3, 0xe0, 0xba, 0x7a, 0xbd, 0xe2, 0xba, 0x16, 0x4f, 0xbc, 0x7e, 0x7e,
		0x5d, 0x8b, 0x47, 0x2f, 0xfb, 0xcf, 0x68, 0x05, 0x39, 0x3a, 0x0e, 0x87, 0x90, 0xb3, 0xd1, 0xa4,
		0x7f, 0x45, 0xce, 0xc3, 0x94, 0x22, 0x6a, 0x6a, 0x1c, 0x31, 0xc7, 0xfc, 0x2e, 0x88, 0x46, 0xda,
		0xfe, 0xc6, 0x16, 0x31, 0xb3, 0x0e, 0x33, 0xe7, 0xa0, 0xed, 0x6f, 0x6c, 0x12, 0x33, 0x2c, 0x77,
		0x0f, 0x34, 0x83, 0xd8, 0x0c, 0xb3, 0x78, 0xa8, 0x4f, 0xc3, 0x0d, 0xc5, 0x30, 0xd0, 0x8f, 0x27,
		0xc9, 0x50, 0x90, 0xbc, 0x7c, 0xf9, 0x72, 0x10, 0xb7, 0x5f, 0xe2, 0x64, 0xba, 0x22, 0xb4, 0x3c,
		0xc0, 0x12, 0x2d, 0x54, 0x6b, 0x27, 0x7e, 0x6a, 0x24, 0x57, 0x93, 0x6b, 0x11, 0x49, 0x6d, 0x7f,
		0x43, 0x26, 0x13, 0x41, 0xd4, 0xd0, 0x07, 0x56, 0x96, 0x60, 0x42, 0xbc, 0xb3, 0x12, 0xef, 0xed,
		0x20, 0x21, 0xaa, 0xda, 0x33, 0x55, 0x46, 0xd6, 0x99, 0xcc, 0xfc, 0x31, 0x55, 0x51, 0x4e, 0x58,
		0x00, 0x90, 0x17, 0x02, 0x1c, 0x04, 0x01, 0x23, 0x61, 0xc0, 0x45, 0x20, 0xb0, 0x13, 0x0a, 0xec,
		0x04, 0x03, 0x2f, 0xe1, 0x40, 0x53, 0x40, 0x10, 0x15, 0x12, 0xe4, 0x05, 0xc5, 0xc3, 0x2a, 0xc2,
		0x9b, 0x6d, 0xfa, 0x4e, 0xe8, 0x41, 0x5d, 0xe1, 0xcd, 0x36, 0x75, 0x07, 0x54, 0x08, 0x8d, 0x4d,
		0xe2, 0x66, 0x52, 0x17, 0x1c, 0x9c, 0x84, 0x07, 0x43, 0x01, 0xc2, 0x4d, 0x88, 0xb0, 0x15, 0x24,
		0x6c, 0x85, 0x09, 0x4f, 0x81, 0x42, 0x5b, 0xa8, 0x10, 0x17, 0x2c, 0xe5, 0x47, 0xee, 0xde, 0x8e,
		0x05, 0x2f, 0x8f, 0x3b, 0x09, 0x22, 0x49, 0x5e, 0x1b, 0x3c, 0xd4, 0x07, 0xbb, 0x0c, 0x4c, 0x75,
		0xfc, 0xe8, 0x4a, 0xb0, 0xd9, 0x14, 0xcc, 0x67, 0x9b, 0xa7, 0x76, 0x1a, 0x44, 0x6c, 0x22, 0x2e,
		0x33, 0x61, 0xfb, 0xc4, 0xec, 0x6c, 0x6b, 0x3b, 0x43, 0xbb, 0x8f, 0x12, 0x7f, 0x28, 0x83, 0x38,
		0x6a, 0x07, 0x57, 0x81, 0x4c, 0xa7, 0x6f, 0x00, 0x7b, 0xc3, 0x57, 0xb1, 0x14, 0xfd, 0xaf, 0x58,
		0x8a, 0x15, 0x2f, 0xc5, 0xe6, 0xf6, 0x5e, 0x73, 0xaf, 0xb5, 0xbb, 0xbd, 0xb7, 0x83, 0x35, 0x09,
		0x41, 0xcc, 0xcb, 0xca, 0x73, 0x24, 0x16, 0x2f, 0x58, 0x40, 0x76, 0x90, 0x4a, 0x43, 0xca, 0x84,
		0x47, 0x72, 0x71, 0x1a, 0x44, 0x66, 0x28, 0xa6, 0xb9, 0x6f, 0xca, 0xc3, 0xdb, 0x4e, 0xa3, 0xd9,
		0x03, 0x8b, 0xb7, 0xde, 0x36, 0x9b, 0xad, 0xdd, 0x66, 0x73, 0x73, 0xf7, 0xcd, 0xee, 0xe6, 0xde,
		0xce, 0xce, 0x56, 0x6b, 0x8b, 0x81, 0xc7, 0xd5, 0xba, 0xc9, 0x48, 0x24, 0x62, 0x74, 0x70, 0xab,
		0xed, 0x6f, 0x44, 0x93, 0x30, 0xfc, 0x0d, 0x1e, 0x4b, 0x1d, 0xcb, 0xa8, 0xde, 0xab, 0x21, 0xbe,
		0x73, 0xbb, 0xb4, 0x53, 0x95, 0x1d, 0xdc, 0xd2, 0xbf, 0x6a, 0x50, 0xde, 0x30, 0xb2, 0xa1, 0xc0,
		0x6e, 0x6e, 0xd7, 0xbf, 0xa2, 0xb8, 0xa3, 0x9b, 0xae, 0x83, 0xc2, 0xfe, 0x38, 0xc6, 0x2e, 0x52,
		0x25, 0xd7, 0x88, 0xd6, 0x96, 0x55, 0x38, 0x43, 0x34, 0xb6, 0x90, 0x77, 0x34, 0x9a, 0xf4, 0xaf,
		0x5a, 0x4d, 0xd2, 0xad, 0x2d, 0xad, 0x26, 0x9a, 0x5b, 0x7e, 0xc9, 0x2c, 0x34, 0xb7, 0xbc, 0x00,
		0x34, 0x34, 0xb7, 0x2c, 0xbe, 0x1c, 0xd0, 0xdc, 0xb2, 0x6c, 0xe5, 0x87, 0xe6, 0x16, 0xee, 0xe2,
		0x1d, 0xcd, 0x2d, 0x2f, 0xf3, 0xc7, 0x68, 0x6e, 0x51, 0x4f, 0x08, 0x70, 0x10, 0x04, 0x8c, 0x84,
		0x01, 0x17, 0x81, 0xc0, 0x4e, 0x28, 0xb0, 0x13, 0x0c, 0xbc, 0x84, 0x03, 0x4d, 0x01, 0x41, 0x54,
		0x48, 0x90, 0x17, 0x14, 0xc4, 0x2b, 0x09, 0xac, 0x2a, 0x0b, 0xf3, 0x84, 0x06, 0x9a, 0x5b, 0xd6,
		0x47, 0x78, 0x30, 0x14, 0x20, 0xdc, 0x84, 0x08, 0x5b, 0x41, 0xc2, 0x56, 0x98, 0xf0, 0x14, 0x28,
		0xb4, 0x85, 0x0a, 0x71, 0xc1, 0x52, 0x7e, 0xe4, 0x3c, 0x9b, 0x5b, 0xc8, 0x6b, 0x83, 0x87, 0xfa,
		0xe0, 0x2d, 0x9a, 0x5b, 0x96, 0xfc, 0x85, 0xe6, 0x16, 0x08, 0xdb, 0xef, 0x98, 0x8d, 0xe6, 0x16,
		0x84, 0xb7, 0x1f, 0x2d, 0x45, 0x34, 0xb7, 0x54, 0xbe, 0x14, 0x79, 0x6e, 0xba, 0x56, 0x66, 0x75,
		0xa2, 0xcd, 0x65, 0x29, 0x5f, 0x68, 0x73, 0x79, 0xc9, 0x02, 0x42, 0x9b, 0xcb, 0xca, 0xe3, 0x1a,
		0xda, 0x5c, 0xe0, 0xb1, 0x08, 0x5b, 0x86, 0x36, 0x97, 0x97, 0xd9, 0xa9, 0xd0, 0x5e, 0xee, 0x56,
		0x13, 0x8d, 0x2e, 0xab, 0xdf, 0xdb, 0xdd, 0x6a, 0xa2, 0xd5, 0x85, 0xaf, 0x45, 0x68, 0x75, 0x59,
		0x63, 0xf7, 0x88, 0x66, 0x97, 0xd5, 0x38, 0x44, 0xb4, 0xbb, 0x90, 0x77, 0x36, 0x9a, 0xa4, 0x78,
		0x33, 0xea, 0x7e, 0x4f, 0xca, 0xd4, 0x3a, 0x9a, 0xcd, 0x2e, 0x9b, 0x68, 0x76, 0xf9, 0x35, 0xc3,
		0xd0, 0xec, 0xf2, 0x22, 0x13, 0xd1, 0xec, 0xb2, 0x24, 0x43, 0xd1, 0xec, 0x02, 0xf9, 0x5e, 0xd5,
		0x47, 0x48, 0x76, 0x8b, 0x47, 0xe9, 0xf1, 0x42, 0xe1, 0x5f, 0x26, 0xe2, 0x92, 0xa2, 0xc7, 0x9b,
		0x35, 0x93, 0x10, 0x9c, 0x50, 0xaa, 0xf5, 0x8a, 0x8c, 0xe7, 0x8f, 0x3f, 0xf2, 0x9a, 0x4a, 0x23,
		0x53, 0x28, 0xd0, 0xb9, 0x84, 0x2d, 0x21, 0xe2, 0x1b, 0xa6, 0x81, 0x92, 0x98, 0xa4, 0xa5, 0x79,
		0x9b, 0x88, 0xee, 0xed, 0x20, 0x56, 0xb7, 0x7d, 0x68, 0xde, 0xde, 0xa1, 0xb2, 0x18, 0x89, 0xd6,
		0xd7, 0x54, 0xa9, 0xab, 0x11, 0x92, 0x15, 0xcc, 0x2b, 0x69, 0x34, 0xb4, 0x45, 0xfd, 0x91, 0xbc,
		0x5e, 0x0b, 0x6a, 0x76, 0x5b, 0xd4, 0xdc, 0x15, 0x7b, 0x37, 0x45, 0xc0, 0x3f, 0x71, 0xf5, 0x4b,
		0xf5, 0x3a, 0xa4, 0xfa, 0xdc, 0x40, 0x8d, 0x2e, 0x40, 0x9b, 0x44, 0x23, 0x71, 0x19, 0x44, 0x62,
		0xa4, 0xcf, 0xf8, 0xad, 0xdb, 0x0b, 0xdc, 0xb7, 0x86, 0x3c, 0x31, 0xad, 0x66, 0x57, 0x49, 0x63,
		0x14, 0x05, 0x99, 0x72, 0x3c, 0xa5, 0xf2, 0x3b, 0xc1, 0x72, 0x3b, 0xb5, 0xf2, 0x3a, 0xd9, 0x72,
		0x3a, 0xd9, 0xf2, 0x39, 0xcd, 0x72, 0xf9, 0x7a, 0xcb, 0x55, 0x2a, 0xa3, 0x19, 0x9e, 0x44, 0x27,
		0x3a, 0xeb, 0x7c, 0x5e, 0xfc, 0xa4, 0xb2, 0xdc, 0x69, 0x4d, 0x74, 0x22, 0x77, 0x77, 0x9b, 0xe2,
		0x5d, 0x6d, 0xc2, 0x77, 0xb3, 0xa9, 0xde, 0xc5, 0x26, 0x7f, 0xf7, 0x9a, 0xfc, 0x5d, 0x6b, 0xda,
		0x77, 0xab, 0x71, 0x07, 0x8a, 0x62, 0x58, 0x7e, 0x50, 0x02, 0xa1, 0x38, 0x7a, 0x91, 0xf4, 0xc8,
		0x45, 0xcc, 0x5a, 0xe6, 0x1f, 0xa8, 0x19, 0x04, 0x6c, 0xea, 0x81, 0x9b, 0x4d, 0x00, 0x67, 0x13,
		0xc8, 0x79, 0x04, 0x74, 0x5a, 0x81, 0x9d, 0x58, 0x80, 0x27, 0x1b, 0xe8, 0x4b, 0xc3, 0x42, 0x11,
		0x5d, 0x65, 0xf7, 0x8c, 0x88, 0x0f, 0x5b, 0x2e, 0xec, 0xa4, 0x3d, 0x6d, 0x79, 0x13, 0xd3, 0x96,
		0x95, 0x93, 0x04, 0x8c, 0xa4, 0x01, 0x17, 0x89, 0xc0, 0x4e, 0x2a, 0xb0, 0x93, 0x0c, 0xbc, 0xa4,
		0x03, 0x4d, 0x09, 0x41, 0x54, 0x4a, 0x94, 0x1f, 0x2d, 0xf9, 0xa1, 0x85, 0xff, 0x1a, 0x56, 0xf8,
		0x96, 0xb2, 0xbf, 0x2c, 0xc2, 0x37, 0xe1, 0x11, 0x21, 0x4c, 0x66, 0x13, 0xf2, 0x18, 0x6d, 0xc3,
		0x68, 0xfa, 0x2f, 0xab, 0xc1, 0x67, 0xdc, 0x66, 0x0f, 0x72, 0x9c, 0x6a, 0x76, 0xc7, 0x63, 0x16,
		0x13, 0x96, 0xd8, 0x8a, 0x97, 0xd8, 0xf6, 0xce, 0x0e, 0x16, 0xd9, 0x7a, 0x09, 0x51, 0xfa, 0xd6,
		0x9d, 0x63, 0xd2, 0x0e, 0x57, 0x27, 0x4e, 0x73, 0xec, 0xc4, 0x93, 0x54, 0x82, 0xe0, 0xf8, 0x09,
		0x26, 0x91, 0x04, 0x45, 0xc0, 0x65, 0x72, 0x88, 0x22, 0xe0, 0xf2, 0x96, 0x0d, 0x8a, 0x80, 0x2b,
		0x36, 0x18, 0x45, 0x40, 0x55, 0xd3, 0x2e, 0x14, 0x01, 0x97, 0x1e, 0xbe, 0x51, 0x04, 0x7c, 0xe9,
		0x17, 0x8a, 0x80, 0xa8, 0x50, 0xa0, 0x08, 0xb8, 0x86, 0xd1, 0xe8, 0xdf, 0x4b, 0x0c, 0x45, 0xc0,
		0x95, 0x2f, 0x31, 0x14, 0x01, 0xd7, 0x4e, 0x88, 0xd2, 0xb7, 0x0e, 0x45, 0x40, 0xb6, 0x4e, 0x5c,
		0xbb, 0x29, 0x1c, 0x0b, 0xf1, 0x2a, 0x60, 0x6e, 0x26, 0xca, 0x80, 0x8b, 0x98, 0x87, 0x32, 0xe0,
		0x12, 0x41, 0x44, 0x19, 0x70, 0x79, 0xcb, 0x06, 0x65, 0xc0, 0x15, 0x1b, 0x8c, 0x32, 0xa0, 0xaa,
		0x89, 0x17, 0xa3, 0x32, 0xe0, 0x45, 0x10, 0xf9, 0xc9, 0x2d, 0x83, 0x3a, 0xe0, 0x1e, 0x64, 0x2c,
		0x43, 0x8b, 0x70, 0x6a, 0xcc, 0xf3, 0xec, 0x63, 0x3b, 0x36, 0xee, 0xc9, 0x94, 0xab, 0x27, 0xaf,
		0x90, 0x3d, 0x62, 0x8b, 0xdd, 0x9c, 0xb9, 0xc1, 0xec, 0xca, 0xce, 0x06, 0x61, 0x3e, 0x7a, 0x81,
		0xe2, 0x31, 0x5b, 0x38, 0x5b, 0xe6, 0x7b, 0xe4, 0xe1, 0x6c, 0x19, 0x35, 0xb2, 0x79, 0x34, 0xf7,
		0xab, 0x99, 0xb5, 0xa3, 0xb9, 0x7f, 0xdd, 0xb2, 0x73, 0x34, 0xf7, 0xf3, 0x17, 0xf9, 0x38, 0x5b,
		0xe6, 0xe5, 0x01, 0x16, 0x67, 0xcb, 0xb0, 0xd7, 0xb9, 0x98, 0xec, 0xf5, 0xef, 0x40, 0x89, 0xb3,
		0x65, 0x7e, 0xc5, 0x2a, 0x9c, 0x2d, 0xb3, 0x14, 0x63, 0x71, 0xb6, 0xcc, 0x8f, 0x34, 0x16, 0xce,
		0x96, 0xa9, 0xba, 0xfa, 0x86, 0xf3, 0x66, 0x56, 0x57, 0x6f, 0xc3, 0x09, 0x34, 0x14, 0x2c, 0xc0,
		0x09, 0x34, 0xaa, 0x3a, 0x33, 0x9c, 0x45, 0xf3, 0x72, 0x9f, 0xb5, 0xb6, 0x87, 0xd2, 0xfc, 0xb6,
		0x46, 0xbe, 0x68, 0x96, 0xe5, 0x4c, 0x97, 0xd9, 0x68, 0xa3, 0xd6, 0x82, 0x20, 0x8d, 0xec, 0x86,
		0x4e, 0x36, 0x43, 0x3a, 0x7b, 0xa1, 0x91, 0xad, 0xd4, 0xb5, 0x68, 0x88, 0x04, 0x6e, 0xb6, 0x01,
		0xbb, 0xc6, 0xf0, 0xcc, 0x2d, 0x2c, 0xd7, 0x13, 0x85, 0xab, 0x8f, 0x81, 0xd5, 0xfe, 0xc6, 0x8a,
		0x1d, 0x47, 0xdd, 0x0e, 0x83, 0x9f, 0xa3, 0xa8, 0xc1, 0x43, 0xb0, 0xf1, 0x0c, 0xd5, 0xba, 0x84,
		0xea, 0x16, 0x66, 0x35, 0xbf, 0xa9, 0xa2, 0xa5, 0x5f, 0xd7, 0x92, 0x67, 0xb3, 0xd4, 0x2b, 0x5c,
		0xe1, 0xd4, 0x57, 0x76, 0x35, 0x0b, 0x7a, 0xf5, 0xcb, 0xab, 0x82, 0xa5, 0xa5, 0xe5, 0x28, 0xb5,
		0xfe, 0x8d, 0x52, 0x55, 0x0b, 0xac, 0xbc, 0x1b, 0xff, 0x5d, 0x2b, 0x2a, 0x72, 0x2c, 0xd5, 0x1e,
		0x56, 0x53, 0xf9, 0x3e, 0xb5, 0x3a, 0xf6, 0x9f, 0xd5, 0xb8, 0xaf, 0xac, 0xae, 0xfd, 0x62, 0xb5,
		0xef, 0x03, 0xab, 0x7d, 0x7f, 0x57, 0xbd, 0xfb, 0xb6, 0xd4, 0x12, 0x3b, 0x55, 0x1f, 0x8e, 0xa2,
		0x95, 0x79, 0x42, 0xe5, 0xeb, 0x66, 0xe6, 0x2a, 0x6a, 0xca, 0x54, 0x6a, 0x3a, 0xab, 0xac, 0xb6,
		0xed, 0xca, 0x75, 0x6e, 0x47, 0x26, 0xb0, 0xdd, 0xb8, 0xee, 0xed, 0xc4, 0x64, 0xb6, 0x0b, 0x93,
		0xd9, 0x0e, 0x4c, 0x63, 0xbb, 0xaf, 0xda, 0xe5, 0xb2, 0xba, 0xce, 0xda, 0x9a, 0x21, 0x5e, 0xdb,
		0x6a, 0xfb, 0x77, 0x70, 0xa9, 0x6b, 0xa9, 0xd5, 0x7b, 0x1c, 0x66, 0xed, 0x9d, 0x31, 0x14, 0x3a,
		0x60, 0x08, 0x75, 0xba, 0x50, 0xe9, 0x68, 0x21, 0xd7, 0xb9, 0x42, 0xae, 0x43, 0x85, 0x56, 0x27,
		0xca, 0x7a, 0xed, 0xa3, 0xa8, 0xfb, 0x78, 0xc8, 0x7c, 0x07, 0x47, 0xfd, 0x8b, 0xf4, 0x61, 0x85,
		0x6c, 0x54, 0xf7, 0x02, 0xa5, 0xd1, 0xfa, 0x49, 0xa6, 0xd5, 0x93, 0x52, 0x6b, 0x27, 0xc1, 0x56,
		0x4e, 0x6a, 0xad, 0x9b, 0x64, 0x5b, 0x35, 0xc9, 0xb6, 0x66, 0xd2, 0x6c, 0xc5, 0x5c, 0xef, 0x4d,
		0xce, 0x64, 0x5a, 0x2b, 0x09, 0xb6, 0x52, 0x52, 0x6a, 0x9d, 0x7c, 0xda, 0x2a, 0x99, 0x87, 0xf0,
		0x75, 0xdd, 0x05, 0x5c, 0x63, 0xc2, 0x35, 0xa6, 0x11, 0xa6, 0x69, 0x54, 0x23, 0x20, 0xe6, 0x20,
		0xe6, 0x20, 0xe6, 0x20, 0xe6, 0x20, 0xe6, 0x20, 0xe6, 0x20, 0xe6, 0x16, 0x16, 0x73, 0xe3, 0x1a,
		0x77, 0x93, 0xaf, 0xb7, 0x9a, 0xcb, 0x87, 0x18, 0x92, 0x11, 0x73, 0x14, 0x66, 0x2a, 0xd6, 0x7c,
		0x87, 0x09, 0x5a, 0x0e, 0x5a, 0x0e, 0x5a, 0x0e, 0x5a, 0x6e, 0xbd, 0xb5, 0x5c, 0xdd, 0x77, 0xac,
		0x4a, 0x43, 0xae, 0x85, 0x4c, 0x82, 0x21, 0x9d, 0xd5, 0x5d, 0xde, 0xc2, 0xca, 0xed, 0xa2, 0x32,
		0x8e, 0x8a, 0xd4, 0x18, 0x53, 0x72, 0xe3, 0x4b, 0x29, 0x8e, 0x2d, 0x25, 0x3c, 0xae, 0x94, 0xea,
		0x98, 0x52, 0xf2, 0xe3, 0x49, 0xc9, 0x8f, 0x25, 0xa5, 0x3d, 0x8e, 0x14, 0x23, 0x06, 0x49, 0x96,
		0x53, 0x9e, 0x78, 0xac, 0x2f, 0xc1, 0x48, 0xe8, 0xa4, 0x02, 0xe0, 0xc3, 0x20, 0x48, 0x68, 0xd2,
		0x28, 0xd1, 0x13, 0x7d, 0x09, 0x4e, 0xb2, 0xa5, 0x7c, 0x62, 0x2f, 0xf5, 0x23, 0xdf, 0x66, 0xc7,
		0x85, 0x6e, 0x11, 0xb5, 0x8f, 0xc1, 0xe1, 0xa0, 0x14, 0x0f, 0x6b, 0xa4, 0x7c, 0xc2, 0x2e, 0x9b,
		0x25, 0xd1, 0xda, 0xdd, 0xdd, 0xdd, 0xde, 0xda, 0xc1, 0xca, 0xe0, 0xad, 0xc9, 0xe8, 0x59, 0x73,
		0x8e, 0x21, 0x9d, 0x54, 0x3c, 0x27, 0x91, 0xdd, 0xcd, 0x4f, 0x64, 0x32, 0x85, 0x5d, 0xce, 0x44,
		0x1d, 0x36, 0x2a, 0x44, 0xcf, 0x01, 0x09, 0x15, 0xa2, 0x5f, 0xc7, 0x1c, 0x15, 0xa2, 0x17, 0x1a,
		0x88, 0x0a, 0x11, 0x97, 0x6c, 0x81, 0x70, 0x85, 0x68, 0x12, 0x44, 0x72, 0xab, 0x45, 0xb0, 0x38,
		0xd4, 0x42, 0x71, 0xe8, 0x27, 0x5f, 0x28, 0x0e, 0x29, 0x99, 0x09, 0x6f, 0x22, 0x05, 0x66, 0xee,
		0xee, 0xff, 0xbd, 0x24, 0x50, 0x1c, 0x7a, 0xf1, 0x92, 0x68, 0x6e, 0xee, 0xa1, 0x30, 0xa4, 0x40,
		0x29, 0x66, 0x03, 0x85, 0x21, 0x82, 0xd7, 0x83, 0x42, 0x61, 0x68, 0x4c, 0x2b, 0xa9, 0xa7, 0xd5,
		0x33, 0x45, 0xd4, 0x5d, 0xa3, 0x34, 0xf4, 0x1c, 0x92, 0x50, 0x1a, 0xfa, 0x75, 0xcc, 0x51, 0x1a,
		0x7a, 0xa1, 0x81, 0x28, 0x0d, 0x71, 0xc9, 0x15, 0x08, 0x97, 0x86, 0xb2, 0xd1, 0xc8, 0xe4, 0x16,
		0x60, 0xd9, 0x74, 0xf2, 0x96, 0x90, 0x4d, 0x3d, 0x5f, 0x4a, 0x91, 0x44, 0xe4, 0x4a, 0x44, 0xda,
		0xab, 0x57, 0x1f, 0x37, 0xf5, 0x3d, 0x5f, 0xbf, 0x34, 0xf4, 0xa3, 0xf3, 0x7f, 0xb6, 0x7e, 0x6f,
		0xde, 0xed, 0xbf, 0xfe, 0x67, 0xf7, 0xee, 0xf1, 0x8b, 0xdf, 0xbe, 0xf7, 0xcf, 0xb6, 0x7e, 0xdf,
		0xbd, 0xdb, 0x9f, 0xf3, 0x37, 0xad, 0xbb, 0xfd, 0x5f, 0xfc, 0x3f, 0x76, 0xee, 0x5e, 0x3d, 0xf9,
		0xa7, 0xd3, 0xd7, 0xb7, 0xe7, 0xfd, 0x40, 0x73, 0xce, 0x0f, 0xbc, 0x99, 0xf7, 0x03, 0x6f, 0xe6,
		0xfc, 0xc0, 0x5c, 0x93, 0xb6, 0xe7, 0xfc, 0xc0, 0xce, 0xdd, 0xb7, 0x27, 0xff, 0xfe, 0xd5, 0xf7,
		0xff, 0x69, 0xeb, 0xee, 0xf5, 0xb7, 0x79, 0x7f, 0xb7, 0x7b, 0xf7, 0x6d, 0xff, 0xf5, 0xeb, 0xc6,
		0xab, 0xad, 0xed, 0x8f, 0x9b, 0xfa, 0xdb, 0xf3, 0x6f, 0x5b, 0x1f, 0x37, 0xf5, 0xad, 0xf3, 0xe9,
		0xbf, 0x3c, 0xff, 0xf6, 0x71, 0x4b, 0xdf, 0x9b, 0x3d, 0x9d, 0x7e, 0x7f, 0x4d, 0xc7, 0x2d, 0x9f,
		0x53, 0x5a, 0x4f, 0xdd, 0xbe, 0xf5, 0x9e, 0xec, 0xa2, 0xfa, 0x1f, 0x56, 0x15, 0xf1, 0x55, 0xf5,
		0x1f, 0x0d, 0x55, 0x06, 0x54, 0x19, 0x9e, 0x2c, 0xdc, 0x54, 0xbf, 0x08, 0x24, 0xbd, 0x22, 0x43,
		0x6e, 0x16, 0x6a, 0x0c, 0xa8, 0x31, 0xa0, 0xc6, 0x80, 0x1a, 0x03, 0x6a, 0x0c, 0xa8, 0x31, 0xac,
		0x4d, 0x8d, 0xe1, 0x22, 0x8e, 0x43, 0xe1, 0x47, 0x14, 0xeb, 0x0b, 0x5b, 0x10, 0x6e, 0x64, 0x84,
		0xdb, 0x64, 0xac, 0x8f, 0xe2, 0x2f, 0x11, 0x3d, 0xe9, 0x36, 0x33, 0x0c, 0xe2, 0x0d, 0xe2, 0x0d,
		0xe2, 0x0d, 0xe2, 0x0d, 0xe2, 0x0d, 0xe2, 0x0d, 0xe2, 0x0d, 0xe2, 0x0d, 0xe2, 0xed, 0xfe, 0x33,
		0xf9, 0x4a, 0xb3, 0xea, 0xf6, 0x15, 0x55, 0x37, 0x08, 0x37, 0x08, 0x37, 0x08, 0x37, 0x08, 0x37,
		0x08, 0x37, 0x08, 0x37, 0x08, 0x37, 0x5a, 0xc2, 0x6d, 0xad, 0x87, 0x5a, 0x1a, 0x51, 0x14, 0x4b,
		0x5f, 0x06, 0x31, 0x8d, 0x92, 0x9f, 0x96, 0x0e, 0x3f, 0x89, 0x6b, 0x7f, 0x5c, 0x4c, 0xe3, 0x6e,
		0xc4, 0x63, 0x11, 0x0d, 0x33, 0x89, 0xa4, 0x47, 0x42, 0x7e, 0x89, 0x93, 0xcf, 0x7a, 0x10, 0xa5,
		0xd2, 0x8f, 0x86, 0xa2, 0xf1, 0xf8, 0x85, 0xf4, 0xc9, 0x2b, 0x8d, 0x71, 0x12, 0xcb, 0x78, 0x18,
		0x87, 0x69, 0xf9, 0xac, 0x31, 0xf5, 0xe3, 0x8d, 0x50, 0xdc, 0x88, 0xb0, 0x78, 0x68, 0x84, 0x41,
		0xf4, 0x59, 0xcf, 0xa6, 0x3c, 0xeb, 0x23, 0x5f, 0xfa, 0x17, 0x7e, 0x2a, 0x1a, 0x61, 0x3a, 0x6e,
		0xc8, 0xf0, 0x26, 0x9d, 0x7e, 0xcb, 0xce, 0x75, 0x19, 0xdf, 0xb4, 0xf4, 0x44, 0xf8, 0xc3, 0x4f,
		0xfe, 0x45, 0x10, 0x06, 0xf2, 0xb6, 0x31, 0x3b, 0xce, 0xba, 0x78, 0xd2, 0xa0, 0x30, 0x26, 0x3a,
		0xbf, 0x82, 0x32, 0x99, 0x0c, 0x65, 0x54, 0x38, 0xa0, 0x6e, 0x79, 0x01, 0x3b, 0xf9, 0xc5, 0xb1,
		0x8a, 0x6b, 0xe3, 0x3d, 0xfa, 0x73, 0xfa, 0xf8, 0x05, 0xaf, 0x37, 0xbb, 0x78, 0xe5, 0x33, 0xcf,
		0x4a, 0x83, 0xd4, 0xb3, 0xb3, 0x8b, 0x97, 0x3f, 0x78, 0x76, 0x10, 0x7d, 0xee, 0x4f, 0xdf, 0x7a,
		0xbb, 0xb8, 0x74, 0x9e, 0x9d, 0x8e, 0x3d, 0x37, 0xbc, 0x49, 0xa7, 0xdf, 0xbc, 0x53, 0x69, 0x8d,
		0x6f, 0x5a, 0xce, 0x83, 0x0b, 0xe7, 0xf5, 0x8a, 0x0b, 0x57, 0x3c, 0xf1, 0xb2, 0x9f, 0xc6, 0x9c,
		0xf5, 0x1a, 0x40, 0x99, 0x5c, 0x4c, 0x11, 0x27, 0x34, 0x69, 0xbd, 0x30, 0x08, 0xb3, 0xd6, 0x31,
		0x6b, 0x9d, 0x4d, 0x26, 0x88, 0x59, 0xeb, 0xdc, 0x33, 0x3e, 0xcc, 0x5a, 0xa7, 0x27, 0x4b, 0xc9,
		0xcc, 0x5a, 0xcf, 0x63, 0x12, 0xc1, 0x9d, 0x8c, 0xb9, 0x5d, 0xb4, 0x8a, 0xaa, 0x5b, 0x28, 0xaa,
		0x92, 0x0f, 0xa1, 0x84, 0x43, 0x29, 0xd5, 0x90, 0x4a, 0x3e, 0xb4, 0x92, 0x0f, 0xb1, 0xb4, 0x43,
		0x2d, 0x9d, 0x5a, 0xd4, 0x06, 0xa1, 0xa2, 0x2a, 0x95, 0x10, 0x5c, 0x1a, 0x74, 0x19, 0xfa, 0x57,
		0x29, 0x3d, 0xa7, 0x30, 0xf3, 0xa3, 0xb9, 0x79, 0xc4, 0xd6, 0x1b, 0xad, 0xc0, 0x4c, 0x36, 0x40,
		0x53, 0x0e, 0xd4, 0x0c, 0x02, 0x36, 0xf5, 0xc0, 0xcd, 0x26, 0x80, 0xb3, 0x09, 0xe4, 0x3c, 0x02,
		0x3a, 0xad, 0xc0, 0x4e, 0x2c, 0xc0, 0x93, 0x0d, 0xf4, 0xf7, 0xb9, 0x37, 0x89, 0x83, 0x40, 0x7f,
		0x9e, 0x8a, 0x13, 0xb9, 0xf3, 0xc3, 0x48, 0x00, 0x90, 0x17, 0x02, 0x1c, 0x04, 0x01, 0x23, 0x61,
		0xc0, 0x45, 0x20, 0xb0, 0x13, 0x0a, 0xec, 0x04, 0x03, 0x2f, 0xe1, 0x40, 0x53, 0x40, 0x10, 0x15,
		0x12, 0xe4, 0x05, 0x05, 0xf1, 0x4a, 0x02, 0xab, 0xca, 0xc2, 0x3c, 0xa1, 0xb1, 0x49, 0xdc, 0x4c,
		0xea, 0x82, 0x83, 0x93, 0xf0, 0x60, 0x28, 0x40, 0xb8, 0x09, 0x11, 0xb6, 0x82, 0x84, 0xad, 0x30,
		0xe1, 0x29, 0x50, 0x68, 0x0b, 0x15, 0xe2, 0x82, 0xa5, 0xfc, 0xc8, 0xc9, 0xed, 0x23, 0xff, 0xa9,
		0xc7, 0x15, 0xd1, 0xe4, 0x5a, 0x24, 0xf9, 0xfe, 0x5d, 0x06, 0x5e, 0x77, 0x56, 0x8d, 0x68, 0x32,
		0xb0, 0xd5, 0x8c, 0x26, 0xd7, 0x53, 0x18, 0xb0, 0xa4, 0x5e, 0x72, 0x15, 0xed, 0x20, 0x95, 0x86,
		0x94, 0x09, 0x8f, 0x65, 0x75, 0x1a, 0x44, 0x66, 0x28, 0xa6, 0x5e, 0x3f, 0xa5, 0x2f, 0x11, 0x37,
		0x8a, 0x43, 0x2f, 0x1e, 0x58, 0xbc, 0xf5, 0xb6, 0xd9, 0x6c, 0xed, 0x36, 0x9b, 0x9b, 0xbb, 0x6f,
		0x76, 0x37, 0xf7, 0x76, 0x76, 0xb6, 0x5a, 0x54, 0xcf, 0xf9, 0xfc, 0xd7, 0x9b, 0xe8, 0x26, 0x23,
		0x91, 0x88, 0xd1, 0xc1, 0xad, 0xb6, 0xbf, 0x11, 0x4d, 0xc2, 0xf0, 0x37, 0x84, 0x58, 0xc5, 0x7c,
		0x81, 0x26, 0x39, 0x84, 0xd6, 0x32, 0xac, 0x66, 0xd6, 0x22, 0xe1, 0x46, 0xc2, 0x8d, 0x84, 0x1b,
		0x09, 0x37, 0x12, 0x6e, 0x24, 0xdc, 0x48, 0xb8, 0x91, 0x70, 0xe7, 0x47, 0x35, 0x8c, 0x44, 0x24,
		0x03, 0x79, 0x9b, 0x88, 0x4b, 0x4e, 0x09, 0x37, 0x87, 0x2c, 0xc0, 0x2a, 0x2e, 0xed, 0x81, 0x9f,
		0x32, 0x8a, 0x13, 0x33, 0x30, 0xac, 0xbe, 0xd5, 0xf7, 0xfa, 0x83, 0x03, 0xd7, 0x3e, 0xf3, 0xdc,
		0x0f, 0x3d, 0x93, 0x4b, 0xb8, 0xc8, 0x4e, 0xfe, 0x4b, 0xc9, 0x8d, 0xfe, 0xff, 0xd1, 0xd7, 0x3f,
		0x6c, 0x2c, 0x7d, 0x44, 0x88, 0xe7, 0x98, 0xc6, 0xe1, 0x89, 0x71, 0x60, 0xd9, 0x96, 0xfb, 0xa1,
		0x80, 0xa5, 0xcf, 0x89, 0x16, 0xce, 0xd4, 0xf0, 0xa4, 0xe7, 0xa7, 0x14, 0x1d, 0x18, 0x9d, 0xf6,
		0x7f, 0xad, 0xb6, 0x7b, 0xe2, 0x1d, 0x76, 0x3b, 0x7d, 0xd7, 0x31, 0xac, 0x8e, 0xdb, 0xd7, 0xd8,
		0xbd, 0xc7, 0xbb, 0xdf, 0x01, 0x52, 0xbd, 0x20, 0x0d, 0x5c, 0xcb, 0xb6, 0xfe, 0x32, 0xdb, 0xf7,
		0x44, 0x81, 0x22, 0x50, 0xf4, 0x5c, 0x8a, 0x8c, 0xf6, 0x9f, 0x5e, 0xdf, 0x6a, 0x03, 0x1d, 0xa0,
		0xf3, 0x6c, 0x74, 0xce, 0x0c, 0xcb, 0x36, 0x0e, 0x6c, 0x13, 0x1e, 0x08, 0x18, 0x2d, 0x8e, 0x91,
		0xd5, 0x3b, 0x6b, 0x79, 0x1d, 0xd3, 0x3a, 0x3e, 0x39, 0xe8, 0x3a, 0x9e, 0xd1, 0x6e, 0x3b, 0x66,
		0x1f, 0x82, 0x08, 0x20, 0x3d, 0x5f, 0x10, 0x75, 0x4a, 0x45, 0x6d, 0xb6, 0x3d, 0xbb, 0xdf, 0x03,
		0x44, 0x80, 0xe8, 0xb9, 0x10, 0xd9, 0x56, 0xe7, 0x9d, 0x67, 0xb8, 0xae, 0x63, 0x1d, 0x0c, 0x5c,
		0x13, 0x7e, 0x08, 0x08, 0x2d, 0x86, 0x50, 0xcf, 0xe9, 0xba, 0xe6, 0xa1, 0x6b, 0x75, 0x3b, 0x79,
		0xbd, 0x08, 0x1c, 0x81, 0xa3, 0x67, 0xa7, 0x66, 0xa7, 0x56, 0xc7, 0x3b, 0x76, 0xba, 0x03, 0x44,
		0x32, 0xe0, 0xb3, 0x98, 0xae, 0xb6, 0x3a, 0xae, 0xe9, 0x1c, 0x19, 0x87, 0x26, 0x84, 0x35, 0x48,
		0x5a, 0x94, 0xa4, 0x53, 0xe3, 0x7d, 0x1e, 0xd4, 0x90, 0xe7, 0x83, 0xa2, 0x17, 0x84, 0xb3, 0x3f,
		0x3d, 0xdb, 0xe8, 0xa0, 0xda, 0x08, 0x7c, 0x16, 0x56, 0xd5, 0x40, 0x07, 0xe8, 0x2c, 0xa4, 0x84,
		0x9a, 0xa8, 0x30, 0x02, 0xa4, 0xe5, 0x80, 0x04, 0x49, 0x0d, 0x92, 0x96, 0x22, 0xa9, 0x1d, 0xb3,
		0x6f, 0x3a, 0x67, 0xb8, 0x81, 0x06, 0x96, 0x5e, 0xc6, 0x92, 0x6b, 0x7a, 0x6d, 0xf3, 0xc8, 0x18,
		0xd8, 0xae, 0x77, 0x6a, 0xba, 0x8e, 0x75, 0x08, 0x88, 0x00, 0xd1, 0x73, 0x21, 0x1a, 0x74, 0x72,
		0x77, 0x84, 0xfd, 0x44, 0xe0, 0xe8, 0xc5, 0x69, 0x5a, 0xdb, 0xb4, 0x8d, 0x0f, 0xde, 0x99, 0xe1,
		0x58, 0x86, 0x6b, 0x75, 0x3b, 0xe0, 0x08, 0x1c, 0x3d, 0x97, 0x23, 0xf3, 0xbd, 0x6b, 0x76, 0xda,
		0x66, 0x1b, 0x77, 0x41, 0xc0, 0xd1, 0x8b, 0x84, 0xb6, 0xd5, 0xb9, 0xaf, 0x5f, 0x67, 0x7e, 0x09,
		0x14, 0x81, 0xa2, 0x85, 0xa2, 0x9a, 0xdd, 0x45, 0xae, 0x0f, 0x78, 0x5e, 0x22, 0x89, 0x40, 0x0f,
		0xe8, 0x79, 0x2e, 0x3d, 0x8e, 0xd9, 0xb7, 0xda, 0x03, 0xc3, 0x66, 0x9d, 0x96, 0xb1, 0xb2, 0xf8,
		0xfc, 0x37, 0xac, 0xce, 0x35, 0x5f, 0x95, 0xaa, 0x76, 0xef, 0x01, 0x98, 0xaa, 0x81, 0xe1, 0xdc,
		0xa5, 0x07, 0x5a, 0xaa, 0xa6, 0x85, 0x5d, 0x37, 0x1e, 0x10, 0xa9, 0x1c, 0x11, 0xce, 0x5d, 0x77,
		0xc0, 0xa5, 0x6a, 0x5c, 0x98, 0x77, 0xd7, 0x01, 0x98, 0xca, 0x05, 0x0b, 0xdf, 0x2e, 0x3a, 0xc0,
		0x52, 0x35, 0x2c, 0x6c, 0xbb, 0xe5, 0x80, 0x4a, 0x2d, 0xa8, 0xb0, 0xed, 0x8a, 0x03, 0x2f, 0xd5,
		0xa7, 0x42, 0x0c, 0xef, 0xfb, 0x02, 0x93, 0x5a, 0xf4, 0x2d, 0xe3, 0x2d, 0xb9, 0x20, 0xa6, 0x6a,
		0x62, 0x38, 0x77, 0xb3, 0x81, 0x96, 0xea, 0xc3, 0x10, 0xc3, 0xae, 0x35, 0x60, 0x52, 0x8b, 0xba,
		0x05, 0x22, 0x40, 0x44, 0xd9, 0x2e, 0x34, 0x00, 0x53, 0x0b, 0x30, 0x90, 0xb6, 0x20, 0xe6, 0x59,
		0xd2, 0x96, 0x77, 0x57, 0x19, 0x98, 0xa9, 0x9a, 0x19, 0xc6, 0xdd, 0x63, 0x80, 0xa5, 0x6a, 0x58,
		0x78, 0x77, 0x89, 0x81, 0x97, 0x5a, 0xd2, 0x22, 0xb6, 0xdd, 0x60, 0xe0, 0xa5, 0x6a, 0x5e, 0x78,
		0x77, 0x7d, 0x81, 0x97, 0xca, 0x05, 0x2f, 0xe3, 0xee, 0x2e, 0xd0, 0x52, 0x4b, 0x34, 0xe2, 0xd5,
		0xc5, 0x05, 0x48, 0xea, 0x93, 0x2c, 0xa0, 0x04, 0x94, 0xa8, 0xd8, 0x95, 0x05, 0x5a, 0x56, 0x4e,
		0x4b, 0x0f, 0x27, 0xc7, 0x81, 0x9e, 0x65, 0x53, 0xe4, 0x1a, 0xc7, 0xad, 0x26, 0x5a, 0x88, 0x01,
		0xce, 0x73, 0xc1, 0xe9, 0x39, 0xe6, 0x91, 0xf5, 0x1e, 0x83, 0x77, 0x41, 0xcf, 0x22, 0xf4, 0x64,
		0x3b, 0xec, 0x9c, 0xee, 0xc0, 0x35, 0x1d, 0xcc, 0xdf, 0x05, 0x41, 0x8b, 0x05, 0x2e, 0x60, 0x03,
		0x6c, 0x16, 0x0c, 0x5b, 0x47, 0xb6, 0x71, 0x8c, 0xb9, 0x3b, 0xe0, 0x67, 0x91, 0xc0, 0xd5, 0x64,
		0x1d, 0xb8, 0x30, 0x35, 0x05, 0xf5, 0x0f, 0x64, 0xae, 0x00, 0x44, 0x7d, 0x40, 0x38, 0x66, 0xa8,
		0xa0, 0x04, 0x99, 0x28, 0x48, 0x41, 0xc6, 0x09, 0x3c, 0x90, 0x59, 0x82, 0x13, 0x55, 0x03, 0x4e,
		0x13, 0x01, 0x07, 0xa4, 0x3c, 0x25, 0xa5, 0x80, 0xe2, 0xd0, 0xe8, 0xe1, 0x1e, 0x2f, 0xf8, 0x59,
		0x2a, 0x47, 0x8e, 0x67, 0xd8, 0xc7, 0x5d, 0xc7, 0x72, 0x4f, 0x4e, 0x51, 0xf5, 0x04, 0x41, 0x0b,
		0x11, 0x74, 0xff, 0x27, 0x94, 0x3d, 0x57, 0xfb, 0x85, 0xb2, 0x27, 0x44, 0x81, 0x6a, 0xce, 0x1c,
		0xa4, 0xc0, 0x69, 0x2b, 0xe5, 0xac, 0xe9, 0x3b, 0x69, 0xda, 0xd7, 0x91, 0xae, 0x75, 0x34, 0x2d,
		0x23, 0xea, 0x40, 0x35, 0x23, 0x8a, 0x62, 0xe9, 0xcb, 0x20, 0x8e, 0xb4, 0x7d, 0xc2, 0xae, 0x53,
		0x4b, 0x87, 0x9f, 0xc4, 0xb5, 0x3f, 0xf6, 0xe5, 0xa7, 0xa9, 0xb3, 0x6c, 0xc4, 0x63, 0x11, 0x0d,
		0xe3, 0xe8, 0x32, 0xb8, 0xd2, 0x23, 0x21, 0xbf, 0xc4, 0xc9, 0x67, 0x3d, 0x88, 0x52, 0xe9, 0x47,
		0x43, 0xd1, 0x78, 0xfc, 0x42, 0xfa, 0xe4, 0x95, 0xc6, 0x38, 0x89, 0x65, 0x3c, 0x8c, 0xc3, 0xb4,
		0x7c, 0xd6, 0x08, 0xd2, 0x20, 0x6d, 0x84, 0xe2, 0x46, 0x84, 0xc5, 0x43, 0x23, 0x0c, 0xa2, 0xcf,
		0x7a, 0x2a, 0x7d, 0x29, 0xf4, 0x91, 0x2f, 0xfd, 0x0b, 0x3f, 0x15, 0x8d, 0x30, 0x1d, 0x37, 0x64,
		0x78, 0x93, 0x4e, 0xbf, 0x35, 0xae, 0xa5, 0x1e, 0x8c, 0x6f, 0x5a, 0x7a, 0x22, 0xfc, 0xe1, 0x27,
		0xff, 0x22, 0x08, 0x03, 0x79, 0xdb, 0x18, 0x27, 0xe2, 0x32, 0xf8, 0x2a, 0xd2, 0xe2, 0x49, 0x23,
		0x9d, 0x5c, 0x64, 0x3f, 0x90, 0x3f, 0x36, 0x2e, 0x43, 0xff, 0x2a, 0x6d, 0x64, 0xff, 0x2b, 0xe1,
		0x92, 0x80, 0x96, 0xca, 0x64, 0x32, 0x94, 0x51, 0x11, 0x9b, 0xba, 0xe5, 0xd5, 0xee, 0xe4, 0x57,
		0xd2, 0x2a, 0x2e, 0xa4, 0xf7, 0xe8, 0xcf, 0xe9, 0xe3, 0x17, 0xbc, 0xde, 0xec, 0x4a, 0x97, 0xcf,
		0x3c, 0x2b, 0x0d, 0x52, 0xcf, 0xce, 0xae, 0x74, 0xfe, 0xe0, 0xd9, 0x41, 0xf4, 0xb9, 0x3f, 0xbd,
		0x24, 0xed, 0xe2, 0x3a, 0x7b, 0x76, 0x3a, 0xf6, 0xdc, 0xf0, 0x26, 0x9d, 0x7e, 0xf3, 0x4e, 0xa5,
		0x35, 0xbe, 0x69, 0x39, 0x0f, 0xae, 0xb2, 0xd7, 0x2b, 0xae, 0x72, 0xf1, 0xc4, 0xeb, 0xe7, 0x57,
		0xb9, 0x78, 0xf4, 0x8e, 0xa6, 0x57, 0xd9, 0xcb, 0xfe, 0x4b, 0x9a, 0x81, 0x93, 0x9e, 0x93, 0xa2,
		0x65, 0x11, 0x31, 0x77, 0x49, 0xdd, 0x4d, 0xaa, 0xe5, 0x1e, 0x09, 0x3a, 0x46, 0x25, 0x1c, 0x22,
		0x2d, 0x57, 0x48, 0xc7, 0xe1, 0x10, 0x72, 0x36, 0x5a, 0x30, 0xbe, 0x69, 0xea, 0x69, 0x3c, 0x49,
		0x86, 0x42, 0x4f, 0xe2, 0x89, 0x14, 0x89, 0x1e, 0x8c, 0xc8, 0xf9, 0x9c, 0x32, 0x6b, 0xfd, 0xbe,
		0xb9, 0xc4, 0x9c, 0xf7, 0xbb, 0x20, 0x9a, 0x5e, 0xc2, 0x2d, 0x62, 0x66, 0x1d, 0x66, 0x0e, 0x44,
		0xdb, 0xdf, 0xd8, 0x24, 0x66, 0x58, 0xee, 0x42, 0x68, 0x06, 0xba, 0x19, 0x78, 0xf1, 0x50, 0x9f,
		0x86, 0x24, 0x8a, 0xa1, 0xa2, 0x9f, 0x2d, 0x07, 0xb2, 0xe9, 0x94, 0xf6, 0x4e, 0xdc, 0x7e, 0x89,
		0x93, 0xe9, 0x8a, 0xd0, 0xf2, 0x20, 0x4c, 0x34, 0x11, 0xd1, 0x4e, 0xfc, 0xd4, 0x48, 0xae, 0x26,
		0xd7, 0x22, 0x92, 0xda, 0xfe, 0x86, 0x4c, 0x26, 0x82, 0x6a, 0x12, 0x7d, 0x6f, 0x65, 0x09, 0x26,
		0x04, 0x3e, 0x2b, 0x81, 0xdf, 0x0e, 0x12, 0xa2, 0xca, 0x3e, 0x4b, 0x62, 0xc9, 0x3a, 0x93, 0x99,
		0x3f, 0xa6, 0x5c, 0xd1, 0x20, 0x2a, 0x00, 0xc8, 0x0b, 0x01, 0x0e, 0x82, 0x80, 0x91, 0x30, 0xe0,
		0x22, 0x10, 0xd8, 0x09, 0x05, 0x76, 0x82, 0x81, 0x97, 0x70, 0xa0, 0x29, 0x20, 0x88, 0x0a, 0x09,
		0xf2, 0x82, 0xa2, 0x34, 0x90, 0x6e, 0x75, 0x61, 0xae, 0x6f, 0xa7, 0x5a, 0x61, 0x98, 0x27, 0x38,
		0x36, 0x89, 0x9b, 0x49, 0x5d, 0x78, 0x70, 0x12, 0x20, 0x0c, 0x85, 0x08, 0x37, 0x41, 0xc2, 0x56,
		0x98, 0xb0, 0x15, 0x28, 0x3c, 0x85, 0x0a, 0x6d, 0xc1, 0x42, 0x5c, 0xb8, 0x94, 0x1f, 0xb9, 0x7b,
		0x3b, 0x16, 0xbc, 0x3c, 0x6e, 0x76, 0x33, 0xc2, 0x1f, 0x8d, 0x12, 0x91, 0xb2, 0x70, 0xbb, 0xb3,
		0xb2, 0xc4, 0x5b, 0x06, 0xb6, 0xf6, 0x7c, 0x29, 0x45, 0x12, 0xb1, 0x69, 0x08, 0xd1, 0x5e, 0xbd,
		0xfa, 0xb8, 0xa9, 0xef, 0x9d, 0x7f, 0xfb, 0xb8, 0xa5, 0xef, 0x9d, 0xe7, 0x4f, 0xb7, 0xb2, 0x87,
		0xfc, 0xf9, 0xf6, 0xc7, 0x4d, 0xbd, 0x39, 0x7b, 0xbe, 0xf3, 0x71, 0x53, 0xdf, 0x39, 0x7f, 0xfd,
		0xf7, 0xdf, 0x7f, 0xbc, 0xfe, 0xe7, 0xcd, 0xdd, 0xf3, 0x7f, 0x90, 0xbe, 0x2b, 0x3c, 0xe7, 0x80,
		0x58, 0xb7, 0x6f, 0xbd, 0x67, 0xc7, 0xd9, 0xff, 0xaa, 0x04, 0xed, 0x3f, 0x0c, 0x48, 0xc3, 0xb6,
		0x55, 0xd5, 0xe4, 0x80, 0x26, 0x39, 0x48, 0x81, 0x52, 0x06, 0x64, 0xd6, 0xa2, 0x40, 0x80, 0x02,
		0x01, 0x0a, 0x04, 0x28, 0x10, 0xa0, 0x40, 0x80, 0x02, 0x01, 0x0a, 0x04, 0x28, 0x10, 0xe4, 0x05,
		0x82, 0x91, 0x88, 0x64, 0x20, 0x6f, 0x13, 0x71, 0xc9, 0xa9, 0x3e, 0xb0, 0xc3, 0xc0, 0x56, 0xab,
		0xb8, 0xb4, 0x07, 0x7e, 0xca, 0x28, 0x4e, 0xdc, 0x9f, 0xe5, 0x61, 0xf5, 0x8b, 0x71, 0x1d, 0x9c,
		0xa6, 0x75, 0x70, 0x9c, 0xd2, 0xa1, 0xc8, 0x69, 0x2f, 0x98, 0xed, 0x02, 0x7a, 0x5e, 0x4e, 0x51,
		0x79, 0x54, 0x90, 0x77, 0xd8, 0xed, 0xf4, 0x5d, 0xc7, 0xb0, 0x3a, 0x2e, 0x06, 0x5b, 0x03, 0xa4,
		0x67, 0x83, 0x34, 0x70, 0x2d, 0xdb, 0xfa, 0x8b, 0xe7, 0x19, 0xbc, 0xa0, 0x88, 0x0a, 0x45, 0x46,
		0xfb, 0x4f, 0x1c, 0x09, 0x03, 0x74, 0x16, 0x42, 0xe7, 0xcc, 0xb0, 0x6c, 0xe3, 0xc0, 0x36, 0xe1,
		0x81, 0x80, 0xd1, 0xe2, 0x18, 0x65, 0xf3, 0x9c, 0x3b, 0xa6, 0x75, 0x7c, 0x72, 0xd0, 0x75, 0x3c,
		0xa3, 0xdd, 0x76, 0xcc, 0x3e, 0x04, 0x11, 0x40, 0x7a, 0xbe, 0x20, 0xea, 0x94, 0x8a, 0xda, 0x6c,
		0x7b, 0x76, 0xbf, 0x07, 0x88, 0x00, 0xd1, 0x73, 0x21, 0xca, 0x0e, 0xfe, 0x35, 0x5c, 0xd7, 0xb1,
		0x0e, 0x06, 0xae, 0x09, 0x3f, 0x04, 0x84, 0x16, 0x43, 0xa8, 0xe7, 0x74, 0x5d, 0xf3, 0xd0, 0xb5,
		0xba, 0x9d, 0xbc, 0x5e, 0x04, 0x8e, 0xc0, 0xd1, 0xb3, 0x53, 0xb3, 0x53, 0xab, 0xe3, 0x1d, 0x3b,
		0xdd, 0x01, 0x22, 0x19, 0xf0, 0x59, 0x4c, 0x57, 0x5b, 0x1d, 0xd7, 0x74, 0x8e, 0x8c, 0x43, 0x13,
		0xc2, 0x1a, 0x24, 0x2d, 0x4a, 0xd2, 0xa9, 0xf1, 0x3e, 0x0f, 0x6a, 0xc8, 0xf3, 0x41, 0xd1, 0x0b,
		0xc2, 0xd9, 0x9f, 0x9e, 0x6d, 0x74, 0x50, 0x6d, 0x04, 0x3e, 0x0b, 0xab, 0x6a, 0xa0, 0x03, 0x74,
		0x16, 0x52, 0x42, 0x4d, 0x54, 0x18, 0x01, 0xd2, 0x72, 0x40, 0x82, 0xa4, 0x06, 0x49, 0x4b, 0x91,
		0xd4, 0x8e, 0xd9, 0x37, 0x9d, 0x33, 0xdc, 0x40, 0x03, 0x4b, 0x2f, 0x63, 0xc9, 0x35, 0xbd, 0xb6,
		0x79, 0x64, 0x0c, 0x6c, 0xd7, 0x3b, 0x35, 0x5d, 0xc7, 0x3a, 0x04, 0x44, 0x80, 0xe8, 0xb9, 0x10,
		0x0d, 0x3a, 0xb9, 0x3b, 0xc2, 0x7e, 0x22, 0x70, 0xf4, 0xe2, 0x34, 0xad, 0x6d, 0xda, 0xc6, 0x07,
		0xef, 0xcc, 0x70, 0x2c, 0xc3, 0xb5, 0xba, 0x1d, 0x70, 0x04, 0x8e, 0x9e, 0xcb, 0x91, 0xf9, 0xde,
		0x35, 0x3b, 0x6d, 0xb3, 0x8d, 0xbb, 0x20, 0xe0, 0xe8, 0x45, 0x42, 0xdb, 0xea, 0xdc, 0xd7, 0xaf,
		0x33, 0xbf, 0x04, 0x8a, 0x40, 0xd1, 0x42, 0x51, 0xcd, 0xee, 0x22, 0xd7, 0x07, 0x3c, 0x2f, 0x91,
		0x44, 0xa0, 0x07, 0xf4, 0x3c, 0x97, 0x1e, 0xc7, 0xec, 0x5b, 0xed, 0x81, 0x61, 0xb3, 0x4e, 0xcb,
		0x70, 0x98, 0xef, 0xba, 0xaf, 0x4e, 0x45, 0x7a, 0x40, 0x99, 0x77, 0xef, 0x01, 0x98, 0xaa, 0x81,
		0xe1, 0xdc, 0xa5, 0x07, 0x5a, 0xaa, 0xa6, 0x85, 0x5d, 0x37, 0x1e, 0x10, 0xa9, 0x1c, 0x11, 0xce,
		0x5d, 0x77, 0xc0, 0xa5, 0x6a, 0x5c, 0x98, 0x77, 0xd7, 0x01, 0x98, 0xca, 0x05, 0x0b, 0xdf, 0x2e,
		0x3a, 0xc0, 0x52, 0x35, 0x2c, 0x6c, 0xbb, 0xe5, 0x80, 0x4a, 0x2d, 0xa8, 0xb0, 0xed, 0x8a, 0x03,
		0x2f, 0xd5, 0xa7, 0x42, 0x0c, 0xef, 0xfb, 0x02, 0x93, 0x5a, 0xf4, 0x2d, 0xe3, 0x2d, 0xb9, 0x20,
		0xa6, 0x6a, 0x62, 0x38, 0x77, 0xb3, 0x81, 0x96, 0xea, 0xc3, 0x10, 0xc3, 0xae, 0x35, 0x60, 0x52,
		0x8b, 0xba, 0x05, 0x22, 0x40, 0x44, 0xd9, 0x2e, 0x34, 0x00, 0x53, 0x0b, 0x30, 0x90, 0xb6, 0x20,
		0xe6, 0x59, 0xd2, 0x96, 0x77, 0x57, 0x19, 0x98, 0xa9, 0x9a, 0x19, 0xc6, 0xdd, 0x63, 0x80, 0xa5,
		0x6a, 0x58, 0x78, 0x77, 0x89, 0x81, 0x97, 0x5a, 0xd2, 0x22, 0xb6, 0xdd, 0x60, 0xe0, 0xa5, 0x6a,
		0x5e, 0x78, 0x77, 0x7d, 0x81, 0x97, 0xca, 0x05, 0x2f, 0xe3, 0xee, 0x2e, 0xd0, 0x52, 0x4b, 0x34,
		0xe2, 0xd5, 0xc5, 0x05, 0x48, 0xea, 0x93, 0x2c, 0xa0, 0x04, 0x94, 0xa8, 0xd8, 0x95, 0x05, 0x5a,
		0x56, 0x4e, 0x4b, 0x0f, 0x27, 0xc7, 0x81, 0x9e, 0x65, 0x53, 0xe4, 0x1a, 0xc7, 0xad, 0x26, 0x5a,
		0x88, 0x01, 0xce, 0x73, 0xc1, 0xe9, 0x39, 0xe6, 0x91, 0xf5, 0x1e, 0x83, 0x77, 0x41, 0xcf, 0x22,
		0xf4, 0x64, 0x3b, 0xec, 0x9c, 0xee, 0xc0, 0x35, 0x1d, 0xcc, 0xdf, 0x05, 0x41, 0x8b, 0x05, 0x2e,
		0x60, 0x03, 0x6c, 0x16, 0x0c, 0x5b, 0x47, 0xb6, 0x71, 0x8c, 0xb9, 0x3b, 0xe0, 0x67, 0x91, 0xc0,
		0xd5, 0x64, 0x1d, 0xb8, 0x30, 0x35, 0x05, 0xf5, 0x0f, 0x64, 0xae, 0x00, 0x44, 0x7d, 0x40, 0x38,
		0x66, 0xa8, 0xa0, 0x04, 0x99, 0x28, 0x48, 0x41, 0xc6, 0x09, 0x3c, 0x90, 0x59, 0x82, 0x13, 0x55,
		0x03, 0x4e, 0x13, 0x01, 0x07, 0xa4, 0x3c, 0x25, 0xa5, 0x80, 0xe2, 0xd0, 0xe8, 0xe1, 0x1e, 0x2f,
		0xf8, 0x59, 0x2a, 0x47, 0x8e, 0x67, 0xd8, 0xc7, 0x5d, 0xc7, 0x72, 0x4f, 0x4e, 0x51, 0xf5, 0x04,
		0x41, 0x0b, 0x11, 0x74, 0xff, 0x27, 0x94, 0x3d, 0x57, 0xfb, 0x85, 0xb2, 0x27, 0x44, 0x81, 0x6a,
		0xce, 0x1c, 0xa4, 0xc0, 0x69, 0x2b, 0xe5, 0xac, 0xe9, 0x3b, 0x69, 0xda, 0xd7, 0x91, 0xae, 0x75,
		0x34, 0x2d, 0x23, 0xea, 0x40, 0x35, 0x23, 0x8a, 0x62, 0xe9, 0xcb, 0x20, 0x8e, 0xb4, 0x7d, 0xc2,
		0xae, 0x53, 0x4b, 0x87, 0x9f, 0xc4, 0xb5, 0x3f, 0xf6, 0xe5, 0xa7, 0xa9, 0xb3, 0x6c, 0xc4, 0x63,
		0x11, 0x0d, 0xe3, 0xe8, 0x32, 0xb8, 0xd2, 0x23, 0x21, 0xbf, 0xc4, 0xc9, 0x67, 0x3d, 0x88, 0x52,
		0xe9, 0x47, 0x43, 0xd1, 0x78, 0xfc, 0x42, 0xfa, 0xe4, 0x95, 0xc6, 0x38, 0x89, 0x65, 0x3c, 0x8c,
		0xc3, 0xb4, 0x7c, 0xd6, 0x08, 0xd2, 0x20, 0x6d, 0x84, 0xe2, 0x46, 0x84, 0xc5, 0x43, 0x23, 0x0c,
		0xa2, 0xcf, 0x7a, 0x2a, 0x7d, 0x29, 0xf4, 0x91, 0x2f, 0xfd, 0x0b, 0x3f, 0x15, 0x8d, 0x30, 0x1d,
		0x37, 0x64, 0x78, 0x93, 0x4e, 0xbf, 0x35, 0xae, 0xa5, 0x1e, 0x8c, 0x6f, 0x5a, 0x7a, 0x22, 0xfc,
		0xe1, 0x27, 0xff, 0x22, 0x08, 0x03, 0x79, 0xdb, 0x18, 0x27, 0xe2, 0x32, 0xf8, 0x2a, 0xd2, 0xe2,
		0x49, 0x23, 0x9d, 0x5c, 0x64, 0x3f, 0x90, 0x3f, 0x36, 0x82, 0xf1, 0x4d, 0x53, 0x4f, 0xe3, 0x49,
		0x32, 0x14, 0x7a, 0x12, 0x4f, 0xa4, 0x48, 0xf4, 0x60, 0xd4, 0xc8, 0x7e, 0x0b, 0xe1, 0x12, 0x81,
		0x96, 0xca, 0x64, 0x32, 0x94, 0x51, 0x11, 0xab, 0xba, 0xe5, 0xd5, 0xef, 0xe4, 0x57, 0xd6, 0x2a,
		0x2e, 0xac, 0xf7, 0xe8, 0xcf, 0xe9, 0xe3, 0x17, 0xbc, 0xde, 0xec, 0xca, 0x97, 0xcf, 0x3c, 0x2b,
		0x0d, 0x52, 0xcf, 0xce, 0xae, 0x7c, 0xfe, 0xe0, 0xd9, 0x41, 0xf4, 0xb9, 0x3f, 0xbd, 0x24, 0xed,
		0xe2, 0xba, 0x7b, 0x76, 0x3a, 0xf6, 0xdc, 0xf0, 0x26, 0x9d, 0x7e, 0xf3, 0x4e, 0xa5, 0x35, 0xbe,
		0x69, 0x39, 0x0f, 0xae, 0xba, 0xd7, 0x2b, 0xae, 0x7a, 0xf1, 0xc4, 0xeb, 0xe7, 0x57, 0xbd, 0x78,
		0xf4, 0xac, 0xf1, 0x4d, 0xb3, 0x9f, 0x5d, 0x74, 0x27, 0xbb, 0xe6, 0xd6, 0xc8, 0xcb, 0xfe, 0x7f,
		0x9a, 0x51, 0x95, 0x9e, 0x07, 0xa3, 0x65, 0x11, 0x31, 0x5f, 0x4a, 0xdd, 0x87, 0xaa, 0xed, 0x3b,
		0x09, 0x7a, 0x4d, 0xf5, 0xbc, 0x25, 0x2d, 0x3f, 0x49, 0xc7, 0x1b, 0x11, 0xf2, 0x44, 0x5a, 0xb6,
		0x9c, 0x9e, 0xac, 0x0e, 0x6a, 0x0e, 0xa9, 0xcc, 0x77, 0xbf, 0x6f, 0x2e, 0x31, 0xcf, 0xfe, 0x2e,
		0x88, 0xa6, 0x97, 0x70, 0x8b, 0x98, 0x59, 0x87, 0x99, 0x37, 0xd1, 0xf6, 0x37, 0x36, 0x89, 0x19,
		0x96, 0xfb, 0x13, 0x9a, 0x51, 0x70, 0x06, 0x5e, 0x3c, 0xd4, 0xa7, 0xf1, 0x8a, 0x62, 0xdc, 0xc8,
		0x9d, 0x2e, 0xd9, 0x44, 0x4c, 0x7b, 0x27, 0x6e, 0xbf, 0xc4, 0xc9, 0x74, 0x45, 0x68, 0x79, 0x84,
		0x26, 0x9a, 0xb2, 0x68, 0x27, 0x7e, 0x6a, 0x24, 0x57, 0x93, 0x6b, 0x11, 0x49, 0x6d, 0x7f, 0x43,
		0x26, 0x13, 0x41, 0x35, 0xfd, 0xbe, 0xb7, 0xb2, 0x04, 0x13, 0xea, 0x9f, 0x95, 0xfa, 0x6f, 0x07,
		0x09, 0x51, 0xd9, 0x9f, 0x65, 0xb8, 0x64, 0x9d, 0xc9, 0xcc, 0x1f, 0x53, 0xae, 0x7d, 0x10, 0x15,
		0x00, 0xe4, 0x85, 0x00, 0x07, 0x41, 0xc0, 0x48, 0x18, 0x70, 0x11, 0x08, 0xec, 0x84, 0x02, 0x3b,
		0xc1, 0xc0, 0x4b, 0x38, 0xd0, 0x14, 0x10, 0x44, 0x85, 0x04, 0x79, 0x41, 0x51, 0x1a, 0x48, 0xb7,
		0xba, 0x30, 0xd7, 0xb7, 0x53, 0x2e, 0x17, 0x7e, 0x4f, 0x70, 0x6c, 0x12, 0x37, 0x93, 0xba, 0xf0,
		0xe0, 0x24, 0x40, 0x18, 0x0a, 0x11, 0x6e, 0x82, 0x84, 0xad, 0x30, 0x61, 0x2b, 0x50, 0x78, 0x0a,
		0x15, 0xda, 0x82, 0x85, 0xb8, 0x70, 0x29, 0x3f, 0x72, 0xf7, 0x76, 0x2c, 0x78, 0x79, 0xdc, 0xec,
		0x66, 0x84, 0x3f, 0x1a, 0x25, 0x22, 0x65, 0xe1, 0x76, 0x67, 0x65, 0x89, 0xb7, 0x0c, 0x6c, 0xed,
		0xf9, 0x52, 0x8a, 0x24, 0x62, 0xd3, 0x4a, 0xa2, 0xbd, 0x7a, 0xf5, 0x71, 0x53, 0xdf, 0xf3, 0xf5,
		0x4b, 0x43, 0x3f, 0x3a, 0xff, 0x67, 0xeb, 0xf7, 0xe6, 0xdd, 0xfe, 0xeb, 0x7f, 0x76, 0xef, 0x1e,
		0xbf, 0xf8, 0xed, 0x7b, 0xff, 0x6c, 0xeb, 0xf7, 0xdd, 0xbb, 0xfd, 0x39, 0x7f, 0xd3, 0xba, 0xdb,
		0xff, 0xc5, 0xff, 0x63, 0xe7, 0xee, 0xd5, 0x93, 0x7f, 0x3a, 0x7d, 0x7d, 0x7b, 0xde, 0x0f, 0x34,
		0xe7, 0xfc, 0xc0, 0x9b, 0x79, 0x3f, 0xf0, 0x66, 0xce, 0x0f, 0xcc, 0x35, 0x69, 0x7b, 0xce, 0x0f,
		0xec, 0xdc, 0x7d, 0x7b, 0xf2, 0xef, 0x5f, 0x7d, 0xff, 0x9f, 0xb6, 0xee, 0x5e, 0x7f, 0x9b, 0xf7,
		0x77, 0xbb, 0x77, 0xdf, 0xf6, 0x5f, 0xbf, 0xa6, 0x1f, 0x18, 0xce, 0x39, 0x2c, 0xb8, 0x6e, 0xdf,
		0x7a, 0xcf, 0x6e, 0xd5, 0xfd, 0x0f, 0xcb, 0xae, 0xae, 0x65, 0xf7, 0x1f, 0x06, 0xeb, 0x0e, 0x9b,
		0xa1, 0x55, 0x93, 0x8a, 0x9a, 0xe4, 0x20, 0x13, 0x4b, 0x89, 0x98, 0x59, 0x8b, 0xe2, 0x11, 0x8a,
		0x47, 0x28, 0x1e, 0xa1, 0x78, 0x84, 0xe2, 0x11, 0x8a, 0x47, 0x28, 0x1e, 0xa1, 0x78, 0x94, 0x17,
		0x8f, 0x46, 0x22, 0x92, 0x81, 0xbc, 0x4d, 0xc4, 0x25, 0xa7, 0xda, 0xd1, 0x0e, 0x03, 0x5b, 0xad,
		0xe2, 0xd2, 0x1e, 0xf8, 0x29, 0xa3, 0x38, 0x71, 0x7f, 0x42, 0x8c, 0xd5, 0x2f, 0x86, 0xc0, 0x70,
		0x9a, 0x01, 0xc3, 0x71, 0xf6, 0x8b, 0x22, 0x67, 0x08, 0x61, 0x62, 0x10, 0xe8, 0x79, 0x39, 0x45,
		0xe5, 0x01, 0x54, 0xde, 0x61, 0xb7, 0xd3, 0x77, 0x1d, 0xc3, 0xea, 0xb8, 0x18, 0x97, 0x0e, 0x90,
		0x9e, 0x0d, 0xd2, 0xc0, 0xb5, 0x6c, 0xeb, 0x2f, 0x9e, 0x27, 0x3b, 0x83, 0x22, 0x2a, 0x14, 0x19,
		0xed, 0x3f, 0x71, 0xd0, 0x10, 0xd0, 0x59, 0x08, 0x9d, 0x33, 0xc3, 0xb2, 0x8d, 0x03, 0xdb, 0x84,
		0x07, 0x02, 0x46, 0x8b, 0x63, 0x94, 0x4d, 0x09, 0xef, 0x98, 0xd6, 0xf1, 0xc9, 0x41, 0xd7, 0xf1,
		0x8c, 0x76, 0xdb, 0x31, 0xfb, 0x10, 0x44, 0x00, 0xe9, 0xf9, 0x82, 0xa8, 0x53, 0x2a, 0x6a, 0xb3,
		0xed, 0xd9, 0xfd, 0x1e, 0x20, 0x02, 0x44, 0xcf, 0x85, 0x28, 0x3b, 0x4e, 0xda, 0x70, 0x5d, 0xc7,
		0x3a, 0x18, 0xb8, 0x26, 0xfc, 0x10, 0x10, 0x5a, 0x0c, 0xa1, 0x9e, 0xd3, 0x75, 0xcd, 0x43, 0xd7,
		0xea, 0x76, 0xf2, 0x7a, 0x11, 0x38, 0x02, 0x47, 0xcf, 0x4e, 0xcd, 0x4e, 0xad, 0x8e, 0x77, 0xec,
		0x74, 0x07, 0x88, 0x64, 0xc0, 0x67, 0x31, 0x5d, 0x6d, 0x75, 0x5c, 0xd3, 0x39, 0x32, 0x0e, 0x4d,
		0x08, 0x6b, 0x90, 0xb4, 0x28, 0x49, 0xa7, 0xc6, 0xfb, 0x3c, 0xa8, 0x21, 0xcf, 0x07, 0x45, 0x2f,
		0x08, 0x67, 0x7f, 0x7a, 0xb6, 0xd1, 0x41, 0xb5, 0x11, 0xf8, 0x2c, 0xac, 0xaa, 0x81, 0x0e, 0xd0,
		0x59, 0x48, 0x09, 0x35, 0x51, 0x61, 0x04, 0x48, 0xcb, 0x01, 0x09, 0x92, 0x1a, 0x24, 0x2d, 0x45,
		0x52, 0x3b, 0x66, 0xdf, 0x74, 0xce, 0x70, 0x03, 0x0d, 0x2c, 0xbd, 0x8c, 0x25, 0xd7, 0xf4, 0xda,
		0xe6, 0x91, 0x31, 0xb0, 0x5d, 0xef, 0xd4, 0x74, 0x1d, 0xeb, 0x10, 0x10, 0x01, 0xa2, 0xe7, 0x42,
		0x34, 0xe8, 0xe4, 0xee, 0x08, 0xfb, 0x89, 0xc0, 0xd1, 0x8b, 0xd3, 0xb4, 0xb6, 0x69, 0x1b, 0x1f,
		0xbc, 0x33, 0xc3, 0xb1, 0x0c, 0xd7, 0xea, 0x76, 0xc0, 0x11, 0x38, 0x7a, 0x2e, 0x47, 0xe6, 0x7b,
		0xd7, 0xec, 0xb4, 0xcd, 0x36, 0xee, 0x82, 0x80, 0xa3, 0x17, 0x09, 0x6d, 0xab, 0x73, 0x5f, 0xbf,
		0xce, 0xfc, 0x12, 0x28, 0x02, 0x45, 0x0b, 0x45, 0x35, 0xbb, 0x8b, 0x5c, 0x1f, 0xf0, 0xbc, 0x44,
		0x12, 0x81, 0x1e, 0xd0, 0xf3, 0x5c, 0x7a, 0x1c, 0xb3, 0x6f, 0xb5, 0x07, 0x86, 0xcd, 0x3a, 0x2d,
		0xc3, 0x11, 0xd1, 0xeb, 0xbe, 0x3a, 0x15, 0xe9, 0x01, 0x65, 0xde, 0xbd, 0x07, 0x60, 0xaa, 0x06,
		0x86, 0x73, 0x97, 0x1e, 0x68, 0xa9, 0x9a, 0x16, 0x76, 0xdd, 0x78, 0x40, 0xa4, 0x72, 0x44, 0x38,
		0x77, 0xdd, 0x01, 0x97, 0xaa, 0x71, 0x61, 0xde, 0x5d, 0x07, 0x60, 0x2a, 0x17, 0x2c, 0x7c, 0xbb,
		0xe8, 0x00, 0x4b, 0xd5, 0xb0, 0xb0, 0xed, 0x96, 0x03, 0x2a, 0xb5, 0xa0, 0xc2, 0xb6, 0x2b, 0x0e,
		0xbc, 0x54, 0x9f, 0x0a, 0x31, 0xbc, 0xef, 0x0b, 0x4c, 0x6a, 0xd1, 0xb7, 0x8c, 0xb7, 0xe4, 0x82,
		0x98, 0xaa, 0x89, 0xe1, 0xdc, 0xcd, 0x06, 0x5a, 0xaa, 0x0f, 0x43, 0x0c, 0xbb, 0xd6, 0x80, 0x49,
		0x2d, 0xea, 0x16, 0x88, 0x00, 0x11, 0x65, 0xbb, 0xd0, 0x00, 0x4c, 0x2d, 0xc0, 0x40, 0xda, 0x82,
		0x98, 0x67, 0x49, 0x5b, 0xde, 0x5d, 0x65, 0x60, 0xa6, 0x6a, 0x66, 0x18, 0x77, 0x8f, 0x01, 0x96,
		0xaa, 0x61, 0xe1, 0xdd, 0x25, 0x06, 0x5e, 0x6a, 0x49, 0x8b, 0xd8, 0x76, 0x83, 0x81, 0x97, 0xaa,
		0x79, 0xe1, 0xdd, 0xf5, 0x05, 0x5e, 0x2a, 0x17, 0xbc, 0x8c, 0xbb, 0xbb, 0x40, 0x4b, 0x2d, 0xd1,
		0x88, 0x57, 0x17, 0x17, 0x20, 0xa9, 0x4f, 0xb2, 0x80, 0x12, 0x50, 0xa2, 0x62, 0x57, 0x16, 0x68,
		0x59, 0x39, 0x2d, 0x3d, 0x9c, 0x1c, 0x07, 0x7a, 0x96, 0x4d, 0x91, 0x6b, 0x1c, 0xb7, 0x9a, 0x68,
		0x21, 0x06, 0x38, 0xcf, 0x05, 0xa7, 0xe7, 0x98, 0x47, 0xd6, 0x7b, 0x0c, 0xde, 0x05, 0x3d, 0x8b,
		0xd0, 0x93, 0xed, 0xb0, 0x73, 0xba, 0x03, 0xd7, 0x74, 0x30, 0x7f, 0x17, 0x04, 0x2d, 0x16, 0xb8,
		0x80, 0x0d, 0xb0, 0x59, 0x30, 0x6c, 0x1d, 0xd9, 0xc6, 0x31, 0xe6, 0xee, 0x80, 0x9f, 0x45, 0x02,
		0x57, 0x93, 0x75, 0xe0, 0xc2, 0xd4, 0x14, 0xd4, 0x3f, 0x90, 0xb9, 0x02, 0x10, 0xf5, 0x01, 0xe1,
		0x98, 0xa1, 0x82, 0x12, 0x64, 0xa2, 0x20, 0x05, 0x19, 0x27, 0xf0, 0x40, 0x66, 0x09, 0x4e, 0x54,
		0x0d, 0x38, 0x4d, 0x04, 0x1c, 0x90, 0xf2, 0x94, 0x94, 0x02, 0x8a, 0x43, 0xa3, 0x87, 0x7b, 0xbc,
		0xe0, 0x67, 0xa9, 0x1c, 0x39, 0x9e, 0x61, 0x1f, 0x77, 0x1d, 0xcb, 0x3d, 0x39, 0x45, 0xd5, 0x13,
		0x04, 0x2d, 0x44, 0xd0, 0xfd, 0x9f, 0x50, 0xf6, 0x5c, 0xed, 0x17, 0xca, 0x9e, 0x10, 0x05, 0xaa,
		0x39, 0x73, 0x90, 0x02, 0xa7, 0xad, 0x94, 0xb3, 0xa6, 0xef, 0xa4, 0x69, 0x5f, 0x47, 0xba, 0xd6,
		0xd1, 0xb4, 0x8c, 0xa8, 0x03, 0xd5, 0x8c, 0x28, 0x8a, 0xa5, 0x2f, 0x83, 0x38, 0xd2, 0xf6, 0x09,
		0xbb, 0x4e, 0x2d, 0x1d, 0x7e, 0x12, 0xd7, 0xfe, 0xd8, 0x97, 0x9f, 0xa6, 0xce, 0xb2, 0x11, 0x8f,
		0x45, 0x34, 0x8c, 0xa3, 0xcb, 0xe0, 0x4a, 0x8f, 0x84, 0xfc, 0x12, 0x27, 0x9f, 0xf5, 0x20, 0x4a,
		0xa5, 0x1f, 0x0d, 0x45, 0xe3, 0xf1, 0x0b, 0xe9, 0x93, 0x57, 0x1a, 0xe3, 0x24, 0x96, 0xf1, 0x30,
		0x0e, 0xd3, 0xf2, 0x59, 0x23, 0x48, 0x83, 0xb4, 0x11, 0x8a, 0x1b, 0x11, 0x16, 0x0f, 0x8d, 0x30,
		0x88, 0x3e, 0xeb, 0xa9, 0xf4, 0xa5, 0xd0, 0x47, 0xbe, 0xf4, 0x2f, 0xfc, 0x54, 0x34, 0xc2, 0x74,
		0xdc, 0x90, 0xe1, 0x4d, 0x3a, 0xfd, 0xd6, 0xb8, 0x96, 0x7a, 0x30, 0xbe, 0x69, 0xe9, 0x89, 0xf0,
		0x87, 0x9f, 0xfc, 0x8b, 0x20, 0x0c, 0xe4, 0x6d, 0x63, 0x9c, 0x88, 0xcb, 0xe0, 0xab, 0x48, 0x8b,
		0x27, 0x8d, 0x74, 0x72, 0x91, 0xfd, 0x40, 0xfe, 0xd8, 0xc8, 0x7e, 0x20, 0x8d, 0x27, 0xc9, 0x50,
		0xe8, 0x49, 0x3c, 0x91, 0x22, 0xd1, 0x83, 0x51, 0x23, 0xfb, 0x2d, 0x84, 0x4b, 0x04, 0x5a, 0x2a,
		0x93, 0xc9, 0x50, 0x46, 0x45, 0xac, 0xea, 0x96, 0x57, 0xbf, 0x93, 0x5f, 0x59, 0xab, 0xb8, 0xb0,
		0xde, 0xa3, 0x3f, 0xa7, 0x8f, 0x5f, 0xf0, 0x7a, 0xb3, 0x2b, 0x5f, 0x3e, 0xf3, 0xac, 0x34, 0x48,
		0x3d, 0x3b, 0xbb, 0xf2, 0xf9, 0x83, 0x67, 0x07, 0xd1, 0xe7, 0xfe, 0xf4, 0x92, 0xb4, 0x8b, 0xeb,
		0xee, 0xd9, 0xe9, 0xd8, 0x73, 0xc3, 0x9b, 0x74, 0xfa, 0xcd, 0x3b, 0x95, 0xd6, 0xf8, 0xa6, 0xe5,
		0x3c, 0xb8, 0xea, 0x5e, 0xaf, 0xb8, 0xea, 0xc5, 0x13, 0xaf, 0x9f, 0x5f, 0xf5, 0xe2, 0xd1, 0x9b,
		0xfe, 0xfb, 0x7e, 0x76, 0xd1, 0x9d, 0xec, 0x9a, 0x5b, 0x23, 0x2f, 0xfb, 0xff, 0x69, 0x46, 0x55,
		0x7a, 0x1e, 0x8c, 0x96, 0x45, 0xc4, 0x7c, 0x29, 0x75, 0x1f, 0xaa, 0xb6, 0xef, 0x24, 0xe8, 0x35,
		0xd5, 0xf3, 0x96, 0xb4, 0xfc, 0x24, 0x1d, 0x6f, 0x44, 0xc8, 0x13, 0x69, 0xf9, 0x9a, 0xd1, 0xd3,
		0x60, 0x94, 0x92, 0x73, 0x43, 0x65, 0x96, 0xfb, 0xd0, 0x48, 0x62, 0x5e, 0xfc, 0x5d, 0x10, 0x8d,
		0xb4, 0xfd, 0x8d, 0x2d, 0x62, 0x66, 0x1d, 0x66, 0x9e, 0x43, 0xdb, 0xdf, 0xd8, 0x24, 0x66, 0x58,
		0xee, 0x3b, 0x68, 0x46, 0xbc, 0x19, 0x6e, 0xf1, 0x50, 0x9f, 0xc6, 0x26, 0x8a, 0x31, 0x22, 0x77,
		0xb0, 0x64, 0x93, 0x2e, 0xed, 0x9d, 0xb8, 0xfd, 0x12, 0x27, 0xa3, 0xfb, 0x45, 0x4b, 0x34, 0x3d,
		0xd1, 0x4e, 0xfc, 0xd4, 0x48, 0xae, 0x26, 0xd7, 0x22, 0x92, 0xda, 0xfe, 0x86, 0x4c, 0x26, 0x82,
		0x6a, 0xaa, 0x7d, 0x6f, 0x65, 0x09, 0x26, 0x94, 0x3e, 0x2b, 0xa5, 0xdf, 0x0e, 0x12, 0x9a, 0x0e,
		0xef, 0x3e, 0xae, 0xd2, 0xf5, 0x28, 0x4f, 0x35, 0x00, 0x55, 0x97, 0x42, 0x53, 0x0a, 0x90, 0x97,
		0x04, 0x1c, 0xa4, 0x01, 0x23, 0x89, 0xc0, 0x45, 0x2a, 0xb0, 0x93, 0x0c, 0xec, 0xa4, 0x03, 0x2f,
		0x09, 0x41, 0x53, 0x4a, 0x10, 0x95, 0x14, 0xe4, 0xa5, 0x45, 0x69, 0x60, 0x7e, 0x8f, 0x82, 0xbc,
		0x13, 0x9a, 0xf9, 0x75, 0xea, 0xb7, 0x54, 0x18, 0x08, 0x0d, 0x36, 0x82, 0x83, 0x93, 0xf0, 0x60,
		0x28, 0x40, 0xb8, 0x09, 0x11, 0xb6, 0x82, 0x84, 0xad, 0x30, 0xe1, 0x29, 0x50, 0x68, 0x0b, 0x15,
		0xe2, 0x82, 0x85, 0x8d, 0x70, 0x29, 0x0d, 0xf5, 0xc3, 0xab, 0x38, 0x09, 0xe4, 0xa7, 0x6b, 0x3e,
		0x0e, 0x6c, 0x16, 0x23, 0xee, 0x4d, 0x67, 0xe2, 0x07, 0x0a, 0x61, 0xb3, 0xc9, 0xc4, 0x5c, 0x2e,
		0x02, 0x87, 0xa3, 0xd0, 0x61, 0x2c, 0x78, 0xb8, 0x0a, 0x1f, 0xf6, 0x02, 0x88, 0xbd, 0x10, 0xe2,
		0x2d, 0x88, 0x78, 0x08, 0x23, 0x26, 0x02, 0xa9, 0x44, 0xc1, 0xbd, 0x1d, 0x0b, 0x9e, 0x1e, 0x7b,
		0x12, 0x44, 0xf2, 0x2d, 0x27, 0x7f, 0x5d, 0xc8, 0x8f, 0x1d, 0x46, 0x26, 0x3b, 0x7e, 0x74, 0x25,
		0xd8, 0xf5, 0xdb, 0xf2, 0xeb, 0x94, 0xd4, 0x4e, 0x83, 0x88, 0x5d, 0x20, 0x67, 0xaa, 0xab, 0x9f,
		0x98, 0x9f, 0x75, 0x95, 0x33, 0xb6, 0xff, 0x28, 0xf1, 0x87, 0x32, 0x88, 0xa3, 0x76, 0x70, 0x15,
		0xc8, 0x74, 0xfa, 0x46, 0xd0, 0x8e, 0x5d, 0xc5, 0x92, 0xf5, 0xbf, 0x62, 0xc9, 0xd6, 0xbc, 0x64,
		0xb7, 0x77, 0x76, 0xb0, 0x68, 0x21, 0xc4, 0xd5, 0xb2, 0x96, 0x47, 0xab, 0x3e, 0xfd, 0xeb, 0xc9,
		0x20, 0xa8, 0x68, 0x97, 0xa1, 0x7f, 0x95, 0xf2, 0x2b, 0xfd, 0xe6, 0x66, 0xa3, 0xec, 0xbb, 0x0a,
		0x73, 0x51, 0xf6, 0xad, 0x10, 0x64, 0x94, 0x7d, 0xab, 0x5b, 0x86, 0x28, 0xfb, 0xd6, 0xfc, 0x06,
		0x50, 0xf6, 0x85, 0xe6, 0x28, 0x50, 0xe0, 0x5b, 0xf6, 0x15, 0xd1, 0xe4, 0x5a, 0x24, 0x79, 0x63,
		0x33, 0xbf, 0xe2, 0xef, 0x56, 0x93, 0x91, 0xcd, 0x66, 0x34, 0xc9, 0xb6, 0x25, 0x60, 0xe9, 0x2d,
		0xf3, 0xaa, 0xda, 0x41, 0x2a, 0x0d, 0x29, 0x13, 0x5e, 0xcb, 0xef, 0x34, 0x88, 0xcc, 0x50, 0x4c,
		0xa3, 0x47, 0xca, 0xab, 0x6e, 0xa4, 0x9d, 0xfa, 0x5f, 0x1f, 0x58, 0xbe, 0xf5, 0xb6, 0xd9, 0x6c,
		0xed, 0x36, 0x9b, 0x9b, 0xbb, 0x6f, 0x76, 0x37, 0xf7, 0x76, 0x76, 0xb6, 0x5a, 0x5b, 0x9c, 0x6e,
		0xc8, 0x74, 0x93, 0x91, 0x48, 0xc4, 0xe8, 0xe0, 0x56, 0xdb, 0xdf, 0x88, 0x26, 0x61, 0x88, 0x52,
		0xc1, 0xda, 0x94, 0x0a, 0x6e, 0x8a, 0x9a, 0x27, 0xb3, 0x52, 0x41, 0x6e, 0x36, 0x4a, 0x05, 0x28,
		0x15, 0xa0, 0x54, 0x80, 0x52, 0x01, 0x4a, 0x05, 0x28, 0x15, 0x40, 0x6f, 0xa0, 0x54, 0x50, 0x89,
		0xc7, 0x9e, 0x04, 0x91, 0x7c, 0xb3, 0xcd, 0xb0, 0x4a, 0xb0, 0x8b, 0x2d, 0x62, 0x2b, 0xfe, 0xc2,
		0x16, 0x31, 0x08, 0xeb, 0x67, 0x98, 0x8f, 0x2d, 0x62, 0x08, 0x97, 0x8b, 0x2c, 0x59, 0x6c, 0x11,
		0xab, 0x7d, 0xc9, 0x36, 0xb7, 0xf7, 0x9a, 0x7b, 0xad, 0xdd, 0xed, 0x3d, 0xec, 0x14, 0x83, 0x20,
		0x57, 0xcc, 0x5a, 0xec, 0x14, 0x5b, 0x07, 0x0b, 0xa9, 0xf7, 0x5a, 0x33, 0x99, 0xd6, 0x5f, 0xda,
		0xab, 0xca, 0xe4, 0xe9, 0x07, 0x63, 0x6b, 0x1f, 0x3c, 0x6f, 0x70, 0x98, 0x31, 0xb3, 0xa1, 0xc0,
		0x40, 0xea, 0xfc, 0xd5, 0x7e, 0x30, 0x4a, 0xef, 0x9f, 0x52, 0x1e, 0xe0, 0x4f, 0xdf, 0xd9, 0x11,
		0x76, 0x74, 0x4c, 0xee, 0xbe, 0xb1, 0xba, 0xeb, 0xc6, 0x24, 0xc3, 0xc0, 0xa0, 0xa9, 0x55, 0x82,
		0x8a, 0x41, 0x53, 0xab, 0x5b, 0x5e, 0x18, 0x34, 0x55, 0xb5, 0x12, 0xc6, 0xa0, 0xa9, 0x75, 0x4b,
		0x7e, 0xd8, 0xdc, 0x1d, 0x2b, 0x3d, 0x6e, 0x28, 0xfc, 0xcb, 0x44, 0x5c, 0x72, 0xf0, 0xb8, 0xb3,
		0x4d, 0xb3, 0x0c, 0xee, 0x87, 0x69, 0xbd, 0x22, 0x9f, 0xfc, 0xe3, 0x8f, 0x3c, 0x03, 0x6b, 0xe4,
		0x12, 0x0c, 0xa9, 0x80, 0x42, 0x96, 0x51, 0x1d, 0xd3, 0xfb, 0x4e, 0xdc, 0x52, 0x17, 0xfd, 0x3c,
		0xb6, 0x3d, 0xf3, 0xd9, 0xe6, 0xcc, 0x7a, 0x5b, 0x33, 0x8f, 0x6d, 0xcc, 0x38, 0x1d, 0xf5, 0x65,
		0x76, 0xaa, 0x5d, 0x67, 0xc5, 0xc1, 0xa8, 0x95, 0x56, 0x56, 0x71, 0x28, 0x2a, 0x47, 0x8b, 0x70,
		0x28, 0xea, 0xda, 0xbb, 0x4c, 0x1c, 0x85, 0xba, 0x42, 0xff, 0x88, 0x23, 0x50, 0xc9, 0xfb, 0x1d,
		0xa2, 0x47, 0x94, 0x90, 0x3e, 0x92, 0x04, 0xc7, 0x9e, 0x3e, 0xb7, 0xf8, 0x84, 0x63, 0x4f, 0x5f,
		0x62, 0x22, 0x8e, 0x3d, 0x5d, 0x92, 0xa1, 0x38, 0xf6, 0x14, 0x5a, 0xbe, 0xaa, 0x8f, 0x90, 0xec,
		0xb1, 0xa7, 0x92, 0xf2, 0x2d, 0xa1, 0xd2, 0x1d, 0x67, 0x56, 0xd2, 0x3e, 0xea, 0x74, 0x13, 0x47,
		0x9d, 0x2a, 0x27, 0x07, 0x18, 0xc9, 0x02, 0x2e, 0xf2, 0x80, 0x9d, 0x4c, 0x60, 0x27, 0x17, 0x78,
		0xc9, 0x06, 0x9a, 0xf2, 0x81, 0xa8, 0x8c, 0x28, 0x3f, 0x5a, 0xf2, 0x1b, 0x39, 0x4a, 0x8f, 0x19,
		0x8c, 0x44, 0x24, 0x03, 0x79, 0x4b, 0x7b, 0x13, 0x47, 0x99, 0xc3, 0x53, 0xbe, 0x0f, 0x69, 0x15,
		0x97, 0xf2, 0xc0, 0x4f, 0x19, 0x6d, 0xee, 0xb5, 0xfa, 0x56, 0xdf, 0xeb, 0x0f, 0x0e, 0x5c, 0xfb,
		0xcc, 0x73, 0x3f, 0xf4, 0x4c, 0xea, 0x6e, 0x3e, 0x6b, 0xc5, 0x4b, 0x59, 0xf4, 0x88, 0x33, 0x1b,
		0xae, 0x64, 0xf5, 0x3d, 0xc7, 0x34, 0x0e, 0x4f, 0x8c, 0x03, 0xcb, 0xb6, 0xdc, 0x0f, 0x05, 0x14,
		0x7d, 0x0e, 0x54, 0x70, 0xa4, 0x83, 0x17, 0x25, 0x3f, 0xa5, 0xe5, 0xc0, 0xe8, 0xb4, 0xff, 0x6b,
		0xb5, 0xdd, 0x13, 0xef, 0xb0, 0xdb, 0xe9, 0xbb, 0x8e, 0x61, 0x75, 0xdc, 0x3e, 0xa3, 0x31, 0x2f,
		0xbf, 0x03, 0x98, 0x6a, 0x81, 0x19, 0xb8, 0x96, 0x6d, 0xfd, 0x65, 0xb6, 0xef, 0xc9, 0x01, 0x2d,
		0xa0, 0x65, 0x1e, 0x2d, 0x46, 0xfb, 0x4f, 0xaf, 0x6f, 0xb5, 0x81, 0x08, 0x10, 0x99, 0x8b, 0xc8,
		0x99, 0x61, 0xd9, 0xc6, 0x81, 0x6d, 0xc2, 0xa3, 0x00, 0x97, 0x9f, 0xe3, 0x62, 0xf5, 0xce, 0x5a,
		0x5e, 0xc7, 0xb4, 0x8e, 0x4f, 0x0e, 0xba, 0x8e, 0x67, 0xb4, 0xdb, 0x8e, 0xd9, 0x87, 0x60, 0x01,
		0x30, 0xf3, 0x05, 0x4b, 0xa7, 0x54, 0xb6, 0x66, 0xdb, 0xb3, 0xfb, 0x3d, 0xc0, 0x02, 0x58, 0xe6,
		0xc1, 0x62, 0x5b, 0x9d, 0x77, 0x9e, 0xe1, 0xba, 0x8e, 0x75, 0x30, 0x70, 0x4d, 0xf8, 0x15, 0xa0,
		0xf2, 0x63, 0x54, 0x7a, 0x4e, 0xd7, 0x35, 0x0f, 0x5d, 0xab, 0xdb, 0xc9, 0xeb, 0x2d, 0xe0, 0x05,
		0xbc, 0xcc, 0x4d, 0x85, 0x4e, 0xad, 0x8e, 0x77, 0xec, 0x74, 0x07, 0x88, 0x40, 0xc0, 0xe4, 0xc7,
		0xfa, 0xd6, 0xea, 0xb8, 0xa6, 0x73, 0x64, 0x1c, 0x9a, 0x10, 0xb8, 0x20, 0xe6, 0x67, 0xc4, 0x9c,
		0x1a, 0xef, 0xf3, 0x60, 0x84, 0xfc, 0x19, 0xb4, 0xfc, 0x42, 0x18, 0xfa, 0xd3, 0xb3, 0x8d, 0x0e,
		0xaa, 0x72, 0xc0, 0xe4, 0xa7, 0xea, 0x16, 0x88, 0x00, 0x91, 0x1f, 0x2a, 0x95, 0x26, 0x2a, 0x71,
		0x00, 0xe6, 0x79, 0xc0, 0x40, 0xda, 0x82, 0x98, 0x67, 0x49, 0x5b, 0xc7, 0xec, 0x9b, 0xce, 0x19,
		0x6e, 0x10, 0x81, 0x99, 0x5f, 0x63, 0xc6, 0x35, 0xbd, 0xb6, 0x79, 0x64, 0x0c, 0x6c, 0xd7, 0x3b,
		0x35, 0x5d, 0xc7, 0x3a, 0x04, 0x2c, 0x80, 0x65, 0xfe, 0xcd, 0xa1, 0xdc, 0xbd, 0x60, 0x3f, 0x0b,
		0x78, 0xf9, 0xe5, 0xb4, 0xa8, 0x6d, 0xda, 0xc6, 0x07, 0xef, 0xcc, 0x70, 0x2c, 0xc3, 0xb5, 0xba,
		0x1d, 0xf0, 0x02, 0x5e, 0xe6, 0xf1, 0x62, 0xbe, 0x77, 0xcd, 0x4e, 0xdb, 0x6c, 0xa3, 0xfa, 0x0f,
		0x5e, 0x7e, 0x49, 0xf0, 0x5a, 0x9d, 0xfb, 0x7a, 0x6e, 0xe6, 0x67, 0x40, 0x0b, 0x68, 0xf9, 0x61,
		0x34, 0xb2, 0xbb, 0xc8, 0xa1, 0x01, 0xc9, 0xaf, 0x48, 0x16, 0x50, 0x02, 0x4a, 0xe6, 0x51, 0xe2,
		0x98, 0x7d, 0xab, 0x3d, 0x30, 0x6c, 0x96, 0x69, 0x10, 0x0b, 0x4b, 0xe9, 0x1f, 0xd4, 0xc5, 0x60,
		0xd5, 0x31, 0xef, 0xcd, 0x63, 0xda, 0x6d, 0x05, 0x30, 0x56, 0x0d, 0x06, 0xc7, 0xae, 0x2a, 0x50,
		0xb1, 0x6a, 0x2a, 0xd8, 0x74, 0x4f, 0x01, 0x85, 0x95, 0xa3, 0xc0, 0xb1, 0x4b, 0x0a, 0x58, 0xac,
		0x1a, 0x0b, 0xa6, 0xdd, 0x50, 0x00, 0x63, 0xe5, 0x82, 0x82, 0x5f, 0xd7, 0x13, 0xa0, 0x58, 0x35,
		0x14, 0xec, 0xba, 0x9b, 0x80, 0x44, 0x25, 0x48, 0xb0, 0xeb, 0x62, 0x02, 0x17, 0xab, 0x4f, 0x3d,
		0x18, 0xdd, 0xaf, 0x04, 0x0e, 0x95, 0xe8, 0x4c, 0x86, 0x5b, 0x37, 0x41, 0xc6, 0xaa, 0xc9, 0xe0,
		0xd8, 0x7d, 0x04, 0x2a, 0x56, 0x1f, 0x3e, 0x18, 0x75, 0x19, 0x01, 0x87, 0x4a, 0x54, 0x26, 0x50,
		0x00, 0x0a, 0x6c, 0xbb, 0x86, 0x00, 0x46, 0x25, 0x60, 0x40, 0x62, 0x82, 0x0c, 0x85, 0xba, 0x80,
		0xc0, 0xc6, 0xaa, 0xd9, 0x60, 0xd8, 0xed, 0x03, 0x28, 0x56, 0x0d, 0x05, 0xcf, 0xae, 0x1e, 0x70,
		0x51, 0x49, 0x1a, 0xc2, 0xae, 0x7b, 0x07, 0x5c, 0xac, 0x9a, 0x0b, 0x9e, 0x5d, 0x3a, 0xe0, 0x62,
		0xe5, 0xc2, 0x93, 0x61, 0x37, 0x0e, 0xa8, 0xa8, 0x24, 0x8a, 0xf0, 0xe8, 0xba, 0x01, 0x0c, 0xd5,
		0x49, 0x0a, 0xd0, 0x00, 0x1a, 0x38, 0x76, 0xd1, 0x80, 0x8a, 0xa5, 0x53, 0xd1, 0xc3, 0x89, 0x4c,
		0xa0, 0x64, 0x51, 0x5a, 0x5c, 0xe3, 0xb8, 0xd5, 0x44, 0xab, 0x26, 0x00, 0x99, 0x07, 0x48, 0xcf,
		0x31, 0x8f, 0xac, 0xf7, 0x18, 0xe0, 0x09, 0x4a, 0x7e, 0x44, 0x49, 0xb6, 0x63, 0xcb, 0xe9, 0x0e,
		0x5c, 0xd3, 0xc1, 0x1c, 0x4f, 0x90, 0xf2, 0xe3, 0x80, 0x03, 0x3c, 0x80, 0xc7, 0x4f, 0xc2, 0xcd,
		0x91, 0x6d, 0x1c, 0x63, 0xce, 0x08, 0x38, 0xf9, 0x51, 0xc0, 0x69, 0xb2, 0x0c, 0x38, 0x98, 0x1e,
		0x81, 0x3a, 0x02, 0x32, 0x43, 0x80, 0x80, 0x0c, 0x10, 0x34, 0x20, 0xd3, 0x03, 0x11, 0x4a, 0x04,
		0x0a, 0x60, 0x00, 0x0c, 0x78, 0x65, 0x6e, 0xe0, 0x01, 0x19, 0x1a, 0x88, 0x58, 0x2d, 0x11, 0xc5,
		0x87, 0x7f, 0x68, 0xf4, 0x70, 0x6f, 0x12, 0x9c, 0x2c, 0xc4, 0x8b, 0xe3, 0x19, 0xf6, 0x71, 0xd7,
		0xb1, 0xdc, 0x93, 0x53, 0x54, 0x03, 0x41, 0xca, 0x0f, 0x49, 0xb9, 0xff, 0x13, 0xca, 0x81, 0xcb,
		0xfd, 0x42, 0x39, 0x10, 0xc1, 0x9b, 0x9b, 0x33, 0x06, 0x11, 0x70, 0xba, 0xac, 0x9c, 0x2d, 0x5d,
		0x27, 0x4b, 0xf3, 0xba, 0xd1, 0xb3, 0x8a, 0x96, 0x45, 0xc4, 0x1c, 0xa0, 0x66, 0x44, 0x51, 0x2c,
		0x7d, 0x19, 0xc4, 0x91, 0xb6, 0x4f, 0xd0, 0xf5, 0x69, 0xe9, 0xf0, 0x93, 0xb8, 0xf6, 0xc7, 0xbe,
		0xfc, 0x34, 0x75, 0x76, 0x8d, 0x78, 0x2c, 0xa2, 0x61, 0x1c, 0x5d, 0x06, 0x57, 0x7a, 0x24, 0xe4,
		0x97, 0x38, 0xf9, 0xac, 0x07, 0x51, 0x2a, 0xfd, 0x68, 0x28, 0x1a, 0x8f, 0x5f, 0x48, 0x9f, 0xbc,
		0xd2, 0x18, 0x27, 0xb1, 0x8c, 0x87, 0x71, 0x98, 0x96, 0xcf, 0x1a, 0x41, 0x1a, 0xa4, 0x8d, 0x50,
		0xdc, 0x88, 0xb0, 0x78, 0x68, 0x84, 0x41, 0xf4, 0x59, 0x4f, 0xa5, 0x2f, 0x85, 0x3e, 0xf2, 0xa5,
		0x7f, 0xe1, 0xa7, 0xa2, 0x11, 0xa6, 0xe3, 0x86, 0x0c, 0x6f, 0xd2, 0xe9, 0xb7, 0xc6, 0xb5, 0xd4,
		0x83, 0xf1, 0x4d, 0x4b, 0x4f, 0x84, 0x3f, 0xfc, 0xe4, 0x5f, 0x04, 0x61, 0x20, 0x6f, 0x1b, 0xe3,
		0x44, 0x5c, 0x06, 0x5f, 0x45, 0x5a, 0x3c, 0x69, 0xa4, 0x93, 0x8b, 0xec, 0x07, 0xf2, 0xc7, 0x46,
		0xf6, 0xff, 0x11, 0x4c, 0xae, 0xb5, 0x54, 0x26, 0x93, 0xa1, 0x8c, 0x8a, 0x68, 0xd2, 0x2d, 0xaf,
		0x6f, 0x27, 0xbf, 0x76, 0x56, 0x71, 0xe9, 0xbc, 0x47, 0x7f, 0x4e, 0x1f, 0xbf, 0xe0, 0xf5, 0x66,
		0xd7, 0xb6, 0x7c, 0xe6, 0x59, 0x69, 0x90, 0x7a, 0x76, 0x76, 0x6d, 0xf3, 0x07, 0xcf, 0x0e, 0xa2,
		0xcf, 0xfd, 0xe9, 0xa5, 0x68, 0x17, 0x57, 0xd6, 0xb3, 0xd3, 0xb1, 0xe7, 0x86, 0x37, 0xe9, 0xf4,
		0x9b, 0x77, 0x2a, 0xad, 0xf1, 0x4d, 0xcb, 0x79, 0x70, 0x5d, 0xbd, 0x5e, 0x71, 0x5d, 0x8b, 0x27,
		0x5e, 0x3f, 0xbf, 0xae, 0xc5, 0xa3, 0x97, 0xfd, 0x67, 0xb4, 0x82, 0x1c, 0x1d, 0x87, 0x43, 0xc8,
		0xd9, 0x68, 0xd2, 0xbf, 0x22, 0xe7, 0x61, 0x4a, 0x11, 0x35, 0x35, 0x8e, 0x98, 0x63, 0x7e, 0x17,
		0x44, 0x23, 0x6d, 0x7f, 0x63, 0x8b, 0x98, 0x59, 0x87, 0x99, 0x73, 0xd0, 0xf6, 0x37, 0x36, 0x89,
		0x19, 0x96, 0xbb, 0x07, 0x9a, 0x41, 0x6c, 0x86, 0x59, 0x3c, 0xd4, 0xa7, 0xe1, 0x86, 0x62, 0x18,
		0xe8, 0xc7, 0x93, 0x64, 0x28, 0x48, 0x5e, 0xbe, 0x7c, 0x39, 0x88, 0xdb, 0x2f, 0x71, 0x32, 0x5d,
		0x11, 0x5a, 0x1e, 0x60, 0x89, 0x16, 0xaa, 0xb5, 0x13, 0x3f, 0x35, 0x92, 0xab, 0xc9, 0xb5, 0x88,
		0xa4, 0xb6, 0xbf, 0x21, 0x93, 0x89, 0x20, 0x6a, 0xe8, 0x03, 0x2b, 0x4b, 0x30, 0x21, 0xde, 0x59,
		0x89, 0xf7, 0x76, 0x90, 0x10, 0x55, 0xed, 0x99, 0x2a, 0x23, 0xeb, 0x4c, 0x66, 0xfe, 0x98, 0xaa,
		0x28, 0x27, 0x2c, 0x00, 0xc8, 0x0b, 0x01, 0x0e, 0x82, 0x80, 0x91, 0x30, 0xe0, 0x22, 0x10, 0xd8,
		0x09, 0x05, 0x76, 0x82, 0x81, 0x97, 0x70, 0xa0, 0x29, 0x20, 0x88, 0x0a, 0x09, 0xf2, 0x82, 0xe2,
		0x61, 0x15, 0xe1, 0xcd, 0x36, 0x7d, 0x27, 0xf4, 0xa0, 0xae, 0xf0, 0x66, 0x9b, 0xba, 0x03, 0x2a,
		0x84, 0xc6, 0x26, 0x71, 0x33, 0xa9, 0x0b, 0x0e, 0x4e, 0xc2, 0x83, 0xa1, 0x00, 0xe1, 0x26, 0x44,
		0xd8, 0x0a, 0x12, 0xb6, 0xc2, 0x84, 0xa7, 0x40, 0xa1, 0x2d, 0x54, 0x88, 0x0b, 0x96, 0xf2, 0x23,
		0x77, 0x6f, 0xc7, 0x82, 0x97, 0xc7, 0x9d, 0x04, 0x91, 0x24, 0xaf, 0x0d, 0x1e, 0xea, 0x83, 0x5d,
		0x06, 0xa6, 0x3a, 0x7e, 0x74, 0x25, 0xd8, 0x6c, 0x0a, 0xe6, 0xb3, 0xcd, 0x53, 0x3b, 0x0d, 0x22,
		0x36, 0x11, 0x97, 0x99, 0xb0, 0x7d, 0x62, 0x76, 0xb6, 0xb5, 0x9d, 0xa1, 0xdd, 0x47, 0x89, 0x3f,
		0x94, 0x41, 0x1c, 0xb5, 0x83, 0xab, 0x40, 0xa6, 0xd3, 0x37, 0x80, 0xbd, 0xe1, 0xab, 0x58, 0x8a,
		0xfe, 0x57, 0x2c, 0xc5, 0x8a, 0x97, 0x62, 0x73, 0x7b, 0xaf, 0xb9, 0xd7, 0xda, 0xdd, 0xde, 0xdb,
		0xc1, 0x9a, 0x84, 0x20, 0xe6, 0x65, 0xe5, 0x39, 0x12, 0x8b, 0x17, 0x2c, 0x20, 0x3b, 0x48, 0xa5,
		0x21, 0x65, 0xc2, 0x23, 0xb9, 0x38, 0x0d, 0x22, 0x33, 0x14, 0xd3, 0xdc, 0x37, 0xe5, 0xe1, 0x6d,
		0xa7, 0xd1, 0xec, 0xff, 0xb3, 0x77, 0x7e, 0x4d, 0x6d, 0x63, 0xc9, 0xfb, 0xbf, 0x9f, 0x57, 0x41,
		0xa9, 0xf6, 0x62, 0xb7, 0x6a, 0x1c, 0x03, 0x31, 0x10, 0xb8, 0x13, 0x58, 0x24, 0x9a, 0x18, 0xdb,
		0x65, 0x0b, 0x36, 0xd9, 0x19, 0x56, 0x25, 0xf0, 0x81, 0xe8, 0x17, 0x23, 0x53, 0x92, 0x4c, 0xc2,
		0x77, 0x36, 0xef, 0xfd, 0x57, 0xfe, 0x27, 0x13, 0x0c, 0x93, 0x49, 0x62, 0x49, 0xfd, 0xb4, 0x1e,
		0x5f, 0x04, 0xe2, 0x19, 0x42, 0xcb, 0x7a, 0x4e, 0xf7, 0xa7, 0x5b, 0xa7, 0xfb, 0x3c, 0xb0, 0x78,
		0xeb, 0x55, 0xa3, 0xb1, 0xbb, 0xd7, 0x68, 0x6c, 0xee, 0xbd, 0xdc, 0xdb, 0xdc, 0xdf, 0xd9, 0xd9,
		0xda, 0xdd, 0x02, 0xf0, 0xb8, 0x56, 0x27, 0x1e, 0x98, 0xd8, 0x0c, 0x0e, 0xef, 0xad, 0x83, 0x8d,
		0x68, 0x3c, 0x1c, 0xfe, 0x42, 0x8f, 0xa5, 0xc7, 0x32, 0xa9, 0xcf, 0x6a, 0x84, 0xef, 0xdc, 0xce,
		0xec, 0xd4, 0xb2, 0x83, 0x3b, 0x0d, 0xae, 0xeb, 0x92, 0x37, 0x8c, 0x6c, 0x28, 0xd8, 0xcd, 0xed,
		0x05, 0xd7, 0x12, 0x77, 0x74, 0xcb, 0x75, 0x50, 0xdc, 0x1f, 0x07, 0xec, 0x22, 0x35, 0xb9, 0x46,
		0xb6, 0xb6, 0xe4, 0xe1, 0x0c, 0xd9, 0xd8, 0x22, 0xde, 0xd1, 0x58, 0x69, 0x70, 0xbd, 0xdb, 0x10,
		0xdd, 0xda, 0xb2, 0xdb, 0x60, 0x73, 0xcb, 0xdf, 0x32, 0x8b, 0xcd, 0x2d, 0x3f, 0x21, 0x34, 0x36,
		0xb7, 0xfc, 0xf8, 0x72, 0x60, 0x73, 0xcb, 0xba, 0xc9, 0x8f, 0xcd, 0x2d, 0xe8, 0xf0, 0xce, 0xe6,
		0x96, 0x9f, 0xf3, 0xc7, 0x6c, 0x6e, 0xd1, 0x07, 0x02, 0x08, 0x40, 0x00, 0x04, 0x06, 0x28, 0x80,
		0x00, 0x07, 0x0a, 0x70, 0xc0, 0x80, 0x05, 0x0e, 0x32, 0x01, 0x42, 0x28, 0x48, 0x88, 0x07, 0x0a,
		0xe1, 0x95, 0x04, 0xa8, 0xca, 0xc2, 0x73, 0xa0, 0xc1, 0xe6, 0x96, 0xea, 0x80, 0x07, 0x20, 0x80,
		0xa0, 0x81, 0x08, 0x2c, 0x90, 0xc0, 0x82, 0x09, 0x26, 0xa0, 0xc8, 0x06, 0x15, 0xe1, 0xc0, 0x92,
		0xdd, 0x72, 0xcc, 0xe6, 0x16, 0xf1, 0x6c, 0xf0, 0x90, 0x0f, 0x5e, 0xb1, 0xb9, 0x65, 0xcd, 0x2f,
		0x36, 0xb7, 0x10, 0x6c, 0x9f, 0x30, 0x9b, 0xcd, 0x2d, 0x0c, 0x6f, 0x7f, 0xb5, 0x14, 0xd9, 0xdc,
		0x52, 0xf8, 0x52, 0xc4, 0xdc, 0x74, 0xad, 0x66, 0x75, 0xb2, 0xcd, 0x65, 0x2d, 0x2f, 0xb6, 0xb9,
		0xfc, 0xcc, 0x02, 0x62, 0x9b, 0x4b, 0xee, 0x71, 0x8d, 0x6d, 0x2e, 0xf4, 0x58, 0x82, 0x2d, 0x63,
		0x9b, 0xcb, 0xcf, 0xd9, 0xa9, 0x68, 0x2f, 0xf7, 0x6e, 0x83, 0x8d, 0x2e, 0xf9, 0xef, 0xed, 0xde,
		0x6d, 0xb0, 0xd5, 0x05, 0xd7, 0x22, 0xb6, 0xba, 0x54, 0xd8, 0x3d, 0xb2, 0xd9, 0x25, 0x1f, 0x87,
		0xc8, 0x76, 0x17, 0xf1, 0xce, 0xc6, 0x4a, 0x25, 0x3e, 0x8c, 0x5a, 0xee, 0x49, 0x99, 0x58, 0x27,
		0xb3, 0xd9, 0x65, 0x93, 0xcd, 0x2e, 0x7f, 0xcf, 0x30, 0x36, 0xbb, 0xfc, 0x94, 0x89, 0x6c, 0x76,
		0x59, 0x93, 0xa1, 0x6c, 0x76, 0x21, 0xbe, 0x17, 0x75, 0x0b, 0xc5, 0x6e, 0xf1, 0xc8, 0x3c, 0xde,
		0xd0, 0x04, 0x57, 0xb1, 0xb9, 0x92, 0xe8, 0xf1, 0x16, 0xcd, 0x24, 0x02, 0x27, 0x94, 0x5a, 0xdd,
		0x79, 0xc6, 0xf3, 0xe2, 0xc5, 0xac, 0xa6, 0x52, 0x9f, 0x12, 0x0a, 0x39, 0x57, 0xb0, 0x25, 0x42,
		0x7c, 0xc3, 0x24, 0x50, 0x0a, 0x43, 0x5a, 0x99, 0x8f, 0x89, 0xe4, 0x3e, 0x0e, 0x82, 0x7a, 0xec,
		0x23, 0xf3, 0xf1, 0x8e, 0x94, 0xc5, 0x28, 0xb4, 0xbe, 0xa6, 0xa5, 0xae, 0x26, 0x08, 0x2b, 0xc0,
		0x2b, 0x69, 0x32, 0xd8, 0xa2, 0xfc, 0x48, 0x5e, 0xae, 0x05, 0x25, 0xbb, 0x2d, 0x69, 0xee, 0x0a,
		0xde, 0x4d, 0x09, 0xf0, 0x4f, 0xa8, 0x7e, 0xa9, 0x5c, 0x87, 0x54, 0x9e, 0x1b, 0x28, 0xd1, 0x05,
		0x58, 0xe3, 0x68, 0x60, 0xae, 0xc2, 0xc8, 0x0c, 0x6a, 0x0b, 0xfd, 0x96, 0xed, 0x05, 0x96, 0xad,
		0x21, 0x2b, 0xa6, 0x95, 0xec, 0x2a, 0x65, 0x8c, 0xa2, 0x10, 0x53, 0x8e, 0x97, 0x54, 0x7e, 0x17,
		0x58, 0x6e, 0x97, 0x56, 0x5e, 0x17, 0x5b, 0x4e, 0x17, 0x5b, 0x3e, 0x97, 0x59, 0x2e, 0xaf, 0x36,
		0xae, 0x4a, 0x19, 0xcd, 0xb0, 0x12, 0x9d, 0xe4, 0xac, 0xf3, 0xe7, 0xe2, 0xa7, 0x94, 0xe5, 0x2e,
		0x6b, 0xa2, 0x93, 0xb8, 0xa7, 0xdb, 0x12, 0x9f, 0x6a, 0x0b, 0x7e, 0x9a, 0x2d, 0xf5, 0x29, 0xb6,
		0xf8, 0xa7, 0xd7, 0xe2, 0x9f, 0x5a, 0xcb, 0x7e, 0x5a, 0xcd, 0x27, 0x50, 0x12, 0xc3, 0xf2, 0x83,
		0x12, 0x88, 0xc4, 0xd1, 0x8b, 0xa2, 0x47, 0x2e, 0x72, 0xd6, 0x32, 0x7e, 0xa0, 0x06, 0x08, 0xd8,
		0xd2, 0x03, 0x37, 0x4c, 0x00, 0x87, 0x09, 0xe4, 0x18, 0x01, 0x5d, 0x56, 0x60, 0x17, 0x16, 0xe0,
		0xc5, 0x06, 0xfa, 0xcc, 0xb0, 0xa1, 0x89, 0xae, 0xa7, 0xcf, 0x8c, 0x84, 0x0f, 0x5b, 0x9e, 0xdb,
		0x29, 0x7b, 0xda, 0xf2, 0x26, 0xa7, 0x2d, 0xab, 0x43, 0x02, 0x20, 0x34, 0x40, 0x41, 0x04, 0x38,
		0x54, 0x80, 0x43, 0x06, 0x2c, 0x74, 0x90, 0x89, 0x10, 0x42, 0x51, 0x22, 0xbb, 0xb5, 0xe2, 0x87,
		0x16, 0x7e, 0x35, 0xac, 0xf0, 0x95, 0x64, 0x7f, 0x39, 0x0f, 0xdf, 0x82, 0x47, 0x84, 0x80, 0xcc,
		0x26, 0xc4, 0x18, 0x6d, 0x03, 0x34, 0xfd, 0x17, 0x6a, 0xf0, 0x19, 0xda, 0xec, 0x41, 0xc4, 0xa9,
		0x66, 0x5f, 0x30, 0x66, 0x31, 0x71, 0x89, 0xe5, 0xbc, 0xc4, 0xb6, 0x77, 0x76, 0xb8, 0xc8, 0xaa,
		0x05, 0xa2, 0xf2, 0xad, 0x3b, 0xe7, 0xa4, 0x1d, 0x54, 0x27, 0x2e, 0x73, 0xec, 0xc4, 0x4a, 0x2a,
		0x21, 0x70, 0xfc, 0x04, 0x48, 0x24, 0x61, 0x11, 0x70, 0x9d, 0x3a, 0x64, 0x11, 0x70, 0x7d, 0xcb,
		0x86, 0x45, 0xc0, 0x9c, 0x0d, 0x66, 0x11, 0x50, 0x6b, 0xda, 0xc5, 0x22, 0xe0, 0xda, 0xc3, 0x37,
		0x8b, 0x80, 0x3f, 0xfb, 0x62, 0x11, 0x90, 0x15, 0x0a, 0x16, 0x01, 0x2b, 0x18, 0x8d, 0xbe, 0x5e,
		0x62, 0x2c, 0x02, 0xe6, 0xbe, 0xc4, 0x58, 0x04, 0xac, 0x1c, 0x88, 0xca, 0xb7, 0x8e, 0x45, 0x40,
		0x58, 0x27, 0x6e, 0xdd, 0xcd, 0x1d, 0x8b, 0xf0, 0x2a, 0xe0, 0xcc, 0x4c, 0x96, 0x01, 0x7f, 0xc4,
		0x3c, 0x96, 0x01, 0xd7, 0x28, 0x44, 0x96, 0x01, 0xd7, 0xb7, 0x6c, 0x58, 0x06, 0xcc, 0xd9, 0x60,
		0x96, 0x01, 0xb5, 0x26, 0x5e, 0x40, 0x65, 0xc0, 0x8b, 0x30, 0x0a, 0xe2, 0x7b, 0x80, 0x3a, 0xe0,
		0x3e, 0x31, 0x16, 0xd0, 0x22, 0x9e, 0x1a, 0xf3, 0x7d, 0xf6, 0xc1, 0x8e, 0x8d, 0x5b, 0x99, 0x72,
		0xb5, 0xf2, 0x8e, 0xd8, 0x23, 0xb6, 0xe0, 0xe6, 0xcc, 0x9d, 0x2e, 0x3e, 0xd9, 0xc5, 0x20, 0xcc,
		0x47, 0x6f, 0x48, 0x3c, 0x66, 0x8b, 0x67, 0xcb, 0x3c, 0xa5, 0x3c, 0x9e, 0x2d, 0xa3, 0x23, 0x9b,
		0x67, 0x73, 0xbf, 0xce, 0xac, 0x9d, 0xcd, 0xfd, 0x55, 0xcb, 0xce, 0xd9, 0xdc, 0x8f, 0x0f, 0xf9,
		0x3c, 0x5b, 0xe6, 0xe7, 0x03, 0x2c, 0xcf, 0x96, 0x81, 0xe7, 0x5c, 0x4e, 0xf6, 0xfa, 0x3a, 0x50,
		0xf2, 0x6c, 0x99, 0xbf, 0x63, 0x15, 0xcf, 0x96, 0x59, 0x8b, 0xb1, 0x3c, 0x5b, 0xe6, 0xaf, 0x18,
		0x8b, 0x67, 0xcb, 0x14, 0x5d, 0x7d, 0xe3, 0x79, 0x33, 0xf9, 0xd5, 0xdb, 0x78, 0x02, 0x8d, 0x04,
		0x0b, 0x78, 0x02, 0x8d, 0x56, 0x67, 0xc6, 0xb3, 0x68, 0x7e, 0xde, 0x67, 0x55, 0xf6, 0x50, 0x9a,
		0x5f, 0x2a, 0xe4, 0x8b, 0x16, 0x59, 0xce, 0x6c, 0x21, 0x6d, 0x4c, 0x56, 0xdb, 0xa0, 0xa4, 0xc5,
		0x23, 0x23, 0xbb, 0x91, 0x93, 0xcd, 0x88, 0xce, 0x5e, 0x64, 0x64, 0x2b, 0x65, 0x2d, 0x1a, 0x21,
		0x81, 0x1b, 0x36, 0x60, 0x97, 0x18, 0x9e, 0xd1, 0xc2, 0x72, 0x39, 0x51, 0xb8, 0xf8, 0x18, 0x58,
		0xec, 0x6f, 0x2c, 0xd8, 0x71, 0x94, 0xed, 0x30, 0xf0, 0x1c, 0x45, 0x09, 0x1e, 0x02, 0xc6, 0x33,
		0x14, 0xeb, 0x12, 0x8a, 0x5b, 0x98, 0xc5, 0xfc, 0xa6, 0x82, 0x96, 0x7e, 0x59, 0x4b, 0x1e, 0x66,
		0xa9, 0x17, 0xb8, 0xc2, 0xa5, 0xaf, 0xec, 0x62, 0x16, 0x74, 0xfe, 0xcb, 0xab, 0x80, 0xa5, 0x65,
		0x4d, 0xa4, 0x94, 0x84, 0x49, 0x2d, 0x32, 0xe1, 0xf5, 0x87, 0x8b, 0x51, 0x5c, 0x0b, 0xd2, 0x34,
		0x0e, 0x2f, 0xc6, 0x05, 0x9e, 0x79, 0x93, 0x3d, 0x93, 0xff, 0x0b, 0x5b, 0x0a, 0x72, 0x32, 0xc5,
		0x1e, 0x5c, 0x53, 0xf8, 0x9e, 0xb5, 0x32, 0xf6, 0xa2, 0x95, 0xb8, 0xc7, 0xac, 0xac, 0xbd, 0x63,
		0xa5, 0xef, 0x09, 0x2b, 0x7d, 0xaf, 0x57, 0xb9, 0x7b, 0xb8, 0x74, 0x81, 0x4f, 0xd1, 0x07, 0xa5,
		0x58, 0x0b, 0xf7, 0x5b, 0xfc, 0x09, 0xde, 0x99, 0xaf, 0x58, 0x9a, 0x50, 0xb0, 0x6e, 0xcb, 0x39,
		0xb9, 0xac, 0xb4, 0xcd, 0xcb, 0x65, 0x6e, 0x4e, 0x16, 0xb0, 0xf9, 0xb8, 0xec, 0xcd, 0xc5, 0x62,
		0x36, 0x0f, 0x8b, 0xd9, 0x1c, 0x2c, 0x63, 0xf3, 0xaf, 0xee, 0xe2, 0x59, 0x59, 0x27, 0x6f, 0x65,
		0x5e, 0xbd, 0xbc, 0xf5, 0xf6, 0x38, 0xbe, 0x94, 0xb5, 0xdc, 0xca, 0x3d, 0x20, 0xb3, 0xf4, 0x5e,
		0x19, 0x09, 0x3d, 0x31, 0x82, 0x7a, 0x5f, 0xa4, 0xf4, 0xb8, 0x88, 0xeb, 0x65, 0x11, 0xd7, 0xb3,
		0x22, 0xab, 0x37, 0xa5, 0x5a, 0x3b, 0x2b, 0xca, 0x3e, 0x30, 0xd2, 0xca, 0xca, 0xba, 0xe5, 0x2f,
		0xd4, 0x85, 0xef, 0x5a, 0x9a, 0x54, 0xf2, 0xba, 0x90, 0x71, 0xe2, 0xb3, 0x98, 0x26, 0x50, 0x49,
		0x4d, 0x9f, 0x02, 0x9b, 0x3c, 0xa5, 0x35, 0x75, 0x8a, 0x6d, 0xe2, 0x14, 0xdb, 0xb4, 0x29, 0xb3,
		0x49, 0xb3, 0xda, 0xdb, 0x9f, 0xa5, 0x9c, 0xa8, 0x9c, 0x45, 0x25, 0x39, 0xeb, 0xfb, 0x71, 0xbc,
		0x94, 0xb2, 0xbc, 0x65, 0x84, 0x4d, 0x71, 0xe1, 0x53, 0x62, 0x18, 0x15, 0x1c, 0x4e, 0xa5, 0x86,
		0x55, 0xf1, 0xe1, 0x55, 0x7c, 0x98, 0x95, 0x1d, 0x6e, 0x65, 0x84, 0x5d, 0x21, 0xe1, 0x57, 0x5c,
		0x18, 0x5e, 0x86, 0xe3, 0x81, 0xdc, 0x01, 0x47, 0xa5, 0x75, 0x47, 0x7c, 0x2b, 0x24, 0x73, 0xbc,
		0x11, 0x6e, 0x88, 0x06, 0x08, 0xd5, 0xd2, 0x43, 0x36, 0x4c, 0xe8, 0x86, 0x09, 0xe1, 0x18, 0xa1,
		0x5c, 0x56, 0x48, 0x17, 0x16, 0xda, 0xb3, 0x5b, 0xc8, 0xf1, 0x46, 0x6b, 0xc8, 0x79, 0x21, 0xc6,
		0x1b, 0x85, 0x03, 0x0e, 0x37, 0x12, 0xbf, 0x26, 0xad, 0xd9, 0x5c, 0x5b, 0xb1, 0x90, 0x2b, 0x71,
		0xec, 0xae, 0xb0, 0xd2, 0x13, 0x39, 0x97, 0x9c, 0x4b, 0xce, 0x25, 0xe7, 0x92, 0x73, 0x25, 0xdd,
		0x42, 0x69, 0xa5, 0xac, 0xcc, 0x30, 0x81, 0x25, 0xad, 0x15, 0x67, 0x2c, 0xae, 0xb4, 0xf5, 0x38,
		0xf4, 0xf3, 0x3c, 0x2e, 0x7d, 0x28, 0x00, 0x84, 0x04, 0x28, 0x68, 0x00, 0x87, 0x08, 0x70, 0xa8,
		0x80, 0x85, 0x0c, 0x32, 0xd1, 0x41, 0x28, 0x42, 0x64, 0xb7, 0x16, 0xeb, 0x58, 0xfe, 0xdd, 0x06,
		0xc0, 0x79, 0x5c, 0xaf, 0x78, 0x2e, 0xff, 0x4f, 0xbe, 0x78, 0x2e, 0x7f, 0x95, 0xc0, 0x72, 0xc5,
		0x5c, 0x9e, 0xcb, 0x5f, 0xd5, 0x70, 0xf4, 0xf5, 0x12, 0xe3, 0xb9, 0xfc, 0xb9, 0x2f, 0x31, 0xd9,
		0xb3, 0xe2, 0xd5, 0xad, 0x3a, 0x1e, 0xd4, 0xff, 0x43, 0x2f, 0x1e, 0xd4, 0x0f, 0xeb, 0xd5, 0xad,
		0x1b, 0x93, 0xc6, 0xe1, 0xa5, 0xfc, 0xb2, 0xe0, 0xdc, 0x4e, 0x96, 0x06, 0x7f, 0xc4, 0x3c, 0x96,
		0x06, 0xd7, 0xa8, 0x44, 0x96, 0x06, 0xd7, 0xb7, 0x6c, 0x58, 0x1a, 0xcc, 0xd9, 0x60, 0x96, 0x06,
		0xb5, 0xe6, 0x62, 0x40, 0xa5, 0xc1, 0x4f, 0xe1, 0xc0, 0xd4, 0x44, 0x07, 0xf0, 0x87, 0x41, 0x7c,
		0x8f, 0xf5, 0xc1, 0x9f, 0x7c, 0xb1, 0x3e, 0xc8, 0xe2, 0x85, 0xbc, 0x3d, 0x72, 0xaa, 0x2a, 0x15,
		0xac, 0x0f, 0x72, 0x89, 0x4d, 0x96, 0xd8, 0xee, 0xde, 0xde, 0xde, 0x36, 0x6b, 0x82, 0x55, 0x63,
		0x52, 0xf9, 0xd6, 0xb1, 0x26, 0x88, 0x68, 0x91, 0xb4, 0x9d, 0x94, 0x42, 0xcf, 0x5b, 0xcd, 0xec,
		0x93, 0x7a, 0xca, 0xc1, 0xd3, 0xe3, 0xe0, 0xeb, 0xd9, 0x7c, 0xe0, 0xec, 0xbb, 0xfa, 0xd2, 0x9c,
		0xcc, 0x0c, 0x89, 0x7d, 0x17, 0x1b, 0x12, 0xcf, 0x4f, 0x48, 0xc2, 0xa4, 0x3d, 0xff, 0x1c, 0xed,
		0xc5, 0x67, 0xec, 0x2f, 0xde, 0x49, 0xb2, 0xef, 0xfc, 0xa5, 0x21, 0x99, 0x05, 0xd3, 0x7f, 0x98,
		0x3d, 0x52, 0xe2, 0xbd, 0x90, 0xb5, 0x38, 0xc9, 0x53, 0x6e, 0x97, 0x94, 0x98, 0xa3, 0x46, 0x9f,
		0x02, 0x6a, 0xf6, 0x49, 0xfd, 0x4d, 0xc3, 0xd8, 0x27, 0xf5, 0x53, 0x26, 0xb2, 0x4f, 0x6a, 0x4d,
		0x86, 0xb2, 0x4f, 0x8a, 0x74, 0x5f, 0xd4, 0x2d, 0x14, 0xdb, 0x27, 0x35, 0x8b, 0xa9, 0xf2, 0x37,
		0x45, 0xcc, 0xed, 0x94, 0xbd, 0x29, 0x62, 0x8b, 0x9b, 0x22, 0xd4, 0x21, 0x01, 0x10, 0x1a, 0xa0,
		0x20, 0x02, 0x1c, 0x2a, 0xc0, 0x21, 0x03, 0x16, 0x3a, 0xc8, 0x44, 0x08, 0xa1, 0x28, 0x21, 0x1e,
		0x29, 0x32, 0x03, 0x83, 0xc1, 0xff, 0x0b, 0x2e, 0x4d, 0x74, 0x79, 0x5f, 0x4b, 0xc2, 0x41, 0x22,
		0xdf, 0x1b, 0x2d, 0x1c, 0xfc, 0x23, 0xbb, 0x85, 0xaf, 0x70, 0xd9, 0xe8, 0x01, 0x83, 0x20, 0x48,
		0x28, 0x02, 0x88, 0x24, 0x68, 0x68, 0x02, 0x8b, 0x28, 0xb0, 0xa8, 0x82, 0x89, 0x2c, 0xb2, 0xd1,
		0x45, 0x38, 0xc2, 0xc0, 0xa0, 0xcc, 0xd3, 0x48, 0x83, 0xe3, 0xc4, 0x9e, 0x24, 0x1b, 0x14, 0x47,
		0x86, 0x01, 0x38, 0x70, 0xa0, 0x83, 0x08, 0x3c, 0xc0, 0xe0, 0x83, 0x0a, 0x40, 0xf0, 0x20, 0x04,
		0x0f, 0x44, 0xd8, 0x60, 0x84, 0x01, 0x48, 0x20, 0xa0, 0x04, 0x07, 0x4c, 0x99, 0xc1, 0x32, 0xe7,
		0xef, 0xfe, 0xed, 0x38, 0x23, 0x75, 0x9f, 0x98, 0x22, 0x70, 0x82, 0x05, 0x28, 0x64, 0x90, 0x52,
		0x00, 0x54, 0xe8, 0x60, 0xa5, 0x06, 0xb0, 0xd4, 0x80, 0x96, 0x0e, 0xe0, 0xc2, 0x02, 0x2f, 0x30,
		0x00, 0x83, 0x05, 0xb1, 0xcc, 0xf0, 0xab, 0x61, 0x70, 0x9d, 0xe0, 0x3a, 0xcb, 0x45, 0xbc, 0x9a,
		0x5d, 0x06, 0xa8, 0x7f, 0xc1, 0xea, 0xc4, 0x53, 0x03, 0x6a, 0x1a, 0x80, 0x4d, 0x11, 0xb8, 0x69,
		0x01, 0x38, 0x75, 0x20, 0xa7, 0x0e, 0xe8, 0x74, 0x81, 0x1d, 0x26, 0xe0, 0x81, 0x82, 0x5e, 0x26,
		0x1d, 0xf1, 0xa3, 0x68, 0xfe, 0x76, 0xc4, 0x30, 0xd1, 0xf8, 0xc6, 0xc4, 0xb3, 0x8e, 0x53, 0xe0,
		0xa8, 0xb1, 0xa8, 0x72, 0x35, 0x80, 0xaf, 0xc1, 0x89, 0xc6, 0x37, 0x13, 0x51, 0x71, 0x29, 0x17,
		0xf9, 0xa9, 0xb7, 0xc2, 0x24, 0xb5, 0xd3, 0x34, 0xc6, 0x5e, 0xce, 0x27, 0x61, 0xe4, 0x0c, 0xcd,
		0x24, 0x9a, 0x25, 0xb8, 0x28, 0xbe, 0x31, 0x9f, 0xa2, 0xf2, 0xe0, 0x4a, 0x70, 0xe7, 0x01, 0x3f,
		0x79, 0x71, 0x9d, 0x78, 0x60, 0x62, 0x33, 0x38, 0xbc, 0xb7, 0x0e, 0x36, 0xa2, 0xf1, 0x70, 0xf8,
		0x0b, 0x51, 0x83, 0xbe, 0xe9, 0x69, 0xa9, 0xdc, 0xcd, 0x27, 0xde, 0x80, 0x97, 0x66, 0x66, 0x97,
		0xc1, 0xd2, 0x4c, 0x19, 0xe6, 0xb3, 0x34, 0x23, 0x68, 0x21, 0xb0, 0x34, 0x23, 0x67, 0x59, 0xb3,
		0x34, 0x23, 0xfc, 0x82, 0x58, 0x9a, 0x21, 0x33, 0xfd, 0xa0, 0x74, 0xf4, 0x94, 0x66, 0xc6, 0x61,
		0x94, 0xbe, 0xdc, 0x56, 0x50, 0x95, 0xd9, 0x03, 0xbe, 0x04, 0x8c, 0x01, 0xc4, 0xdf, 0x7a, 0x61,
		0x07, 0xec, 0x0d, 0xb4, 0x01, 0xc6, 0xca, 0x13, 0x8b, 0x95, 0xcb, 0x01, 0x3b, 0x20, 0xed, 0x9b,
		0xd7, 0x03, 0x38, 0xb6, 0x55, 0x69, 0x38, 0xff, 0xda, 0x05, 0x04, 0x9f, 0xe9, 0x02, 0x84, 0xbb,
		0x80, 0xc6, 0xf6, 0x7e, 0x63, 0x7f, 0x77, 0x6f, 0x7b, 0x7f, 0x87, 0xbe, 0x80, 0x09, 0x09, 0xad,
		0x7f, 0xf8, 0x3a, 0x67, 0xb9, 0x9f, 0xb1, 0xee, 0x19, 0x37, 0xf3, 0xc9, 0x84, 0xd7, 0x1f, 0x52,
		0xfc, 0x7a, 0xff, 0xfc, 0x3a, 0x58, 0xf0, 0x2f, 0xc3, 0x7c, 0x16, 0xfc, 0x05, 0xad, 0x04, 0x16,
		0xfc, 0xe5, 0x2c, 0x6b, 0x16, 0xfc, 0x85, 0x5f, 0x10, 0x0b, 0xfe, 0xa4, 0xa6, 0x1f, 0x94, 0x8e,
		0xae, 0x82, 0xff, 0x2b, 0x05, 0xf5, 0xfe, 0x1d, 0xd6, 0xfb, 0x4b, 0x7e, 0xb1, 0xde, 0xcf, 0xbc,
		0x22, 0xc7, 0xcb, 0x61, 0xbd, 0x9f, 0xd1, 0xbc, 0x08, 0x17, 0xc0, 0x7a, 0xbf, 0x78, 0x17, 0xb0,
		0xbd, 0xc3, 0x42, 0x3f, 0x13, 0x11, 0x5a, 0xff, 0xd5, 0x8b, 0x85, 0x7e, 0x5a, 0x0c, 0x1f, 0x92,
		0xa5, 0x9f, 0x45, 0xf9, 0x4d, 0xfb, 0x75, 0x9e, 0x55, 0x39, 0x3b, 0xfd, 0x6e, 0xfe, 0xb5, 0xfe,
		0xf5, 0x94, 0xfa, 0xaf, 0xff, 0x5a, 0x47, 0x9c, 0x57, 0xb6, 0xa1, 0xed, 0xdc, 0xcb, 0xd9, 0xfd,
		0x9a, 0x7f, 0xf5, 0xed, 0xc5, 0x0d, 0xea, 0x87, 0x83, 0xe4, 0xab, 0xbf, 0x49, 0x3c, 0x21, 0x53,
		0x8f, 0xff, 0x05, 0xf2, 0xbd, 0xa0, 0x9d, 0x5f, 0xd0, 0x1d, 0x5f, 0xa0, 0xd9, 0x19, 0xa7, 0x24,
		0x96, 0x29, 0x74, 0x4e, 0x49, 0x2c, 0x6f, 0xb9, 0x72, 0x4a, 0xa2, 0xb4, 0x64, 0x81, 0x53, 0x12,
		0xc9, 0x34, 0x7f, 0x2d, 0x11, 0xd8, 0x07, 0xb5, 0x99, 0xc7, 0x1f, 0x9a, 0xe0, 0x2a, 0x36, 0x57,
		0x88, 0x1e, 0x7f, 0x31, 0x20, 0x07, 0xb0, 0x17, 0xcb, 0xea, 0xce, 0x53, 0xf8, 0x17, 0x2f, 0x66,
		0x29, 0x6d, 0x7d, 0x86, 0x98, 0x4c, 0x95, 0x2a, 0x6c, 0x29, 0xca, 0x8c, 0xfe, 0xb7, 0xe6, 0x1e,
		0x2d, 0x29, 0xc2, 0x1c, 0x89, 0x84, 0x3b, 0x02, 0x49, 0xd5, 0xc8, 0x23, 0xcc, 0x11, 0x47, 0x28,
		0xde, 0x04, 0xb4, 0x24, 0x5f, 0xf9, 0x52, 0x3c, 0xd2, 0xd1, 0x54, 0x55, 0x2c, 0xbe, 0x63, 0xb0,
		0xe4, 0x17, 0x1e, 0x80, 0xa9, 0xd9, 0xcb, 0xa3, 0x79, 0xf7, 0x0a, 0x7a, 0x75, 0x84, 0xb3, 0x95,
		0x2b, 0xe2, 0xbf, 0x65, 0xbb, 0x6c, 0xb9, 0x8e, 0x50, 0xb0, 0x13, 0xb4, 0x82, 0xc1, 0x4d, 0x18,
		0xd5, 0xae, 0xe3, 0xd1, 0xf8, 0x56, 0xbc, 0x07, 0x7c, 0x70, 0x9c, 0xee, 0xd2, 0x68, 0xe1, 0x01,
		0x06, 0xe3, 0x2c, 0x38, 0x98, 0xa7, 0x9a, 0x48, 0x4f, 0x31, 0x01, 0x9f, 0x5a, 0xa2, 0x3d, 0xa5,
		0x84, 0x7d, 0x2a, 0x09, 0xfb, 0x14, 0x12, 0xf3, 0xa9, 0x23, 0x93, 0xa4, 0x9f, 0xb9, 0xe5, 0x28,
		0x67, 0xad, 0x81, 0x1d, 0x76, 0x0b, 0x79, 0xc8, 0x2d, 0xd8, 0xe1, 0xb6, 0x70, 0xdb, 0xb5, 0x10,
		0xb7, 0x69, 0x01, 0x6f, 0xcf, 0x42, 0xdd, 0x96, 0x05, 0xbf, 0x1d, 0x0b, 0x7e, 0x1b, 0x16, 0xf6,
		0xf6, 0x2b, 0xee, 0x38, 0xa8, 0x22, 0x20, 0x65, 0x06, 0x23, 0x55, 0x7d, 0x9e, 0x8d, 0x36, 0x38,
		0x55, 0xa0, 0xe7, 0x20, 0x8a, 0x7b, 0xdf, 0x09, 0x55, 0x8a, 0xe1, 0x0a, 0x1d, 0xb2, 0xd4, 0xc0,
		0x96, 0x1a, 0xe8, 0xd2, 0x01, 0x5f, 0x58, 0x10, 0x06, 0x06, 0x63, 0x99, 0x44, 0xf0, 0xf7, 0xbe,
		0xc3, 0x9e, 0x46, 0x02, 0x7c, 0x0a, 0x09, 0xf8, 0x34, 0x32, 0xec, 0xf3, 0x54, 0x15, 0x8c, 0x3d,
		0x55, 0x31, 0x72, 0x48, 0xcb, 0xb4, 0x31, 0x4d, 0x03, 0x86, 0xbe, 0x60, 0x1f, 0x30, 0xcc, 0xa5,
		0x2d, 0x6c, 0x69, 0x6b, 0x39, 0x35, 0x44, 0xd5, 0x1a, 0xe7, 0x10, 0xab, 0x42, 0x5e, 0xe7, 0x4c,
		0xbc, 0x72, 0x5c, 0x90, 0xd0, 0xc7, 0xfb, 0xe3, 0x1f, 0xeb, 0xaf, 0xf2, 0x38, 0x7f, 0xec, 0x63,
		0xfc, 0xd9, 0x89, 0x5c, 0x49, 0x8f, 0xc8, 0xde, 0x41, 0xd1, 0x5d, 0x26, 0xd9, 0xd3, 0x43, 0xb8,
		0xa9, 0x7d, 0xaa, 0x1b, 0x4e, 0x6e, 0xc2, 0xe8, 0xf5, 0xe4, 0xae, 0x20, 0x4d, 0xe7, 0x63, 0x9b,
		0xa0, 0x6a, 0x87, 0xce, 0x36, 0x41, 0xd9, 0x0e, 0x9c, 0x3d, 0x82, 0x32, 0x5c, 0x36, 0x1b, 0x04,
		0xd5, 0xb9, 0x3f, 0x2b, 0xb8, 0x0b, 0xc2, 0x61, 0x70, 0x31, 0x34, 0xb5, 0x8b, 0x20, 0x1a, 0x7c,
		0x0a, 0x07, 0x53, 0x9f, 0x82, 0xd2, 0x28, 0xf8, 0x84, 0xf1, 0x6c, 0x18, 0x5c, 0x87, 0x99, 0x6c,
		0x18, 0xcc, 0x51, 0xb6, 0x6c, 0x18, 0xcc, 0x6f, 0x79, 0xb1, 0x61, 0xb0, 0x68, 0x76, 0x66, 0xc3,
		0x60, 0xd5, 0xd2, 0x25, 0x36, 0x0c, 0xe6, 0x1b, 0x1f, 0xd8, 0x30, 0x48, 0xb0, 0x41, 0x04, 0x1c,
		0x60, 0xd0, 0x41, 0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07, 0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10,
		0x30, 0x82, 0x03, 0xa4, 0xcc, 0x60, 0x9c, 0xda, 0xcf, 0xb3, 0xb1, 0x06, 0xa5, 0x02, 0xf4, 0x1c,
		0x40, 0xb1, 0x59, 0x90, 0x40, 0xa5, 0x18, 0xac, 0xd0, 0x01, 0x4b, 0x0d, 0x68, 0xa9, 0x01, 0x2e,
		0x1d, 0xe0, 0x85, 0x05, 0x60, 0x60, 0x20, 0x96, 0x49, 0x04, 0xbf, 0x59, 0x30, 0x34, 0xc6, 0x5c,
		0x0d, 0x47, 0x01, 0x76, 0xc7, 0xe0, 0x3e, 0xa0, 0xe9, 0x2d, 0x13, 0x5d, 0x4f, 0xc1, 0x98, 0x2d,
		0x83, 0x05, 0x7f, 0xf2, 0x6c, 0x19, 0x94, 0x73, 0x19, 0x59, 0x5f, 0x11, 0xdb, 0x89, 0x18, 0x84,
		0xd7, 0xb0, 0xb4, 0xd9, 0x32, 0xc8, 0xa5, 0xcd, 0xa5, 0xad, 0x23, 0x1b, 0xc0, 0xb5, 0xfa, 0x9c,
		0x7d, 0x46, 0x55, 0x0f, 0x4d, 0x56, 0x8a, 0x98, 0x1b, 0x66, 0x79, 0xe1, 0xd4, 0x7a, 0x56, 0xbc,
		0x8b, 0x30, 0x9b, 0x15, 0xef, 0x12, 0x75, 0xce, 0x8a, 0x77, 0x79, 0xcb, 0x95, 0x15, 0x6f, 0x61,
		0x17, 0xc2, 0x8a, 0x37, 0x89, 0xe6, 0x1b, 0x12, 0x51, 0x50, 0xf1, 0x1e, 0x98, 0x28, 0x0d, 0xd3,
		0x7b, 0xf0, 0xe3, 0xe1, 0x11, 0xa7, 0x31, 0xb8, 0xf3, 0x8f, 0xfe, 0x30, 0x48, 0x80, 0xe3, 0xd6,
		0x42, 0x48, 0x6e, 0xdf, 0xed, 0xfb, 0xfd, 0xd3, 0x43, 0xaf, 0x75, 0xe6, 0x7b, 0xef, 0xbb, 0x0e,
		0x6a, 0xf8, 0x9a, 0xd6, 0x69, 0x12, 0xd8, 0x07, 0x11, 0x1b, 0xd0, 0x0f, 0x23, 0x1e, 0x29, 0xca,
		0xef, 0x39, 0xf6, 0xd1, 0x1b, 0xfb, 0xd0, 0x6d, 0xb9, 0xde, 0xfb, 0xb9, 0xb8, 0xfa, 0xc8, 0xea,
		0xd2, 0xa4, 0x32, 0x1d, 0x6a, 0xfb, 0xa6, 0xea, 0x0e, 0xed, 0x76, 0xf3, 0xdf, 0x6e, 0xd3, 0x7b,
		0xe3, 0x1f, 0x75, 0xda, 0x7d, 0xaf, 0x67, 0xbb, 0x6d, 0xaf, 0x6f, 0xc1, 0x5f, 0xf3, 0x97, 0x5f,
		0x29, 0x3c, 0xd9, 0xc2, 0x3b, 0xf5, 0xdc, 0x96, 0xfb, 0x1f, 0xa7, 0xb9, 0x54, 0x20, 0x55, 0x47,
		0xd5, 0xe5, 0xad, 0x3a, 0xbb, 0xf9, 0x9b, 0xdf, 0x77, 0x9b, 0x94, 0x1a, 0xa5, 0x96, 0xbb, 0xd4,
		0xce, 0x6c, 0xb7, 0x65, 0x1f, 0xb6, 0x1c, 0x7a, 0x38, 0xca, 0xae, 0x38, 0xd9, 0xb9, 0xdd, 0xb3,
		0x5d, 0xbf, 0xed, 0xb8, 0xaf, 0xdf, 0x1c, 0x76, 0x7a, 0xbe, 0xdd, 0x6c, 0xf6, 0x9c, 0x3e, 0x81,
		0x8e, 0xc2, 0xcb, 0x1f, 0xe8, 0xda, 0x59, 0x06, 0xe1, 0x34, 0xfd, 0x56, 0xbf, 0x4b, 0xd1, 0x51,
		0x74, 0x79, 0x8b, 0xae, 0xe5, 0xb6, 0xdf, 0xfa, 0xb6, 0xe7, 0xf5, 0xdc, 0xc3, 0x53, 0xcf, 0xa1,
		0x9f, 0xa3, 0xe4, 0x8a, 0x91, 0x5c, 0xb7, 0xd7, 0xf1, 0x9c, 0x23, 0xcf, 0xed, 0xb4, 0x67, 0xf5,
		0x3a, 0xea, 0x8e, 0xba, 0xcb, 0x3d, 0x75, 0x3d, 0x71, 0xdb, 0xfe, 0xeb, 0x5e, 0xe7, 0x94, 0x91,
		0x95, 0x72, 0x2b, 0x26, 0x8f, 0x70, 0xdb, 0x9e, 0xd3, 0x3b, 0xb6, 0x8f, 0x1c, 0x26, 0x12, 0x54,
		0x5e, 0x51, 0xca, 0x3b, 0xb1, 0xdf, 0xcd, 0x82, 0x2c, 0xeb, 0x26, 0x54, 0x5d, 0x81, 0xe1, 0xf5,
		0x37, 0xbf, 0x65, 0xb7, 0x59, 0x1d, 0xa6, 0xdc, 0x0a, 0xcb, 0x22, 0x28, 0x35, 0x4a, 0xad, 0x10,
		0x92, 0x6b, 0xb0, 0x22, 0x4c, 0xe1, 0x95, 0x23, 0x3c, 0xa6, 0x10, 0x54, 0x5e, 0x29, 0x29, 0x44,
		0xcf, 0xe9, 0x3b, 0xbd, 0x33, 0x3e, 0x80, 0xa5, 0xf6, 0x8a, 0xd5, 0x9e, 0xe7, 0xf8, 0x4d, 0xe7,
		0xd8, 0x3e, 0x6d, 0x79, 0xfe, 0x89, 0xe3, 0xf5, 0xdc, 0x23, 0x8a, 0x8e, 0xa2, 0xcb, 0x5b, 0x74,
		0xa7, 0xed, 0x99, 0xbb, 0xe3, 0x7e, 0x3a, 0xea, 0xae, 0xf0, 0x34, 0xb6, 0xe9, 0xb4, 0xec, 0xf7,
		0xfe, 0x99, 0xdd, 0x73, 0x6d, 0xcf, 0xed, 0xb4, 0xa9, 0x3b, 0xea, 0x2e, 0x6f, 0xdd, 0x39, 0xef,
		0x3c, 0xa7, 0xdd, 0x74, 0x9a, 0x7c, 0x2a, 0x46, 0xdd, 0x15, 0x9a, 0x58, 0xb8, 0xed, 0xe5, 0xf3,
		0x89, 0xa9, 0xdf, 0xa3, 0xea, 0xa8, 0xba, 0x42, 0xa2, 0x6c, 0xab, 0xc3, 0xda, 0x09, 0xc5, 0x56,
		0x24, 0xd2, 0x51, 0x6d, 0x54, 0x5b, 0xde, 0x6a, 0xeb, 0x39, 0x7d, 0xb7, 0x79, 0x6a, 0xb7, 0x54,
		0xa5, 0xad, 0xd0, 0x57, 0x70, 0xce, 0x59, 0x96, 0x5c, 0xe5, 0x6b, 0x5a, 0xdd, 0xca, 0xba, 0x8b,
		0x29, 0x30, 0x69, 0x02, 0xd3, 0xd4, 0x45, 0x4c, 0x75, 0x49, 0x53, 0x17, 0x7c, 0xb7, 0x30, 0x25,
		0x25, 0x4e, 0x52, 0x9a, 0xba, 0x82, 0x29, 0x2f, 0x69, 0xf2, 0x52, 0xd6, 0xfd, 0x4b, 0x81, 0x89,
		0x03, 0x2e, 0x3d, 0x5d, 0xbe, 0x14, 0x97, 0x34, 0x71, 0xa9, 0xe9, 0xe6, 0xa5, 0xb4, 0x44, 0x4a,
		0x4b, 0x4d, 0xd7, 0x2e, 0xf5, 0x25, 0x2f, 0x55, 0x54, 0xb0, 0x0f, 0x81, 0xb2, 0x12, 0xc9, 0xf3,
		0x8a, 0xb6, 0xd0, 0x53, 0x61, 0xd2, 0x14, 0xa6, 0xa9, 0xdb, 0x96, 0xea, 0x92, 0x17, 0x16, 0x15,
		0x74, 0xd5, 0x52, 0x56, 0x22, 0x69, 0x9e, 0x92, 0xa2, 0xa4, 0xd6, 0x4a, 0x5a, 0x0d, 0x56, 0x4e,
		0x29, 0xb0, 0x7c, 0x05, 0x46, 0x94, 0xa7, 0xc2, 0x72, 0x45, 0x79, 0x5d, 0x5d, 0xaf, 0xd4, 0x98,
		0x34, 0x8d, 0x29, 0xea, 0x6e, 0xa5, 0xb8, 0xa4, 0x89, 0x4b, 0x57, 0x17, 0x2b, 0xf5, 0x25, 0x32,
		0x6d, 0x54, 0xd3, 0xad, 0x4a, 0x7d, 0x49, 0xd3, 0x97, 0xae, 0xae, 0x54, 0xea, 0x4b, 0x1c, 0xe0,
		0x2b, 0xea, 0x3e, 0xa5, 0xba, 0x44, 0x46, 0x47, 0xec, 0x2e, 0x53, 0x8a, 0x4a, 0x2e, 0x72, 0x51,
		0x55, 0x54, 0xd5, 0xba, 0x54, 0xa5, 0xa9, 0x6b, 0x94, 0xea, 0x2a, 0x5d, 0x5d, 0x5d, 0x9e, 0xc4,
		0x4b, 0xb5, 0x95, 0xad, 0x3a, 0xcf, 0x7e, 0xbd, 0xdb, 0xe0, 0xc8, 0x05, 0x0a, 0x2d, 0x6f, 0xa1,
		0x75, 0x7b, 0xce, 0xb1, 0xfb, 0x8e, 0x83, 0xee, 0xa9, 0xb6, 0x22, 0xd4, 0x36, 0xdd, 0xc1, 0xda,
		0xeb, 0x9c, 0x7a, 0x4e, 0x8f, 0xf3, 0xee, 0xa9, 0xb8, 0x62, 0x02, 0x29, 0x65, 0x46, 0x99, 0x15,
		0x14, 0x46, 0x8f, 0x5b, 0xf6, 0x6b, 0xce, 0x65, 0xa3, 0xde, 0x8a, 0x08, 0xa4, 0x0d, 0x55, 0x81,
		0x94, 0x53, 0xb2, 0xb8, 0xd2, 0xab, 0xb4, 0xc2, 0xb5, 0x66, 0xfe, 0x14, 0x14, 0x33, 0x7c, 0xaa,
		0x4a, 0xbf, 0xaa, 0xb4, 0x64, 0xf2, 0x54, 0x16, 0x33, 0x76, 0xca, 0x49, 0x7f, 0xf8, 0x03, 0xcf,
		0xcc, 0xa9, 0x2b, 0x66, 0xe0, 0x54, 0x96, 0x4e, 0x65, 0xcd, 0x45, 0x74, 0x64, 0x77, 0xb9, 0xe7,
		0x80, 0x7a, 0x2b, 0x55, 0x77, 0x3d, 0xdf, 0x6e, 0xbd, 0xee, 0xf4, 0x5c, 0xef, 0xcd, 0x09, 0xab,
		0xd8, 0x54, 0x5c, 0x21, 0x8a, 0x5b, 0xfe, 0x8d, 0x65, 0xec, 0x72, 0x5f, 0x2c, 0x63, 0x73, 0x89,
		0x33, 0x98, 0x50, 0x59, 0x0c, 0x1a, 0x0c, 0x16, 0x8a, 0x82, 0x04, 0xd6, 0xe7, 0x8c, 0x63, 0x2d,
		0x86, 0xa5, 0x20, 0x0e, 0xdc, 0xb2, 0xa3, 0x68, 0x94, 0x06, 0x69, 0x38, 0x8a, 0xac, 0x03, 0x20,
		0xd7, 0x6d, 0x25, 0x97, 0x1f, 0xcc, 0x4d, 0x70, 0x1b, 0xa4, 0x1f, 0x26, 0xce, 0xba, 0x3e, 0xba,
		0x35, 0xd1, 0xe5, 0x28, 0xba, 0x0a, 0xaf, 0x6b, 0x91, 0x49, 0x3f, 0x8d, 0xe2, 0x8f, 0xb5, 0x30,
		0x4a, 0xd2, 0x20, 0xba, 0x34, 0xf5, 0xc7, 0x6f, 0x24, 0x2b, 0xef, 0xd4, 0x6f, 0xe3, 0x51, 0x3a,
		0xba, 0x1c, 0x0d, 0x93, 0xec, 0xbb, 0x7a, 0x98, 0x84, 0x49, 0x7d, 0x68, 0xee, 0xcc, 0x70, 0xfe,
		0xa5, 0x3e, 0x0c, 0xa3, 0x8f, 0xb5, 0x24, 0x0d, 0x52, 0x53, 0x1b, 0x04, 0x69, 0x70, 0x11, 0x24,
		0xa6, 0x3e, 0x4c, 0x6e, 0xeb, 0xe9, 0xf0, 0x2e, 0x99, 0xfc, 0x51, 0xbf, 0x49, 0x6b, 0x93, 0x9f,
		0xaa, 0x45, 0x26, 0xbc, 0xfe, 0x70, 0x31, 0x8a, 0x6b, 0x41, 0x9a, 0xc6, 0xe1, 0xc5, 0x38, 0x9d,
		0xd8, 0x30, 0x7b, 0x2b, 0xc9, 0xbe, 0xab, 0x2f, 0xcd, 0xc9, 0xcc, 0x48, 0xc6, 0x17, 0xd3, 0x7f,
		0x6c, 0xf6, 0xb5, 0x1e, 0xdc, 0x05, 0xe1, 0x30, 0xb8, 0x18, 0x9a, 0xda, 0x45, 0x10, 0x0d, 0x3e,
		0x85, 0x83, 0xf4, 0x43, 0x7d, 0xfa, 0xfb, 0x81, 0x8a, 0x33, 0x56, 0x92, 0xc6, 0xe3, 0xcb, 0x34,
		0x9a, 0x47, 0xd5, 0x4e, 0x76, 0x9f, 0xda, 0xb3, 0x7b, 0xe0, 0xce, 0xaf, 0xdd, 0x7f, 0xf4, 0xf7,
		0xe4, 0xf1, 0x1b, 0x7e, 0x77, 0x71, 0x8f, 0xb2, 0xef, 0x7c, 0x37, 0x09, 0x13, 0xbf, 0x35, 0xbd,
		0x47, 0xb3, 0x2f, 0x7e, 0x2b, 0x8c, 0x3e, 0xf6, 0x27, 0x1f, 0x51, 0x73, 0x7e, 0x87, 0xfc, 0x56,
		0x72, 0xeb, 0x7b, 0xc3, 0xbb, 0x64, 0xf2, 0x87, 0x7f, 0x92, 0x4e, 0x7e, 0xa4, 0x3d, 0xbf, 0x05,
		0xf6, 0xe2, 0xf6, 0xf8, 0x8b, 0x77, 0x92, 0xec, 0x3b, 0x7f, 0x69, 0x48, 0x66, 0x41, 0x7f, 0x76,
		0x7b, 0xe6, 0x5f, 0x7d, 0x7b, 0x71, 0x7b, 0x0e, 0x17, 0x77, 0xc7, 0x9f, 0xfe, 0x6a, 0x0c, 0x34,
		0x90, 0xef, 0x46, 0x65, 0x5b, 0x28, 0xdc, 0xc1, 0xa3, 0x39, 0xf6, 0xaa, 0x3a, 0x74, 0x00, 0x57,
		0x5e, 0x29, 0x17, 0x2e, 0xdb, 0x79, 0xcb, 0x75, 0x89, 0x82, 0xdd, 0xa1, 0x95, 0x2d, 0xb6, 0xda,
		0xe5, 0x28, 0x4a, 0xd2, 0x38, 0x08, 0xa3, 0x34, 0x11, 0xef, 0x15, 0xb3, 0x4a, 0xc4, 0xd3, 0xe6,
		0x0b, 0x0f, 0x3f, 0x6f, 0xc3, 0x68, 0x60, 0x1d, 0x6c, 0x6c, 0x09, 0x37, 0xf3, 0x68, 0xea, 0xc8,
		0xac, 0x83, 0x8d, 0x4d, 0xe1, 0x86, 0x76, 0x63, 0x73, 0x15, 0x7e, 0xc6, 0x08, 0xe5, 0x0b, 0xe1,
		0x8e, 0x2e, 0xa7, 0xe1, 0x13, 0x21, 0xc4, 0xf5, 0x47, 0xe3, 0xf8, 0xd2, 0xc0, 0xa4, 0xc0, 0xd6,
		0x5b, 0x73, 0xff, 0x69, 0x14, 0x4f, 0x56, 0x98, 0x75, 0x3b, 0x53, 0x06, 0x48, 0xbd, 0xe1, 0x4d,
		0x90, 0xd8, 0xf1, 0xf5, 0xf8, 0xc6, 0x44, 0xa9, 0x75, 0xb0, 0x91, 0xc6, 0x63, 0x83, 0x52, 0x28,
		0x59, 0x5a, 0x9d, 0x09, 0x9b, 0x29, 0x94, 0xea, 0x14, 0xaa, 0x19, 0xc6, 0x18, 0x0e, 0xf7, 0x29,
		0x42, 0xc0, 0xf1, 0x65, 0x7f, 0xc5, 0x39, 0x28, 0x6e, 0x0d, 0x03, 0x77, 0xe0, 0xb0, 0x07, 0x11,
		0x7f, 0x80, 0x31, 0x08, 0x15, 0x87, 0xe0, 0xb1, 0x08, 0x1e, 0x8f, 0xb0, 0x31, 0x09, 0x03, 0x97,
		0x40, 0xb0, 0x09, 0x0e, 0x9f, 0x32, 0x83, 0x91, 0xaa, 0x43, 0xcf, 0x46, 0x1b, 0x9c, 0x1a, 0x11,
		0x38, 0x44, 0xc1, 0xc2, 0x14, 0x32, 0x54, 0x29, 0x80, 0x2b, 0x74, 0xc8, 0x52, 0x03, 0x5b, 0x6a,
		0xa0, 0x4b, 0x07, 0x7c, 0x61, 0x41, 0x18, 0x18, 0x8c, 0xc1, 0x42, 0xd9, 0x13, 0x70, 0x86, 0xeb,
		0x31, 0x57, 0x19, 0x0d, 0xd5, 0x65, 0x62, 0xa2, 0x1a, 0x3c, 0xb2, 0x69, 0x40, 0x37, 0x45, 0x08,
		0xa7, 0x05, 0xe5, 0xd4, 0x21, 0x9d, 0x3a, 0xb4, 0xd3, 0x85, 0x78, 0x98, 0xa8, 0x07, 0x8a, 0x7c,
		0xf0, 0xe8, 0xf7, 0x04, 0x02, 0xd6, 0xc2, 0x01, 0xbe, 0xb3, 0x5d, 0xa5, 0xc1, 0xc9, 0x65, 0x81,
		0xfb, 0xa7, 0x39, 0x18, 0x6e, 0x82, 0x5f, 0x06, 0x3a, 0x20, 0x6a, 0x02, 0x45, 0x85, 0xc0, 0xa8,
		0x0d, 0x1c, 0xd5, 0x02, 0xa4, 0x5a, 0x90, 0xd4, 0x09, 0x94, 0xd8, 0x60, 0x09, 0x0e, 0x98, 0x99,
		0xa4, 0xbc, 0xfb, 0x5b, 0xa3, 0x2b, 0xe2, 0x0c, 0x4d, 0x70, 0x15, 0x9b, 0x2b, 0x0d, 0x11, 0x67,
		0x51, 0xb9, 0xdb, 0x53, 0x70, 0x2d, 0xdd, 0x79, 0xb7, 0xd8, 0x8b, 0x17, 0xb3, 0xbe, 0xd8, 0xfa,
		0xd7, 0x28, 0xfd, 0x0b, 0x5d, 0x18, 0xdd, 0xd7, 0xf7, 0x29, 0x6a, 0xd6, 0x5e, 0xad, 0x26, 0xb5,
		0x44, 0xeb, 0x16, 0xff, 0x4b, 0x8f, 0xc5, 0x94, 0x92, 0x29, 0x25, 0x53, 0x4a, 0xa6, 0x94, 0x4c,
		0x29, 0x99, 0x52, 0x92, 0xc7, 0xaa, 0x95, 0x52, 0xa2, 0x3f, 0xbb, 0xc8, 0x2e, 0x64, 0x39, 0xf8,
		0xe1, 0x40, 0xdb, 0x98, 0x55, 0xa4, 0x99, 0x16, 0xdf, 0x03, 0x9e, 0x9b, 0x4a, 0x2e, 0x47, 0x0b,
		0x80, 0x6a, 0x04, 0x51, 0xc5, 0x40, 0xaa, 0x15, 0x4c, 0xd5, 0x03, 0xaa, 0x7a, 0x50, 0xd5, 0x0d,
		0xac, 0x3a, 0xc0, 0x55, 0x09, 0xc0, 0x66, 0x52, 0x53, 0xf3, 0x6c, 0x64, 0x25, 0x62, 0x85, 0xc6,
		0x98, 0xab, 0xe1, 0x28, 0x48, 0x5f, 0x6e, 0x6b, 0x8a, 0x5a, 0x73, 0x08, 0xdc, 0x57, 0x74, 0x49,
		0x2d, 0x13, 0x5d, 0x4f, 0x13, 0x90, 0xdf, 0x55, 0xb9, 0x71, 0x5d, 0x58, 0x31, 0xbd, 0x53, 0x27,
		0x61, 0xa4, 0x8e, 0x97, 0x94, 0xa6, 0x57, 0x2b, 0x97, 0x37, 0x3d, 0x81, 0xc8, 0x3a, 0xd8, 0x68,
		0x28, 0xbd, 0xbe, 0xe3, 0x38, 0xb8, 0x4c, 0xc3, 0x51, 0xd4, 0x0c, 0xaf, 0xc3, 0x69, 0xc3, 0xf4,
		0xa6, 0xba, 0xeb, 0xfc, 0xf2, 0xab, 0x42, 0x97, 0x12, 0x7c, 0xa6, 0x4b, 0xa1, 0x4b, 0xa1, 0x4b,
		0x61, 0x36, 0xc6, 0xab, 0x59, 0xbe, 0xce, 0x7f, 0xe1, 0xfd, 0x60, 0xc8, 0x5d, 0x8f, 0x1b, 0xd3,
		0xd5, 0xa7, 0xb2, 0x92, 0xe8, 0x6b, 0xea, 0x57, 0x51, 0x4a, 0x0e, 0x7c, 0xd6, 0x83, 0xb4, 0xa0,
		0xf8, 0xac, 0x07, 0xc7, 0x4d, 0xf0, 0x59, 0x0f, 0xf8, 0x05, 0xf2, 0x59, 0x0f, 0x19, 0xb0, 0x20,
		0xa9, 0xe9, 0x7d, 0xd6, 0x33, 0x0e, 0x23, 0x9d, 0x8f, 0x79, 0xf6, 0x14, 0x5d, 0x52, 0x2f, 0x88,
		0xae, 0x0d, 0x9f, 0xf2, 0xc8, 0xbf, 0x51, 0x7c, 0xca, 0x83, 0x7b, 0x79, 0x8b, 0x92, 0xec, 0x26,
		0x4b, 0xb2, 0xc4, 0x0d, 0x41, 0x2e, 0x85, 0x4f, 0x79, 0xe0, 0x5d, 0x4a, 0x63, 0x7b, 0xbf, 0xb1,
		0xbf, 0xbb, 0xb7, 0xbd, 0xbf, 0x43, 0xdf, 0xc2, 0x84, 0x8c, 0x57, 0xb3, 0xce, 0x17, 0x1f, 0xf7,
		0xf0, 0x0a, 0x2a, 0x4f, 0x0e, 0xa8, 0x87, 0xbf, 0x3f, 0x7b, 0x3d, 0x55, 0x38, 0x43, 0xf8, 0xc9,
		0xd3, 0x40, 0x9f, 0x7c, 0xb7, 0xfe, 0xf0, 0x7f, 0x78, 0xf0, 0xb6, 0x86, 0xa1, 0x00, 0x1b, 0xba,
		0xcf, 0x25, 0xce, 0x8e, 0x23, 0x3e, 0x5a, 0xde, 0xc2, 0xa7, 0xde, 0xf4, 0x1f, 0xfe, 0xf7, 0x07,
		0x6f, 0x03, 0x9d, 0x43, 0xaf, 0x2f, 0x32, 0x70, 0xaa, 0x69, 0xa1, 0xc9, 0xa0, 0xb9, 0xd7, 0xb2,
		0x29, 0xc1, 0x6a, 0x85, 0x49, 0x3a, 0xf1, 0x1c, 0xd8, 0x63, 0x5a, 0x4f, 0xc2, 0xc8, 0x19, 0x9a,
		0x1b, 0x33, 0x3b, 0x46, 0x09, 0x38, 0x4b, 0xb7, 0x4e, 0x82, 0xcf, 0x0f, 0xae, 0x64, 0xeb, 0x55,
		0xa3, 0xb1, 0xbb, 0xd7, 0x68, 0x6c, 0xee, 0xbd, 0xdc, 0xdb, 0xdc, 0xdf, 0xd9, 0xd9, 0xda, 0xdd,
		0x02, 0xce, 0xcc, 0xad, 0x4e, 0x3c, 0x30, 0xb1, 0x19, 0x1c, 0x4e, 0x96, 0x4f, 0x34, 0x1e, 0x0e,
		0xe9, 0xb5, 0x48, 0xde, 0x24, 0xee, 0x3c, 0x88, 0xdb, 0x82, 0x1e, 0x88, 0x46, 0xc6, 0x7e, 0x92,
		0xb1, 0x31, 0xe9, 0xfa, 0x0b, 0x8f, 0x83, 0x62, 0x3c, 0xd2, 0x13, 0x87, 0x18, 0x7f, 0x9e, 0x8d,
		0x3f, 0x88, 0x27, 0x22, 0x32, 0xd8, 0x3c, 0x0c, 0x36, 0x58, 0x11, 0x06, 0xc7, 0x4f, 0x03, 0xf9,
		0x68, 0xeb, 0x66, 0x34, 0x30, 0x43, 0xc4, 0x2e, 0x92, 0x6c, 0xab, 0x60, 0x76, 0x05, 0x98, 0x87,
		0x11, 0x6f, 0xf2, 0x30, 0xe2, 0x62, 0x0c, 0xe7, 0x61, 0xc4, 0xa5, 0x5e, 0x02, 0x0f, 0x23, 0x16,
		0x72, 0x21, 0x3c, 0x8c, 0x98, 0x54, 0x53, 0x95, 0xec, 0x13, 0xb6, 0x41, 0x42, 0xc1, 0xc1, 0x20,
		0xc8, 0x07, 0x81, 0xac, 0x1e, 0xfc, 0x91, 0x51, 0x26, 0x73, 0xa6, 0xca, 0xe7, 0x4c, 0x98, 0x67,
		0x78, 0x40, 0x9f, 0xd9, 0x01, 0x7a, 0x46, 0x07, 0xb3, 0x25, 0x66, 0x4b, 0xcc, 0x96, 0x98, 0x2d,
		0x31, 0x5b, 0x62, 0xb6, 0x24, 0x5f, 0x22, 0xa8, 0x67, 0x60, 0xe0, 0x16, 0xb1, 0x57, 0x42, 0x16,
		0x68, 0x31, 0xfb, 0x31, 0xa6, 0x81, 0xee, 0xc9, 0x83, 0x9f, 0x6a, 0xa4, 0x61, 0x8a, 0x91, 0xa2,
		0xa9, 0x45, 0x5a, 0xa6, 0x14, 0xa9, 0x9b, 0x4a, 0xa4, 0x6e, 0x0a, 0x91, 0xae, 0xa9, 0x43, 0x6c,
		0x70, 0x28, 0x52, 0x3a, 0xf0, 0x53, 0x84, 0xbe, 0x9a, 0x1a, 0xf4, 0x0a, 0x39, 0x5e, 0xcc, 0xf1,
		0x09, 0x79, 0xd7, 0xbf, 0x8e, 0xa1, 0x40, 0x0a, 0x7a, 0x55, 0x35, 0x0d, 0xfd, 0xd1, 0x36, 0x3d,
		0x55, 0xd9, 0x50, 0x1f, 0x8d, 0x83, 0x36, 0x34, 0xcc, 0x89, 0xd6, 0x34, 0xa4, 0x47, 0xab, 0x0b,
		0xd8, 0xde, 0xd9, 0xa1, 0x13, 0x60, 0x22, 0x42, 0xeb, 0x1f, 0xbe, 0xce, 0xd9, 0xfb, 0x44, 0x8b,
		0xd1, 0x43, 0x32, 0x7b, 0x9f, 0x74, 0xf5, 0x3e, 0xa1, 0x8e, 0xb5, 0x61, 0xd7, 0x13, 0xe4, 0xbc,
		0x1a, 0xa0, 0xbd, 0x7b, 0xbf, 0x30, 0x7a, 0xac, 0x31, 0xcf, 0x99, 0xcd, 0x9b, 0x01, 0x7b, 0x12,
		0x8c, 0x39, 0x5a, 0x06, 0x77, 0x94, 0x8c, 0xaa, 0xd1, 0x31, 0x98, 0xa3, 0x62, 0x50, 0x1c, 0x0a,
		0x28, 0x86, 0x12, 0x3f, 0xbf, 0x7a, 0xd7, 0x82, 0xda, 0x20, 0x5f, 0x75, 0xe0, 0xc4, 0x40, 0x4d,
		0xf9, 0xe0, 0x26, 0xdb, 0x42, 0xe1, 0x11, 0x00, 0xcd, 0xf3, 0x57, 0xd7, 0xe3, 0x03, 0x38, 0xf7,
		0x8a, 0x39, 0x75, 0xd9, 0x0e, 0x5c, 0xae, 0x5b, 0x14, 0xec, 0x12, 0x2d, 0xf3, 0x39, 0x35, 0xd1,
		0xc0, 0x0c, 0x6a, 0xc1, 0xe0, 0x26, 0x8c, 0x6a, 0xd7, 0xf1, 0x68, 0x7c, 0x2b, 0xde, 0x31, 0x66,
		0x9b, 0x9b, 0x9e, 0xb4, 0x5e, 0x78, 0x00, 0xc2, 0xe8, 0xda, 0x83, 0xd9, 0xf6, 0x8d, 0xb4, 0xbd,
		0x1b, 0x70, 0x1b, 0x37, 0xda, 0x76, 0x6d, 0xd8, 0x6d, 0xd9, 0xb0, 0xdb, 0xaf, 0x31, 0xb7, 0x59,
		0x33, 0x89, 0xfa, 0x99, 0x5b, 0x8e, 0xd2, 0x15, 0x07, 0x36, 0x96, 0x00, 0x72, 0x1c, 0x01, 0xd8,
		0x18, 0x02, 0xb8, 0x7e, 0x36, 0xc4, 0xfe, 0x35, 0xe0, 0x7e, 0x35, 0xd4, 0xfe, 0x34, 0xf8, 0x7e,
		0x34, 0xf8, 0xfe, 0x33, 0xec, 0x7e, 0x33, 0x6e, 0x58, 0xa8, 0x22, 0x20, 0x65, 0x06, 0x43, 0xd6,
		0x81, 0x9e, 0x0d, 0x3b, 0x80, 0x75, 0xa1, 0xe7, 0xb0, 0x8a, 0xb3, 0x70, 0x89, 0x59, 0x8a, 0x71,
		0x0b, 0x1d, 0xbb, 0xd4, 0xe0, 0x97, 0x1a, 0x0c, 0xd3, 0x81, 0x63, 0x58, 0x58, 0x06, 0x86, 0x67,
		0x99, 0x44, 0xf0, 0x67, 0xe1, 0x8e, 0xc3, 0x28, 0x7d, 0xb9, 0x0d, 0x3c, 0x0a, 0x17, 0x71, 0x12,
		0x2e, 0x76, 0x3f, 0x3f, 0xf6, 0x29, 0x97, 0x0a, 0x06, 0x07, 0xa9, 0x68, 0xda, 0xd5, 0xd2, 0xaf,
		0xaf, 0xa9, 0x45, 0xf7, 0x0b, 0xf6, 0xb1, 0xaf, 0x5c, 0xda, 0xc2, 0x96, 0x76, 0x63, 0x7b, 0xbf,
		0xb1, 0xbf, 0xbb, 0xb7, 0xbd, 0xbf, 0xc3, 0x35, 0xce, 0x84, 0xa0, 0x5a, 0x56, 0x9f, 0x33, 0xf1,
		0xca, 0x71, 0x41, 0x42, 0x1f, 0xba, 0x8e, 0x7f, 0xd8, 0xba, 0xca, 0x43, 0xd6, 0xb1, 0x0f, 0x57,
		0x67, 0x6b, 0x73, 0x25, 0x3d, 0x22, 0x3b, 0x11, 0x05, 0xf7, 0xa5, 0x3c, 0xf5, 0x18, 0x11, 0x6e,
		0xe4, 0x85, 0xe2, 0x26, 0x15, 0x67, 0x7e, 0x7f, 0xec, 0xc9, 0xed, 0x79, 0x3d, 0xb9, 0x3b, 0x48,
		0x43, 0x2d, 0xd8, 0x69, 0xa8, 0xda, 0xc3, 0xb3, 0xd3, 0x10, 0xc4, 0xa3, 0xb3, 0xd1, 0x50, 0x96,
		0x0f, 0x67, 0x9b, 0xa1, 0x3a, 0x7f, 0x68, 0x85, 0xb7, 0x77, 0x8d, 0x5a, 0x18, 0xa5, 0x26, 0xbe,
		0x0a, 0x2e, 0x4d, 0x2d, 0x18, 0x0c, 0x62, 0x93, 0x24, 0x38, 0x8d, 0x86, 0xcf, 0xd8, 0xcf, 0x56,
		0xc3, 0x75, 0x98, 0xc9, 0x56, 0xc3, 0x1c, 0x95, 0xcb, 0x56, 0xc3, 0xfc, 0x96, 0x17, 0x5b, 0x0d,
		0x8b, 0x46, 0x6a, 0xb6, 0x1a, 0x56, 0x2d, 0x8b, 0x62, 0xab, 0x61, 0xbe, 0xf1, 0x81, 0xad, 0x86,
		0x04, 0x1b, 0x44, 0xc0, 0x01, 0x06, 0x1d, 0x54, 0xe0, 0x81, 0x07, 0x1f, 0x78, 0x00, 0xc2, 0x06,
		0x21, 0x0c, 0x20, 0x02, 0x01, 0x23, 0x38, 0x40, 0xca, 0x0c, 0x46, 0x29, 0xfe, 0x3c, 0x1b, 0x69,
		0x30, 0xaa, 0x3f, 0xcf, 0xc1, 0x13, 0x1b, 0x0a, 0x09, 0x53, 0x8a, 0xa1, 0x0a, 0x1d, 0xae, 0xd4,
		0x40, 0x96, 0x1a, 0xd8, 0xd2, 0x01, 0x5d, 0x58, 0xf0, 0x05, 0x06, 0x61, 0x99, 0x44, 0xf0, 0x1b,
		0x0a, 0xa7, 0x4f, 0xba, 0x30, 0x09, 0xe7, 0x21, 0xe5, 0x6c, 0xbd, 0x02, 0xb4, 0xbd, 0x1b, 0xa4,
		0xa9, 0x89, 0x23, 0xd8, 0xce, 0x42, 0xeb, 0x9f, 0xff, 0xfc, 0x7d, 0xb3, 0xb6, 0x7f, 0xfe, 0xbf,
		0xdf, 0xb7, 0x6a, 0xfb, 0xe7, 0xb3, 0x6f, 0xb7, 0xa6, 0x5f, 0x66, 0xdf, 0x6f, 0xff, 0xbe, 0x59,
		0x6b, 0x2c, 0xbe, 0xdf, 0xf9, 0x7d, 0xb3, 0xb6, 0x73, 0xfe, 0xaf, 0x3f, 0xfe, 0x78, 0xf1, 0xaf,
		0x3f, 0x5f, 0x7e, 0xf9, 0xfe, 0x1f, 0xc4, 0x73, 0xbd, 0xe7, 0x88, 0x92, 0xec, 0xf4, 0xdd, 0x77,
		0xf0, 0xba, 0xfc, 0x6f, 0x91, 0xc2, 0xfc, 0x87, 0xc5, 0x66, 0x17, 0x42, 0xc1, 0x03, 0xf5, 0xb1,
		0xd9, 0xa5, 0xe4, 0x2b, 0x60, 0xb3, 0x0b, 0x93, 0x10, 0xd5, 0x96, 0xb2, 0xd9, 0x25, 0x5f, 0xbb,
		0xab, 0xb0, 0x35, 0xfa, 0xe9, 0x2d, 0x8e, 0x6c, 0x77, 0x91, 0xb3, 0x55, 0xda, 0xbd, 0xbd, 0x6b,
		0xb8, 0x8b, 0x1b, 0x64, 0xcf, 0xee, 0x0f, 0x1b, 0x5e, 0xaa, 0x63, 0x21, 0x1b, 0x5e, 0xe8, 0xd5,
		0xd7, 0xe3, 0xd5, 0xd9, 0xf2, 0x22, 0xcd, 0x8f, 0xb3, 0xe9, 0x45, 0x9d, 0x4f, 0x9c, 0x95, 0xd2,
		0x97, 0x0b, 0x19, 0xb2, 0xe7, 0x65, 0xc5, 0x7c, 0xb6, 0xbc, 0xac, 0xc3, 0x4c, 0xb6, 0xbc, 0xe4,
		0x28, 0x5c, 0xb6, 0xbc, 0xe4, 0xb7, 0xbc, 0xd8, 0xf2, 0x52, 0x34, 0x54, 0xb3, 0xe5, 0xa5, 0x6a,
		0x79, 0x14, 0x5b, 0x5e, 0xf2, 0x8d, 0x0f, 0x6c, 0x79, 0x21, 0xd8, 0x20, 0x02, 0x0e, 0x30, 0xe8,
		0xa0, 0x02, 0x0f, 0x3c, 0xf8, 0xc0, 0x03, 0x10, 0x36, 0x08, 0x61, 0x00, 0x11, 0x08, 0x18, 0xc1,
		0x01, 0x52, 0x66, 0x30, 0x5b, 0x5e, 0x4a, 0x85, 0x27, 0xb6, 0xbc, 0x10, 0xa6, 0x14, 0x43, 0x15,
		0x3a, 0x5c, 0xa9, 0x81, 0x2c, 0x35, 0xb0, 0xa5, 0x03, 0xba, 0xb0, 0xe0, 0x0b, 0x0c, 0xc2, 0x32,
		0x89, 0xb0, 0xe5, 0x45, 0x08, 0xe5, 0xb0, 0xe5, 0xa5, 0x8c, 0x0b, 0x60, 0xcb, 0xcb, 0x5f, 0xbd,
		0xd8, 0xf2, 0x52, 0xd6, 0x55, 0xb0, 0xe5, 0xe5, 0x1b, 0xca, 0x24, 0x14, 0xe4, 0xa8, 0x3e, 0xb6,
		0xbc, 0x94, 0x7c, 0x05, 0x6c, 0x79, 0x61, 0x12, 0xa2, 0xda, 0x52, 0xb6, 0xbc, 0xe4, 0x6b, 0x77,
		0x65, 0x36, 0x47, 0x3f, 0xde, 0xe1, 0xc8, 0x8e, 0x17, 0x59, 0x3b, 0xa5, 0xb3, 0x7f, 0x8a, 0x0d,
		0x2f, 0x55, 0xb3, 0x90, 0x0d, 0x2f, 0xf4, 0xe9, 0x6b, 0xf1, 0xe9, 0xec, 0x77, 0x11, 0xe6, 0xc5,
		0xd9, 0xee, 0xa2, 0xce, 0x23, 0x5a, 0xe1, 0xed, 0xdd, 0x2e, 0xf8, 0x19, 0x2f, 0xbb, 0x3c, 0xe3,
		0x25, 0x27, 0x33, 0xd9, 0xf0, 0x92, 0xa3, 0x72, 0xd9, 0xf0, 0x92, 0xdf, 0xf2, 0x62, 0xc3, 0x4b,
		0xd1, 0x50, 0xcd, 0x86, 0x97, 0xaa, 0xe5, 0x51, 0x6c, 0x78, 0xc9, 0x37, 0x3e, 0xb0, 0xe1, 0x85,
		0x60, 0x83, 0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8, 0x20,
		0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x99, 0xc1, 0x6c, 0x78, 0x29, 0x15, 0x9e, 0xd8,
		0xf0, 0x42, 0x98, 0x52, 0x0c, 0x55, 0xe8, 0x70, 0xa5, 0x06, 0xb2, 0xd4, 0xc0, 0x96, 0x0e, 0xe8,
		0xc2, 0x82, 0x2f, 0x30, 0x08, 0xcb, 0x24, 0xa2, 0xa2, 0xe1, 0x65, 0x97, 0x0d, 0x2f, 0x25, 0x11,
		0x83, 0x8e, 0x86, 0x97, 0xa0, 0x76, 0x65, 0xd7, 0x8e, 0xcf, 0xff, 0xdc, 0xfa, 0xb5, 0xf1, 0xe5,
		0xe0, 0x5f, 0x7f, 0xee, 0x7d, 0x79, 0xfc, 0xe6, 0xff, 0x9e, 0xfa, 0xdf, 0xb6, 0x7e, 0xdd, 0xfb,
		0x72, 0xf0, 0xcc, 0x7f, 0xd9, 0xfd, 0x72, 0xf0, 0x37, 0xff, 0x8d, 0x9d, 0x2f, 0xff, 0x5c, 0xf9,
		0x5f, 0x27, 0xef, 0x6f, 0x3f, 0xf7, 0x03, 0x8d, 0x67, 0x7e, 0xe0, 0xe5, 0x73, 0x3f, 0xf0, 0xf2,
		0x99, 0x1f, 0x78, 0xd6, 0xa4, 0xed, 0x67, 0x7e, 0x60, 0xe7, 0xcb, 0xff, 0x56, 0xfe, 0xff, 0x7f,
		0x3e, 0xfd, 0xbf, 0xee, 0x7e, 0xf9, 0xd7, 0xff, 0x9e, 0xfb, 0x6f, 0x7b, 0x5f, 0xfe, 0x77, 0xf0,
		0x2f, 0xb6, 0xff, 0x14, 0xb3, 0x40, 0x35, 0xb5, 0xff, 0x70, 0x99, 0x16, 0xbf, 0x4c, 0xd9, 0x0c,
		0x45, 0x60, 0xfc, 0x6a, 0x2d, 0xb2, 0x19, 0xaa, 0xe4, 0x2b, 0x60, 0x33, 0x14, 0x13, 0x54, 0xd5,
		0x96, 0xb2, 0x19, 0x2a, 0x5f, 0xbb, 0x2b, 0xb2, 0x71, 0x7e, 0x97, 0xe7, 0xff, 0x08, 0xdf, 0x47,
		0xbf, 0xcb, 0xf3, 0x7f, 0xaa, 0x6b, 0x21, 0xdb, 0xa1, 0xe8, 0xd5, 0xd7, 0xe3, 0xd5, 0xd9, 0x0f,
		0x25, 0xcd, 0x8f, 0xb3, 0x21, 0x4a, 0x9d, 0x4f, 0x9c, 0x3d, 0x66, 0x81, 0x3e, 0xff, 0x67, 0x97,
		0xe7, 0xff, 0xe4, 0x63, 0x26, 0xdb, 0xa1, 0x72, 0x14, 0x2e, 0xdb, 0xa1, 0xf2, 0x5b, 0x5e, 0x6c,
		0x87, 0x2a, 0x1a, 0xaa, 0xd9, 0x0e, 0x55, 0xb5, 0x3c, 0x8a, 0xed, 0x50, 0xf9, 0xc6, 0x07, 0xb6,
		0x43, 0x11, 0x6c, 0x10, 0x01, 0x07, 0x18, 0x74, 0x50, 0x81, 0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08,
		0x1b, 0x84, 0x30, 0x80, 0x08, 0x04, 0x8c, 0xe0, 0x00, 0x29, 0x33, 0x98, 0xed, 0x50, 0xa5, 0xc2,
		0x13, 0xdb, 0xa1, 0x08, 0x53, 0x8a, 0xa1, 0x0a, 0x1d, 0xae, 0xd4, 0x40, 0x96, 0x1a, 0xd8, 0xd2,
		0x01, 0x5d, 0x58, 0xf0, 0x05, 0x06, 0x61, 0x99, 0x44, 0xd8, 0x0e, 0x25, 0x84, 0x72, 0xd8, 0x0e,
		0x55, 0xc6, 0x05, 0xb0, 0xcf, 0x82, 0xed, 0x50, 0x7f, 0xf7, 0xc5, 0x76, 0xa8, 0xb2, 0xae, 0x82,
		0xed, 0x50, 0x6c, 0x87, 0xfa, 0x8e, 0x75, 0x4a, 0x60, 0xcc, 0x71, 0x2d, 0xb2, 0x1d, 0xaa, 0xe4,
		0x2b, 0x60, 0x3b, 0x14, 0x13, 0x54, 0xd5, 0x96, 0xb2, 0x1d, 0x2a, 0x5f, 0xbb, 0x2b, 0xb3, 0x71,
		0x9e, 0x67, 0x43, 0xc9, 0xde, 0x45, 0xcf, 0xb3, 0xa1, 0x2a, 0x6b, 0x21, 0x9b, 0xa1, 0xe8, 0xd3,
		0xd7, 0xe2, 0xd3, 0xd9, 0x0b, 0x25, 0xcc, 0x8b, 0xb3, 0x15, 0x4a, 0x9d, 0x47, 0xb4, 0x86, 0x41,
		0x54, 0x0b, 0x06, 0xff, 0x2f, 0xb8, 0x34, 0xd1, 0xe5, 0x7d, 0x2d, 0x09, 0x07, 0x40, 0x7d, 0x50,
		0x4f, 0xd8, 0xce, 0x26, 0xa8, 0x75, 0x98, 0xc9, 0x26, 0xa8, 0x1c, 0x55, 0xcb, 0x26, 0xa8, 0xfc,
		0x96, 0x17, 0x9b, 0xa0, 0x8a, 0x86, 0x69, 0x36, 0x41, 0x55, 0x2d, 0x7f, 0x82, 0x69, 0x82, 0x5a,
		0xc1, 0x03, 0xbc, 0x86, 0xa8, 0xd5, 0x4b, 0x60, 0x73, 0x54, 0x95, 0x81, 0x07, 0x11, 0x7c, 0x80,
		0x01, 0x08, 0x15, 0x84, 0xe0, 0x81, 0x08, 0x1e, 0x8c, 0xb0, 0x01, 0x09, 0x03, 0x94, 0x40, 0x80,
		0x09, 0x0e, 0x9c, 0x32, 0x83, 0xb1, 0xba, 0xc8, 0x57, 0xe2, 0x0c, 0xda, 0x23, 0x41, 0x40, 0x70,
		0x82, 0x05, 0x28, 0x64, 0x90, 0x52, 0x00, 0x54, 0xe8, 0x60, 0xa5, 0x06, 0xb0, 0xd4, 0x80, 0x96,
		0x0e, 0xe0, 0xc2, 0x02, 0x2f, 0x30, 0x00, 0x83, 0x05, 0xb1, 0xcc, 0xf0, 0xab, 0x61, 0x70, 0x9d,
		0xe0, 0x3a, 0xcb, 0x45, 0xbc, 0x9a, 0x5d, 0x06, 0xa8, 0x7f, 0xc1, 0xec, 0x5c, 0x87, 0x07, 0x35,
		0x0d, 0xc0, 0xa6, 0x08, 0xdc, 0xb4, 0x00, 0x9c, 0x3a, 0x90, 0x53, 0x07, 0x74, 0xba, 0xc0, 0x0e,
		0x13, 0xf0, 0x40, 0x41, 0x2f, 0x93, 0x0e, 0x6c, 0x27, 0xfc, 0x4a, 0xc4, 0x30, 0xd1, 0xf8, 0xc6,
		0xc4, 0xb3, 0xdd, 0xab, 0xc0, 0x51, 0x63, 0x51, 0xe5, 0x6a, 0x00, 0x5f, 0x83, 0x13, 0x8d, 0x6f,
		0x26, 0xa2, 0xe2, 0x52, 0x2e, 0xf2, 0x53, 0x87, 0xee, 0x51, 0xcc, 0xae, 0x02, 0xbe, 0x57, 0x71,
		0x79, 0x25, 0x0a, 0x7b, 0x16, 0xb3, 0x8b, 0x83, 0xee, 0x5d, 0xc4, 0x45, 0x0d, 0x40, 0xdf, 0x64,
		0x65, 0xcd, 0x0b, 0x40, 0xdb, 0x8c, 0x9e, 0xa5, 0x8c, 0x87, 0x17, 0xc3, 0x32, 0x4d, 0x19, 0xe6,
		0xb3, 0x4c, 0x23, 0x68, 0x39, 0xb0, 0x4c, 0x23, 0x67, 0x59, 0xb3, 0x4c, 0x23, 0xfc, 0x82, 0x58,
		0xa6, 0x21, 0x3f, 0xfd, 0xa0, 0x74, 0xf4, 0x94, 0x69, 0x92, 0xfb, 0x24, 0x35, 0x37, 0xb8, 0xf8,
		0xb4, 0x01, 0x3e, 0xbd, 0x70, 0x89, 0x21, 0xe0, 0xf3, 0xd1, 0xb2, 0x0b, 0xf9, 0xef, 0xef, 0x9b,
		0xb5, 0x7d, 0xbb, 0x76, 0x1c, 0xd4, 0xae, 0xce, 0xff, 0x6c, 0x7c, 0xf9, 0xe3, 0x8f, 0x17, 0xdf,
		0x78, 0xe3, 0x1f, 0xb8, 0x5e, 0xf7, 0x1c, 0x59, 0x70, 0x1a, 0xa6, 0xf2, 0x55, 0x53, 0x75, 0xac,
		0xee, 0x90, 0x4e, 0x9e, 0x59, 0x07, 0x77, 0xc1, 0x70, 0x6c, 0xf0, 0xeb, 0x3a, 0xb3, 0xcb, 0x60,
		0x45, 0xa7, 0x0c, 0xf3, 0x59, 0xd1, 0x11, 0xb4, 0x10, 0x58, 0xd1, 0x91, 0xb3, 0xac, 0x59, 0xd1,
		0x11, 0x7e, 0x41, 0xac, 0xe8, 0x90, 0x99, 0x7e, 0x50, 0x3a, 0x7a, 0x2a, 0x3a, 0xe3, 0x30, 0x4a,
		0x5f, 0x6e, 0x2b, 0x28, 0xe7, 0xec, 0x01, 0x5f, 0x42, 0x2f, 0x88, 0xae, 0x0d, 0x7c, 0x56, 0x8d,
		0x1d, 0xb0, 0x37, 0xe6, 0xfb, 0x57, 0xe0, 0xc9, 0x43, 0x49, 0x62, 0xb1, 0x72, 0x39, 0x67, 0xf3,
		0x5c, 0x55, 0xcb, 0xf5, 0x1c, 0xc7, 0xc1, 0x65, 0x1a, 0x8e, 0xa2, 0x66, 0x78, 0x1d, 0xce, 0xb6,
		0x4b, 0xc1, 0x5f, 0xd7, 0x97, 0x5f, 0x15, 0xb8, 0x80, 0xe0, 0x33, 0x5d, 0x80, 0x70, 0x17, 0xd0,
		0xd8, 0xde, 0x6f, 0xec, 0xef, 0xee, 0x6d, 0xef, 0xef, 0xd0, 0x17, 0x30, 0x21, 0xa1, 0xf5, 0x0f,
		0x5f, 0x2c, 0xf7, 0x33, 0xd6, 0x3d, 0xe7, 0x66, 0x3e, 0x99, 0xf0, 0xfa, 0x43, 0x8a, 0x5f, 0xef,
		0x9f, 0x5f, 0x07, 0x0b, 0xfe, 0x65, 0x98, 0xcf, 0x82, 0xbf, 0xa0, 0x95, 0xc0, 0x82, 0xbf, 0x9c,
		0x65, 0xcd, 0x82, 0xbf, 0xf0, 0x0b, 0x62, 0xc1, 0x9f, 0xd4, 0xf4, 0x83, 0xd2, 0xd1, 0x55, 0xf0,
		0x7f, 0xa5, 0xa0, 0xde, 0xbf, 0xc3, 0x7a, 0x7f, 0xc9, 0x2f, 0xd6, 0xfb, 0x99, 0x57, 0xe4, 0x78,
		0x39, 0xac, 0xf7, 0x33, 0x9a, 0x17, 0xe1, 0x02, 0x58, 0xef, 0x17, 0xef, 0x02, 0xb6, 0x77, 0x58,
		0xe8, 0x67, 0x22, 0x42, 0xeb, 0xbf, 0x7a, 0xb1, 0xd0, 0x4f, 0x8b, 0xe1, 0x43, 0x32, 0xea, 0x89,
		0xd4, 0x99, 0xfd, 0x55, 0x38, 0xc5, 0x74, 0xf5, 0x3c, 0xc2, 0xd5, 0xb7, 0xea, 0x88, 0x53, 0xe9,
		0x37, 0x74, 0x1f, 0x75, 0xda, 0x0a, 0x22, 0x7b, 0x71, 0x8f, 0xfa, 0xe1, 0x20, 0x79, 0xfc, 0x06,
		0xd2, 0xe9, 0xd5, 0x78, 0xde, 0x18, 0xc8, 0x13, 0x83, 0xf6, 0x81, 0x41, 0xf7, 0x7f, 0x81, 0xe6,
		0x6a, 0x3c, 0x11, 0xa3, 0x4c, 0xa1, 0xf3, 0x44, 0x8c, 0xf2, 0x96, 0x2b, 0x4f, 0xc4, 0x90, 0x96,
		0x3a, 0xf0, 0x44, 0x0c, 0x32, 0xcd, 0x5f, 0x4b, 0x04, 0xf6, 0xb1, 0xed, 0xf2, 0xa4, 0x54, 0x13,
		0x5c, 0xc5, 0xe6, 0x0a, 0xd1, 0xe3, 0x2f, 0xe6, 0xec, 0x00, 0x76, 0x66, 0x59, 0xdd, 0x79, 0x42,
		0xff, 0xe2, 0xc5, 0x2c, 0xb1, 0xad, 0xcf, 0x10, 0x93, 0xa9, 0x52, 0x85, 0x2d, 0x45, 0x39, 0x8f,
		0xf1, 0xad, 0xb9, 0x47, 0x4b, 0x8a, 0x30, 0xc7, 0x5f, 0xe3, 0x8e, 0xbb, 0x56, 0x35, 0xde, 0x1a,
		0x73, 0x9c, 0x35, 0x8a, 0x37, 0x01, 0x2d, 0xd0, 0xb3, 0x30, 0x8f, 0x75, 0xb2, 0xfe, 0x46, 0xb5,
		0x4b, 0xf1, 0x18, 0x64, 0x29, 0x9f, 0xd3, 0x64, 0x5b, 0x28, 0xdc, 0xe7, 0xa3, 0xf9, 0xfa, 0x8a,
		0xfa, 0x78, 0x00, 0x8f, 0x5e, 0x21, 0x4f, 0x2e, 0xdb, 0x73, 0xcb, 0xf5, 0x87, 0x82, 0x7d, 0xa1,
		0x35, 0x5d, 0xe4, 0xd9, 0xba, 0x95, 0x7f, 0x32, 0xed, 0xb2, 0x5a, 0xf8, 0xc8, 0x70, 0xe1, 0xf1,
		0x66, 0x51, 0x21, 0x14, 0x6e, 0x26, 0xca, 0x23, 0x4f, 0xa4, 0x47, 0x9c, 0x80, 0x8f, 0x34, 0xd1,
		0x1e, 0x61, 0xc2, 0x3e, 0xb2, 0x84, 0x7d, 0x44, 0x89, 0xf9, 0x48, 0x92, 0x39, 0xd3, 0xcf, 0xdc,
		0x72, 0x94, 0x43, 0xf7, 0xad, 0xd9, 0x06, 0x4d, 0x18, 0xe7, 0x95, 0x1d, 0x39, 0x02, 0xb4, 0xaf,
		0x14, 0x04, 0x68, 0xe0, 0xc0, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07,
		0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83, 0x87, 0xa3,
		0xcb, 0x60, 0x58, 0xbb, 0x8d, 0x47, 0xa9, 0xb9, 0x84, 0x6c, 0x4c, 0x5a, 0x96, 0x83, 0x1e, 0x5f,
		0x09, 0xb7, 0xc8, 0x13, 0xab, 0x74, 0xe1, 0x95, 0x02, 0xcc, 0x42, 0xc7, 0x2d, 0x35, 0xd8, 0xa5,
		0x06, 0xbf, 0x74, 0x60, 0x18, 0x16, 0x8e, 0x81, 0x61, 0x59, 0x26, 0x11, 0xfc, 0x2d, 0xf2, 0x26,
		0x1a, 0xdf, 0x98, 0x38, 0x00, 0x04, 0x9c, 0x87, 0x90, 0xb3, 0xd5, 0x00, 0xb4, 0xdd, 0x89, 0xc6,
		0x37, 0x13, 0xf1, 0x70, 0x89, 0xe6, 0xf9, 0x29, 0x43, 0x6e, 0x8e, 0xce, 0xac, 0x87, 0xdd, 0x24,
		0xbd, 0xbc, 0x02, 0x45, 0x9b, 0xa5, 0xb3, 0x8b, 0x82, 0xdc, 0x34, 0x8d, 0x87, 0x04, 0xac, 0x25,
		0xad, 0x95, 0x67, 0xb9, 0x19, 0x5d, 0xee, 0x46, 0xc5, 0xaf, 0xf7, 0x1e, 0xc1, 0x0d, 0x84, 0xd1,
		0xbc, 0x67, 0x31, 0x8c, 0x3e, 0x66, 0xff, 0x44, 0x82, 0x34, 0xf6, 0x85, 0x3b, 0xce, 0x55, 0x3b,
		0x76, 0xee, 0x38, 0x97, 0xef, 0xc8, 0xb9, 0xdd, 0x5c, 0x8e, 0xeb, 0xe6, 0x66, 0x73, 0x75, 0x6e,
		0x70, 0xb6, 0x67, 0x7b, 0x60, 0x86, 0xc1, 0x3d, 0xd8, 0x3e, 0xf3, 0x99, 0xcd, 0xdc, 0x62, 0xbe,
		0x0e, 0x33, 0xb9, 0xc5, 0x3c, 0x47, 0xb5, 0x72, 0x8b, 0x79, 0x7e, 0xcb, 0x8b, 0x5b, 0xcc, 0x8b,
		0x26, 0x66, 0x6e, 0x31, 0xaf, 0x5a, 0x92, 0xc4, 0x2d, 0xe6, 0xf9, 0xc6, 0x07, 0x6e, 0x31, 0x27,
		0xd8, 0x20, 0x02, 0x0e, 0x30, 0xe8, 0xa0, 0x02, 0x0f, 0x3c, 0xf8, 0xc0, 0x03, 0x10, 0x36, 0x08,
		0x61, 0x00, 0x11, 0x08, 0x18, 0xc1, 0x01, 0x52, 0x66, 0x70, 0x50, 0xbb, 0x08, 0x53, 0xdc, 0x7d,
		0xe5, 0x33, 0xf3, 0xb9, 0x99, 0x9c, 0x00, 0xa5, 0x0b, 0xa4, 0x14, 0x00, 0x15, 0x3a, 0x58, 0xa9,
		0x01, 0x2c, 0x35, 0xa0, 0xa5, 0x03, 0xb8, 0xb0, 0xc0, 0x0b, 0x0c, 0xc0, 0x32, 0x89, 0xe0, 0x6f,
		0x26, 0xbf, 0x18, 0x8d, 0x86, 0x26, 0x80, 0xde, 0x48, 0xbe, 0xc5, 0xad, 0x9c, 0x55, 0x5f, 0x8c,
		0x16, 0xc6, 0xf3, 0xe4, 0x67, 0x57, 0x21, 0xc2, 0xa3, 0x65, 0x26, 0x18, 0x4c, 0x30, 0x98, 0x60,
		0x30, 0xc1, 0x60, 0x82, 0xc1, 0x04, 0x83, 0x09, 0x06, 0x13, 0x8c, 0xbf, 0xe9, 0xf1, 0xc7, 0x61,
		0x94, 0xbe, 0xdc, 0x06, 0xce, 0x2f, 0x10, 0x8f, 0x73, 0xea, 0x05, 0xd1, 0xf5, 0xe4, 0xd3, 0xff,
		0x1d, 0xd2, 0x31, 0xfe, 0x09, 0x7b, 0x46, 0xbd, 0x75, 0x12, 0x46, 0xb0, 0x84, 0x00, 0x0e, 0xf6,
		0x2b, 0x97, 0x71, 0x36, 0x3f, 0xe4, 0x17, 0xfd, 0x3a, 0x8e, 0xe3, 0x60, 0x3a, 0xcd, 0xa8, 0x19,
		0x5e, 0x87, 0xb3, 0x9e, 0x62, 0xd8, 0xeb, 0xf9, 0xf2, 0x2b, 0xf0, 0xd2, 0x0e, 0x3e, 0x73, 0x69,
		0x0b, 0x5b, 0xda, 0x8d, 0xed, 0xfd, 0xc6, 0xfe, 0xee, 0xde, 0xf6, 0xfe, 0x0e, 0xd7, 0x38, 0x13,
		0x82, 0x6a, 0x59, 0x7d, 0xce, 0xb2, 0x77, 0x85, 0x2d, 0xe5, 0x04, 0x83, 0x7c, 0xed, 0xae, 0x4c,
		0xe3, 0xeb, 0xf4, 0xd1, 0x03, 0x87, 0x17, 0xc8, 0xea, 0x80, 0x6d, 0x4e, 0x6e, 0x0a, 0xe7, 0x16,
		0x54, 0xc7, 0x42, 0xce, 0x2d, 0xa0, 0xfb, 0xfe, 0x71, 0xf7, 0xcd, 0x91, 0x05, 0x22, 0x1c, 0x36,
		0xa7, 0x15, 0xa8, 0x73, 0x7e, 0x0f, 0x3a, 0xff, 0x6b, 0x77, 0x41, 0x1c, 0x62, 0xb8, 0xc0, 0x27,
		0xe6, 0x16, 0x3c, 0xb0, 0x9e, 0x13, 0x0c, 0xd6, 0x61, 0x26, 0x27, 0x18, 0xe4, 0xa8, 0x5b, 0x4e,
		0x30, 0xc8, 0x6f, 0x79, 0x71, 0x82, 0x41, 0xd1, 0xec, 0xcc, 0x09, 0x06, 0x55, 0x4b, 0x97, 0x38,
		0xc1, 0x20, 0xdf, 0xf8, 0xc0, 0x09, 0x06, 0x04, 0x1b, 0x44, 0xc0, 0x01, 0x06, 0x1d, 0x54, 0xe0,
		0x81, 0x07, 0x1f, 0x78, 0x00, 0xc2, 0x06, 0x21, 0x0c, 0x20, 0x02, 0x01, 0x23, 0x38, 0x40, 0xca,
		0x0c, 0x66, 0x83, 0x51, 0x69, 0xe0, 0xc4, 0x06, 0x23, 0x82, 0x94, 0x62, 0xa0, 0x42, 0x07, 0x2b,
		0x35, 0x80, 0xa5, 0x06, 0xb4, 0x74, 0x00, 0x17, 0x16, 0x78, 0x81, 0x01, 0x58, 0x26, 0x11, 0x36,
		0x18, 0x95, 0xce, 0x37, 0x6c, 0x30, 0x2a, 0xfa, 0xc5, 0x06, 0x23, 0x82, 0xfd, 0x1a, 0x2e, 0x83,
		0x0d, 0x46, 0x0c, 0xbf, 0xeb, 0x5c, 0xda, 0x6c, 0x30, 0x12, 0xb7, 0xb4, 0xd9, 0x60, 0xc4, 0x84,
		0xa0, 0xaa, 0x56, 0xb3, 0xc1, 0xa8, 0xca, 0x96, 0xb2, 0xc1, 0x28, 0x5f, 0xbb, 0xab, 0xb5, 0x43,
		0x7d, 0xb9, 0xfd, 0x94, 0xad, 0x46, 0x02, 0x77, 0xae, 0x9f, 0x2d, 0xee, 0x0e, 0x7b, 0x8e, 0xaa,
		0x63, 0x21, 0x7b, 0x8e, 0xe8, 0xd1, 0xd7, 0xe1, 0xd1, 0xd9, 0x7d, 0x24, 0xcb, 0x87, 0xb3, 0x0d,
		0x49, 0x9d, 0x3f, 0x9c, 0x35, 0xf2, 0x84, 0x03, 0xb0, 0xce, 0xa3, 0x70, 0xc0, 0x66, 0xa3, 0xb5,
		0x98, 0xc9, 0x66, 0xa3, 0x1c, 0xa5, 0xca, 0x66, 0xa3, 0xfc, 0x96, 0x17, 0x9b, 0x8d, 0x8a, 0x86,
		0x66, 0x36, 0x1b, 0x55, 0x2d, 0x4f, 0x62, 0xb3, 0x51, 0xbe, 0xf1, 0x81, 0xcd, 0x46, 0x04, 0x1b,
		0x44, 0xc0, 0x01, 0x06, 0x1d, 0x54, 0xe0, 0x81, 0x07, 0x1f, 0x78, 0x00, 0xc2, 0x06, 0x21, 0x0c,
		0x20, 0x02, 0x01, 0x23, 0x38, 0x40, 0xca, 0x0c, 0x1e, 0x8e, 0x2e, 0x83, 0x21, 0x6e, 0xb3, 0xd1,
		0xcc, 0x7c, 0x36, 0x1b, 0x11, 0xa0, 0x74, 0x81, 0x94, 0x02, 0xa0, 0x42, 0x07, 0x2b, 0x35, 0x80,
		0xa5, 0x06, 0xb4, 0x74, 0x00, 0x17, 0x16, 0x78, 0x81, 0x01, 0x58, 0x26, 0x11, 0x36, 0x1b, 0x95,
		0xce, 0x37, 0x6c, 0x36, 0x2a, 0xfa, 0xc5, 0x66, 0x23, 0x82, 0xfd, 0x1a, 0x2e, 0x83, 0xcd, 0x46,
		0x0c, 0xbf, 0xeb, 0x5c, 0xda, 0x6c, 0x36, 0x12, 0xb7, 0xb4, 0xd9, 0x6c, 0xc4, 0x84, 0xa0, 0xaa,
		0x56, 0xb3, 0xd9, 0xa8, 0xf2, 0x31, 0xca, 0x8a, 0xcd, 0xcd, 0x28, 0x35, 0xb8, 0x75, 0xef, 0xb9,
		0xfd, 0x2c, 0x7c, 0x17, 0x61, 0x36, 0x0b, 0xdf, 0x25, 0x2a, 0x9d, 0x85, 0xef, 0xf2, 0x96, 0x2b,
		0x0b, 0xdf, 0xc2, 0x2e, 0x84, 0x85, 0x6f, 0x52, 0xcd, 0x37, 0x24, 0xc2, 0xc2, 0x77, 0xe9, 0x7c,
		0xc3, 0xc2, 0x77, 0xd1, 0x2f, 0x16, 0xbe, 0x09, 0xf6, 0x6b, 0xb8, 0x0c, 0x16, 0xbe, 0x19, 0x7e,
		0xd7, 0xb9, 0xb4, 0x59, 0xf8, 0x16, 0xb7, 0xb4, 0x59, 0xf8, 0x66, 0x42, 0x50, 0x55, 0xab, 0x59,
		0xf8, 0xae, 0xb2, 0xa5, 0x9c, 0xb2, 0x95, 0xaf, 0xdd, 0x95, 0x99, 0xc9, 0x12, 0x0e, 0x38, 0x58,
		0x4b, 0xd6, 0x50, 0x16, 0x77, 0xc0, 0x61, 0x5a, 0xd5, 0xb1, 0x90, 0xc3, 0xb4, 0xe8, 0xb8, 0x7f,
		0xd0, 0x71, 0x73, 0x7e, 0x56, 0xf9, 0xae, 0x9a, 0x33, 0xb3, 0xd4, 0xb9, 0xbd, 0xd9, 0x08, 0xaa,
		0xe1, 0x28, 0x49, 0xc0, 0xa6, 0x66, 0x4d, 0x4d, 0xe6, 0xdc, 0xac, 0x75, 0x98, 0xc9, 0xb9, 0x59,
		0x39, 0x8a, 0x95, 0x73, 0xb3, 0xf2, 0x5b, 0x5e, 0x9c, 0x9b, 0x55, 0x34, 0x1f, 0x73, 0x6e, 0x56,
		0xd5, 0x52, 0x22, 0xce, 0xcd, 0xca, 0x37, 0x3e, 0x70, 0x6e, 0x16, 0xc1, 0x06, 0x11, 0x70, 0x80,
		0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0,
		0x08, 0x0e, 0x90, 0x32, 0x83, 0x83, 0xda, 0x45, 0x98, 0xe2, 0xf6, 0x0f, 0xcd, 0xcc, 0x67, 0xfb,
		0x10, 0x01, 0x4a, 0x17, 0x48, 0x29, 0x00, 0x2a, 0x74, 0xb0, 0x52, 0x03, 0x58, 0x6a, 0x40, 0x4b,
		0x07, 0x70, 0x61, 0x81, 0x17, 0x18, 0x80, 0x65, 0x12, 0xc1, 0x6f, 0x1f, 0xba, 0x18, 0x8d, 0x86,
		0x26, 0x88, 0x80, 0xfb, 0x87, 0xb6, 0xb6, 0xb8, 0x51, 0xb3, 0xea, 0x8b, 0x11, 0xe8, 0x91, 0xf2,
		0xb3, 0x2b, 0x11, 0xe5, 0x11, 0x33, 0x13, 0x0d, 0x26, 0x1a, 0x4c, 0x34, 0x98, 0x68, 0x30, 0xd1,
		0x60, 0xa2, 0xc1, 0x44, 0x83, 0x89, 0xc6, 0xdf, 0xf4, 0xf8, 0x9c, 0x53, 0x50, 0x82, 0xe9, 0x9c,
		0x53, 0x50, 0xd2, 0x07, 0xcf, 0x39, 0x05, 0x72, 0x2e, 0x83, 0x73, 0x0a, 0x18, 0x7e, 0xd7, 0xb9,
		0xb4, 0x39, 0xa7, 0x40, 0xdc, 0xd2, 0xe6, 0x9c, 0x02, 0x26, 0x04, 0x55, 0xb5, 0x9a, 0x73, 0x0a,
		0xaa, 0x6c, 0x29, 0xe7, 0x14, 0xe4, 0x6b, 0x77, 0x65, 0xda, 0x5d, 0x87, 0xa3, 0x24, 0xe1, 0xa4,
		0x02, 0x59, 0xed, 0xaf, 0xad, 0x51, 0x92, 0x70, 0x56, 0x41, 0x75, 0x2c, 0xe4, 0xac, 0x02, 0x3a,
		0xef, 0x1f, 0x76, 0xde, 0x9c, 0x56, 0x20, 0xc1, 0x5d, 0x73, 0x5e, 0x81, 0x3a, 0xd7, 0x37, 0xdb,
		0x99, 0x31, 0x59, 0xf3, 0x66, 0x9a, 0x9b, 0xd7, 0x52, 0x84, 0x87, 0x31, 0x5f, 0xef, 0x2b, 0x79,
		0x6c, 0x3d, 0xa7, 0x18, 0xac, 0xc3, 0x4c, 0x4e, 0x31, 0xc8, 0x51, 0xb7, 0x9c, 0x62, 0x90, 0xdf,
		0xf2, 0xe2, 0x14, 0x83, 0xa2, 0xc9, 0x99, 0x53, 0x0c, 0xaa, 0x96, 0x2c, 0x71, 0x8a, 0x41, 0xbe,
		0xf1, 0x81, 0x53, 0x0c, 0x08, 0x36, 0x88, 0x80, 0x03, 0x0c, 0x3a, 0xa8, 0xc0, 0x03, 0x0f, 0x3e,
		0xf0, 0x00, 0x84, 0x0d, 0x42, 0x18, 0x40, 0x04, 0x02, 0x46, 0x70, 0x80, 0x94, 0x19, 0x9c, 0x22,
		0x6e, 0xc2, 0xcd, 0xc2, 0x0c, 0x40, 0xdd, 0xe7, 0x39, 0x6c, 0x62, 0x6b, 0x11, 0x31, 0x4a, 0x31,
		0x4e, 0xa1, 0x63, 0x95, 0x1a, 0xbc, 0x52, 0x83, 0x59, 0x3a, 0x70, 0x0b, 0x0b, 0xbb, 0xc0, 0xf0,
		0x2b, 0x93, 0x08, 0x7e, 0x6b, 0x91, 0x89, 0xc6, 0x37, 0x26, 0x9e, 0xed, 0x4b, 0x00, 0x9e, 0x63,
		0xd0, 0x00, 0xb4, 0xdd, 0x89, 0xc6, 0x37, 0x13, 0xf1, 0x70, 0x89, 0xe6, 0xf9, 0x29, 0xb7, 0xc2,
		0x24, 0xb5, 0xd3, 0x34, 0xc6, 0x5c, 0xa6, 0x27, 0x61, 0xe4, 0x0c, 0xcd, 0x24, 0x0a, 0x25, 0x98,
		0x2d, 0x07, 0xd6, 0x49, 0xf0, 0xf9, 0xc1, 0x15, 0x6c, 0xbd, 0x6a, 0x34, 0x76, 0xf7, 0x1a, 0x8d,
		0xcd, 0xbd, 0x97, 0x7b, 0x9b, 0xfb, 0x3b, 0x3b, 0x5b, 0xbb, 0x5b, 0x80, 0x6d, 0x07, 0x56, 0x27,
		0x1e, 0x98, 0xd8, 0x0c, 0x0e, 0xef, 0xad, 0x83, 0x8d, 0x68, 0x3c, 0x1c, 0x72, 0x1b, 0x79, 0x85,
		0x2d, 0xe5, 0x36, 0xf2, 0x7c, 0xed, 0xae, 0xcc, 0x4e, 0xc4, 0x47, 0x1b, 0x8d, 0xb8, 0xa3, 0x5c,
		0xd6, 0x16, 0xc5, 0x6e, 0x76, 0x7b, 0x26, 0xd8, 0xcf, 0xbd, 0xe5, 0xd5, 0xb1, 0x90, 0x7b, 0xcb,
		0xe9, 0xd1, 0xd7, 0xe1, 0xd1, 0xb9, 0xcd, 0x5c, 0x96, 0x0f, 0xe7, 0x86, 0x73, 0x75, 0xfe, 0xd0,
		0xba, 0x09, 0x3e, 0xd7, 0xa6, 0x6b, 0xef, 0x22, 0x88, 0x06, 0x9f, 0xc2, 0xc1, 0xd4, 0xc7, 0x80,
		0x6c, 0x37, 0x7f, 0xc2, 0x76, 0x6e, 0x36, 0x5f, 0x87, 0x99, 0xdc, 0x6c, 0x9e, 0xa3, 0x6a, 0xb9,
		0xd9, 0x3c, 0xbf, 0xe5, 0xc5, 0xcd, 0xe6, 0x45, 0xa3, 0x34, 0x37, 0x9b, 0x57, 0x2d, 0x7b, 0xe2,
		0x66, 0xf3, 0x7c, 0xe3, 0x03, 0x37, 0x9b, 0x13, 0x6c, 0x10, 0x01, 0x07, 0x18, 0x74, 0x50, 0x81,
		0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08, 0x1b, 0x84, 0x30, 0x80, 0x08, 0x04, 0x8c, 0xe0, 0x00, 0x29,
		0x33, 0x18, 0xa7, 0xf4, 0xf3, 0x6c, 0xac, 0x41, 0xa9, 0x00, 0x3d, 0x07, 0x50, 0xdc, 0x76, 0x4e,
		0xa0, 0x52, 0x0c, 0x56, 0xe8, 0x80, 0xa5, 0x06, 0xb4, 0xd4, 0x00, 0x97, 0x0e, 0xf0, 0xc2, 0x02,
		0x30, 0x30, 0x10, 0xcb, 0x24, 0x82, 0xbf, 0xed, 0x3c, 0x34, 0xc6, 0x5c, 0x0d, 0x47, 0x01, 0xf6,
		0xb1, 0x16, 0xfb, 0x80, 0xa6, 0xb7, 0x4c, 0x74, 0x3d, 0x05, 0x63, 0x9e, 0x6b, 0x51, 0xf0, 0x27,
		0xcf, 0x73, 0x2d, 0xe4, 0x5c, 0x46, 0x36, 0xfc, 0x9e, 0x33, 0xef, 0x19, 0x84, 0xd7, 0xb0, 0xb4,
		0x79, 0xae, 0x05, 0x97, 0x36, 0x97, 0xb6, 0x8e, 0x6c, 0x00, 0xd7, 0x6a, 0x1e, 0x67, 0x51, 0x65,
		0x4b, 0xd9, 0x87, 0x94, 0xaf, 0xdd, 0x55, 0xd8, 0xb5, 0xbe, 0xba, 0x03, 0x95, 0x5d, 0x48, 0x72,
		0x76, 0xb0, 0x9f, 0x04, 0x9f, 0x27, 0xbf, 0xee, 0x70, 0x71, 0x6f, 0xd8, 0x83, 0x54, 0x1d, 0x0b,
		0xd9, 0x83, 0x44, 0x6f, 0xfe, 0xf3, 0xde, 0x9c, 0x1d, 0x48, 0x92, 0xfc, 0x37, 0xfb, 0x8f, 0xd4,
		0xf9, 0xc2, 0x69, 0x0f, 0x4f, 0x6c, 0x12, 0x13, 0xdf, 0x05, 0x17, 0x43, 0x03, 0xdd, 0x8a, 0xf4,
		0xfc, 0x65, 0xb0, 0x2b, 0x69, 0x1d, 0x66, 0xb2, 0x2b, 0x29, 0x47, 0x01, 0xb3, 0x2b, 0x29, 0xbf,
		0xe5, 0xc5, 0xae, 0xa4, 0xa2, 0xe1, 0x9a, 0x5d, 0x49, 0x55, 0xcb, 0xa7, 0xd8, 0x95, 0x94, 0x6f,
		0x7c, 0x60, 0x57, 0x12, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07,
		0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83, 0xd9, 0x95,
		0x54, 0x3a, 0x40, 0xb1, 0x2b, 0x89, 0x40, 0xa5, 0x18, 0xac, 0xd0, 0x01, 0x4b, 0x0d, 0x68, 0xa9,
		0x01, 0x2e, 0x1d, 0xe0, 0x85, 0x05, 0x60, 0x60, 0x20, 0x96, 0x49, 0x84, 0x5d, 0x49, 0x32, 0x20,
		0x87, 0x5d, 0x49, 0x85, 0xbf, 0xd8, 0x95, 0x44, 0xbc, 0x5f, 0xc3, 0x65, 0xb0, 0x75, 0x81, 0x41,
		0x78, 0x9d, 0x4b, 0x9b, 0x5d, 0x49, 0x5c, 0xda, 0x5c, 0xda, 0x3a, 0xb2, 0x01, 0x5c, 0xab, 0xd9,
		0x95, 0x54, 0x65, 0x4b, 0xd9, 0x95, 0x94, 0xaf, 0xdd, 0x55, 0xd9, 0xc7, 0xfe, 0xec, 0x66, 0x54,
		0x36, 0x28, 0x89, 0xda, 0xe0, 0xde, 0xcb, 0xee, 0x13, 0x5b, 0x95, 0x2a, 0x6a, 0x21, 0x5b, 0x95,
		0xe8, 0xe2, 0xd7, 0xea, 0xe2, 0xd9, 0xb5, 0x24, 0xd3, 0xa9, 0xb3, 0x7f, 0x49, 0x9d, 0x83, 0xb4,
		0x6e, 0xc2, 0xa8, 0x96, 0xf5, 0x0d, 0x0e, 0xcc, 0x30, 0xb8, 0x07, 0x6a, 0x5a, 0x5a, 0xb5, 0x9d,
		0x9d, 0x4a, 0xeb, 0x30, 0x93, 0x9d, 0x4a, 0x39, 0xaa, 0x96, 0x9d, 0x4a, 0xf9, 0x2d, 0x2f, 0x76,
		0x2a, 0x15, 0xcd, 0xd6, 0xec, 0x54, 0xaa, 0x5a, 0x3a, 0xc5, 0x4e, 0xa5, 0x7c, 0xe3, 0x03, 0x3b,
		0x95, 0x08, 0x36, 0x88, 0x80, 0x03, 0x0c, 0x3a, 0xa8, 0xc0, 0x03, 0x0f, 0x3e, 0xf0, 0x00, 0x84,
		0x0d, 0x42, 0x18, 0x40, 0x04, 0x02, 0x46, 0x70, 0x80, 0x94, 0x19, 0x1c, 0xd4, 0x2e, 0xc2, 0x14,
		0xb7, 0x4b, 0x69, 0x66, 0x3e, 0x3b, 0x94, 0x08, 0x50, 0xba, 0x40, 0x4a, 0x01, 0x50, 0xa1, 0x83,
		0x95, 0x1a, 0xc0, 0x52, 0x03, 0x5a, 0x3a, 0x80, 0x0b, 0x0b, 0xbc, 0xc0, 0x00, 0x2c, 0x93, 0x08,
		0x7e, 0x87, 0xd2, 0xc5, 0x68, 0x34, 0x34, 0x41, 0x04, 0xdc, 0x9d, 0xb4, 0xb5, 0xc5, 0xed, 0xa0,
		0x55, 0x5f, 0x8c, 0xd3, 0xe9, 0x92, 0x18, 0xcf, 0x96, 0x9f, 0x5d, 0x89, 0xcb, 0x4b, 0x60, 0xa2,
		0xc1, 0x44, 0x83, 0x89, 0x06, 0x13, 0x0d, 0x26, 0x1a, 0x4c, 0x34, 0xc8, 0x35, 0x4c, 0x34, 0x54,
		0x24, 0x1a, 0xe3, 0x30, 0xc2, 0x9e, 0x82, 0xb0, 0x07, 0x68, 0x7a, 0x2f, 0x88, 0xae, 0x0d, 0x87,
		0x20, 0x14, 0xff, 0xc1, 0x73, 0x08, 0x82, 0x9c, 0xcb, 0x58, 0x74, 0x4a, 0x6f, 0xb2, 0x53, 0x9a,
		0xe1, 0x77, 0x0d, 0x4b, 0x9b, 0x43, 0x10, 0xc4, 0x2d, 0xed, 0xc6, 0xf6, 0x7e, 0x63, 0x7f, 0x77,
		0x6f, 0x7b, 0x7f, 0x87, 0x6b, 0x9c, 0x09, 0x41, 0xb5, 0xac, 0xe6, 0x34, 0x84, 0xca, 0xc7, 0xa8,
		0x69, 0x9f, 0x12, 0x7a, 0xf9, 0x3b, 0xbb, 0x04, 0x96, 0xbf, 0x8b, 0x30, 0x9b, 0xe5, 0xef, 0x12,
		0xc5, 0xce, 0xf2, 0x77, 0x79, 0xcb, 0x95, 0xe5, 0x6f, 0x61, 0x17, 0xc2, 0xf2, 0x37, 0xd9, 0xe6,
		0x1b, 0x12, 0x61, 0xf9, 0xbb, 0x74, 0xbe, 0x61, 0xf9, 0xbb, 0xe8, 0x17, 0xcb, 0xdf, 0x04, 0xfb,
		0x35, 0x5c, 0x06, 0xcb, 0xdf, 0x0c, 0xbf, 0xeb, 0x5c, 0xda, 0x2c, 0x7f, 0x8b, 0x5b, 0xda, 0x2c,
		0x7f, 0x33, 0x21, 0xa8, 0xaa, 0xd5, 0x2c, 0x7f, 0x57, 0xd9, 0x52, 0x0e, 0x03, 0xce, 0xd7, 0xee,
		0x4a, 0x4c, 0x8a, 0x5c, 0x19, 0xf2, 0xc6, 0x09, 0xc0, 0x82, 0x86, 0x45, 0x86, 0xd1, 0x49, 0xf0,
		0x79, 0xf2, 0x1b, 0x9b, 0x93, 0x5b, 0xc3, 0xb1, 0xbf, 0xd5, 0xb1, 0x90, 0x63, 0x7f, 0xe9, 0xcc,
		0x7f, 0xde, 0x99, 0x73, 0xd6, 0xaf, 0x20, 0xf7, 0xcd, 0x01, 0xbf, 0xea, 0x5c, 0xa1, 0x15, 0x9b,
		0x24, 0x1c, 0x8c, 0x83, 0x61, 0x0d, 0xe7, 0x3c, 0xea, 0xec, 0xb1, 0xcc, 0x13, 0xb6, 0x73, 0xc0,
		0xef, 0x3a, 0xcc, 0xe4, 0x80, 0xdf, 0x1c, 0x55, 0xcb, 0x01, 0xbf, 0xf9, 0x2d, 0x2f, 0x0e, 0xf8,
		0x2d, 0x9a, 0xa2, 0x39, 0xe0, 0xb7, 0x6a, 0x89, 0x13, 0x07, 0xfc, 0xe6, 0x1b, 0x1f, 0x38, 0xe0,
		0x97, 0x60, 0x83, 0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8,
		0x20, 0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x99, 0xc1, 0x38, 0xa5, 0x9f, 0x67, 0x63,
		0x0d, 0xd2, 0xe1, 0x70, 0x4f, 0x01, 0x14, 0x1b, 0x90, 0x08, 0x54, 0x8a, 0xc1, 0x0a, 0x1d, 0xb0,
		0xd4, 0x80, 0x96, 0x1a, 0xe0, 0xd2, 0x01, 0x5e, 0x58, 0x00, 0x06, 0x06, 0x62, 0x99, 0x44, 0xf0,
		0x1b, 0x90, 0x42, 0x63, 0xcc, 0xd5, 0x70, 0x14, 0x60, 0x77, 0x21, 0xed, 0x03, 0x9a, 0xde, 0x32,
		0xd1, 0xf5, 0x14, 0x8c, 0xd9, 0x86, 0x54, 0xf0, 0x27, 0xcf, 0x36, 0x24, 0x39, 0x97, 0x91, 0xf5,
		0x2a, 0xb0, 0x45, 0x81, 0x41, 0x78, 0x0d, 0x4b, 0x9b, 0x6d, 0x48, 0x5c, 0xda, 0x5c, 0xda, 0x3a,
		0xb2, 0x01, 0x5c, 0xab, 0xd9, 0x7d, 0x54, 0x65, 0x4b, 0xd9, 0x7d, 0x94, 0xaf, 0xdd, 0x55, 0xd8,
		0xb0, 0xbe, 0xba, 0x03, 0x95, 0xdd, 0x47, 0x72, 0xb6, 0xaf, 0xf7, 0xe6, 0x77, 0xe7, 0x70, 0x71,
		0x73, 0xd8, 0x7f, 0x54, 0x1d, 0x0b, 0xd9, 0x7f, 0x44, 0x77, 0xfe, 0xf3, 0xee, 0x9c, 0xfd, 0x47,
		0xa2, 0x1c, 0x38, 0x3b, 0x90, 0xd4, 0x39, 0x43, 0x90, 0x6d, 0xba, 0x50, 0xdb, 0x73, 0xd9, 0x67,
		0xb4, 0x66, 0x43, 0xd9, 0x67, 0x94, 0xab, 0xc9, 0xec, 0x33, 0x2a, 0xc8, 0x70, 0xf6, 0x19, 0x91,
		0x07, 0x50, 0x12, 0x24, 0x98, 0x3e, 0xa3, 0x14, 0x69, 0x7b, 0x49, 0x16, 0x1e, 0xa6, 0x56, 0x63,
		0x75, 0x19, 0x6d, 0xb2, 0xcb, 0xa8, 0xf2, 0x78, 0x03, 0x8c, 0x39, 0xa8, 0xb8, 0x03, 0x8f, 0x3d,
		0xf0, 0xf8, 0x83, 0x8d, 0x41, 0x18, 0x38, 0x04, 0x82, 0x45, 0x99, 0x14, 0xe0, 0x36, 0xb5, 0x2e,
		0x37, 0xb3, 0x0e, 0x4c, 0x94, 0x86, 0xe9, 0x7d, 0x6c, 0xae, 0x90, 0xbc, 0xf6, 0xa2, 0xa6, 0x02,
		0x34, 0xa6, 0xd7, 0x72, 0xe7, 0x1f, 0xf5, 0x61, 0x90, 0x18, 0xdc, 0xe6, 0x2e, 0xb7, 0xef, 0xf6,
		0xfd, 0xfe, 0xe9, 0xa1, 0xd7, 0x3a, 0xf3, 0xbd, 0xf7, 0x5d, 0x07, 0x2d, 0xec, 0x4c, 0xb7, 0x58,
		0x25, 0x90, 0x7b, 0x88, 0x41, 0xdb, 0x74, 0x96, 0xca, 0xf1, 0x7b, 0x8e, 0x7d, 0xf4, 0xc6, 0x3e,
		0x74, 0x5b, 0xae, 0xf7, 0x7e, 0x2e, 0xa2, 0x3e, 0xa2, 0x8a, 0x34, 0xa8, 0x09, 0x5b, 0x55, 0xdf,
		0x54, 0xd7, 0xa1, 0xdd, 0x6e, 0xfe, 0xdb, 0x6d, 0x7a, 0x6f, 0xfc, 0xa3, 0x4e, 0xbb, 0xef, 0xf5,
		0x6c, 0xb7, 0xed, 0xf5, 0x2d, 0xee, 0x30, 0xa6, 0xc0, 0xd6, 0x24, 0xb0, 0x53, 0xcf, 0x6d, 0xb9,
		0xff, 0x71, 0x9a, 0x4b, 0xa5, 0x51, 0x5d, 0x54, 0xd7, 0xba, 0xd4, 0x65, 0x37, 0x7f, 0xf3, 0xfb,
		0x6e, 0x93, 0x92, 0xa2, 0xa4, 0xd6, 0x26, 0xa9, 0x33, 0xdb, 0x6d, 0xd9, 0x87, 0x2d, 0x87, 0x1e,
		0x8b, 0xf2, 0x5a, 0xbf, 0xbc, 0xdc, 0xee, 0xd9, 0xae, 0xdf, 0x76, 0xdc, 0xd7, 0x6f, 0x0e, 0x3b,
		0x3d, 0xdf, 0x6e, 0x36, 0x7b, 0x4e, 0x9f, 0xc0, 0x45, 0x81, 0xad, 0x0f, 0xb8, 0xda, 0x19, 0xc9,
		0x3b, 0x4d, 0xbf, 0xd5, 0xef, 0x52, 0x5c, 0x14, 0xd7, 0xba, 0xc4, 0xd5, 0x72, 0xdb, 0x6f, 0x7d,
		0xdb, 0xf3, 0x7a, 0xee, 0xe1, 0xa9, 0xe7, 0xd0, 0x6f, 0x51, 0x5a, 0xeb, 0x95, 0x56, 0xb7, 0xd7,
		0xf1, 0x9c, 0x23, 0xcf, 0xed, 0xb4, 0x67, 0xf5, 0x2e, 0xea, 0x8b, 0xfa, 0x5a, 0x5b, 0xaa, 0x78,
		0xe2, 0xb6, 0xfd, 0xd7, 0xbd, 0xce, 0x29, 0x23, 0x22, 0x65, 0xb5, 0x5e, 0x9e, 0x77, 0xdb, 0x9e,
		0xd3, 0x3b, 0xb6, 0x8f, 0x1c, 0x02, 0x3d, 0x15, 0xb6, 0x6e, 0x85, 0x9d, 0xd8, 0xef, 0x66, 0xc1,
		0x91, 0xf5, 0x08, 0xaa, 0x2b, 0x87, 0xb0, 0xf8, 0x9b, 0xdf, 0xb2, 0xdb, 0xac, 0xa2, 0x52, 0x56,
		0x6b, 0xa7, 0x79, 0x4a, 0x8a, 0x92, 0x5a, 0x2b, 0x69, 0x35, 0x58, 0x39, 0xa5, 0xc0, 0xf2, 0x15,
		0x18, 0x51, 0x9e, 0x0a, 0xcb, 0x15, 0xe5, 0x7b, 0x4e, 0xdf, 0xe9, 0x9d, 0xf1, 0x01, 0x23, 0x35,
		0x96, 0x8f, 0xc6, 0x3c, 0xc7, 0x6f, 0x3a, 0xc7, 0xf6, 0x69, 0xcb, 0xf3, 0x4f, 0x1c, 0xaf, 0xe7,
		0x1e, 0x51, 0x5c, 0x14, 0xd7, 0xba, 0xc4, 0x75, 0xda, 0x9e, 0xb9, 0x2f, 0xee, 0xe7, 0xa2, 0xbe,
		0x72, 0x4b, 0x1b, 0x9b, 0x4e, 0xcb, 0x7e, 0xef, 0x9f, 0xd9, 0x3d, 0xd7, 0xf6, 0xdc, 0x4e, 0x9b,
		0xfa, 0xa2, 0xbe, 0xd6, 0xa5, 0x2f, 0xe7, 0x9d, 0xe7, 0xb4, 0x9b, 0x4e, 0x93, 0x4f, 0x83, 0xa8,
		0xaf, 0x5c, 0x00, 0xdf, 0x6d, 0x2f, 0xeb, 0xf5, 0x53, 0x3f, 0x46, 0x75, 0x51, 0x5d, 0x6b, 0x8d,
		0x8e, 0xad, 0x0e, 0x6b, 0x12, 0x14, 0x55, 0x1e, 0xc8, 0x45, 0x55, 0x51, 0x55, 0xeb, 0x52, 0x55,
		0xcf, 0xe9, 0xbb, 0xcd, 0x53, 0xbb, 0xa5, 0x22, 0x4d, 0x84, 0xb4, 0xfc, 0xfc, 0x17, 0xae, 0x62,
		0xae, 0xde, 0xef, 0x5b, 0xb5, 0x4a, 0xba, 0x41, 0x29, 0xa4, 0xb2, 0x85, 0xa4, 0xa1, 0xeb, 0x93,
		0x2a, 0x2a, 0x5b, 0x45, 0xb0, 0xdd, 0x9d, 0x94, 0x4e, 0xe9, 0xd2, 0xd1, 0xd0, 0xc5, 0x49, 0x19,
		0x95, 0x2d, 0x23, 0x25, 0xdd, 0x9a, 0x14, 0x52, 0xe9, 0x40, 0x84, 0xdf, 0x95, 0x49, 0x11, 0x95,
		0x2d, 0x22, 0xf8, 0xee, 0x4b, 0x4a, 0x48, 0x84, 0x84, 0xe0, 0xbb, 0x2c, 0xa9, 0xa3, 0xf2, 0x53,
		0x33, 0xe0, 0xe7, 0xe7, 0x94, 0x8f, 0x08, 0xae, 0x56, 0xb0, 0xd5, 0x9a, 0x4a, 0x2a, 0x5b, 0x49,
		0x1a, 0xba, 0x23, 0xa9, 0xa2, 0xf2, 0xc3, 0x19, 0x70, 0x17, 0x24, 0xe5, 0x23, 0x82, 0xaa, 0x29,
		0x1d, 0x4a, 0xe7, 0x87, 0x48, 0xa8, 0xc1, 0x0a, 0x23, 0x85, 0xb4, 0x1e, 0x21, 0x11, 0xa9, 0xa9,
		0xa4, 0xb5, 0x20, 0xb5, 0x8e, 0x2e, 0x45, 0x6a, 0xa9, 0x6c, 0x2d, 0x29, 0xe8, 0x46, 0xa4, 0x88,
		0xca, 0x16, 0x91, 0x8e, 0xae, 0x43, 0xea, 0x48, 0x44, 0x9a, 0x06, 0xdf, 0x5d, 0x48, 0x1d, 0x95,
		0xad, 0x23, 0x1d, 0x5d, 0x84, 0xd4, 0x51, 0xe9, 0xa0, 0xad, 0xa0, 0x5b, 0x90, 0x2a, 0x12, 0x11,
		0xd5, 0x30, 0xbb, 0x02, 0x29, 0x1e, 0x39, 0x48, 0x44, 0xf5, 0x50, 0x3d, 0xdf, 0xab, 0x1e, 0x0d,
		0x5d, 0x7e, 0x54, 0x51, 0xe1, 0x2a, 0xea, 0xf2, 0x84, 0x4b, 0xaa, 0xaa, 0x28, 0x75, 0x79, 0xf6,
		0xeb, 0xdd, 0x06, 0x5b, 0xdb, 0x29, 0xa8, 0x75, 0x09, 0xaa, 0xdb, 0x73, 0x8e, 0xdd, 0x77, 0x1c,
		0x98, 0x4d, 0x55, 0xad, 0x53, 0x55, 0xd3, 0x1d, 0x91, 0xbd, 0xce, 0xa9, 0xe7, 0xf4, 0x38, 0x37,
		0x9b, 0xca, 0x5a, 0x6f, 0x00, 0xa4, 0x9c, 0x28, 0xa7, 0x35, 0x87, 0xbf, 0xe3, 0x96, 0xfd, 0x9a,
		0x73, 0xa8, 0xa8, 0xab, 0x75, 0x06, 0xc0, 0x86, 0x8a, 0x00, 0xc8, 0x69, 0x41, 0x5c, 0xc1, 0x9a,
		0x56, 0xae, 0xb6, 0xcc, 0x9a, 0xc2, 0x61, 0x06, 0x4d, 0xf5, 0x30, 0x53, 0xa6, 0x82, 0x2a, 0x1c,
		0xb8, 0x28, 0x1b, 0xca, 0xa6, 0x5a, 0x99, 0x2f, 0xf5, 0xc3, 0x0c, 0x97, 0x0a, 0xc2, 0x52, 0xd0,
		0x5c, 0x2c, 0x47, 0x76, 0x97, 0xcf, 0xca, 0xa9, 0xab, 0x42, 0xf4, 0xd5, 0xf3, 0xed, 0xd6, 0xeb,
		0x4e, 0xcf, 0xf5, 0xde, 0x9c, 0xb0, 0xba, 0x4b, 0x65, 0xad, 0x55, 0x59, 0xcb, 0xbf, 0xb1, 0xbc,
		0x5b, 0xec, 0x8b, 0xe5, 0x5d, 0x2e, 0xdd, 0xaa, 0x05, 0x03, 0x2a, 0x88, 0x4e, 0xbf, 0x52, 0xce,
		0x1e, 0xc7, 0xc9, 0x63, 0x7c, 0xae, 0xf2, 0xad, 0x94, 0x6d, 0xa1, 0x70, 0x07, 0x6c, 0xd9, 0x51,
		0x34, 0x4a, 0x83, 0x34, 0x1c, 0x45, 0xd6, 0x01, 0x80, 0xeb, 0xb5, 0x92, 0xcb, 0x0f, 0xe6, 0x26,
		0xb8, 0x0d, 0xd2, 0x0f, 0x13, 0x67, 0x5b, 0x1f, 0xdd, 0x9a, 0xe8, 0x72, 0x14, 0x5d, 0x85, 0xd7,
		0xb5, 0xc8, 0xa4, 0x9f, 0x46, 0xf1, 0xc7, 0x5a, 0x18, 0x25, 0x69, 0x10, 0x5d, 0x9a, 0xfa, 0xe3,
		0x37, 0x92, 0x95, 0x77, 0xea, 0xb7, 0xf1, 0x28, 0x1d, 0x5d, 0x8e, 0x86, 0x49, 0xf6, 0x5d, 0x3d,
		0x4c, 0xc2, 0xa4, 0x3e, 0x34, 0x77, 0x66, 0x38, 0xff, 0x52, 0x1f, 0x86, 0xd1, 0xc7, 0x5a, 0x92,
		0x06, 0xa9, 0xa9, 0x0d, 0x82, 0x34, 0xb8, 0x08, 0x12, 0x53, 0x1f, 0x26, 0xb7, 0xf5, 0x74, 0x78,
		0x97, 0x4c, 0xfe, 0xa8, 0xdf, 0xa4, 0xb5, 0xc9, 0x4f, 0xd5, 0x22, 0x13, 0x5e, 0x7f, 0xb8, 0x18,
		0xc5, 0xb5, 0x20, 0x4d, 0xe3, 0xf0, 0x62, 0x9c, 0x4e, 0x6c, 0x98, 0xbd, 0x95, 0x64, 0xdf, 0xd5,
		0x97, 0xe6, 0x64, 0x66, 0x24, 0xe3, 0x8b, 0xe9, 0x3f, 0x36, 0xfb, 0x5a, 0x9f, 0xfe, 0x2e, 0x80,
		0xc2, 0x86, 0x95, 0xa4, 0xf1, 0xf8, 0x32, 0x8d, 0xe6, 0x91, 0xaf, 0x93, 0xdd, 0x8b, 0xf6, 0xec,
		0x73, 0x76, 0xe7, 0xd7, 0xe7, 0x3f, 0xfa, 0x7b, 0xf2, 0xf8, 0x0d, 0xbf, 0xbb, 0xb8, 0x0f, 0xd9,
		0x77, 0xbe, 0x9b, 0x84, 0x89, 0xdf, 0x9a, 0xde, 0x87, 0xd9, 0x17, 0xbf, 0x15, 0x46, 0x1f, 0xfb,
		0x93, 0x8f, 0xa6, 0x39, 0xbf, 0x0b, 0x7e, 0x2b, 0xb9, 0xf5, 0xbd, 0xe1, 0x5d, 0x32, 0xf9, 0xc3,
		0x3f, 0x49, 0x27, 0x3f, 0xd2, 0x9e, 0x7f, 0xcc, 0xf6, 0xe2, 0x16, 0xf8, 0x8b, 0x77, 0x92, 0xec,
		0x3b, 0x7f, 0x69, 0x48, 0x66, 0x41, 0x7f, 0x76, 0x0b, 0xe6, 0x5f, 0xfd, 0xe9, 0xef, 0x91, 0x1d,
		0xab, 0xe5, 0xfa, 0x3d, 0xc1, 0x3e, 0xcf, 0x9a, 0x2c, 0x62, 0x73, 0x15, 0x8c, 0x87, 0x69, 0xed,
		0xc6, 0xa4, 0x71, 0x78, 0x29, 0xde, 0xed, 0x65, 0x64, 0xb9, 0x6a, 0xba, 0xf0, 0xd8, 0xf2, 0x36,
		0x8c, 0x06, 0xd6, 0xc1, 0xc6, 0x96, 0x70, 0x33, 0x8f, 0xa6, 0x3e, 0xcb, 0x3a, 0xd8, 0xd8, 0x14,
		0x6e, 0x68, 0x37, 0x36, 0x57, 0xe1, 0x67, 0x8c, 0x38, 0xbd, 0x10, 0xed, 0xe8, 0x72, 0x1a, 0x1b,
		0x11, 0xa2, 0x59, 0x7f, 0x34, 0x8e, 0x2f, 0x0d, 0xc4, 0xc7, 0x3b, 0x5b, 0x5e, 0xe6, 0xfe, 0xd3,
		0x28, 0x9e, 0xac, 0x30, 0xeb, 0x76, 0xa6, 0x0c, 0x8c, 0x64, 0xdf, 0x7a, 0x13, 0x24, 0x76, 0x7c,
		0x3d, 0xbe, 0x31, 0x51, 0x6a, 0x1d, 0x6c, 0xa4, 0xf1, 0xd8, 0x80, 0x18, 0xfe, 0xc0, 0xea, 0x4c,
		0xd8, 0xcc, 0x8f, 0x54, 0xe7, 0x47, 0xcd, 0x30, 0x06, 0x49, 0x8c, 0xa6, 0xc4, 0x0a, 0xe3, 0xbc,
		0x16, 0xf1, 0x01, 0x25, 0xd7, 0x01, 0x02, 0x1a, 0x38, 0xb0, 0x41, 0x04, 0x1c, 0x60, 0xd0, 0x41,
		0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07, 0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10, 0x30, 0x82, 0x03,
		0xa4, 0xcc, 0x60, 0x90, 0xb2, 0xcf, 0xb3, 0x81, 0x06, 0xa2, 0xf6, 0xf3, 0x1c, 0x3a, 0x6d, 0x82,
		0x99, 0x8d, 0x86, 0x50, 0xc8, 0x28, 0xa5, 0x00, 0xa9, 0xd0, 0xd1, 0x4a, 0x0d, 0x62, 0xa9, 0x41,
		0x2d, 0x1d, 0xc8, 0x85, 0x85, 0x5e, 0x60, 0x08, 0x96, 0x49, 0xc4, 0xbb, 0xbf, 0x35, 0xd8, 0x1e,
		0x7f, 0x1c, 0x46, 0xe9, 0xcb, 0x6d, 0x44, 0x87, 0x3f, 0xe7, 0x9b, 0x3d, 0x40, 0xd3, 0x7b, 0x41,
		0x74, 0x6d, 0x60, 0x3b, 0x11, 0x70, 0xf7, 0x8a, 0x5b, 0x27, 0x61, 0x04, 0x4b, 0x08, 0xe0, 0x60,
		0xbf, 0x72, 0x19, 0xd3, 0x7e, 0x1c, 0x05, 0xd7, 0x71, 0x1c, 0x07, 0x97, 0x69, 0x38, 0x8a, 0x9a,
		0xe1, 0x75, 0x98, 0x26, 0x93, 0x0b, 0x62, 0x03, 0x4b, 0x19, 0x4b, 0x3b, 0xf8, 0xcc, 0xa5, 0x2d,
		0x6c, 0x69, 0x37, 0xb6, 0xf7, 0x1b, 0xfb, 0xbb, 0x7b, 0xdb, 0xfb, 0x3b, 0x5c, 0xe3, 0x4c, 0x08,
		0xaa, 0x65, 0x35, 0x56, 0xef, 0xd3, 0x17, 0x3e, 0x4b, 0xa8, 0x62, 0x24, 0x45, 0xdb, 0x8c, 0x9e,
		0xd9, 0x5d, 0x85, 0x4d, 0xe9, 0x2b, 0xbb, 0x4f, 0xeb, 0x48, 0x5b, 0x37, 0x36, 0x74, 0x6f, 0x57,
		0xf7, 0x4c, 0x73, 0x76, 0x6f, 0x4e, 0xa6, 0xb7, 0x06, 0x61, 0xfb, 0x3a, 0x8e, 0x07, 0xe5, 0x06,
		0xba, 0x0a, 0xf9, 0xf4, 0x6a, 0xfa, 0x72, 0x36, 0x1b, 0x09, 0xf2, 0xde, 0x6c, 0x3b, 0x52, 0xe7,
		0x09, 0xad, 0x14, 0xe1, 0xd1, 0xcc, 0xb2, 0xd3, 0x68, 0x62, 0x2d, 0x46, 0x73, 0xd1, 0x26, 0x9b,
		0x8b, 0xd6, 0x63, 0x28, 0x9b, 0x8b, 0x72, 0x35, 0x99, 0xcd, 0x45, 0x05, 0x19, 0xce, 0xe6, 0x22,
		0xd2, 0x00, 0x4a, 0x6e, 0x04, 0xb3, 0x61, 0x23, 0xf3, 0xb8, 0x43, 0x13, 0x5c, 0xc5, 0xe6, 0x0a,
		0xc1, 0xe3, 0x2e, 0x9a, 0x75, 0x00, 0xb6, 0x64, 0x58, 0xdd, 0x79, 0xba, 0xf9, 0xe2, 0xc5, 0xac,
		0xaa, 0x56, 0x9f, 0x12, 0x18, 0xf3, 0x00, 0x75, 0x79, 0xc0, 0x78, 0x92, 0xb4, 0x26, 0x69, 0x1c,
		0x84, 0x91, 0x19, 0xd4, 0x86, 0xc9, 0x2d, 0x4e, 0x52, 0xb0, 0x6a, 0x3a, 0xc7, 0x0f, 0x30, 0x43,
		0x60, 0x86, 0xc0, 0x0c, 0x81, 0x19, 0x02, 0x33, 0x04, 0x66, 0x08, 0xb9, 0xdc, 0x72, 0x8e, 0x1f,
		0xc8, 0x37, 0x3e, 0x70, 0xfc, 0x00, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0,
		0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83,
		0x2f, 0x47, 0xe3, 0xa9, 0x70, 0x41, 0xa7, 0x0f, 0xcc, 0xcc, 0xe7, 0xf0, 0x01, 0x02, 0x94, 0x2e,
		0x90, 0x52, 0x00, 0x54, 0xe8, 0x60, 0xa5, 0x06, 0xb0, 0xd4, 0x80, 0x96, 0x0e, 0xe0, 0xc2, 0x02,
		0x2f, 0x30, 0x00, 0xcb, 0x24, 0xa2, 0x63, 0xf8, 0xc0, 0xd6, 0x2e, 0xf0, 0xf0, 0x81, 0x5d, 0x0e,
		0x1f, 0x28, 0xf8, 0xc5, 0xe1, 0x03, 0x04, 0xfb, 0x35, 0x5c, 0x06, 0x87, 0x0f, 0x30, 0xfc, 0xae,
		0x73, 0x69, 0x73, 0xf8, 0x80, 0xb8, 0xa5, 0xbd, 0xbb, 0xb3, 0xf3, 0x92, 0x73, 0x07, 0x98, 0x0b,
		0x54, 0xcc, 0x6a, 0xce, 0x1d, 0xa8, 0x7c, 0x78, 0xc2, 0xe8, 0x7d, 0x7a, 0x36, 0x2b, 0x04, 0xe8,
		0x85, 0x52, 0x12, 0x3b, 0x59, 0xef, 0x2e, 0x53, 0xe7, 0xac, 0x77, 0x97, 0xb7, 0x5c, 0x59, 0xef,
		0x16, 0x76, 0x21, 0xac, 0x77, 0x93, 0x68, 0xbe, 0x21, 0x11, 0xfc, 0x7a, 0x77, 0x38, 0x30, 0x51,
		0x1a, 0xa6, 0xf7, 0x18, 0xfd, 0x5c, 0xcf, 0x41, 0xce, 0x16, 0x60, 0x56, 0x6d, 0xb9, 0xf3, 0x8f,
		0xfe, 0x30, 0x48, 0x80, 0xe3, 0xd6, 0x42, 0x48, 0x6e, 0xdf, 0xed, 0xfb, 0xfd, 0xd3, 0x43, 0xaf,
		0x75, 0xe6, 0x7b, 0xef, 0xbb, 0x0e, 0x6a, 0xf8, 0x9a, 0xd6, 0x6a, 0x12, 0xd8, 0x87, 0x11, 0x1b,
		0xd0, 0x0f, 0x24, 0x1e, 0x29, 0xca, 0xef, 0x39, 0xf6, 0xd1, 0x1b, 0xfb, 0xd0, 0x6d, 0xb9, 0xde,
		0xfb, 0xb9, 0xb8, 0xfa, 0xc8, 0xea, 0xd2, 0xa4, 0x32, 0x1d, 0x6a, 0xfb, 0xa6, 0xea, 0x0e, 0xed,
		0x76, 0xf3, 0xdf, 0x6e, 0xd3, 0x7b, 0xe3, 0x1f, 0x75, 0xda, 0x7d, 0xaf, 0x67, 0xbb, 0x6d, 0xaf,
		0x6f, 0xc1, 0x5f, 0xf3, 0x97, 0x5f, 0x29, 0x3c, 0xd9, 0xc2, 0x3b, 0xf5, 0xdc, 0x96, 0xfb, 0x1f,
		0xa7, 0xb9, 0x54, 0x20, 0x55, 0x47, 0xd5, 0xe5, 0xad, 0x3a, 0xbb, 0xf9, 0x9b, 0xdf, 0x77, 0x9b,
		0x94, 0x1a, 0xa5, 0x96, 0xbb, 0xd4, 0xce, 0x6c, 0xb7, 0x65, 0x1f, 0xb6, 0x1c, 0x7a, 0x38, 0xca,
		0xae, 0x38, 0xd9, 0xb9, 0xdd, 0xb3, 0x5d, 0xbf, 0xed, 0xb8, 0xaf, 0xdf, 0x1c, 0x76, 0x7a, 0xbe,
		0xdd, 0x6c, 0xf6, 0x9c, 0x3e, 0x81, 0x8e, 0xc2, 0xcb, 0x1f, 0xe8, 0xda, 0x59, 0x06, 0xe1, 0x34,
		0xfd, 0x56, 0xbf, 0x4b, 0xd1, 0x51, 0x74, 0x79, 0x8b, 0xae, 0xe5, 0xb6, 0xdf, 0xfa, 0xb6, 0xe7,
		0xf5, 0xdc, 0xc3, 0x53, 0xcf, 0xa1, 0x9f, 0xa3, 0xe4, 0x8a, 0x91, 0x5c, 0xb7, 0xd7, 0xf1, 0x9c,
		0x23, 0xcf, 0xed, 0xb4, 0x67, 0xf5, 0x3a, 0xea, 0x8e, 0xba, 0xcb, 0x3d, 0x75, 0x3d, 0x71, 0xdb,
		0xfe, 0xeb, 0x5e, 0xe7, 0x94, 0x91, 0x95, 0x72, 0x2b, 0x26, 0x8f, 0x70, 0xdb, 0x9e, 0xd3, 0x3b,
		0xb6, 0x8f, 0x1c, 0x26, 0x12, 0x54, 0x5e, 0x51, 0xca, 0x3b, 0xb1, 0xdf, 0xcd, 0x82, 0x2c, 0xeb,
		0x26, 0x54, 0x5d, 0x81, 0xe1, 0xf5, 0x37, 0xbf, 0x65, 0xb7, 0x59, 0x1d, 0xa6, 0xdc, 0x0a, 0xcb,
		0x22, 0x28, 0x35, 0x4a, 0xad, 0x10, 0x92, 0x6b, 0xb0, 0x22, 0x4c, 0xe1, 0x95, 0x23, 0x3c, 0xa6,
		0x10, 0x54, 0x5e, 0x29, 0x29, 0x44, 0xcf, 0xe9, 0x3b, 0xbd, 0x33, 0x3e, 0x80, 0xa5, 0xf6, 0x8a,
		0xd5, 0x9e, 0xe7, 0xf8, 0x4d, 0xe7, 0xd8, 0x3e, 0x6d, 0x79, 0xfe, 0x89, 0xe3, 0xf5, 0xdc, 0x23,
		0x8a, 0x8e, 0xa2, 0xcb, 0x5b, 0x74, 0xa7, 0xed, 0x99, 0xbb, 0xe3, 0x7e, 0x3a, 0xea, 0xae, 0xf0,
		0x34, 0xb6, 0xe9, 0xb4, 0xec, 0xf7, 0xfe, 0x99, 0xdd, 0x73, 0x6d, 0xcf, 0xed, 0xb4, 0xa9, 0x3b,
		0xea, 0x2e, 0x6f, 0xdd, 0x39, 0xef, 0x3c, 0xa7, 0xdd, 0x74, 0x9a, 0x7c, 0x2a, 0x46, 0xdd, 0x15,
		0x9a, 0x58, 0xb8, 0xed, 0xe5, 0xf3, 0x89, 0xa9, 0xdf, 0xa3, 0xea, 0xa8, 0xba, 0x42, 0xa2, 0x6c,
		0xab, 0xc3, 0xda, 0x09, 0xc5, 0x56, 0x24, 0xd2, 0x51, 0x6d, 0x54, 0x5b, 0xde, 0x6a, 0xeb, 0x39,
		0x7d, 0xb7, 0x79, 0x6a, 0xb7, 0x54, 0xa5, 0xad, 0xd0, 0x57, 0x70, 0xce, 0x79, 0x96, 0x5c, 0xe5,
		0x6b, 0x5a, 0xdd, 0xca, 0xba, 0x8b, 0x29, 0x30, 0x69, 0x02, 0xd3, 0xd4, 0x45, 0x4c, 0x75, 0x49,
		0x53, 0x17, 0x7c, 0xb7, 0x30, 0x25, 0x25, 0x4e, 0x52, 0x9a, 0xba, 0x82, 0x29, 0x2f, 0x69, 0xf2,
		0x52, 0xd6, 0xfd, 0x4b, 0x81, 0x89, 0x03, 0x2e, 0x3d, 0x5d, 0xbe, 0x14, 0x97, 0x34, 0x71, 0xa9,
		0xe9, 0xe6, 0xa5, 0xb4, 0x44, 0x4a, 0x4b, 0x4d, 0xd7, 0x2e, 0xf5, 0x25, 0x2f, 0x55, 0x54, 0xb0,
		0x0f, 0x81, 0xb2, 0x12, 0xc9, 0xf3, 0x8a, 0xb6, 0xd0, 0x53, 0x61, 0xd2, 0x14, 0xa6, 0xa9, 0xdb,
		0x96, 0xea, 0x92, 0x17, 0x16, 0x15, 0x74, 0xd5, 0x52, 0x56, 0x22, 0x69, 0x9e, 0x92, 0xa2, 0xa4,
		0xd6, 0x4a, 0x5a, 0x0d, 0x56, 0x4e, 0x29, 0xb0, 0x7c, 0x05, 0x46, 0x94, 0xa7, 0xc2, 0x72, 0x45,
		0x79, 0x5d, 0x5d, 0xaf, 0xd4, 0x98, 0x34, 0x8d, 0x29, 0xea, 0x6e, 0xa5, 0xb8, 0xa4, 0x89, 0x4b,
		0x57, 0x17, 0x2b, 0xf5, 0x25, 0x32, 0x6d, 0x54, 0xd3, 0xad, 0x4a, 0x7d, 0x49, 0xd3, 0x97, 0xae,
		0xae, 0x54, 0xea, 0x4b, 0x1c, 0xe0, 0x2b, 0xea, 0x3e, 0xa5, 0xba, 0x44, 0x46, 0x47, 0xec, 0x2e,
		0x53, 0x8a, 0x4a, 0x2e, 0x72, 0x51, 0x55, 0x54, 0xd5, 0xba, 0x54, 0xa5, 0xa9, 0x6b, 0x94, 0xea,
		0x2a, 0x5d, 0x5d, 0x5d, 0x9e, 0xc4, 0x4b, 0xb5, 0x95, 0xad, 0x3a, 0xcf, 0x7e, 0xbd, 0xdb, 0xe0,
		0xc8, 0x05, 0x0a, 0x2d, 0x6f, 0xa1, 0x75, 0x7b, 0xce, 0xb1, 0xfb, 0x8e, 0x83, 0xee, 0xa9, 0xb6,
		0x22, 0xd4, 0x36, 0xdd, 0xc1, 0xda, 0xeb, 0x9c, 0x7a, 0x4e, 0x8f, 0xf3, 0xee, 0xa9, 0xb8, 0x62,
		0x02, 0x29, 0x65, 0x46, 0x99, 0x15, 0x14, 0x46, 0x8f, 0x5b, 0xf6, 0x6b, 0xce, 0x65, 0xa3, 0xde,
		0x8a, 0x08, 0xa4, 0x0d, 0x55, 0x81, 0x94, 0x53, 0xb2, 0xb8, 0xd2, 0xab, 0xb4, 0xc2, 0xb5, 0x66,
		0xfe, 0x14, 0x14, 0x33, 0x7c, 0xaa, 0x4a, 0xbf, 0xaa, 0xb4, 0x64, 0xf2, 0x54, 0x16, 0x33, 0x76,
		0xca, 0x49, 0x7f, 0xf8, 0x03, 0xcf, 0xcc, 0xa9, 0x2b, 0x66, 0xe0, 0x54, 0x96, 0x4e, 0x65, 0xcd,
		0x45, 0x74, 0x64, 0x77, 0xb9, 0xe7, 0x80, 0x7a, 0x2b, 0x55, 0x77, 0x3d, 0xdf, 0x6e, 0xbd, 0xee,
		0xf4, 0x5c, 0xef, 0xcd, 0x09, 0xab, 0xd8, 0x54, 0x5c, 0x21, 0x8a, 0x5b, 0xfe, 0x8d, 0x65, 0xec,
		0x72, 0x5f, 0x2c, 0x63, 0x73, 0x89, 0x33, 0x98, 0x50, 0x59, 0x0c, 0x1a, 0x0c, 0x16, 0x8a, 0x82,
		0x04, 0xd6, 0xe7, 0x8c, 0x63, 0x2d, 0x86, 0xa5, 0x20, 0x0e, 0xdc, 0xb2, 0xa3, 0x68, 0x94, 0x06,
		0x69, 0x38, 0x8a, 0xac, 0x03, 0x20, 0xd7, 0x6d, 0x25, 0x97, 0x1f, 0xcc, 0x4d, 0x70, 0x1b, 0xa4,
		0x1f, 0x26, 0xce, 0xba, 0x3e, 0xba, 0x35, 0xd1, 0xe5, 0x28, 0xba, 0x0a, 0xaf, 0x6b, 0x91, 0x49,
		0x3f, 0x8d, 0xe2, 0x8f, 0xb5, 0x30, 0x4a, 0xd2, 0x20, 0xba, 0x34, 0xf5, 0xc7, 0x6f, 0x24, 0x2b,
		0xef, 0xd4, 0x6f, 0xe3, 0x51, 0x3a, 0xba, 0x1c, 0x0d, 0x93, 0xec, 0xbb, 0x7a, 0x98, 0x84, 0x49,
		0x7d, 0x68, 0xee, 0xcc, 0x70, 0xfe, 0xa5, 0x3e, 0x0c, 0xa3, 0x8f, 0xb5, 0x24, 0x0d, 0x52, 0x53,
		0x1b, 0x04, 0x69, 0x70, 0x11, 0x24, 0xa6, 0x3e, 0x4c, 0x6e, 0xeb, 0xe9, 0xf0, 0x2e, 0x99, 0xfc,
		0x51, 0xbf, 0x49, 0x6b, 0x93, 0x9f, 0xaa, 0x45, 0x26, 0xbc, 0xfe, 0x70, 0x31, 0x8a, 0x6b, 0x41,
		0x9a, 0xc6, 0xe1, 0xc5, 0x38, 0x9d, 0xd8, 0x30, 0x7b, 0x2b, 0xc9, 0xbe, 0xab, 0x2f, 0xcd, 0xc9,
		0xcc, 0x48, 0xc6, 0x17, 0xd3, 0x7f, 0x6c, 0xf6, 0xb5, 0x3e, 0x9e, 0x5c, 0x52, 0x92, 0xc6, 0x41,
		0x18, 0x99, 0x41, 0x6d, 0xf2, 0xab, 0xa6, 0xbf, 0x1d, 0xa8, 0x34, 0x63, 0x25, 0x69, 0x3c, 0xbe,
		0x4c, 0xa3, 0x79, 0x4c, 0xed, 0x64, 0x77, 0xa9, 0x3d, 0xbb, 0x03, 0xee, 0xfc, 0xca, 0xfd, 0x47,
		0x7f, 0x4f, 0x1e, 0xbf, 0xe1, 0x77, 0x17, 0x77, 0x28, 0xfb, 0xce, 0x77, 0x93, 0x30, 0xf1, 0x5b,
		0xd3, 0x3b, 0x34, 0xfb, 0xe2, 0xb7, 0xc2, 0xe8, 0x63, 0x7f, 0xf2, 0x11, 0x35, 0xe7, 0xf7, 0xc7,
		0x6f, 0x25, 0xb7, 0xbe, 0x37, 0xbc, 0x4b, 0x26, 0x7f, 0xf8, 0x27, 0xe9, 0xe4, 0x47, 0xda, 0xf3,
		0x1b, 0x60, 0x2f, 0x6e, 0x8e, 0xbf, 0x78, 0x27, 0xc9, 0xbe, 0xf3, 0x97, 0x86, 0x64, 0x16, 0xf4,
		0x67, 0x37, 0x67, 0xfe, 0xd5, 0x3f, 0x7d, 0x78, 0x73, 0x26, 0xbf, 0x66, 0xfa, 0x8b, 0x31, 0xb0,
		0x40, 0xbe, 0x0b, 0x95, 0x6d, 0xa1, 0x70, 0xe7, 0x8e, 0xe6, 0xd4, 0xab, 0xe9, 0xcc, 0x01, 0xdc,
		0x78, 0x85, 0xdc, 0xb7, 0x6c, 0xc7, 0x2d, 0xd7, 0x1d, 0x0a, 0x76, 0x85, 0xd6, 0x38, 0x8a, 0x4d,
		0x62, 0xe2, 0x3b, 0x33, 0xa8, 0x5d, 0x04, 0xd1, 0xe0, 0x53, 0x38, 0x98, 0x3a, 0x18, 0xd9, 0x0e,
		0x31, 0x2b, 0x40, 0x3c, 0x69, 0xbd, 0xf0, 0xc0, 0xf3, 0x36, 0x8c, 0x06, 0xd6, 0xc1, 0xc6, 0x96,
		0x70, 0x33, 0x8f, 0xa6, 0x4e, 0xcc, 0x3a, 0xd8, 0xd8, 0x14, 0x6e, 0x68, 0x37, 0x36, 0x57, 0xe1,
		0x67, 0x8c, 0x20, 0xbe, 0xd0, 0xed, 0xe8, 0x72, 0x1a, 0x38, 0x11, 0xc2, 0x5b, 0x7f, 0x34, 0x8e,
		0x2f, 0x0d, 0x4c, 0xe2, 0x6b, 0xbd, 0x35, 0xf7, 0x9f, 0x46, 0xf1, 0x64, 0x85, 0x59, 0xb7, 0x33,
		0x65, 0x80, 0x54, 0x19, 0xde, 0x04, 0x89, 0x1d, 0x5f, 0x8f, 0x6f, 0x4c, 0x94, 0x5a, 0x07, 0x1b,
		0x69, 0x3c, 0x36, 0x28, 0xe5, 0x91, 0xa5, 0xd5, 0x99, 0xb0, 0x99, 0x3c, 0xa9, 0x4e, 0x9e, 0x9a,
		0x61, 0x0c, 0x92, 0x35, 0x99, 0x74, 0x7c, 0x5b, 0xbb, 0x8d, 0xc3, 0x51, 0x1c, 0xa6, 0xf7, 0x38,
		0x5e, 0x6c, 0x11, 0x28, 0x1e, 0xd9, 0x0f, 0xe2, 0x11, 0x30, 0x10, 0x07, 0x0e, 0x75, 0x10, 0x91,
		0x07, 0x18, 0x7d, 0x50, 0x11, 0x08, 0x1e, 0x85, 0xe0, 0x91, 0x08, 0x1b, 0x8d, 0x30, 0x10, 0x09,
		0x04, 0x95, 0xe0, 0x90, 0x29, 0x33, 0x18, 0x0e, 0x9a, 0x56, 0x42, 0x0d, 0x18, 0x36, 0x3d, 0xc6,
		0xa7, 0x4d, 0x30, 0xb3, 0xd1, 0x30, 0x0a, 0x19, 0xa7, 0x14, 0x60, 0x15, 0x3a, 0x5e, 0xa9, 0xc1,
		0x2c, 0x35, 0xb8, 0xa5, 0x03, 0xbb, 0xb0, 0xf0, 0x0b, 0x0c, 0xc3, 0x32, 0x89, 0x78, 0xf7, 0xb7,
		0x06, 0xdb, 0xe3, 0x0f, 0x4d, 0x70, 0x15, 0x9b, 0x2b, 0x44, 0x8f, 0xbf, 0xa8, 0x0f, 0xed, 0x01,
		0xda, 0xde, 0x9d, 0xef, 0xc0, 0x78, 0xf1, 0x62, 0xb6, 0xd3, 0xac, 0x9e, 0x51, 0x26, 0xf7, 0xb2,
		0x56, 0xdd, 0xb3, 0x58, 0xb3, 0xbd, 0x87, 0xb0, 0x09, 0x13, 0xda, 0xd6, 0xc9, 0x0d, 0xbc, 0x62,
		0x33, 0xb3, 0x25, 0x66, 0x4b, 0xcc, 0x96, 0x98, 0x2d, 0x31, 0x5b, 0x62, 0xb6, 0x84, 0x23, 0x11,
		0xb4, 0xe2, 0x75, 0x66, 0x38, 0xce, 0x9e, 0xc6, 0x6f, 0xc6, 0x2c, 0x94, 0x0d, 0x8e, 0xdf, 0x02,
		0xb5, 0x4d, 0x50, 0xf3, 0x51, 0x81, 0x4d, 0x03, 0xb8, 0x29, 0x02, 0x38, 0x2d, 0x20, 0xa7, 0x0e,
		0xe8, 0xd4, 0x81, 0x9d, 0x2e, 0xc0, 0xc3, 0x04, 0x3d, 0x50, 0xe0, 0xcb, 0xa4, 0x03, 0x5b, 0x26,
		0x5f, 0x89, 0x18, 0xa1, 0x31, 0xe6, 0x6a, 0x38, 0x0a, 0xd2, 0x97, 0xdb, 0xc8, 0x51, 0x63, 0x0e,
		0x51, 0xfb, 0xc0, 0x97, 0xd0, 0x32, 0xd1, 0xf5, 0x14, 0xc8, 0xb1, 0xc7, 0xce, 0xe1, 0x0f, 0x00,
		0xb3, 0x4e, 0xc2, 0x08, 0x9e, 0x3f, 0x94, 0xa4, 0x17, 0x2b, 0x97, 0x33, 0x1d, 0xce, 0x68, 0x1d,
		0x6c, 0x34, 0x94, 0x5c, 0xcf, 0x71, 0x1c, 0x5c, 0xa6, 0xe1, 0x28, 0x6a, 0x86, 0xd7, 0x61, 0x9a,
		0x4c, 0x6e, 0x14, 0xa7, 0x18, 0x4a, 0x70, 0x01, 0xc1, 0x67, 0xba, 0x00, 0xba, 0x00, 0xba, 0x80,
		0x2a, 0x65, 0x23, 0xf8, 0xd6, 0x63, 0xce, 0xc3, 0xc4, 0xfb, 0xbc, 0x01, 0x43, 0x1c, 0xee, 0xc6,
		0xf5, 0x95, 0x9c, 0x15, 0x74, 0x03, 0xbb, 0x92, 0x78, 0xcc, 0x8a, 0xbf, 0xa4, 0xb5, 0xc0, 0x8a,
		0xbf, 0x9c, 0x65, 0xcd, 0x8a, 0xbf, 0xf0, 0x0b, 0x62, 0xc5, 0x9f, 0xe4, 0xf4, 0x83, 0xd2, 0xd1,
		0x53, 0xf1, 0x1f, 0x87, 0x51, 0xfa, 0x4a, 0x41, 0xad, 0x7f, 0x07, 0xf8, 0x12, 0x7a, 0x41, 0x74,
		0x6d, 0x58, 0xea, 0x2f, 0xff, 0x46, 0xb0, 0xd4, 0x2f, 0xf7, 0x72, 0x16, 0x75, 0xbe, 0x4d, 0xd6,
		0xf9, 0x18, 0xcd, 0x73, 0x74, 0x01, 0x2c, 0xf5, 0x8b, 0x77, 0x01, 0x7b, 0x74, 0x01, 0x4c, 0x43,
		0x68, 0xfd, 0xc3, 0x17, 0x4b, 0xfd, 0xb4, 0x18, 0x3e, 0x20, 0xa3, 0x9e, 0x21, 0x92, 0xd9, 0x5f,
		0x8d, 0xf1, 0xf3, 0xab, 0xd3, 0xa4, 0xeb, 0x5f, 0x4f, 0x60, 0xac, 0x23, 0xb6, 0xc8, 0x6e, 0x68,
		0x1f, 0x53, 0xbf, 0xb8, 0x6d, 0x87, 0x8b, 0xbb, 0xe6, 0xf7, 0x27, 0x77, 0xad, 0x3b, 0xbf, 0x69,
		0x48, 0xc7, 0x8e, 0xe0, 0x79, 0x63, 0x8e, 0x89, 0x5b, 0x6b, 0x5e, 0x63, 0xee, 0x01, 0x9f, 0xfc,
		0x5a, 0xad, 0x30, 0x49, 0x27, 0xcb, 0x18, 0x6b, 0xc4, 0xdd, 0x49, 0x18, 0x39, 0x43, 0x73, 0x63,
		0xa2, 0x59, 0x8a, 0x02, 0x34, 0x68, 0xe2, 0x24, 0xf8, 0xfc, 0xc0, 0xf2, 0xad, 0x57, 0x8d, 0xc6,
		0xee, 0x5e, 0xa3, 0xb1, 0xb9, 0xf7, 0x72, 0x6f, 0x73, 0x7f, 0x67, 0x67, 0x6b, 0x77, 0x0b, 0xa8,
		0x68, 0x6c, 0x75, 0xe2, 0x81, 0x89, 0xcd, 0xe0, 0x70, 0xa2, 0xfc, 0x68, 0x3c, 0x1c, 0xd2, 0xa1,
		0x10, 0x3c, 0x09, 0x9c, 0x70, 0x5b, 0x7f, 0xaa, 0x8c, 0x98, 0x3c, 0xd3, 0xae, 0x0a, 0x16, 0xf2,
		0x4c, 0x3b, 0xfa, 0xf8, 0x75, 0xf8, 0x78, 0x1e, 0x6b, 0x27, 0xcc, 0x99, 0xf3, 0x64, 0x3b, 0x75,
		0x0e, 0xd1, 0x1a, 0xa7, 0xe1, 0x30, 0xfc, 0x3f, 0xd0, 0x73, 0xed, 0x56, 0x6d, 0xe7, 0xa9, 0x76,
		0xeb, 0x30, 0x93, 0xa7, 0xda, 0xe5, 0xa8, 0x5a, 0x9e, 0x6a, 0x97, 0x67, 0x59, 0x90, 0xa7, 0xda,
		0x15, 0xcb, 0xd2, 0x3c, 0xd5, 0xae, 0x6a, 0xe9, 0x13, 0xce, 0xa9, 0x76, 0x50, 0x63, 0x86, 0x21,
		0xc7, 0x0b, 0xf3, 0x0c, 0x3b, 0x02, 0x8e, 0x02, 0xd0, 0x41, 0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07,
		0x20, 0x6c, 0x10, 0xc2, 0x00, 0x22, 0x10, 0x30, 0x82, 0x03, 0xa4, 0xcc, 0x60, 0xdc, 0xf1, 0xbf,
		0xf0, 0x63, 0x7f, 0x79, 0x8a, 0x1d, 0x81, 0xaa, 0x02, 0x60, 0x85, 0x0e, 0x58, 0x6a, 0x40, 0x4b,
		0x0d, 0x70, 0xe9, 0x00, 0x2f, 0x2c, 0x00, 0x03, 0x03, 0xb1, 0x4c, 0x22, 0xf8, 0xa7, 0xd8, 0x61,
		0x8f, 0xe5, 0x05, 0x1e, 0xc7, 0x8b, 0x3e, 0x86, 0x17, 0x78, 0x40, 0x85, 0x86, 0x5e, 0x7c, 0x25,
		0x0d, 0xb8, 0x5a, 0x66, 0x6c, 0x6a, 0x6a, 0xb8, 0x05, 0xee, 0xb5, 0x57, 0xd1, 0x63, 0xcf, 0xa5,
		0xcd, 0xa5, 0xcd, 0x6c, 0x00, 0xda, 0xea, 0x73, 0xf6, 0x3a, 0x56, 0x3d, 0x34, 0x59, 0x29, 0x62,
		0x6e, 0x98, 0xe5, 0x85, 0x53, 0xeb, 0x59, 0xf1, 0x2e, 0xc2, 0x6c, 0x56, 0xbc, 0x4b, 0xd4, 0x39,
		0x2b, 0xde, 0xe5, 0x2d, 0x57, 0x56, 0xbc, 0x85, 0x5d, 0x08, 0x2b, 0xde, 0x24, 0x9a, 0x6f, 0x48,
		0x44, 0x41, 0xc5, 0x7b, 0x60, 0xa2, 0x34, 0x4c, 0xef, 0x63, 0x73, 0x05, 0x5c, 0xf1, 0xde, 0x02,
		0x9c, 0x4a, 0x6b, 0xb9, 0xf3, 0x8f, 0xfe, 0x30, 0x48, 0x0c, 0xfe, 0xe9, 0x10, 0x6e, 0xdf, 0xed,
		0xfb, 0xfd, 0xd3, 0x43, 0xaf, 0x75, 0xe6, 0x7b, 0xef, 0xbb, 0x0e, 0x6a, 0xf8, 0x9a, 0xd6, 0x69,
		0x12, 0xe8, 0x21, 0xc1, 0xe0, 0x05, 0xbf, 0xa5, 0xa2, 0xfc, 0x9e, 0x63, 0x1f, 0xbd, 0xb1, 0x0f,
		0xdd, 0x96, 0xeb, 0xbd, 0x9f, 0x8b, 0xab, 0x8f, 0xac, 0x2e, 0x4d, 0x2a, 0xd3, 0xa1, 0xb6, 0x6f,
		0xaa, 0xee, 0xd0, 0x6e, 0x37, 0xff, 0xed, 0x36, 0xbd, 0x37, 0xfe, 0x51, 0xa7, 0xdd, 0xf7, 0x7a,
		0xb6, 0xdb, 0xf6, 0xfa, 0x16, 0x47, 0x08, 0x53, 0x78, 0x39, 0x0b, 0xef, 0xd4, 0x73, 0x5b, 0xee,
		0x7f, 0x9c, 0xe6, 0x52, 0x81, 0x54, 0x1d, 0x55, 0x97, 0xb7, 0xea, 0xec, 0xe6, 0x6f, 0x7e, 0xdf,
		0x6d, 0x52, 0x6a, 0x94, 0x5a, 0xee, 0x52, 0x3b, 0xb3, 0xdd, 0x96, 0x7d, 0xd8, 0x72, 0xe8, 0xe1,
		0x28, 0xbb, 0xe2, 0x64, 0xe7, 0x76, 0xcf, 0x76, 0xfd, 0xb6, 0xe3, 0xbe, 0x7e, 0x73, 0xd8, 0xe9,
		0xf9, 0x76, 0xb3, 0xd9, 0x73, 0xfa, 0x04, 0x3a, 0x0a, 0x2f, 0x7f, 0xa0, 0x6b, 0x67, 0x19, 0x84,
		0xd3, 0xf4, 0x5b, 0xfd, 0x2e, 0x45, 0x47, 0xd1, 0xe5, 0x2d, 0xba, 0x96, 0xdb, 0x7e, 0xeb, 0xdb,
		0x9e, 0xd7, 0x73, 0x0f, 0x4f, 0x3d, 0x87, 0x7e, 0x8e, 0x92, 0x2b, 0x46, 0x72, 0xdd, 0x5e, 0xc7,
		0x73, 0x8e, 0x3c, 0xb7, 0xd3, 0x9e, 0xd5, 0xeb, 0xa8, 0x3b, 0xea, 0x2e, 0xf7, 0xd4, 0xf5, 0xc4,
		0x6d, 0xfb, 0xaf, 0x7b, 0x9d, 0x53, 0x46, 0x56, 0xca, 0xad, 0x98, 0x3c, 0xc2, 0x6d, 0x7b, 0x4e,
		0xef, 0xd8, 0x3e, 0x72, 0x98, 0x48, 0x50, 0x79, 0x45, 0x29, 0xef, 0xc4, 0x7e, 0x37, 0x0b, 0xb2,
		0xac, 0x9b, 0x50, 0x75, 0x05, 0x86, 0xd7, 0xdf, 0xfc, 0x96, 0xdd, 0x66, 0x75, 0x98, 0x72, 0x2b,
		0x2c, 0x8b, 0xa0, 0xd4, 0x28, 0xb5, 0x42, 0x48, 0xae, 0xc1, 0x8a, 0x30, 0x85, 0x57, 0x8e, 0xf0,
		0x98, 0x42, 0x50, 0x79, 0xa5, 0xa4, 0x10, 0x3d, 0xa7, 0xef, 0xf4, 0xce, 0xf8, 0x00, 0x96, 0xda,
		0x2b, 0x56, 0x7b, 0x9e, 0xe3, 0x37, 0x9d, 0x63, 0xfb, 0xb4, 0xe5, 0xf9, 0x27, 0x8e, 0xd7, 0x73,
		0x8f, 0x28, 0x3a, 0x8a, 0x2e, 0x6f, 0xd1, 0x9d, 0xb6, 0x67, 0xee, 0x8e, 0xfb, 0xe9, 0xa8, 0xbb,
		0xc2, 0xd3, 0xd8, 0xa6, 0xd3, 0xb2, 0xdf, 0xfb, 0x67, 0x76, 0xcf, 0xb5, 0x3d, 0xb7, 0xd3, 0xa6,
		0xee, 0xa8, 0xbb, 0xbc, 0x75, 0xe7, 0xbc, 0xf3, 0x9c, 0x76, 0xd3, 0x69, 0xf2, 0xa9, 0x18, 0x75,
		0x57, 0x68, 0x62, 0xe1, 0xb6, 0x97, 0xcf, 0x27, 0xa6, 0x7e, 0x8f, 0xaa, 0xa3, 0xea, 0x0a, 0x89,
		0xb2, 0xad, 0x0e, 0x6b, 0x27, 0x14, 0x5b, 0x91, 0x48, 0x47, 0xb5, 0x51, 0x6d, 0x79, 0xab, 0xad,
		0xe7, 0xf4, 0xdd, 0xe6, 0xa9, 0xdd, 0x52, 0x95, 0xb6, 0x42, 0x5f, 0xc1, 0x39, 0x67, 0x59, 0x72,
		0x95, 0xaf, 0x69, 0x75, 0x2b, 0xeb, 0x2e, 0xa6, 0xc0, 0xa4, 0x09, 0x4c, 0x53, 0x17, 0x31, 0xd5,
		0x25, 0x4d, 0x5d, 0xf0, 0xdd, 0xc2, 0x94, 0x94, 0x38, 0x49, 0x69, 0xea, 0x0a, 0xa6, 0xbc, 0xa4,
		0xc9, 0x4b, 0x59, 0xf7, 0x2f, 0x05, 0x26, 0x0e, 0xb8, 0xf4, 0x74, 0xf9, 0x52, 0x5c, 0xd2, 0xc4,
		0xa5, 0xa6, 0x9b, 0x97, 0xd2, 0x12, 0x29, 0x2d, 0x35, 0x5d, 0xbb, 0xd4, 0x97, 0xbc, 0x54, 0x51,
		0xc1, 0x3e, 0x04, 0xca, 0x4a, 0x24, 0xcf, 0x2b, 0xda, 0x42, 0x4f, 0x85, 0x49, 0x53, 0x98, 0xa6,
		0x6e, 0x5b, 0xaa, 0x4b, 0x5e, 0x58, 0x54, 0xd0, 0x55, 0x4b, 0x59, 0x89, 0xa4, 0x79, 0x4a, 0x8a,
		0x92, 0x5a, 0x2b, 0x69, 0x35, 0x58, 0x39, 0xa5, 0xc0, 0xf2, 0x15, 0x18, 0x51, 0x9e, 0x0a, 0xcb,
		0x15, 0xe5, 0x75, 0x75, 0xbd, 0x52, 0x63, 0xd2, 0x34, 0xa6, 0xa8, 0xbb, 0x95, 0xe2, 0x92, 0x26,
		0x2e, 0x5d, 0x5d, 0xac, 0xd4, 0x97, 0xc8, 0xb4, 0x51, 0x4d, 0xb7, 0x2a, 0xf5, 0x25, 0x4d, 0x5f,
		0xba, 0xba, 0x52, 0xa9, 0x2f, 0x71, 0x80, 0xaf, 0xa8, 0xfb, 0x94, 0xea, 0x12, 0x19, 0x1d, 0xb1,
		0xbb, 0x4c, 0x29, 0x2a, 0xb9, 0xc8, 0x45, 0x55, 0x51, 0x55, 0xeb, 0x52, 0x95, 0xa6, 0xae, 0x51,
		0xaa, 0xab, 0x74, 0x75, 0x75, 0x79, 0x12, 0x2f, 0xd5, 0x56, 0xb6, 0xea, 0x3c, 0xfb, 0xf5, 0x6e,
		0x83, 0x23, 0x17, 0x28, 0xb4, 0xbc, 0x85, 0xd6, 0xed, 0x39, 0xc7, 0xee, 0x3b, 0x0e, 0xba, 0xa7,
		0xda, 0x8a, 0x50, 0xdb, 0x74, 0x07, 0x6b, 0xaf, 0x73, 0xea, 0x39, 0x3d, 0xce, 0xbb, 0xa7, 0xe2,
		0x8a, 0x09, 0xa4, 0x94, 0x19, 0x65, 0x56, 0x50, 0x18, 0x3d, 0x6e, 0xd9, 0xaf, 0x39, 0x97, 0x8d,
		0x7a, 0x2b, 0x22, 0x90, 0x36, 0x54, 0x05, 0x52, 0x4e, 0xc9, 0xe2, 0x4a, 0xaf, 0xd2, 0x0a, 0xd7,
		0x9a, 0xf9, 0x53, 0x50, 0xcc, 0xf0, 0xa9, 0x2a, 0xfd, 0xaa, 0xd2, 0x92, 0xc9, 0x53, 0x59, 0xcc,
		0xd8, 0x29, 0x27, 0xfd, 0xe1, 0x0f, 0x3c, 0x33, 0xa7, 0xae, 0x98, 0x81, 0x53, 0x59, 0x3a, 0x95,
		0x35, 0x17, 0xd1, 0x91, 0xdd, 0xe5, 0x9e, 0x03, 0xea, 0xad, 0x54, 0xdd, 0xf5, 0x7c, 0xbb, 0xf5,
		0xba, 0xd3, 0x73, 0xbd, 0x37, 0x27, 0xac, 0x62, 0x53, 0x71, 0x85, 0x28, 0x6e, 0xf9, 0x37, 0x96,
		0xb1, 0xcb, 0x7d, 0xb1, 0x8c, 0xcd, 0x25, 0xce, 0x60, 0x42, 0x65, 0x31, 0x68, 0x30, 0x58, 0x28,
		0x0a, 0x12, 0x58, 0x9f, 0x33, 0x8e, 0xb5, 0x18, 0x96, 0x82, 0x38, 0x70, 0xcb, 0x8e, 0xa2, 0x51,
		0x1a, 0xa4, 0xe1, 0x28, 0xb2, 0x0e, 0x80, 0x5c, 0xb7, 0x95, 0x5c, 0x7e, 0x30, 0x37, 0xc1, 0x6d,
		0x90, 0x7e, 0x98, 0x38, 0xeb, 0xfa, 0xe8, 0xd6, 0x44, 0x97, 0xa3, 0xe8, 0x2a, 0xbc, 0xae, 0x45,
		0x26, 0xfd, 0x34, 0x8a, 0x3f, 0xd6, 0xc2, 0x28, 0x49, 0x83, 0xe8, 0xd2, 0xd4, 0x1f, 0xbf, 0x91,
		0xac, 0xbc, 0x53, 0xbf, 0x8d, 0x47, 0xe9, 0xe8, 0x72, 0x34, 0x4c, 0xb2, 0xef, 0xea, 0x61, 0x12,
		0x26, 0xf5, 0xa1, 0xb9, 0x33, 0xc3, 0xf9, 0x97, 0xfa, 0x30, 0x8c, 0x3e, 0xd6, 0x92, 0x34, 0x48,
		0x4d, 0x6d, 0x10, 0xa4, 0xc1, 0x45, 0x90, 0x98, 0xfa, 0x30, 0xb9, 0xad, 0xa7, 0xc3, 0xbb, 0x64,
		0xf2, 0x47, 0xfd, 0x26, 0xad, 0x4d, 0x7e, 0xaa, 0x16, 0x99, 0xf0, 0xfa, 0xc3, 0xc5, 0x28, 0xae,
		0x05, 0x69, 0x1a, 0x87, 0x17, 0xe3, 0x74, 0x62, 0xc3, 0xec, 0xad, 0x24, 0xfb, 0xae, 0xbe, 0x34,
		0x27, 0x33, 0x23, 0x19, 0x5f, 0x4c, 0xff, 0xb1, 0xd9, 0xd7, 0xfa, 0x38, 0x0d, 0x87, 0xe1, 0xff,
		0x99, 0x41, 0xed, 0x22, 0x88, 0x06, 0x9f, 0xc2, 0x41, 0xfa, 0xa1, 0x3e, 0xfd, 0xf5, 0x40, 0xb5,
		0x19, 0x2b, 0x49, 0xe3, 0xf1, 0x65, 0x1a, 0xcd, 0x83, 0x6a, 0x27, 0xbb, 0x4d, 0xed, 0xd9, 0x2d,
		0x70, 0xe7, 0x97, 0xee, 0x3f, 0xfa, 0x7b, 0xf2, 0xf8, 0x0d, 0xbf, 0xbb, 0xb8, 0x45, 0xd9, 0x77,
		0xbe, 0x9b, 0x84, 0x89, 0xdf, 0x9a, 0xde, 0xa2, 0xd9, 0x17, 0xbf, 0x15, 0x46, 0x1f, 0xfb, 0x93,
		0x8f, 0xa8, 0x39, 0xbf, 0x41, 0x7e, 0x2b, 0xb9, 0xf5, 0xbd, 0xe1, 0x5d, 0x32, 0xf9, 0xc3, 0x3f,
		0x49, 0x27, 0x3f, 0xd2, 0x9e, 0xdf, 0x01, 0x7b, 0x71, 0x77, 0xfc, 0xc5, 0x3b, 0x49, 0xf6, 0x9d,
		0xbf, 0x34, 0x24, 0xb3, 0xa0, 0x3f, 0xbb, 0x3b, 0xf3, 0xaf, 0xfe, 0xe9, 0xfc, 0xee, 0x1c, 0x2e,
		0x6e, 0x8e, 0x3f, 0xfd, 0xcd, 0x18, 0x60, 0x20, 0xdf, 0x89, 0xca, 0xb6, 0x50, 0xb8, 0x7b, 0x47,
		0x73, 0xeb, 0x15, 0x75, 0xe7, 0x00, 0x8e, 0xbc, 0x4a, 0x0e, 0x5c, 0xb6, 0xeb, 0x96, 0xeb, 0x10,
		0x65, 0x5a, 0x26, 0xd4, 0x45, 0x5b, 0x6f, 0xcd, 0xfd, 0x64, 0x25, 0xa5, 0xf7, 0xb7, 0x52, 0x41,
		0xce, 0x6a, 0x85, 0x49, 0x3a, 0x59, 0x5c, 0xa2, 0x63, 0x87, 0x75, 0x12, 0x46, 0xce, 0xd0, 0xdc,
		0x98, 0x28, 0x4d, 0xac, 0x83, 0x8d, 0xcd, 0x5f, 0x05, 0x5b, 0x1a, 0x7c, 0x7e, 0x60, 0xe9, 0xd6,
		0xab, 0x46, 0x63, 0x77, 0xaf, 0xd1, 0xd8, 0xdc, 0x7b, 0xb9, 0xb7, 0xb9, 0xbf, 0xb3, 0xb3, 0xb5,
		0xbb, 0xb5, 0x23, 0xd8, 0xf8, 0x4e, 0x3c, 0x30, 0xb1, 0x19, 0x1c, 0x4e, 0x54, 0x1b, 0x8d, 0x87,
		0x43, 0x2e, 0x76, 0x7d, 0x1c, 0x56, 0x05, 0xfe, 0x12, 0x0c, 0x5b, 0x7a, 0x21, 0x4b, 0x26, 0x52,
		0xc9, 0x03, 0x16, 0x59, 0x16, 0x09, 0xf3, 0xa6, 0xd2, 0xbd, 0xa8, 0x6a, 0xef, 0x29, 0xd0, 0x6d,
		0x2a, 0x74, 0x97, 0xb2, 0xfc, 0xa4, 0x1c, 0x6f, 0x24, 0xc8, 0x13, 0x59, 0xe3, 0x68, 0x60, 0xae,
		0xc2, 0xc8, 0x0c, 0x6a, 0x8b, 0xa5, 0x21, 0xcd, 0x19, 0x65, 0x0f, 0xaf, 0x57, 0x4d, 0x15, 0xe6,
		0xd1, 0xdf, 0x86, 0xd1, 0x60, 0x92, 0x0a, 0x09, 0x33, 0xeb, 0x68, 0xea, 0x46, 0xe4, 0x65, 0x93,
		0x56, 0x37, 0x36, 0x57, 0xe1, 0x67, 0x99, 0xd1, 0x6f, 0x21, 0xba, 0xd1, 0xe5, 0x34, 0xe2, 0x48,
		0x0c, 0x18, 0xfd, 0xd1, 0x38, 0xbe, 0x34, 0x62, 0x53, 0x30, 0xeb, 0xad, 0xb9, 0xff, 0x34, 0x8a,
		0x27, 0x2b, 0xc2, 0xba, 0x9d, 0xdd, 0x69, 0xa1, 0xf9, 0xec, 0x9b, 0x20, 0xb1, 0xe3, 0xeb, 0xf1,
		0x8d, 0x89, 0x52, 0xeb, 0x60, 0x23, 0x8d, 0xc7, 0x46, 0x6a, 0xe2, 0xbd, 0xb4, 0x32, 0x13, 0x26,
		0xa9, 0x1f, 0x8a, 0xfa, 0x9b, 0xa1, 0xcc, 0x02, 0xe4, 0x4a, 0x74, 0x95, 0xeb, 0x57, 0x9e, 0xe3,
		0x01, 0xa9, 0xee, 0x45, 0x26, 0x16, 0x88, 0xc7, 0x03, 0x04, 0x4c, 0x00, 0xc2, 0x05, 0x14, 0x6c,
		0x80, 0xc3, 0x07, 0x38, 0x8c, 0xc0, 0xc2, 0x09, 0x99, 0x58, 0x21, 0x14, 0x2f, 0xc4, 0x63, 0x46,
		0x66, 0xe0, 0x6c, 0xcf, 0x9f, 0x78, 0x27, 0xb4, 0xf0, 0xeb, 0x08, 0x5b, 0x14, 0x85, 0x83, 0x06,
		0x0c, 0x70, 0x20, 0x81, 0x07, 0x20, 0x80, 0xa0, 0x81, 0x08, 0x2c, 0x90, 0xc0, 0x82, 0x09, 0x26,
		0xa0, 0xc8, 0x06, 0x15, 0xe1, 0xc0, 0x02, 0x03, 0x2e, 0x99, 0xa1, 0x43, 0x13, 0x5d, 0x4f, 0x1f,
		0x8d, 0x82, 0x78, 0xaf, 0x45, 0x80, 0x98, 0xdb, 0x0d, 0xe2, 0x01, 0xe6, 0x48, 0xb3, 0x09, 0x62,
		0x2e, 0x0a, 0xda, 0x20, 0x22, 0x0e, 0x30, 0xea, 0xa0, 0x22, 0x0f, 0x3c, 0xfa, 0xc0, 0x23, 0x10,
		0x36, 0x0a, 0x61, 0x20, 0x11, 0x08, 0x1a, 0x65, 0x52, 0xf0, 0xee, 0x6f, 0x0d, 0xa6, 0xc7, 0x1e,
		0x87, 0x51, 0xfa, 0x0a, 0xc9, 0x5f, 0xcf, 0xf1, 0x63, 0x07, 0xc8, 0xe4, 0x5e, 0x10, 0x5d, 0x1b,
		0xb8, 0x11, 0x61, 0x78, 0xf3, 0x35, 0xac, 0x93, 0x30, 0x82, 0x0b, 0xe4, 0xa0, 0x5c, 0xbd, 0x62,
		0xfe, 0x74, 0x10, 0x1e, 0xb0, 0xfd, 0xc7, 0x71, 0x70, 0x99, 0x86, 0xa3, 0xa8, 0x19, 0x5e, 0x87,
		0xb3, 0x46, 0x1f, 0xbc, 0x49, 0x20, 0xbf, 0x02, 0x2e, 0xd9, 0xe0, 0x33, 0x97, 0x6c, 0xc9, 0x4b,
		0x76, 0x7b, 0x67, 0x87, 0x8b, 0x96, 0x20, 0xae, 0xcb, 0xda, 0x73, 0xce, 0xc7, 0xa8, 0x4a, 0x50,
		0x99, 0xf5, 0x38, 0xc3, 0x95, 0x7d, 0x05, 0x77, 0x66, 0x83, 0x47, 0x3a, 0x16, 0x7d, 0x8b, 0xd4,
		0x31, 0x8b, 0xbe, 0xc5, 0x2d, 0x43, 0x16, 0x7d, 0x4b, 0xbe, 0x00, 0x16, 0x7d, 0x49, 0x1c, 0x73,
		0x29, 0xb0, 0xe8, 0x5b, 0x34, 0x7e, 0xb0, 0xe8, 0x9b, 0xf7, 0x8b, 0x45, 0x5f, 0x72, 0xf5, 0x77,
		0x98, 0xcf, 0xa2, 0x2f, 0xa3, 0xe5, 0x8f, 0x2c, 0x59, 0x16, 0x7d, 0x4b, 0x5f, 0xb2, 0x2c, 0xfa,
		0x12, 0xc4, 0xd5, 0x59, 0xcb, 0xa2, 0x6f, 0x65, 0x82, 0x8a, 0x75, 0x37, 0x77, 0x64, 0x60, 0x55,
		0xdf, 0x99, 0xd9, 0x2c, 0xfb, 0xe6, 0x61, 0x2e, 0xcb, 0xbe, 0x05, 0x0a, 0x99, 0x65, 0xdf, 0xe2,
		0x96, 0x21, 0xcb, 0xbe, 0x25, 0x5f, 0x00, 0xcb, 0xbe, 0x64, 0x8e, 0xb9, 0x14, 0x70, 0xcb, 0xbe,
		0x17, 0x61, 0x14, 0xc4, 0xf7, 0x80, 0x75, 0xdf, 0x7d, 0x62, 0x7d, 0x05, 0x2c, 0xe4, 0x59, 0x27,
		0xeb, 0xb5, 0x57, 0xe5, 0xb4, 0xd8, 0x95, 0x89, 0x93, 0x2b, 0xef, 0xc0, 0x9c, 0x5d, 0xa5, 0x69,
		0xbc, 0xec, 0xe9, 0xe2, 0x26, 0x2c, 0xc6, 0x72, 0x3f, 0x7a, 0x03, 0xe1, 0xcc, 0x2a, 0xc1, 0x07,
		0x9f, 0x08, 0x9e, 0x5d, 0x05, 0xb1, 0xf7, 0x0e, 0x69, 0xcf, 0x1d, 0x48, 0xd1, 0x85, 0x33, 0x63,
		0x58, 0x5c, 0xd9, 0xe0, 0xcc, 0x18, 0x16, 0x51, 0x94, 0x16, 0x4f, 0x98, 0x2b, 0x55, 0xa2, 0x48,
		0xf2, 0x60, 0x08, 0x4b, 0x70, 0x15, 0x9b, 0x2b, 0x04, 0x8f, 0xbb, 0x18, 0x2a, 0xb7, 0x07, 0x60,
		0x6b, 0x77, 0x9e, 0x7e, 0xbe, 0x78, 0x31, 0xcb, 0xcb, 0xea, 0x53, 0x02, 0x63, 0x1e, 0xa0, 0xc8,
		0x32, 0x1e, 0x80, 0xf8, 0xc3, 0x26, 0xf2, 0x00, 0xc4, 0x35, 0x5b, 0xca, 0x03, 0x10, 0x2b, 0xba,
		0xd8, 0x79, 0x00, 0xa2, 0xe8, 0xa2, 0x2c, 0x0f, 0x45, 0x14, 0x51, 0x86, 0xe5, 0x31, 0x89, 0x88,
		0x16, 0xf1, 0x98, 0x44, 0xfa, 0xd8, 0xba, 0xf4, 0xa3, 0xd6, 0xb4, 0xbb, 0x52, 0x9e, 0x9c, 0x28,
		0xd9, 0x12, 0x21, 0x2e, 0x72, 0x91, 0x73, 0x86, 0x03, 0x21, 0xab, 0x53, 0x66, 0x86, 0x29, 0x37,
		0xa3, 0x84, 0xca, 0x20, 0x65, 0x66, 0x8c, 0x52, 0x96, 0xa2, 0x50, 0x4a, 0x51, 0x49, 0x27, 0x82,
		0x58, 0x44, 0x11, 0x83, 0xc8, 0x40, 0x8e, 0xf2, 0x03, 0x7c, 0xb9, 0x16, 0x94, 0xec, 0xcf, 0xa4,
		0xf9, 0x31, 0x4d, 0xfe, 0x4b, 0x80, 0xdb, 0xc2, 0x77, 0x57, 0xe5, 0x7a, 0xa9, 0xf2, 0x7c, 0x43,
		0x89, 0x7e, 0xc1, 0x9a, 0xe8, 0x7d, 0x50, 0xba, 0x3b, 0xc8, 0x9e, 0x9d, 0xcf, 0xcc, 0x29, 0xd9,
		0x4f, 0xca, 0xd8, 0x36, 0x27, 0x66, 0x5b, 0x9c, 0xa4, 0x6d, 0x6f, 0x02, 0xb7, 0xb5, 0x49, 0xdb,
		0xb6, 0x26, 0x76, 0x5b, 0x9a, 0xd8, 0x6d, 0x67, 0x32, 0xb7, 0x95, 0x55, 0x9b, 0x55, 0xc5, 0x6c,
		0xfb, 0x12, 0xb8, 0xad, 0x4b, 0xd2, 0xb6, 0xad, 0xd5, 0x6d, 0x59, 0xb3, 0x10, 0x4e, 0x94, 0x2b,
		0x81, 0xff, 0x25, 0x9c, 0xba, 0x2b, 0xea, 0x54, 0x5d, 0x21, 0xa7, 0xe6, 0x12, 0xe5, 0x88, 0x72,
		0x44, 0x39, 0xa2, 0x5c, 0x35, 0x51, 0x4e, 0xca, 0xa9, 0xaf, 0x42, 0x6a, 0x1d, 0x22, 0x6b, 0x1e,
		0xc2, 0x6a, 0x1f, 0xe2, 0x02, 0xa7, 0xc4, 0x00, 0x2a, 0x38, 0x90, 0x4a, 0x0d, 0xa8, 0xe2, 0x03,
		0xab, 0xf8, 0x00, 0x2b, 0x3b, 0xd0, 0xca, 0x08, 0xb8, 0x42, 0x02, 0xaf, 0xbc, 0x5a, 0xca, 0x8a,
		0xc7, 0x1a, 0x87, 0x51, 0xba, 0xb5, 0x2b, 0xc9, 0x61, 0xcd, 0xe3, 0xdf, 0xae, 0x20, 0x93, 0x64,
		0xce, 0x7f, 0x17, 0xb8, 0x5b, 0x57, 0xf2, 0xfc, 0x76, 0xe1, 0xb3, 0x18, 0xa4, 0xcf, 0x5f, 0x47,
		0x18, 0xd5, 0x2c, 0xb0, 0xa1, 0x49, 0xf4, 0x7c, 0x74, 0x94, 0x25, 0xd1, 0xd8, 0xdc, 0xdf, 0xe1,
		0xaa, 0xc0, 0x46, 0x31, 0x79, 0xd6, 0x9c, 0x73, 0x4b, 0x9e, 0x14, 0xaf, 0x69, 0x25, 0xf7, 0x49,
		0x6a, 0x6e, 0x44, 0x16, 0x87, 0x96, 0xa6, 0xb1, 0x40, 0xf4, 0x94, 0x39, 0x2c, 0x10, 0x7d, 0x87,
		0x98, 0x58, 0x20, 0xfa, 0xfb, 0x32, 0x67, 0x81, 0xe8, 0x27, 0x0d, 0x64, 0x81, 0x08, 0x25, 0x63,
		0x10, 0x5c, 0x20, 0x92, 0x16, 0xfe, 0x1e, 0x86, 0xc0, 0xad, 0x57, 0x82, 0x6c, 0xea, 0x06, 0x69,
		0x6a, 0xe2, 0x48, 0x5c, 0x99, 0xc8, 0xfa, 0xef, 0xef, 0x9b, 0xb5, 0x7d, 0xbb, 0x76, 0x1c, 0xd4,
		0xae, 0xce, 0xff, 0x6c, 0x7c, 0xf9, 0xe3, 0x8f, 0x17, 0xdf, 0x78, 0xe3, 0x1f, 0x72, 0xbc, 0xc4,
		0xb9, 0xa4, 0x1b, 0xdc, 0xe9, 0xbb, 0xef, 0x78, 0x97, 0x99, 0x89, 0x29, 0xb5, 0x80, 0xcd, 0x51,
		0x8f, 0x72, 0x52, 0xf8, 0xe6, 0x28, 0x29, 0xd3, 0xd3, 0x61, 0x1b, 0xa3, 0x04, 0x4c, 0x3a, 0xaf,
		0xe8, 0x4e, 0x5a, 0x31, 0xf5, 0x20, 0x71, 0x20, 0xcc, 0xe6, 0x28, 0xb9, 0xf5, 0x1e, 0xee, 0xa8,
		0xc5, 0xad, 0xeb, 0x70, 0x47, 0x2d, 0x59, 0x15, 0xaf, 0x5e, 0xc3, 0xe6, 0xa8, 0x6f, 0x56, 0x65,
		0xbe, 0x6e, 0x8e, 0x5a, 0x86, 0xf1, 0xaa, 0x62, 0xdd, 0x2f, 0x15, 0x5a, 0xb0, 0x8b, 0x21, 0x5e,
		0xd3, 0x1d, 0xde, 0x1b, 0x65, 0x23, 0x9c, 0x8c, 0x09, 0x5e, 0x72, 0x26, 0x76, 0x89, 0x9e, 0xd0,
		0x25, 0x63, 0x22, 0x57, 0x59, 0xeb, 0x46, 0x48, 0x31, 0x06, 0xbf, 0x08, 0x63, 0x95, 0xda, 0x8f,
		0x0a, 0x59, 0x76, 0x29, 0x27, 0x32, 0x17, 0x1f, 0x17, 0x8b, 0xfd, 0x8d, 0x05, 0x7b, 0x92, 0xb2,
		0x3d, 0x08, 0xac, 0xe7, 0x28, 0xc1, 0x61, 0x80, 0x39, 0x8a, 0x62, 0xfd, 0x43, 0x71, 0xab, 0xb4,
		0x98, 0xdf, 0x54, 0x90, 0x1f, 0x28, 0x6b, 0xfd, 0x83, 0xad, 0xfb, 0x02, 0x57, 0x3b, 0xc4, 0x2a,
		0x2f, 0x66, 0x6d, 0xe7, 0xbf, 0xd2, 0x0a, 0x58, 0x65, 0xd3, 0xa4, 0x36, 0x29, 0x6e, 0x75, 0x7d,
		0xd5, 0x2e, 0x9d, 0x44, 0x05, 0x29, 0xb7, 0xe0, 0x01, 0x22, 0x85, 0x3f, 0xd6, 0x28, 0xe3, 0xf1,
		0x45, 0x89, 0x8f, 0x29, 0xca, 0x7a, 0x1c, 0x51, 0xfa, 0x63, 0x87, 0xd2, 0x1f, 0x2f, 0x94, 0xfb,
		0x18, 0x41, 0x17, 0xdb, 0x14, 0x3d, 0x50, 0xc3, 0x5a, 0x66, 0x07, 0x85, 0x2f, 0x9c, 0x85, 0xaf,
		0x28, 0x2b, 0x41, 0x29, 0x69, 0x82, 0x54, 0x69, 0xcf, 0xb7, 0xcb, 0x7c, 0x9e, 0x2d, 0xe0, 0xf9,
		0x75, 0xd9, 0xcf, 0xab, 0xc5, 0x3c, 0x9f, 0x16, 0xf3, 0x3c, 0x5a, 0xc6, 0xf3, 0x67, 0xdd, 0xc5,
		0xb2, 0xb2, 0x26, 0x34, 0x65, 0x5e, 0xbd, 0xbc, 0xf5, 0xf6, 0x38, 0xbe, 0x94, 0xb5, 0xdc, 0xca,
		0x1d, 0x54, 0x58, 0xfa, 0x76, 0x2a, 0x09, 0xdb, 0xa8, 0x04, 0x6d, 0x9f, 0x92, 0xb2, 0x6d, 0x4a,
		0xdc, 0x76, 0x29, 0x71, 0xdb, 0xa4, 0x64, 0x6d, 0x8f, 0xaa, 0xd6, 0xee, 0x8a, 0xb2, 0x07, 0x0b,
		0x5a, 0xcb, 0xe3, 0x3f, 0xc4, 0xec, 0x13, 0x96, 0x72, 0x22, 0x09, 0x27, 0xef, 0xca, 0x0b, 0x70,
		0x02, 0x03, 0x9d, 0xb4, 0x80, 0x27, 0x36, 0xf0, 0x89, 0x0d, 0x80, 0x32, 0x03, 0x61, 0xb9, 0x01,
		0xb1, 0xe4, 0xc0, 0x28, 0x26, 0x40, 0xae, 0x04, 0x4a, 0x79, 0xf3, 0x55, 0x84, 0x9d, 0x3b, 0x28,
		0x24, 0x6c, 0x8a, 0x0b, 0x9f, 0x12, 0xc3, 0xa8, 0xe0, 0x70, 0x2a, 0x35, 0xac, 0x8a, 0x0f, 0xaf,
		0xe2, 0xc3, 0xac, 0xec, 0x70, 0x2b, 0x23, 0xec, 0x0a, 0x09, 0xbf, 0xe2, 0xc2, 0xf0, 0x32, 0x1c,
		0x0f, 0xe4, 0x79, 0x84, 0x2c, 0x20, 0x0f, 0xa4, 0xb9, 0x02, 0x99, 0x63, 0x2a, 0xc5, 0x85, 0x66,
		0xc9, 0x21, 0x1a, 0x20, 0x54, 0x4b, 0x0f, 0xd9, 0x30, 0xa1, 0x1b, 0x26, 0x84, 0x63, 0x84, 0x72,
		0x59, 0x21, 0x5d, 0x58, 0x68, 0xcf, 0x6e, 0xa1, 0xb8, 0x09, 0x6a, 0x2b, 0x1e, 0x4f, 0x4e, 0x87,
		0xee, 0xb3, 0x39, 0xef, 0x9e, 0x40, 0xdb, 0x56, 0x3a, 0x78, 0xcb, 0x6e, 0xdd, 0x95, 0xbb, 0x2e,
		0x05, 0xad, 0x49, 0x21, 0x67, 0x21, 0x3e, 0xbb, 0x18, 0xa5, 0x8c, 0x46, 0x7a, 0x72, 0x19, 0x92,
		0x73, 0xc9, 0xb9, 0xe4, 0x5c, 0x72, 0x2e, 0x39, 0x97, 0x31, 0xf5, 0xf1, 0x2d, 0x94, 0x56, 0xca,
		0xca, 0x0c, 0x13, 0x58, 0xd2, 0x5a, 0x71, 0xc6, 0xe2, 0x4a, 0x5b, 0x8f, 0x43, 0xbf, 0xd4, 0x93,
		0x58, 0xa4, 0x22, 0x00, 0x02, 0x0a, 0x00, 0x21, 0x01, 0x0a, 0x1a, 0xc0, 0x21, 0x02, 0x1c, 0x2a,
		0x60, 0x21, 0x83, 0x4c, 0x74, 0x10, 0x8a, 0x10, 0xd9, 0xad, 0x15, 0x5b, 0x32, 0x5b, 0xf1, 0x98,
		0xe3, 0x30, 0x4a, 0x77, 0x1b, 0x92, 0x1d, 0xe6, 0x3c, 0x7e, 0xbf, 0x12, 0x6c, 0xa2, 0xcc, 0x53,
		0x2c, 0x1f, 0xbf, 0x64, 0x07, 0x9c, 0x0d, 0xe9, 0xa7, 0x5c, 0x82, 0x81, 0xe5, 0x8a, 0xb9, 0xc2,
		0x4f, 0xc1, 0x5c, 0xb1, 0x17, 0xe0, 0xfc, 0x3f, 0x90, 0x70, 0xf4, 0xf5, 0x12, 0x0b, 0x3e, 0x73,
		0x89, 0xe5, 0xbc, 0xc4, 0x64, 0x8d, 0x5b, 0x54, 0xbf, 0xea, 0x7e, 0xa1, 0x75, 0x3f, 0xf2, 0x3a,
		0xff, 0x85, 0x9f, 0x17, 0xa8, 0x57, 0xb7, 0x6e, 0x4c, 0x1a, 0x87, 0x97, 0xf2, 0xcb, 0x82, 0x73,
		0x3b, 0x59, 0x1a, 0xfc, 0x11, 0xf3, 0x58, 0x1a, 0x5c, 0xa3, 0x12, 0x59, 0x1a, 0x5c, 0xdf, 0xb2,
		0x61, 0x69, 0x30, 0x67, 0x83, 0x59, 0x1a, 0xd4, 0x9a, 0x8b, 0x01, 0x95, 0x06, 0x3f, 0x85, 0x03,
		0x53, 0x13, 0x1d, 0xc0, 0x1f, 0x06, 0xf1, 0x3d, 0xd6, 0x07, 0x7f, 0xf2, 0xc5, 0xfa, 0x20, 0x8b,
		0x17, 0xf2, 0xf6, 0xc8, 0xa9, 0xaa, 0x54, 0xb0, 0x3e, 0xc8, 0x25, 0x36, 0x59, 0x62, 0xbb, 0x7b,
		0x7b, 0x7b, 0xdb, 0xac, 0x09, 0x56, 0x8d, 0x49, 0xe5, 0x5b, 0xc7, 0x9a, 0x20, 0xa2, 0x45, 0xd2,
		0x76, 0x52, 0x0a, 0x3b, 0x6f, 0x7a, 0xc5, 0x3e, 0xb1, 0x07, 0x19, 0x44, 0x4f, 0x9d, 0x35, 0xbd,
		0xfc, 0xd5, 0xd9, 0xaf, 0x94, 0xd8, 0x63, 0xb1, 0x21, 0xf2, 0x20, 0x84, 0xe8, 0xa9, 0xc3, 0xa7,
		0x97, 0xbf, 0x36, 0xfb, 0x7d, 0x02, 0xce, 0xa3, 0x96, 0xeb, 0x63, 0x44, 0x75, 0x3f, 0x8d, 0x2f,
		0x26, 0x6b, 0x46, 0x70, 0xff, 0xd3, 0xdc, 0x40, 0x76, 0x40, 0xfd, 0x1d, 0xb3, 0xd8, 0x01, 0xf5,
		0x13, 0x52, 0x63, 0x07, 0xd4, 0x8f, 0x2f, 0x07, 0x76, 0x40, 0xad, 0x1b, 0xfa, 0xd8, 0x01, 0x85,
		0xce, 0xed, 0x62, 0x3b, 0xa0, 0x66, 0x31, 0x55, 0xfe, 0x76, 0x87, 0xb9, 0x9d, 0xb2, 0xb7, 0x3b,
		0x6c, 0x71, 0xbb, 0x83, 0x3a, 0x24, 0x00, 0x42, 0x03, 0x14, 0x44, 0x80, 0x43, 0x05, 0x38, 0x64,
		0xc0, 0x42, 0x07, 0x99, 0x08, 0x21, 0x14, 0x25, 0xc4, 0x23, 0x45, 0x66, 0x60, 0x30, 0xf8, 0x7f,
		0xc1, 0xa5, 0x89, 0x2e, 0xef, 0x6b, 0x49, 0x38, 0x48, 0xe4, 0x7b, 0xa3, 0x85, 0x83, 0x7f, 0x64,
		0xb7, 0xf0, 0x15, 0x2e, 0x1b, 0x3d, 0x60, 0x10, 0x04, 0x09, 0x45, 0x00, 0x91, 0x04, 0x0d, 0x4d,
		0x60, 0x11, 0x05, 0x16, 0x55, 0x30, 0x91, 0x45, 0x36, 0xba, 0x08, 0x47, 0x18, 0x18, 0x94, 0x79,
		0x1a, 0x69, 0x70, 0x9c, 0xd8, 0x93, 0x64, 0x83, 0xe2, 0xc8, 0x30, 0x00, 0x07, 0x0e, 0x74, 0x10,
		0x81, 0x07, 0x18, 0x7c, 0x50, 0x01, 0x08, 0x1e, 0x84, 0xe0, 0x81, 0x08, 0x1b, 0x8c, 0x30, 0x00,
		0x09, 0x04, 0x94, 0xe0, 0x80, 0x29, 0x33, 0x58, 0xe6, 0x64, 0xdd, 0xbf, 0x1d, 0x67, 0xa4, 0xee,
		0x0a, 0x53, 0x04, 0x4e, 0xb0, 0x00, 0x85, 0x0c, 0x52, 0x0a, 0x80, 0x0a, 0x1d, 0xac, 0xd4, 0x00,
		0x96, 0x1a, 0xd0, 0xd2, 0x01, 0x5c, 0x58, 0xe0, 0x05, 0x06, 0x60, 0xb0, 0x20, 0x96, 0x19, 0x7e,
		0x35, 0x0c, 0xae, 0x13, 0x5c, 0x67, 0xb9, 0x88, 0x57, 0xb3, 0xcb, 0x00, 0xf5, 0x2f, 0x58, 0x3d,
		0x76, 0x6a, 0x40, 0x4d, 0x03, 0xb0, 0x29, 0x02, 0x37, 0x2d, 0x00, 0xa7, 0x0e, 0xe4, 0xd4, 0x01,
		0x9d, 0x2e, 0xb0, 0xc3, 0x04, 0x3c, 0x50, 0xd0, 0xcb, 0xa4, 0x23, 0x7e, 0xc8, 0xcc, 0xdf, 0x8e,
		0x18, 0x26, 0x1a, 0xdf, 0x98, 0x78, 0xd6, 0x4b, 0x0a, 0x1c, 0x35, 0x16, 0x55, 0xae, 0x06, 0xf0,
		0x35, 0x38, 0xd1, 0xf8, 0x66, 0x22, 0x2a, 0x2e, 0xe5, 0x22, 0x3f, 0xf5, 0x56, 0x98, 0xa4, 0x76,
		0x9a, 0xc6, 0xd8, 0xcb, 0xf9, 0x24, 0x8c, 0x9c, 0xa1, 0x99, 0x44, 0xb3, 0x04, 0x17, 0xc5, 0x37,
		0xe6, 0xf3, 0x51, 0x1e, 0x5c, 0x09, 0xee, 0xa4, 0xdf, 0x27, 0x2f, 0xae, 0x13, 0x0f, 0x4c, 0x6c,
		0x06, 0x87, 0xf7, 0xd6, 0xc1, 0x46, 0x34, 0x1e, 0x0e, 0x7f, 0x21, 0x6a, 0xd0, 0x37, 0x3d, 0x2d,
		0x95, 0xbb, 0xf9, 0x2c, 0x1b, 0xf0, 0xd2, 0xcc, 0xec, 0x32, 0x58, 0x9a, 0x29, 0xc3, 0x7c, 0x96,
		0x66, 0x04, 0x2d, 0x04, 0x96, 0x66, 0xe4, 0x2c, 0x6b, 0x96, 0x66, 0x84, 0x5f, 0x10, 0x4b, 0x33,
		0x64, 0xa6, 0x1f, 0x94, 0x8e, 0x9e, 0xd2, 0xcc, 0x38, 0x8c, 0xd2, 0x97, 0xdb, 0x0a, 0xaa, 0x32,
		0x7b, 0xc0, 0x97, 0x80, 0x31, 0x5a, 0xf8, 0x5b, 0x2f, 0xec, 0x80, 0xbd, 0x81, 0x36, 0x9a, 0x58,
		0x79, 0x62, 0xb1, 0x72, 0x39, 0x60, 0x47, 0x9f, 0x7d, 0xf3, 0x7a, 0x00, 0x07, 0xb2, 0x2a, 0x0d,
		0xe7, 0x5f, 0xbb, 0x80, 0xe0, 0x33, 0x5d, 0x80, 0x70, 0x17, 0xd0, 0xd8, 0xde, 0x6f, 0xec, 0xef,
		0xee, 0x6d, 0xef, 0xef, 0xd0, 0x17, 0x30, 0x21, 0xa1, 0xf5, 0x0f, 0x5f, 0xe7, 0x2c, 0xf7, 0x33,
		0xd6, 0x3d, 0xe3, 0x66, 0x3e, 0x99, 0xf0, 0xfa, 0x43, 0x8a, 0x5f, 0xef, 0x9f, 0x5f, 0x07, 0x0b,
		0xfe, 0x65, 0x98, 0xcf, 0x82, 0xbf, 0xa0, 0x95, 0xc0, 0x82, 0xbf, 0x9c, 0x65, 0xcd, 0x82, 0xbf,
		0xf0, 0x0b, 0x62, 0xc1, 0x9f, 0xd4, 0xf4, 0x83, 0xd2, 0xd1, 0x55, 0xf0, 0x7f, 0xa5, 0xa0, 0xde,
		0xbf, 0xc3, 0x7a, 0x7f, 0xc9, 0x2f, 0xd6, 0xfb, 0x99, 0x57, 0xe4, 0x78, 0x39, 0xac, 0xf7, 0x33,
		0x9a, 0x17, 0xe1, 0x02, 0x58, 0xef, 0x17, 0xef, 0x02, 0xb6, 0x77, 0x58, 0xe8, 0x67, 0x22, 0x42,
		0xeb, 0xbf, 0x7a, 0xb1, 0xd0, 0x4f, 0x8b, 0xe1, 0x43, 0xb2, 0xf4, 0x53, 0x26, 0xbf, 0x69, 0x3f,
		0xfe, 0x29, 0x94, 0xb3, 0x93, 0xee, 0xe6, 0x5f, 0xeb, 0x5f, 0x4f, 0xa4, 0xff, 0xfa, 0xaf, 0x75,
		0xc4, 0xd9, 0x64, 0x1b, 0xd8, 0x27, 0x5a, 0xce, 0xee, 0xce, 0xfc, 0xab, 0x6f, 0x2f, 0x6e, 0x47,
		0x3f, 0x1c, 0x24, 0x5f, 0xfd, 0x4d, 0xe2, 0xd9, 0x97, 0x7a, 0x3c, 0x2b, 0x90, 0x57, 0x05, 0xed,
		0xe9, 0x82, 0xee, 0xe5, 0x02, 0xcd, 0xbb, 0x38, 0xff, 0xb0, 0x4c, 0xa1, 0x73, 0xfe, 0x61, 0x79,
		0xcb, 0x95, 0xf3, 0x0f, 0xa5, 0xa5, 0x01, 0x9c, 0x7f, 0x48, 0xa6, 0xf9, 0x6b, 0x89, 0xc0, 0x3e,
		0x82, 0xcd, 0x3c, 0xfe, 0xd0, 0x04, 0x57, 0xb1, 0xb9, 0x42, 0xf4, 0xf8, 0x8b, 0xd1, 0x37, 0x80,
		0x5d, 0x56, 0x56, 0x77, 0x9e, 0x9c, 0xbf, 0x78, 0x31, 0x4b, 0x60, 0xeb, 0x33, 0xc4, 0x64, 0xaa,
		0x54, 0x61, 0x4b, 0x51, 0xa6, 0xef, 0xbf, 0x35, 0xf7, 0x68, 0x49, 0x11, 0xe6, 0xb0, 0x23, 0xdc,
		0xe1, 0x46, 0xaa, 0x86, 0x19, 0x61, 0x0e, 0x2f, 0x42, 0xf1, 0x26, 0xa0, 0xc5, 0xf6, 0x4a, 0x15,
		0xd9, 0x91, 0x0e, 0x98, 0xd2, 0x5f, 0x56, 0xc7, 0xa0, 0xc4, 0x2f, 0x3c, 0xb4, 0x52, 0xb3, 0xff,
		0x46, 0xf3, 0xdb, 0xca, 0xfd, 0x35, 0xc2, 0xd9, 0xc7, 0x2a, 0x3d, 0xb3, 0x6c, 0x67, 0x2c, 0xd7,
		0xc5, 0x09, 0x76, 0x6f, 0x56, 0x30, 0xb8, 0x09, 0xa3, 0xda, 0x75, 0x3c, 0x1a, 0xdf, 0x22, 0x1d,
		0xdb, 0xbf, 0x34, 0x9a, 0x67, 0xf6, 0xaf, 0xc3, 0x4c, 0x9e, 0xd9, 0x9f, 0xa3, 0x5c, 0x79, 0x66,
		0x7f, 0x9e, 0xf5, 0x39, 0x9e, 0xd9, 0x5f, 0x2c, 0x0b, 0xf3, 0xcc, 0xfe, 0xaa, 0xa5, 0x3f, 0x30,
		0x67, 0xf6, 0x63, 0x1d, 0x3d, 0x0b, 0x79, 0xe4, 0x2c, 0xcf, 0xe8, 0x27, 0xe0, 0x28, 0x00, 0x1d,
		0x54, 0xe0, 0x81, 0x07, 0x1f, 0x78, 0x00, 0xc2, 0x06, 0x21, 0x0c, 0x20, 0x02, 0x01, 0x23, 0x38,
		0x40, 0xca, 0x0c, 0x46, 0xaa, 0xfa, 0x3c, 0x1b, 0x6d, 0x70, 0xaa, 0x40, 0xcf, 0x41, 0x14, 0xf7,
		0xab, 0x13, 0xaa, 0x14, 0xc3, 0x15, 0x3a, 0x64, 0xa9, 0x81, 0x2d, 0x35, 0xd0, 0xa5, 0x03, 0xbe,
		0xb0, 0x20, 0x0c, 0x0c, 0xc6, 0x32, 0x89, 0xe0, 0xef, 0x57, 0x87, 0x3d, 0x1b, 0x04, 0xf8, 0x4c,
		0x10, 0xf0, 0xd9, 0x60, 0xd8, 0xa7, 0x9b, 0x2a, 0x18, 0x42, 0xaa, 0x62, 0x00, 0x90, 0x96, 0xd9,
		0x5f, 0x9a, 0xc6, 0xfd, 0x7c, 0xc1, 0x3e, 0xee, 0x97, 0x4b, 0x5b, 0xd8, 0xd2, 0xd6, 0x72, 0x86,
		0x87, 0xaa, 0x35, 0xce, 0x91, 0x52, 0x85, 0xbc, 0xce, 0x99, 0x78, 0xe5, 0xb8, 0x20, 0xa1, 0x0f,
		0xdb, 0xc7, 0x3f, 0x64, 0x5f, 0xe5, 0xe1, 0xfa, 0xd8, 0x87, 0xea, 0xb3, 0x7b, 0xb8, 0x92, 0x1e,
		0x91, 0xfd, 0x7e, 0x62, 0xfa, 0x47, 0xb2, 0x27, 0x85, 0x70, 0x33, 0xf4, 0x14, 0xb5, 0x92, 0xdc,
		0x84, 0xd1, 0xeb, 0xc9, 0x3d, 0x40, 0x9a, 0x95, 0xc7, 0xd6, 0x3e, 0xd5, 0xae, 0x9a, 0xad, 0x7d,
		0x72, 0x5c, 0x33, 0xfb, 0xfa, 0xca, 0x70, 0xc6, 0x6c, 0xea, 0x53, 0xe7, 0xd8, 0xac, 0xe0, 0x2e,
		0x08, 0x87, 0xc1, 0xc5, 0xd0, 0xd4, 0x2e, 0x82, 0x68, 0xf0, 0x29, 0x1c, 0x4c, 0xbd, 0x05, 0x4a,
		0x73, 0xdf, 0x13, 0xc6, 0xb3, 0xc9, 0x6f, 0x1d, 0x66, 0xb2, 0xc9, 0x2f, 0x47, 0xd9, 0xb2, 0xc9,
		0x2f, 0xbf, 0xe5, 0xc5, 0x26, 0xbf, 0xa2, 0xa9, 0x98, 0x4d, 0x7e, 0x55, 0x4b, 0x84, 0xd8, 0xe4,
		0x97, 0x6f, 0x7c, 0x60, 0x93, 0x1f, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0,
		0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83,
		0x71, 0x6a, 0x3f, 0xcf, 0xc6, 0x1a, 0x94, 0x0a, 0xd0, 0x73, 0x00, 0xc5, 0x06, 0x3f, 0x02, 0x95,
		0x62, 0xb0, 0x42, 0x07, 0x2c, 0x35, 0xa0, 0xa5, 0x06, 0xb8, 0x74, 0x80, 0x17, 0x16, 0x80, 0x81,
		0x81, 0x58, 0x26, 0x11, 0xfc, 0x06, 0xbf, 0xd0, 0x18, 0x73, 0x35, 0x1c, 0x05, 0xd8, 0x5d, 0x7e,
		0xfb, 0x80, 0xa6, 0xb7, 0x4c, 0x74, 0x3d, 0x05, 0x63, 0xb6, 0xf9, 0x15, 0xfc, 0xc9, 0xb3, 0xcd,
		0x4f, 0xce, 0x65, 0x64, 0xbd, 0x40, 0x6c, 0x01, 0x62, 0x10, 0x5e, 0xc3, 0xd2, 0x66, 0x9b, 0x1f,
		0x97, 0x36, 0x97, 0xb6, 0x8e, 0x6c, 0x00, 0xd7, 0xea, 0x73, 0xf6, 0x06, 0x55, 0x3d, 0x34, 0x59,
		0x29, 0x62, 0x6e, 0x98, 0xe5, 0x85, 0x53, 0xeb, 0x59, 0xf1, 0x2e, 0xc2, 0x6c, 0x56, 0xbc, 0x4b,
		0xd4, 0x39, 0x2b, 0xde, 0xe5, 0x2d, 0x57, 0x56, 0xbc, 0x85, 0x5d, 0x08, 0x2b, 0xde, 0x24, 0x9a,
		0x6f, 0x48, 0x44, 0x41, 0xc5, 0x7b, 0x60, 0xa2, 0x34, 0x4c, 0xef, 0xc1, 0x8f, 0x61, 0x47, 0x9c,
		0xa0, 0xe0, 0xce, 0x3f, 0xfa, 0xc3, 0x20, 0x01, 0x8e, 0x5b, 0x0b, 0x21, 0xb9, 0x7d, 0xb7, 0xef,
		0xf7, 0x4f, 0x0f, 0xbd, 0xd6, 0x99, 0xef, 0xbd, 0xef, 0x3a, 0xa8, 0xe1, 0x6b, 0x5a, 0xa7, 0x49,
		0x60, 0x1f, 0x44, 0x6c, 0x40, 0x3f, 0x8c, 0x78, 0xa4, 0x28, 0xbf, 0xe7, 0xd8, 0x47, 0x6f, 0xec,
		0x43, 0xb7, 0xe5, 0x7a, 0xef, 0xe7, 0xe2, 0xea, 0x23, 0xab, 0x4b, 0x93, 0xca, 0x74, 0xa8, 0xed,
		0x9b, 0xaa, 0x3b, 0xb4, 0xdb, 0xcd, 0x7f, 0xbb, 0x4d, 0xef, 0x8d, 0x7f, 0xd4, 0x69, 0xf7, 0xbd,
		0x9e, 0xed, 0xb6, 0xbd, 0xbe, 0x05, 0x7f, 0xcd, 0x5f, 0x7e, 0xa5, 0xf0, 0x64, 0x0b, 0xef, 0xd4,
		0x73, 0x5b, 0xee, 0x7f, 0x9c, 0xe6, 0x52, 0x81, 0x54, 0x1d, 0x55, 0x97, 0xb7, 0xea, 0xec, 0xe6,
		0x6f, 0x7e, 0xdf, 0x6d, 0x52, 0x6a, 0x94, 0x5a, 0xee, 0x52, 0x3b, 0xb3, 0xdd, 0x96, 0x7d, 0xd8,
		0x72, 0xe8, 0xe1, 0x28, 0xbb, 0xe2, 0x64, 0xe7, 0x76, 0xcf, 0x76, 0xfd, 0xb6, 0xe3, 0xbe, 0x7e,
		0x73, 0xd8, 0xe9, 0xf9, 0x76, 0xb3, 0xd9, 0x73, 0xfa, 0x04, 0x3a, 0x0a, 0x2f, 0x7f, 0xa0, 0x6b,
		0x67, 0x19, 0x84, 0xd3, 0xf4, 0x5b, 0xfd, 0x2e, 0x45, 0x47, 0xd1, 0xe5, 0x2d, 0xba, 0x96, 0xdb,
		0x7e, 0xeb, 0xdb, 0x9e, 0xd7, 0x73, 0x0f, 0x4f, 0x3d, 0x87, 0x7e, 0x8e, 0x92, 0x2b, 0x46, 0x72,
		0xdd, 0x5e, 0xc7, 0x73, 0x8e, 0x3c, 0xb7, 0xd3, 0x9e, 0xd5, 0xeb, 0xa8, 0x3b, 0xea, 0x2e, 0xf7,
		0xd4, 0xf5, 0xc4, 0x6d, 0xfb, 0xaf, 0x7b, 0x9d, 0x53, 0x46, 0x56, 0xca, 0xad, 0x98, 0x3c, 0xc2,
		0x6d, 0x7b, 0x4e, 0xef, 0xd8, 0x3e, 0x72, 0x98, 0x48, 0x50, 0x79, 0x45, 0x29, 0xef, 0xc4, 0x7e,
		0x37, 0x0b, 0xb2, 0xac, 0x9b, 0x50, 0x75, 0x05, 0x86, 0xd7, 0xdf, 0xfc, 0x96, 0xdd, 0x66, 0x75,
		0x98, 0x72, 0x2b, 0x2c, 0x8b, 0xa0, 0xd4, 0x28, 0xb5, 0x42, 0x48, 0xae, 0xc1, 0x8a, 0x30, 0x85,
		0x57, 0x8e, 0xf0, 0x98, 0x42, 0x50, 0x79, 0xa5, 0xa4, 0x10, 0x3d, 0xa7, 0xef, 0xf4, 0xce, 0xf8,
		0x00, 0x96, 0xda, 0x2b, 0x56, 0x7b, 0x9e, 0xe3, 0x37, 0x9d, 0x63, 0xfb, 0xb4, 0xe5, 0xf9, 0x27,
		0x8e, 0xd7, 0x73, 0x8f, 0x28, 0x3a, 0x8a, 0x2e, 0x6f, 0xd1, 0x9d, 0xb6, 0x67, 0xee, 0x8e, 0xfb,
		0xe9, 0xa8, 0xbb, 0xc2, 0xd3, 0xd8, 0xa6, 0xd3, 0xb2, 0xdf, 0xfb, 0x67, 0x76, 0xcf, 0xb5, 0x3d,
		0xb7, 0xd3, 0xa6, 0xee, 0xa8, 0xbb, 0xbc, 0x75, 0xe7, 0xbc, 0xf3, 0x9c, 0x76, 0xd3, 0x69, 0xf2,
		0xa9, 0x18, 0x75, 0x57, 0x68, 0x62, 0xe1, 0xb6, 0x97, 0xcf, 0x27, 0xa6, 0x7e, 0x8f, 0xaa, 0xa3,
		0xea, 0x0a, 0x89, 0xb2, 0xad, 0x0e, 0x6b, 0x27, 0x14, 0x5b, 0x91, 0x48, 0x47, 0xb5, 0x51, 0x6d,
		0x79, 0xab, 0xad, 0xe7, 0xf4, 0xdd, 0xe6, 0xa9, 0xdd, 0x52, 0x95, 0xb6, 0x42, 0x5f, 0xc1, 0x39,
		0x67, 0x59, 0x72, 0x95, 0xaf, 0x69, 0x75, 0x2b, 0xeb, 0x2e, 0xa6, 0xc0, 0xa4, 0x09, 0x4c, 0x53,
		0x17, 0x31, 0xd5, 0x25, 0x4d, 0x5d, 0xf0, 0xdd, 0xc2, 0x94, 0x94, 0x38, 0x49, 0x69, 0xea, 0x0a,
		0xa6, 0xbc, 0xa4, 0xc9, 0x4b, 0x59, 0xf7, 0x2f, 0x05, 0x26, 0x0e, 0xb8, 0xf4, 0x74, 0xf9, 0x52,
		0x5c, 0xd2, 0xc4, 0xa5, 0xa6, 0x9b, 0x97, 0xd2, 0x12, 0x29, 0x2d, 0x35, 0x5d, 0xbb, 0xd4, 0x97,
		0xbc, 0x54, 0x51, 0xc1, 0x3e, 0x04, 0xca, 0x4a, 0x24, 0xcf, 0x2b, 0xda, 0x42, 0x4f, 0x85, 0x49,
		0x53, 0x98, 0xa6, 0x6e, 0x5b, 0xaa, 0x4b, 0x5e, 0x58, 0x54, 0xd0, 0x55, 0x4b, 0x59, 0x89, 0xa4,
		0x79, 0x4a, 0x8a, 0x92, 0x5a, 0x2b, 0x69, 0x35, 0x58, 0x39, 0xa5, 0xc0, 0xf2, 0x15, 0x18, 0x51,
		0x9e, 0x0a, 0xcb, 0x15, 0xe5, 0x75, 0x75, 0xbd, 0x52, 0x63, 0xd2, 0x34, 0xa6, 0xa8, 0xbb, 0x95,
		0xe2, 0x92, 0x26, 0x2e, 0x5d, 0x5d, 0xac, 0xd4, 0x97, 0xc8, 0xb4, 0x51, 0x4d, 0xb7, 0x2a, 0xf5,
		0x25, 0x4d, 0x5f, 0xba, 0xba, 0x52, 0xa9, 0x2f, 0x71, 0x80, 0xaf, 0xa8, 0xfb, 0x94, 0xea, 0x12,
		0x19, 0x1d, 0xb1, 0xbb, 0x4c, 0x29, 0x2a, 0xb9, 0xc8, 0x45, 0x55, 0x51, 0x55, 0xeb, 0x52, 0x95,
		0xa6, 0xae, 0x51, 0xaa, 0xab, 0x74, 0x75, 0x75, 0x79, 0x12, 0x2f, 0xd5, 0x56, 0xb6, 0xea, 0x3c,
		0xfb, 0xf5, 0x6e, 0x83, 0x23, 0x17, 0x28, 0xb4, 0xbc, 0x85, 0xd6, 0xed, 0x39, 0xc7, 0xee, 0x3b,
		0x0e, 0xba, 0xa7, 0xda, 0x8a, 0x50, 0xdb, 0x74, 0x07, 0x6b, 0xaf, 0x73, 0xea, 0x39, 0x3d, 0xce,
		0xbb, 0xa7, 0xe2, 0x8a, 0x09, 0xa4, 0x94, 0x19, 0x65, 0x56, 0x50, 0x18, 0x3d, 0x6e, 0xd9, 0xaf,
		0x39, 0x97, 0x8d, 0x7a, 0x2b, 0x22, 0x90, 0x36, 0x54, 0x05, 0x52, 0x4e, 0xc9, 0xe2, 0x4a, 0xaf,
		0xd2, 0x0a, 0xd7, 0x9a, 0xf9, 0x53, 0x50, 0xcc, 0xf0, 0xa9, 0x2a, 0xfd, 0xaa, 0xd2, 0x92, 0xc9,
		0x53, 0x59, 0xcc, 0xd8, 0x29, 0x27, 0xfd, 0xe1, 0x0f, 0x3c, 0x33, 0xa7, 0xae, 0x98, 0x81, 0x53,
		0x59, 0x3a, 0x95, 0x35, 0x17, 0xd1, 0x91, 0xdd, 0xe5, 0x9e, 0x03, 0xea, 0xad, 0x54, 0xdd, 0xf5,
		0x7c, 0xbb, 0xf5, 0xba, 0xd3, 0x73, 0xbd, 0x37, 0x27, 0xac, 0x62, 0x53, 0x71, 0x85, 0x28, 0x6e,
		0xf9, 0x37, 0x96, 0xb1, 0xcb, 0x7d, 0xb1, 0x8c, 0xcd, 0x25, 0xce, 0x60, 0x42, 0x65, 0x31, 0x68,
		0x30, 0x58, 0x28, 0x0a, 0x12, 0x58, 0x9f, 0x33, 0x8e, 0xb5, 0x18, 0x96, 0x82, 0x38, 0x70, 0xcb,
		0x8e, 0xa2, 0x51, 0x1a, 0xa4, 0xe1, 0x28, 0xb2, 0x0e, 0x80, 0x5c, 0xb7, 0x95, 0x5c, 0x7e, 0x30,
		0x37, 0xc1, 0x6d, 0x90, 0x7e, 0x98, 0x38, 0xeb, 0xfa, 0xe8, 0xd6, 0x44, 0x97, 0xa3, 0xe8, 0x2a,
		0xbc, 0xae, 0x45, 0x26, 0xfd, 0x34, 0x8a, 0x3f, 0xd6, 0xc2, 0x28, 0x49, 0x83, 0xe8, 0xd2, 0xd4,
		0x1f, 0xbf, 0x91, 0xac, 0xbc, 0x53, 0xbf, 0x8d, 0x47, 0xe9, 0xe8, 0x72, 0x34, 0x4c, 0xb2, 0xef,
		0xea, 0x61, 0x12, 0x26, 0xf5, 0xa1, 0xb9, 0x33, 0xc3, 0xf9, 0x97, 0xfa, 0x30, 0x8c, 0x3e, 0xd6,
		0x92, 0x34, 0x48, 0x4d, 0x6d, 0x10, 0xa4, 0xc1, 0x45, 0x90, 0x98, 0xfa, 0x30, 0xb9, 0xad, 0xa7,
		0xc3, 0xbb, 0x64, 0xf2, 0x47, 0xfd, 0x26, 0xad, 0x85, 0x49, 0x54, 0x8f, 0x4c, 0x78, 0xfd, 0xe1,
		0x62, 0x14, 0x27, 0xd9, 0x77, 0xf5, 0xe5, 0xaf, 0xce, 0x7e, 0x65, 0x32, 0xbe, 0x98, 0xfe, 0xe0,
		0xec, 0x6b, 0x3d, 0xb8, 0x0b, 0xc2, 0x61, 0x70, 0x31, 0x34, 0xb5, 0x8b, 0x20, 0x1a, 0x7c, 0x0a,
		0x07, 0xe9, 0x87, 0xfa, 0xf4, 0x77, 0x01, 0x15, 0x62, 0xac, 0x24, 0x8d, 0xc7, 0x97, 0x69, 0x34,
		0x8f, 0xa0, 0x9d, 0xec, 0x9e, 0xb4, 0x67, 0x9f, 0xb7, 0x3b, 0xbf, 0x76, 0xff, 0xd1, 0xdf, 0x93,
		0xc7, 0x6f, 0xf8, 0xdd, 0xc5, 0xfd, 0xc8, 0xbe, 0xf3, 0xdd, 0x24, 0x4c, 0xfc, 0xd6, 0xf4, 0x7e,
		0xcc, 0xbe, 0xf8, 0xad, 0x30, 0xfa, 0xd8, 0x9f, 0x7c, 0x44, 0xcd, 0xf9, 0xdd, 0xf0, 0x5b, 0xc9,
		0xad, 0xef, 0x0d, 0xef, 0x92, 0xc9, 0x1f, 0xfe, 0x49, 0xea, 0x26, 0x91, 0xdf, 0x5e, 0xdc, 0x8c,
		0xec, 0x3b, 0x7f, 0xf9, 0x6b, 0xb3, 0xdf, 0xd7, 0x9f, 0xdd, 0x8c, 0xf9, 0x57, 0xdf, 0x5e, 0xdc,
		0x8c, 0xc3, 0xc5, 0xbd, 0xf0, 0xa7, 0xbf, 0x08, 0x23, 0xe8, 0xcb, 0x77, 0x90, 0xb2, 0x2d, 0x14,
		0xee, 0xba, 0xd1, 0x5c, 0x76, 0x15, 0x5c, 0x35, 0x80, 0x93, 0x56, 0xec, 0x9c, 0x65, 0xbb, 0x65,
		0xb9, 0xce, 0x4e, 0xb0, 0xa3, 0xb3, 0xb2, 0xa5, 0x55, 0xbb, 0x1c, 0x45, 0x49, 0x1a, 0x07, 0x61,
		0x94, 0x26, 0xe2, 0xfd, 0x5d, 0x56, 0x3d, 0x78, 0xda, 0x7c, 0xe1, 0x81, 0xe5, 0x6d, 0x18, 0x0d,
		0xac, 0x83, 0x8d, 0x2d, 0xe1, 0x66, 0x1e, 0x4d, 0xdd, 0x96, 0x75, 0xb0, 0xb1, 0x29, 0xdc, 0xd0,
		0x6e, 0x6c, 0xae, 0xc2, 0xcf, 0x18, 0x41, 0x7a, 0x21, 0xdc, 0xd1, 0x65, 0x6d, 0x12, 0x4e, 0x11,
		0x02, 0x5a, 0x7f, 0x34, 0x8e, 0x2f, 0x0d, 0x4c, 0xda, 0x6a, 0xbd, 0x35, 0xf7, 0x9f, 0x46, 0xf1,
		0x64, 0x85, 0x59, 0xb7, 0x33, 0x65, 0x80, 0xd4, 0x08, 0xde, 0x04, 0x89, 0x1d, 0x5f, 0x8f, 0x6f,
		0x4c, 0x94, 0x5a, 0x07, 0x1b, 0x69, 0x3c, 0x36, 0x28, 0xc5, 0x8d, 0xa5, 0xd5, 0x99, 0xb0, 0x99,
		0x1c, 0xa9, 0x4e, 0x8e, 0x9a, 0x61, 0x8c, 0xe1, 0x70, 0x9f, 0x22, 0x04, 0x1c, 0x5f, 0xf6, 0x57,
		0x9c, 0x83, 0xe2, 0xd6, 0x30, 0x70, 0x07, 0x0e, 0x7b, 0x10, 0xf1, 0x07, 0x18, 0x83, 0x50, 0x71,
		0x08, 0x1e, 0x8b, 0xe0, 0xf1, 0x08, 0x1b, 0x93, 0x30, 0x70, 0x09, 0x04, 0x9b, 0xe0, 0xf0, 0x29,
		0x33, 0x18, 0xa9, 0x3a, 0xf4, 0x6c, 0xb4, 0xc1, 0xa9, 0x11, 0x81, 0x43, 0x14, 0x2c, 0x4c, 0x21,
		0x43, 0x95, 0x02, 0xb8, 0x42, 0x87, 0x2c, 0x35, 0xb0, 0xa5, 0x06, 0xba, 0x74, 0xc0, 0x17, 0x16,
		0x84, 0x81, 0xc1, 0x18, 0x2c, 0x94, 0x3d, 0x01, 0x67, 0xb8, 0x1e, 0x73, 0x95, 0xd1, 0x50, 0x5d,
		0x26, 0x26, 0xaa, 0xc1, 0x23, 0x9b, 0x06, 0x74, 0x53, 0x84, 0x70, 0x5a, 0x50, 0x4e, 0x1d, 0xd2,
		0xa9, 0x43, 0x3b, 0x5d, 0x88, 0x87, 0x89, 0x7a, 0xa0, 0xc8, 0x07, 0x8f, 0x7e, 0x4f, 0x20, 0x60,
		0x2d, 0x1c, 0xe0, 0x3b, 0xdb, 0x55, 0x1a, 0x9c, 0x5c, 0x16, 0xb8, 0x7f, 0x9a, 0x83, 0xe1, 0x26,
		0xf8, 0x65, 0xa0, 0x03, 0xa2, 0x26, 0x50, 0x54, 0x08, 0x8c, 0xda, 0xc0, 0x51, 0x2d, 0x40, 0xaa,
		0x05, 0x49, 0x9d, 0x40, 0x89, 0x0d, 0x96, 0xe0, 0x80, 0x99, 0x49, 0xca, 0xbb, 0xbf, 0x35, 0xba,
		0x22, 0xce, 0xd0, 0x04, 0x57, 0xb1, 0xb9, 0xd2, 0x10, 0x71, 0x16, 0x95, 0xbb, 0x3d, 0x05, 0xd7,
		0xd2, 0x9d, 0xf7, 0x81, 0xbd, 0x78, 0x31, 0xeb, 0x6f, 0xad, 0x7f, 0x8d, 0xd2, 0xbf, 0xd0, 0x85,
		0xd1, 0x7d, 0x7d, 0x9f, 0xa2, 0x66, 0x6d, 0xd2, 0x6a, 0x52, 0x4b, 0xb4, 0xae, 0xef, 0xbf, 0xf4,
		0x58, 0x4c, 0x29, 0x99, 0x52, 0x32, 0xa5, 0x64, 0x4a, 0xc9, 0x94, 0x92, 0x29, 0x25, 0x79, 0xac,
		0x5a, 0x29, 0x25, 0xfa, 0xb3, 0x8b, 0xec, 0x42, 0x96, 0x63, 0x1e, 0x0e, 0xb4, 0x8d, 0x46, 0x45,
		0x9a, 0x60, 0xf1, 0x3d, 0xe0, 0xb9, 0xa9, 0xe4, 0x72, 0xb4, 0x00, 0xa8, 0x46, 0x10, 0x55, 0x0c,
		0xa4, 0x5a, 0xc1, 0x54, 0x3d, 0xa0, 0xaa, 0x07, 0x55, 0xdd, 0xc0, 0xaa, 0x03, 0x5c, 0x95, 0x00,
		0x6c, 0x26, 0x35, 0x35, 0xcf, 0x46, 0x56, 0x22, 0x56, 0x68, 0x8c, 0xb9, 0x1a, 0x8e, 0x82, 0xf4,
		0xe5, 0xb6, 0xa6, 0xa8, 0x35, 0x87, 0xc0, 0x7d, 0x45, 0x97, 0xd4, 0x32, 0xd1, 0xf5, 0x34, 0x01,
		0xf9, 0x5d, 0x95, 0x1b, 0xd7, 0x85, 0x15, 0xd3, 0x3b, 0x75, 0x12, 0x46, 0xea, 0x78, 0x49, 0x69,
		0x7a, 0xb5, 0x72, 0x79, 0xd3, 0x53, 0x83, 0xac, 0x83, 0x8d, 0x86, 0xd2, 0xeb, 0x3b, 0x8e, 0x83,
		0xcb, 0x34, 0x1c, 0x45, 0xcd, 0xf0, 0x3a, 0x9c, 0x36, 0x4c, 0x6f, 0xaa, 0xbb, 0xce, 0x2f, 0xbf,
		0x2a, 0x74, 0x29, 0xc1, 0x67, 0xba, 0x14, 0xba, 0x14, 0xba, 0x14, 0x66, 0x63, 0xbc, 0x9a, 0xe5,
		0xeb, 0xfc, 0x17, 0xde, 0x0f, 0x86, 0xdc, 0xf5, 0xb8, 0x31, 0x5d, 0x7d, 0x2a, 0x2b, 0x89, 0xbe,
		0xa6, 0x7e, 0x15, 0xa5, 0xe4, 0xc0, 0x67, 0x3d, 0x48, 0x0b, 0x8a, 0xcf, 0x7a, 0x70, 0xdc, 0x04,
		0x9f, 0xf5, 0x80, 0x5f, 0x20, 0x9f, 0xf5, 0x90, 0x01, 0x0b, 0x92, 0x9a, 0xde, 0x67, 0x3d, 0xe3,
		0x30, 0xd2, 0xf9, 0x98, 0x67, 0x4f, 0xd1, 0x25, 0xf5, 0x82, 0xe8, 0xda, 0xf0, 0x29, 0x8f, 0xfc,
		0x1b, 0xc5, 0xa7, 0x3c, 0xb8, 0x97, 0xb7, 0x28, 0xc9, 0x6e, 0xb2, 0x24, 0x4b, 0xdc, 0x10, 0xe4,
		0x52, 0xf8, 0x94, 0x07, 0xde, 0xa5, 0x34, 0xb6, 0xf7, 0x1b, 0xfb, 0xbb, 0x7b, 0xdb, 0xfb, 0x3b,
		0xf4, 0x2d, 0x4c, 0xc8, 0x78, 0x35, 0xeb, 0x7c, 0xf1, 0x71, 0x0f, 0xaf, 0xa0, 0xf2, 0xe4, 0x80,
		0x7a, 0x60, 0xfb, 0xb3, 0xd7, 0xa3, 0xed, 0x74, 0xe0, 0x27, 0x4f, 0xfe, 0x7c, 0xf2, 0xdd, 0xfa,
		0xc3, 0xff, 0xe1, 0xc1, 0xdb, 0x1a, 0x06, 0x00, 0x6c, 0x68, 0x3a, 0x71, 0x38, 0x3b, 0x68, 0xf8,
		0x68, 0x79, 0xc3, 0x9e, 0x7a, 0xd3, 0x7f, 0xf8, 0xdf, 0x1f, 0xbc, 0x0d, 0x74, 0x76, 0xbc, 0x3e,
		0x9f, 0xcf, 0x79, 0xa5, 0x85, 0xa6, 0x79, 0xe6, 0x5e, 0xcb, 0x76, 0x03, 0xab, 0x15, 0x26, 0xa9,
		0x9d, 0xa6, 0xe0, 0x03, 0x58, 0x4f, 0xc2, 0xc8, 0x19, 0x9a, 0x1b, 0x33, 0x3b, 0x20, 0x09, 0x38,
		0xff, 0xb6, 0x4e, 0x82, 0xcf, 0x0f, 0xae, 0x64, 0xeb, 0x55, 0xa3, 0xb1, 0xbb, 0xd7, 0x68, 0x6c,
		0xee, 0xbd, 0xdc, 0xdb, 0xdc, 0xdf, 0xd9, 0xd9, 0xda, 0xdd, 0x02, 0xce, 0xb9, 0xad, 0x4e, 0x3c,
		0x30, 0xb1, 0x19, 0x1c, 0x4e, 0x96, 0x4f, 0x34, 0x1e, 0x0e, 0xe9, 0xb5, 0xc8, 0xd4, 0x64, 0xe9,
		0x9f, 0x65, 0x69, 0x0b, 0x7a, 0xac, 0x19, 0xe9, 0x79, 0x72, 0x0b, 0x7f, 0x21, 0x75, 0xd2, 0x62,
		0xf0, 0x48, 0x83, 0x1e, 0x61, 0x18, 0x59, 0x10, 0x0f, 0xe7, 0xac, 0x7c, 0x18, 0xc1, 0x8a, 0x1d,
		0x38, 0x1e, 0x18, 0xc8, 0xfb, 0x5a, 0x37, 0xa3, 0x81, 0x19, 0x22, 0xf6, 0x74, 0x64, 0x1b, 0xf7,
		0xb2, 0x2b, 0xc0, 0x3c, 0x1a, 0x78, 0x93, 0x47, 0x03, 0x17, 0x63, 0x38, 0x8f, 0x06, 0x2e, 0xf5,
		0x12, 0x78, 0x34, 0xb0, 0x90, 0x0b, 0xe1, 0xd1, 0xc0, 0xa4, 0x9a, 0xaa, 0xe4, 0x95, 0xb0, 0xed,
		0x0a, 0x0a, 0x8e, 0xe9, 0x40, 0x3e, 0x96, 0x63, 0xf5, 0x18, 0x8e, 0x8c, 0x32, 0x99, 0x33, 0x55,
		0x3e, 0x67, 0xc2, 0x3c, 0x51, 0x03, 0xfa, 0x04, 0x0d, 0xd0, 0x13, 0x33, 0x98, 0x2d, 0x31, 0x5b,
		0x62, 0xb6, 0xc4, 0x6c, 0x89, 0xd9, 0x12, 0xb3, 0x25, 0xf9, 0x12, 0x41, 0x3d, 0x91, 0x02, 0xb7,
		0x88, 0xbd, 0x12, 0xb2, 0x40, 0x8b, 0xd9, 0x8f, 0x31, 0x0d, 0x74, 0x1f, 0x1d, 0xfc, 0x8c, 0x21,
		0x0d, 0x33, 0x85, 0x14, 0xcd, 0x10, 0xd2, 0x32, 0x33, 0x48, 0xdd, 0x8c, 0x20, 0x75, 0x33, 0x81,
		0x74, 0xcd, 0x00, 0x62, 0x53, 0x42, 0x91, 0xd2, 0x81, 0x9f, 0xe9, 0xf3, 0xd5, 0x0c, 0x9f, 0x57,
		0xc8, 0xf1, 0x62, 0x8e, 0x4f, 0xc8, 0x3b, 0xf5, 0x75, 0x8c, 0xe8, 0x51, 0xd0, 0x39, 0xaa, 0x69,
		0x04, 0x8f, 0xb6, 0x59, 0xa6, 0xca, 0x46, 0xec, 0x68, 0x1c, 0x7b, 0xa1, 0x61, 0x6a, 0xb3, 0xa6,
		0x91, 0x39, 0x5a, 0x5d, 0xc0, 0xf6, 0xce, 0x0e, 0x9d, 0x00, 0x13, 0x11, 0x5a, 0xff, 0xf0, 0x75,
		0xce, 0xae, 0x26, 0x5a, 0x8c, 0x1e, 0x92, 0xd9, 0xd5, 0x84, 0xdb, 0xd5, 0x84, 0x3a, 0x64, 0xa6,
		0x7a, 0xfd, 0x4c, 0x80, 0xd3, 0x63, 0x80, 0x76, 0xe5, 0xfd, 0xc2, 0xb8, 0xb0, 0xc6, 0x0c, 0x66,
		0x36, 0xfd, 0x05, 0xec, 0x19, 0x2f, 0xe6, 0xa0, 0x17, 0xdc, 0xc1, 0x2e, 0xaa, 0x06, 0xb9, 0x60,
		0x0e, 0x6e, 0x41, 0x71, 0x28, 0xa0, 0x80, 0x59, 0x61, 0xb0, 0xb4, 0xa0, 0xb6, 0xb9, 0x57, 0x0b,
		0x25, 0x31, 0x20, 0x52, 0x3e, 0x92, 0xc9, 0xb6, 0x50, 0xb8, 0x6f, 0x47, 0xf3, 0xe9, 0xd5, 0xf0,
		0xe5, 0x00, 0x6e, 0x5b, 0xb5, 0xbb, 0x96, 0xed, 0x9a, 0xe5, 0x3a, 0x3c, 0xc1, 0xce, 0xce, 0x32,
		0x9f, 0x53, 0x13, 0x0d, 0xcc, 0xa0, 0x16, 0x0c, 0x6e, 0xc2, 0xa8, 0x76, 0x1d, 0x8f, 0xc6, 0xb7,
		0xe2, 0x5d, 0x5e, 0xb6, 0xd5, 0xe8, 0x49, 0xeb, 0x85, 0x87, 0x16, 0x8c, 0x1e, 0x3a, 0x98, 0x4d,
		0xd8, 0x48, 0x9b, 0xad, 0x01, 0x37, 0x55, 0xa3, 0x6d, 0x9e, 0x86, 0xdd, 0x24, 0x0d, 0xbb, 0x19,
		0x1a, 0x73, 0xd3, 0x33, 0xd3, 0xa3, 0x9f, 0xb9, 0xe5, 0x28, 0x3d, 0x6a, 0x60, 0x43, 0x02, 0x20,
		0x87, 0x03, 0x80, 0x0d, 0x05, 0x80, 0xeb, 0x2e, 0x43, 0xec, 0x26, 0x03, 0xee, 0x1e, 0x43, 0xed,
		0x16, 0x83, 0xef, 0x0e, 0x83, 0xef, 0x06, 0xc3, 0xee, 0xfe, 0xe2, 0x26, 0x83, 0x2a, 0x02, 0x52,
		0x66, 0x30, 0x64, 0x1d, 0xe8, 0xd9, 0xb0, 0x03, 0x58, 0x17, 0x7a, 0x0e, 0xab, 0x38, 0x99, 0x96,
		0x98, 0xa5, 0x18, 0xb7, 0xd0, 0xb1, 0x4b, 0x0d, 0x7e, 0xa9, 0xc1, 0x30, 0x1d, 0x38, 0x86, 0x85,
		0x65, 0x60, 0x78, 0x96, 0x49, 0x04, 0x7f, 0x32, 0xed, 0x38, 0x8c, 0xd2, 0x97, 0xdb, 0xc0, 0x83,
		0x69, 0x11, 0xe7, 0xd2, 0x62, 0x77, 0xd7, 0x63, 0x9f, 0x13, 0xa9, 0x60, 0x8c, 0x8f, 0x8a, 0x16,
		0x5a, 0x2d, 0xdd, 0xf3, 0x9a, 0x1a, 0x66, 0xbf, 0x60, 0x1f, 0x9c, 0xca, 0xa5, 0x2d, 0x6c, 0x69,
		0x37, 0xb6, 0xf7, 0x1b, 0xfb, 0xbb, 0x7b, 0xdb, 0xfb, 0x3b, 0x5c, 0xe3, 0x4c, 0x08, 0xaa, 0x65,
		0xf5, 0x39, 0x13, 0xaf, 0x1c, 0x17, 0x24, 0xf4, 0xb1, 0xe5, 0xf8, 0xc7, 0x95, 0xab, 0x3c, 0xa6,
		0x1c, 0xfb, 0x78, 0x72, 0xb6, 0x23, 0x57, 0xd2, 0x23, 0xb2, 0x7b, 0x50, 0x48, 0xc7, 0xc9, 0x53,
		0x8f, 0x0c, 0xe1, 0x06, 0x50, 0xa8, 0x69, 0x3f, 0x71, 0xe6, 0x77, 0xc3, 0x9e, 0xdc, 0x8c, 0xd7,
		0x93, 0x7b, 0x81, 0x34, 0x62, 0x82, 0xdd, 0x81, 0xaa, 0x7d, 0x37, 0xbb, 0x03, 0x05, 0xfa, 0x6a,
		0x36, 0x07, 0x96, 0xe9, 0x9d, 0xd9, 0x1a, 0xa8, 0xce, 0xd3, 0x59, 0xe1, 0xed, 0x5d, 0xa3, 0x16,
		0x46, 0xa9, 0x89, 0xaf, 0x82, 0x4b, 0x53, 0x0b, 0x06, 0x83, 0xd8, 0x24, 0x09, 0x4e, 0x73, 0xe0,
		0x33, 0xf6, 0xb3, 0x3d, 0x70, 0x1d, 0x66, 0xb2, 0x3d, 0x30, 0x47, 0xe5, 0xb2, 0x3d, 0x30, 0xbf,
		0xe5, 0xc5, 0xf6, 0xc0, 0xa2, 0x61, 0x99, 0xed, 0x81, 0x55, 0xcb, 0x8f, 0xd8, 0x1e, 0x98, 0x6f,
		0x7c, 0x60, 0x7b, 0x20, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07,
		0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83, 0x51, 0x8a,
		0x3f, 0xcf, 0x46, 0x1a, 0x8c, 0xea, 0xcf, 0x73, 0xf0, 0xc4, 0x26, 0x40, 0xc2, 0x94, 0x62, 0xa8,
		0x42, 0x87, 0x2b, 0x35, 0x90, 0xa5, 0x06, 0xb6, 0x74, 0x40, 0x17, 0x16, 0x7c, 0x81, 0x41, 0x58,
		0x26, 0x11, 0xfc, 0x26, 0xc0, 0xe9, 0x93, 0x2e, 0x4c, 0xc2, 0x79, 0x48, 0x39, 0x5b, 0xaf, 0x00,
		0x6d, 0xef, 0x06, 0x69, 0x6a, 0xe2, 0x08, 0xb6, 0x1b, 0xd0, 0xfa, 0xe7, 0x3f, 0x7f, 0xdf, 0xac,
		0xed, 0x9f, 0xff, 0xef, 0xf7, 0xad, 0xda, 0xfe, 0xf9, 0xec, 0xdb, 0xad, 0xe9, 0x97, 0xd9, 0xf7,
		0xdb, 0xbf, 0x6f, 0xd6, 0x1a, 0x8b, 0xef, 0x77, 0x7e, 0xdf, 0xac, 0xed, 0x9c, 0xff, 0xeb, 0x8f,
		0x3f, 0x5e, 0xfc, 0xeb, 0xcf, 0x97, 0x5f, 0xbe, 0xff, 0x07, 0xf1, 0x5c, 0xef, 0x39, 0xa2, 0x24,
		0x3b, 0x7d, 0xf7, 0x1d, 0xbc, 0x2e, 0xff, 0x5b, 0xa4, 0x30, 0xff, 0x61, 0xb1, 0x41, 0x85, 0x50,
		0xf0, 0x40, 0x7d, 0x6c, 0x50, 0x29, 0xf9, 0x0a, 0xd8, 0xa0, 0xc2, 0x24, 0x44, 0xb5, 0xa5, 0x6c,
		0x50, 0xc9, 0xd7, 0x6e, 0x6d, 0x9b, 0x9e, 0x9f, 0xde, 0xce, 0xc8, 0x16, 0x95, 0xb2, 0x36, 0x41,
		0xbb, 0xb7, 0x77, 0x0d, 0x77, 0x71, 0x3b, 0xec, 0xd9, 0xdd, 0x60, 0x93, 0x4a, 0x75, 0x2c, 0x64,
		0x93, 0x0a, 0xfd, 0xf5, 0xf7, 0xfb, 0x6b, 0xb6, 0xa9, 0x94, 0xeb, 0xa1, 0xd9, 0xa8, 0xa2, 0xce,
		0xdb, 0xcd, 0xca, 0xdf, 0x8b, 0x95, 0x09, 0xda, 0xa7, 0xb2, 0x62, 0x3e, 0xdb, 0x54, 0xd6, 0x61,
		0x26, 0xdb, 0x54, 0x72, 0x14, 0x2e, 0xdb, 0x54, 0xf2, 0x5b, 0x5e, 0x6c, 0x53, 0x29, 0x1a, 0x97,
		0xd9, 0xa6, 0x52, 0xb5, 0x0c, 0x89, 0x6d, 0x2a, 0xf9, 0xc6, 0x07, 0xb6, 0xa9, 0x10, 0x6c, 0x10,
		0x01, 0x07, 0x18, 0x74, 0x50, 0x81, 0x07, 0x1e, 0x7c, 0xe0, 0x01, 0x08, 0x1b, 0x84, 0x30, 0x80,
		0x08, 0x04, 0x8c, 0xe0, 0x00, 0x29, 0x33, 0x98, 0x6d, 0x2a, 0xa5, 0xc2, 0x13, 0xdb, 0x54, 0x08,
		0x53, 0x8a, 0xa1, 0x0a, 0x1d, 0xae, 0xd4, 0x40, 0x96, 0x1a, 0xd8, 0xd2, 0x01, 0x5d, 0x58, 0xf0,
		0x05, 0x06, 0x61, 0x99, 0x44, 0xd8, 0xa6, 0x22, 0x84, 0x72, 0xd8, 0xa6, 0x52, 0xc6, 0x05, 0xb0,
		0x4d, 0xe5, 0xaf, 0x5e, 0x6c, 0x53, 0x29, 0xeb, 0x2a, 0xd8, 0xa6, 0xf2, 0x0d, 0x65, 0x12, 0x0a,
		0x72, 0x54, 0x1f, 0xdb, 0x54, 0x4a, 0xbe, 0x02, 0xb6, 0xa9, 0x30, 0x09, 0x51, 0x6d, 0x29, 0xdb,
		0x54, 0xf2, 0xb5, 0x5b, 0xe5, 0xb6, 0xe7, 0xc7, 0xbb, 0x19, 0xd9, 0xa5, 0x52, 0xe6, 0x1e, 0xe8,
		0xc5, 0xff, 0xce, 0x26, 0x95, 0xca, 0x59, 0xc8, 0x26, 0x15, 0x7a, 0xeb, 0xef, 0xf6, 0xd6, 0xec,
		0x51, 0x29, 0xd5, 0x3f, 0xb3, 0x45, 0x45, 0x9d, 0xaf, 0xb3, 0xc2, 0xdb, 0xbb, 0x5d, 0xf0, 0xb3,
		0x54, 0x76, 0x79, 0x96, 0x4a, 0x4e, 0x66, 0xb2, 0x49, 0x25, 0x47, 0xe5, 0xb2, 0x49, 0x25, 0xbf,
		0xe5, 0xc5, 0x26, 0x95, 0xa2, 0x71, 0x99, 0x4d, 0x2a, 0x55, 0xcb, 0x90, 0xd8, 0xa4, 0x92, 0x6f,
		0x7c, 0x60, 0x93, 0x0a, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07,
		0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83, 0xd9, 0xa4,
		0x52, 0x2a, 0x3c, 0xb1, 0x49, 0x85, 0x30, 0xa5, 0x18, 0xaa, 0xd0, 0xe1, 0x4a, 0x0d, 0x64, 0xa9,
		0x81, 0x2d, 0x1d, 0xd0, 0x85, 0x05, 0x5f, 0x60, 0x10, 0x96, 0x49, 0x44, 0x45, 0x93, 0xca, 0x2e,
		0x9b, 0x54, 0x4a, 0x22, 0x06, 0x1d, 0x4d, 0x2a, 0x41, 0xed, 0xca, 0xae, 0x1d, 0x9f, 0xff, 0xb9,
		0xf5, 0x6b, 0xe3, 0xcb, 0xc1, 0xbf, 0xfe, 0xdc, 0xfb, 0xf2, 0xf8, 0xcd, 0xff, 0x3d, 0xf5, 0xbf,
		0x6d, 0xfd, 0xba, 0xf7, 0xe5, 0xe0, 0x99, 0xff, 0xb2, 0xfb, 0xe5, 0xe0, 0x6f, 0xfe, 0x1b, 0x3b,
		0x5f, 0xfe, 0xb9, 0xf2, 0xbf, 0x4e, 0xde, 0xdf, 0x7e, 0xee, 0x07, 0x1a, 0xcf, 0xfc, 0xc0, 0xcb,
		0xe7, 0x7e, 0xe0, 0xe5, 0x33, 0x3f, 0xf0, 0xac, 0x49, 0xdb, 0xcf, 0xfc, 0xc0, 0xce, 0x97, 0xff,
		0xad, 0xfc, 0xff, 0xff, 0x7c, 0xfa, 0x7f, 0xdd, 0xfd, 0xf2, 0xaf, 0xff, 0x3d, 0xf7, 0xdf, 0xf6,
		0xbe, 0xfc, 0xef, 0xe0, 0x5f, 0x6c, 0xd9, 0x29, 0x66, 0x81, 0x6a, 0x6a, 0xd9, 0xe1, 0x32, 0x2d,
		0x7e, 0x99, 0xb2, 0x81, 0x89, 0xc0, 0xf8, 0xd5, 0x5a, 0x64, 0x03, 0x53, 0xc9, 0x57, 0xc0, 0x06,
		0x26, 0x26, 0xa8, 0xaa, 0x2d, 0x65, 0x03, 0x53, 0xbe, 0x76, 0x2b, 0xdc, 0x12, 0xbf, 0xcb, 0x73,
		0x76, 0x44, 0xed, 0x90, 0xdf, 0xe5, 0x39, 0x3b, 0xd5, 0xb5, 0x90, 0x2d, 0x4c, 0xf4, 0xd7, 0xdf,
		0xef, 0xaf, 0xd9, 0xc3, 0x54, 0xae, 0x87, 0x66, 0x13, 0x93, 0x3a, 0x6f, 0x37, 0x7b, 0x34, 0x02,
		0x7d, 0xce, 0xce, 0x2e, 0xcf, 0xd9, 0xc9, 0xc7, 0x4c, 0xb6, 0x30, 0xe5, 0x28, 0x5c, 0xb6, 0x30,
		0xe5, 0xb7, 0xbc, 0xd8, 0xc2, 0x54, 0x34, 0x2e, 0xb3, 0x85, 0xa9, 0x6a, 0x19, 0x12, 0x5b, 0x98,
		0xf2, 0x8d, 0x0f, 0x6c, 0x61, 0x22, 0xd8, 0x20, 0x02, 0x0e, 0x30, 0xe8, 0xa0, 0x02, 0x0f, 0x3c,
		0xf8, 0xc0, 0x03, 0x10, 0x36, 0x08, 0x61, 0x00, 0x11, 0x08, 0x18, 0xc1, 0x01, 0x52, 0x66, 0x30,
		0x5b, 0x98, 0x4a, 0x85, 0x27, 0xb6, 0x30, 0x11, 0xa6, 0x14, 0x43, 0x15, 0x3a, 0x5c, 0xa9, 0x81,
		0x2c, 0x35, 0xb0, 0xa5, 0x03, 0xba, 0xb0, 0xe0, 0x0b, 0x0c, 0xc2, 0x32, 0x89, 0xb0, 0x85, 0x49,
		0x08, 0xe5, 0xb0, 0x85, 0xa9, 0x8c, 0x0b, 0x60, 0x6f, 0x04, 0x5b, 0x98, 0xfe, 0xee, 0x8b, 0x2d,
		0x4c, 0x65, 0x5d, 0x05, 0x5b, 0x98, 0xd8, 0xc2, 0xf4, 0x1d, 0xeb, 0x94, 0xc0, 0x98, 0xe3, 0x5a,
		0x64, 0x0b, 0x53, 0xc9, 0x57, 0xc0, 0x16, 0x26, 0x26, 0xa8, 0xaa, 0x2d, 0x65, 0x0b, 0x53, 0xbe,
		0x76, 0xab, 0xdc, 0x12, 0xcf, 0x33, 0x98, 0x24, 0xed, 0x8f, 0xe7, 0x19, 0x4c, 0x95, 0xb5, 0x90,
		0x0d, 0x4c, 0xf4, 0xd6, 0xdf, 0xed, 0xad, 0xd9, 0xbf, 0x54, 0xaa, 0x7f, 0x66, 0xfb, 0x92, 0x3a,
		0x5f, 0x67, 0x0d, 0x83, 0xa8, 0x16, 0x0c, 0xfe, 0x5f, 0x70, 0x69, 0xa2, 0xcb, 0xfb, 0x5a, 0x12,
		0x0e, 0x80, 0x7a, 0x97, 0x9e, 0xb0, 0x9d, 0x8d, 0x4b, 0xeb, 0x30, 0x93, 0x8d, 0x4b, 0x39, 0xaa,
		0x96, 0x8d, 0x4b, 0xf9, 0x2d, 0x2f, 0x36, 0x2e, 0x15, 0x8d, 0xc9, 0x6c, 0x5c, 0xaa, 0x5a, 0x66,
		0x04, 0xd3, 0xb8, 0xb4, 0x82, 0x07, 0x78, 0x4d, 0x4c, 0xab, 0x97, 0xc0, 0x86, 0xa6, 0x2a, 0x03,
		0x0f, 0x22, 0xf8, 0x00, 0x03, 0x10, 0x2a, 0x08, 0xc1, 0x03, 0x11, 0x3c, 0x18, 0x61, 0x03, 0x12,
		0x06, 0x28, 0x81, 0x00, 0x13, 0x1c, 0x38, 0x65, 0x06, 0x63, 0x75, 0x7e, 0xaf, 0xc4, 0x19, 0xb4,
		0x47, 0x7b, 0x80, 0xe0, 0x04, 0x0b, 0x50, 0xc8, 0x20, 0xa5, 0x00, 0xa8, 0xd0, 0xc1, 0x4a, 0x0d,
		0x60, 0xa9, 0x01, 0x2d, 0x1d, 0xc0, 0x85, 0x05, 0x5e, 0x60, 0x00, 0x06, 0x0b, 0x62, 0x99, 0xe1,
		0x57, 0xc3, 0xe0, 0x3a, 0xc1, 0x75, 0x96, 0x8b, 0x78, 0x35, 0xbb, 0x0c, 0x50, 0xff, 0x82, 0xd9,
		0x6d, 0x0e, 0x0f, 0x6a, 0x1a, 0x80, 0x4d, 0x11, 0xb8, 0x69, 0x01, 0x38, 0x75, 0x20, 0xa7, 0x0e,
		0xe8, 0x74, 0x81, 0x1d, 0x26, 0xe0, 0x81, 0x82, 0x5e, 0x26, 0x1d, 0xd8, 0xee, 0xf5, 0x95, 0x88,
		0x61, 0xa2, 0xf1, 0x8d, 0x89, 0x67, 0xfb, 0x52, 0x81, 0xa3, 0xc6, 0xa2, 0xca, 0xd5, 0x00, 0xbe,
		0x06, 0x27, 0x1a, 0xdf, 0x4c, 0x44, 0xc5, 0xa5, 0x5c, 0xe4, 0xa7, 0x0e, 0xdd, 0x57, 0x98, 0x5d,
		0x05, 0x7c, 0x7f, 0xe1, 0xf2, 0x4a, 0x14, 0xf6, 0x19, 0x66, 0x17, 0x07, 0xdd, 0x6f, 0x88, 0x8b,
		0x1a, 0x80, 0xbe, 0xc9, 0xca, 0x5a, 0x15, 0x80, 0xb6, 0x19, 0x3d, 0x4b, 0x19, 0x0f, 0x2f, 0x86,
		0x65, 0x9a, 0x32, 0xcc, 0x67, 0x99, 0x46, 0xd0, 0x72, 0x60, 0x99, 0x46, 0xce, 0xb2, 0x66, 0x99,
		0x46, 0xf8, 0x05, 0xb1, 0x4c, 0x43, 0x7e, 0xfa, 0x41, 0xe9, 0xe8, 0x29, 0xd3, 0x24, 0xf7, 0x49,
		0x6a, 0x6e, 0x70, 0xf1, 0x69, 0x03, 0x7c, 0xe2, 0xe0, 0x12, 0x43, 0xc0, 0x67, 0x9a, 0x65, 0x17,
		0xf2, 0xdf, 0xdf, 0x37, 0x6b, 0xfb, 0x76, 0xed, 0x38, 0xa8, 0x5d, 0x9d, 0xff, 0xd9, 0xf8, 0xf2,
		0xc7, 0x1f, 0x2f, 0xbe, 0xf1, 0xc6, 0x3f, 0x70, 0xbd, 0xee, 0x39, 0xb2, 0xe0, 0x34, 0x4c, 0xd2,
		0xab, 0xa6, 0xea, 0x58, 0xdd, 0x21, 0x9d, 0x3c, 0xb3, 0x0e, 0xee, 0x82, 0xe1, 0xd8, 0xe0, 0xd7,
		0x75, 0x66, 0x97, 0xc1, 0x8a, 0x4e, 0x19, 0xe6, 0xb3, 0xa2, 0x23, 0x68, 0x21, 0xb0, 0xa2, 0x23,
		0x67, 0x59, 0xb3, 0xa2, 0x23, 0xfc, 0x82, 0x58, 0xd1, 0x21, 0x33, 0xfd, 0xa0, 0x74, 0xf4, 0x54,
		0x74, 0xc6, 0x61, 0x94, 0xbe, 0xdc, 0x56, 0x50, 0xce, 0xd9, 0x03, 0xbe, 0x84, 0x5e, 0x10, 0x5d,
		0x1b, 0xf8, 0xac, 0x1a, 0x3b, 0x60, 0x6f, 0xcc, 0xf7, 0xaf, 0xc0, 0x93, 0x87, 0x92, 0xc4, 0x62,
		0xe5, 0x72, 0xce, 0xe6, 0xb9, 0xaa, 0x96, 0xeb, 0x39, 0x8e, 0x83, 0xcb, 0x34, 0x1c, 0x45, 0xcd,
		0xf0, 0x3a, 0x9c, 0x6d, 0x97, 0x82, 0xbf, 0xae, 0x2f, 0xbf, 0x2a, 0x70, 0x01, 0xc1, 0x67, 0xba,
		0x00, 0xe1, 0x2e, 0xa0, 0xb1, 0xbd, 0xdf, 0xd8, 0xdf, 0xdd, 0xdb, 0xde, 0xdf, 0xa1, 0x2f, 0x60,
		0x42, 0x42, 0xeb, 0x1f, 0xbe, 0x58, 0xee, 0x67, 0xac, 0x7b, 0xce, 0xcd, 0x7c, 0x32, 0xe1, 0xf5,
		0x87, 0x14, 0xbf, 0xde, 0x3f, 0xbf, 0x0e, 0x16, 0xfc, 0xcb, 0x30, 0x9f, 0x05, 0x7f, 0x41, 0x2b,
		0x81, 0x05, 0x7f, 0x39, 0xcb, 0x9a, 0x05, 0x7f, 0xe1, 0x17, 0xc4, 0x82, 0x3f, 0xa9, 0xe9, 0x07,
		0xa5, 0xa3, 0xab, 0xe0, 0xff, 0x4a, 0x41, 0xbd, 0x7f, 0x87, 0xf5, 0xfe, 0x92, 0x5f, 0xac, 0xf7,
		0x33, 0xaf, 0xc8, 0xf1, 0x72, 0x58, 0xef, 0x67, 0x34, 0x2f, 0xc2, 0x05, 0xb0, 0xde, 0x2f, 0xde,
		0x05, 0x6c, 0xef, 0xb0, 0xd0, 0xcf, 0x44, 0x84, 0xd6, 0x7f, 0xf5, 0x62, 0xa1, 0x9f, 0x16, 0xc3,
		0x87, 0x64, 0xd4, 0x53, 0xa4, 0x33, 0xfb, 0xb5, 0x9d, 0x4f, 0xba, 0x7a, 0xf6, 0xe0, 0xea, 0x5b,
		0x75, 0xc4, 0x09, 0xf4, 0x1b, 0x9a, 0x0e, 0x31, 0x6d, 0x05, 0x91, 0xbd, 0xb8, 0x23, 0xfd, 0x70,
		0x90, 0x3c, 0x7e, 0x03, 0xe9, 0xc4, 0x69, 0x3c, 0x3f, 0x0b, 0xe4, 0x63, 0x41, 0x3b, 0xbc, 0xa0,
		0x3b, 0xbb, 0x40, 0xb3, 0x30, 0x9e, 0x75, 0x51, 0xa6, 0xd0, 0x79, 0xd6, 0x45, 0x79, 0xcb, 0x95,
		0x67, 0x5d, 0x48, 0x4b, 0x0a, 0x78, 0xd6, 0x05, 0x99, 0xe6, 0xaf, 0x25, 0x02, 0xfb, 0x40, 0x76,
		0x79, 0x06, 0xaa, 0x09, 0xae, 0x62, 0x73, 0x85, 0xe8, 0xf1, 0x17, 0x13, 0x74, 0x00, 0x7b, 0xae,
		0xac, 0xee, 0x3c, 0x55, 0x7f, 0xf1, 0x62, 0x96, 0xc6, 0xd6, 0x67, 0x88, 0xc9, 0x54, 0xa9, 0xc2,
		0x96, 0xa2, 0x9c, 0xb4, 0xf8, 0xd6, 0xdc, 0xa3, 0x25, 0x45, 0x98, 0x83, 0xad, 0x71, 0x07, 0x59,
		0xab, 0x1a, 0x5c, 0x8d, 0x39, 0xa8, 0x1a, 0xc5, 0x9b, 0x80, 0x96, 0xde, 0x2b, 0x59, 0x72, 0x47,
		0x3a, 0x54, 0xbc, 0x2a, 0x45, 0x76, 0x0c, 0x66, 0x94, 0x4f, 0x60, 0xb2, 0x2d, 0x14, 0xee, 0xcd,
		0xd1, 0xbc, 0x78, 0x05, 0xbc, 0x37, 0x80, 0xaf, 0x56, 0xeb, 0xa3, 0x65, 0xfb, 0x64, 0xb9, 0x9e,
		0x4e, 0xb0, 0x97, 0xb3, 0xa6, 0xcb, 0x37, 0x48, 0xd3, 0x38, 0xbc, 0x18, 0xa7, 0x46, 0xfe, 0x39,
		0xb1, 0xcb, 0x0a, 0xdf, 0x23, 0xc3, 0x85, 0x47, 0x12, 0x8c, 0x23, 0xfa, 0x61, 0x1e, 0x53, 0x22,
		0x3d, 0x96, 0x04, 0x7c, 0x0c, 0x89, 0xf6, 0xd8, 0x11, 0xf6, 0x31, 0x23, 0xec, 0x63, 0x45, 0xcc,
		0xc7, 0x88, 0xcc, 0x86, 0x7e, 0xe6, 0x96, 0xa3, 0x1c, 0x81, 0x6f, 0xcd, 0xb6, 0x50, 0xc2, 0x38,
		0xaf, 0xec, 0x00, 0x10, 0xa0, 0x9d, 0x9f, 0x20, 0x40, 0x03, 0x07, 0x36, 0x88, 0x80, 0x03, 0x0c,
		0x3a, 0xa8, 0xc0, 0x03, 0x0f, 0x3e, 0xf0, 0x00, 0x84, 0x0d, 0x42, 0x18, 0x40, 0x04, 0x02, 0x46,
		0x70, 0x80, 0x94, 0x19, 0x3c, 0x1c, 0x5d, 0x06, 0xc3, 0xda, 0x6d, 0x3c, 0x4a, 0xcd, 0x25, 0x64,
		0x9b, 0xd0, 0xb2, 0x1c, 0xf4, 0xf8, 0x4a, 0xb8, 0xad, 0x9d, 0x58, 0xa5, 0x0b, 0xaf, 0x14, 0x60,
		0x16, 0x3a, 0x6e, 0xa9, 0xc1, 0x2e, 0x35, 0xf8, 0xa5, 0x03, 0xc3, 0xb0, 0x70, 0x0c, 0x0c, 0xcb,
		0x32, 0x89, 0xe0, 0x6f, 0x6b, 0x37, 0xd1, 0xf8, 0xc6, 0xc4, 0x01, 0x20, 0xe0, 0x3c, 0x84, 0x9c,
		0xad, 0x06, 0xa0, 0xed, 0x4e, 0x34, 0xbe, 0x99, 0x88, 0x87, 0x4b, 0x34, 0xcf, 0x4f, 0x19, 0x72,
		0x43, 0x73, 0x66, 0x3d, 0xec, 0xc6, 0xe6, 0xe5, 0x15, 0x28, 0xda, 0xe0, 0x9c, 0x5d, 0x14, 0xe4,
		0x46, 0x67, 0x3c, 0x24, 0x60, 0x2d, 0x69, 0xad, 0x3c, 0xcb, 0x0d, 0xe4, 0x32, 0xb6, 0x20, 0x7e,
		0xbd, 0xcf, 0x08, 0x6e, 0x3c, 0x8b, 0x9e, 0xdd, 0x88, 0x61, 0xf4, 0xd1, 0xce, 0xee, 0x03, 0xd2,
		0x10, 0x16, 0xee, 0x12, 0x57, 0xed, 0xb2, 0xb9, 0x4b, 0x5c, 0x96, 0x8b, 0xe6, 0x16, 0xf1, 0xb2,
		0x9c, 0x32, 0x37, 0x88, 0xab, 0x73, 0x70, 0xb3, 0x7d, 0xd6, 0x03, 0x33, 0x0c, 0xee, 0xc1, 0xf6,
		0x86, 0xcf, 0x6c, 0xe6, 0xb6, 0xf0, 0x75, 0x98, 0xc9, 0x6d, 0xe1, 0x39, 0xaa, 0x95, 0xdb, 0xc2,
		0xf3, 0x5b, 0x5e, 0xdc, 0x16, 0x5e, 0x34, 0x0b, 0x73, 0x5b, 0x78, 0xd5, 0xd2, 0x1f, 0x6e, 0x0b,
		0xcf, 0x37, 0x3e, 0x70, 0x5b, 0x38, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0,
		0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83,
		0x83, 0xda, 0x45, 0x98, 0xe2, 0xee, 0x05, 0x9f, 0x99, 0xcf, 0x0d, 0xe0, 0x04, 0x28, 0x5d, 0x20,
		0xa5, 0x00, 0xa8, 0xd0, 0xc1, 0x4a, 0x0d, 0x60, 0xa9, 0x01, 0x2d, 0x1d, 0xc0, 0x85, 0x05, 0x5e,
		0x60, 0x00, 0x96, 0x49, 0x04, 0x7f, 0x03, 0xf8, 0xc5, 0x68, 0x34, 0x34, 0x01, 0xf4, 0xe6, 0xef,
		0x2d, 0x6e, 0xbf, 0xac, 0xfa, 0x62, 0xb4, 0x30, 0x9e, 0x27, 0x3f, 0xbb, 0x0a, 0x11, 0x1e, 0x2d,
		0x33, 0xc1, 0x60, 0x82, 0xc1, 0x04, 0x83, 0x09, 0x06, 0x13, 0x0c, 0x26, 0x18, 0x4c, 0x30, 0x98,
		0x60, 0xfc, 0x4d, 0x8f, 0x3f, 0x0e, 0xa3, 0xf4, 0xe5, 0x36, 0x70, 0x7e, 0x81, 0x78, 0x6c, 0x52,
		0x2f, 0x88, 0xae, 0x27, 0x9f, 0xfe, 0xef, 0x90, 0x8e, 0xf1, 0x4f, 0xd8, 0x53, 0xde, 0xad, 0x93,
		0x30, 0x82, 0x25, 0x04, 0x70, 0xb0, 0x5f, 0xb9, 0x8c, 0xb3, 0xf9, 0x61, 0xba, 0xe8, 0xd7, 0x71,
		0x1c, 0x07, 0xd3, 0x09, 0x44, 0xcd, 0xf0, 0x3a, 0x9c, 0xf5, 0x01, 0xc3, 0x5e, 0xcf, 0x97, 0x5f,
		0x81, 0x97, 0x76, 0xf0, 0x99, 0x4b, 0x5b, 0xd8, 0xd2, 0x6e, 0x6c, 0xef, 0x37, 0xf6, 0x77, 0xf7,
		0xb6, 0xf7, 0x77, 0xb8, 0xc6, 0x99, 0x10, 0x54, 0xcb, 0xea, 0x73, 0x96, 0xbd, 0x2b, 0x6c, 0x29,
		0xa7, 0x0e, 0xe4, 0x6b, 0xb7, 0xca, 0x96, 0xd6, 0xe9, 0x63, 0x06, 0x0e, 0x1c, 0x28, 0xb3, 0xb7,
		0xb5, 0x39, 0xb9, 0x05, 0x9c, 0x35, 0x50, 0x1d, 0x0b, 0x39, 0x6b, 0x80, 0x8e, 0xf9, 0xef, 0x39,
		0x66, 0x8e, 0x19, 0x28, 0xc1, 0x15, 0x73, 0xc2, 0x80, 0x3a, 0xb7, 0xf6, 0xa0, 0x5b, 0xbf, 0x76,
		0x17, 0xc4, 0x21, 0x86, 0x73, 0x7b, 0x62, 0xd6, 0xc0, 0x03, 0xeb, 0x39, 0x75, 0x60, 0x1d, 0x66,
		0x72, 0xea, 0x40, 0x8e, 0xba, 0xe5, 0xd4, 0x81, 0xfc, 0x96, 0x17, 0xa7, 0x0e, 0x14, 0x4d, 0xc5,
		0x9c, 0x3a, 0x50, 0xb5, 0x44, 0x88, 0x53, 0x07, 0xf2, 0x8d, 0x0f, 0x9c, 0x3a, 0x40, 0xb0, 0x41,
		0x04, 0x1c, 0x60, 0xd0, 0x41, 0x05, 0x1e, 0x78, 0xf0, 0x81, 0x07, 0x20, 0x6c, 0x10, 0xc2, 0x00,
		0x22, 0x10, 0x30, 0x82, 0x03, 0xa4, 0xcc, 0x60, 0x36, 0x05, 0x95, 0x06, 0x4e, 0x6c, 0x0a, 0x22,
		0x48, 0x29, 0x06, 0x2a, 0x74, 0xb0, 0x52, 0x03, 0x58, 0x6a, 0x40, 0x4b, 0x07, 0x70, 0x61, 0x81,
		0x17, 0x18, 0x80, 0x65, 0x12, 0x61, 0x53, 0x50, 0xe9, 0x7c, 0xc3, 0xa6, 0xa0, 0xa2, 0x5f, 0x6c,
		0x0a, 0x22, 0xd8, 0xaf, 0xe1, 0x32, 0xd8, 0x14, 0xc4, 0xf0, 0xbb, 0xce, 0xa5, 0xcd, 0xa6, 0x20,
		0x71, 0x4b, 0x9b, 0x4d, 0x41, 0x4c, 0x08, 0xaa, 0x6a, 0x35, 0x9b, 0x82, 0xaa, 0x6c, 0x29, 0x9b,
		0x82, 0xf2, 0xb5, 0x5b, 0xef, 0xde, 0xf3, 0xe5, 0x56, 0x53, 0xb6, 0x07, 0x95, 0xbe, 0x27, 0xfd,
		0x6c, 0x71, 0x2f, 0xd8, 0x27, 0x54, 0x1d, 0x0b, 0xd9, 0x27, 0x44, 0x5f, 0xfd, 0xbd, 0xbe, 0x9a,
		0x1d, 0x43, 0x65, 0x7a, 0x67, 0xb6, 0x0e, 0xa9, 0xf3, 0x74, 0xb3, 0xe6, 0x9b, 0x70, 0x00, 0xd6,
		0x2d, 0x14, 0x0e, 0xd8, 0x20, 0xb4, 0x16, 0x33, 0xd9, 0x20, 0x94, 0xa3, 0x54, 0xd9, 0x20, 0x94,
		0xdf, 0xf2, 0x62, 0x83, 0x50, 0xd1, 0x38, 0xcc, 0x06, 0xa1, 0xaa, 0x65, 0x40, 0x6c, 0x10, 0xca,
		0x37, 0x3e, 0xb0, 0x41, 0x88, 0x60, 0x83, 0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0,
		0x03, 0x0f, 0x40, 0xd8, 0x20, 0x84, 0x01, 0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x99, 0xc1, 0xc3,
		0xd1, 0x65, 0x30, 0xc4, 0x6d, 0x10, 0x9a, 0x99, 0xcf, 0x06, 0x21, 0x02, 0x94, 0x2e, 0x90, 0x52,
		0x00, 0x54, 0xe8, 0x60, 0xa5, 0x06, 0xb0, 0xd4, 0x80, 0x96, 0x0e, 0xe0, 0xc2, 0x02, 0x2f, 0x30,
		0x00, 0xcb, 0x24, 0xc2, 0x06, 0xa1, 0xd2, 0xf9, 0x86, 0x0d, 0x42, 0x45, 0xbf, 0xd8, 0x20, 0x44,
		0xb0, 0x5f, 0xc3, 0x65, 0xb0, 0x41, 0x88, 0xe1, 0x77, 0x9d, 0x4b, 0x9b, 0x0d, 0x42, 0xe2, 0x96,
		0x36, 0x1b, 0x84, 0x98, 0x10, 0x54, 0xd5, 0x6a, 0x36, 0x08, 0x55, 0x3e, 0x46, 0x59, 0xb1, 0xb9,
		0x19, 0xa5, 0x06, 0xb7, 0xee, 0x3d, 0xb7, 0x9f, 0x85, 0xef, 0x22, 0xcc, 0x66, 0xe1, 0xbb, 0x44,
		0xa5, 0xb3, 0xf0, 0x5d, 0xde, 0x72, 0x65, 0xe1, 0x5b, 0xd8, 0x85, 0xb0, 0xf0, 0x4d, 0xaa, 0xf9,
		0x86, 0x44, 0x58, 0xf8, 0x2e, 0x9d, 0x6f, 0x58, 0xf8, 0x2e, 0xfa, 0xc5, 0xc2, 0x37, 0xc1, 0x7e,
		0x0d, 0x97, 0xc1, 0xc2, 0x37, 0xc3, 0xef, 0x3a, 0x97, 0x36, 0x0b, 0xdf, 0xe2, 0x96, 0x36, 0x0b,
		0xdf, 0x4c, 0x08, 0xaa, 0x6a, 0x35, 0x0b, 0xdf, 0x55, 0xb6, 0x94, 0x93, 0xb1, 0xf2, 0xb5, 0x5b,
		0xe5, 0xb4, 0x95, 0x70, 0xc0, 0x61, 0x58, 0x65, 0x8e, 0x5b, 0x71, 0x07, 0x1c, 0x80, 0x55, 0x1d,
		0x0b, 0x39, 0x00, 0x8b, 0x2e, 0xf9, 0x6f, 0xb8, 0x64, 0xce, 0xbc, 0x2a, 0xda, 0x09, 0x73, 0xce,
		0x95, 0x3a, 0x87, 0x36, 0x1b, 0x1b, 0x35, 0x1c, 0x25, 0x09, 0xd8, 0xa4, 0xab, 0xa9, 0xc9, 0x9c,
		0x75, 0xb5, 0x0e, 0x33, 0x39, 0xeb, 0x2a, 0x47, 0xb1, 0x72, 0xd6, 0x55, 0x7e, 0xcb, 0x8b, 0xb3,
		0xae, 0x8a, 0x26, 0x5f, 0xce, 0xba, 0xaa, 0x5a, 0xb2, 0xc3, 0x59, 0x57, 0xf9, 0xc6, 0x07, 0xce,
		0xba, 0x22, 0xd8, 0x20, 0x02, 0x0e, 0x30, 0xe8, 0xa0, 0x02, 0x0f, 0x3c, 0xf8, 0xc0, 0x03, 0x10,
		0x36, 0x08, 0x61, 0x00, 0x11, 0x08, 0x18, 0xc1, 0x01, 0x52, 0x66, 0x70, 0x50, 0xbb, 0x08, 0x53,
		0xdc, 0x9e, 0x9f, 0x99, 0xf9, 0x6c, 0xf9, 0x21, 0x40, 0xe9, 0x02, 0x29, 0x05, 0x40, 0x85, 0x0e,
		0x56, 0x6a, 0x00, 0x4b, 0x0d, 0x68, 0xe9, 0x00, 0x2e, 0x2c, 0xf0, 0x02, 0x03, 0xb0, 0x4c, 0x22,
		0xf8, 0x2d, 0x3f, 0x17, 0xa3, 0xd1, 0xd0, 0x04, 0x11, 0x70, 0xcf, 0xcf, 0xd6, 0x16, 0x37, 0x57,
		0x56, 0x7d, 0x31, 0x02, 0x3d, 0x52, 0x7e, 0x76, 0x25, 0xa2, 0x3c, 0x62, 0x66, 0xa2, 0xc1, 0x44,
		0x83, 0x89, 0x06, 0x13, 0x0d, 0x26, 0x1a, 0x4c, 0x34, 0x98, 0x68, 0x30, 0xd1, 0xf8, 0x9b, 0x1e,
		0x9f, 0xb3, 0x05, 0x4a, 0x30, 0x9d, 0xb3, 0x05, 0x4a, 0xfa, 0xe0, 0x39, 0x5b, 0x40, 0xce, 0x65,
		0x70, 0xb6, 0x00, 0xc3, 0xef, 0x3a, 0x97, 0x36, 0x67, 0x0b, 0x88, 0x5b, 0xda, 0x9c, 0x2d, 0xc0,
		0x84, 0xa0, 0xaa, 0x56, 0x73, 0xb6, 0x40, 0x95, 0x2d, 0xe5, 0x6c, 0x81, 0x7c, 0xed, 0x56, 0xd9,
		0xc8, 0x3a, 0x1c, 0x25, 0x09, 0xa7, 0x0b, 0x94, 0xd9, 0xd8, 0xda, 0x1a, 0x25, 0x09, 0xe7, 0x0b,
		0x54, 0xc7, 0x42, 0xce, 0x17, 0xa0, 0x5b, 0xfe, 0x5b, 0x6e, 0x99, 0x13, 0x06, 0x8a, 0x77, 0xc4,
		0x9c, 0x31, 0xa0, 0xce, 0xa9, 0xcd, 0x76, 0x53, 0x4c, 0x56, 0xb3, 0x99, 0xe6, 0xd3, 0xb5, 0x14,
		0xe1, 0x01, 0xca, 0xd7, 0x7b, 0x41, 0x1e, 0x5b, 0xcf, 0xc9, 0x03, 0xeb, 0x30, 0x93, 0x93, 0x07,
		0x72, 0xd4, 0x2d, 0x27, 0x0f, 0xe4, 0xb7, 0xbc, 0x38, 0x79, 0xa0, 0x68, 0x26, 0xe6, 0xe4, 0x81,
		0xaa, 0xa5, 0x41, 0x9c, 0x3c, 0x90, 0x6f, 0x7c, 0xe0, 0xe4, 0x01, 0x82, 0x0d, 0x22, 0xe0, 0x00,
		0x83, 0x0e, 0x2a, 0xf0, 0xc0, 0x83, 0x0f, 0x3c, 0x00, 0x61, 0x83, 0x10, 0x06, 0x10, 0x81, 0x80,
		0x11, 0x1c, 0x20, 0x65, 0x06, 0xa7, 0x88, 0x1b, 0x67, 0xb3, 0x30, 0x03, 0x50, 0xf7, 0x79, 0x0e,
		0x9b, 0xd8, 0x0e, 0x44, 0x8c, 0x52, 0x8c, 0x53, 0xe8, 0x58, 0xa5, 0x06, 0xaf, 0xd4, 0x60, 0x96,
		0x0e, 0xdc, 0xc2, 0xc2, 0x2e, 0x30, 0xfc, 0xca, 0x24, 0x82, 0xdf, 0x0e, 0x64, 0xa2, 0xf1, 0x8d,
		0x89, 0x67, 0x3b, 0x0e, 0x80, 0x67, 0x0f, 0x34, 0x00, 0x6d, 0x77, 0xa2, 0xf1, 0xcd, 0x44, 0x3c,
		0x5c, 0xa2, 0x79, 0x7e, 0xca, 0xad, 0x30, 0x49, 0xed, 0x34, 0x8d, 0x31, 0x97, 0xe9, 0x49, 0x18,
		0x39, 0x43, 0x33, 0x89, 0x42, 0x09, 0x66, 0x9b, 0x80, 0x75, 0x12, 0x7c, 0x7e, 0x70, 0x05, 0x5b,
		0xaf, 0x1a, 0x8d, 0xdd, 0xbd, 0x46, 0x63, 0x73, 0xef, 0xe5, 0xde, 0xe6, 0xfe, 0xce, 0xce, 0xd6,
		0xee, 0x16, 0x60, 0xab, 0x80, 0xd5, 0x89, 0x07, 0x26, 0x36, 0x83, 0xc3, 0x7b, 0xeb, 0x60, 0x23,
		0x1a, 0x0f, 0x87, 0xdc, 0xfa, 0x5d, 0x61, 0x4b, 0xb9, 0xf5, 0x3b, 0x5f, 0xbb, 0x55, 0xee, 0x31,
		0x7c, 0xb4, 0xa9, 0x88, 0xbb, 0xc0, 0xcb, 0xdc, 0x7c, 0xd8, 0xcd, 0x6e, 0xc6, 0x04, 0xe8, 0xb9,
		0x1f, 0xbc, 0x3a, 0x16, 0x72, 0x3f, 0x38, 0x7d, 0xf5, 0xf7, 0xfa, 0x6a, 0x6e, 0x0d, 0x2f, 0xd3,
		0x3b, 0x73, 0x93, 0xb8, 0x3a, 0x4f, 0x67, 0xdd, 0x04, 0x9f, 0x6b, 0xd3, 0x95, 0x76, 0x11, 0x44,
		0x83, 0x4f, 0xe1, 0x60, 0xea, 0x3d, 0x40, 0xb6, 0x88, 0x3f, 0x61, 0x3b, 0x37, 0x88, 0xaf, 0xc3,
		0x4c, 0x6e, 0x10, 0xcf, 0x51, 0xb5, 0xdc, 0x20, 0x9e, 0xdf, 0xf2, 0xe2, 0x06, 0xf1, 0xa2, 0x21,
		0x99, 0x1b, 0xc4, 0xab, 0x96, 0x17, 0x71, 0x83, 0x78, 0xbe, 0xf1, 0x81, 0x1b, 0xc4, 0x09, 0x36,
		0x88, 0x80, 0x03, 0x0c, 0x3a, 0xa8, 0xc0, 0x03, 0x0f, 0x3e, 0xf0, 0x00, 0x84, 0x0d, 0x42, 0x18,
		0x40, 0x04, 0x02, 0x46, 0x70, 0x80, 0x94, 0x19, 0x8c, 0x53, 0xfa, 0x79, 0x36, 0xd6, 0xa0, 0x54,
		0x80, 0x9e, 0x03, 0x28, 0x6e, 0x15, 0x27, 0x50, 0x29, 0x06, 0x2b, 0x74, 0xc0, 0x52, 0x03, 0x5a,
		0x6a, 0x80, 0x4b, 0x07, 0x78, 0x61, 0x01, 0x18, 0x18, 0x88, 0x65, 0x12, 0xc1, 0xdf, 0x2a, 0x1e,
		0x1a, 0x63, 0xae, 0x86, 0xa3, 0x00, 0xfb, 0xf8, 0x88, 0x7d, 0x40, 0xd3, 0x5b, 0x26, 0xba, 0x9e,
		0x82, 0x31, 0xcf, 0x8f, 0x28, 0xf8, 0x93, 0xe7, 0xf9, 0x11, 0x72, 0x2e, 0x23, 0x1b, 0x32, 0xcf,
		0xd9, 0xf2, 0x0c, 0xc2, 0x6b, 0x58, 0xda, 0x3c, 0x3f, 0x82, 0x4b, 0x9b, 0x4b, 0x5b, 0x47, 0x36,
		0x80, 0x6b, 0x35, 0x8f, 0x8d, 0xa8, 0xb2, 0xa5, 0xec, 0x1d, 0xca, 0xd7, 0x6e, 0x6d, 0xfb, 0xd1,
		0x57, 0x77, 0x9b, 0xb2, 0x73, 0xa8, 0xac, 0xbd, 0xe9, 0x27, 0xc1, 0xe7, 0xc9, 0x3f, 0x7e, 0xb8,
		0xb8, 0x13, 0xec, 0x1b, 0xaa, 0x8e, 0x85, 0xec, 0x1b, 0xa2, 0x9f, 0xfe, 0x3e, 0x3f, 0xcd, 0xae,
		0xa1, 0xf2, 0x3c, 0x33, 0x7b, 0x86, 0xd4, 0x79, 0xb9, 0x69, 0xdf, 0x4d, 0x6c, 0x12, 0x13, 0xdf,
		0x05, 0x17, 0x43, 0x03, 0xdd, 0x3e, 0xf4, 0xfc, 0x65, 0xb0, 0x93, 0x68, 0x1d, 0x66, 0xb2, 0x93,
		0x28, 0x47, 0x01, 0xb3, 0x93, 0x28, 0xbf, 0xe5, 0xc5, 0x4e, 0xa2, 0xa2, 0xb1, 0x99, 0x9d, 0x44,
		0x55, 0xcb, 0x94, 0xd8, 0x49, 0x94, 0x6f, 0x7c, 0x60, 0x27, 0x11, 0xc1, 0x06, 0x11, 0x70, 0x80,
		0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0,
		0x08, 0x0e, 0x90, 0x32, 0x83, 0xd9, 0x49, 0x54, 0x3a, 0x40, 0xb1, 0x93, 0x88, 0x40, 0xa5, 0x18,
		0xac, 0xd0, 0x01, 0x4b, 0x0d, 0x68, 0xa9, 0x01, 0x2e, 0x1d, 0xe0, 0x85, 0x05, 0x60, 0x60, 0x20,
		0x96, 0x49, 0x84, 0x9d, 0x44, 0x32, 0x20, 0x87, 0x9d, 0x44, 0x85, 0xbf, 0xd8, 0x49, 0x44, 0xbc,
		0x5f, 0xc3, 0x65, 0xb0, 0xdd, 0x80, 0x41, 0x78, 0x9d, 0x4b, 0x9b, 0x9d, 0x44, 0x5c, 0xda, 0x5c,
		0xda, 0x3a, 0xb2, 0x01, 0x5c, 0xab, 0xd9, 0x49, 0x54, 0x65, 0x4b, 0xd9, 0x49, 0x94, 0xaf, 0xdd,
		0x1a, 0x77, 0xa8, 0x3f, 0xbb, 0xf1, 0x94, 0x4d, 0x45, 0x25, 0x6e, 0x5d, 0xef, 0x65, 0x77, 0x85,
		0xed, 0x45, 0x15, 0xb5, 0x90, 0xed, 0x45, 0x74, 0xde, 0x3f, 0xec, 0xbc, 0xd9, 0x69, 0x24, 0xc1,
		0x5d, 0xb3, 0xe7, 0x48, 0x9d, 0xeb, 0xb3, 0x6e, 0xc2, 0xa8, 0x96, 0x75, 0xf6, 0x0d, 0xcc, 0x30,
		0xb8, 0x07, 0x6a, 0x34, 0x5a, 0xb5, 0x9d, 0xdd, 0x45, 0xeb, 0x30, 0x93, 0xdd, 0x45, 0x39, 0xaa,
		0x96, 0xdd, 0x45, 0xf9, 0x2d, 0x2f, 0x76, 0x17, 0x15, 0x4d, 0xcd, 0xec, 0x2e, 0xaa, 0x5a, 0xa2,
		0xc4, 0xee, 0xa2, 0x7c, 0xe3, 0x03, 0xbb, 0x8b, 0x08, 0x36, 0x88, 0x80, 0x03, 0x0c, 0x3a, 0xa8,
		0xc0, 0x03, 0x0f, 0x3e, 0xf0, 0x00, 0x84, 0x0d, 0x42, 0x18, 0x40, 0x04, 0x02, 0x46, 0x70, 0x80,
		0x94, 0x19, 0x1c, 0xd4, 0x2e, 0xc2, 0x14, 0xb7, 0xb3, 0x68, 0x66, 0x3e, 0xbb, 0x8a, 0x08, 0x50,
		0xba, 0x40, 0x4a, 0x01, 0x50, 0xa1, 0x83, 0x95, 0x1a, 0xc0, 0x52, 0x03, 0x5a, 0x3a, 0x80, 0x0b,
		0x0b, 0xbc, 0xc0, 0x00, 0x2c, 0x93, 0x08, 0x7e, 0x57, 0xd1, 0xc5, 0x68, 0x34, 0x34, 0x41, 0x04,
		0xdc, 0x51, 0xb4, 0xb5, 0xc5, 0x2d, 0x9c, 0x55, 0x5f, 0x8c, 0xd3, 0x89, 0x90, 0x18, 0xcf, 0x96,
		0x9f, 0x5d, 0x89, 0xcb, 0x4b, 0x60, 0xa2, 0xc1, 0x44, 0x83, 0x89, 0x06, 0x13, 0x0d, 0x26, 0x1a,
		0x4c, 0x34, 0xc8, 0x35, 0x4c, 0x34, 0x54, 0x24, 0x1a, 0xe3, 0x30, 0xc2, 0x9e, 0x5c, 0xb0, 0x07,
		0x68, 0x7a, 0x2f, 0x88, 0xae, 0x0d, 0x07, 0x17, 0x14, 0xff, 0xc1, 0x73, 0x70, 0x81, 0x9c, 0xcb,
		0x58, 0x74, 0x37, 0x6f, 0xb2, 0xbb, 0x99, 0xe1, 0x77, 0x0d, 0x4b, 0x9b, 0x83, 0x0b, 0xc4, 0x2d,
		0xed, 0xc6, 0xf6, 0x7e, 0x63, 0x7f, 0x77, 0x6f, 0x7b, 0x7f, 0x87, 0x6b, 0x9c, 0x09, 0x41, 0xb5,
		0xac, 0xe6, 0x04, 0x83, 0xca, 0xc7, 0xa8, 0x69, 0x9f, 0x12, 0x7a, 0xf9, 0x3b, 0xbb, 0x04, 0x96,
		0xbf, 0x8b, 0x30, 0x9b, 0xe5, 0xef, 0x12, 0xc5, 0xce, 0xf2, 0x77, 0x79, 0xcb, 0x95, 0xe5, 0x6f,
		0x61, 0x17, 0xc2, 0xf2, 0x37, 0xd9, 0xe6, 0x1b, 0x12, 0x61, 0xf9, 0xbb, 0x74, 0xbe, 0x61, 0xf9,
		0xbb, 0xe8, 0x17, 0xcb, 0xdf, 0x04, 0xfb, 0x35, 0x5c, 0x06, 0xcb, 0xdf, 0x0c, 0xbf, 0xeb, 0x5c,
		0xda, 0x2c, 0x7f, 0x8b, 0x5b, 0xda, 0x2c, 0x7f, 0x33, 0x21, 0xa8, 0xaa, 0xd5, 0x2c, 0x7f, 0x57,
		0xd9, 0x52, 0x0e, 0xf0, 0xcd, 0xd7, 0x6e, 0x75, 0x33, 0x20, 0x57, 0x06, 0xba, 0x71, 0x6a, 0x6f,
		0x69, 0x63, 0x20, 0xc3, 0xe8, 0x24, 0xf8, 0x3c, 0xf9, 0xf7, 0x9b, 0x93, 0x1b, 0xc1, 0x51, 0xbd,
		0xd5, 0xb1, 0x90, 0xa3, 0x7a, 0xe9, 0xa6, 0xbf, 0xcf, 0x4d, 0x73, 0x3e, 0x6f, 0x69, 0x8e, 0x99,
		0x43, 0x79, 0xd5, 0x39, 0x39, 0x2b, 0x36, 0x49, 0x38, 0x18, 0x07, 0xc3, 0x1a, 0xce, 0xb9, 0xcf,
		0xd9, 0xa3, 0x94, 0x27, 0x6c, 0xe7, 0x50, 0xde, 0x75, 0x98, 0xc9, 0xa1, 0xbc, 0x39, 0xaa, 0x96,
		0x43, 0x79, 0xf3, 0x5b, 0x5e, 0x1c, 0xca, 0x5b, 0x34, 0x1f, 0x73, 0x28, 0x6f, 0xd5, 0x52, 0x22,
		0x0e, 0xe5, 0xcd, 0x37, 0x3e, 0x70, 0x28, 0x2f, 0xc1, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15,
		0x78, 0xe0, 0xc1, 0x07, 0x1e, 0x80, 0xb0, 0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90,
		0x32, 0x83, 0x71, 0x4a, 0x3f, 0xcf, 0xc6, 0x1a, 0xa4, 0xe3, 0xdb, 0x9e, 0x02, 0x28, 0x36, 0x0d,
		0x11, 0xa8, 0x14, 0x83, 0x15, 0x3a, 0x60, 0xa9, 0x01, 0x2d, 0x35, 0xc0, 0xa5, 0x03, 0xbc, 0xb0,
		0x00, 0x0c, 0x0c, 0xc4, 0x32, 0x89, 0xe0, 0x37, 0x0d, 0x85, 0xc6, 0x98, 0xab, 0xe1, 0x28, 0xc0,
		0xee, 0x1c, 0xda, 0x07, 0x34, 0xbd, 0x65, 0xa2, 0xeb, 0x29, 0x18, 0xb3, 0x75, 0xa8, 0xe0, 0x4f,
		0x9e, 0xad, 0x43, 0x72, 0x2e, 0x23, 0xeb, 0x2f, 0x60, 0x5b, 0x01, 0x83, 0xf0, 0x1a, 0x96, 0x36,
		0x5b, 0x87, 0xb8, 0xb4, 0xb9, 0xb4, 0x75, 0x64, 0x03, 0xb8, 0x56, 0xb3, 0x63, 0xa8, 0xca, 0x96,
		0xb2, 0x63, 0x28, 0x5f, 0xbb, 0xb5, 0x6d, 0x45, 0x5f, 0xdd, 0x6d, 0xca, 0x8e, 0xa1, 0xb2, 0x36,
		0xa6, 0xf7, 0xe6, 0xf7, 0xe2, 0x70, 0x71, 0x2b, 0xd8, 0x33, 0x54, 0x1d, 0x0b, 0xd9, 0x33, 0x44,
		0x47, 0xfd, 0x7d, 0x8e, 0x9a, 0x3d, 0x43, 0x25, 0xba, 0x66, 0x76, 0x0d, 0xa9, 0x73, 0x73, 0x20,
		0x5b, 0x6b, 0xa1, 0xb6, 0xd4, 0xb2, 0x37, 0x68, 0xcd, 0x86, 0xb2, 0x37, 0x28, 0x57, 0x93, 0xd9,
		0x1b, 0x54, 0x90, 0xe1, 0xec, 0x0d, 0x22, 0x0f, 0xa0, 0xa4, 0x3e, 0x30, 0xbd, 0x41, 0x29, 0xd2,
		0x96, 0x90, 0x2c, 0x3c, 0x4c, 0xad, 0xc6, 0xea, 0x0c, 0xda, 0x64, 0x67, 0x50, 0xe5, 0xf1, 0x06,
		0x18, 0x73, 0x50, 0x71, 0x07, 0x1e, 0x7b, 0xe0, 0xf1, 0x07, 0x1b, 0x83, 0x30, 0x70, 0x08, 0x04,
		0x8b, 0x32, 0x29, 0xc0, 0x6d, 0x44, 0x5d, 0x6e, 0x40, 0x1d, 0x98, 0x28, 0x0d, 0xd3, 0xfb, 0xd8,
		0x5c, 0x21, 0x79, 0xed, 0x45, 0x4d, 0x05, 0x68, 0x1c, 0xae, 0xe5, 0xce, 0x3f, 0xea, 0xc3, 0x20,
		0x31, 0xb8, 0x0d, 0x59, 0x6e, 0xdf, 0xed, 0xfb, 0xfd, 0xd3, 0x43, 0xaf, 0x75, 0xe6, 0x7b, 0xef,
		0xbb, 0x0e, 0x5a, 0xd8, 0x99, 0x6e, 0x8b, 0x4a, 0x20, 0xf7, 0xfd, 0x82, 0xb6, 0xd6, 0x2c, 0x95,
		0xe3, 0xf7, 0x1c, 0xfb, 0xe8, 0x8d, 0x7d, 0xe8, 0xb6, 0x5c, 0xef, 0xfd, 0x5c, 0x44, 0x7d, 0x44,
		0x15, 0x69, 0x50, 0x13, 0xb6, 0xaa, 0xbe, 0xa9, 0xae, 0x43, 0xbb, 0xdd, 0xfc, 0xb7, 0xdb, 0xf4,
		0xde, 0xf8, 0x47, 0x9d, 0x76, 0xdf, 0xeb, 0xd9, 0x6e, 0xdb, 0xeb, 0x5b, 0xdc, 0x15, 0x4c, 0x81,
		0xad, 0x49, 0x60, 0xa7, 0x9e, 0xdb, 0x72, 0xff, 0xe3, 0x34, 0x97, 0x4a, 0xa3, 0xba, 0xa8, 0xae,
		0x75, 0xa9, 0xcb, 0x6e, 0xfe, 0xe6, 0xf7, 0xdd, 0x26, 0x25, 0x45, 0x49, 0xad, 0x4d, 0x52, 0x67,
		0xb6, 0xdb, 0xb2, 0x0f, 0x5b, 0x0e, 0x3d, 0x16, 0xe5, 0xb5, 0x7e, 0x79, 0xb9, 0xdd, 0xb3, 0x5d,
		0xbf, 0xed, 0xb8, 0xaf, 0xdf, 0x1c, 0x76, 0x7a, 0xbe, 0xdd, 0x6c, 0xf6, 0x9c, 0x3e, 0x81, 0x8b,
		0x02, 0x5b, 0x1f, 0x70, 0xb5, 0x33, 0x92, 0x77, 0x9a, 0x7e, 0xab, 0xdf, 0xa5, 0xb8, 0x28, 0xae,
		0x75, 0x89, 0xab, 0xe5, 0xb6, 0xdf, 0xfa, 0xb6, 0xe7, 0xf5, 0xdc, 0xc3, 0x53, 0xcf, 0xa1, 0xdf,
		0xa2, 0xb4, 0xd6, 0x2b, 0xad, 0x6e, 0xaf, 0xe3, 0x39, 0x47, 0x9e, 0xdb, 0x69, 0xcf, 0xea, 0x5d,
		0xd4, 0x17, 0xf5, 0xb5, 0xb6, 0x54, 0xf1, 0xc4, 0x6d, 0xfb, 0xaf, 0x7b, 0x9d, 0x53, 0x46, 0x44,
		0xca, 0x6a, 0xbd, 0x3c, 0xef, 0xb6, 0x3d, 0xa7, 0x77, 0x6c, 0x1f, 0x39, 0x04, 0x7a, 0x2a, 0x6c,
		0xdd, 0x0a, 0x3b, 0xb1, 0xdf, 0xcd, 0x82, 0x23, 0xeb, 0x11, 0x54, 0x57, 0x0e, 0x61, 0xf1, 0x37,
		0xbf, 0x65, 0xb7, 0x59, 0x45, 0xa5, 0xac, 0xd6, 0x4e, 0xf3, 0x94, 0x14, 0x25, 0xb5, 0x56, 0xd2,
		0x6a, 0xb0, 0x72, 0x4a, 0x81, 0xe5, 0x2b, 0x30, 0xa2, 0x3c, 0x15, 0x96, 0x2b, 0xca, 0xf7, 0x9c,
		0xbe, 0xd3, 0x3b, 0xe3, 0x03, 0x46, 0x6a, 0x2c, 0x1f, 0x8d, 0x79, 0x8e, 0xdf, 0x74, 0x8e, 0xed,
		0xd3, 0x96, 0xe7, 0x9f, 0x38, 0x5e, 0xcf, 0x3d, 0xa2, 0xb8, 0x28, 0xae, 0x75, 0x89, 0xeb, 0xb4,
		0x3d, 0x73, 0x5f, 0xdc, 0xcf, 0x45, 0x7d, 0xe5, 0x96, 0x36, 0x36, 0x9d, 0x96, 0xfd, 0xde, 0x3f,
		0xb3, 0x7b, 0xae, 0xed, 0xb9, 0x9d, 0x36, 0xf5, 0x45, 0x7d, 0xad, 0x4b, 0x5f, 0xce, 0x3b, 0xcf,
		0x69, 0x37, 0x9d, 0x26, 0x9f, 0x06, 0x51, 0x5f, 0xb9, 0x00, 0xbe, 0xdb, 0x5e, 0xd6, 0xeb, 0xa7,
		0x7e, 0x8c, 0xea, 0xa2, 0xba, 0xd6, 0x1a, 0x1d, 0x5b, 0x1d, 0xd6, 0x24, 0x28, 0xaa, 0x3c, 0x90,
		0x8b, 0xaa, 0xa2, 0xaa, 0xd6, 0xa5, 0xaa, 0x9e, 0xd3, 0x77, 0x9b, 0xa7, 0x76, 0x4b, 0x45, 0x9a,
		0x08, 0x69, 0xf9, 0xf9, 0x2f, 0x5c, 0xc5, 0x5c, 0xbd, 0xdf, 0xb7, 0x6a, 0x95, 0x74, 0x83, 0x52,
		0x48, 0x65, 0x0b, 0x49, 0x43, 0xd7, 0x27, 0x55, 0x54, 0xb6, 0x8a, 0x60, 0xbb, 0x3b, 0x29, 0x9d,
		0xd2, 0xa5, 0xa3, 0xa1, 0x8b, 0x93, 0x32, 0x2a, 0x5b, 0x46, 0x4a, 0xba, 0x35, 0x29, 0xa4, 0xd2,
		0x81, 0x08, 0xbf, 0x2b, 0x93, 0x22, 0x2a, 0x5b, 0x44, 0xf0, 0xdd, 0x97, 0x94, 0x90, 0x08, 0x09,
		0xc1, 0x77, 0x59, 0x52, 0x47, 0xe5, 0xa7, 0x66, 0xc0, 0xcf, 0xcf, 0x29, 0x1f, 0x11, 0x5c, 0xad,
		0x60, 0xab, 0x35, 0x95, 0x54, 0xb6, 0x92, 0x34, 0x74, 0x47, 0x52, 0x45, 0xe5, 0x87, 0x33, 0xe0,
		0x2e, 0x48, 0xca, 0x47, 0x04, 0x55, 0x53, 0x3a, 0x94, 0xce, 0x0f, 0x91, 0x50, 0x83, 0x15, 0x46,
		0x0a, 0x69, 0x3d, 0x42, 0x22, 0x52, 0x53, 0x49, 0x6b, 0x41, 0x6a, 0x1d, 0x5d, 0x8a, 0xd4, 0x52,
		0xd9, 0x5a, 0x52, 0xd0, 0x8d, 0x48, 0x11, 0x95, 0x2d, 0x22, 0x1d, 0x5d, 0x87, 0xd4, 0x91, 0x88,
		0x34, 0x0d, 0xbe, 0xbb, 0x90, 0x3a, 0x2a, 0x5b, 0x47, 0x3a, 0xba, 0x08, 0xa9, 0xa3, 0xd2, 0x41,
		0x5b, 0x41, 0xb7, 0x20, 0x55, 0x24, 0x22, 0xaa, 0x61, 0x76, 0x05, 0x52, 0x3c, 0x72, 0x90, 0x88,
		0xea, 0xa1, 0x7a, 0xbe, 0x57, 0x3d, 0x1a, 0xba, 0xfc, 0xa8, 0xa2, 0xc2, 0x55, 0xd4, 0xe5, 0x09,
		0x97, 0x54, 0x55, 0x51, 0xea, 0xf2, 0xec, 0xd7, 0xbb, 0x0d, 0xb6, 0xb6, 0x53, 0x50, 0xeb, 0x12,
		0x54, 0xb7, 0xe7, 0x1c, 0xbb, 0xef, 0x38, 0x30, 0x9b, 0xaa, 0x5a, 0xa7, 0xaa, 0xa6, 0x3b, 0x22,
		0x7b, 0x9d, 0x53, 0xcf, 0xe9, 0x71, 0x6e, 0x36, 0x95, 0xb5, 0xde, 0x00, 0x48, 0x39, 0x51, 0x4e,
		0x6b, 0x0e, 0x7f, 0xc7, 0x2d, 0xfb, 0x35, 0xe7, 0x50, 0x51, 0x57, 0xeb, 0x0c, 0x80, 0x0d, 0x15,
		0x01, 0x90, 0xd3, 0x82, 0xb8, 0x82, 0x35, 0xad, 0x5c, 0x6d, 0x99, 0x35, 0x85, 0xc3, 0x0c, 0x9a,
		0xea, 0x61, 0xa6, 0x4c, 0x05, 0x55, 0x38, 0x70, 0x51, 0x36, 0x94, 0x4d, 0xb5, 0x32, 0x5f, 0xea,
		0x87, 0x19, 0x2e, 0x15, 0x84, 0xa5, 0xa0, 0xb9, 0x58, 0x8e, 0xec, 0x2e, 0x9f, 0x95, 0x53, 0x57,
		0x85, 0xe8, 0xab, 0xe7, 0xdb, 0xad, 0xd7, 0x9d, 0x9e, 0xeb, 0xbd, 0x39, 0x61, 0x75, 0x97, 0xca,
		0x5a, 0xab, 0xb2, 0x96, 0x7f, 0x63, 0x79, 0xb7, 0xd8, 0x17, 0xcb, 0xbb, 0x5c, 0xba, 0x55, 0x0b,
		0x06, 0x54, 0x10, 0x9d, 0x7e, 0xa5, 0x9c, 0x3d, 0x8e, 0x93, 0xc7, 0xf8, 0x5c, 0xe5, 0x5b, 0x29,
		0xdb, 0x42, 0xe1, 0x0e, 0xd8, 0xb2, 0xa3, 0x68, 0x94, 0x06, 0x69, 0x38, 0x8a, 0xac, 0x03, 0x00,
		0xd7, 0x6b, 0x25, 0x97, 0x1f, 0xcc, 0x4d, 0x70, 0x1b, 0xa4, 0x1f, 0x26, 0xce, 0xb6, 0x3e, 0xba,
		0x35, 0xd1, 0xe5, 0x28, 0xba, 0x0a, 0xaf, 0x6b, 0x91, 0x49, 0x3f, 0x8d, 0xe2, 0x8f, 0xb5, 0x30,
		0x4a, 0xd2, 0x20, 0xba, 0x34, 0xf5, 0xc7, 0x6f, 0x24, 0x2b, 0xef, 0xd4, 0x6f, 0xe3, 0x51, 0x3a,
		0xba, 0x1c, 0x0d, 0x93, 0xec, 0xbb, 0x7a, 0x98, 0x84, 0x49, 0x7d, 0x68, 0xee, 0xcc, 0x70, 0xfe,
		0xa5, 0x3e, 0x0c, 0xa3, 0x8f, 0xb5, 0x24, 0x0d, 0x52, 0x53, 0x1b, 0x04, 0x69, 0x70, 0x11, 0x24,
		0xa6, 0x3e, 0x4c, 0x6e, 0xeb, 0xe9, 0xf0, 0x2e, 0x99, 0xfc, 0x51, 0xbf, 0x49, 0x6b, 0x61, 0x12,
		0xd5, 0x23, 0x13, 0x5e, 0x7f, 0xb8, 0x18, 0xc5, 0x49, 0xf6, 0x5d, 0x7d, 0xf9, 0xab, 0xb3, 0x5f,
		0x99, 0x8c, 0x2f, 0xa6, 0x3f, 0x38, 0xfb, 0x5a, 0x9f, 0xfe, 0xbb, 0x00, 0x45, 0x0c, 0x2b, 0x49,
		0xe3, 0xf1, 0x65, 0x1a, 0xcd, 0xa3, 0x5c, 0x27, 0xfb, 0xdc, 0xdb, 0xb3, 0xcf, 0xd4, 0x9d, 0x5f,
		0x9f, 0xff, 0xe8, 0xef, 0xc9, 0xe3, 0x37, 0xfc, 0xee, 0xe2, 0x33, 0xcf, 0xbe, 0xf3, 0xdd, 0x24,
		0x4c, 0xfc, 0xd6, 0xf4, 0x33, 0x9f, 0x7d, 0xf1, 0x5b, 0x61, 0xf4, 0xb1, 0x3f, 0xf9, 0x68, 0x9a,
		0xf3, 0x4f, 0xdc, 0x6f, 0x25, 0xb7, 0xbe, 0x37, 0xbc, 0x4b, 0x26, 0x7f, 0xf8, 0x27, 0xa9, 0x9b,
		0x44, 0x7e, 0x7b, 0xf1, 0x81, 0x67, 0xdf, 0xf9, 0xcb, 0x5f, 0x9b, 0xfd, 0xbe, 0xfe, 0xec, 0x03,
		0x9f, 0x7f, 0xf5, 0xa7, 0xff, 0xaa, 0xec, 0x28, 0x2c, 0xd7, 0xa3, 0x09, 0xf6, 0x66, 0xd6, 0x64,
		0x79, 0x9a, 0xab, 0x60, 0x3c, 0x4c, 0x6b, 0x37, 0x26, 0x8d, 0xc3, 0x4b, 0xf1, 0x0e, 0x2d, 0x63,
		0xc6, 0x55, 0xd3, 0x85, 0x47, 0x8d, 0xb7, 0x61, 0x34, 0xb0, 0x0e, 0x36, 0xb6, 0x84, 0x9b, 0x79,
		0x34, 0xf5, 0x50, 0xd6, 0xc1, 0xc6, 0xa6, 0x70, 0x43, 0xbb, 0xb1, 0xb9, 0x0a, 0x3f, 0x63, 0x44,
		0xe0, 0x85, 0x68, 0x47, 0x97, 0xb5, 0x49, 0xac, 0x44, 0x88, 0x5d, 0xfd, 0xd1, 0x38, 0xbe, 0x34,
		0x10, 0x1f, 0xef, 0x6c, 0x79, 0x99, 0xfb, 0x4f, 0xa3, 0x78, 0xb2, 0xc2, 0xac, 0xdb, 0x99, 0x32,
		0x30, 0xd2, 0x78, 0xeb, 0x4d, 0x90, 0xd8, 0xf1, 0xf5, 0xf8, 0xc6, 0x44, 0xa9, 0x75, 0xb0, 0x91,
		0xc6, 0x63, 0x03, 0x62, 0xf8, 0x03, 0xab, 0x33, 0x61, 0x33, 0xf3, 0x51, 0x9d, 0xf9, 0x34, 0xc3,
		0x18, 0x24, 0xe5, 0x99, 0x12, 0x2b, 0x8c, 0xf3, 0x5a, 0xc4, 0x07, 0x94, 0xcc, 0x06, 0x08, 0x68,
		0xe0, 0xc0, 0x06, 0x11, 0x70, 0x80, 0x41, 0x07, 0x15, 0x78, 0xe0, 0xc1, 0x07, 0x1e, 0x80, 0xb0,
		0x41, 0x08, 0x03, 0x88, 0x40, 0xc0, 0x08, 0x0e, 0x90, 0x32, 0x83, 0x41, 0xca, 0x3e, 0xcf, 0x06,
		0x1a, 0x88, 0xda, 0xcf, 0x73, 0xe8, 0xb4, 0x09, 0x66, 0x36, 0x1a, 0x42, 0x21, 0xa3, 0x94, 0x02,
		0xa4, 0x42, 0x47, 0x2b, 0x35, 0x88, 0xa5, 0x06, 0xb5, 0x74, 0x20, 0x17, 0x16, 0x7a, 0x81, 0x21,
		0x58, 0x26, 0x11, 0xef, 0xfe, 0xd6, 0x60, 0x7b, 0xfc, 0x71, 0x18, 0xa5, 0x2f, 0xb7, 0x11, 0x1d,
		0xfe, 0x9c, 0x6f, 0xf6, 0x00, 0x4d, 0xef, 0x05, 0xd1, 0xb5, 0x81, 0xed, 0x31, 0xc0, 0xdd, 0x05,
		0x6e, 0x9d, 0x84, 0x11, 0x2c, 0x21, 0x80, 0x83, 0xfd, 0xca, 0x65, 0x4c, 0x3b, 0x6d, 0x14, 0x5c,
		0xc7, 0x71, 0x1c, 0x5c, 0xa6, 0xe1, 0x28, 0x6a, 0x86, 0xd7, 0x61, 0x9a, 0x4c, 0x2e, 0x88, 0xad,
		0x29, 0x65, 0x2c, 0xed, 0xe0, 0x33, 0x97, 0xb6, 0xb0, 0xa5, 0xdd, 0xd8, 0xde, 0x6f, 0xec, 0xef,
		0xee, 0x6d, 0xef, 0xef, 0x70, 0x8d, 0x33, 0x21, 0xa8, 0x96, 0xd5, 0x58, 0x5d, 0x4d, 0x5f, 0xf8,
		0x2c, 0xa1, 0x8a, 0x91, 0x14, 0x6d, 0x9b, 0x79, 0x66, 0xb7, 0xb6, 0xed, 0xe6, 0x2b, 0x3b, 0x4d,
		0xeb, 0x48, 0xdb, 0x34, 0x36, 0x34, 0x6d, 0x44, 0xf7, 0x4c, 0x73, 0x76, 0x27, 0x4e, 0xa6, 0x37,
		0x02, 0x61, 0x63, 0x3a, 0x8e, 0x6f, 0xe4, 0xd6, 0xb8, 0x0a, 0x79, 0x6b, 0xfd, 0x5e, 0x9a, 0x0d,
		0x42, 0xa5, 0xf9, 0x65, 0xb6, 0x0a, 0xa9, 0xf3, 0x71, 0x56, 0x8a, 0xf0, 0x38, 0x65, 0xd9, 0x1d,
		0x34, 0xb1, 0x16, 0xa3, 0x21, 0x68, 0x93, 0x0d, 0x41, 0xeb, 0x31, 0x94, 0x0d, 0x41, 0xb9, 0x9a,
		0xcc, 0x86, 0xa0, 0x82, 0x0c, 0x67, 0x43, 0x10, 0x69, 0x00, 0x25, 0xeb, 0x81, 0xd9, 0x64, 0x91,
		0x79, 0xdc, 0xa1, 0x09, 0xae, 0x62, 0x73, 0x85, 0xe0, 0x71, 0x17, 0x0d, 0x36, 0x00, 0xdb, 0x28,
		0xac, 0xee, 0x3c, 0x91, 0x7c, 0xf1, 0x62, 0x56, 0x1d, 0xab, 0x4f, 0x09, 0x8c, 0x79, 0x80, 0xba,
		0x3c, 0x60, 0x3c, 0x49, 0x51, 0x93, 0x34, 0x0e, 0xc2, 0xc8, 0x0c, 0x6a, 0xc3, 0xe4, 0x16, 0x27,
		0x29, 0x58, 0x35, 0x9d, 0x23, 0x03, 0x98, 0x21, 0x30, 0x43, 0x60, 0x86, 0xc0, 0x0c, 0x81, 0x19,
		0x02, 0x33, 0x84, 0x5c, 0x6e, 0x39, 0x47, 0x06, 0xe4, 0x1b, 0x1f, 0x38, 0x32, 0x80, 0x60, 0x83,
		0x08, 0x38, 0xc0, 0xa0, 0x83, 0x0a, 0x3c, 0xf0, 0xe0, 0x03, 0x0f, 0x40, 0xd8, 0x20, 0x84, 0x01,
		0x44, 0x20, 0x60, 0x04, 0x07, 0x48, 0x99, 0xc1, 0x97, 0xa3, 0xf1, 0x54, 0xb8, 0xa0, 0x13, 0x03,
		0x66, 0xe6, 0x73, 0x60, 0x00, 0x01, 0x4a, 0x17, 0x48, 0x29, 0x00, 0x2a, 0x74, 0xb0, 0x52, 0x03,
		0x58, 0x6a, 0x40, 0x4b, 0x07, 0x70, 0x61, 0x81, 0x17, 0x18, 0x80, 0x65, 0x12, 0xd1, 0x31, 0x30,
		0x60, 0x6b, 0x17, 0x78, 0x60, 0xc0, 0x2e, 0x07, 0x06, 0x14, 0xfc, 0xe2, 0xc0, 0x00, 0x82, 0xfd,
		0x1a, 0x2e, 0x83, 0x03, 0x03, 0x18, 0x7e, 0xd7, 0xb9, 0xb4, 0x39, 0x30, 0x40, 0xdc, 0xd2, 0xde,
		0xdd, 0xd9, 0x79, 0xc9, 0x59, 0x01, 0xcc, 0x05, 0x2a, 0x66, 0x35, 0x67, 0x05, 0x54, 0x3e, 0x3c,
		0x61, 0xf4, 0x3e, 0x3d, 0x9b, 0x15, 0x02, 0xf4, 0x42, 0x29, 0x89, 0x9d, 0xac, 0x77, 0x97, 0xa9,
		0x73, 0xd6, 0xbb, 0xcb, 0x5b, 0xae, 0xac, 0x77, 0x0b, 0xbb, 0x10, 0xd6, 0xbb, 0x49, 0x34, 0xdf,
		0x90, 0x08, 0x7e, 0xbd, 0x3b, 0x1c, 0x98, 0x28, 0x0d, 0xd3, 0x7b, 0x8c, 0x7e, 0xae, 0xe7, 0x20,
		0x67, 0x0b, 0x30, 0xab, 0xb6, 0xdc, 0xf9, 0x47, 0x7f, 0x18, 0x24, 0xc0, 0x71, 0x6b, 0x21, 0x24,
		0xb7, 0xef, 0xf6, 0xfd, 0xfe, 0xe9, 0xa1, 0xd7, 0x3a, 0xf3, 0xbd, 0xf7, 0x5d, 0x07, 0x35, 0x7c,
		0x4d, 0x6b, 0x35, 0x09, 0xec, 0xc3, 0x88, 0x0d, 0xe8, 0x07, 0x12, 0x8f, 0x14, 0xe5, 0xf7, 0x1c,
		0xfb, 0xe8, 0x8d, 0x7d, 0xe8, 0xb6, 0x5c, 0xef, 0xfd, 0x5c, 0x5c, 0x7d, 0x64, 0x75, 0x69, 0x52,
		0x99, 0x0e, 0xb5, 0x7d, 0x53, 0x75, 0x87, 0x76, 0xbb, 0xf9, 0x6f, 0xb7, 0xe9, 0xbd, 0xf1, 0x8f,
		0x3a, 0xed, 0xbe, 0xd7, 0xb3, 0xdd, 0xb6, 0xd7, 0xb7, 0xe0, 0xaf, 0xf9, 0xcb, 0xaf, 0x14, 0x9e,
		0x6c, 0xe1, 0x9d, 0x7a, 0x6e, 0xcb, 0xfd, 0x8f, 0xd3, 0x5c, 0x2a, 0x90, 0xaa, 0xa3, 0xea, 0xf2,
		0x56, 0x9d, 0xdd, 0xfc, 0xcd, 0xef, 0xbb, 0x4d, 0x4a, 0x8d, 0x52, 0xcb, 0x5d, 0x6a, 0x67, 0xb6,
		0xdb, 0xb2, 0x0f, 0x5b, 0x0e, 0x3d, 0x1c, 0x65, 0x57, 0x9c, 0xec, 0xdc, 0xee, 0xd9, 0xae, 0xdf,
		0x76, 0xdc, 0xd7, 0x6f, 0x0e, 0x3b, 0x3d, 0xdf, 0x6e, 0x36, 0x7b, 0x4e, 0x9f, 0x40, 0x47, 0xe1,
		0xe5, 0x0f, 0x74, 0xed, 0x2c, 0x83, 0x70, 0x9a, 0x7e, 0xab, 0xdf, 0xa5, 0xe8, 0x28, 0xba, 0xbc,
		0x45, 0xd7, 0x72, 0xdb, 0x6f, 0x7d, 0xdb, 0xf3, 0x7a, 0xee, 0xe1, 0xa9, 0xe7, 0xd0, 0xcf, 0x51,
		0x72, 0xc5, 0x48, 0xae, 0xdb, 0xeb, 0x78, 0xce, 0x91, 0xe7, 0x76, 0xda, 0xb3, 0x7a, 0x1d, 0x75,
		0x47, 0xdd, 0xe5, 0x9e, 0xba, 0x9e, 0xb8, 0x6d, 0xff, 0x75, 0xaf, 0x73, 0xca, 0xc8, 0x4a, 0xb9,
		0x15, 0x93, 0x47, 0xb8, 0x6d, 0xcf, 0xe9, 0x1d, 0xdb, 0x47, 0x0e, 0x13, 0x09, 0x2a, 0xaf, 0x28,
		0xe5, 0x9d, 0xd8, 0xef, 0x66, 0x41, 0x96, 0x75, 0x13, 0xaa, 0xae, 0xc0, 0xf0, 0xfa, 0x9b, 0xdf,
		0xb2, 0xdb, 0xac, 0x0e, 0x53, 0x6e, 0x85, 0x65, 0x11, 0x94, 0x1a, 0xa5, 0x56, 0x08, 0xc9, 0x35,
		0x58, 0x11, 0xa6, 0xf0, 0xca, 0x11, 0x1e, 0x53, 0x08, 0x2a, 0xaf, 0x94, 0x14, 0xa2, 0xe7, 0xf4,
		0x9d, 0xde, 0x19, 0x1f, 0xc0, 0x52, 0x7b, 0xc5, 0x6a, 0xcf, 0x73, 0xfc, 0xa6, 0x73, 0x6c, 0x9f,
		0xb6, 0x3c, 0xff, 0xc4, 0xf1, 0x7a, 0xee, 0x11, 0x45, 0x47, 0xd1, 0xe5, 0x2d, 0xba, 0xd3, 0xf6,
		0xcc, 0xdd, 0x71, 0x3f, 0x1d, 0x75, 0x57, 0x78, 0x1a, 0xdb, 0x74, 0x5a, 0xf6, 0x7b, 0xff, 0xcc,
		0xee, 0xb9, 0xb6, 0xe7, 0x76, 0xda, 0xd4, 0x1d, 0x75, 0x97, 0xb7, 0xee, 0x9c, 0x77, 0x9e, 0xd3,
		0x6e, 0x3a, 0x4d, 0x3e, 0x15, 0xa3, 0xee, 0x0a, 0x4d, 0x2c, 0xdc, 0xf6, 0xf2, 0xf9, 0xc4, 0xd4,
		0xef, 0x51, 0x75, 0x54, 0x5d, 0x21, 0x51, 0xb6, 0xd5, 0x61, 0xed, 0x84, 0x62, 0x2b, 0x12, 0xe9,
		0xa8, 0x36, 0xaa, 0x2d, 0x6f, 0xb5, 0xf5, 0x9c, 0xbe, 0xdb, 0x3c, 0xb5, 0x5b, 0xaa, 0xd2, 0x56,
		0xe8, 0x2b, 0x38, 0xe7, 0x3c, 0x4b, 0xae, 0xf2, 0x35, 0xad, 0x6e, 0x65, 0xdd, 0xc5, 0x14, 0x98,
		0x34, 0x81, 0x69, 0xea, 0x22, 0xa6, 0xba, 0xa4, 0xa9, 0x0b, 0xbe, 0x5b, 0x98, 0x92, 0x12, 0x27,
		0x29, 0x4d, 0x5d, 0xc1, 0x94, 0x97, 0x34, 0x79, 0x29, 0xeb, 0xfe, 0xa5, 0xc0, 0xc4, 0x01, 0x97,
		0x9e, 0x2e, 0x5f, 0x8a, 0x4b, 0x9a, 0xb8, 0xd4, 0x74, 0xf3, 0x52, 0x5a, 0x22, 0xa5, 0xa5, 0xa6,
		0x6b, 0x97, 0xfa, 0x92, 0x97, 0x2a, 0x2a, 0xd8, 0x87, 0x40, 0x59, 0x89, 0xe4, 0x79, 0x45, 0x5b,
		0xe8, 0xa9, 0x30, 0x69, 0x0a, 0xd3, 0xd4, 0x6d, 0x4b, 0x75, 0xc9, 0x0b, 0x8b, 0x0a, 0xba, 0x6a,
		0x29, 0x2b, 0x91, 0x34, 0x4f, 0x49, 0x51, 0x52, 0x6b, 0x25, 0xad, 0x06, 0x2b, 0xa7, 0x14, 0x58,
		0xbe, 0x02, 0x23, 0xca, 0x53, 0x61, 0xb9, 0xa2, 0xbc, 0xae, 0xae, 0x57, 0x6a, 0x4c, 0x9a, 0xc6,
		0x14, 0x75, 0xb7, 0x52, 0x5c, 0xd2, 0xc4, 0xa5, 0xab, 0x8b, 0x95, 0xfa, 0x12, 0x99, 0x36, 0xaa,
		0xe9, 0x56, 0xa5, 0xbe, 0xa4, 0xe9, 0x4b, 0x57, 0x57, 0x2a, 0xf5, 0x25, 0x0e, 0xf0, 0x15, 0x75,
		0x9f, 0x52, 0x5d, 0x22, 0xa3, 0x23, 0x76, 0x97, 0x29, 0x45, 0x25, 0x17, 0xb9, 0xa8, 0x2a, 0xaa,
		0x6a, 0x5d, 0xaa, 0xd2, 0xd4, 0x35, 0x4a, 0x75, 0x95, 0xae, 0xae, 0x2e, 0x4f, 0xe2, 0xa5, 0xda,
		0xca, 0x56, 0x9d, 0x67, 0xbf, 0xde, 0x6d, 0x70, 0xe4, 0x02, 0x85, 0x96, 0xb7, 0xd0, 0xba, 0x3d,
		0xe7, 0xd8, 0x7d, 0xc7, 0x41, 0xf7, 0x54, 0x5b, 0x11, 0x6a, 0x9b, 0xee, 0x60, 0xed, 0x75, 0x4e,
		0x3d, 0xa7, 0xc7, 0x79, 0xf7, 0x54, 0x5c, 0x31, 0x81, 0x94, 0x32, 0xa3, 0xcc, 0x0a, 0x0a, 0xa3,
		0xc7, 0x2d, 0xfb, 0x35, 0xe7, 0xb2, 0x51, 0x6f, 0x45, 0x04, 0xd2, 0x86, 0xaa, 0x40, 0xca, 0x29,
		0x59, 0x5c, 0xe9, 0x55, 0x5a, 0xe1, 0x5a, 0x33, 0x7f, 0x0a, 0x8a, 0x19, 0x3e, 0x55, 0xa5, 0x5f,
		0x55, 0x5a, 0x32, 0x79, 0x2a, 0x8b, 0x19, 0x3b, 0xe5, 0xa4, 0x3f, 0xfc, 0x81, 0x67, 0xe6, 0xd4,
		0x15, 0x33, 0x70, 0x2a, 0x4b, 0xa7, 0xb2, 0xe6, 0x22, 0x3a, 0xb2, 0xbb, 0xdc, 0x73, 0x40, 0xbd,
		0x95, 0xaa, 0xbb, 0x9e, 0x6f, 0xb7, 0x5e, 0x77, 0x7a, 0xae, 0xf7, 0xe6, 0x84, 0x55, 0x6c, 0x2a,
		0xae, 0x10, 0xc5, 0x2d, 0xff, 0xc6, 0x32, 0x76, 0xb9, 0x2f, 0x96, 0xb1, 0xb9, 0xc4, 0x19, 0x4c,
		0xa8, 0x2c, 0x06, 0x0d, 0x06, 0x0b, 0x45, 0x41, 0x02, 0xeb, 0x73, 0xc6, 0xb1, 0x16, 0xc3, 0x52,
		0x10, 0x07, 0x6e, 0xd9, 0x51, 0x34, 0x4a, 0x83, 0x34, 0x1c, 0x45, 0xd6, 0x01, 0x90, 0xeb, 0xb6,
		0x92, 0xcb, 0x0f, 0xe6, 0x26, 0xb8, 0x0d, 0xd2, 0x0f, 0x13, 0x67, 0x5d, 0x1f, 0xdd, 0x9a, 0xe8,
		0x72, 0x14, 0x5d, 0x85, 0xd7, 0xb5, 0xc8, 0xa4, 0x9f, 0x46, 0xf1, 0xc7, 0x5a, 0x18, 0x25, 0x69,
		0x10, 0x5d, 0x9a, 0xfa, 0xe3, 0x37, 0x92, 0x95, 0x77, 0xea, 0xb7, 0xf1, 0x28, 0x1d, 0x5d, 0x8e,
		0x86, 0x49, 0xf6, 0x5d, 0x3d, 0x4c, 0xc2, 0xa4, 0x3e, 0x34, 0x77, 0x66, 0x38, 0xff, 0x52, 0x1f,
		0x86, 0xd1, 0xc7, 0x5a, 0x92, 0x06, 0xa9, 0xa9, 0x0d, 0x82, 0x34, 0xb8, 0x08, 0x12, 0x53, 0x1f,
		0x26, 0xb7, 0xf5, 0x74, 0x78, 0x97, 0x4c, 0xfe, 0xa8, 0xdf, 0xa4, 0xb5, 0x30, 0x89, 0xea, 0x91,
		0x09, 0xaf, 0x3f, 0x5c, 0x8c, 0xe2, 0x24, 0xfb, 0xae, 0xbe, 0xfc, 0xd5, 0xd9, 0xaf, 0x4c, 0xc6,
		0x17, 0xd3, 0x1f, 0x9c, 0x7d, 0xad, 0x8f, 0x27, 0xe6, 0x27, 0x69, 0x1c, 0x84, 0x91, 0x19, 0xd4,
		0x26, 0xff, 0xec, 0xf4, 0x37, 0x01, 0x95, 0x61, 0xac, 0x24, 0x8d, 0xc7, 0x97, 0x69, 0x34, 0x8f,
		0x9f, 0x9d, 0xec, 0x8e, 0xb4, 0x67, 0x9f, 0xb6, 0x3b, 0xbf, 0x72, 0xff, 0xd1, 0xdf, 0x93, 0xc7,
		0x6f, 0xf8, 0xdd, 0xc5, 0xdd, 0xc8, 0xbe, 0xf3, 0xdd, 0x24, 0x4c, 0xfc, 0xd6, 0xf4, 0x6e, 0xcc,
		0xbe, 0xf8, 0xad, 0x30, 0xfa, 0xd8, 0x9f, 0x7c, 0x44, 0xcd, 0xf9, 0xbd, 0xf0, 0x5b, 0xc9, 0xad,
		0xef, 0x0d, 0xef, 0x92, 0xc9, 0x1f, 0xfe, 0x49, 0xea, 0x26, 0x91, 0xdf, 0x5e, 0xdc, 0x8a, 0xec,
		0x3b, 0x7f, 0xf9, 0x6b, 0xb3, 0xdf, 0xd7, 0x9f, 0xdd, 0x8a, 0xf9, 0x57, 0xff, 0xf4, 0xe1, 0xad,
		0x98, 0xfc, 0xa3, 0xd3, 0x5f, 0x83, 0x11, 0xf0, 0xe5, 0x3b, 0x47, 0xd9, 0x16, 0x0a, 0x77, 0xdb,
		0x68, 0xee, 0x5a, 0xbf, 0x9b, 0x06, 0x70, 0xd0, 0x6a, 0x1d, 0xb3, 0x6c, 0x97, 0x2c, 0xd7, 0xd1,
		0x09, 0x76, 0x72, 0xd6, 0x38, 0x8a, 0x4d, 0x62, 0xe2, 0x3b, 0x33, 0xa8, 0x5d, 0x04, 0xd1, 0xe0,
		0x53, 0x38, 0x98, 0xba, 0x0e, 0xd9, 0xae, 0x2e, 0x2b, 0x1a, 0x3c, 0x69, 0xbd, 0xf0, 0x90, 0xf2,
		0x36, 0x8c, 0x06, 0xd6, 0xc1, 0xc6, 0x96, 0x70, 0x33, 0x8f, 0xa6, 0x2e, 0xcb, 0x3a, 0xd8, 0xd8,
		0x14, 0x6e, 0x68, 0x37, 0x36, 0x57, 0xe1, 0x67, 0x8c, 0xf0, 0xbc, 0xd0, 0xed, 0xe8, 0xb2, 0x36,
		0x09, 0xa4, 0x08, 0xc1, 0xac, 0x3f, 0x1a, 0xc7, 0x97, 0x06, 0x26, 0x59, 0xb5, 0xde, 0x9a, 0xfb,
		0x4f, 0xa3, 0x78, 0xb2, 0xc2, 0xac, 0xdb, 0x99, 0x32, 0x40, 0x2a, 0x03, 0x6f, 0x82, 0xc4, 0x8e,
		0xaf, 0xc7, 0x37, 0x26, 0x4a, 0xad, 0x83, 0x8d, 0x34, 0x1e, 0x1b, 0x94, 0x92, 0xc6, 0xd2, 0xea,
		0x4c, 0xd8, 0x4c, 0x8b, 0x54, 0xa7, 0x45, 0xcd, 0x30, 0x06, 0xc9, 0x87, 0x4c, 0x3a, 0xbe, 0xad,
		0xdd, 0xc6, 0xe1, 0x28, 0x0e, 0xd3, 0x7b, 0x1c, 0x2f, 0xb6, 0x08, 0x14, 0x8f, 0xec, 0x07, 0xf1,
		0x08, 0x18, 0x88, 0x03, 0x87, 0x3a, 0x88, 0xc8, 0x03, 0x8c, 0x3e, 0xa8, 0x08, 0x04, 0x8f, 0x42,
		0xf0, 0x48, 0x84, 0x8d, 0x46, 0x18, 0x88, 0x04, 0x82, 0x4a, 0x70, 0xc8, 0x94, 0x19, 0x0c, 0x07,
		0x4d, 0x2b, 0xa1, 0x06, 0x0c, 0x9b, 0x1e, 0xe3, 0xd3, 0x26, 0x98, 0xd9, 0x68, 0x18, 0x85, 0x8c,
		0x53, 0x0a, 0xb0, 0x0a, 0x1d, 0xaf, 0xd4, 0x60, 0x96, 0x1a, 0xdc, 0xd2, 0x81, 0x5d, 0x58, 0xf8,
		0x05, 0x86, 0x61, 0x99, 0x44, 0xbc, 0xfb, 0x5b, 0x83, 0xed, 0xf1, 0x87, 0x26, 0xb8, 0x8a, 0xcd,
		0x15, 0xa2, 0xc7, 0x5f, 0xd4, 0x87, 0xf6, 0x00, 0x6d, 0xef, 0xce, 0xf7, 0x56, 0xbc, 0x78, 0x31,
		0xdb, 0x31, 0x56, 0xcf, 0x28, 0x93, 0xfb, 0x4f, 0xab, 0xee, 0x59, 0xac, 0xd9, 0x1e, 0x42, 0xd8,
		0x84, 0x09, 0x6d, 0x0b, 0xe4, 0x06, 0x5e, 0xb1, 0x99, 0xd9, 0x12, 0xb3, 0x25, 0x66, 0x4b, 0xcc,
		0x96, 0x98, 0x2d, 0x31, 0x5b, 0xc2, 0x91, 0x08, 0x5a, 0xf1, 0x3a, 0x33, 0x1c, 0x67, 0x4f, 0xe3,
		0x37, 0x63, 0x16, 0xca, 0x06, 0xc7, 0x6f, 0x81, 0xda, 0x26, 0xa8, 0xf9, 0xa8, 0xc0, 0xa6, 0x01,
		0xdc, 0x14, 0x01, 0x9c, 0x16, 0x90, 0x53, 0x07, 0x74, 0xea, 0xc0, 0x4e, 0x17, 0xe0, 0x61, 0x82,
		0x1e, 0x28, 0xf0, 0x65, 0xd2, 0x81, 0x2d, 0x93, 0xaf, 0x44, 0x8c, 0xd0, 0x18, 0x73, 0x35, 0x1c,
		0x05, 0xe9, 0xcb, 0x6d, 0xe4, 0xa8, 0x31, 0x87, 0xa8, 0x7d, 0xe0, 0x4b, 0x68, 0x99, 0xe8, 0x7a,
		0x0a, 0xe4, 0xd8, 0xa3, 0xe2, 0xf0, 0x87, 0x76, 0x59, 0x27, 0x61, 0x04, 0xcf, 0x1f, 0x4a, 0xd2,
		0x8b, 0x95, 0xcb, 0x99, 0x0e, 0x54, 0xb4, 0x0e, 0x36, 0x1a, 0x4a, 0xae, 0xe7, 0x38, 0x0e, 0x2e,
		0xd3, 0x70, 0x14, 0x35, 0xc3, 0xeb, 0x30, 0x4d, 0x26, 0x37, 0x8a, 0x93, 0x07, 0x25, 0xb8, 0x80,
		0xe0, 0x33, 0x5d, 0x00, 0x5d, 0x00, 0x5d, 0x40, 0x95, 0xb2, 0x11, 0x7c, 0xeb, 0x31, 0x67, 0x58,
		0xe2, 0x7d, 0xde, 0x80, 0x21, 0x0e, 0x77, 0xe3, 0xfa, 0x4a, 0xce, 0x0a, 0xba, 0x81, 0x5d, 0x49,
		0x3c, 0x66, 0xc5, 0x5f, 0xd2, 0x5a, 0x60, 0xc5, 0x5f, 0xce, 0xb2, 0x66, 0xc5, 0x5f, 0xf8, 0x05,
		0xb1, 0xe2, 0x4f, 0x72, 0xfa, 0x41, 0xe9, 0xe8, 0xa9, 0xf8, 0x8f, 0xc3, 0x28, 0x7d, 0xa5, 0xa0,
		0xd6, 0xbf, 0x03, 0x7c, 0x09, 0xbd, 0x20, 0xba, 0x36, 0x2c, 0xf5, 0x97, 0x7f, 0x23, 0x58, 0xea,
		0x97, 0x7b, 0x39, 0x8b, 0x3a, 0xdf, 0x26, 0xeb, 0x7c, 0x8c, 0xe6, 0x39, 0xba, 0x00, 0x96, 0xfa,
		0xc5, 0xbb, 0x80, 0x3d, 0xba, 0x00, 0xa6, 0x21, 0xb4, 0xfe, 0xe1, 0x8b, 0xa5, 0x7e, 0x5a, 0x0c,
		0x1f, 0x90, 0x51, 0xcf, 0xfd, 0xc8, 0xec, 0xd7, 0x37, 0x58, 0x7e, 0x75, 0x72, 0x74, 0xfd, 0xeb,
		0x69, 0x8b, 0x75, 0xc4, 0x76, 0xd8, 0x0d, 0x5d, 0x03, 0xe8, 0x17, 0x37, 0xe9, 0x70, 0x71, 0x8f,
		0xfc, 0xfe, 0xe4, 0x1e, 0x75, 0xe7, 0xb7, 0x08, 0xe9, 0xa8, 0x10, 0x3c, 0x3f, 0xcb, 0x01, 0x70,
		0x6b, 0xcd, 0x58, 0xcc, 0x3d, 0xe0, 0x33, 0x5d, 0xab, 0x15, 0x26, 0xa9, 0x9d, 0xa6, 0x60, 0xc3,
		0xeb, 0x4e, 0xc2, 0xc8, 0x19, 0x9a, 0x1b, 0x13, 0xcd, 0x92, 0x0f, 0xa0, 0x11, 0x12, 0x27, 0xc1,
		0xe7, 0x07, 0x96, 0x6f, 0xbd, 0x6a, 0x34, 0x76, 0xf7, 0x1a, 0x8d, 0xcd, 0xbd, 0x97, 0x7b, 0x9b,
		0xfb, 0x3b, 0x3b, 0x5b, 0xbb, 0x5b, 0x40, 0xe5, 0x60, 0xab, 0x13, 0x0f, 0x4c, 0x6c, 0x06, 0x87,
		0x13, 0xe5, 0x47, 0xe3, 0xe1, 0x90, 0x0e, 0x85, 0x48, 0x59, 0x45, 0x94, 0xe4, 0xb1, 0x72, 0x02,
		0xe1, 0x91, 0x27, 0xcc, 0x55, 0xc1, 0x42, 0x9e, 0x30, 0x47, 0xef, 0xfd, 0xbd, 0xde, 0x9b, 0x87,
		0xcc, 0x95, 0xea, 0xa6, 0x79, 0xce, 0x9c, 0x3a, 0x57, 0x67, 0x8d, 0xd3, 0x70, 0x18, 0xfe, 0x1f,
		0xe8, 0x29, 0x73, 0xab, 0xb6, 0xf3, 0x8c, 0xb9, 0x75, 0x98, 0xc9, 0x33, 0xe6, 0x72, 0x54, 0x2d,
		0xcf, 0x98, 0xcb, 0xb3, 0x94, 0xc7, 0x33, 0xe6, 0x8a, 0xa5, 0x64, 0x9e, 0x31, 0x57, 0xb5, 0xc4,
		0x08, 0xe7, 0x8c, 0x39, 0xa8, 0xa1, 0xbf, 0x90, 0xc3, 0x7e, 0x79, 0xa2, 0x1c, 0x01, 0x47, 0x01,
		0xe8, 0xa0, 0x02, 0x0f, 0x3c, 0xf8, 0xc0, 0x03, 0x10, 0x36, 0x08, 0x61, 0x00, 0x11, 0x08, 0x18,
		0xc1, 0x01, 0x52, 0x66, 0x30, 0xee, 0x30, 0x5e, 0xf8, 0x21, 0xbc, 0x3c, 0x53, 0x8e, 0x40, 0x55,
		0x01, 0xb0, 0x42, 0x07, 0x2c, 0x35, 0xa0, 0xa5, 0x06, 0xb8, 0x74, 0x80, 0x17, 0x16, 0x80, 0x81,
		0x81, 0x58, 0x26, 0x11, 0xfc, 0x33, 0xe5, 0xb0, 0x87, 0xe4, 0x02, 0x0f, 0xc7, 0x45, 0x1f, 0x8a,
		0x0b, 0x3c, 0x2e, 0x42, 0x43, 0x67, 0xbc, 0x92, 0x76, 0x58, 0x2d, 0x13, 0x2f, 0x35, 0xb5, 0xbf,
		0x02, 0x77, 0xbe, 0xab, 0xe8, 0x78, 0xe7, 0xd2, 0xe6, 0xd2, 0x66, 0x36, 0x00, 0x6d, 0xf5, 0x39,
		0xfb, 0x13, 0xab, 0x1e, 0x9a, 0xac, 0x14, 0x31, 0x37, 0xcc, 0xf2, 0xc2, 0xa9, 0xf5, 0xac, 0x78,
		0x17, 0x61, 0x36, 0x2b, 0xde, 0x25, 0xea, 0x9c, 0x15, 0xef, 0xf2, 0x96, 0x2b, 0x2b, 0xde, 0xc2,
		0x2e, 0x84, 0x15, 0x6f, 0x12, 0xcd, 0x37, 0x24, 0xa2, 0xa0, 0xe2, 0x3d, 0x30, 0x51, 0x1a, 0xa6,
		0xf7, 0xb1, 0xb9, 0x02, 0xae, 0x78, 0x6f, 0x01, 0xce, 0x88, 0xb5, 0xdc, 0xf9, 0x47, 0x7f, 0x18,
		0x24, 0x06, 0xff, 0xac, 0x06, 0xb7, 0xef, 0xf6, 0xfd, 0xfe, 0xe9, 0xa1, 0xd7, 0x3a, 0xf3, 0xbd,
		0xf7, 0x5d, 0x07, 0x35, 0x7c, 0x4d, 0xeb, 0x34, 0x09, 0xf4, 0xc8, 0x5e, 0xf0, 0x82, 0xdf, 0x52,
		0x51, 0x7e, 0xcf, 0xb1, 0x8f, 0xde, 0xd8, 0x87, 0x6e, 0xcb, 0xf5, 0xde, 0xcf, 0xc5, 0xd5, 0x47,
		0x56, 0x97, 0x26, 0x95, 0xe9, 0x50, 0xdb, 0x37, 0x55, 0x77, 0x68, 0xb7, 0x9b, 0xff, 0x76, 0x9b,
		0xde, 0x1b, 0xff, 0xa8, 0xd3, 0xee, 0x7b, 0x3d, 0xdb, 0x6d, 0x7b, 0x7d, 0x8b, 0x03, 0x7d, 0x29,
		0xbc, 0x9c, 0x85, 0x77, 0xea, 0xb9, 0x2d, 0xf7, 0x3f, 0x4e, 0x73, 0xa9, 0x40, 0xaa, 0x8e, 0xaa,
		0xcb, 0x5b, 0x75, 0x76, 0xf3, 0x37, 0xbf, 0xef, 0x36, 0x29, 0x35, 0x4a, 0x2d, 0x77, 0xa9, 0x9d,
		0xd9, 0x6e, 0xcb, 0x3e, 0x6c, 0x39, 0xf4, 0x70, 0x94, 0x5d, 0x71, 0xb2, 0x73, 0xbb, 0x67, 0xbb,
		0x7e, 0xdb, 0x71, 0x5f, 0xbf, 0x39, 0xec, 0xf4, 0x7c, 0xbb, 0xd9, 0xec, 0x39, 0x7d, 0x02, 0x1d,
		0x85, 0x97, 0x3f, 0xd0, 0xb5, 0xb3, 0x0c, 0xc2, 0x69, 0xfa, 0xad, 0x7e, 0x97, 0xa2, 0xa3, 0xe8,
		0xf2, 0x16, 0x5d, 0xcb, 0x6d, 0xbf, 0xf5, 0x6d, 0xcf, 0xeb, 0xb9, 0x87, 0xa7, 0x9e, 0x43, 0x3f,
		0x47, 0xc9, 0x15, 0x23, 0xb9, 0x6e, 0xaf, 0xe3, 0x39, 0x47, 0x9e, 0xdb, 0x69, 0xcf, 0xea, 0x75,
		0xd4, 0x1d, 0x75, 0x97, 0x7b, 0xea, 0x7a, 0xe2, 0xb6, 0xfd, 0xd7, 0xbd, 0xce, 0x29, 0x23, 0x2b,
		0xe5, 0x56, 0x4c, 0x1e, 0xe1, 0xb6, 0x3d, 0xa7, 0x77, 0x6c, 0x1f, 0x39, 0x4c, 0x24, 0xa8, 0xbc,
		0xa2, 0x94, 0x77, 0x62, 0xbf, 0x9b, 0x05, 0x59, 0xd6, 0x4d, 0xa8, 0xba, 0x02, 0xc3, 0xeb, 0x6f,
		0x7e, 0xcb, 0x6e, 0xb3, 0x3a, 0x4c, 0xb9, 0x15, 0x96, 0x45, 0x50, 0x6a, 0x94, 0x5a, 0x21, 0x24,
		0xd7, 0x60, 0x45, 0x98, 0xc2, 0x2b, 0x47, 0x78, 0x4c, 0x21, 0xa8, 0xbc, 0x52, 0x52, 0x88, 0x9e,
		0xd3, 0x77, 0x7a, 0x67, 0x7c, 0x00, 0x4b, 0xed, 0x15, 0xab, 0x3d, 0xcf, 0xf1, 0x9b, 0xce, 0xb1,
		0x7d, 0xda, 0xf2, 0xfc, 0x13, 0xc7, 0xeb, 0xb9, 0x47, 0x14, 0x1d, 0x45, 0x97, 0xb7, 0xe8, 0x4e,
		0xdb, 0x33, 0x77, 0xc7, 0xfd, 0x74, 0xd4, 0x5d, 0xe1, 0x69, 0x6c, 0xd3, 0x69, 0xd9, 0xef, 0xfd,
		0x33, 0xbb, 0xe7, 0xda, 0x9e, 0xdb, 0x69, 0x53, 0x77, 0xd4, 0x5d, 0xde, 0xba, 0x73, 0xde, 0x79,
		0x4e, 0xbb, 0xe9, 0x34, 0xf9, 0x54, 0x8c, 0xba, 0x2b, 0x34, 0xb1, 0x70, 0xdb, 0xcb, 0xe7, 0x13,
		0x53, 0xbf, 0x47, 0xd5, 0x51, 0x75, 0x85, 0x44, 0xd9, 0x56, 0x87, 0xb5, 0x13, 0x8a, 0xad, 0x48,
		0xa4, 0xa3, 0xda, 0xa8, 0xb6, 0xbc, 0xd5, 0xd6, 0x73, 0xfa, 0x6e, 0xf3, 0xd4, 0x6e, 0xa9, 0x4a,
		0x5b, 0xa1, 0xaf, 0xe0, 0x9c, 0xb3, 0x2c, 0xb9, 0xca, 0xd7, 0xb4, 0xba, 0x95, 0x75, 0x17, 0x53,
		0x60, 0xd2, 0x04, 0xa6, 0xa9, 0x8b, 0x98, 0xea, 0x92, 0xa6, 0x2e, 0xf8, 0x6e, 0x61, 0x4a, 0x4a,
		0x9c, 0xa4, 0x34, 0x75, 0x05, 0x53, 0x5e, 0xd2, 0xe4, 0xa5, 0xac, 0xfb, 0x97, 0x02, 0x13, 0x07,
		0x5c, 0x7a, 0xba, 0x7c, 0x29, 0x2e, 0x69, 0xe2, 0x52, 0xd3, 0xcd, 0x4b, 0x69, 0x89, 0x94, 0x96,
		0x9a, 0xae, 0x5d, 0xea, 0x4b, 0x5e, 0xaa, 0xa8, 0x60, 0x1f, 0x02, 0x65, 0x25, 0x92, 0xe7, 0x15,
		0x6d, 0xa1, 0xa7, 0xc2, 0xa4, 0x29, 0x4c, 0x53, 0xb7, 0x2d, 0xd5, 0x25, 0x2f, 0x2c, 0x2a, 0xe8,
		0xaa, 0xa5, 0xac, 0x44, 0xd2, 0x3c, 0x25, 0x45, 0x49, 0xad, 0x95, 0xb4, 0x1a, 0xac, 0x9c, 0x52,
		0x60, 0xf9, 0x0a, 0x8c, 0x28, 0x4f, 0x85, 0xe5, 0x8a, 0xf2, 0xba, 0xba, 0x5e, 0xa9, 0x31, 0x69,
		0x1a, 0x53, 0xd4, 0xdd, 0x4a, 0x71, 0x49, 0x13, 0x97, 0xae, 0x2e, 0x56, 0xea, 0x4b, 0x64, 0xda,
		0xa8, 0xa6, 0x5b, 0x95, 0xfa, 0x92, 0xa6, 0x2f, 0x5d, 0x5d, 0xa9, 0xd4, 0x97, 0x38, 0xc0, 0x57,
		0xd4, 0x7d, 0x4a, 0x75, 0x89, 0x8c, 0x8e, 0xd8, 0x5d, 0xa6, 0x14, 0x95, 0x5c, 0xe4, 0xa2, 0xaa,
		0xa8, 0xaa, 0x75, 0xa9, 0x4a, 0x53, 0xd7, 0x28, 0xd5, 0x55, 0xba, 0xba, 0xba, 0x3c, 0x89, 0x97,
		0x6a, 0x2b, 0x5b, 0x75, 0x9e, 0xfd, 0x7a, 0xb7, 0xc1, 0x91, 0x0b, 0x14, 0x5a, 0xde, 0x42, 0xeb,
		0xf6, 0x9c, 0x63, 0xf7, 0x1d, 0x07, 0xdd, 0x53, 0x6d, 0x45, 0xa8, 0x6d, 0xba, 0x83, 0xb5, 0xd7,
		0x39, 0xf5, 0x9c, 0x1e, 0xe7, 0xdd, 0x53, 0x71, 0xc5, 0x04, 0x52, 0xca, 0x8c, 0x32, 0x2b, 0x28,
		0x8c, 0x1e, 0xb7, 0xec, 0xd7, 0x9c, 0xcb, 0x46, 0xbd, 0x15, 0x11, 0x48, 0x1b, 0xaa, 0x02, 0x29,
		0xa7, 0x64, 0x71, 0xa5, 0x57, 0x69, 0x85, 0x6b, 0xcd, 0xfc, 0x29, 0x28, 0x66, 0xf8, 0x54, 0x95,
		0x7e, 0x55, 0x69, 0xc9, 0xe4, 0xa9, 0x2c, 0x66, 0xec, 0x94, 0x93, 0xfe, 0xf0, 0x07, 0x9e, 0x99,
		0x53, 0x57, 0xcc, 0xc0, 0xa9, 0x2c, 0x9d, 0xca, 0x9a, 0x8b, 0xe8, 0xc8, 0xee, 0x72, 0xcf, 0x01,
		0xf5, 0x56, 0xaa, 0xee, 0x7a, 0xbe, 0xdd, 0x7a, 0xdd, 0xe9, 0xb9, 0xde, 0x9b, 0x13, 0x56, 0xb1,
		0xa9, 0xb8, 0x42, 0x14, 0xb7, 0xfc, 0x1b, 0xcb, 0xd8, 0xe5, 0xbe, 0x58, 0xc6, 0xe6, 0x12, 0x67,
		0x30, 0xa1, 0xb2, 0x18, 0x34, 0x18, 0x2c, 0x14, 0x05, 0x09, 0xac, 0xcf, 0x19, 0xc7, 0x5a, 0x0c,
		0x4b, 0x41, 0x1c, 0xb8, 0x65, 0x47, 0xd1, 0x28, 0x0d, 0xd2, 0x70, 0x14, 0x59, 0x07, 0x40, 0xae,
		0xdb, 0x4a, 0x2e, 0x3f, 0x98, 0x9b, 0xe0, 0x36, 0x48, 0x3f, 0x4c, 0x9c, 0x75, 0x7d, 0x74, 0x6b,
		0xa2, 0xcb, 0x51, 0x74, 0x15, 0x5e, 0xd7, 0x22, 0x93, 0x7e, 0x1a, 0xc5, 0x1f, 0x6b, 0x61, 0x94,
		0xa4, 0x41, 0x74, 0x69, 0xea, 0x8f, 0xdf, 0x48, 0x56, 0xde, 0xa9, 0xdf, 0xc6, 0xa3, 0x74, 0x74,
		0x39, 0x1a, 0x26, 0xd9, 0x77, 0xf5, 0x30, 0x09, 0x93, 0xfa, 0xd0, 0xdc, 0x99, 0xe1, 0xfc, 0x4b,
		0x7d, 0x18, 0x46, 0x1f, 0x6b, 0x49, 0x1a, 0xa4, 0xa6, 0x36, 0x08, 0xd2, 0xe0, 0x22, 0x48, 0x4c,
		0x7d, 0x98, 0xdc, 0xd6, 0xd3, 0xe1, 0x5d, 0x32, 0xf9, 0xa3, 0x7e, 0x93, 0xd6, 0xc2, 0x24, 0xaa,
		0x47, 0x26, 0xbc, 0xfe, 0x70, 0x31, 0x8a, 0x93, 0xec, 0xbb, 0xfa, 0xf2, 0x57, 0x67, 0xbf, 0x32,
		0x19, 0x5f, 0x4c, 0x7f, 0x70, 0xf6, 0xb5, 0x3e, 0x4e, 0xc3, 0x61, 0xf8, 0x7f, 0x66, 0x50, 0xbb,
		0x08, 0xa2, 0xc1, 0xa7, 0x70, 0x90, 0x7e, 0xa8, 0x4f, 0x7f, 0x15, 0x50, 0x1d, 0xc6, 0x4a, 0xd2,
		0x78, 0x7c, 0x99, 0x46, 0xf3, 0x00, 0xda, 0xc9, 0x6e, 0x49, 0x7b, 0xf6, 0x71, 0xbb, 0xf3, 0x4b,
		0xf7, 0x1f, 0xfd, 0x3d, 0x79, 0xfc, 0x86, 0xdf, 0x5d, 0xdc, 0x8e, 0xec, 0x3b, 0xdf, 0x4d, 0xc2,
		0xc4, 0x6f, 0x4d, 0x6f, 0xc7, 0xec, 0x8b, 0xdf, 0x0a, 0xa3, 0x8f, 0xfd, 0xc9, 0x47, 0xd4, 0x9c,
		0xdf, 0x0c, 0xbf, 0x95, 0xdc, 0xfa, 0xde, 0xf0, 0x2e, 0x99, 0xfc, 0xe1, 0x9f, 0xa4, 0x6e, 0x12,
		0xf9, 0xed, 0xc5, 0xbd, 0xc8, 0xbe, 0xf3, 0x97, 0xbf, 0x36, 0xfb, 0x7d, 0xfd, 0xd9, 0xbd, 0x98,
		0x7f, 0xf5, 0x4f, 0xe7, 0xf7, 0xe2, 0x70, 0x71, 0x2b, 0xfc, 0xe9, 0xef, 0xc1, 0x08, 0xf9, 0xf2,
		0xdd, 0xa3, 0x6c, 0x0b, 0x85, 0x3b, 0x6e, 0x34, 0x87, 0x5d, 0x01, 0x47, 0x0d, 0xe0, 0xa2, 0xf5,
		0xba, 0x66, 0xd9, 0x4e, 0x59, 0xae, 0xab, 0x93, 0x69, 0x99, 0x50, 0xe7, 0x6b, 0xbd, 0x35, 0xf7,
		0x93, 0x75, 0x93, 0xde, 0xdf, 0x4a, 0x05, 0x32, 0xab, 0x15, 0x26, 0xa9, 0x9d, 0xa6, 0xb1, 0xe8,
		0xa8, 0x60, 0x9d, 0x84, 0x91, 0x33, 0x34, 0x37, 0x26, 0x4a, 0x13, 0xeb, 0x60, 0x63, 0xf3, 0x57,
		0xc1, 0x96, 0x06, 0x9f, 0x1f, 0x58, 0xba, 0xf5, 0xaa, 0xd1, 0xd8, 0xdd, 0x6b, 0x34, 0x36, 0xf7,
		0x5e, 0xee, 0x6d, 0xee, 0xef, 0xec, 0x6c, 0xed, 0x6e, 0xed, 0x08, 0x36, 0xbe, 0x13, 0x0f, 0x4c,
		0x6c, 0x06, 0x87, 0x13, 0xd5, 0x46, 0xe3, 0xe1, 0x90, 0x8b, 0x5d, 0x1f, 0x61, 0x69, 0x23, 0x2b,
		0xc1, 0x18, 0xa5, 0x05, 0x9f, 0x64, 0xc2, 0x92, 0x3c, 0x14, 0x91, 0x65, 0x91, 0x30, 0x3f, 0x29,
		0xdd, 0x3f, 0xaa, 0xf1, 0x8b, 0x02, 0x1d, 0x22, 0xbc, 0x23, 0x94, 0xe5, 0x01, 0xe5, 0xf8, 0x19,
		0x41, 0x3e, 0xc6, 0x1a, 0x47, 0x03, 0x73, 0x15, 0x46, 0x66, 0x50, 0x5b, 0x2c, 0x04, 0x69, 0x6e,
		0x26, 0x7b, 0x48, 0xbc, 0x6a, 0xaa, 0x30, 0x5f, 0xfd, 0x36, 0x8c, 0x06, 0x93, 0xf4, 0x45, 0x98,
		0x59, 0x47, 0x53, 0xa7, 0x21, 0x2f, 0x03, 0xb4, 0xba, 0xb1, 0xb9, 0x0a, 0x3f, 0xcb, 0x8c, 0x6b,
		0x0b, 0xd1, 0x8d, 0x2e, 0x6b, 0x93, 0x08, 0x24, 0x31, 0x3c, 0xf4, 0x47, 0xe3, 0xf8, 0xd2, 0x88,
		0x4d, 0x9b, 0xac, 0xb7, 0xe6, 0xfe, 0xd3, 0x28, 0x9e, 0xac, 0x08, 0xeb, 0x76, 0x76, 0xa7, 0x85,
		0xe6, 0xa0, 0x6f, 0x82, 0xc4, 0x8e, 0xaf, 0xc7, 0x37, 0x26, 0x4a, 0xad, 0x83, 0x8d, 0x34, 0x1e,
		0x1b, 0xa9, 0xc9, 0xf2, 0xd2, 0xca, 0x4c, 0x98, 0xe4, 0x79, 0x28, 0x9e, 0x6f, 0x86, 0x32, 0x8b,
		0x86, 0x2b, 0xd1, 0x55, 0xae, 0x5f, 0x79, 0x8e, 0x07, 0xa4, 0xba, 0x17, 0x99, 0x58, 0x20, 0x1e,
		0x0f, 0x10, 0x30, 0x01, 0x08, 0x17, 0x50, 0xb0, 0x01, 0x0e, 0x1f, 0xe0, 0x30, 0x02, 0x0b, 0x27,
		0x64, 0x62, 0x85, 0x50, 0xbc, 0x10, 0x8f, 0x19, 0x99, 0x81, 0xb3, 0xfd, 0x76, 0xe2, 0x9d, 0xd0,
		0xc2, 0xaf, 0x23, 0x6c, 0x0f, 0x14, 0x0e, 0x1a, 0x30, 0xc0, 0x81, 0x04, 0x1e, 0x80, 0x00, 0x82,
		0x06, 0x22, 0xb0, 0x40, 0x02, 0x0b, 0x26, 0x98, 0x80, 0x22, 0x1b, 0x54, 0x84, 0x03, 0x0b, 0x0c,
		0xb8, 0x64, 0x86, 0x0e, 0x4d, 0x74, 0x3d, 0x7d, 0xe8, 0x09, 0xe2, 0xbd, 0x16, 0x01, 0x62, 0x6e,
		0x37, 0x88, 0x07, 0x98, 0x23, 0xcd, 0x26, 0x88, 0xb9, 0x28, 0x68, 0x83, 0x88, 0x38, 0xc0, 0xa8,
		0x83, 0x8a, 0x3c, 0xf0, 0xe8, 0x03, 0x8f, 0x40, 0xd8, 0x28, 0x84, 0x81, 0x44, 0x20, 0x68, 0x94,
		0x49, 0xc1, 0xbb, 0xbf, 0x35, 0x98, 0x1e, 0x7b, 0x1c, 0x46, 0xe9, 0x2b, 0x24, 0x7f, 0x3d, 0xc7,
		0x8f, 0x1d, 0x20, 0x93, 0x7b, 0x41, 0x74, 0x6d, 0xe0, 0x46, 0x71, 0xe1, 0xcd, 0xb1, 0xb0, 0x4e,
		0xc2, 0x08, 0x2e, 0x90, 0x83, 0x72, 0xf5, 0x8a, 0xf9, 0xd3, 0x81, 0x73, 0xc0, 0xf6, 0x1f, 0xc7,
		0xc1, 0x65, 0x1a, 0x8e, 0xa2, 0x66, 0x78, 0x1d, 0xce, 0x9a, 0x73, 0xf0, 0x26, 0x6e, 0xfc, 0x0a,
		0xb8, 0x64, 0x83, 0xcf, 0x5c, 0xb2, 0x25, 0x2f, 0xd9, 0xed, 0x9d, 0x1d, 0x2e, 0x5a, 0x82, 0xb8,
		0x2e, 0x6b, 0xcf, 0x39, 0xad, 0xa2, 0x2a, 0x41, 0x65, 0xd6, 0x97, 0x0c, 0x57, 0xf6, 0x15, 0xdc,
		0x4d, 0x0d, 0x1e, 0xe9, 0x58, 0xf4, 0x2d, 0x52, 0xc7, 0x2c, 0xfa, 0x16, 0xb7, 0x0c, 0x59, 0xf4,
		0x2d, 0xf9, 0x02, 0x58, 0xf4, 0x25, 0x71, 0xcc, 0xa5, 0xc0, 0xa2, 0x6f, 0xd1, 0xf8, 0xc1, 0xa2,
		0x6f, 0xde, 0x2f, 0x16, 0x7d, 0xc9, 0xd5, 0xdf, 0x61, 0x3e, 0x8b, 0xbe, 0x8c, 0x96, 0x3f, 0xb2,
		0x64, 0x59, 0xf4, 0x2d, 0x7d, 0xc9, 0xb2, 0xe8, 0x4b, 0x10, 0x57, 0x67, 0x2d, 0x8b, 0xbe, 0x95,
		0x09, 0x2a, 0xd6, 0xdd, 0xdc, 0x91, 0x81, 0x55, 0x7d, 0x67, 0x66, 0xb3, 0xec, 0x9b, 0x87, 0xb9,
		0x2c, 0xfb, 0x16, 0x28, 0x64, 0x96, 0x7d, 0x8b, 0x5b, 0x86, 0x2c, 0xfb, 0x96, 0x7c, 0x01, 0x2c,
		0xfb, 0x92, 0x39, 0xe6, 0x52, 0xc0, 0x2d, 0xfb, 0x5e, 0x84, 0x51, 0x10, 0xdf, 0x03, 0xd6, 0x7d,
		0xf7, 0x89, 0xf5, 0x15, 0xb0, 0x90, 0x27, 0x8f, 0xac, 0xd7, 0x5e, 0xf8, 0x39, 0xb0, 0x2b, 0xd3,
		0x25, 0x57, 0xde, 0x81, 0x39, 0x23, 0x0a, 0x77, 0x70, 0xec, 0xe9, 0xe2, 0x23, 0x5f, 0x8c, 0xd2,
		0x7e, 0xf4, 0x06, 0xc2, 0xd9, 0x50, 0x82, 0x8f, 0x21, 0x11, 0x3c, 0x95, 0x0a, 0x62, 0x57, 0x1d,
		0xd2, 0x6e, 0x3a, 0x90, 0x72, 0x0a, 0xa7, 0xc1, 0xb0, 0x6c, 0xb2, 0xc1, 0x69, 0x30, 0x2c, 0x8f,
		0x28, 0x2d, 0x8b, 0x30, 0x0b, 0xaa, 0x44, 0xf9, 0xe3, 0xc1, 0x78, 0x95, 0xe0, 0x2a, 0x36, 0x57,
		0x08, 0x1e, 0x77, 0x31, 0x2e, 0x6e, 0x0f, 0xc0, 0xd6, 0xee, 0x3c, 0xb1, 0x7c, 0xf1, 0x62, 0x96,
		0x85, 0xd5, 0xa7, 0x04, 0xc6, 0x3c, 0x40, 0x91, 0x65, 0x3c, 0x8e, 0xf0, 0x87, 0x4d, 0xe4, 0x71,
		0x84, 0x6b, 0xb6, 0x94, 0xc7, 0x11, 0x56, 0x74, 0xb1, 0xf3, 0x38, 0x42, 0x31, 0xe5, 0x56, 0x1e,
		0x51, 0x58, 0x42, 0x81, 0x95, 0x87, 0x16, 0x22, 0x5a, 0xc4, 0x43, 0x0b, 0xab, 0xee, 0x3d, 0x79,
		0x7c, 0x61, 0x8e, 0x4e, 0x92, 0xe7, 0x18, 0x4a, 0xb6, 0x44, 0x88, 0xf3, 0x5b, 0xe4, 0x89, 0xe1,
		0x40, 0xc8, 0x5a, 0x94, 0x99, 0x15, 0xca, 0xcd, 0x02, 0xa1, 0xb2, 0x3e, 0x99, 0x59, 0x9e, 0x94,
		0xa5, 0x28, 0x94, 0x3f, 0xe0, 0xb9, 0x43, 0x10, 0x65, 0xc0, 0xd2, 0x85, 0x0c, 0x98, 0x28, 0x3f,
		0x74, 0x97, 0x6b, 0x41, 0xc9, 0x9e, 0x4a, 0x9a, 0x87, 0x42, 0xf5, 0x4c, 0x02, 0x1c, 0x12, 0x9a,
		0x23, 0x2a, 0xd7, 0xff, 0x94, 0xb7, 0xea, 0x4b, 0x5c, 0xf1, 0xd6, 0x44, 0xc9, 0x83, 0xd2, 0x17,
		0x7a, 0xf6, 0x8c, 0x7a, 0x66, 0x4e, 0xc9, 0x1e, 0x50, 0xc6, 0xf6, 0x34, 0x31, 0xdb, 0xcf, 0x24,
		0x6d, 0x2f, 0x13, 0xb8, 0x7d, 0x4c, 0xda, 0xf6, 0x30, 0xb1, 0xdb, 0xbf, 0xc4, 0x6e, 0xef, 0x92,
		0xb9, 0x7d, 0xab, 0xda, 0x14, 0x2a, 0x66, 0x7b, 0x95, 0xc0, 0xed, 0x53, 0x92, 0xb6, 0x47, 0xad,
		0x6e, 0x7f, 0x9a, 0x85, 0x70, 0xa2, 0x5c, 0x09, 0xb4, 0x2f, 0xe1, 0xdc, 0x5a, 0x51, 0xe7, 0xd2,
		0x0a, 0x39, 0x77, 0x96, 0x28, 0x47, 0x94, 0x23, 0xca, 0x11, 0xe5, 0xaa, 0x89, 0x72, 0x52, 0xce,
		0x4d, 0x15, 0x52, 0xeb, 0x10, 0x59, 0xf3, 0x10, 0x56, 0xfb, 0x10, 0x17, 0x38, 0x25, 0x06, 0x50,
		0xc1, 0x81, 0x54, 0x6a, 0x40, 0x15, 0x1f, 0x58, 0xc5, 0x07, 0x58, 0xd9, 0x81, 0x56, 0x46, 0xc0,
		0x15, 0x12, 0x78, 0xe5, 0xd5, 0x52, 0x56, 0x3c, 0xd6, 0x38, 0x8c, 0xd2, 0xad, 0x5d, 0x49, 0x0e,
		0x6b, 0x1e, 0xff, 0x76, 0x05, 0x99, 0x24, 0x73, 0x82, 0xba, 0xc0, 0xbd, 0xb3, 0x92, 0x27, 0xa0,
		0x0b, 0x9f, 0x79, 0x20, 0x7d, 0x82, 0x39, 0xc2, 0xb0, 0x63, 0x81, 0x8d, 0x43, 0xa2, 0x27, 0x8c,
		0xa3, 0x2c, 0x89, 0xc6, 0xe6, 0xfe, 0x0e, 0x57, 0x05, 0x36, 0x8a, 0xc9, 0xb3, 0xe6, 0x9c, 0x9b,
		0xed, 0xa4, 0x78, 0x4d, 0x2b, 0xb9, 0x4f, 0x52, 0x73, 0x23, 0xb2, 0x38, 0xb4, 0x34, 0x8d, 0x05,
		0xa2, 0xa7, 0xcc, 0x61, 0x81, 0xe8, 0x3b, 0xc4, 0xc4, 0x02, 0xd1, 0xdf, 0x97, 0x39, 0x0b, 0x44,
		0x3f, 0x69, 0x20, 0x0b, 0x44, 0x28, 0x19, 0x83, 0xe0, 0x02, 0x91, 0xb4, 0xf0, 0xf7, 0x30, 0x04,
		0x6e, 0xbd, 0x12, 0x64, 0x53, 0x37, 0x48, 0x53, 0x13, 0x47, 0xe2, 0xca, 0x44, 0xd6, 0x7f, 0x7f,
		0xdf, 0xac, 0xed, 0xdb, 0xb5, 0xe3, 0xa0, 0x76, 0x75, 0xfe, 0x67, 0xe3, 0xcb, 0x1f, 0x7f, 0xbc,
		0xf8, 0xc6, 0x1b, 0xff, 0x90, 0xe3, 0x25, 0xce, 0x25, 0xdd, 0xe0, 0x4e, 0xdf, 0x7d, 0xc7, 0xbb,
		0xcc, 0x4c, 0x4c, 0xa9, 0x05, 0x6c, 0x7b, 0x7a, 0x94, 0x93, 0x42, 0xb5, 0x3d, 0x49, 0x99, 0x3f,
		0x0e, 0xd2, 0xf2, 0x24, 0x60, 0x56, 0x78, 0x45, 0xf7, 0xc8, 0x8a, 0xa9, 0xf4, 0x88, 0x43, 0x5c,
		0xb6, 0x3d, 0xc9, 0xad, 0xe4, 0x70, 0xaf, 0x2c, 0x6e, 0xc5, 0x86, 0x7b, 0x65, 0x49, 0xa1, 0x78,
		0x95, 0x18, 0xb6, 0x3d, 0x7d, 0xb3, 0xde, 0xf2, 0x75, 0xdb, 0xd3, 0x32, 0x8c, 0x57, 0x15, 0xeb,
		0x7e, 0xa9, 0xd0, 0x82, 0x5d, 0x8c, 0xd4, 0x9a, 0xee, 0xdd, 0xde, 0x28, 0x1b, 0xe1, 0x64, 0xcc,
		0xd3, 0x92, 0x33, 0x3f, 0x4b, 0xf4, 0xbc, 0x2c, 0x19, 0xf3, 0xb1, 0xca, 0x5a, 0x37, 0x42, 0xca,
		0x2c, 0x58, 0xe5, 0x15, 0xab, 0xd4, 0xae, 0x52, 0x80, 0x82, 0x4a, 0x39, 0x31, 0xb7, 0xf8, 0x88,
		0x57, 0xec, 0x6f, 0x2c, 0xd8, 0x47, 0x94, 0xed, 0x1b, 0x20, 0x7c, 0x42, 0x09, 0xae, 0x40, 0xb4,
		0x0b, 0x28, 0x76, 0xe5, 0x17, 0xb7, 0xfe, 0x8a, 0xf9, 0x4d, 0x05, 0xad, 0xf0, 0xb2, 0x56, 0xb6,
		0xe0, 0x15, 0x5d, 0xe0, 0x3a, 0x16, 0xb8, 0x7e, 0x8b, 0x59, 0xb5, 0xf9, 0xaf, 0xa1, 0x02, 0xd6,
		0x8f, 0x75, 0x33, 0x1e, 0xa6, 0x61, 0x2d, 0x1d, 0xdd, 0x8e, 0x86, 0xa3, 0xeb, 0xfb, 0xc2, 0xd6,
		0xcf, 0xb2, 0x3d, 0xf9, 0xeb, 0xdf, 0x5f, 0x90, 0xc7, 0x28, 0x76, 0x70, 0x47, 0xe1, 0x0f, 0x1d,
		0xca, 0x78, 0xb8, 0x50, 0xe2, 0x43, 0x84, 0xb2, 0x1e, 0x16, 0x94, 0xfe, 0x50, 0xa0, 0xf4, 0xe2,
		0x7f, 0xb9, 0x45, 0x7e, 0x5d, 0x14, 0x53, 0xf4, 0x20, 0x0b, 0x6b, 0xee, 0x74, 0x43, 0x93, 0x14,
		0xbf, 0x72, 0xb2, 0xf3, 0xa4, 0x97, 0x36, 0x14, 0xac, 0xdc, 0x72, 0x66, 0x37, 0x95, 0xf6, 0xfc,
		0xb9, 0xcc, 0xe7, 0xcd, 0x02, 0x9e, 0x2f, 0x97, 0xfd, 0x3c, 0x59, 0xcc, 0xf3, 0x63, 0x31, 0xcf,
		0x8b, 0x65, 0x3c, 0x1f, 0xd6, 0x5d, 0xf2, 0x2a, 0x6b, 0x36, 0x92, 0x55, 0x78, 0x3e, 0xf1, 0xad,
		0x00, 0x73, 0x5f, 0xd6, 0x72, 0x2b, 0x77, 0x44, 0x60, 0xe9, 0xdb, 0x9d, 0x24, 0x6c, 0x73, 0x12,
		0xb4, 0xbd, 0x49, 0xca, 0xb6, 0x26, 0x71, 0xdb, 0x99, 0xc4, 0x6d, 0x63, 0x92, 0xb5, 0x7d, 0xa9,
		0x5a, 0xbb, 0x1f, 0xca, 0x1e, 0xe9, 0xc7, 0x63, 0x0b, 0x9e, 0x0f, 0x64, 0xdc, 0xbf, 0x2b, 0x27,
		0xb0, 0x09, 0x0c, 0x70, 0xd2, 0x02, 0x9d, 0xd8, 0x80, 0x27, 0x36, 0xf0, 0xc9, 0x0c, 0x80, 0xe5,
		0x06, 0xc2, 0x92, 0x03, 0x62, 0x76, 0x4b, 0xb8, 0x7f, 0xf7, 0x6f, 0x64, 0x5a, 0x3c, 0xb6, 0x40,
		0xda, 0xd2, 0xe1, 0xb1, 0x05, 0x3c, 0xb6, 0x80, 0x28, 0x47, 0x94, 0x23, 0xca, 0x11, 0xe5, 0x88,
		0x72, 0x32, 0x6a, 0x1c, 0x99, 0x21, 0x41, 0x9a, 0xc6, 0xe1, 0xc5, 0x38, 0x2d, 0xe1, 0x29, 0xf0,
		0x37, 0x9d, 0xe0, 0x03, 0xdb, 0x38, 0x9f, 0x4e, 0x72, 0x08, 0x95, 0x18, 0x4a, 0x05, 0x87, 0x54,
		0xa9, 0xa1, 0x55, 0x7c, 0x88, 0x15, 0x1f, 0x6a, 0x65, 0x87, 0x5c, 0x19, 0xa1, 0x57, 0x48, 0x08,
		0x96, 0x57, 0x55, 0x59, 0xf1, 0x58, 0x26, 0x1a, 0xdf, 0x98, 0x78, 0xb6, 0xb3, 0x5d, 0xe0, 0x84,
		0xba, 0x86, 0x20, 0x9b, 0x9c, 0xe8, 0xff, 0xb3, 0xf7, 0xb7, 0xcd, 0x69, 0x23, 0xdb, 0xd7, 0x38,
		0xfc, 0x3e, 0x9f, 0xc2, 0xa5, 0xba, 0x4e, 0x55, 0x3c, 0x67, 0x14, 0x0c, 0x06, 0x13, 0x52, 0x75,
		0xd7, 0x14, 0x8e, 0x49, 0x86, 0xeb, 0x60, 0xf0, 0x8d, 0x49, 0xce, 0xcc, 0x65, 0xf3, 0x53, 0xc9,
		0xd0, 0x38, 0xfa, 0x45, 0x96, 0x38, 0x92, 0xf0, 0xd8, 0x27, 0xe3, 0xef, 0xfe, 0x2f, 0x04, 0xc8,
		0x3c, 0xd8, 0xf1, 0x03, 0x52, 0xf7, 0xde, 0xad, 0xe5, 0x17, 0x09, 0xf6, 0x4c, 0xac, 0x2d, 0xa9,
		0x7b, 0xed, 0xb5, 0x76, 0xef, 0x87, 0xc9, 0xd5, 0xf4, 0x25, 0xde, 0xa1, 0xdd, 0x16, 0x95, 0xcd,
		0x85, 0x89, 0x58, 0x20, 0x94, 0x20, 0x94, 0x20, 0x94, 0x20, 0x94, 0x20, 0x94, 0x20, 0x94, 0x24,
		0x10, 0x0b, 0x13, 0xb1, 0x9e, 0x61, 0x12, 0x26, 0x62, 0x3d, 0xf3, 0x41, 0x61, 0x22, 0xd6, 0xeb,
		0xcd, 0xc3, 0x44, 0x2c, 0x5d, 0xe0, 0x7e, 0x75, 0x4b, 0x60, 0x22, 0xd6, 0xd6, 0x5b, 0x02, 0x13,
		0xb1, 0xf8, 0x53, 0x31, 0x7a, 0xd6, 0xa0, 0x0f, 0x3b, 0x05, 0x0b, 0xd0, 0x87, 0x7d, 0xd5, 0x1e,
		0x92, 0x2d, 0x44, 0x56, 0x5a, 0x32, 0x14, 0xee, 0x4b, 0x74, 0x0b, 0xc9, 0xcf, 0xd0, 0x90, 0xfd,
		0xc1, 0xe6, 0x23, 0xd3, 0x07, 0xd7, 0x9b, 0x3f, 0x23, 0xab, 0x97, 0x3c, 0x37, 0x2b, 0xf9, 0x59,
		0xbe, 0x3b, 0xb3, 0xe7, 0xb6, 0x85, 0x27, 0x1a, 0x77, 0xa2, 0x71, 0xe7, 0x93, 0xc6, 0xa1, 0x71,
		0x27, 0x1a, 0x77, 0xbe, 0xd2, 0x1f, 0xa3, 0x83, 0xe7, 0x73, 0x3d, 0x30, 0x5a, 0x79, 0x6a, 0x80,
		0x1a, 0x68, 0xe5, 0xf9, 0x12, 0x94, 0x40, 0x4f, 0xcf, 0x47, 0x40, 0x01, 0xcd, 0x3d, 0x19, 0xec,
		0x79, 0x34, 0xf7, 0x7c, 0x74, 0x8f, 0xe7, 0xb7, 0xc9, 0xe7, 0xf2, 0x86, 0x46, 0xb3, 0xcf, 0xe7,
		0xbf, 0x45, 0xcf, 0x1d, 0x4b, 0x4c, 0xc8, 0x4a, 0x4e, 0x9d, 0x67, 0x97, 0x45, 0x6b, 0xcf, 0x54,
		0x2e, 0x88, 0xd6, 0x9e, 0xb2, 0xc2, 0x37, 0x68, 0xed, 0x89, 0xd6, 0x9e, 0xe9, 0x3c, 0x4a, 0xe9,
		0xad, 0x3d, 0xd5, 0x54, 0x3d, 0x2b, 0xad, 0x72, 0x46, 0x43, 0x4f, 0x05, 0x2f, 0x1a, 0x0d, 0x3d,
		0xd1, 0xd0, 0x93, 0x86, 0xc3, 0xc8, 0x47, 0xe0, 0x4b, 0x59, 0x43, 0x4f, 0xb9, 0xca, 0x81, 0x84,
		0x92, 0x78, 0xcc, 0xc1, 0xec, 0xa1, 0x95, 0x27, 0x5a, 0x79, 0xa2, 0x95, 0x27, 0x7d, 0x87, 0x44,
		0xcb, 0x31, 0xa9, 0x71, 0x50, 0x8a, 0x1c, 0x55, 0xf2, 0xe8, 0x95, 0x97, 0x42, 0x10, 0xab, 0xa5,
		0xa5, 0x50, 0x3b, 0xab, 0xb8, 0x56, 0xf6, 0x0e, 0xc9, 0x30, 0x48, 0x86, 0x79, 0xca, 0x38, 0x1a,
		0xc9, 0x30, 0x50, 0x2f, 0xe9, 0xfa, 0x61, 0x1c, 0xdb, 0x6f, 0x1c, 0xe9, 0xc5, 0x8a, 0x46, 0x59,
		0x3e, 0x2d, 0xad, 0x73, 0xbd, 0xf6, 0xf4, 0x59, 0xa8, 0xc8, 0x91, 0xc5, 0xd9, 0x3c, 0xab, 0x0d,
		0x4d, 0x77, 0x23, 0xe7, 0xf6, 0x48, 0x3e, 0xde, 0xba, 0x38, 0x8a, 0x7f, 0xfe, 0xdb, 0x1b, 0x4f,
		0x82, 0x4b, 0x61, 0xfa, 0x8e, 0xfc, 0xd3, 0xf8, 0xe4, 0xca, 0x38, 0x90, 0xe7, 0x1a, 0x16, 0xc3,
		0x81, 0x3c, 0x0e, 0xe4, 0x71, 0x20, 0xbf, 0xc5, 0xa3, 0xc4, 0x81, 0xbc, 0x76, 0xc0, 0xaf, 0xcc,
		0x01, 0xa8, 0x74, 0x04, 0x04, 0x1c, 0x82, 0x6a, 0xc7, 0x40, 0xc6, 0x41, 0x90, 0x71, 0x14, 0x34,
		0x1c, 0x46, 0x3e, 0x42, 0x5a, 0xca, 0x0e, 0xe4, 0x03, 0x31, 0x10, 0xce, 0xb5, 0x18, 0x9a, 0xe1,
		0x6d, 0x18, 0x89, 0x2b, 0x93, 0xc2, 0xe9, 0xfc, 0x03, 0x36, 0xe1, 0xa8, 0x5e, 0x89, 0x01, 0x38,
		0xaa, 0xa7, 0xe4, 0x9a, 0xc8, 0xb9, 0x28, 0x72, 0xae, 0x8a, 0x96, 0xcb, 0x52, 0xe3, 0xba, 0x14,
		0xb9, 0xb0, 0xe4, 0xd1, 0xd3, 0x39, 0xaa, 0x57, 0xed, 0x3e, 0x56, 0xd4, 0xcb, 0x7b, 0x85, 0x36,
		0x9c, 0xd8, 0x51, 0x24, 0x02, 0x4f, 0x79, 0x2f, 0x42, 0xe3, 0x7f, 0xce, 0xf6, 0xcc, 0x5a, 0xdd,
		0xfc, 0x64, 0x9b, 0xa3, 0xfe, 0x8f, 0xf2, 0xdd, 0xf9, 0xf9, 0xbb, 0x27, 0x7e, 0xf0, 0x7f, 0xd4,
		0xed, 0xda, 0xbe, 0xca, 0x17, 0xd6, 0x39, 0x6d, 0xfe, 0x81, 0xb7, 0xf6, 0x9a, 0xb7, 0x96, 0x97,
		0x13, 0x7e, 0x15, 0x87, 0xbc, 0x31, 0xfd, 0xa1, 0xa4, 0x14, 0x36, 0x2c, 0x82, 0x4e, 0x80, 0x4e,
		0x80, 0x4e, 0x80, 0x4e, 0x80, 0x4e, 0x80, 0x4e, 0x80, 0x4e, 0x80, 0x4e, 0x80, 0x4e, 0xc0, 0x5b,
		0x83, 0x4e, 0x90, 0xad, 0x13, 0x16, 0x78, 0x6a, 0x0e, 0xfc, 0x49, 0xec, 0x5b, 0x55, 0xcb, 0x84,
		0x35, 0x83, 0xa0, 0x12, 0xa0, 0x12, 0xa0, 0x12, 0xa0, 0x12, 0xa0, 0x12, 0xa0, 0x12, 0x9e, 0x8d,
		0x18, 0x13, 0xc7, 0x8b, 0xde, 0x13, 0x50, 0x08, 0x2a, 0xcb, 0xa9, 0x68, 0x8c, 0x34, 0x22, 0xd0,
		0x6f, 0x9f, 0xd2, 0xc8, 0x22, 0x6a, 0xb3, 0x1f, 0x89, 0x8d, 0x24, 0xa2, 0x38, 0x6c, 0x85, 0xc2,
		0x54, 0x55, 0x4a, 0x23, 0x86, 0xa8, 0x2e, 0xe1, 0x52, 0xa5, 0x82, 0x45, 0x4c, 0x8b, 0x88, 0xa8,
		0xbf, 0x7a, 0x1f, 0x45, 0xc4, 0xfc, 0x21, 0x11, 0x45, 0xc4, 0x0f, 0xd4, 0x1e, 0x2e, 0x4a, 0xba,
		0x50, 0x47, 0x1c, 0x17, 0x23, 0x9e, 0x4c, 0x1f, 0x47, 0xc7, 0x41, 0x25, 0x31, 0x9b, 0xdd, 0x8d,
		0x4a, 0xe2, 0x07, 0x76, 0x73, 0x6e, 0x8b, 0x89, 0xe7, 0xfb, 0x17, 0xe5, 0xc4, 0xcf, 0x7f, 0x7f,
		0x81, 0x3f, 0x89, 0x44, 0x60, 0x0e, 0xec, 0xb1, 0x7d, 0xe1, 0xb8, 0x4e, 0xe4, 0x88, 0x50, 0x7e,
		0x65, 0xf1, 0x43, 0x46, 0xa0, 0xc8, 0x38, 0x95, 0x0b, 0xa2, 0xc8, 0x58, 0xce, 0x32, 0x42, 0x91,
		0x31, 0x8a, 0x8c, 0xd3, 0x7a, 0x94, 0xd2, 0x8b, 0x8c, 0x13, 0xe0, 0xbd, 0x55, 0x57, 0x69, 0xbc,
		0x64, 0x03, 0xca, 0x8d, 0x75, 0x73, 0x09, 0x04, 0x5c, 0x83, 0x6a, 0x17, 0x41, 0xc6, 0x55, 0x90,
		0x71, 0x19, 0x34, 0x5c, 0x47, 0x3e, 0x82, 0x5f, 0xca, 0xca, 0x8d, 0x17, 0x12, 0xd7, 0xf4, 0x26,
		0x57, 0x17, 0x22, 0x50, 0x9f, 0x1a, 0xb4, 0x6e, 0x10, 0x52, 0x83, 0x94, 0x18, 0x80, 0xd4, 0x20,
		0x4a, 0x4e, 0x89, 0x9c, 0x73, 0x22, 0xe7, 0xa4, 0x68, 0x39, 0x2b, 0x35, 0x4e, 0x4b, 0x91, 0xf3,
		0x4a, 0x1e, 0x3d, 0x9d, 0xd4, 0x20, 0x57, 0xd8, 0xa3, 0x40, 0x8c, 0x28, 0x94, 0x0f, 0x54, 0xd5,
		0x96, 0x0f, 0xc4, 0xe1, 0xef, 0x77, 0xef, 0x66, 0x07, 0x48, 0x85, 0x75, 0xe7, 0x8a, 0x9c, 0xeb,
		0xcc, 0x9e, 0xbd, 0x9a, 0xc6, 0x60, 0x1b, 0x3b, 0x41, 0xd5, 0xc1, 0xa1, 0x42, 0xe5, 0x0e, 0x12,
		0x05, 0x12, 0x05, 0x12, 0x05, 0x12, 0xc5, 0x93, 0x44, 0xa9, 0x8a, 0x04, 0x24, 0x06, 0x8c, 0x5c,
		0xfb, 0x32, 0x54, 0xbf, 0x49, 0x17, 0xb8, 0x35, 0x33, 0x47, 0xf1, 0x7e, 0xa0, 0x91, 0x0d, 0xa9,
		0xdc, 0xa1, 0x51, 0x72, 0x6c, 0x04, 0x1d, 0x1c, 0x35, 0x47, 0x47, 0xd6, 0xe1, 0x91, 0x75, 0x7c,
		0x34, 0x1d, 0xa0, 0x5a, 0x47, 0xa8, 0xd8, 0x21, 0xd2, 0x89, 0x2e, 0x6c, 0x20, 0x0e, 0x8d, 0xc9,
		0x63, 0x1b, 0x6a, 0xab, 0x4c, 0xc0, 0x16, 0xb5, 0x93, 0xc8, 0xa8, 0x2c, 0x59, 0x12, 0x93, 0xc9,
		0x12, 0x6b, 0xc8, 0x4c, 0x28, 0xbb, 0xb7, 0x88, 0xf0, 0xa4, 0xb2, 0xc4, 0x48, 0x12, 0x13, 0xcb,
		0xd4, 0xbb, 0x00, 0x85, 0x7b, 0x89, 0xcc, 0x21, 0xe5, 0x86, 0x07, 0xa0, 0x71, 0x58, 0x09, 0x99,
		0x02, 0x99, 0x02, 0x99, 0x02, 0x99, 0x02, 0x99, 0x02, 0x99, 0xf2, 0x00, 0xe2, 0x4c, 0x1c, 0x2f,
		0xda, 0x2f, 0x11, 0x52, 0x28, 0x55, 0x02, 0xa6, 0xd0, 0x68, 0x9c, 0xb0, 0xf8, 0xa2, 0x01, 0xc0,
		0x3b, 0xd4, 0x1a, 0x29, 0x10, 0x23, 0x36, 0x1b, 0x66, 0x11, 0x6b, 0xac, 0x90, 0xd8, 0x45, 0xb0,
		0x36, 0x9d, 0x08, 0x3c, 0xaf, 0xcb, 0x4f, 0x2c, 0xf5, 0x17, 0x2e, 0xf5, 0x72, 0xa9, 0x56, 0xae,
		0x1d, 0x54, 0x4b, 0xb5, 0x0a, 0xd6, 0x3c, 0x0f, 0x42, 0x44, 0xc7, 0x8a, 0x3e, 0x42, 0x27, 0xd2,
		0xb7, 0xc5, 0xbc, 0x74, 0x53, 0x61, 0x6f, 0xf8, 0x0d, 0x3e, 0x7a, 0x6f, 0x12, 0xc2, 0x25, 0x08,
		0x97, 0x20, 0x5c, 0x82, 0x70, 0x09, 0xc2, 0x25, 0x08, 0x97, 0x90, 0x41, 0x1c, 0x67, 0x7c, 0x5d,
		0x36, 0xed, 0xe1, 0x30, 0x10, 0x61, 0x48, 0xe9, 0x58, 0xf7, 0x3d, 0x01, 0x5b, 0xa8, 0x74, 0x36,
		0x4f, 0x0c, 0x7a, 0xfb, 0xf6, 0x6c, 0xcf, 0xac, 0xf5, 0xff, 0x3e, 0x2b, 0x9a, 0xb5, 0xfe, 0xec,
		0x63, 0x31, 0xfe, 0x6b, 0xf6, 0xb9, 0x74, 0xb6, 0x67, 0x96, 0x17, 0x9f, 0x2b, 0x67, 0x7b, 0x66,
		0xa5, 0xbf, 0x7b, 0x7e, 0xfe, 0x6e, 0xf7, 0xc7, 0xfe, 0xdd, 0xcb, 0xff, 0xa1, 0x7a, 0xa8, 0xe8,
		0x53, 0x58, 0x02, 0x94, 0x3a, 0xdc, 0x27, 0x56, 0xfd, 0x8f, 0xcc, 0x85, 0xf0, 0x7f, 0x0c, 0x48,
		0xa9, 0x5c, 0x5d, 0x59, 0x55, 0x2e, 0xb0, 0xe2, 0x96, 0x78, 0x89, 0x1d, 0x14, 0x9b, 0x69, 0x3d,
		0xd0, 0x93, 0xa8, 0x70, 0xdf, 0xa3, 0xa2, 0xa0, 0xb2, 0xee, 0x65, 0x87, 0x5c, 0xe3, 0xad, 0x6e,
		0xfc, 0xb0, 0x3e, 0x2e, 0x3d, 0x2b, 0x2b, 0xf9, 0xe6, 0x56, 0x45, 0x3b, 0x3d, 0x75, 0xfb, 0x59,
		0x49, 0x2d, 0xd8, 0xe4, 0x62, 0xba, 0x6e, 0x09, 0x54, 0x83, 0xcd, 0x0d, 0x41, 0x3d, 0x58, 0x5e,
		0x03, 0x2c, 0xa8, 0x07, 0xa3, 0x1f, 0x48, 0x41, 0x3d, 0x18, 0x38, 0x60, 0xf2, 0xe8, 0x95, 0xd7,
		0x83, 0xcd, 0x7c, 0x06, 0x9d, 0xe3, 0x83, 0xb9, 0x3d, 0x34, 0xce, 0x0e, 0x8a, 0x38, 0x3b, 0x20,
		0xe3, 0xda, 0x08, 0xba, 0x38, 0x6a, 0xae, 0x8e, 0xac, 0xcb, 0x23, 0xeb, 0xfa, 0x68, 0xba, 0x40,
		0xf5, 0x81, 0x98, 0x1d, 0x02, 0x67, 0x07, 0xaa, 0x5d, 0xe3, 0xbd, 0x8b, 0x14, 0x97, 0xd3, 0xa5,
		0x61, 0x06, 0xfe, 0x24, 0x72, 0xbc, 0x4b, 0xd3, 0x76, 0x2f, 0xfd, 0xc0, 0x89, 0xbe, 0x5d, 0x85,
		0x74, 0x76, 0x7c, 0xe2, 0x3e, 0x1f, 0xb7, 0xf5, 0x57, 0x52, 0xa3, 0x67, 0x8a, 0x44, 0xcc, 0xa1,
		0xe2, 0x62, 0x29, 0xba, 0x5a, 0xc2, 0x2e, 0x97, 0xaa, 0xeb, 0x25, 0xef, 0x82, 0xc9, 0xbb, 0x62,
		0xda, 0x2e, 0x99, 0x86, 0x6b, 0x26, 0xe2, 0xa2, 0xc9, 0xb9, 0xea, 0x7b, 0x97, 0xad, 0xb4, 0x3d,
		0xd7, 0xd3, 0x5e, 0x5a, 0xf1, 0xf1, 0x05, 0x03, 0xc7, 0x4c, 0xd6, 0x41, 0x53, 0x76, 0xd4, 0x0c,
		0x1c, 0x36, 0x75, 0xc7, 0xcd, 0xc6, 0x81, 0xb3, 0x71, 0xe4, 0x3c, 0x1c, 0x3a, 0x2d, 0xc7, 0x4e,
		0xcc, 0xc1, 0x93, 0x75, 0xf4, 0x89, 0x61, 0x89, 0xce, 0xa5, 0x0b, 0x28, 0x0b, 0x4c, 0xbe, 0x37,
		0x95, 0xe8, 0x3e, 0xa5, 0x59, 0xa3, 0x44, 0x9e, 0x10, 0x70, 0x20, 0x06, 0x8c, 0x08, 0x02, 0x17,
		0xa2, 0xc0, 0x8e, 0x30, 0xb0, 0x23, 0x0e, 0xbc, 0x08, 0x04, 0x4d, 0x22, 0x41, 0x94, 0x50, 0x24,
		0xaf, 0x96, 0x4c, 0xa1, 0xc0, 0x93, 0x88, 0x49, 0xab, 0x2d, 0xdc, 0x93, 0x6a, 0xbe, 0x4c, 0xd8,
		0x46, 0x1a, 0x6d, 0xe4, 0xb8, 0x6d, 0x15, 0x52, 0x6d, 0xe7, 0x1e, 0xb5, 0x92, 0x5c, 0x3b, 0xba,
		0xc7, 0x2d, 0x65, 0xd0, 0xa6, 0xee, 0x51, 0xe3, 0x49, 0xb5, 0xaf, 0xe3, 0xe3, 0x0a, 0xa1, 0xf2,
		0x7f, 0xca, 0xb3, 0x68, 0x14, 0x26, 0x3c, 0x6a, 0x1f, 0xc7, 0x82, 0x85, 0x59, 0x6a, 0xf6, 0xfc,
		0xef, 0xc2, 0xe3, 0xc7, 0xf4, 0x05, 0x8a, 0x67, 0x03, 0x3b, 0xdc, 0x4a, 0x1e, 0x66, 0x4f, 0x7b,
		0xfe, 0xb7, 0x75, 0x3a, 0x7b, 0xda, 0xdd, 0xd9, 0xc3, 0xae, 0x27, 0xcf, 0x5a, 0x65, 0x69, 0x04,
		0x7d, 0x64, 0xc2, 0x11, 0x27, 0x03, 0x4c, 0xd4, 0x1a, 0x0b, 0x29, 0xe5, 0x99, 0xe8, 0x87, 0x7e,
		0x06, 0xfa, 0x16, 0x51, 0x41, 0x98, 0x8d, 0xb4, 0x3d, 0x85, 0x23, 0xc1, 0x9f, 0x0c, 0x80, 0xfc,
		0xc4, 0x56, 0xa4, 0x18, 0x3e, 0x64, 0x0e, 0x52, 0x0c, 0x5f, 0xb0, 0xba, 0x90, 0x62, 0xf8, 0xfc,
		0x65, 0x8e, 0x14, 0xc3, 0x6d, 0x49, 0x1d, 0x52, 0x0c, 0xb9, 0xf0, 0x6f, 0x7a, 0x29, 0x86, 0xc1,
		0xe5, 0x85, 0x39, 0x14, 0xe1, 0x20, 0x70, 0xc6, 0x91, 0x1f, 0x84, 0x84, 0xb3, 0x0d, 0xd7, 0x2d,
		0x45, 0xe2, 0x21, 0x47, 0xb7, 0x4d, 0xd9, 0x7d, 0x33, 0x70, 0xe3, 0xd4, 0xdd, 0x39, 0x1b, 0xb7,
		0xce, 0xc6, 0xbd, 0xf3, 0x70, 0xf3, 0xb4, 0xdc, 0x3d, 0x31, 0xb7, 0x4f, 0xd6, 0xfd, 0x3f, 0x46,
		0x03, 0xe8, 0xa7, 0x1f, 0xae, 0x1b, 0x4c, 0x3b, 0x09, 0xb1, 0x88, 0x24, 0x44, 0xed, 0x48, 0x02,
		0x23, 0xb2, 0xc0, 0x85, 0x34, 0xb0, 0x23, 0x0f, 0xec, 0x48, 0x04, 0x2f, 0x32, 0x41, 0x93, 0x54,
		0x10, 0x25, 0x17, 0xe4, 0x49, 0x46, 0x62, 0x60, 0x30, 0x1f, 0x6b, 0x44, 0x1c, 0x84, 0x92, 0x51,
		0x00, 0xb1, 0xb9, 0xc4, 0xf7, 0x33, 0xed, 0x6a, 0x07, 0x36, 0x84, 0x83, 0x13, 0xf1, 0x60, 0x48,
		0x40, 0xb8, 0x11, 0x11, 0xb6, 0x84, 0x84, 0x2d, 0x31, 0xe1, 0x49, 0x50, 0x68, 0x13, 0x15, 0xe2,
		0x84, 0x25, 0x79, 0xe5, 0xe4, 0xab, 0x27, 0x36, 0x10, 0xd7, 0x15, 0xf6, 0x28, 0x10, 0x23, 0x0e,
		0x88, 0xbb, 0x88, 0x44, 0x54, 0x19, 0xd8, 0x7a, 0x32, 0xcf, 0x03, 0x7b, 0xf7, 0x6e, 0x96, 0x47,
		0x5a, 0x98, 0x51, 0xb0, 0x37, 0xd8, 0xfa, 0x9a, 0x6d, 0x7b, 0xa2, 0x1d, 0x4e, 0x1e, 0xdd, 0xef,
		0x54, 0xb3, 0x9a, 0x1f, 0xdc, 0xe9, 0x90, 0x02, 0x90, 0x02, 0x90, 0x02, 0x90, 0x02, 0x90, 0x02,
		0xe0, 0x03, 0xdc, 0xa4, 0x00, 0xf5, 0x18, 0x66, 0x62, 0xa8, 0x6b, 0x5f, 0x08, 0x97, 0x0f, 0x78,
		0x25, 0xc2, 0x25, 0x36, 0x9b, 0xc9, 0xfe, 0xe7, 0x11, 0xdb, 0x64, 0x47, 0x6c, 0x38, 0x12, 0x1c,
		0xc6, 0x44, 0x87, 0x2b, 0xe1, 0x61, 0x4f, 0x7c, 0xd8, 0x13, 0x20, 0xde, 0x44, 0x88, 0x07, 0x21,
		0x62, 0x42, 0x8c, 0x92, 0xa5, 0xc0, 0x26, 0x56, 0xba, 0x81, 0xd8, 0x57, 0x63, 0x37, 0x34, 0x39,
		0xf1, 0x8f, 0x95, 0xa0, 0x4a, 0x8d, 0x91, 0xcd, 0xf3, 0x35, 0x72, 0xc6, 0x0a, 0xe4, 0x78, 0x39,
		0xc5, 0x95, 0x95, 0x3d, 0x71, 0xbc, 0x68, 0xbf, 0xc4, 0xcc, 0x2b, 0x2e, 0xaf, 0xee, 0x2a, 0x43,
		0xd3, 0xbb, 0xf3, 0x64, 0x92, 0x33, 0x76, 0xa6, 0xf3, 0x5c, 0xed, 0xc9, 0x83, 0x3f, 0x76, 0x3c,
		0x76, 0x1c, 0x96, 0xb9, 0xb4, 0x7c, 0xf4, 0x36, 0xbe, 0xda, 0xee, 0x64, 0xba, 0x09, 0x8a, 0x07,
		0xcc, 0x6f, 0xe4, 0x53, 0x60, 0x0f, 0x22, 0xc7, 0xf7, 0x8e, 0x9c, 0x4b, 0x67, 0xd6, 0x72, 0x8b,
		0xed, 0xfd, 0xdc, 0xfd, 0xca, 0x78, 0x6f, 0xdb, 0x37, 0xd8, 0xdb, 0xd4, 0xf6, 0xf6, 0x5e, 0xf9,
		0x7d, 0xa5, 0x5a, 0xc1, 0x06, 0x87, 0xa0, 0xcd, 0x97, 0xd5, 0xfd, 0x37, 0x80, 0x7d, 0x10, 0xd0,
		0x4d, 0xb9, 0xc5, 0xa3, 0x85, 0xed, 0x93, 0x11, 0x85, 0x32, 0x43, 0xdb, 0x69, 0xb7, 0xbc, 0xe5,
		0x0f, 0x7d, 0x3c, 0x20, 0x8f, 0xfe, 0xf3, 0x64, 0x00, 0xc6, 0x4c, 0xaa, 0x61, 0x36, 0xd0, 0x97,
		0x43, 0x55, 0x0c, 0x53, 0x29, 0x80, 0x13, 0x64, 0x99, 0x0b, 0x19, 0x27, 0xc8, 0xf2, 0xb6, 0x21,
		0x4e, 0x90, 0x15, 0xdf, 0x00, 0x4e, 0x90, 0xc1, 0x39, 0xe6, 0x4b, 0x81, 0xef, 0x09, 0x32, 0xbb,
		0x73, 0x36, 0x86, 0xe7, 0x6b, 0x4c, 0xcf, 0xd5, 0x18, 0x86, 0x33, 0x38, 0x9f, 0xa3, 0x31, 0x8f,
		0xb1, 0x27, 0xb1, 0x75, 0xae, 0xf6, 0x6b, 0x10, 0x4d, 0x67, 0x78, 0x4c, 0xc6, 0xfa, 0x78, 0x4c,
		0x97, 0x2d, 0x5b, 0x2e, 0xd5, 0xca, 0xb5, 0x83, 0x6a, 0xa9, 0x56, 0xc1, 0xde, 0x05, 0x21, 0xd7,
		0xcb, 0x5a, 0x84, 0x7f, 0xf3, 0x60, 0x21, 0xf5, 0x1a, 0x2c, 0xe2, 0xf3, 0xb3, 0x36, 0xec, 0xd5,
		0x6f, 0x86, 0xcc, 0xf2, 0xff, 0xb9, 0xd6, 0xfd, 0x7a, 0xfd, 0x07, 0x05, 0x0e, 0xa5, 0xe9, 0x3b,
		0x3a, 0x8d, 0xa0, 0x59, 0xfe, 0xff, 0x82, 0xcb, 0x8b, 0xa3, 0xfb, 0x77, 0xb3, 0xf6, 0x3d, 0xc5,
		0xf9, 0x5c, 0x7c, 0x90, 0x12, 0xbd, 0xff, 0x5e, 0x44, 0xee, 0xc5, 0x2d, 0xf5, 0xc3, 0x39, 0x4c,
		0x7e, 0x4d, 0x5f, 0x8d, 0x62, 0xf2, 0x6b, 0x2e, 0x77, 0x3b, 0x13, 0x86, 0x96, 0x6f, 0x66, 0x66,
		0x90, 0x6e, 0xbf, 0x94, 0x33, 0x2e, 0x66, 0x60, 0xb2, 0x34, 0x43, 0x8b, 0x30, 0x59, 0x1a, 0x78,
		0xfb, 0x28, 0xde, 0x62, 0xc8, 0xb4, 0x0a, 0x5c, 0xc5, 0xb8, 0x69, 0xf2, 0x50, 0x45, 0xb4, 0xb9,
		0x22, 0xe9, 0x66, 0x8a, 0x98, 0xe2, 0xf6, 0x42, 0xc3, 0x30, 0xc5, 0x6d, 0x2b, 0x13, 0x31, 0xc5,
		0x2d, 0x25, 0x43, 0x31, 0xc5, 0x0d, 0xf4, 0x5f, 0xd6, 0x2b, 0x24, 0x3b, 0xc5, 0x6d, 0xe4, 0xda,
		0x97, 0x21, 0xfd, 0xd9, 0x6d, 0x33, 0x33, 0x69, 0x4f, 0x6c, 0xdb, 0xc3, 0xc4, 0x36, 0xed, 0x08,
		0x01, 0x23, 0x62, 0xc0, 0x85, 0x20, 0xb0, 0x23, 0x0a, 0xec, 0x08, 0x03, 0x2f, 0xe2, 0x40, 0x93,
		0x40, 0x10, 0x25, 0x12, 0xc9, 0xab, 0x25, 0x5f, 0x8a, 0xc1, 0xac, 0xe6, 0x9e, 0x43, 0x6d, 0x3d,
		0xf1, 0x1a, 0xfa, 0x3b, 0x24, 0x0f, 0x6c, 0x61, 0x25, 0x92, 0x07, 0xa4, 0x18, 0xcf, 0x23, 0x79,
		0x00, 0xea, 0x9e, 0x95, 0xba, 0xc7, 0xe1, 0x9e, 0xca, 0xc3, 0x3d, 0xa2, 0x59, 0xac, 0x5a, 0x9e,
		0xe8, 0xd1, 0x4b, 0x4b, 0x25, 0x74, 0x8e, 0xf7, 0x06, 0xd8, 0x48, 0x1e, 0x13, 0xb5, 0xc6, 0x42,
		0x83, 0xd4, 0x49, 0xb2, 0x6e, 0xe8, 0x47, 0x03, 0xf7, 0xd4, 0xa3, 0x0c, 0x01, 0x84, 0x21, 0x96,
		0xa7, 0x40, 0x32, 0x3f, 0x81, 0x58, 0x5e, 0x02, 0xb9, 0x63, 0x08, 0x8a, 0xc7, 0x0e, 0x84, 0x8f,
		0x19, 0xa8, 0x1e, 0x2b, 0x90, 0x3f, 0x46, 0x20, 0x7f, 0x6c, 0x40, 0xfb, 0x98, 0x00, 0xac, 0x7a,
		0xf9, 0x55, 0x51, 0xcb, 0x23, 0x30, 0x22, 0x8a, 0xe7, 0x10, 0x09, 0x8c, 0xc6, 0xd6, 0xd1, 0x4c,
		0x17, 0xdc, 0x43, 0xba, 0x20, 0x5b, 0x37, 0xcd, 0xc0, 0x5d, 0x53, 0x77, 0xdb, 0x6c, 0xdc, 0x37,
		0x1b, 0x37, 0xce, 0xc3, 0x9d, 0xd3, 0x72, 0xeb, 0xc4, 0xdc, 0x7b, 0xf2, 0x0a, 0xc9, 0x9e, 0xee,
		0x27, 0x88, 0xe7, 0x0c, 0x85, 0x17, 0x39, 0xd1, 0x6d, 0x20, 0x46, 0x14, 0x51, 0x6f, 0xa1, 0x7d,
		0x09, 0x1e, 0x45, 0x1a, 0xcd, 0xf9, 0xa3, 0x3b, 0xb4, 0x43, 0x41, 0x3f, 0xf3, 0xb2, 0x79, 0xda,
		0x3c, 0xb5, 0x4e, 0xbf, 0x1c, 0xf6, 0x5a, 0x5f, 0xad, 0xde, 0x9f, 0x27, 0x0d, 0xaa, 0xf0, 0x1c,
		0x37, 0xf9, 0x0a, 0x49, 0x77, 0x9f, 0x24, 0x9e, 0x8f, 0x77, 0xff, 0xc6, 0xad, 0x6e, 0xa3, 0xfe,
		0xf1, 0xf7, 0xfa, 0x61, 0xb3, 0xd5, 0xec, 0xfd, 0x39, 0x7f, 0xf9, 0xa7, 0x94, 0xdf, 0x3e, 0xa7,
		0x55, 0xc0, 0x63, 0x35, 0x3c, 0xb9, 0x2a, 0x0e, 0xeb, 0xed, 0xa3, 0x7f, 0x37, 0x8f, 0x7a, 0xbf,
		0x5b, 0x1f, 0x3b, 0xed, 0xd3, 0x5e, 0xb7, 0xde, 0x6c, 0xf7, 0x4e, 0x0d, 0x8c, 0x77, 0xc8, 0xfd,
		0xc2, 0xf8, 0xd2, 0x6b, 0xb6, 0x9a, 0xff, 0xaf, 0x71, 0x74, 0xbf, 0x42, 0xb0, 0x2a, 0xb0, 0x2a,
		0xea, 0x47, 0xff, 0xd7, 0x3a, 0x6d, 0x1e, 0x61, 0x29, 0x60, 0x29, 0xd4, 0xbf, 0xd6, 0x9b, 0xad,
		0xfa, 0x61, 0xab, 0x01, 0x84, 0xc0, 0xb2, 0xb8, 0x5f, 0x16, 0xcd, 0x93, 0xaf, 0x07, 0x56, 0xbb,
		0xd1, 0xfc, 0xfc, 0xfb, 0x61, 0xa7, 0x6b, 0xd5, 0x8f, 0x8e, 0xba, 0x8d, 0x53, 0x10, 0x0a, 0x2c,
		0x0c, 0xeb, 0x4b, 0x3b, 0x61, 0x98, 0x8d, 0x23, 0xab, 0x75, 0x7a, 0x82, 0x45, 0x81, 0x45, 0xd1,
		0x6a, 0xb6, 0xff, 0x65, 0xd5, 0x7b, 0xbd, 0x6e, 0xf3, 0xf0, 0x4b, 0xaf, 0x01, 0x9c, 0xc0, 0x92,
		0x98, 0x2d, 0x89, 0x93, 0x6e, 0xa7, 0xd7, 0xf8, 0xd8, 0x6b, 0x76, 0xda, 0xb3, 0x78, 0x05, 0xd6,
		0x05, 0xf8, 0xe6, 0xd1, 0x71, 0xb3, 0x6d, 0x7d, 0xee, 0x76, 0xbe, 0xc0, 0x73, 0x60, 0x39, 0xcc,
		0x78, 0x66, 0xb3, 0xdd, 0x6b, 0x74, 0x3f, 0xd5, 0x3f, 0x36, 0x40, 0x34, 0xb1, 0x32, 0x16, 0x2b,
		0xe3, 0xb8, 0xfe, 0xc7, 0xcc, 0x89, 0x40, 0x97, 0x62, 0x55, 0xac, 0x44, 0xae, 0x5a, 0xf5, 0x36,
		0xa2, 0x57, 0x58, 0x0e, 0x09, 0xcb, 0xc4, 0x52, 0xc0, 0x52, 0x88, 0x99, 0x44, 0x19, 0x11, 0x2b,
		0x2c, 0x8c, 0x87, 0x17, 0x06, 0x28, 0x26, 0x56, 0xc6, 0x83, 0x14, 0xb3, 0xdb, 0x38, 0x6d, 0x74,
		0xbf, 0xe2, 0x00, 0x04, 0x6b, 0x63, 0x75, 0x6d, 0xf4, 0x1a, 0xd6, 0x51, 0xe3, 0x53, 0xfd, 0x4b,
		0xab, 0x67, 0x1d, 0x37, 0x7a, 0xdd, 0xe6, 0x47, 0x2c, 0x0a, 0x2c, 0x8a, 0x2f, 0xed, 0x19, 0x5c,
		0x20, 0x9f, 0x02, 0xeb, 0x62, 0x43, 0x86, 0x1c, 0x35, 0x5a, 0xf5, 0x3f, 0xad, 0xaf, 0xf5, 0x6e,
		0xb3, 0xde, 0x6b, 0x76, 0xda, 0x58, 0x17, 0x58, 0x17, 0x8d, 0x3f, 0x7a, 0x8d, 0xf6, 0x51, 0xe3,
		0x08, 0x51, 0x6f, 0xac, 0x8b, 0x15, 0xe2, 0xd9, 0x6c, 0xdf, 0xc7, 0x37, 0x63, 0xdc, 0xc0, 0xaa,
		0xc0, 0xaa, 0x88, 0x57, 0x43, 0xab, 0x03, 0x6d, 0x8a, 0xc5, 0xf0, 0x27, 0xa0, 0x01, 0xab, 0x61,
		0x69, 0x35, 0x74, 0x1b, 0xa7, 0xcd, 0xa3, 0x2f, 0xf5, 0x16, 0x2b, 0xd9, 0x41, 0xda, 0x42, 0xba,
		0x23, 0xda, 0x09, 0xef, 0x26, 0xa6, 0x35, 0x53, 0xcc, 0xaa, 0x63, 0xb0, 0x00, 0x52, 0x8f, 0xdb,
		0x30, 0xaa, 0x82, 0xc1, 0xdb, 0x4f, 0xfb, 0xed, 0x93, 0xaf, 0x76, 0xc1, 0x2b, 0x4f, 0xfd, 0x95,
		0x73, 0xaa, 0x6a, 0xc1, 0xeb, 0x4f, 0xfb, 0xf5, 0x33, 0xab, 0x5e, 0xc1, 0x02, 0x48, 0xdd, 0xe1,
		0xf3, 0xa9, 0x52, 0xc1, 0xcb, 0xcf, 0x24, 0x74, 0xc2, 0xa1, 0x1a, 0x05, 0xaf, 0x3e, 0x93, 0x57,
		0xcf, 0xa6, 0xea, 0x04, 0xef, 0x3f, 0x7d, 0xaa, 0xcf, 0xe0, 0x9c, 0x0d, 0xaf, 0x3d, 0x13, 0xbe,
		0xc7, 0x28, 0xc5, 0x0f, 0x2b, 0x20, 0xed, 0x15, 0xc0, 0xa9, 0x5a, 0x04, 0x6f, 0x3f, 0x8b, 0x08,
		0x0f, 0xf9, 0xaa, 0x10, 0xbc, 0xf6, 0x4c, 0xd8, 0x1e, 0x5e, 0x79, 0xce, 0x3c, 0x7d, 0x19, 0x91,
		0x9d, 0xbc, 0x2f, 0x00, 0x50, 0xbd, 0x9c, 0x53, 0x3d, 0x5e, 0x55, 0x1b, 0x58, 0x03, 0x69, 0xaf,
		0x01, 0x46, 0xd5, 0x19, 0x78, 0xf9, 0x69, 0xbf, 0x7c, 0x5e, 0x55, 0x18, 0x78, 0xff, 0x99, 0xd0,
		0x7e, 0x36, 0xd5, 0x16, 0x78, 0xff, 0x69, 0xbf, 0x7f, 0x5e, 0x55, 0x15, 0x78, 0xff, 0xa9, 0x13,
		0x40, 0x46, 0xd5, 0x13, 0x78, 0xfb, 0x99, 0xa0, 0x3f, 0xed, 0x2a, 0x09, 0xbc, 0xf4, 0xec, 0x5c,
		0x3e, 0xde, 0x7a, 0x7e, 0xde, 0x3a, 0xa7, 0xaa, 0x07, 0xbc, 0xfd, 0xad, 0xdf, 0xfe, 0x09, 0x26,
		0x9d, 0xe4, 0x7e, 0x35, 0x3c, 0xb9, 0x2a, 0x7a, 0xf5, 0xcf, 0x07, 0x65, 0x94, 0xc4, 0x61, 0x21,
		0x9c, 0x74, 0x1b, 0x9f, 0x9a, 0x7f, 0xa0, 0x11, 0x20, 0x56, 0x43, 0x92, 0x01, 0xd4, 0xed, 0x7c,
		0xe9, 0x35, 0xba, 0xe8, 0x07, 0x88, 0x15, 0x31, 0x73, 0x14, 0x58, 0x06, 0x58, 0x06, 0x73, 0x37,
		0xf1, 0xa9, 0x55, 0xff, 0x8c, 0xbe, 0x0a, 0x58, 0x0f, 0xb3, 0xfc, 0x01, 0x4e, 0x8e, 0x02, 0x55,
		0xf4, 0xd0, 0xe3, 0x50, 0x5e, 0x78, 0xe1, 0x50, 0x58, 0x78, 0xeb, 0x50, 0x52, 0x78, 0xf3, 0x39,
		0x55, 0x4c, 0x78, 0xdd, 0xf9, 0x54, 0x46, 0x78, 0xef, 0x79, 0x55, 0x40, 0x78, 0xf3, 0xdb, 0xbe,
		0xf9, 0xf9, 0x4b, 0xfe, 0x58, 0x3f, 0xc1, 0x99, 0x1a, 0x62, 0x22, 0x3f, 0x5d, 0x17, 0x5d, 0xab,
		0xde, 0xfa, 0xdc, 0xe9, 0x36, 0x7b, 0xbf, 0x1f, 0x23, 0x4a, 0x86, 0x15, 0x11, 0xaf, 0x88, 0xfb,
		0xef, 0x10, 0x26, 0xdb, 0xee, 0x0b, 0x61, 0xb2, 0x5c, 0x39, 0x59, 0x16, 0x60, 0x8a, 0x37, 0x9f,
		0x5b, 0xd0, 0xa4, 0x09, 0x96, 0xf4, 0x40, 0x92, 0xd6, 0x73, 0xa2, 0x63, 0x0d, 0x0d, 0x4b, 0x88,
		0x00, 0x98, 0x51, 0xf7, 0x3c, 0x3f, 0xb2, 0x23, 0xc7, 0xf7, 0x8c, 0x0f, 0x84, 0xa0, 0xcb, 0x08,
		0x07, 0xdf, 0xc4, 0x95, 0x3d, 0xb6, 0xa3, 0x6f, 0x53, 0xb0, 0x2a, 0xf8, 0x63, 0xe1, 0x0d, 0x7c,
		0x6f, 0xe4, 0x5c, 0x9a, 0x9e, 0x88, 0xfe, 0xf2, 0x83, 0xef, 0xa6, 0xe3, 0x85, 0x91, 0xed, 0x0d,
		0x44, 0x61, 0xfd, 0x07, 0xe1, 0xc6, 0x4f, 0x0a, 0xe3, 0xc0, 0x8f, 0xfc, 0x81, 0xef, 0x86, 0xc9,
		0xa7, 0x82, 0x13, 0x3a, 0x61, 0xc1, 0x15, 0xd7, 0xc2, 0x9d, 0xff, 0x55, 0x70, 0x1d, 0xef, 0xbb,
		0x19, 0x46, 0x76, 0x24, 0xcc, 0xa1, 0x1d, 0xd9, 0x17, 0x76, 0x28, 0x0a, 0x6e, 0x38, 0x2e, 0x44,
		0xee, 0x75, 0x38, 0xfd, 0xa3, 0x10, 0xf8, 0x93, 0x48, 0x04, 0xe6, 0xc0, 0x1e, 0xdb, 0x17, 0x8e,
		0xeb, 0x44, 0x8e, 0x08, 0x0b, 0xc9, 0x37, 0xb7, 0x85, 0x70, 0x72, 0x11, 0xff, 0xaf, 0xb3, 0xbf,
		0x0b, 0xf1, 0x6f, 0x22, 0x24, 0x53, 0x8d, 0x30, 0x0a, 0x26, 0x83, 0xc8, 0x9b, 0xe3, 0x7f, 0x27,
		0x79, 0xa2, 0xed, 0xd9, 0xd3, 0x6a, 0xce, 0x1f, 0x96, 0xb5, 0xf6, 0x7d, 0xb8, 0xfe, 0x03, 0xeb,
		0x64, 0xf1, 0x34, 0x93, 0x4f, 0x56, 0x33, 0x74, 0x42, 0xab, 0x15, 0x3f, 0xcd, 0xd9, 0x5f, 0x56,
		0xcb, 0xf1, 0xbe, 0x9f, 0x4e, 0x1f, 0xc1, 0xd1, 0xfc, 0x59, 0x5a, 0xad, 0x70, 0x6c, 0xf5, 0xdc,
		0xeb, 0x70, 0xfa, 0x87, 0xd5, 0x8d, 0x9f, 0xe5, 0xc7, 0xa5, 0x47, 0x69, 0x25, 0xdf, 0xdc, 0x5a,
		0xa7, 0xb3, 0x47, 0x39, 0xff, 0xdb, 0x8a, 0x7f, 0x0f, 0x0d, 0x8f, 0xa4, 0x1e, 0x3d, 0x08, 0x20,
		0x87, 0x11, 0xdd, 0x8e, 0x05, 0x19, 0xbc, 0x48, 0x28, 0x4d, 0x6c, 0x15, 0x11, 0x5c, 0xfd, 0x97,
		0xe3, 0x0d, 0x8d, 0x0f, 0x3b, 0x7b, 0x44, 0xcc, 0xf9, 0x18, 0xef, 0x74, 0x42, 0x06, 0x9d, 0x04,
		0x62, 0xe4, 0xdc, 0xd0, 0xf2, 0x39, 0x8b, 0x75, 0xe4, 0x0f, 0xcc, 0xa9, 0x77, 0xa0, 0x84, 0xdd,
		0xa7, 0xfe, 0x24, 0x18, 0x08, 0x52, 0x8f, 0x6b, 0xb6, 0xcc, 0xc5, 0xed, 0x5f, 0x7e, 0x30, 0x5d,
		0xe9, 0xc6, 0x78, 0xf6, 0x46, 0x69, 0x09, 0x33, 0xe3, 0x77, 0x3b, 0xac, 0x07, 0x97, 0x93, 0x2b,
		0xe1, 0x45, 0xc6, 0x87, 0x9d, 0x28, 0x98, 0x08, 0x62, 0x06, 0x2e, 0x59, 0x97, 0x2c, 0x3c, 0x70,
		0x65, 0x92, 0x5c, 0xb9, 0x47, 0xc9, 0xeb, 0xad, 0x20, 0x96, 0x2b, 0xec, 0x51, 0x20, 0x46, 0x94,
		0x10, 0x6b, 0xee, 0x00, 0x8b, 0x55, 0x42, 0x36, 0x9d, 0xcc, 0xe5, 0xc4, 0xbb, 0x77, 0x33, 0x76,
		0x5e, 0x88, 0x19, 0x03, 0x78, 0x25, 0x01, 0x0b, 0x14, 0xef, 0xf1, 0xa9, 0x23, 0x23, 0x42, 0x21,
		0x8d, 0x96, 0x13, 0x46, 0xf5, 0x28, 0x0a, 0x48, 0x40, 0x8d, 0x71, 0xec, 0x78, 0x0d, 0x57, 0x4c,
		0x3d, 0x54, 0x48, 0x83, 0x3e, 0x1a, 0xc7, 0xf6, 0xcd, 0x92, 0x45, 0xc5, 0xf7, 0xe5, 0xf2, 0x41,
		0xb5, 0x5c, 0xde, 0xab, 0xee, 0x57, 0xf7, 0x6a, 0x95, 0x4a, 0xf1, 0xa0, 0x58, 0x21, 0x60, 0x64,
		0x27, 0x18, 0x8a, 0x40, 0x0c, 0x0f, 0xa7, 0xab, 0xca, 0x9b, 0xb8, 0x6e, 0xae, 0x37, 0x17, 0xb1,
		0x20, 0x13, 0xff, 0xe0, 0x12, 0x01, 0x47, 0xcf, 0x37, 0x9c, 0xa4, 0xd6, 0xe1, 0xab, 0x73, 0xb3,
		0x6a, 0xae, 0xac, 0x08, 0x7b, 0xa8, 0x60, 0x0e, 0x63, 0xac, 0x51, 0x08, 0x32, 0x0c, 0xc1, 0x45,
		0x0d, 0xaa, 0xc8, 0xdf, 0xd3, 0x0a, 0xf6, 0xb3, 0x31, 0xf1, 0x86, 0x62, 0xe4, 0x78, 0x62, 0x68,
		0x2e, 0x96, 0xa6, 0xaa, 0x2d, 0x9d, 0x28, 0xee, 0x4d, 0x93, 0x14, 0xe1, 0xdc, 0x42, 0x67, 0x2b,
		0xba, 0xbc, 0xea, 0xc0, 0x32, 0x85, 0x40, 0x32, 0xa1, 0xc0, 0x31, 0x95, 0x40, 0x31, 0xb9, 0xc0,
		0x30, 0xb9, 0x40, 0x30, 0xad, 0xc0, 0x6f, 0xbe, 0xb8, 0xe1, 0x91, 0xa3, 0x36, 0xb8, 0xb2, 0xe1,
		0x3d, 0xd4, 0xef, 0xd7, 0xc7, 0xfc, 0x9a, 0xea, 0x6d, 0xab, 0xd6, 0xbd, 0x91, 0x71, 0x73, 0x94,
		0xdc, 0x1d, 0x41, 0xb7, 0x47, 0xcd, 0xfd, 0x91, 0x75, 0x83, 0x64, 0xdd, 0x21, 0x4d, 0xb7, 0xa8,
		0x3e, 0x68, 0xb3, 0x43, 0x20, 0x7c, 0xab, 0xda, 0x5d, 0x2e, 0x45, 0x05, 0xec, 0x88, 0x60, 0xde,
		0x11, 0xa5, 0x4c, 0x3f, 0x22, 0x0e, 0x93, 0x9c, 0xe3, 0xa4, 0xe8, 0x40, 0x09, 0x3b, 0x52, 0xaa,
		0x0e, 0x95, 0xbc, 0x63, 0x25, 0xef, 0x60, 0x69, 0x3b, 0x5a, 0x1a, 0x0e, 0x97, 0x88, 0xe3, 0x25,
		0xe7, 0x80, 0x13, 0x83, 0x5c, 0xe1, 0x5d, 0xc6, 0x07, 0x1a, 0xc4, 0x50, 0xe1, 0x3e, 0x1f, 0x2a,
		0xb6, 0x8f, 0xd8, 0x8e, 0xa3, 0x95, 0x13, 0x4c, 0xd6, 0x45, 0x53, 0x76, 0xd5, 0x0c, 0x5c, 0x36,
		0x75, 0xd7, 0xcd, 0xc6, 0x85, 0xb3, 0x71, 0xe5, 0x3c, 0x5c, 0x3a, 0x2d, 0xd7, 0x4e, 0xcc, 0xc5,
		0x27, 0xaf, 0x90, 0x5c, 0x8e, 0xf1, 0x06, 0xe2, 0x4d, 0x1c, 0x2f, 0x7a, 0x4f, 0x11, 0xef, 0xe6,
		0xee, 0xb5, 0x42, 0xd0, 0xb4, 0xae, 0xed, 0x5d, 0x0a, 0xb2, 0xcd, 0x60, 0xe8, 0x56, 0xac, 0x1b,
		0xc7, 0x8e, 0x47, 0xd6, 0x81, 0x11, 0xe7, 0x75, 0x1b, 0x66, 0xc6, 0x2d, 0x89, 0x18, 0xd8, 0xf9,
		0x29, 0xb0, 0x07, 0x91, 0xe3, 0x7b, 0x47, 0xce, 0xa5, 0x33, 0x4b, 0x3a, 0x46, 0x1b, 0x8a, 0xd7,
		0x6c, 0x1d, 0xfb, 0x06, 0x5b, 0x27, 0xe5, 0xad, 0x53, 0xaa, 0x54, 0xb0, 0x79, 0xf4, 0x24, 0x82,
		0x74, 0xad, 0xea, 0xa3, 0x91, 0x07, 0x75, 0xf0, 0xa5, 0x55, 0x10, 0xbf, 0x41, 0xd9, 0x09, 0x15,
		0xc6, 0x13, 0x47, 0x7e, 0x04, 0xc3, 0xb6, 0x59, 0x67, 0x08, 0x86, 0xbd, 0x7e, 0x3b, 0x20, 0x18,
		0x96, 0xb2, 0xa1, 0x08, 0x86, 0x71, 0x97, 0x33, 0x08, 0x86, 0x6d, 0xed, 0x5e, 0x11, 0x0c, 0x7b,
		0xe9, 0x17, 0x82, 0x61, 0xb9, 0x52, 0xf4, 0x08, 0x86, 0xe9, 0xea, 0x3d, 0x56, 0xb7, 0x0e, 0x82,
		0x61, 0xa9, 0x6f, 0x1d, 0x04, 0xc3, 0xb4, 0x25, 0x82, 0x74, 0xad, 0x42, 0x30, 0x8c, 0x3c, 0xf8,
		0x1a, 0xd7, 0x73, 0x80, 0x20, 0x1a, 0x0d, 0x9b, 0x99, 0x87, 0x70, 0xd8, 0x73, 0xcc, 0x42, 0x38,
		0x6c, 0x8b, 0x85, 0x86, 0x70, 0xd8, 0xeb, 0xb7, 0x03, 0xc2, 0x61, 0x29, 0x1b, 0x8a, 0x70, 0x18,
		0x77, 0x41, 0xc3, 0x20, 0x1c, 0x76, 0xe1, 0x78, 0x76, 0x70, 0x4b, 0x38, 0x1e, 0x56, 0x03, 0x7d,
		0x24, 0x6c, 0x09, 0x86, 0x22, 0xfc, 0xdc, 0x2e, 0x86, 0xbd, 0xa4, 0x36, 0xfa, 0xe4, 0x6c, 0xfc,
		0x04, 0x83, 0x12, 0xb6, 0x68, 0x3e, 0xf5, 0x65, 0xf1, 0x30, 0x17, 0x2d, 0xee, 0xd6, 0x7e, 0x80,
		0xd1, 0x09, 0xc4, 0xf0, 0x05, 0xa3, 0x13, 0x98, 0x49, 0x61, 0x54, 0x30, 0xf3, 0x96, 0xbc, 0xa8,
		0x60, 0xd6, 0x55, 0xda, 0xa2, 0x82, 0x99, 0x0f, 0xa3, 0xc6, 0xe8, 0x84, 0x97, 0x3b, 0x40, 0x8c,
		0x4e, 0x60, 0xc3, 0x2b, 0x31, 0x3a, 0x01, 0xa3, 0x13, 0x36, 0xad, 0xc1, 0xe8, 0x84, 0x57, 0x19,
		0x89, 0xd1, 0x09, 0x74, 0x43, 0x51, 0x7a, 0x86, 0xa0, 0x30, 0x4e, 0x21, 0xd5, 0xa0, 0x13, 0x06,
		0x2c, 0xe4, 0x00, 0xa1, 0x30, 0x60, 0x21, 0x45, 0x44, 0xc2, 0xa8, 0x85, 0x57, 0x01, 0x4f, 0x6e,
		0x66, 0x2e, 0xbc, 0xd1, 0x18, 0x50, 0x16, 0xfa, 0x61, 0xb1, 0x05, 0x4d, 0x6f, 0x72, 0x75, 0x21,
		0x02, 0xc9, 0x5b, 0x42, 0xad, 0x74, 0x50, 0x2f, 0x15, 0x48, 0x4a, 0x03, 0xb5, 0x52, 0x40, 0xf6,
		0x3e, 0x50, 0xec, 0x50, 0x19, 0x3a, 0x52, 0x05, 0x6e, 0x93, 0x91, 0xbb, 0x94, 0xeb, 0x1d, 0xe5,
		0xf9, 0x28, 0x39, 0x57, 0x92, 0xb4, 0xfb, 0x55, 0xed, 0x7a, 0x2e, 0xbb, 0x5d, 0xe2, 0x16, 0xa7,
		0xbe, 0xb5, 0xe5, 0xec, 0xe7, 0xec, 0x77, 0x97, 0x84, 0x9d, 0x25, 0xb9, 0x53, 0xbc, 0x92, 0x4e,
		0xf0, 0x92, 0x3b, 0xbd, 0xdf, 0xe7, 0x41, 0x94, 0x24, 0x5d, 0x50, 0x41, 0x9e, 0x83, 0xc2, 0x3c,
		0x06, 0x55, 0x79, 0x0a, 0xca, 0xf3, 0x10, 0x94, 0xe7, 0x19, 0xa8, 0xcd, 0x23, 0xd0, 0x8b, 0xcd,
		0xc8, 0xee, 0x54, 0xae, 0x26, 0x9d, 0x4e, 0x65, 0xda, 0x9c, 0xa2, 0xf4, 0x38, 0x65, 0x69, 0x70,
		0x2a, 0xd3, 0xdd, 0x08, 0xa4, 0xb5, 0xa9, 0x4e, 0x5f, 0x23, 0x93, 0xa6, 0x46, 0x26, 0x1d, 0x8d,
		0x46, 0xda, 0x99, 0xde, 0x21, 0x61, 0x65, 0xe9, 0x62, 0xc9, 0x8e, 0x77, 0x86, 0xc2, 0x8b, 0x9c,
		0xe8, 0x56, 0x4d, 0x6a, 0x58, 0xc2, 0xed, 0x55, 0x04, 0x5d, 0x9b, 0xf3, 0x5b, 0x3f, 0xb4, 0x43,
		0xa1, 0x7e, 0xd0, 0x72, 0xf3, 0xb4, 0x79, 0x6a, 0xf5, 0x5a, 0x5f, 0xad, 0xde, 0x9f, 0x27, 0x0d,
		0x55, 0xd8, 0x13, 0xb7, 0xbc, 0x08, 0x95, 0xf6, 0x2c, 0x22, 0x32, 0x1f, 0xf4, 0xb8, 0x67, 0x35,
		0x4f, 0xbe, 0x96, 0xad, 0x6e, 0xa3, 0xfe, 0xf1, 0xf7, 0xfa, 0x61, 0xb3, 0xd5, 0xec, 0xfd, 0xa9,
		0x70, 0x6c, 0xed, 0xaf, 0x79, 0x7f, 0x1f, 0xcd, 0xe6, 0xa9, 0xd5, 0x6e, 0x34, 0x3f, 0xff, 0x7e,
		0xd8, 0xe9, 0x9e, 0xe2, 0x45, 0xa8, 0x7b, 0x11, 0x8d, 0x3f, 0x7a, 0x8d, 0xf6, 0x51, 0xe3, 0xc8,
		0x6a, 0x9e, 0x62, 0x73, 0x50, 0xd9, 0x1c, 0x27, 0x5f, 0x0f, 0xac, 0x66, 0xbb, 0xd7, 0xe8, 0x7e,
		0xaa, 0x7f, 0x6c, 0x58, 0xf5, 0xa3, 0xa3, 0x6e, 0xe3, 0xf4, 0xb4, 0x81, 0x7d, 0xa2, 0xf0, 0x9d,
		0xd4, 0xbf, 0xf4, 0x7e, 0x6f, 0xb4, 0x7b, 0xcd, 0x8f, 0xf5, 0x5e, 0xb3, 0xd3, 0xc6, 0x9b, 0x50,
		0xb8, 0x3b, 0xda, 0xa7, 0xbd, 0x7a, 0xfb, 0x63, 0xc3, 0x6a, 0x1e, 0xe1, 0x35, 0x50, 0x70, 0x1c,
		0xe0, 0x55, 0xc4, 0x5c, 0x47, 0xaf, 0x61, 0x75, 0x3b, 0x5f, 0x7a, 0x8d, 0x2e, 0xb6, 0x88, 0x7a,
		0x0d, 0x58, 0x6f, 0x35, 0xeb, 0xa7, 0x78, 0x11, 0x4a, 0x5f, 0x44, 0xbb, 0x75, 0x82, 0x17, 0xa0,
		0x18, 0x96, 0xca, 0xd6, 0xd4, 0x63, 0x74, 0xdb, 0xf5, 0x16, 0x9c, 0x05, 0x91, 0xb7, 0x72, 0xf2,
		0xa5, 0xfb, 0xb9, 0x61, 0x75, 0x9a, 0x78, 0x07, 0x8a, 0x1d, 0x36, 0x36, 0x04, 0x8d, 0x97, 0xd1,
		0x3a, 0x3d, 0xb1, 0x0e, 0xbf, 0x7c, 0xfa, 0xd4, 0xe8, 0x5a, 0xa7, 0xcd, 0xff, 0xd7, 0xc0, 0xab,
		0x50, 0xf7, 0x2a, 0x8e, 0xbf, 0xb4, 0x7a, 0x4d, 0xab, 0xd7, 0x39, 0xe9, 0xb4, 0x3a, 0x9f, 0xb1,
		0x29, 0x14, 0xbe, 0x89, 0xb9, 0x94, 0xf8, 0x58, 0x3f, 0x01, 0x42, 0x29, 0x7f, 0x19, 0xf5, 0x6e,
		0xa3, 0x8e, 0x80, 0x20, 0x19, 0x4a, 0x7b, 0xda, 0x6d, 0x7d, 0xc6, 0x4b, 0x50, 0xe8, 0x25, 0x7a,
		0x56, 0xf3, 0x14, 0xd1, 0x58, 0xd5, 0xdb, 0x00, 0x01, 0x27, 0x42, 0x2f, 0x23, 0x3e, 0x38, 0x82,
		0xcc, 0xa6, 0x96, 0x7b, 0x00, 0x95, 0x47, 0xe5, 0x7d, 0x1c, 0xfd, 0xd9, 0xae, 0x1f, 0x37, 0x3f,
		0x5a, 0xed, 0xfa, 0x31, 0x24, 0x9e, 0x4a, 0xb4, 0xba, 0x4f, 0x01, 0xb1, 0xea, 0xbd, 0x5e, 0xb7,
		0x79, 0xf8, 0xa5, 0x87, 0x17, 0xa2, 0x9a, 0x4d, 0xe1, 0x9d, 0x10, 0x75, 0xe9, 0xc8, 0x05, 0x21,
		0x15, 0xb3, 0x55, 0x2c, 0xfd, 0x94, 0x5c, 0xb9, 0xaf, 0x7b, 0xbe, 0x38, 0xca, 0xa7, 0x5e, 0xb5,
		0x31, 0x50, 0x0c, 0x7e, 0x5f, 0x0c, 0x2e, 0x7b, 0x2c, 0x00, 0xad, 0xf2, 0x6f, 0x89, 0x7d, 0xfb,
		0xf5, 0xa8, 0xf8, 0x96, 0x5a, 0x08, 0xa8, 0xa2, 0x00, 0x50, 0x72, 0xe1, 0x9f, 0xf4, 0x82, 0x3f,
		0xd4, 0x7b, 0xcb, 0xb9, 0x2e, 0xea, 0xbd, 0x51, 0xef, 0x9d, 0xda, 0xa3, 0x94, 0x5e, 0xa8, 0xa7,
		0xb0, 0x6f, 0xbb, 0x8a, 0xbe, 0xec, 0x2a, 0xfb, 0xae, 0x4b, 0xe0, 0x05, 0x6f, 0x18, 0xef, 0x01,
		0x89, 0x7d, 0xcf, 0xe5, 0x36, 0x27, 0x94, 0xdf, 0x8c, 0x90, 0x44, 0xf3, 0x41, 0xb9, 0xcd, 0x06,
		0xb3, 0x5e, 0x9c, 0x92, 0x95, 0x24, 0x45, 0x05, 0x69, 0x48, 0xe9, 0x33, 0x45, 0x47, 0x33, 0x66,
		0xeb, 0x15, 0xb2, 0xc3, 0xea, 0x6c, 0x7e, 0x73, 0x46, 0x1b, 0x4c, 0xd6, 0xc6, 0xa2, 0xb6, 0xa1,
		0x32, 0xdc, 0x4c, 0x64, 0x36, 0x51, 0x36, 0x1b, 0x28, 0xfd, 0xe5, 0x9d, 0xc1, 0xd2, 0x36, 0xee,
		0x5b, 0x92, 0xc7, 0x6f, 0x3b, 0xab, 0xa5, 0x9d, 0xd0, 0xf7, 0xb5, 0xeb, 0x65, 0xb4, 0x59, 0xb3,
		0x6d, 0x91, 0x97, 0x79, 0x88, 0x44, 0x46, 0x48, 0x44, 0x62, 0x08, 0x44, 0x56, 0xc8, 0x43, 0x7a,
		0x88, 0x43, 0x7a, 0x48, 0x43, 0x6e, 0x08, 0x83, 0x97, 0x83, 0xce, 0xba, 0x05, 0xdd, 0x2a, 0x74,
		0x65, 0xbf, 0x98, 0x1f, 0x44, 0xcc, 0xac, 0x17, 0xb4, 0x9c, 0xde, 0xa2, 0xd2, 0x62, 0xcc, 0x32,
		0x63, 0xcb, 0x0a, 0x62, 0xca, 0xb2, 0x63, 0xc9, 0xca, 0x62, 0xc8, 0xca, 0x62, 0xc7, 0x6a, 0x62,
		0xc6, 0xbc, 0xe3, 0x63, 0xb2, 0x7a, 0x81, 0xa2, 0xd9, 0x33, 0x5f, 0x60, 0x56, 0x01, 0xd0, 0x0a,
		0x81, 0x5a, 0x15, 0x60, 0x2b, 0x07, 0x6e, 0xe5, 0x00, 0xae, 0x16, 0xc8, 0xe5, 0x00, 0xba, 0x24,
		0x60, 0x97, 0x0e, 0xf0, 0xc9, 0x05, 0x5d, 0xe1, 0x5d, 0xc6, 0xf1, 0x30, 0x45, 0xed, 0x9e, 0xe7,
		0xd7, 0x47, 0xc3, 0x67, 0xdd, 0x5c, 0x01, 0x01, 0x97, 0xa0, 0xda, 0x35, 0x90, 0x71, 0x11, 0x64,
		0x5c, 0x05, 0x0d, 0x97, 0x21, 0xd7, 0x75, 0x48, 0x76, 0x21, 0xc9, 0x23, 0x56, 0xdf, 0xf0, 0x79,
		0xe2, 0x78, 0xd1, 0x7b, 0x85, 0xad, 0x9e, 0x55, 0x74, 0x7a, 0xee, 0xda, 0xde, 0xa5, 0x50, 0xd6,
		0xd5, 0x58, 0xe1, 0xcc, 0xd8, 0x63, 0x47, 0xfd, 0x38, 0x6d, 0x45, 0x7e, 0x7d, 0xc3, 0x8c, 0xb8,
		0xb7, 0x35, 0x01, 0x3b, 0x3e, 0x05, 0xf6, 0x20, 0x72, 0x7c, 0xef, 0xc8, 0xb9, 0x74, 0x66, 0x89,
		0x27, 0x79, 0xac, 0xcc, 0x31, 0x8e, 0xed, 0x1b, 0x2c, 0xcd, 0xb5, 0xa5, 0x59, 0xaa, 0x54, 0xb0,
		0x38, 0xd5, 0x10, 0x01, 0x75, 0x57, 0xed, 0xeb, 0x5a, 0xb1, 0xf4, 0x2b, 0xa6, 0x23, 0x41, 0x2c,
		0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c,
		0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x43, 0x2c, 0x2b, 0x13, 0xcb, 0xd7, 0xf3, 0x0d,
		0xa4, 0x48, 0x2d, 0xcf, 0x2e, 0x0f, 0xb9, 0x0c, 0xb9, 0x0c, 0xb9, 0x0c, 0xb9, 0x0c, 0xb9, 0xac,
		0x91, 0x5c, 0xbe, 0x70, 0x3c, 0x3b, 0xb8, 0x55, 0xa8, 0x97, 0x6b, 0xe8, 0xfe, 0x45, 0x7f, 0xc1,
		0xa2, 0xfb, 0xd7, 0xb8, 0xb0, 0x5a, 0x16, 0xb8, 0xfa, 0x6d, 0x3e, 0x3b, 0x82, 0x7d, 0x59, 0x3c,
		0x82, 0xb8, 0xcc, 0x7b, 0xf9, 0x3b, 0xf4, 0x08, 0x7b, 0xe9, 0xfb, 0x44, 0x8f, 0x30, 0xe6, 0x3c,
		0x1e, 0x65, 0x02, 0xf9, 0xe0, 0xe9, 0x28, 0x13, 0xd0, 0x88, 0xd6, 0xa0, 0x47, 0x58, 0xd6, 0xa0,
		0x88, 0x1e, 0x61, 0x44, 0xf7, 0x00, 0x7a, 0x84, 0xa5, 0x78, 0x45, 0xf4, 0x08, 0xe3, 0xad, 0x37,
		0xb9, 0xe8, 0xcc, 0xbc, 0xf4, 0x0d, 0x7b, 0x5c, 0x59, 0xa2, 0x93, 0x98, 0x84, 0x6d, 0x98, 0xc7,
		0x4e, 0x62, 0x52, 0xba, 0x3e, 0xd1, 0xdc, 0x60, 0x6c, 0x9a, 0x8b, 0xbd, 0x21, 0xbc, 0x77, 0x16,
		0x7c, 0xca, 0x0d, 0xc7, 0xa6, 0x33, 0x4c, 0x79, 0xfd, 0x64, 0xcb, 0xa0, 0xb2, 0x67, 0x4c, 0x4a,
		0x18, 0x52, 0xb6, 0x8c, 0x28, 0xed, 0xe5, 0x93, 0x31, 0xe4, 0x12, 0x82, 0xda, 0x0c, 0xb0, 0x95,
		0x02, 0xa6, 0xa6, 0x8b, 0xa2, 0xe9, 0x61, 0x5d, 0x3a, 0xbf, 0x29, 0xa5, 0xe5, 0x9e, 0xd5, 0x32,
		0x27, 0xb2, 0xbc, 0x53, 0x5c, 0xda, 0xaa, 0x97, 0x74, 0x3a, 0xcb, 0x79, 0xfb, 0xc5, 0x97, 0xc2,
		0xc2, 0x33, 0x02, 0x7f, 0x12, 0x09, 0x73, 0x1c, 0x88, 0x91, 0x08, 0x84, 0x97, 0x62, 0xd4, 0x3a,
		0x09, 0xe7, 0x6d, 0x5c, 0x21, 0xa5, 0xed, 0x92, 0x6e, 0x6f, 0xa5, 0xd4, 0x0f, 0x45, 0xb2, 0x38,
		0xf4, 0xc8, 0xf0, 0x50, 0x23, 0xab, 0x43, 0x8b, 0xcc, 0x0f, 0x25, 0x32, 0x3f, 0x74, 0xc8, 0xf6,
		0x50, 0x81, 0x96, 0x0b, 0x4a, 0xbb, 0x37, 0x90, 0x31, 0x58, 0xec, 0xaa, 0x94, 0x57, 0xd5, 0x62,
		0x23, 0xcc, 0x7f, 0x7f, 0xda, 0x7a, 0x25, 0x93, 0xb6, 0x6d, 0x99, 0x9d, 0xbb, 0x66, 0x79, 0xbe,
		0x2a, 0xe1, 0x1c, 0x35, 0xeb, 0xf3, 0x52, 0x69, 0xe7, 0xa2, 0xd2, 0xce, 0x3f, 0xe5, 0x9c, 0x73,
		0xd2, 0x8e, 0x29, 0x64, 0xd5, 0xc6, 0xcc, 0x10, 0x37, 0x91, 0x08, 0x3c, 0xdb, 0x35, 0x33, 0xa3,
		0x46, 0x8f, 0xee, 0xb1, 0xc7, 0x2f, 0x9d, 0x6d, 0xa7, 0xf5, 0x3d, 0x74, 0x5a, 0x57, 0x09, 0x80,
		0xb2, 0x80, 0x50, 0x3a, 0x20, 0x4a, 0x07, 0x46, 0xb9, 0x00, 0x99, 0x0d, 0x50, 0x66, 0x04, 0x98,
		0xc9, 0xa3, 0xc9, 0x3c, 0xb1, 0x43, 0x5a, 0xbd, 0xb1, 0x84, 0xba, 0x62, 0x49, 0xf5, 0xc3, 0x72,
		0x8e, 0xfe, 0x25, 0x76, 0x1a, 0x97, 0x9b, 0xd0, 0xb8, 0x28, 0xa2, 0x94, 0xd5, 0x67, 0x59, 0x41,
		0xa9, 0xe4, 0x9d, 0x9c, 0x5c, 0x0d, 0xe9, 0x4b, 0x64, 0x5f, 0xf2, 0x12, 0xd9, 0xd3, 0x78, 0x89,
		0x30, 0x3d, 0xff, 0xef, 0xe7, 0x78, 0x80, 0x93, 0xe3, 0x29, 0x13, 0x1b, 0x8f, 0x5f, 0x1a, 0x62,
		0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62,
		0x03, 0x62, 0x03, 0x62, 0x43, 0xb2, 0xd8, 0x40, 0x46, 0x9e, 0xdc, 0x94, 0xa5, 0x75, 0x15, 0x54,
		0xc8, 0xe4, 0x68, 0x79, 0x47, 0x7e, 0xfa, 0x52, 0x77, 0x7a, 0x63, 0x27, 0xc9, 0x7d, 0x59, 0x73,
		0x9d, 0x44, 0x35, 0x25, 0x2f, 0xd5, 0x34, 0xb1, 0x2c, 0x26, 0xcc, 0x65, 0x3a, 0x49, 0x2e, 0xf3,
		0xd4, 0x83, 0x12, 0x52, 0x0f, 0x24, 0x8a, 0x60, 0xa4, 0x1e, 0xe8, 0xe8, 0xfd, 0x90, 0x7a, 0x40,
		0x5e, 0xb5, 0x21, 0x1a, 0x48, 0x0b, 0x08, 0xa5, 0x03, 0xa2, 0x74, 0x60, 0x94, 0x0b, 0x90, 0xd9,
		0x0a, 0x25, 0x44, 0x03, 0x9f, 0x0b, 0x5f, 0x88, 0x06, 0x3e, 0x27, 0xd4, 0x83, 0x68, 0x20, 0xeb,
		0x50, 0x0f, 0xa2, 0x81, 0xa9, 0x2c, 0x11, 0x44, 0x03, 0xc9, 0xfd, 0x76, 0xa4, 0x1e, 0x20, 0xf5,
		0x00, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62, 0x03, 0x62,
		0x03, 0x62, 0x03, 0x62, 0x23, 0xdf, 0x62, 0x03, 0xa9, 0x07, 0x8a, 0x53, 0x0f, 0xb2, 0x6a, 0x99,
		0xaf, 0x38, 0xf3, 0x20, 0x83, 0xce, 0xf7, 0xe8, 0x05, 0xc4, 0x6e, 0x75, 0xf3, 0x6d, 0x04, 0xb4,
		0xb6, 0x9e, 0x75, 0x6a, 0x03, 0x94, 0x6e, 0xaa, 0x4c, 0x26, 0x29, 0x32, 0x99, 0x35, 0xfc, 0x29,
		0xa1, 0xe1, 0x0f, 0xa7, 0xa0, 0x0b, 0x1a, 0xfe, 0x50, 0x6e, 0xf8, 0x63, 0x4f, 0xa2, 0x6f, 0xc2,
		0x8b, 0x9c, 0x41, 0xec, 0xbc, 0xcc, 0xc1, 0x37, 0x31, 0xf8, 0x9e, 0x5d, 0x0a, 0xde, 0x83, 0x57,
		0x4b, 0x3b, 0xdb, 0x47, 0x8c, 0xec, 0x89, 0x1b, 0x2f, 0x86, 0xe9, 0x5a, 0xcb, 0x28, 0xe1, 0x6f,
		0x0f, 0xbd, 0x86, 0x90, 0xf0, 0x47, 0x09, 0x05, 0xe5, 0xa0, 0x21, 0x0f, 0xcd, 0x99, 0x59, 0x28,
		0xf9, 0x7e, 0xd6, 0xa0, 0xef, 0xbb, 0xc2, 0xf6, 0xb2, 0x58, 0xf1, 0x0b, 0xda, 0x54, 0xcc, 0x41,
		0xc6, 0xb7, 0xf0, 0xec, 0x0b, 0x57, 0x0c, 0xb3, 0x73, 0x38, 0x8b, 0x0b, 0x64, 0xe7, 0x63, 0x46,
		0xb6, 0x1b, 0xc2, 0xc9, 0xc0, 0xc9, 0xc0, 0xc9, 0xc0, 0xc9, 0xc0, 0xc9, 0x50, 0x74, 0x32, 0x71,
		0x58, 0xcb, 0xf4, 0x26, 0x57, 0x17, 0x22, 0xc8, 0xce, 0xd3, 0xac, 0x5c, 0x05, 0xee, 0x00, 0xee,
		0x00, 0xee, 0x00, 0xee, 0x80, 0x0b, 0xc2, 0xec, 0x64, 0x9b, 0xb5, 0x92, 0x71, 0xb6, 0x4a, 0x86,
		0x29, 0x43, 0x32, 0xb2, 0x53, 0x24, 0x65, 0xa5, 0xc8, 0xca, 0x46, 0x91, 0x99, 0x62, 0x90, 0x61,
		0xf6, 0x89, 0x94, 0xac, 0x13, 0xd9, 0xaf, 0xbe, 0xa4, 0xd1, 0xab, 0x67, 0x92, 0x9d, 0xd1, 0xcf,
		0x01, 0xc3, 0xbe, 0x12, 0x51, 0xe0, 0x0c, 0xcc, 0x30, 0xba, 0x75, 0x33, 0xac, 0xdf, 0x5f, 0xb9,
		0x0a, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x18, 0x36, 0x17, 0x84, 0x59, 0x89, 0xba, 0x94, 0x33,
		0xf8, 0xdd, 0x0d, 0x6f, 0x72, 0x35, 0x7d, 0x3a, 0x77, 0xc8, 0xd7, 0x7a, 0xce, 0x76, 0xd2, 0x27,
		0x5f, 0x2b, 0xed, 0xe4, 0x43, 0xc9, 0x49, 0x5a, 0x29, 0x26, 0x19, 0x12, 0x49, 0xcd, 0xba, 0x0d,
		0x23, 0x71, 0x65, 0xce, 0xd4, 0xfa, 0xc0, 0x9f, 0x78, 0x91, 0x08, 0xc2, 0x0c, 0x52, 0xb5, 0x1e,
		0xbc, 0x0c, 0x66, 0xb5, 0x11, 0xa4, 0x3d, 0x48, 0xdd, 0x52, 0x43, 0x6b, 0x34, 0x4f, 0xdd, 0x42,
		0xbb, 0xb4, 0x4d, 0x80, 0x41, 0xbb, 0x34, 0xe8, 0x2c, 0xe8, 0x2c, 0x5a, 0x40, 0x95, 0xfc, 0x62,
		0x7b, 0x12, 0x7d, 0x33, 0x47, 0xb6, 0xe3, 0x86, 0xd9, 0xb7, 0x2c, 0x58, 0xba, 0x16, 0x7a, 0x14,
		0xc8, 0x86, 0x36, 0x89, 0x10, 0x27, 0x0b, 0xea, 0xa4, 0x43, 0x9e, 0x74, 0xe8, 0x93, 0x0b, 0x81,
		0xd9, 0x40, 0x61, 0x46, 0x90, 0x98, 0x7d, 0x08, 0x6a, 0x63, 0xc7, 0xcc, 0x15, 0xdd, 0x7e, 0x49,
		0x42, 0x9f, 0x82, 0x2a, 0xfa, 0x14, 0x3c, 0x7d, 0x23, 0x79, 0xe8, 0x53, 0xb0, 0x87, 0x3e, 0x05,
		0x5b, 0x2d, 0x11, 0x05, 0x7d, 0x0a, 0x64, 0x2f, 0x91, 0x72, 0xa9, 0x56, 0xae, 0x1d, 0x54, 0x4b,
		0xb5, 0x0a, 0x1a, 0x16, 0x50, 0xfb, 0xed, 0x79, 0xee, 0x8e, 0x16, 0xf3, 0xfd, 0xe8, 0x76, 0x2c,
		0xa4, 0x0a, 0x8c, 0xa5, 0x0b, 0x42, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40,
		0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x40, 0x65, 0x68, 0xa6, 0x32, 0x06, 0x7e,
		0x10, 0x4c, 0xc6, 0x91, 0x18, 0x9a, 0x6e, 0x38, 0x96, 0x20, 0x32, 0xd6, 0xae, 0x07, 0x8d, 0x01,
		0x8d, 0x01, 0x8d, 0x01, 0x8d, 0x01, 0x8d, 0x01, 0x8d, 0x01, 0x8d, 0x01, 0x8d, 0x01, 0x8d, 0x01,
		0x8d, 0x01, 0x8d, 0xa1, 0x99, 0xc6, 0x18, 0xda, 0x91, 0x7d, 0x61, 0x87, 0xc2, 0xf4, 0xaf, 0x45,
		0xe0, 0xfa, 0xf6, 0x50, 0x82, 0xce, 0x78, 0xe0, 0x9a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0,
		0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x1a, 0x9a,
		0x69, 0x0d, 0x71, 0x33, 0x10, 0x62, 0x68, 0x5e, 0xd9, 0x37, 0x66, 0x28, 0xfe, 0x63, 0x7a, 0x93,
		0xab, 0x50, 0xc6, 0xe8, 0xfa, 0xcd, 0x8b, 0x42, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x40,
		0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x40, 0x6d, 0x68, 0xa6, 0x36,
		0x9c, 0xa1, 0xe9, 0x0a, 0xcf, 0xbc, 0x72, 0xc2, 0x2b, 0x3b, 0x1a, 0x7c, 0x93, 0x30, 0xb7, 0x7e,
		0xed, 0x82, 0x50, 0x19, 0x50, 0x19, 0x50, 0x19, 0x50, 0x19, 0x50, 0x19, 0x50, 0x19, 0x50, 0x19,
		0x50, 0x19, 0x50, 0x19, 0x50, 0x19, 0x50, 0x19, 0x9a, 0xa9, 0x0c, 0x37, 0x1c, 0x9b, 0x22, 0x08,
		0xfc, 0x40, 0xc2, 0x51, 0xc6, 0xd2, 0xb5, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0,
		0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0xa0, 0x2d, 0x34, 0xd3, 0x16,
		0x57, 0xb6, 0x37, 0xb1, 0x5d, 0xd3, 0x1e, 0x0e, 0x03, 0x11, 0x86, 0xe6, 0x30, 0xf0, 0xc7, 0xe6,
		0x28, 0xf0, 0xaf, 0x4c, 0x3b, 0x10, 0xb6, 0x04, 0xbd, 0xf1, 0xc4, 0xf5, 0xa1, 0x41, 0xa0, 0x41,
		0xa0, 0x41, 0xa0, 0x41, 0xa0, 0x41, 0xa0, 0x41, 0xa0, 0x41, 0xa0, 0x41, 0xa0, 0x41, 0xa0, 0x41,
		0xa0, 0x41, 0xb4, 0xd3, 0x20, 0x37, 0x31, 0xdd, 0x4f, 0x54, 0xc0, 0x22, 0xbd, 0x49, 0x48, 0x11,
		0x20, 0x8f, 0x5f, 0x1c, 0xea, 0x03, 0xea, 0x03, 0xea, 0x03, 0xea, 0x03, 0xea, 0x03, 0xea, 0x03,
		0xea, 0x03, 0xea, 0x03, 0xea, 0x03, 0xea, 0x03, 0xea, 0x43, 0x33, 0xf5, 0xe1, 0xff, 0xe5, 0x99,
		0x6e, 0x38, 0x36, 0xc7, 0x93, 0xe0, 0x52, 0x86, 0xe0, 0x58, 0xbb, 0x1e, 0x34, 0x06, 0x34, 0x06,
		0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06, 0x34, 0x06,
		0x34, 0x86, 0x66, 0x1a, 0x63, 0x6c, 0x07, 0x91, 0x39, 0xf8, 0x36, 0xf5, 0x36, 0x12, 0x14, 0xc6,
		0xca, 0xd5, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f,
		0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0xa0, 0x2f, 0x34, 0xd3, 0x17, 0xf3, 0xae, 0xb3, 0x66, 0xf8,
		0xdd, 0x91, 0x31, 0xc4, 0x6f, 0xf5, 0x72, 0x50, 0x18, 0x50, 0x18, 0x50, 0x18, 0x50, 0x18, 0x50,
		0x18, 0x50, 0x18, 0x50, 0x18, 0x50, 0x18, 0x50, 0x18, 0x50, 0x18, 0x50, 0x18, 0xba, 0x29, 0x8c,
		0xf1, 0xc8, 0x0c, 0x26, 0x9e, 0x0c, 0x71, 0xb1, 0xb8, 0x12, 0x74, 0x05, 0x74, 0x05, 0x74, 0x05,
		0x74, 0x05, 0x74, 0x05, 0x74, 0x05, 0x74, 0x05, 0x74, 0x05, 0x74, 0x05, 0x74, 0x05, 0x74, 0x85,
		0x4a, 0x5d, 0xf1, 0x86, 0xf0, 0xce, 0x36, 0xea, 0x9e, 0xe7, 0x47, 0xf6, 0x74, 0xc9, 0x65, 0xb2,
		0x99, 0x8d, 0x70, 0xf0, 0x4d, 0x5c, 0xd9, 0x63, 0x3b, 0xfa, 0x36, 0xf5, 0xf3, 0x05, 0x7f, 0x2c,
		0xbc, 0x41, 0xcc, 0xf5, 0x4d, 0x4f, 0x44, 0x7f, 0xf9, 0xc1, 0x77, 0xd3, 0xf1, 0xc2, 0xc8, 0xf6,
		0x06, 0xa2, 0xb0, 0xfe, 0x83, 0x70, 0xe3, 0x27, 0x85, 0x71, 0xe0, 0x47, 0xfe, 0xc0, 0x77, 0xc3,
		0xe4, 0x53, 0x61, 0x4a, 0xd8, 0x0a, 0xae, 0xb8, 0x16, 0xee, 0xfc, 0xaf, 0x42, 0x78, 0x1b, 0x46,
		0xe2, 0xca, 0x8c, 0xbf, 0x31, 0xe7, 0xcc, 0x22, 0x2c, 0x84, 0x91, 0x1d, 0x09, 0x23, 0x0b, 0x8d,
		0x17, 0x05, 0x93, 0x41, 0xe4, 0xcd, 0x99, 0x4c, 0x27, 0xb9, 0xc1, 0xf6, 0xcc, 0xf8, 0xe6, 0xdc,
		0x76, 0x6b, 0xed, 0xfb, 0x70, 0xfd, 0x07, 0xd6, 0xc9, 0xe2, 0xe6, 0x92, 0x4f, 0x56, 0x33, 0x74,
		0x42, 0xab, 0x15, 0xdf, 0xdc, 0xec, 0x2f, 0xeb, 0x34, 0xbe, 0xb9, 0xf8, 0xf3, 0xc7, 0xf9, 0xad,
		0x59, 0xa7, 0xf1, 0xad, 0xbd, 0xa1, 0xb9, 0x68, 0xd3, 0xf9, 0x4d, 0x29, 0x2d, 0xfb, 0xac, 0x96,
		0x3b, 0x99, 0x65, 0x9e, 0xe2, 0x02, 0x57, 0xbf, 0xb0, 0xd3, 0x59, 0xd2, 0xdb, 0x2f, 0xc0, 0x14,
		0x16, 0x9f, 0x11, 0x05, 0xf6, 0x68, 0xe4, 0x0c, 0x4c, 0xe1, 0x5d, 0x3a, 0x9e, 0x10, 0x81, 0xe3,
		0x5d, 0xa6, 0xb6, 0x02, 0x13, 0x19, 0xf5, 0xd0, 0x45, 0x52, 0xda, 0x38, 0x73, 0x02, 0x56, 0x4c,
		0xe9, 0xd7, 0xa5, 0x1d, 0xef, 0xc9, 0x22, 0xbe, 0x93, 0x61, 0x3c, 0x27, 0xab, 0xf8, 0x4d, 0xe6,
		0xf1, 0x9a, 0xcc, 0xe3, 0x33, 0xd9, 0xc6, 0x63, 0x68, 0x39, 0xa3, 0x23, 0x27, 0x48, 0x77, 0xc1,
		0x0e, 0x16, 0xbb, 0x2a, 0xe5, 0x55, 0x75, 0x1f, 0xa6, 0x89, 0x7f, 0x7f, 0xca, 0x6f, 0x3c, 0x5d,
		0x68, 0xc9, 0x0c, 0x62, 0xb2, 0x84, 0x1a, 0x09, 0x90, 0x93, 0x35, 0xf4, 0x48, 0x83, 0x20, 0x69,
		0x50, 0x24, 0x07, 0x92, 0x78, 0xc8, 0xc4, 0xb4, 0xa1, 0x2a, 0xf9, 0xc5, 0xc2, 0xb3, 0x2f, 0x5c,
		0x31, 0x94, 0x30, 0x6d, 0x7e, 0x7e, 0xa1, 0x8c, 0xd6, 0xc8, 0x91, 0x18, 0xd9, 0x13, 0x37, 0x5e,
		0x22, 0x23, 0xdb, 0x0d, 0x05, 0xce, 0xe1, 0xa4, 0x83, 0xa7, 0x44, 0x10, 0x95, 0x05, 0xa6, 0xd2,
		0x41, 0x55, 0x3a, 0xb8, 0xca, 0x05, 0xd9, 0x6c, 0xa3, 0x92, 0xfc, 0xcf, 0xe1, 0x2e, 0x7c, 0xdf,
		0x15, 0xb6, 0x27, 0xe1, 0x14, 0xae, 0x58, 0xcc, 0xf3, 0x00, 0xe4, 0xf1, 0x75, 0xd9, 0x0c, 0xfc,
		0x49, 0x24, 0x02, 0xd3, 0x91, 0xe0, 0xfb, 0xd6, 0xae, 0x07, 0xd7, 0x04, 0xd7, 0x04, 0xd7, 0x04,
		0xd7, 0xc4, 0xca, 0x35, 0xc5, 0x18, 0xb6, 0xe8, 0x36, 0xec, 0xf9, 0xe6, 0x7f, 0x7d, 0x4f, 0xc8,
		0xf0, 0x53, 0xef, 0x33, 0xbc, 0xc6, 0x89, 0x1d, 0x45, 0x22, 0xf0, 0x32, 0x4f, 0x18, 0x31, 0xde,
		0xbe, 0x3d, 0xdb, 0x33, 0x6b, 0xfd, 0xbf, 0xcf, 0x8a, 0x66, 0xad, 0x3f, 0xfb, 0x58, 0x8c, 0xff,
		0x9a, 0x7d, 0x2e, 0x9d, 0xed, 0x99, 0xe5, 0xc5, 0xe7, 0xca, 0xd9, 0x9e, 0x59, 0xe9, 0xef, 0x9e,
		0x9f, 0xbf, 0xdb, 0xfd, 0xb1, 0x7f, 0xf7, 0xf2, 0x7f, 0xf8, 0xf6, 0x1f, 0x67, 0xe7, 0xe7, 0xe3,
		0x1f, 0xed, 0xbb, 0xe9, 0x9f, 0xad, 0xbb, 0xfe, 0x3f, 0x77, 0x7f, 0xcb, 0x1a, 0x11, 0xa6, 0x06,
		0x9c, 0x9f, 0xbf, 0xeb, 0xff, 0x62, 0xe0, 0xb4, 0x39, 0x1b, 0xba, 0x72, 0x20, 0x99, 0xae, 0x1c,
		0x80, 0xae, 0x80, 0xae, 0x80, 0xae, 0x80, 0xae, 0x30, 0xa6, 0x2b, 0x07, 0xa0, 0x2b, 0xaf, 0xa6,
		0x2b, 0x1f, 0xfe, 0x9e, 0xfa, 0x74, 0xdb, 0x1c, 0xd5, 0xcd, 0x4f, 0xfd, 0x1f, 0x7b, 0xbf, 0x96,
		0xef, 0x76, 0x3f, 0xec, 0xbe, 0x5d, 0xff, 0xd9, 0x87, 0xdd, 0x1f, 0x7b, 0xbf, 0x56, 0xee, 0xde,
		0xbe, 0x7d, 0xe0, 0xbf, 0xfc, 0xf6, 0xd0, 0xef, 0xd8, 0xfd, 0xfb, 0xed, 0xdb, 0xb7, 0x73, 0xa2,
		0xb2, 0x42, 0x5e, 0xce, 0xf6, 0x8a, 0xfd, 0xdf, 0xe2, 0x8f, 0xb3, 0x3f, 0x13, 0xfa, 0xf3, 0xac,
		0xff, 0x79, 0x57, 0x05, 0xe9, 0x79, 0xfb, 0xf6, 0xec, 0x7f, 0x3e, 0xf4, 0xff, 0xf9, 0x61, 0xf7,
		0xc7, 0xc1, 0xdd, 0xe2, 0x73, 0xfc, 0xe7, 0xee, 0xdf, 0x6f, 0xdf, 0xfd, 0x72, 0x7e, 0xfe, 0xee,
		0xdd, 0x2f, 0xbb, 0xb3, 0x1b, 0x9e, 0xff, 0x7f, 0xbf, 0xcc, 0xfe, 0xeb, 0x6f, 0x1f, 0x3e, 0x6c,
		0xfc, 0x68, 0xf7, 0xed, 0x3f, 0xde, 0x49, 0xe2, 0x69, 0xb3, 0xf7, 0xf1, 0x01, 0x74, 0x2d, 0x83,
		0xdf, 0x88, 0xe4, 0xc0, 0x27, 0xb3, 0xa6, 0x1e, 0x48, 0x91, 0x29, 0x64, 0x72, 0xac, 0xbd, 0x23,
		0x3f, 0x85, 0xaa, 0x37, 0xbb, 0xb7, 0xc6, 0xfd, 0xad, 0x59, 0x73, 0x16, 0x4a, 0x35, 0x37, 0x30,
		0xd5, 0x6c, 0x35, 0x3b, 0x12, 0xd9, 0xa5, 0x3e, 0x64, 0x91, 0x3e, 0x9a, 0x79, 0xe6, 0x43, 0x09,
		0x99, 0x0f, 0x12, 0x25, 0x06, 0x32, 0x1f, 0x74, 0xf4, 0x81, 0xc8, 0x7c, 0x78, 0xea, 0x01, 0x21,
		0xf3, 0x01, 0xf1, 0x1a, 0xc4, 0x6b, 0x10, 0xaf, 0x61, 0x1d, 0xaf, 0x41, 0xe6, 0x83, 0x8c, 0x97,
		0x8a, 0xcc, 0x07, 0xb8, 0x26, 0xb8, 0x26, 0xb8, 0x26, 0xb8, 0xa6, 0x97, 0x62, 0x18, 0x8e, 0x12,
		0x5e, 0x77, 0x21, 0x64, 0x3e, 0x6c, 0xfb, 0x85, 0xcc, 0x07, 0x64, 0x3e, 0x80, 0xae, 0x80, 0xae,
		0x80, 0xae, 0x80, 0xae, 0x3c, 0x1b, 0xc3, 0x40, 0x57, 0x5e, 0x4b, 0x57, 0x90, 0xf9, 0xf0, 0x1c,
		0x4e, 0x87, 0xcc, 0x07, 0xf6, 0x74, 0x0d, 0x99, 0x0f, 0xea, 0x33, 0x1f, 0x34, 0x69, 0x8a, 0xf4,
		0x40, 0xe2, 0x03, 0x7a, 0x22, 0xa9, 0x5e, 0xeb, 0x44, 0xd6, 0x38, 0xdf, 0x8e, 0x48, 0x9b, 0xab,
		0x9a, 0x4c, 0x43, 0xa4, 0x37, 0x0a, 0xd7, 0xed, 0x54, 0xc7, 0x4c, 0x1f, 0xff, 0xac, 0xf1, 0x95,
		0x37, 0xb9, 0xba, 0x10, 0xc1, 0x96, 0x2f, 0xd9, 0x68, 0x39, 0x61, 0x54, 0x8f, 0xa2, 0x74, 0x4e,
		0xfa, 0x8d, 0x63, 0xc7, 0x6b, 0xb8, 0x62, 0x2a, 0x44, 0xc2, 0x74, 0x54, 0xb0, 0x71, 0x6c, 0xdf,
		0x2c, 0xfd, 0xc6, 0xe2, 0xfb, 0x72, 0xf9, 0xa0, 0x5a, 0x2e, 0xef, 0x55, 0xf7, 0xab, 0x7b, 0xb5,
		0x4a, 0xa5, 0x78, 0x50, 0x4c, 0xa1, 0x3f, 0xa5, 0xd1, 0x09, 0x86, 0x22, 0x10, 0xc3, 0xc3, 0xe9,
		0xd3, 0xf5, 0x26, 0xae, 0xab, 0xf4, 0x25, 0xa7, 0x0c, 0x4a, 0x0a, 0xc0, 0x28, 0x05, 0xe0, 0x91,
		0x0b, 0x38, 0xdb, 0xa1, 0xcb, 0xeb, 0x31, 0xe1, 0x75, 0xff, 0xf2, 0x95, 0x0b, 0x2c, 0xad, 0x85,
		0x25, 0x75, 0x41, 0x6d, 0xb1, 0x94, 0x64, 0x2d, 0xa1, 0xd7, 0x2d, 0x9e, 0x97, 0xbf, 0xfa, 0x97,
		0xfd, 0x8b, 0x17, 0x2e, 0x92, 0x6d, 0x17, 0x87, 0x9c, 0x45, 0xf1, 0x8a, 0xd5, 0x90, 0xf9, 0x2a,
		0x78, 0xd9, 0xeb, 0x7f, 0xfe, 0x4b, 0x7c, 0xc1, 0x0b, 0x34, 0x5c, 0x7f, 0x60, 0xbb, 0xa6, 0x7d,
		0x79, 0x19, 0x88, 0x4b, 0x3b, 0x7a, 0xc5, 0xc8, 0xf0, 0x24, 0x84, 0xb5, 0xf1, 0x9b, 0x5e, 0xb8,
		0x8c, 0x5e, 0x97, 0xd7, 0xfb, 0xea, 0xc0, 0xf9, 0x36, 0x01, 0xf1, 0xe5, 0x40, 0xb7, 0xeb, 0x0f,
		0xcc, 0x20, 0x7a, 0xcd, 0xf2, 0xda, 0x32, 0x84, 0x9d, 0x5a, 0x68, 0x3a, 0xb5, 0x90, 0xf3, 0x7a,
		0x28, 0x79, 0xfe, 0x68, 0x88, 0xc1, 0xd5, 0x6b, 0x73, 0x53, 0x8d, 0x64, 0x69, 0xbf, 0xfe, 0x95,
		0x2d, 0xd6, 0xcd, 0xfd, 0xaf, 0x7a, 0xe5, 0x93, 0xde, 0x2e, 0x09, 0x7e, 0xeb, 0xd3, 0xa6, 0x34,
		0x4e, 0x93, 0x52, 0xd9, 0x44, 0x69, 0x6d, 0xa6, 0xd4, 0x37, 0x55, 0xea, 0x9b, 0x2b, 0xed, 0x4d,
		0xa6, 0x86, 0x48, 0x6e, 0x9b, 0x18, 0x9e, 0x56, 0xb7, 0xce, 0x74, 0xbb, 0x73, 0xa6, 0x54, 0x93,
		0x92, 0xda, 0x21, 0x70, 0x9a, 0x87, 0xbd, 0xa9, 0x6e, 0xd3, 0xb4, 0xb7, 0x6b, 0x66, 0xdb, 0x36,
		0xb3, 0xed, 0x9b, 0xd5, 0x36, 0xa6, 0x11, 0x65, 0x4a, 0xab, 0xee, 0xc3, 0x18, 0x8a, 0x70, 0x10,
		0x38, 0xe3, 0x54, 0xe3, 0xab, 0xc9, 0x4a, 0x5e, 0xfe, 0xe5, 0xe9, 0x76, 0xfa, 0xde, 0xcb, 0x69,
		0xa7, 0xef, 0xd4, 0x80, 0x21, 0x2b, 0x80, 0xc8, 0x1c, 0x28, 0x32, 0x07, 0x8c, 0xac, 0x81, 0x23,
		0xbd, 0x40, 0xf7, 0x4e, 0x8a, 0xc7, 0x2c, 0xa9, 0x67, 0x60, 0x2c, 0xd5, 0xa6, 0xa6, 0x7d, 0xd0,
		0x91, 0xe4, 0x54, 0x68, 0x34, 0x81, 0x61, 0xe8, 0x84, 0x03, 0x3b, 0x18, 0x66, 0x80, 0xc1, 0xf3,
		0x5f, 0x9c, 0x56, 0x57, 0xf8, 0x6c, 0xea, 0xe9, 0x80, 0xeb, 0xc0, 0x75, 0xe0, 0x3a, 0x2b, 0x5c,
		0x4f, 0xbf, 0x26, 0x2d, 0xe5, 0x1a, 0x34, 0x1a, 0xc0, 0x3e, 0x4e, 0x17, 0x38, 0x92, 0xc7, 0x9f,
		0xae, 0xfa, 0x02, 0xfc, 0x02, 0x7e, 0x01, 0xbf, 0x9c, 0xe0, 0xd7, 0x19, 0x9b, 0xa9, 0x2f, 0x80,
		0x04, 0x80, 0x6b, 0x29, 0xfe, 0xce, 0xf9, 0x23, 0x48, 0x37, 0x35, 0x39, 0xc3, 0x16, 0x2f, 0x71,
		0x41, 0x5b, 0x66, 0x25, 0x08, 0x59, 0x26, 0x84, 0x67, 0x9e, 0x08, 0x2e, 0xb5, 0x5e, 0xad, 0x30,
		0xbf, 0xd8, 0xee, 0xdf, 0x6f, 0xcf, 0x8a, 0x66, 0xa9, 0xbf, 0xf8, 0x66, 0xff, 0x6c, 0xcf, 0x2c,
		0xf5, 0x77, 0x77, 0xd3, 0x4f, 0x52, 0xee, 0x67, 0xf1, 0x4a, 0x3a, 0xa7, 0xcd, 0x3f, 0x32, 0x7f,
		0x2f, 0xff, 0x43, 0xe9, 0xc5, 0xfc, 0x9f, 0x0c, 0xde, 0x0c, 0xe5, 0x74, 0xec, 0x6c, 0xb1, 0xe8,
		0x00, 0x58, 0xf4, 0x33, 0x2c, 0x5a, 0x94, 0x91, 0x14, 0x67, 0x65, 0x27, 0xd5, 0xbb, 0xf5, 0x1f,
		0xfe, 0xfd, 0xd0, 0xff, 0x56, 0xfc, 0xb5, 0x7a, 0xf7, 0xe1, 0x91, 0xff, 0x72, 0x70, 0xf7, 0xe1,
		0x99, 0xbf, 0xa3, 0x72, 0xf7, 0x76, 0xe3, 0x7f, 0x9d, 0xfe, 0xbc, 0xf4, 0xd8, 0x3f, 0x28, 0x3f,
		0xf2, 0x0f, 0xf6, 0x1f, 0xfb, 0x07, 0xfb, 0x8f, 0xfc, 0x83, 0x47, 0x4d, 0x2a, 0x3d, 0xf2, 0x0f,
		0x2a, 0x77, 0x7f, 0x6f, 0xfc, 0xff, 0x6f, 0x1f, 0xfe, 0x5f, 0x0f, 0xee, 0x76, 0xff, 0x7e, 0xec,
		0xbf, 0x55, 0xef, 0xfe, 0xfe, 0xb0, 0xbb, 0x5b, 0x78, 0x5b, 0x9c, 0xe2, 0xc2, 0xfb, 0x19, 0x54,
		0x14, 0xfb, 0x1b, 0x08, 0x32, 0x43, 0x04, 0x00, 0xf4, 0x06, 0x40, 0x63, 0xb5, 0x92, 0x5d, 0xad,
		0xf4, 0xbd, 0xd6, 0x1b, 0x5a, 0x76, 0xd1, 0x08, 0xaf, 0x84, 0x22, 0x32, 0x23, 0x3b, 0x83, 0x69,
		0xc5, 0x8b, 0x5f, 0x8c, 0x00, 0x0b, 0x02, 0x2c, 0x08, 0xb0, 0xe4, 0x30, 0xc0, 0x12, 0xd9, 0x97,
		0x66, 0x34, 0xfd, 0xed, 0x88, 0xaf, 0xa4, 0xfa, 0x5c, 0x27, 0x8e, 0x17, 0xed, 0x97, 0x32, 0x94,
		0x33, 0xd5, 0x0c, 0x7e, 0x75, 0xd7, 0xf6, 0x2e, 0x45, 0x66, 0xf4, 0x30, 0xc3, 0xbe, 0x07, 0xc7,
		0x8e, 0x27, 0xa1, 0x77, 0x47, 0xa6, 0x2d, 0x5b, 0x92, 0xcb, 0x7c, 0xb5, 0xdd, 0x89, 0x90, 0x70,
		0x9d, 0x4f, 0x81, 0x3d, 0x88, 0x1c, 0xdf, 0x3b, 0x72, 0x2e, 0x9d, 0x59, 0x91, 0x5c, 0x76, 0x6d,
		0x3a, 0x32, 0x6c, 0x0b, 0x71, 0x6c, 0xdf, 0x68, 0xf7, 0xea, 0xcb, 0xa5, 0x5a, 0xb9, 0x76, 0x50,
		0x2d, 0xd5, 0x2a, 0x1a, 0xad, 0x01, 0x26, 0x3d, 0x11, 0xf2, 0x1a, 0x84, 0xfb, 0x26, 0x6e, 0xcc,
		0xd4, 0x93, 0x98, 0x34, 0x89, 0xc1, 0x2d, 0xcb, 0xee, 0x75, 0x35, 0x5f, 0xba, 0xdb, 0xfd, 0x65,
		0xf7, 0x37, 0xc8, 0x6a, 0xe9, 0xb2, 0x1a, 0xa5, 0xd1, 0x2f, 0x29, 0x5a, 0x5c, 0x2f, 0xa7, 0x2b,
		0x24, 0x1f, 0xd3, 0x1b, 0xbd, 0x92, 0x69, 0x85, 0x63, 0x6b, 0x7a, 0x03, 0xf5, 0xc4, 0x7e, 0x2b,
		0xf9, 0x98, 0xca, 0x7c, 0x95, 0x2d, 0x2a, 0xa7, 0xb7, 0xa8, 0x32, 0x4a, 0x29, 0x6b, 0x26, 0xdd,
		0x6c, 0x99, 0x94, 0xc8, 0x0e, 0xaa, 0x4f, 0xc8, 0x05, 0x67, 0x50, 0x7d, 0xa2, 0x26, 0xe8, 0x72,
		0x5f, 0xd3, 0x2c, 0xec, 0x51, 0x20, 0x46, 0x69, 0xac, 0xb9, 0x05, 0xa1, 0x4a, 0x21, 0x0c, 0x30,
		0x25, 0x50, 0xb1, 0xdb, 0x79, 0xf7, 0x6e, 0xee, 0x0b, 0x0a, 0xf3, 0x65, 0xc7, 0x10, 0x52, 0xd3,
		0x19, 0x41, 0x95, 0xea, 0xc8, 0xa9, 0xd4, 0xcb, 0xf9, 0x4a, 0x00, 0x54, 0x00, 0x2a, 0x43, 0x40,
		0x45, 0x39, 0x1f, 0x8e, 0xc5, 0xd2, 0xf9, 0xe5, 0x38, 0x16, 0x93, 0x0c, 0x1c, 0xe9, 0xc6, 0x11,
		0x50, 0xce, 0x47, 0x20, 0x7e, 0x82, 0x72, 0x3e, 0xe0, 0x3a, 0x70, 0x1d, 0xb8, 0x9e, 0x2b, 0x5c,
		0x47, 0x39, 0xdf, 0xb3, 0xee, 0x09, 0xe5, 0x7c, 0x80, 0x5f, 0xc0, 0x2f, 0xe0, 0x37, 0xed, 0x55,
		0x8b, 0x72, 0xbe, 0x74, 0xbf, 0x50, 0xce, 0xf7, 0x8c, 0x0b, 0xa0, 0x9c, 0xef, 0xc5, 0xaf, 0x04,
		0xe5, 0x7c, 0x69, 0xbc, 0x19, 0x94, 0xf3, 0x01, 0x8b, 0x1e, 0xc4, 0x22, 0x14, 0x48, 0xa1, 0x9c,
		0x8f, 0x0f, 0x40, 0x63, 0xb5, 0xa2, 0x9c, 0x4f, 0xad, 0xb0, 0xd9, 0x41, 0x39, 0xdf, 0xf3, 0x5c,
		0x2f, 0xca, 0xf9, 0x10, 0x60, 0x41, 0x80, 0x25, 0xc7, 0x01, 0x16, 0x94, 0xf3, 0x65, 0xa3, 0x69,
		0x50, 0xce, 0x27, 0xe1, 0x69, 0x27, 0x86, 0xa3, 0x9c, 0xef, 0xe5, 0xd7, 0x41, 0x39, 0x1f, 0xd9,
		0x57, 0x8f, 0x72, 0x3e, 0x75, 0xbf, 0x15, 0xe5, 0x7c, 0x88, 0xc1, 0xad, 0xc7, 0xe0, 0x50, 0xce,
		0x47, 0x50, 0x56, 0xa3, 0x9c, 0x2f, 0xa5, 0x72, 0xbe, 0xb4, 0xe6, 0x89, 0x2b, 0xaa, 0xe6, 0x4b,
		0x61, 0x68, 0x38, 0x97, 0x31, 0xa8, 0xf3, 0x21, 0xca, 0xdb, 0x4d, 0xdb, 0x4b, 0x65, 0x6c, 0x72,
		0x7a, 0xe3, 0x92, 0x33, 0x1d, 0x93, 0x9c, 0xce, 0x78, 0x64, 0xed, 0xa7, 0xd6, 0x3e, 0x0e, 0x0e,
		0x54, 0x87, 0xd8, 0x3e, 0x0a, 0x07, 0x18, 0x69, 0xab, 0x64, 0xc5, 0x50, 0x1b, 0x6f, 0xbb, 0xb6,
		0x3e, 0x28, 0x4c, 0xba, 0x9d, 0xdf, 0xe8, 0x2b, 0xa7, 0xdb, 0xc6, 0xff, 0xfa, 0x75, 0x13, 0x6d,
		0xf7, 0x98, 0x4d, 0xb4, 0xf5, 0x44, 0x34, 0x5d, 0x7a, 0x18, 0x69, 0xfb, 0x40, 0x98, 0x7b, 0xf1,
		0x6c, 0x88, 0xe1, 0xd5, 0xab, 0xe3, 0xd3, 0x29, 0x54, 0x3a, 0x6f, 0x53, 0xd9, 0xfc, 0x40, 0x25,
		0x73, 0xbc, 0xd1, 0x08, 0xc0, 0x85, 0x1f, 0x8e, 0x47, 0xd7, 0xa5, 0xd7, 0x03, 0xc6, 0xfc, 0xdf,
		0xe7, 0x63, 0x08, 0xf6, 0xab, 0x6e, 0x36, 0x1f, 0x88, 0x31, 0x7f, 0x34, 0xda, 0x0c, 0xc1, 0x0e,
		0x84, 0x1d, 0xa6, 0x30, 0x00, 0x3b, 0xfe, 0x35, 0x18, 0x7e, 0xbd, 0xd5, 0xe6, 0x49, 0x6b, 0x13,
		0xa5, 0xbe, 0x99, 0x52, 0xdf, 0x54, 0x69, 0x6f, 0x2e, 0x35, 0xe1, 0x83, 0xad, 0x87, 0x5f, 0x4f,
		0x77, 0x4d, 0x7a, 0xad, 0x32, 0xe2, 0xdf, 0x86, 0xc1, 0xd7, 0x52, 0xb6, 0x68, 0xda, 0x5b, 0x35,
		0xb3, 0x2d, 0x9b, 0xd9, 0xd6, 0xcd, 0x6a, 0x0b, 0xd3, 0x88, 0x47, 0xa7, 0xd6, 0x29, 0x23, 0xa5,
		0xf9, 0xf6, 0x1b, 0x8b, 0x38, 0xb5, 0x9e, 0x71, 0x29, 0x6e, 0xfb, 0xd4, 0xb7, 0x7f, 0x16, 0x30,
		0x90, 0x29, 0x1c, 0x64, 0x05, 0x0b, 0x99, 0xc3, 0x43, 0xe6, 0x30, 0x91, 0x35, 0x5c, 0xa4, 0x03,
		0x1b, 0x29, 0xc1, 0x47, 0xea, 0x30, 0x92, 0xfc, 0x42, 0x67, 0x28, 0xbc, 0xc8, 0x19, 0x39, 0x22,
		0x48, 0x7f, 0x6d, 0x25, 0xe5, 0x23, 0xf7, 0xd7, 0x48, 0xf9, 0xdd, 0x67, 0x93, 0xf6, 0x91, 0x3a,
		0xdc, 0x64, 0x09, 0x3b, 0x52, 0xe0, 0x27, 0x6b, 0x18, 0x92, 0x06, 0x47, 0xd2, 0x60, 0x49, 0x16,
		0x3c, 0xa5, 0x0b, 0x53, 0x29, 0xc3, 0xd5, 0xf6, 0xe1, 0xc7, 0x17, 0x45, 0xd3, 0xcc, 0xa9, 0x60,
		0x31, 0x33, 0x43, 0x9b, 0x9d, 0x8c, 0x52, 0x67, 0xd7, 0x9f, 0x12, 0xbb, 0xe4, 0xce, 0xcc, 0x53,
		0x6a, 0xd7, 0x9f, 0x7e, 0x35, 0xc3, 0x4b, 0x64, 0x9b, 0x62, 0x9b, 0xfd, 0xdb, 0x48, 0x6e, 0x44,
		0x46, 0xca, 0x6d, 0xc6, 0x8e, 0xf8, 0xd1, 0xcb, 0x49, 0x4a, 0xc1, 0x4d, 0xae, 0x27, 0x31, 0x0d,
		0x33, 0x23, 0x08, 0x7e, 0x78, 0x89, 0x48, 0x48, 0xcd, 0x55, 0xbd, 0x44, 0x64, 0xa5, 0xea, 0x2a,
		0x5d, 0x2b, 0x6f, 0x78, 0xfe, 0xf6, 0xfe, 0x1b, 0x46, 0x3b, 0x47, 0x82, 0x03, 0x1d, 0xfa, 0x51,
		0x24, 0x86, 0xe6, 0x7f, 0x26, 0xf6, 0x50, 0x82, 0x17, 0xcd, 0x22, 0xd7, 0xf7, 0x5e, 0xe9, 0x64,
		0x9c, 0xf3, 0x9b, 0x5c, 0x48, 0x66, 0xcb, 0x09, 0x83, 0xdb, 0x4e, 0xc8, 0x4d, 0xd2, 0x33, 0xad,
		0x28, 0x4d, 0xca, 0xc9, 0xc7, 0xc9, 0xef, 0xcd, 0x3c, 0x6b, 0x6c, 0xa6, 0x4e, 0x0b, 0xf1, 0xe1,
		0x6b, 0xfc, 0x67, 0x21, 0xd5, 0xb0, 0xf0, 0x4e, 0xd6, 0x59, 0x65, 0x9d, 0xd8, 0x7e, 0xab, 0x3e,
		0xb5, 0x3f, 0xfe, 0x33, 0x95, 0x51, 0x22, 0xe9, 0x2d, 0xb2, 0x34, 0x4a, 0xcd, 0x33, 0x88, 0xd8,
		0x65, 0x17, 0xa9, 0xcb, 0x7b, 0xc1, 0x39, 0x0e, 0x02, 0xa4, 0x45, 0xdc, 0xf2, 0x75, 0x10, 0x90,
		0x5d, 0xc1, 0x79, 0x7a, 0x23, 0x4d, 0x36, 0x08, 0x67, 0x8a, 0x71, 0x9b, 0x07, 0x12, 0x03, 0x97,
		0xc0, 0x4b, 0x27, 0xb8, 0xf7, 0x22, 0x11, 0x8c, 0xec, 0x81, 0x08, 0x33, 0x80, 0xfb, 0xfb, 0xdf,
		0x8d, 0x73, 0x5f, 0xc0, 0x3d, 0xe0, 0x9e, 0x2c, 0xdc, 0xa7, 0x7f, 0xee, 0xbb, 0xd8, 0xfa, 0x19,
		0x1e, 0xfb, 0x26, 0x97, 0xc8, 0xe6, 0xd4, 0xb7, 0x88, 0x53, 0x5f, 0x9c, 0xfa, 0xd2, 0x02, 0x25,
		0x59, 0xe0, 0x94, 0x4d, 0x80, 0x27, 0xed, 0x53, 0xdf, 0xb4, 0x41, 0x2b, 0xf9, 0xc5, 0x29, 0xe7,
		0xc0, 0x3d, 0xba, 0xa9, 0x52, 0x0f, 0x7e, 0x48, 0x80, 0xb1, 0xcc, 0xe1, 0x4c, 0x06, 0xac, 0x49,
		0x85, 0x37, 0x59, 0x30, 0x27, 0x1d, 0xee, 0xa4, 0xc3, 0x9e, 0x6c, 0xf8, 0xcb, 0x06, 0x06, 0x33,
		0x82, 0xc3, 0xcc, 0x61, 0x31, 0xb9, 0x80, 0x3d, 0x89, 0xbe, 0x4d, 0xa5, 0xf0, 0x20, 0x0e, 0x41,
		0xcf, 0xba, 0xc7, 0x65, 0xbe, 0xa8, 0x93, 0xa2, 0x81, 0x07, 0x2e, 0xfe, 0xab, 0x16, 0xcd, 0x9f,
		0xb2, 0x06, 0x54, 0x99, 0xc0, 0xaa, 0x04, 0x60, 0x65, 0x03, 0xad, 0x32, 0xc0, 0x55, 0x06, 0xbc,
		0xaa, 0x00, 0x38, 0x5b, 0x20, 0xce, 0x18, 0x90, 0x93, 0x87, 0xd6, 0x93, 0x01, 0x94, 0x3b, 0x99,
		0x0e, 0x25, 0x7c, 0x92, 0x6c, 0xbe, 0x67, 0x9a, 0x2a, 0x92, 0x65, 0x87, 0xc2, 0x6f, 0xce, 0x50,
		0x2c, 0x4e, 0x50, 0xe5, 0x39, 0xca, 0x95, 0xab, 0xc2, 0x43, 0xc2, 0x43, 0xc2, 0x43, 0xc2, 0x43,
		0xc2, 0x43, 0xae, 0xed, 0xba, 0xf4, 0xc7, 0x3b, 0x3e, 0xe9, 0x22, 0x8b, 0x70, 0x91, 0x1b, 0xcf,
		0xc6, 0x19, 0xca, 0x73, 0x8c, 0xce, 0x10, 0xee, 0x10, 0xee, 0x10, 0xee, 0x10, 0xee, 0x10, 0xee,
		0x10, 0x82, 0x91, 0xa2, 0x37, 0xbc, 0x12, 0x51, 0xe0, 0x0c, 0xe4, 0x79, 0xc4, 0xf9, 0xf5, 0xe0,
		0x15, 0xe1, 0x15, 0xe1, 0x15, 0xe1, 0x15, 0xe1, 0x15, 0xd7, 0x77, 0x5d, 0x38, 0x1e, 0x99, 0x52,
		0x40, 0x72, 0x19, 0x28, 0x0f, 0x24, 0x5c, 0x4a, 0x4e, 0x35, 0xf2, 0xe2, 0x4b, 0x0e, 0x8e, 0xec,
		0xc8, 0xae, 0x4e, 0x96, 0xec, 0xe1, 0x36, 0x2e, 0x2b, 0xb9, 0x5a, 0x39, 0xb9, 0xae, 0x82, 0x4a,
		0x54, 0x49, 0x18, 0xb3, 0xba, 0x94, 0x24, 0x56, 0x31, 0x53, 0x59, 0x4a, 0x07, 0x95, 0xca, 0x7e,
		0x25, 0x47, 0xcb, 0xe9, 0x8d, 0x1e, 0x57, 0xe9, 0x43, 0x4c, 0x6d, 0x8a, 0xa9, 0x89, 0x1b, 0x39,
		0xb3, 0xd6, 0x2d, 0xf6, 0xf0, 0x7f, 0xed, 0x81, 0xf0, 0x06, 0xb7, 0xe6, 0x38, 0x70, 0xae, 0xec,
		0xe0, 0x56, 0xa2, 0xc4, 0xfa, 0x99, 0x15, 0x19, 0x13, 0xa6, 0x23, 0x31, 0xb2, 0x27, 0x6e, 0x4c,
		0x32, 0xa7, 0xdc, 0x16, 0x3a, 0x0f, 0x3a, 0x0f, 0x3a, 0x0f, 0x3a, 0x0f, 0x3a, 0x6f, 0x7d, 0xd7,
		0xe1, 0x30, 0x90, 0x84, 0xc7, 0x5e, 0x74, 0x12, 0x90, 0x9b, 0x58, 0xba, 0x72, 0x55, 0xb8, 0x48,
		0xb8, 0x48, 0xb8, 0x48, 0xb8, 0x48, 0xb8, 0xc8, 0xb5, 0x5d, 0x37, 0x2b, 0x82, 0x8f, 0x6e, 0xd3,
		0xad, 0xe0, 0x7f, 0xd2, 0x4d, 0x4a, 0x88, 0x45, 0x18, 0xcd, 0xf9, 0xad, 0x1d, 0xda, 0xa1, 0xc4,
		0x9d, 0xbe, 0x78, 0xb0, 0x9d, 0xd3, 0x93, 0x4f, 0x56, 0xbb, 0xd1, 0xfb, 0x77, 0xa7, 0xfb, 0x2f,
		0xab, 0xf7, 0xe7, 0x49, 0xc3, 0x90, 0xd9, 0xc8, 0x2e, 0x94, 0x16, 0x03, 0xde, 0x91, 0x1a, 0x07,
		0x5e, 0x79, 0xc4, 0x87, 0xdd, 0x4e, 0xfd, 0xe8, 0x63, 0xfd, 0xb4, 0xb7, 0x78, 0xce, 0x86, 0x8e,
		0xf1, 0x4a, 0x45, 0x0f, 0xb7, 0xdd, 0x69, 0x5b, 0x78, 0xc0, 0x19, 0x3e, 0xe0, 0x93, 0x4e, 0xb3,
		0xdd, 0xb3, 0x7a, 0x1d, 0x6b, 0xf6, 0x41, 0xfe, 0x13, 0x96, 0x72, 0xa5, 0x3e, 0x9a, 0x59, 0x2a,
		0x50, 0x5c, 0x63, 0x3b, 0x0c, 0x9d, 0x6b, 0x89, 0x62, 0x6b, 0x71, 0x41, 0xe8, 0x2c, 0xe8, 0x2c,
		0xe8, 0x2c, 0xe8, 0x2c, 0xe8, 0xac, 0xb5, 0x5d, 0x87, 0x50, 0x24, 0x0d, 0xc7, 0x18, 0x38, 0x7e,
		0xe0, 0x44, 0x12, 0x0f, 0x0a, 0x93, 0x2b, 0xc2, 0x35, 0xc2, 0x35, 0xc2, 0x35, 0xc2, 0x35, 0xc2,
		0x35, 0xae, 0xed, 0xba, 0x89, 0xe3, 0x45, 0xef, 0x25, 0x3a, 0xc6, 0x0a, 0xf2, 0x30, 0x5f, 0x7f,
		0x63, 0xc8, 0xc3, 0xcc, 0xfe, 0xba, 0xc8, 0xc3, 0xd4, 0x76, 0x29, 0x95, 0x2a, 0xc8, 0xc2, 0x64,
		0x77, 0x15, 0xb6, 0x59, 0x98, 0xac, 0xda, 0x9c, 0x65, 0x34, 0x04, 0x63, 0xe3, 0x3a, 0x0a, 0x86,
		0x62, 0xdc, 0xf7, 0xcd, 0xbe, 0xff, 0x58, 0xc8, 0xb4, 0x59, 0xe4, 0x8e, 0xfc, 0xc9, 0x19, 0xcd,
		0xe4, 0x26, 0xef, 0x3f, 0xa6, 0x3a, 0x4e, 0x23, 0xfb, 0xe5, 0x9d, 0xc1, 0xd2, 0x36, 0x84, 0x67,
		0x5f, 0xb8, 0xc2, 0xbc, 0x18, 0x0d, 0xb3, 0xef, 0x3f, 0xba, 0x74, 0x2d, 0xf4, 0x20, 0x55, 0x15,
		0x55, 0x58, 0x8e, 0x26, 0x64, 0xf7, 0x26, 0x76, 0xd0, 0x80, 0x34, 0xc3, 0x50, 0xc1, 0xf4, 0xbd,
		0xc1, 0x2d, 0xef, 0x48, 0xe9, 0x3e, 0x9a, 0x71, 0x73, 0xe6, 0x8d, 0x6d, 0x99, 0xb9, 0xdf, 0x95,
		0x00, 0x94, 0xd2, 0x00, 0x53, 0x26, 0x70, 0xca, 0x07, 0x50, 0xd9, 0x40, 0xaa, 0x0c, 0x50, 0x95,
		0x01, 0xab, 0x12, 0x80, 0x95, 0xa3, 0x0c, 0xb3, 0x0e, 0xc4, 0x66, 0x0d, 0xbc, 0x6b, 0x0c, 0x75,
		0x28, 0x3f, 0x45, 0x72, 0x71, 0xe1, 0x5f, 0xb5, 0x1c, 0x28, 0x2c, 0x0b, 0x9a, 0x55, 0x40, 0xb4,
		0x3a, 0xa8, 0x56, 0x05, 0xd9, 0xca, 0xa1, 0x5b, 0x39, 0x84, 0x2b, 0x85, 0x72, 0x39, 0x90, 0x2e,
		0x09, 0xda, 0x93, 0x27, 0x29, 0xed, 0xac, 0x6d, 0x63, 0xbf, 0xca, 0x4b, 0x47, 0xd9, 0x60, 0xc4,
		0x45, 0x4d, 0xa2, 0xc2, 0xbc, 0xd9, 0x85, 0xa4, 0x68, 0x6b, 0x72, 0x3d, 0x2a, 0x51, 0xd7, 0xfb,
		0x10, 0x59, 0x41, 0x8a, 0x10, 0xdc, 0x21, 0x12, 0x88, 0x6d, 0xc4, 0xf7, 0x7d, 0x38, 0x1a, 0x66,
		0x1a, 0x92, 0xcd, 0x7e, 0x6f, 0xdc, 0x65, 0x1a, 0x2f, 0xb7, 0x23, 0x89, 0x39, 0xd3, 0xb3, 0xcb,
		0x69, 0x16, 0x87, 0x28, 0x21, 0x0e, 0x81, 0x38, 0x04, 0xe2, 0x10, 0x88, 0x43, 0x20, 0x0e, 0x81,
		0x38, 0x04, 0xe2, 0x10, 0x88, 0x43, 0x20, 0x0e, 0x81, 0x38, 0x04, 0xe2, 0x10, 0x60, 0x17, 0x88,
		0x43, 0x3c, 0x16, 0x87, 0x90, 0xa1, 0x03, 0xe9, 0x85, 0x21, 0x4e, 0xe3, 0xbb, 0x46, 0x66, 0x65,
		0xf6, 0x7b, 0x2d, 0x77, 0x99, 0x95, 0x99, 0xa7, 0xc1, 0x91, 0xdb, 0x4d, 0x79, 0x4e, 0xb0, 0x74,
		0x24, 0x24, 0x56, 0x3a, 0x59, 0x27, 0x54, 0xee, 0x21, 0xa1, 0xf2, 0x59, 0xe2, 0x0e, 0x43, 0xdd,
		0xd9, 0xe8, 0x35, 0x0c, 0x75, 0x57, 0x2a, 0xb9, 0x92, 0x5d, 0xe3, 0x0a, 0x7b, 0x94, 0x6d, 0x77,
		0xb7, 0x44, 0x52, 0x55, 0x33, 0xbc, 0xc6, 0xc9, 0x9c, 0x56, 0xbc, 0x7b, 0x37, 0x3f, 0xb8, 0x2b,
		0x38, 0xf9, 0x76, 0x7b, 0x0b, 0x16, 0x60, 0x4e, 0x5f, 0x6e, 0xf6, 0x1e, 0x70, 0xe5, 0x72, 0xa8,
		0x2e, 0xa0, 0xe0, 0x0c, 0x9d, 0x11, 0x1c, 0x21, 0x43, 0x47, 0xe8, 0x8c, 0xe0, 0x04, 0x67, 0x0f,
		0x06, 0xb5, 0x05, 0x04, 0x61, 0x52, 0x1a, 0x5c, 0xca, 0x84, 0x4d, 0xe9, 0xf0, 0x29, 0x1b, 0x46,
		0x95, 0xc1, 0xa9, 0x32, 0x58, 0x55, 0x01, 0xaf, 0xd9, 0xc2, 0x6c, 0xc6, 0x70, 0x2b, 0x0d, 0x76,
		0x37, 0x39, 0xaa, 0xfc, 0x33, 0xfd, 0xfb, 0x4b, 0xe3, 0x54, 0x9f, 0x1b, 0x48, 0x2b, 0x03, 0x6b,
		0x55, 0xa0, 0xad, 0x1c, 0xbc, 0x95, 0x83, 0xb8, 0x4a, 0x30, 0x97, 0x03, 0xea, 0x92, 0xc0, 0x5d,
		0x5e, 0x80, 0x49, 0x61, 0xc0, 0x49, 0x45, 0x00, 0xea, 0xd1, 0x80, 0x54, 0x21, 0x5e, 0xa6, 0x1f,
		0x96, 0x4e, 0xa2, 0xd6, 0x7e, 0x30, 0xff, 0x3e, 0x3e, 0x29, 0xd2, 0x25, 0xe7, 0x40, 0xc6, 0x69,
		0xf5, 0xe4, 0x42, 0x21, 0x7f, 0x58, 0xb9, 0x3a, 0x28, 0x04, 0x28, 0x04, 0x28, 0x04, 0x28, 0x04,
		0x28, 0x04, 0x28, 0x84, 0x12, 0x0a, 0x71, 0x76, 0x4f, 0x21, 0xfe, 0x7f, 0x83, 0x49, 0x10, 0x08,
		0x2f, 0x7a, 0xbb, 0x5b, 0x78, 0xf7, 0xee, 0x3e, 0xe9, 0xa5, 0x3f, 0xff, 0x27, 0xcb, 0x7e, 0x2b,
		0x7c, 0xe0, 0x67, 0xc9, 0x6f, 0x1e, 0x8a, 0x1b, 0x03, 0x19, 0x90, 0x04, 0xa2, 0x31, 0x8d, 0x9b,
		0x48, 0xce, 0xb4, 0x26, 0xf9, 0x01, 0x48, 0x7f, 0x60, 0x8a, 0x9b, 0xe8, 0x43, 0x24, 0x5c, 0x71,
		0x25, 0xa2, 0xe0, 0xd6, 0xf4, 0x3d, 0x73, 0xf0, 0x2d, 0x6e, 0x8d, 0xab, 0x24, 0x28, 0x39, 0xb2,
		0xdd, 0x50, 0x45, 0x54, 0x92, 0x7b, 0x40, 0xb2, 0x8f, 0x24, 0xe0, 0x4c, 0x12, 0x15, 0x57, 0x0e,
		0xd5, 0xf3, 0x55, 0x8f, 0x9c, 0x7c, 0xea, 0x8a, 0x11, 0x4a, 0x92, 0x7f, 0xf2, 0xa6, 0x50, 0x92,
		0xbc, 0xad, 0xbc, 0x2d, 0xe1, 0xf8, 0x92, 0x8d, 0x8c, 0xc5, 0xf1, 0x25, 0x8e, 0x2f, 0x9f, 0x7a,
		0x60, 0x38, 0xbe, 0xcc, 0x0e, 0x94, 0x11, 0x7b, 0x64, 0x0c, 0xd6, 0xaa, 0x40, 0x5b, 0x39, 0x78,
		0x2b, 0x07, 0x71, 0x95, 0x60, 0x2e, 0x2f, 0xce, 0xb2, 0x83, 0xd8, 0x63, 0xb6, 0x8c, 0x18, 0xc7,
		0x97, 0x3b, 0x38, 0xbe, 0x4c, 0x47, 0xc8, 0xe1, 0xf8, 0x12, 0x14, 0x02, 0x14, 0x02, 0x14, 0x02,
		0x14, 0x02, 0x14, 0x42, 0x39, 0x85, 0xc0, 0xf1, 0xa5, 0xbe, 0xd1, 0x18, 0x9c, 0xdd, 0x04, 0x62,
		0x94, 0xab, 0x1e, 0x2e, 0x2b, 0x47, 0x37, 0x68, 0xe3, 0x22, 0x6b, 0xc7, 0xe5, 0xae, 0x8d, 0x8b,
		0x8c, 0x92, 0x63, 0x8a, 0x7b, 0x2a, 0xcf, 0x55, 0xed, 0x6e, 0x68, 0x9b, 0x23, 0xc7, 0x8d, 0x44,
		0x90, 0x7d, 0x49, 0xfb, 0xd2, 0xb5, 0x50, 0xcf, 0xae, 0x4a, 0xf1, 0xa2, 0xb9, 0x0b, 0x4b, 0xd5,
		0x8a, 0xe6, 0x2e, 0x3f, 0x7b, 0x38, 0xa8, 0x6b, 0x27, 0x08, 0x97, 0xd2, 0x03, 0x87, 0xaa, 0x12,
		0x43, 0x32, 0x87, 0x51, 0x55, 0x41, 0x42, 0x24, 0x87, 0x64, 0x0d, 0xb3, 0x7a, 0x84, 0x24, 0xa4,
		0x25, 0x88, 0xd8, 0xae, 0x2b, 0xff, 0x68, 0x67, 0x7a, 0x51, 0x9c, 0xe8, 0x70, 0x03, 0x68, 0xa5,
		0x40, 0xad, 0x0a, 0xb0, 0x95, 0x03, 0xb7, 0x72, 0x00, 0x57, 0x0d, 0xe4, 0x72, 0x00, 0x5d, 0x12,
		0xb0, 0x27, 0x0f, 0x13, 0xfd, 0xea, 0x19, 0x2f, 0x14, 0x1c, 0x77, 0xbc, 0xe4, 0x7a, 0x54, 0x82,
		0xb1, 0xf7, 0xc1, 0xb2, 0x7c, 0xd5, 0xa9, 0xb4, 0x42, 0xfb, 0x53, 0x7c, 0xdb, 0x28, 0x52, 0xf9,
		0xc9, 0x6b, 0x42, 0x91, 0xca, 0xb6, 0x94, 0xb7, 0x84, 0x58, 0x04, 0x62, 0x11, 0x88, 0x45, 0x20,
		0x16, 0x81, 0x58, 0x04, 0x62, 0x11, 0x88, 0x45, 0x20, 0x16, 0x81, 0x58, 0x04, 0x62, 0x11, 0x88,
		0x45, 0x80, 0x5b, 0x20, 0x16, 0xf1, 0xb3, 0x58, 0x44, 0x9e, 0xf2, 0x2e, 0xef, 0x43, 0x11, 0x48,
		0xba, 0x94, 0xb5, 0xd7, 0x72, 0x97, 0x74, 0x99, 0x79, 0x52, 0x1c, 0xb9, 0xdd, 0x94, 0xe7, 0x74,
		0xcb, 0xab, 0xb1, 0x1b, 0x66, 0x9f, 0x68, 0x19, 0x5f, 0x05, 0x29, 0x96, 0xaa, 0x64, 0x1f, 0x52,
		0x2c, 0x59, 0xca, 0x36, 0xa4, 0x58, 0xaa, 0x8c, 0xab, 0x21, 0xc5, 0x92, 0x43, 0xf4, 0x0c, 0xc7,
		0x1a, 0xba, 0x44, 0xc7, 0x70, 0xac, 0xc1, 0x2a, 0xf4, 0x20, 0xed, 0x58, 0x23, 0x0a, 0xec, 0xd1,
		0xc8, 0x19, 0x98, 0xc2, 0xbb, 0x74, 0x3c, 0x21, 0x02, 0xc7, 0xbb, 0x34, 0xaf, 0x44, 0x14, 0x38,
		0x03, 0xf9, 0xa7, 0x1d, 0x3f, 0xb1, 0x05, 0x87, 0x20, 0xdc, 0xe0, 0x5c, 0x29, 0xac, 0xab, 0x82,
		0x77, 0xe5, 0x30, 0xaf, 0x1c, 0xee, 0x55, 0xc3, 0xbe, 0x1c, 0xf8, 0x97, 0xe4, 0x06, 0x92, 0x87,
		0xa9, 0xee, 0x10, 0x64, 0xe2, 0x78, 0xd1, 0x7e, 0x49, 0xc1, 0x19, 0x88, 0xcc, 0x46, 0x1b, 0xdd,
		0xb8, 0x65, 0xba, 0x8c, 0x1e, 0xf1, 0xcb, 0x5f, 0x72, 0x21, 0x29, 0xbe, 0xd1, 0x63, 0xc7, 0x93,
		0x8e, 0x85, 0x8a, 0x9c, 0xeb, 0xc6, 0xe5, 0xbf, 0xda, 0xee, 0x44, 0x28, 0xbc, 0xfe, 0xa7, 0xc0,
		0x1e, 0x44, 0x8e, 0xef, 0x1d, 0x39, 0x97, 0x4e, 0x3c, 0x91, 0x60, 0x4f, 0xba, 0x1d, 0x77, 0xbf,
		0x2a, 0x58, 0x72, 0xf6, 0x4d, 0xee, 0x97, 0x5c, 0xb9, 0x54, 0x2b, 0xd7, 0x0e, 0xaa, 0xa5, 0x5a,
		0x25, 0xc7, 0x6b, 0xef, 0x8d, 0x9e, 0x57, 0xeb, 0xe3, 0xa8, 0x9e, 0x80, 0x5e, 0xce, 0xeb, 0x51,
		0xfd, 0xd5, 0xd8, 0x0d, 0xf3, 0x55, 0x30, 0x70, 0x3c, 0x76, 0x43, 0xd4, 0x0a, 0x3c, 0xfa, 0x86,
		0x9c, 0xcb, 0xb1, 0xe9, 0x0e, 0xc7, 0x66, 0x78, 0xeb, 0x0d, 0xe4, 0x05, 0xd7, 0x57, 0xae, 0x8a,
		0x10, 0x3b, 0xd5, 0x98, 0x0c, 0x42, 0xec, 0x5a, 0xc6, 0x5c, 0x10, 0x62, 0x7f, 0xcd, 0x43, 0x93,
		0x16, 0x62, 0x97, 0x74, 0xd2, 0xb9, 0xb1, 0xc9, 0xa5, 0xd1, 0x02, 0x89, 0xb0, 0x2c, 0x1d, 0x9e,
		0x55, 0xc0, 0xb4, 0x52, 0xb8, 0x56, 0x05, 0xdb, 0xca, 0xe1, 0x5b, 0x39, 0x8c, 0xab, 0x86, 0x73,
		0xb9, 0xda, 0x59, 0x56, 0xe8, 0x5c, 0x16, 0xcc, 0x27, 0x17, 0x14, 0x9e, 0x7d, 0xe1, 0x8a, 0xa1,
		0xfc, 0x8d, 0xb3, 0x40, 0x8b, 0x85, 0x01, 0x92, 0x57, 0xad, 0x9a, 0x58, 0x9b, 0x74, 0x47, 0xa0,
		0xd2, 0x21, 0x90, 0x70, 0x0c, 0xaa, 0x1d, 0x04, 0x19, 0x47, 0x41, 0xc6, 0x61, 0x50, 0x71, 0x1c,
		0x72, 0x1d, 0x88, 0x64, 0x47, 0x92, 0x3c, 0x64, 0xe9, 0x67, 0xb1, 0x1b, 0xbb, 0x5e, 0x7e, 0x61,
		0xda, 0x06, 0xcb, 0x2f, 0x6a, 0x1a, 0xcd, 0x97, 0xb8, 0x98, 0x8c, 0xb1, 0x1f, 0x46, 0x66, 0x28,
		0xc2, 0xd0, 0xf1, 0x3d, 0x73, 0x32, 0x36, 0x87, 0xc2, 0xb5, 0x6f, 0xd5, 0xd1, 0x86, 0x87, 0xcd,
		0x01, 0x89, 0x00, 0x89, 0x00, 0x89, 0x00, 0x89, 0x00, 0x89, 0xd0, 0x8c, 0x44, 0x48, 0x4f, 0xec,
		0x5a, 0xc7, 0xf8, 0xaa, 0x82, 0x4b, 0xab, 0x49, 0xf4, 0x5a, 0x7c, 0xa9, 0x81, 0xb8, 0x1d, 0xd5,
		0x89, 0x5f, 0x8a, 0x9d, 0xfb, 0x86, 0x19, 0x8a, 0x13, 0xc1, 0x12, 0x3b, 0x08, 0x24, 0xe5, 0x28,
		0x82, 0xbf, 0xd5, 0xa5, 0xa9, 0x30, 0x41, 0x8c, 0xea, 0xd2, 0x54, 0x9d, 0x30, 0x46, 0x72, 0x8d,
		0xbe, 0xc9, 0xc7, 0x55, 0xfb, 0xba, 0x4a, 0x6b, 0xad, 0x8e, 0x15, 0x24, 0x27, 0x9c, 0x25, 0xd7,
		0x25, 0x95, 0x78, 0xb6, 0x9c, 0xf6, 0x53, 0x90, 0x7a, 0xdc, 0xbc, 0x43, 0x29, 0x1b, 0xad, 0x79,
		0x39, 0x6e, 0x0d, 0xc7, 0xa7, 0xb7, 0xde, 0x40, 0x4a, 0x62, 0x9a, 0xbc, 0x0d, 0x25, 0x65, 0x8e,
		0xb7, 0x94, 0xe6, 0xb6, 0x1b, 0xf2, 0x47, 0x56, 0x63, 0xa3, 0x1d, 0x95, 0xb9, 0x11, 0x25, 0xe4,
		0x46, 0x68, 0x15, 0xb5, 0x42, 0x6e, 0x04, 0x72, 0x23, 0xd2, 0x7c, 0x98, 0xc8, 0x8d, 0xd0, 0x5a,
		0x5e, 0xe2, 0x58, 0x03, 0xc7, 0x1a, 0x38, 0xd6, 0xa0, 0xe1, 0x38, 0xd4, 0xc4, 0x13, 0x90, 0x1b,
		0x21, 0x1f, 0xe4, 0x91, 0x1b, 0x91, 0xc2, 0xb3, 0x44, 0x6e, 0x04, 0x48, 0x04, 0x48, 0x04, 0x48,
		0x04, 0x48, 0x04, 0x48, 0x84, 0xfc, 0x5d, 0x8f, 0xdc, 0x08, 0xe9, 0x5f, 0xc8, 0x8d, 0x40, 0x6e,
		0xc4, 0x92, 0x1d, 0xc8, 0x8d, 0xd8, 0x41, 0x6e, 0xc4, 0xc3, 0x4b, 0x13, 0xb9, 0x11, 0xaa, 0x09,
		0x81, 0xba, 0xab, 0xf6, 0x21, 0xad, 0xb7, 0x5e, 0xb6, 0xe1, 0xad, 0x37, 0xf8, 0x16, 0xf8, 0x9e,
		0xf3, 0x5f, 0x95, 0x81, 0xf8, 0x15, 0x2b, 0x20, 0xa4, 0x21, 0xa4, 0x21, 0xa4, 0x21, 0xa4, 0x21,
		0xa4, 0x35, 0x13, 0xd2, 0x88, 0xc6, 0x33, 0xbf, 0x12, 0xd2, 0x29, 0x55, 0xa5, 0x53, 0xca, 0x4c,
		0x50, 0xdb, 0x21, 0x9a, 0x4d, 0x29, 0x61, 0x0e, 0x9f, 0xbc, 0xed, 0x84, 0x06, 0x9b, 0x5a, 0x6c,
		0xcc, 0x3c, 0xb5, 0xd9, 0xbc, 0xdf, 0x8a, 0x68, 0xb5, 0xf9, 0xd0, 0x5b, 0x92, 0x91, 0xb9, 0x2c,
		0x35, 0x63, 0x59, 0x7a, 0x73, 0xcd, 0x12, 0x9a, 0x6b, 0xb2, 0x92, 0xb6, 0x68, 0xae, 0x89, 0xe6,
		0x9a, 0xcf, 0x79, 0x68, 0x98, 0x5f, 0x85, 0xf9, 0x55, 0x7a, 0x44, 0x32, 0x51, 0x68, 0x82, 0x42,
		0x13, 0x14, 0x9a, 0x70, 0x8b, 0x44, 0x62, 0x7e, 0x55, 0xf6, 0x5f, 0x98, 0x5f, 0x25, 0xf5, 0xf2,
		0x98, 0x5f, 0x85, 0xf9, 0x55, 0x8a, 0x96, 0x1c, 0xe6, 0x57, 0x61, 0x7e, 0x15, 0xf5, 0xfb, 0x41,
		0x78, 0xfd, 0x25, 0xd7, 0x23, 0x15, 0x5e, 0x97, 0x75, 0xd4, 0x45, 0x26, 0xae, 0x2e, 0xe1, 0x5c,
		0x2b, 0xc3, 0x90, 0xfa, 0x1b, 0x46, 0x1b, 0x4c, 0xd6, 0xc6, 0x22, 0xb5, 0xa1, 0x8c, 0x4c, 0x0f,
		0x3d, 0x48, 0x6c, 0xa1, 0x6c, 0x36, 0x4f, 0xfa, 0x4b, 0x3b, 0x83, 0x65, 0x6d, 0x78, 0xc2, 0xb9,
		0xfc, 0x76, 0xe1, 0x07, 0x61, 0x66, 0x2b, 0x3a, 0x51, 0xcf, 0xf7, 0x97, 0xca, 0x68, 0x7b, 0x66,
		0x7b, 0xde, 0x94, 0x79, 0x80, 0x52, 0x46, 0x40, 0x52, 0x6a, 0x00, 0x52, 0x56, 0xc0, 0x51, 0x7a,
		0x80, 0x51, 0x7a, 0x40, 0x51, 0x76, 0x00, 0x91, 0x97, 0x5b, 0xce, 0xfa, 0x7c, 0x28, 0x41, 0x2e,
		0x79, 0xe7, 0xf3, 0xc9, 0x15, 0x31, 0xff, 0x92, 0x1a, 0x84, 0x2a, 0x81, 0x52, 0xd9, 0x90, 0xaa,
		0x0c, 0x5a, 0x95, 0x41, 0xac, 0x2a, 0xa8, 0xd5, 0x23, 0xe4, 0x80, 0xf9, 0x97, 0x0c, 0x61, 0x59,
		0x3a, 0x3c, 0xab, 0x80, 0x69, 0xa5, 0x70, 0xad, 0x0a, 0xb6, 0x95, 0xc3, 0xb7, 0x72, 0x18, 0x57,
		0x0d, 0xe7, 0x72, 0x60, 0x5d, 0x12, 0xbc, 0x4b, 0x87, 0xf9, 0xe4, 0x82, 0x92, 0xb3, 0xaf, 0x36,
		0xc0, 0x42, 0x6a, 0xc6, 0xd5, 0x3a, 0xfc, 0xa3, 0xa6, 0x54, 0x73, 0xb7, 0xa0, 0xda, 0x3d, 0x90,
		0x71, 0x13, 0x64, 0xdc, 0x05, 0x15, 0xb7, 0x21, 0xd7, 0x7d, 0x48, 0x76, 0x23, 0xc9, 0x43, 0x56,
		0x5f, 0x53, 0x3a, 0x7d, 0xaf, 0xa6, 0x12, 0x90, 0x5f, 0x06, 0xfa, 0x03, 0x74, 0x68, 0x92, 0x77,
		0xe3, 0xe8, 0xd0, 0x74, 0x6f, 0x06, 0x3a, 0x34, 0xa9, 0xc6, 0xc0, 0xd5, 0xa5, 0x89, 0x0e, 0x4d,
		0x1b, 0x4b, 0xf3, 0xa0, 0x52, 0xd9, 0x47, 0x73, 0x26, 0x45, 0x84, 0x40, 0xdd, 0x55, 0xd1, 0x9c,
		0x69, 0xfb, 0x65, 0x1b, 0xf8, 0x93, 0x48, 0x04, 0xa6, 0xa3, 0xb0, 0x33, 0xd3, 0xbd, 0x09, 0x90,
		0xd0, 0x90, 0xd0, 0x90, 0xd0, 0x90, 0xd0, 0x90, 0xd0, 0x9a, 0x49, 0xe8, 0xa1, 0x1f, 0x45, 0x62,
		0x68, 0xfe, 0x67, 0x62, 0x0f, 0x55, 0xb6, 0x66, 0x7a, 0xaf, 0xe0, 0xda, 0x27, 0x76, 0x14, 0x89,
		0xc0, 0x53, 0xa6, 0xa2, 0x8d, 0xb7, 0x6f, 0xcf, 0xf6, 0xcc, 0x5a, 0xff, 0xef, 0xb3, 0xa2, 0x59,
		0xeb, 0xcf, 0x3e, 0x16, 0xe3, 0xbf, 0x66, 0x9f, 0x4b, 0x67, 0x7b, 0x66, 0x79, 0xf1, 0xb9, 0x72,
		0xb6, 0x67, 0x56, 0xfa, 0xbb, 0xe7, 0xe7, 0xef, 0x76, 0x7f, 0xec, 0xdf, 0xbd, 0xfc, 0x1f, 0x1a,
		0xe0, 0x80, 0xac, 0xae, 0x84, 0x6e, 0x5b, 0x72, 0x92, 0xa4, 0x93, 0xb4, 0xd6, 0xe4, 0x53, 0x3e,
		0xa7, 0x97, 0xb6, 0x17, 0xcf, 0x21, 0xf9, 0x84, 0x01, 0xa6, 0x0c, 0x24, 0x9b, 0x32, 0xa9, 0x86,
		0xfe, 0x12, 0x9a, 0x49, 0x31, 0x24, 0xb9, 0x20, 0xc9, 0x45, 0x07, 0x42, 0xa3, 0xae, 0xbf, 0x84,
		0x2b, 0xec, 0x51, 0x20, 0x46, 0x0a, 0x1a, 0x4c, 0x14, 0x65, 0x76, 0x98, 0x38, 0x99, 0x73, 0xb6,
		0x77, 0xef, 0xe6, 0x4c, 0xa9, 0x70, 0xef, 0x7b, 0xc0, 0x15, 0x5e, 0xc0, 0xf9, 0x30, 0xec, 0x3c,
		0x2b, 0x8e, 0x80, 0x61, 0xe7, 0xe0, 0x08, 0xe0, 0x08, 0xe0, 0x08, 0x8f, 0x3d, 0x4c, 0xe9, 0x89,
		0xb0, 0xf6, 0xf0, 0x7f, 0xed, 0x81, 0xf0, 0x06, 0xb7, 0xa6, 0x5c, 0xd8, 0xdf, 0x40, 0x8d, 0x75,
		0x43, 0x70, 0xae, 0xa7, 0x9b, 0x83, 0x20, 0xe1, 0x28, 0x54, 0x3b, 0x0c, 0x32, 0x8e, 0x83, 0x8c,
		0x03, 0xa1, 0xe2, 0x48, 0xe4, 0x3a, 0x14, 0xc9, 0x8e, 0x45, 0x9d, 0x08, 0xdd, 0xd8, 0xf5, 0xce,
		0x50, 0x78, 0x91, 0x13, 0xdd, 0xca, 0x15, 0xa4, 0x1b, 0xcc, 0x5f, 0x41, 0xee, 0x97, 0xd1, 0x9c,
		0xdf, 0xfa, 0xa1, 0x1d, 0x2a, 0x44, 0x9e, 0xc5, 0x8b, 0xe8, 0x9c, 0x9e, 0x7c, 0xb2, 0xda, 0x8d,
		0xe6, 0xe7, 0xdf, 0x0f, 0x3b, 0x5d, 0xeb, 0xb4, 0x57, 0xef, 0x35, 0x0c, 0x95, 0x3d, 0xdc, 0x42,
		0x65, 0xe7, 0x9d, 0x3b, 0x4a, 0x33, 0x87, 0x57, 0x5e, 0x4a, 0xb3, 0xdd, 0xec, 0x19, 0x79, 0x4c,
		0x52, 0x25, 0xf2, 0xfc, 0xeb, 0xbd, 0x5e, 0xe3, 0xf8, 0x04, 0xaf, 0x40, 0xe1, 0x2b, 0xf8, 0xf4,
		0xa5, 0xd5, 0xc2, 0xf3, 0x57, 0xf7, 0xfc, 0x1b, 0x7f, 0x9c, 0xf6, 0xea, 0x5d, 0x6c, 0x01, 0x85,
		0xaf, 0xe0, 0xa8, 0xf3, 0xef, 0x36, 0x9e, 0xbf, 0xba, 0xe7, 0xdf, 0xfb, 0x77, 0xc7, 0xfa, 0x77,
		0xfd, 0x4f, 0xbc, 0x02, 0x75, 0xaf, 0xa0, 0xd5, 0xa9, 0x1f, 0x35, 0xdb, 0x9f, 0xf1, 0x0a, 0x54,
		0x3a, 0x82, 0x8f, 0xbf, 0xd7, 0xdb, 0x9f, 0x1b, 0x46, 0xce, 0xaa, 0x52, 0xfa, 0xe8, 0xdb, 0xcc,
		0x6f, 0x0f, 0x19, 0x17, 0xf6, 0xe0, 0xfb, 0x64, 0x6c, 0x0e, 0x45, 0xe8, 0x5c, 0x7a, 0x76, 0x24,
		0x86, 0xe6, 0xec, 0xf4, 0x57, 0x5d, 0x48, 0xfb, 0x51, 0x8b, 0x10, 0xdb, 0xce, 0xf4, 0xc2, 0x88,
		0x6d, 0x23, 0xb6, 0x3d, 0x33, 0x04, 0xb1, 0x6d, 0xa5, 0x7e, 0x06, 0x35, 0x2b, 0x3b, 0x2a, 0x80,
		0x1e, 0x35, 0x2b, 0xa8, 0x59, 0x01, 0x43, 0xdc, 0x5c, 0x21, 0x43, 0x61, 0x0f, 0xcd, 0xc8, 0xb9,
		0x52, 0x98, 0xe5, 0x70, 0x6f, 0x02, 0x38, 0x20, 0x38, 0x20, 0x38, 0x20, 0x38, 0x20, 0x38, 0xa0,
		0x66, 0x1c, 0x70, 0x8a, 0xee, 0x91, 0x33, 0xf8, 0x1e, 0x1e, 0x94, 0x15, 0x72, 0x40, 0x15, 0x14,
		0xf0, 0x8b, 0x37, 0xeb, 0x62, 0x63, 0x78, 0xb6, 0xe7, 0x87, 0x62, 0xe0, 0x7b, 0xc3, 0xd0, 0x40,
		0x0b, 0x32, 0x79, 0x37, 0x8e, 0x16, 0x64, 0xf7, 0x66, 0xa0, 0x05, 0x99, 0x6a, 0x2c, 0x5e, 0x5d,
		0x9a, 0x68, 0x41, 0xb6, 0xb1, 0x34, 0x8b, 0xef, 0xcb, 0xe5, 0x83, 0x6a, 0xb9, 0xbc, 0x57, 0xdd,
		0xaf, 0xee, 0xd5, 0x2a, 0x95, 0xe2, 0x41, 0x11, 0x1d, 0xc9, 0x14, 0xf1, 0x14, 0x75, 0x57, 0x85,
		0xb2, 0x4f, 0x43, 0xd9, 0x93, 0x39, 0xf4, 0xc1, 0x69, 0x0f, 0x94, 0x3e, 0x94, 0x3e, 0x94, 0x3e,
		0x94, 0xbe, 0xf6, 0x4a, 0x1f, 0xa7, 0x3d, 0x38, 0xed, 0x01, 0x27, 0xa4, 0xca, 0x09, 0x5d, 0x3b,
		0x8c, 0x4c, 0x11, 0x46, 0xf6, 0x85, 0xeb, 0x84, 0xdf, 0x84, 0xea, 0x93, 0x9f, 0x87, 0xcd, 0x01,
		0x37, 0x04, 0x37, 0x04, 0x37, 0x04, 0x37, 0x04, 0x37, 0xd4, 0x8c, 0x1b, 0xe2, 0x14, 0x08, 0xa7,
		0x40, 0x6a, 0xbe, 0x70, 0x0a, 0xb4, 0x64, 0x06, 0x4e, 0x81, 0x54, 0x63, 0xf1, 0xea, 0xd2, 0xc4,
		0x29, 0xd0, 0xc6, 0xd2, 0xc4, 0x29, 0x10, 0x1d, 0x9e, 0xa2, 0xee, 0xaa, 0x50, 0xfc, 0xdb, 0x2f,
		0x5b, 0x0c, 0x75, 0x85, 0xa6, 0x87, 0xa6, 0x87, 0xa6, 0x87, 0xa6, 0x87, 0xa6, 0xcf, 0x64, 0xd7,
		0x63, 0xa8, 0x2b, 0xb4, 0x34, 0x04, 0x0b, 0xb4, 0x34, 0xb4, 0x34, 0xd1, 0xa5, 0x89, 0xa1, 0xae,
		0x10, 0xcf, 0x10, 0xcf, 0xaf, 0x5a, 0xb6, 0xfe, 0x78, 0xba, 0x68, 0x6d, 0xd7, 0x1c, 0xd8, 0x63,
		0xfb, 0xc2, 0x71, 0x9d, 0xc8, 0x89, 0x3b, 0x32, 0x2a, 0xd2, 0xd2, 0x0f, 0x9b, 0x03, 0x69, 0x0d,
		0x69, 0x0d, 0x69, 0x0d, 0x69, 0x0d, 0x69, 0xad, 0x99, 0xb4, 0xfe, 0x26, 0x6e, 0xcc, 0x30, 0x0a,
		0x1c, 0xef, 0x12, 0x99, 0x94, 0x92, 0x0d, 0x88, 0xf3, 0x21, 0x6d, 0x73, 0x54, 0x37, 0x3f, 0xf5,
		0x7f, 0x94, 0xee, 0xde, 0x7e, 0x58, 0xfd, 0x7e, 0xf7, 0x97, 0xdd, 0xdf, 0x90, 0x00, 0xc9, 0x91,
		0xd1, 0x8d, 0x03, 0xc7, 0x0f, 0x9c, 0xe8, 0x56, 0x1d, 0x89, 0x4b, 0x2c, 0x00, 0x6f, 0x03, 0x6f,
		0x03, 0x6f, 0x03, 0x6f, 0x03, 0x6f, 0xd3, 0x8c, 0xb7, 0x4d, 0x1c, 0x2f, 0x7a, 0xaf, 0x90, 0xb2,
		0x55, 0x70, 0x18, 0x22, 0xef, 0xc6, 0x71, 0x18, 0x72, 0x6f, 0x06, 0x0e, 0x43, 0x54, 0xa3, 0xdf,
		0xea, 0xd2, 0xc4, 0x61, 0xc8, 0xc6, 0xd2, 0x2c, 0x55, 0x70, 0x14, 0xa2, 0x88, 0x08, 0xa8, 0xbb,
		0x2a, 0x84, 0xf3, 0xf6, 0xcb, 0x36, 0x10, 0x51, 0x60, 0x7b, 0x57, 0x4e, 0x18, 0x3a, 0xbe, 0x67,
		0xfe, 0x67, 0x22, 0x26, 0xc2, 0x74, 0x85, 0x77, 0x19, 0x4f, 0x97, 0x56, 0x24, 0xa5, 0x7f, 0x62,
		0x13, 0xc4, 0x35, 0xc4, 0x35, 0xc4, 0x35, 0xc4, 0x35, 0xc4, 0xb5, 0x86, 0xe2, 0x7a, 0xbf, 0xa4,
		0x50, 0x5d, 0x57, 0xa1, 0xae, 0xa1, 0xae, 0xa1, 0xae, 0xa1, 0xae, 0xa1, 0xae, 0x37, 0x96, 0x66,
		0xb9, 0x54, 0x2b, 0xd7, 0x0e, 0xaa, 0xa5, 0x1a, 0x44, 0x36, 0x44, 0x36, 0x44, 0xf6, 0xcb, 0x45,
		0x76, 0xdc, 0x1c, 0xd1, 0x74, 0x86, 0x0a, 0x35, 0x75, 0x62, 0x02, 0x24, 0x34, 0x24, 0x34, 0x24,
		0x34, 0x24, 0x34, 0x24, 0xb4, 0x66, 0x12, 0x1a, 0x2d, 0x1a, 0xd1, 0xa2, 0x11, 0x1c, 0x90, 0x2a,
		0x07, 0x0c, 0x23, 0x3b, 0x12, 0xe6, 0xe0, 0x9b, 0xed, 0x5d, 0xaa, 0xac, 0x35, 0x59, 0x35, 0x03,
		0x5c, 0x10, 0x5c, 0x10, 0x5c, 0x10, 0x5c, 0x10, 0x5c, 0x50, 0x33, 0x2e, 0x88, 0xe3, 0x14, 0xe9,
		0x5f, 0x38, 0x4e, 0xc1, 0x71, 0xca, 0x92, 0x1d, 0x38, 0x4e, 0xd9, 0xc1, 0x71, 0xca, 0xc3, 0x4b,
		0x13, 0xc7, 0x29, 0xaa, 0x09, 0x81, 0xba, 0xab, 0x6a, 0x2b, 0xa5, 0xdf, 0x68, 0x84, 0x64, 0x46,
		0xdd, 0xf3, 0xfc, 0xc8, 0x9e, 0x6e, 0x0d, 0xa9, 0xe0, 0x65, 0x84, 0x83, 0x6f, 0xe2, 0xca, 0x1e,
		0xdb, 0x71, 0xf6, 0xa5, 0x51, 0xf0, 0xc7, 0xc2, 0x1b, 0xc4, 0xe2, 0xd5, 0xf4, 0x44, 0xf4, 0x97,
		0x1f, 0x7c, 0x37, 0x1d, 0x2f, 0x8c, 0x6c, 0x6f, 0x20, 0x0a, 0xeb, 0x3f, 0x08, 0x37, 0x7e, 0x52,
		0x18, 0x07, 0x7e, 0xe4, 0x0f, 0x7c, 0x37, 0x4c, 0x3e, 0x15, 0x66, 0x7c, 0xbf, 0x60, 0x07, 0xc2,
		0x0e, 0xe3, 0x3f, 0x0b, 0x8e, 0x17, 0x89, 0x60, 0x64, 0x4f, 0x7f, 0x41, 0xf2, 0xb1, 0xe0, 0x09,
		0xe7, 0xf2, 0xdb, 0x85, 0x1f, 0x84, 0xc9, 0xa7, 0x42, 0x1c, 0x38, 0x30, 0xa4, 0x06, 0x4c, 0x82,
		0xc9, 0x20, 0xf2, 0xe6, 0x84, 0xb6, 0x93, 0x3c, 0x8a, 0xf6, 0xec, 0x36, 0x9b, 0xf3, 0xbb, 0xb4,
		0xd6, 0xbe, 0x0f, 0xd7, 0x7f, 0x60, 0x9d, 0x2c, 0x1e, 0x43, 0xf2, 0xc9, 0xea, 0xc4, 0x8f, 0xc1,
		0xaa, 0x4f, 0x1f, 0x43, 0xfc, 0xa7, 0xd5, 0x4c, 0x1e, 0xc3, 0xfd, 0x47, 0xab, 0xbd, 0x78, 0x0c,
		0xc9, 0x27, 0xeb, 0x34, 0x7e, 0x0c, 0x6f, 0xf4, 0xd8, 0x52, 0xd9, 0x5e, 0x21, 0xe3, 0xcd, 0x3a,
		0x15, 0xf7, 0x32, 0x4f, 0x36, 0x8d, 0x96, 0x13, 0x46, 0xf5, 0x28, 0x92, 0x33, 0x6f, 0x6f, 0xca,
		0xe9, 0x1b, 0xae, 0x98, 0x4a, 0xf5, 0x50, 0x0e, 0x75, 0x99, 0x52, 0xb5, 0xa5, 0x2b, 0xaa, 0x69,
		0xd5, 0x6c, 0x74, 0x82, 0xa1, 0x08, 0xc4, 0xf0, 0x70, 0xfa, 0x6a, 0xbd, 0x89, 0xeb, 0xb2, 0x5e,
		0xa1, 0x92, 0xdd, 0x08, 0x61, 0xf7, 0x21, 0xc1, 0x71, 0xd0, 0x74, 0x18, 0xd9, 0xba, 0x8a, 0xec,
		0x00, 0x3c, 0x9b, 0xdf, 0x9c, 0xd1, 0x86, 0x93, 0xb5, 0xd1, 0xe8, 0x6d, 0xb0, 0x0c, 0xf7, 0x15,
		0xa9, 0xfd, 0x94, 0xcd, 0x36, 0x4a, 0x7f, 0x91, 0x67, 0xb0, 0xc0, 0x67, 0x47, 0x76, 0x99, 0xad,
		0xeb, 0xd5, 0x93, 0xc1, 0x8c, 0xd6, 0x53, 0x92, 0x1c, 0x90, 0xd1, 0xaf, 0x4f, 0x4e, 0xf8, 0x4a,
		0x19, 0x5d, 0x40, 0xc2, 0x49, 0x9e, 0xd4, 0x13, 0x3b, 0x59, 0x27, 0x73, 0xd2, 0x4f, 0xe0, 0xa4,
		0x9f, 0xb4, 0xc9, 0x3e, 0x51, 0xe3, 0xe5, 0x98, 0x8f, 0x9c, 0x6c, 0xe5, 0x92, 0x61, 0x4f, 0xa2,
		0x6f, 0xc2, 0x8b, 0x9c, 0x41, 0xec, 0xfd, 0xcd, 0x48, 0xc6, 0xc9, 0x5b, 0xb2, 0x53, 0x1f, 0xba,
		0x78, 0xd6, 0xa2, 0x57, 0x4a, 0x28, 0x5b, 0x5a, 0xca, 0x84, 0xcc, 0x14, 0x09, 0x25, 0x29, 0x11,
		0xb2, 0x53, 0x20, 0x94, 0xa5, 0x3c, 0x28, 0x4b, 0x71, 0x50, 0x95, 0xd2, 0xc0, 0x3b, 0x78, 0x26,
		0x2d, 0x45, 0x61, 0x89, 0x5f, 0x4a, 0x6a, 0x79, 0x79, 0x9f, 0x89, 0xca, 0x55, 0x7b, 0x67, 0xc8,
		0xfb, 0xbe, 0x39, 0x43, 0xb1, 0x10, 0xab, 0xf2, 0x1c, 0xe5, 0xca, 0x55, 0xe1, 0x21, 0xe1, 0x21,
		0xe1, 0x21, 0xe1, 0x21, 0xe1, 0x21, 0xd7, 0x76, 0xdd, 0x85, 0xef, 0xbb, 0xc2, 0xf6, 0x64, 0xba,
		0xc8, 0x22, 0x5c, 0xe4, 0xc6, 0xb3, 0x91, 0x50, 0xa6, 0x99, 0xbc, 0xf2, 0xec, 0x4f, 0x2d, 0xe1,
		0x0e, 0xe1, 0x0e, 0xe1, 0x0e, 0xe1, 0x0e, 0x21, 0x18, 0x21, 0x18, 0x5f, 0xf3, 0x6c, 0x24, 0x0d,
		0x1a, 0x96, 0x3b, 0x58, 0x18, 0x5e, 0x11, 0x5e, 0x11, 0x5e, 0x11, 0x5e, 0x91, 0xa1, 0x57, 0x94,
		0x3b, 0x98, 0x57, 0xe2, 0x20, 0x5e, 0xc9, 0xe5, 0x5b, 0x12, 0xb3, 0xba, 0x55, 0x94, 0x67, 0xa9,
		0xaa, 0xb5, 0x56, 0x54, 0x7e, 0xa5, 0xb2, 0x94, 0x45, 0x66, 0x17, 0x01, 0x15, 0xe5, 0x54, 0xaa,
		0x97, 0x92, 0x82, 0x41, 0xb7, 0x4a, 0x97, 0x93, 0x26, 0xc5, 0x05, 0x7d, 0x88, 0xa9, 0x4d, 0x31,
		0x35, 0x71, 0x23, 0xc7, 0xb4, 0x03, 0x61, 0x9b, 0xf6, 0xf0, 0x7f, 0xed, 0x81, 0xf0, 0x06, 0xb7,
		0xe6, 0x38, 0x70, 0xae, 0xec, 0xe0, 0x56, 0xa2, 0xc4, 0xfa, 0x99, 0x15, 0x19, 0x13, 0xa6, 0x23,
		0x31, 0xb2, 0x27, 0x6e, 0x4c, 0x32, 0xa7, 0xdc, 0x16, 0x3a, 0x0f, 0x3a, 0x0f, 0x3a, 0x0f, 0x3a,
		0x0f, 0x3a, 0x6f, 0x7d, 0xd7, 0xe1, 0x30, 0x90, 0x84, 0xc7, 0x5e, 0x14, 0x6d, 0xc8, 0x4d, 0x2c,
		0x5d, 0xb9, 0x2a, 0x5c, 0x24, 0x5c, 0x24, 0x5c, 0x24, 0x5c, 0x24, 0x5c, 0xe4, 0xda, 0xae, 0x73,
		0x86, 0xc2, 0x8b, 0x9c, 0xe8, 0x36, 0x10, 0x23, 0x99, 0x6e, 0x52, 0x46, 0x19, 0x74, 0x73, 0x7e,
		0x6b, 0x87, 0x76, 0x28, 0x71, 0xa7, 0x2f, 0x1e, 0x6c, 0xe7, 0xf4, 0xe4, 0x93, 0xd5, 0x6e, 0xf4,
		0xfe, 0xdd, 0xe9, 0xfe, 0xcb, 0xea, 0xfd, 0x79, 0xd2, 0x90, 0xb5, 0xe3, 0xe3, 0x90, 0x4f, 0x28,
		0xb5, 0x85, 0x97, 0xa2, 0x3e, 0x9c, 0x87, 0xdd, 0x4e, 0xfd, 0xe8, 0x63, 0xfd, 0xb4, 0xb7, 0x78,
		0xce, 0x86, 0x8e, 0xf1, 0x4a, 0x45, 0x0f, 0xb7, 0xdd, 0x69, 0x5b, 0x78, 0xc0, 0x19, 0x3e, 0xe0,
		0x93, 0x4e, 0xb3, 0xdd, 0xb3, 0x7a, 0x1d, 0x6b, 0xf6, 0x41, 0xfe, 0x13, 0x96, 0x72, 0xa5, 0x3e,
		0x77, 0x8f, 0xcf, 0x52, 0x71, 0x8d, 0xed, 0x30, 0x74, 0xae, 0x25, 0x8a, 0xad, 0xc5, 0x05, 0xa1,
		0xb3, 0xa0, 0xb3, 0xa0, 0xb3, 0xa0, 0xb3, 0xa0, 0xb3, 0xd6, 0x76, 0x1d, 0x42, 0x91, 0x34, 0x1c,
		0x63, 0xe0, 0xf8, 0x81, 0x13, 0x49, 0x3c, 0x28, 0x4c, 0xae, 0x08, 0xd7, 0x08, 0xd7, 0x08, 0xd7,
		0x08, 0xd7, 0x08, 0xd7, 0xb8, 0xb6, 0xeb, 0x26, 0x8e, 0x17, 0xbd, 0x97, 0xe8, 0x18, 0x2b, 0xc8,
		0xc3, 0x7c, 0xfd, 0x8d, 0x21, 0x0f, 0x33, 0xfb, 0xeb, 0x22, 0x0f, 0x53, 0xdb, 0xa5, 0x54, 0xaa,
		0x20, 0x0b, 0x93, 0xdd, 0x55, 0xfa, 0xe8, 0x3f, 0x9a, 0x3d, 0x44, 0xe4, 0xae, 0xff, 0x68, 0xd6,
		0xcd, 0xe0, 0x29, 0xf4, 0x1e, 0xcd, 0xb0, 0xd3, 0x3b, 0x8f, 0xbe, 0xa3, 0x91, 0x73, 0x25, 0x82,
		0x30, 0xfb, 0xc6, 0xa3, 0xf3, 0xeb, 0x30, 0xef, 0x3c, 0xba, 0x87, 0xce, 0xa3, 0xa4, 0x62, 0x07,
		0xe8, 0x3c, 0x9a, 0x6f, 0x97, 0x9c, 0x79, 0xe7, 0xd1, 0xc1, 0x62, 0xe7, 0x4b, 0x0a, 0xc6, 0xce,
		0xaf, 0x27, 0x27, 0x14, 0x5b, 0x44, 0x28, 0x96, 0x36, 0x8c, 0xca, 0x86, 0x53, 0x65, 0xb0, 0xaa,
		0x0c, 0x5e, 0x55, 0xc1, 0xac, 0x1c, 0x6d, 0x98, 0x75, 0x28, 0x36, 0x6b, 0xf8, 0x4d, 0x2e, 0x34,
		0x14, 0xf6, 0xd0, 0x8c, 0x95, 0xc9, 0xb5, 0xed, 0xca, 0x4f, 0x95, 0x5c, 0xbd, 0xbc, 0xa4, 0x15,
		0x29, 0x37, 0x10, 0x24, 0x7d, 0x7e, 0xb6, 0x8a, 0xb9, 0xd9, 0x4a, 0xe7, 0x65, 0xab, 0x9a, 0x93,
		0xad, 0x7c, 0x3e, 0xb6, 0xf2, 0xb9, 0xd8, 0xaa, 0xe7, 0x61, 0xeb, 0x35, 0x36, 0x51, 0xfa, 0xdc,
		0x6b, 0x75, 0xf3, 0xae, 0x15, 0xcc, 0xb9, 0x56, 0x34, 0xdf, 0x5a, 0xc1, 0x14, 0x73, 0x95, 0xf3,
		0xac, 0x15, 0x0f, 0x0b, 0x56, 0x3d, 0xbf, 0x9a, 0xc2, 0x4c, 0x60, 0x05, 0xf3, 0xaa, 0x95, 0xce,
		0xa9, 0xa6, 0xb2, 0xe4, 0x54, 0xcf, 0xa5, 0x26, 0xb1, 0xf6, 0x34, 0x9d, 0xcf, 0xdc, 0xd7, 0x65,
		0x64, 0xad, 0x84, 0x90, 0xca, 0x37, 0xe1, 0xba, 0xbe, 0x42, 0x4d, 0xb9, 0x76, 0x7d, 0x88, 0x4a,
		0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a,
		0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x88, 0x4a, 0x4e, 0xa2, 0x32, 0x10, 0x51, 0x60, 0x7b, 0xe1,
		0x95, 0x13, 0x86, 0x8e, 0xef, 0x29, 0x54, 0x97, 0x8f, 0x19, 0x02, 0x99, 0x09, 0x99, 0x09, 0x99,
		0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99,
		0x09, 0x99, 0x09, 0x99, 0xc9, 0xe3, 0x0a, 0x59, 0x67, 0xf4, 0x4a, 0xaa, 0x71, 0x4c, 0xae, 0x47,
		0xa5, 0xd6, 0x71, 0x56, 0x9e, 0x56, 0x90, 0x52, 0x7e, 0xb1, 0x43, 0xa4, 0xf6, 0xb1, 0x17, 0xdf,
		0xb3, 0x35, 0x17, 0xcf, 0xe8, 0xc5, 0xf4, 0xc0, 0x3b, 0xb2, 0x23, 0x89, 0x2d, 0x0a, 0xb3, 0xae,
		0xb7, 0xdd, 0x51, 0x51, 0xfa, 0x53, 0x42, 0xe9, 0x0f, 0xab, 0xc8, 0x0b, 0x4a, 0x7f, 0x50, 0xfa,
		0xf3, 0x9c, 0x87, 0x86, 0xd2, 0x1f, 0x6d, 0xe4, 0x16, 0xc2, 0xe7, 0xba, 0x81, 0xb8, 0x72, 0x30,
		0x57, 0x0e, 0xea, 0xaa, 0xc1, 0x5d, 0xae, 0x7e, 0x46, 0xf8, 0x3c, 0x33, 0x0c, 0x46, 0xf8, 0x3c,
		0x83, 0x1b, 0x45, 0xf8, 0x1c, 0xe1, 0x73, 0xd9, 0x4b, 0x0e, 0xe1, 0x73, 0x84, 0xcf, 0x11, 0x3e,
		0x27, 0x7f, 0x3f, 0x28, 0xfd, 0x81, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84,
		0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x84, 0xa8, 0x24,
		0x2d, 0x2a, 0x51, 0xfa, 0x03, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99,
		0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x09, 0x99, 0x99, 0x1f, 0x99, 0x89,
		0xd2, 0x9f, 0x17, 0x5c, 0x8f, 0x58, 0xe9, 0x8f, 0x8c, 0xea, 0x8b, 0x1d, 0x5a, 0x95, 0x3f, 0x19,
		0x0e, 0x3f, 0xcb, 0x7e, 0x4b, 0x60, 0x76, 0x20, 0xfd, 0x4d, 0xa5, 0xf9, 0xf0, 0xc0, 0xd9, 0x36,
		0x62, 0x33, 0x3d, 0xf0, 0x0d, 0xe1, 0x8d, 0x62, 0xfc, 0x4b, 0xdc, 0x4e, 0xdf, 0xa3, 0x33, 0x4c,
		0x79, 0xcd, 0x18, 0x2d, 0x27, 0x8c, 0xea, 0x51, 0x94, 0x4d, 0xb5, 0xca, 0x54, 0x0d, 0x36, 0x5c,
		0x71, 0x25, 0xbc, 0x19, 0x25, 0xcc, 0x60, 0x40, 0xe3, 0xb1, 0x7d, 0xb3, 0x74, 0x85, 0xe2, 0xfb,
		0x72, 0xf9, 0xa0, 0x5a, 0x2e, 0xef, 0x55, 0xf7, 0xab, 0x7b, 0xb5, 0x4a, 0xa5, 0x78, 0x50, 0xcc,
		0x80, 0x10, 0x1b, 0x9d, 0x60, 0x28, 0x02, 0x31, 0x3c, 0x9c, 0xbe, 0x13, 0x6f, 0xe2, 0xba, 0xa4,
		0x97, 0x4e, 0xc6, 0xd8, 0x4a, 0x05, 0x53, 0x33, 0x00, 0x53, 0x02, 0x20, 0x9a, 0x2e, 0x7a, 0xa6,
		0x87, 0x71, 0xe9, 0xfc, 0xa6, 0x94, 0x96, 0x7a, 0x56, 0x4b, 0x5c, 0xed, 0xd2, 0x4e, 0x71, 0x41,
		0x2b, 0x5b, 0xc8, 0xe9, 0x2c, 0xdf, 0xed, 0x17, 0x5b, 0x0a, 0x0b, 0xcd, 0x70, 0xc3, 0xe1, 0x45,
		0x6a, 0xcb, 0x2b, 0x89, 0x7e, 0xc7, 0xbf, 0x35, 0xa5, 0x6d, 0x90, 0x6e, 0xf1, 0x7a, 0xea, 0x45,
		0xea, 0x59, 0x9c, 0x0d, 0x66, 0x7a, 0xf6, 0x97, 0xd5, 0xd9, 0x5e, 0xe6, 0x67, 0x77, 0x99, 0x9f,
		0xcd, 0x65, 0x7d, 0xf6, 0x46, 0xcb, 0xbd, 0xa4, 0x5d, 0xcc, 0x6d, 0xb8, 0xa1, 0x6d, 0x46, 0xb7,
		0x63, 0x91, 0xfe, 0x60, 0xf1, 0x25, 0x5c, 0x59, 0x5c, 0x22, 0x6d, 0x25, 0x92, 0x49, 0x87, 0x8c,
		0xcc, 0x12, 0x15, 0xb2, 0x4c, 0x48, 0x90, 0x92, 0x78, 0x90, 0x75, 0x82, 0x81, 0xb4, 0x44, 0x02,
		0x69, 0x09, 0x03, 0xb2, 0x12, 0x03, 0x68, 0x47, 0x0c, 0xb2, 0xea, 0x40, 0x91, 0x20, 0x4b, 0x76,
		0x2b, 0x72, 0x1d, 0xc3, 0xb2, 0x5a, 0x90, 0xd9, 0x36, 0xfb, 0xc9, 0x3c, 0xf7, 0x4a, 0x46, 0xae,
		0x95, 0xd4, 0xdc, 0x2a, 0x59, 0xb9, 0x54, 0xd2, 0x73, 0xa7, 0xa4, 0xe7, 0x4a, 0xc9, 0xce, 0x8d,
		0xe2, 0x75, 0xda, 0x90, 0x75, 0x73, 0x9e, 0x29, 0x70, 0x85, 0xf2, 0x1a, 0xa3, 0xc5, 0x57, 0xd3,
		0xac, 0x2f, 0xda, 0x1e, 0xfa, 0xa2, 0xb1, 0x80, 0x52, 0x65, 0x90, 0xaa, 0x0c, 0x5a, 0x55, 0x41,
		0x6c, 0xb6, 0x50, 0x9b, 0x31, 0xe4, 0x4a, 0x83, 0xde, 0x65, 0x08, 0x96, 0x5f, 0x5b, 0x30, 0xbd,
		0xa8, 0xdc, 0x3a, 0x82, 0x22, 0xea, 0x08, 0x78, 0x03, 0xb5, 0x2a, 0xc0, 0x56, 0x0e, 0xdc, 0xca,
		0x01, 0x5c, 0x35, 0x90, 0xcb, 0x01, 0x74, 0x49, 0xc0, 0x2e, 0x1d, 0xe0, 0x93, 0x0b, 0xda, 0xa1,
		0x29, 0x6e, 0x22, 0x11, 0x78, 0xb6, 0x6b, 0xca, 0x04, 0xfd, 0x0d, 0xd4, 0x58, 0x37, 0x44, 0xf2,
		0x2a, 0x96, 0xeb, 0x10, 0x94, 0x39, 0x06, 0x95, 0x0e, 0x82, 0x84, 0xa3, 0x50, 0xed, 0x30, 0xc8,
		0x38, 0x0e, 0x32, 0x0e, 0x84, 0x8a, 0x23, 0x91, 0xeb, 0x50, 0x24, 0x3b, 0x16, 0x65, 0x0e, 0x26,
		0xb9, 0xb0, 0x9c, 0x76, 0xf7, 0x4f, 0x62, 0x8e, 0xac, 0x44, 0x6c, 0x42, 0x4e, 0x46, 0xb9, 0xb3,
		0xa1, 0xe0, 0x74, 0x48, 0x39, 0x1f, 0x2a, 0x4e, 0x88, 0x9c, 0x33, 0x22, 0xe7, 0x94, 0xa8, 0x39,
		0x27, 0x35, 0x4e, 0x4a, 0x91, 0xb3, 0x52, 0xee, 0xb4, 0x12, 0x03, 0x12, 0x65, 0x12, 0xf8, 0x93,
		0x48, 0x98, 0x91, 0x7d, 0xa9, 0x7e, 0xcf, 0x2e, 0x80, 0xec, 0x01, 0xdb, 0x14, 0xef, 0x15, 0xb5,
		0x45, 0x9d, 0x64, 0xdc, 0x1d, 0x25, 0xb7, 0x47, 0xd2, 0xfd, 0x51, 0x73, 0x83, 0x64, 0xdd, 0x21,
		0x59, 0xb7, 0x48, 0xd5, 0x3d, 0xaa, 0x75, 0x93, 0x8a, 0xdd, 0x65, 0xf2, 0x52, 0xa4, 0x37, 0x25,
		0x79, 0x12, 0x75, 0xa4, 0x37, 0x2b, 0x79, 0xca, 0x47, 0x55, 0x09, 0x98, 0xa2, 0xa6, 0xb9, 0xc9,
		0x63, 0x5f, 0x34, 0x20, 0x78, 0x47, 0x75, 0x33, 0x14, 0xe2, 0xe4, 0x66, 0xc3, 0x2c, 0xc5, 0xcd,
		0x53, 0x1e, 0xb5, 0x8b, 0x40, 0x63, 0x0b, 0xa2, 0xf0, 0xbc, 0xba, 0xd4, 0xed, 0x1b, 0x2c, 0xf5,
		0x17, 0x2e, 0x75, 0xd5, 0x4d, 0x5b, 0x58, 0xae, 0xf9, 0x37, 0xb0, 0x62, 0x47, 0x5a, 0x53, 0x18,
		0x7a, 0xf7, 0xaf, 0x10, 0xf3, 0x8c, 0x91, 0x1f, 0xfc, 0x65, 0x07, 0x43, 0xc7, 0xbb, 0x34, 0xed,
		0xe1, 0x30, 0x10, 0x61, 0x48, 0x27, 0x88, 0xf2, 0x80, 0x6d, 0x08, 0xa2, 0x20, 0x88, 0x82, 0x20,
		0x0a, 0x82, 0x28, 0x08, 0xa2, 0x20, 0x88, 0x42, 0x0a, 0x75, 0x9c, 0xf1, 0x75, 0x79, 0xe1, 0xa5,
		0x4c, 0xcf, 0x37, 0xff, 0xeb, 0x7b, 0x82, 0x50, 0x48, 0xa5, 0xf8, 0x9e, 0x80, 0x2d, 0x27, 0x76,
		0x14, 0x89, 0xc0, 0x23, 0x13, 0x55, 0x31, 0xde, 0xbe, 0x3d, 0xdb, 0x33, 0x6b, 0xfd, 0xbf, 0xcf,
		0x8a, 0x66, 0xad, 0x3f, 0xfb, 0x58, 0x8c, 0xff, 0x9a, 0x7d, 0x2e, 0x9d, 0xed, 0x99, 0xe5, 0xc5,
		0xe7, 0xca, 0xd9, 0x9e, 0x59, 0xe9, 0xef, 0x9e, 0x9f, 0xbf, 0xdb, 0xfd, 0xb1, 0x7f, 0xf7, 0xf2,
		0x7f, 0xf8, 0xf6, 0x1f, 0x67, 0xe7, 0xe7, 0xe3, 0x1f, 0xed, 0xbb, 0xe9, 0x9f, 0xad, 0xbb, 0xfe,
		0x3f, 0x77, 0x7f, 0xa3, 0x82, 0xbd, 0x53, 0x43, 0xcf, 0xcf, 0xdf, 0xf5, 0x7f, 0x31, 0x20, 0x01,
		0x72, 0x28, 0x01, 0xae, 0xec, 0xf0, 0x3b, 0x1d, 0xd2, 0x1f, 0x5b, 0x03, 0x9a, 0x0f, 0x9a, 0x0f,
		0x9a, 0x0f, 0x9a, 0x0f, 0x9a, 0x0f, 0x9a, 0x4f, 0xee, 0xac, 0xf4, 0x3d, 0x21, 0x5e, 0x5f, 0xc1,
		0x51, 0xe9, 0xda, 0x17, 0x8e, 0x4a, 0x39, 0x70, 0x9b, 0x0d, 0xb3, 0x70, 0x54, 0xca, 0x0d, 0x9d,
		0x57, 0x97, 0x3a, 0x8e, 0x4a, 0x5f, 0xbc, 0xd4, 0xf7, 0x4b, 0x58, 0xeb, 0x3c, 0x78, 0x10, 0x1d,
		0x2b, 0x10, 0x1f, 0x51, 0x10, 0x1f, 0x11, 0x51, 0xe0, 0x0c, 0x08, 0x45, 0x48, 0x66, 0xf6, 0x20,
		0x46, 0x82, 0x18, 0x09, 0x62, 0x24, 0x88, 0x91, 0x20, 0x46, 0x82, 0x18, 0x09, 0x2d, 0xd4, 0x09,
		0xc7, 0x23, 0x93, 0x84, 0x93, 0x5a, 0x76, 0x54, 0x07, 0x88, 0x94, 0x20, 0x52, 0x82, 0x48, 0x09,
		0x22, 0x25, 0x88, 0x94, 0xb0, 0x5b, 0xea, 0x07, 0x95, 0xca, 0x3e, 0xf2, 0xc9, 0x11, 0x2c, 0x41,
		0xb0, 0x84, 0x49, 0xb0, 0x24, 0xdb, 0x66, 0xea, 0xaf, 0x8c, 0x98, 0x64, 0xd9, 0x77, 0x1d, 0x61,
		0x13, 0x84, 0x4d, 0x10, 0x36, 0x41, 0xd8, 0x04, 0x61, 0x13, 0x84, 0x4d, 0x5e, 0x89, 0x3a, 0xc2,
		0x9b, 0x5c, 0x89, 0x60, 0x36, 0xf1, 0x8f, 0x50, 0xe2, 0x78, 0x99, 0x80, 0x2d, 0x0d, 0x6f, 0x72,
		0x35, 0x7d, 0x59, 0x77, 0x79, 0x25, 0x74, 0xb9, 0x6a, 0x2c, 0x25, 0x79, 0x2a, 0xfd, 0xa3, 0x76,
		0x28, 0x98, 0x94, 0xe9, 0x86, 0xc3, 0x8b, 0x42, 0x32, 0xe6, 0x2c, 0xf9, 0x34, 0xfd, 0x10, 0x7f,
		0x57, 0x58, 0x6b, 0xc8, 0x5b, 0x50, 0xd9, 0x39, 0x71, 0x47, 0xfe, 0x14, 0xce, 0x56, 0x38, 0xbc,
		0xb0, 0x5a, 0xa1, 0x3d, 0x45, 0xef, 0x70, 0xf1, 0x61, 0xfa, 0x77, 0xfc, 0x8d, 0x55, 0x0f, 0x1b,
		0xf3, 0x87, 0x33, 0xfd, 0x4e, 0xc2, 0xac, 0x7b, 0x3a, 0x1b, 0x56, 0xc1, 0x66, 0x35, 0xe2, 0x45,
		0x6a, 0xfa, 0x23, 0x33, 0x14, 0xc1, 0xb5, 0x33, 0x20, 0xd0, 0x48, 0x74, 0xc3, 0x22, 0xf4, 0x14,
		0xcd, 0xab, 0xaa, 0x43, 0x4f, 0x51, 0x0e, 0xea, 0x0d, 0x3d, 0x45, 0x41, 0xfd, 0x96, 0x1e, 0xbe,
		0xf2, 0x9e, 0xa2, 0x53, 0x07, 0x42, 0xc1, 0xa3, 0x3d, 0xe8, 0xd9, 0xd4, 0x3b, 0x36, 0x22, 0x0e,
		0x8e, 0x8c, 0xa3, 0xa3, 0xe4, 0xf0, 0x48, 0x3a, 0x3e, 0x6a, 0x0e, 0x90, 0xac, 0x23, 0x24, 0xeb,
		0x10, 0xa9, 0x3a, 0x46, 0xf5, 0x51, 0x99, 0x1d, 0x02, 0x61, 0x4c, 0xd5, 0x0e, 0x73, 0x29, 0x0e,
		0xa0, 0x72, 0x92, 0xc4, 0xa3, 0x18, 0xa8, 0x3a, 0x3e, 0x42, 0xd0, 0x69, 0x92, 0x73, 0x9e, 0x14,
		0x9d, 0x28, 0x69, 0x67, 0x4a, 0xd5, 0xa9, 0x92, 0x77, 0xae, 0xe4, 0x9d, 0x2c, 0x75, 0x67, 0x4b,
		0xc3, 0xe9, 0x12, 0x71, 0xbe, 0xe4, 0x9c, 0x70, 0x62, 0x10, 0xc1, 0xc9, 0x18, 0x8f, 0x02, 0x2b,
		0xb9, 0x49, 0x19, 0x8f, 0xb9, 0x6d, 0x6a, 0xc9, 0x91, 0xd4, 0xdc, 0x37, 0x65, 0x37, 0xce, 0xc2,
		0x9d, 0x53, 0x77, 0xeb, 0x6c, 0xdc, 0x3b, 0x1b, 0x37, 0xcf, 0xc5, 0xdd, 0xd3, 0x72, 0xfb, 0xc4,
		0xdc, 0x7f, 0xf2, 0x12, 0xc9, 0xa4, 0x14, 0x3d, 0x8a, 0x7a, 0x64, 0x26, 0x7d, 0x3c, 0xe6, 0x63,
		0xab, 0x04, 0x4d, 0xa3, 0x55, 0xb4, 0xb5, 0xfe, 0x45, 0xd3, 0x45, 0xec, 0x50, 0x2d, 0xea, 0x62,
		0x42, 0xee, 0x36, 0xcc, 0x24, 0x5a, 0xf4, 0xb5, 0x61, 0x27, 0xe1, 0xaa, 0x18, 0xe2, 0xee, 0x63,
		0x75, 0xeb, 0xd8, 0x37, 0xd8, 0x3a, 0x29, 0x6f, 0x1d, 0xaa, 0x93, 0x49, 0x58, 0xef, 0xa1, 0x37,
		0xb0, 0xea, 0x39, 0x5f, 0xfd, 0x37, 0x78, 0x3e, 0xc4, 0x31, 0x98, 0xe2, 0x24, 0x94, 0x47, 0x89,
		0x3c, 0xb9, 0xc9, 0x28, 0x4c, 0x9c, 0x03, 0x82, 0x66, 0xdb, 0xac, 0x3a, 0x04, 0xcd, 0xb6, 0xd9,
		0x10, 0x08, 0x9a, 0xa5, 0x6c, 0x28, 0x82, 0x66, 0xfc, 0x55, 0x0f, 0x83, 0xa0, 0x19, 0xd1, 0xc9,
		0x2e, 0x8f, 0x79, 0x5c, 0x0a, 0x93, 0x5e, 0x36, 0xbd, 0x1b, 0xb1, 0xc9, 0x2f, 0x1b, 0x06, 0x62,
		0x12, 0xcc, 0x83, 0x8f, 0x85, 0xd0, 0x64, 0x18, 0x48, 0x2a, 0x7e, 0x92, 0x8a, 0x48, 0xe7, 0xd4,
		0x47, 0xa1, 0x9d, 0x4c, 0x93, 0x3a, 0x48, 0x27, 0x48, 0x27, 0x48, 0x27, 0x48, 0x27, 0x48, 0x27,
		0x48, 0x27, 0x8d, 0xa4, 0x13, 0xad, 0x4e, 0xb0, 0x8f, 0x39, 0xda, 0x03, 0x24, 0x1d, 0xbc, 0xf0,
		0x0b, 0x49, 0x07, 0x3a, 0x32, 0xbc, 0x0d, 0x33, 0x91, 0x74, 0xa0, 0xbb, 0x0f, 0x59, 0xdd, 0x3a,
		0x48, 0x3a, 0x48, 0x7d, 0xeb, 0x10, 0xec, 0x5c, 0xcb, 0x7a, 0xfb, 0x20, 0xdf, 0xe0, 0x59, 0x5f,
		0x08, 0x8e, 0x91, 0x87, 0x5f, 0x23, 0xf2, 0x09, 0x27, 0x18, 0x4c, 0x8d, 0x43, 0x58, 0xec, 0x39,
		0x66, 0x21, 0x2c, 0xb6, 0x8d, 0x40, 0x44, 0x58, 0x6c, 0x8b, 0x0d, 0x81, 0xb0, 0x58, 0xca, 0x86,
		0x22, 0x2c, 0xc6, 0x5f, 0xd2, 0x30, 0x29, 0xc3, 0x79, 0x4f, 0x38, 0x20, 0x56, 0x41, 0x40, 0xec,
		0x85, 0x5f, 0x08, 0x88, 0xe5, 0x4a, 0xd5, 0x23, 0x20, 0xa6, 0xab, 0xf7, 0x58, 0xdd, 0x3a, 0x08,
		0x88, 0xa5, 0xbe, 0x75, 0x4a, 0x15, 0x84, 0xc3, 0x34, 0x25, 0x82, 0x74, 0xad, 0x42, 0x38, 0x8c,
		0xb2, 0x25, 0x54, 0xda, 0xf8, 0x10, 0x99, 0x3b, 0xb0, 0x61, 0x17, 0x87, 0x39, 0x04, 0xeb, 0x8d,
		0xd7, 0x0b, 0x6b, 0xfd, 0x6a, 0x0b, 0x94, 0x1a, 0xf1, 0xed, 0x10, 0x1f, 0x5c, 0x10, 0xff, 0x4f,
		0x9d, 0xd1, 0xe9, 0xec, 0xd1, 0xc5, 0xdf, 0xde, 0x7f, 0xa7, 0x70, 0xaa, 0x01, 0x3d, 0xf8, 0x20,
		0x00, 0x1d, 0xa4, 0xe2, 0xf8, 0x04, 0xe3, 0xf7, 0xc4, 0x08, 0x2a, 0xba, 0x5e, 0xbe, 0x64, 0x19,
		0xa1, 0xeb, 0xe5, 0x4b, 0x16, 0x3a, 0xba, 0x5e, 0x6e, 0xcb, 0xc0, 0xd0, 0xf5, 0x92, 0x0f, 0x5d,
		0x26, 0x17, 0x67, 0x4f, 0x50, 0xcb, 0x15, 0xf6, 0x28, 0x10, 0x23, 0x4a, 0x98, 0xb5, 0x28, 0xce,
		0x23, 0xd4, 0xe0, 0xca, 0x38, 0x99, 0x2b, 0x8a, 0x77, 0xef, 0x66, 0xec, 0xbc, 0x30, 0x25, 0x0d,
		0x20, 0x96, 0x04, 0x2c, 0x50, 0xdd, 0x55, 0xfe, 0x5f, 0xe2, 0x96, 0x06, 0x89, 0x34, 0x5a, 0x4e,
		0x18, 0xd5, 0xa3, 0x88, 0x48, 0x93, 0xfb, 0x63, 0xc7, 0x6b, 0xb8, 0x62, 0xea, 0xa1, 0x42, 0x1a,
		0x04, 0xd2, 0x38, 0xb6, 0x6f, 0x96, 0x2c, 0x2a, 0xbe, 0x2f, 0x97, 0x0f, 0xaa, 0xe5, 0xf2, 0x5e,
		0x75, 0xbf, 0xba, 0x57, 0xab, 0x54, 0x8a, 0x07, 0x45, 0x02, 0xd1, 0x56, 0xa3, 0x13, 0x0c, 0x45,
		0x20, 0x86, 0x87, 0xd3, 0x45, 0xe5, 0x4d, 0x5c, 0x37, 0xd7, 0x7b, 0x8b, 0x58, 0x94, 0x49, 0x8b,
		0xe8, 0x12, 0x85, 0x01, 0x37, 0x4c, 0xe3, 0x49, 0x06, 0x46, 0xea, 0xea, 0x0f, 0x3e, 0x18, 0xa9,
		0xbb, 0x05, 0xd8, 0x60, 0xba, 0xee, 0x33, 0x40, 0x25, 0x37, 0x63, 0x76, 0xdf, 0x68, 0x0c, 0x17,
		0xaa, 0x61, 0x82, 0x03, 0x3c, 0x28, 0x40, 0x03, 0xc2, 0x28, 0x20, 0x77, 0xdb, 0xcb, 0xdb, 0x7c,
		0x12, 0x37, 0x9e, 0xe1, 0x3a, 0xde, 0x77, 0x33, 0x0e, 0xc0, 0x98, 0xce, 0x50, 0xfa, 0xbe, 0xbb,
		0x0f, 0x9a, 0xad, 0x98, 0x21, 0x19, 0x78, 0xd4, 0x9c, 0x11, 0x29, 0x3b, 0x0b, 0x52, 0x79, 0xe6,
		0x43, 0xe2, 0x6c, 0x47, 0xf5, 0x19, 0x0e, 0x99, 0xb3, 0x1a, 0x32, 0x67, 0x32, 0x54, 0xce, 0x5e,
		0xf4, 0x26, 0x58, 0xca, 0xce, 0x4c, 0x08, 0x9c, 0x8d, 0xa8, 0x3c, 0x03, 0xd9, 0x3c, 0xeb, 0x58,
		0x75, 0x77, 0xa0, 0x31, 0x5b, 0x3f, 0xe1, 0x05, 0xfd, 0x9e, 0x72, 0x64, 0x65, 0x24, 0x66, 0xd9,
		0x08, 0x35, 0x14, 0xa6, 0x08, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0x03, 0x0a, 0xa3, 0x2b, 0x85, 0x51,
		0x35, 0xec, 0x54, 0xf1, 0x84, 0x71, 0x12, 0x13, 0xc5, 0x15, 0x4f, 0x10, 0x57, 0x9e, 0x3b, 0x49,
		0x21, 0x57, 0x92, 0x54, 0x6e, 0x24, 0x95, 0x5c, 0x48, 0x72, 0xb9, 0x8f, 0xe4, 0x72, 0x1d, 0xa9,
		0xe5, 0x36, 0xe6, 0xeb, 0xfc, 0x53, 0xf5, 0x84, 0x6e, 0xc3, 0x8e, 0x22, 0x7b, 0xf0, 0x4d, 0x0c,
		0x67, 0x53, 0xae, 0xd5, 0xa7, 0x33, 0x25, 0x28, 0xb6, 0x6e, 0x98, 0xea, 0xcc, 0x33, 0x12, 0xc5,
		0x02, 0x64, 0x8a, 0x04, 0x28, 0x15, 0x07, 0x90, 0x2c, 0x0a, 0xa0, 0x56, 0x0c, 0x40, 0xb6, 0x08,
		0x80, 0x6c, 0xf2, 0x3f, 0xd5, 0xa4, 0xff, 0x7c, 0x67, 0x00, 0x93, 0x49, 0xee, 0x4f, 0x50, 0x67,
		0xe8, 0x47, 0x91, 0x18, 0x9a, 0xff, 0x99, 0xd8, 0x43, 0x0a, 0xb8, 0x43, 0x68, 0xda, 0x0e, 0xb9,
		0xe9, 0x3a, 0x52, 0xa7, 0xe9, 0xa8, 0x47, 0x8a, 0x7e, 0xae, 0x91, 0x02, 0x19, 0xfa, 0x4f, 0x58,
		0x84, 0x0c, 0x7d, 0x36, 0x9e, 0x57, 0xe1, 0x5e, 0x4a, 0x8e, 0xae, 0xae, 0xec, 0xf0, 0x3b, 0x1d,
		0x79, 0xb8, 0x62, 0x15, 0xb4, 0x21, 0xb4, 0x21, 0xb4, 0x21, 0xb4, 0x21, 0xb4, 0x21, 0xb4, 0x21,
		0x29, 0xd4, 0xa1, 0xd2, 0x50, 0x95, 0x50, 0x03, 0x55, 0x62, 0x0d, 0x53, 0x09, 0x75, 0x09, 0xa0,
		0xd8, 0x10, 0x95, 0x6a, 0x73, 0x7b, 0xa2, 0x0d, 0x4f, 0x29, 0xf7, 0x68, 0xa4, 0x34, 0x62, 0x82,
		0x62, 0x03, 0x53, 0xea, 0x4b, 0x7d, 0xbf, 0x84, 0xb5, 0xce, 0x83, 0x07, 0xd1, 0xb1, 0xa2, 0x8f,
		0x22, 0x6a, 0xfd, 0x11, 0x16, 0x45, 0xd4, 0x3f, 0xa9, 0x92, 0x5c, 0x4a, 0xbc, 0x56, 0xde, 0xea,
		0x93, 0x56, 0xbd, 0xe4, 0xfc, 0x77, 0x4e, 0x3f, 0x2a, 0x6c, 0xdd, 0x89, 0x4a, 0x69, 0xad, 0xb0,
		0x80, 0x3a, 0x06, 0xe4, 0xbe, 0x4a, 0xfa, 0x7e, 0xd7, 0xa3, 0xb6, 0x68, 0xfb, 0x57, 0xeb, 0x85,
		0xa1, 0xbd, 0x5a, 0x85, 0xaf, 0xae, 0xc2, 0x68, 0xc3, 0x14, 0xd4, 0x19, 0x65, 0x7a, 0x61, 0xd4,
		0x19, 0xa1, 0xce, 0x68, 0x66, 0x08, 0xea, 0x8c, 0xf2, 0xc4, 0xb0, 0x50, 0x67, 0x84, 0x3a, 0x23,
		0xd4, 0x19, 0xa1, 0xce, 0x88, 0xa6, 0x33, 0x22, 0xe7, 0x94, 0xa8, 0x39, 0xa7, 0x7c, 0x86, 0x08,
		0x95, 0xd7, 0x19, 0x25, 0xca, 0x24, 0x2e, 0xe7, 0x31, 0x23, 0xfb, 0x92, 0x4e, 0x2e, 0xd9, 0x03,
		0xb6, 0x21, 0xa3, 0x0c, 0x19, 0x65, 0x0c, 0xdc, 0x1f, 0x35, 0x37, 0x48, 0xd6, 0x1d, 0x92, 0x75,
		0x8b, 0x54, 0xdd, 0xa3, 0x5a, 0x37, 0xa9, 0xd8, 0x5d, 0x26, 0x2f, 0x85, 0x66, 0x46, 0xd9, 0x7e,
		0x89, 0x50, 0x4a, 0x59, 0x15, 0x29, 0x65, 0x6b, 0x5f, 0x48, 0x29, 0xe3, 0x40, 0x6e, 0x36, 0xcc,
		0x42, 0x4a, 0x19, 0x37, 0x78, 0x5e, 0x5d, 0xea, 0x48, 0x29, 0x7b, 0xf1, 0x52, 0x2f, 0x97, 0x6a,
		0xe5, 0xda, 0x41, 0xb5, 0x54, 0xab, 0x60, 0xcd, 0xf3, 0x20, 0x44, 0x74, 0xac, 0xe8, 0xa3, 0x14,
		0x4f, 0xfa, 0xb6, 0x18, 0xf9, 0xc1, 0x5f, 0x76, 0x30, 0x74, 0xbc, 0x4b, 0xd3, 0x1e, 0x0e, 0x03,
		0x11, 0x86, 0x74, 0x82, 0x28, 0x0f, 0xd8, 0x86, 0x20, 0x0a, 0x82, 0x28, 0x08, 0xa2, 0x20, 0x88,
		0x82, 0x20, 0x0a, 0x82, 0x28, 0xa4, 0x50, 0xc7, 0x19, 0x5f, 0x97, 0x17, 0x5e, 0xca, 0xf4, 0x7c,
		0xf3, 0xbf, 0xbe, 0x27, 0xd0, 0xbb, 0x65, 0xcd, 0x5b, 0xe4, 0xb9, 0x77, 0xcb, 0xdb, 0x7f, 0x9c,
		0x9d, 0x9f, 0x8f, 0x7f, 0xb4, 0xef, 0xa6, 0x7f, 0xb6, 0xee, 0xfa, 0xff, 0xdc, 0xfd, 0x8d, 0x0a,
		0xf6, 0x4e, 0x0d, 0x3d, 0x3f, 0x7f, 0xd7, 0xff, 0xc5, 0x80, 0x04, 0xc8, 0xa1, 0x04, 0xa0, 0xd5,
		0x85, 0x03, 0xdd, 0x37, 0x40, 0xf3, 0x41, 0xf3, 0x41, 0xf3, 0x41, 0xf3, 0x41, 0xf3, 0xd1, 0x7d,
		0xe3, 0x29, 0x17, 0x85, 0xee, 0x1b, 0xeb, 0x5f, 0x38, 0x2a, 0xe5, 0xc0, 0x6d, 0x36, 0xcc, 0xc2,
		0x51, 0x29, 0x37, 0x74, 0x5e, 0x5d, 0xea, 0x38, 0x2a, 0x7d, 0xf1, 0x52, 0x47, 0xf7, 0x0d, 0x2e,
		0x3c, 0x88, 0x8e, 0x15, 0x88, 0x8f, 0x28, 0x88, 0x8f, 0x88, 0x28, 0x70, 0x06, 0x84, 0x22, 0x24,
		0x33, 0x7b, 0x10, 0x23, 0x41, 0x8c, 0x04, 0x31, 0x12, 0xc4, 0x48, 0x10, 0x23, 0x41, 0x8c, 0x84,
		0x16, 0xea, 0x84, 0xe3, 0x91, 0x49, 0xc2, 0x49, 0x2d, 0x3b, 0xaa, 0x03, 0x44, 0x4a, 0x10, 0x29,
		0x41, 0xa4, 0x04, 0x91, 0x12, 0x44, 0x4a, 0xd8, 0x2d, 0xf5, 0x83, 0x4a, 0x65, 0x1f, 0xf9, 0xe4,
		0x08, 0x96, 0x20, 0x58, 0xc2, 0x24, 0x58, 0x12, 0x77, 0xcb, 0xa3, 0x16, 0x31, 0x99, 0x19, 0x85,
		0xb0, 0x09, 0xc2, 0x26, 0x08, 0x9b, 0x20, 0x6c, 0x82, 0xb0, 0x09, 0xc2, 0x26, 0xa4, 0x50, 0x47,
		0x78, 0x93, 0x2b, 0x11, 0xcc, 0xfa, 0xec, 0x12, 0x4a, 0x1c, 0x2f, 0x13, 0xb0, 0xa5, 0xe1, 0x4d,
		0xae, 0xa6, 0x2f, 0xeb, 0x0e, 0x84, 0x4e, 0xfa, 0xb3, 0x1f, 0x07, 0xfe, 0xd8, 0xbe, 0x54, 0xd9,
		0x26, 0x70, 0x63, 0xa7, 0xdc, 0x9b, 0x04, 0x32, 0x07, 0x32, 0x07, 0x32, 0x07, 0x32, 0x07, 0x32,
		0x07, 0x32, 0x47, 0x0a, 0x75, 0x2e, 0x7c, 0xdf, 0x15, 0x36, 0x29, 0x22, 0x57, 0xc4, 0xe0, 0x1e,
		0xfd, 0xb7, 0x04, 0x06, 0xf7, 0xfc, 0x6c, 0x68, 0xc7, 0xfa, 0x3c, 0x03, 0x8c, 0xef, 0x59, 0x1d,
		0xe4, 0x11, 0x86, 0x76, 0x63, 0xfe, 0x78, 0xf2, 0x37, 0xc3, 0x47, 0xc1, 0xb8, 0x83, 0x78, 0xa1,
		0x9a, 0xfe, 0xc8, 0x0c, 0x45, 0x70, 0xed, 0x0c, 0x08, 0x74, 0x62, 0xdf, 0xb0, 0x08, 0x4d, 0xd9,
		0xf3, 0xaa, 0xa4, 0xd0, 0x94, 0x9d, 0x83, 0x62, 0x42, 0x53, 0x76, 0xd0, 0xbf, 0xa5, 0x87, 0xaf,
		0xbc, 0x29, 0xfb, 0xd4, 0x81, 0x50, 0xf0, 0x68, 0x0f, 0x7a, 0x36, 0xf5, 0x8e, 0x8d, 0x88, 0x83,
		0x23, 0xe3, 0xe8, 0x28, 0x39, 0x3c, 0x92, 0x8e, 0x8f, 0x9a, 0x03, 0x24, 0xeb, 0x08, 0xc9, 0x3a,
		0x44, 0xaa, 0x8e, 0x51, 0x7d, 0x64, 0x66, 0x87, 0x40, 0xe8, 0x50, 0xb5, 0xc3, 0x5c, 0x8a, 0x04,
		0x50, 0x38, 0x63, 0xdb, 0xc0, 0x40, 0xd5, 0x11, 0x12, 0x82, 0x4e, 0x93, 0x9c, 0xf3, 0xa4, 0xe8,
		0x44, 0x49, 0x3b, 0x53, 0xaa, 0x4e, 0x95, 0xbc, 0x73, 0x25, 0xef, 0x64, 0xa9, 0x3b, 0x5b, 0x1a,
		0x4e, 0x97, 0x88, 0xf3, 0x25, 0xe7, 0x84, 0x13, 0x83, 0x08, 0x8e, 0x16, 0x7b, 0x14, 0x58, 0xc9,
		0x8d, 0x1a, 0x7b, 0xcc, 0x6d, 0x53, 0xab, 0x2e, 0xa1, 0xe6, 0xbe, 0x29, 0xbb, 0x71, 0x16, 0xee,
		0x9c, 0xba, 0x5b, 0x67, 0xe3, 0xde, 0xd9, 0xb8, 0x79, 0x2e, 0xee, 0x9e, 0x96, 0xdb, 0x27, 0xe6,
		0xfe, 0x93, 0x97, 0x48, 0x26, 0x8d, 0xe7, 0x51, 0xd4, 0x23, 0x33, 0x2a, 0xed, 0x31, 0x1f, 0x5b,
		0x25, 0x68, 0x1a, 0xad, 0xaa, 0xf7, 0xf5, 0x2f, 0x9a, 0x2e, 0x62, 0x87, 0x6a, 0x55, 0x3c, 0x13,
		0x72, 0xb7, 0x61, 0x26, 0xd1, 0xaa, 0xf9, 0x0d, 0x3b, 0x09, 0x97, 0x15, 0x13, 0x77, 0x1f, 0xab,
		0x5b, 0xc7, 0xbe, 0xc1, 0xd6, 0x49, 0x79, 0xeb, 0x50, 0x1d, 0xed, 0xc6, 0x7a, 0x0f, 0xbd, 0x81,
		0x55, 0xcf, 0xf9, 0xea, 0xbf, 0xc1, 0xf3, 0x21, 0x8e, 0xc1, 0x14, 0x47, 0xc9, 0x3d, 0x4a, 0xe4,
		0xc9, 0x8d, 0x96, 0x63, 0xe2, 0x1c, 0x10, 0x34, 0xdb, 0x66, 0xd5, 0x21, 0x68, 0xb6, 0xcd, 0x86,
		0x40, 0xd0, 0x2c, 0x65, 0x43, 0x11, 0x34, 0xe3, 0xaf, 0x7a, 0x18, 0x04, 0xcd, 0x88, 0x8e, 0xc6,
		0x7b, 0xcc, 0xe3, 0x52, 0x18, 0x95, 0xb7, 0xe9, 0xdd, 0x88, 0x8d, 0xce, 0xdb, 0x30, 0x10, 0xa3,
		0xf4, 0x1e, 0x7c, 0x2c, 0x84, 0x46, 0xeb, 0x41, 0x52, 0xf1, 0x93, 0x54, 0x44, 0x5a, 0xcf, 0x3f,
		0x0a, 0xed, 0x64, 0xba, 0xfc, 0x42, 0x3a, 0x41, 0x3a, 0x41, 0x3a, 0x41, 0x3a, 0x41, 0x3a, 0x41,
		0x3a, 0x69, 0x24, 0x9d, 0x68, 0xb5, 0xd2, 0x7f, 0xcc, 0xd1, 0x1e, 0x20, 0xe9, 0xe0, 0x85, 0x5f,
		0x48, 0x3a, 0xd0, 0x91, 0xe1, 0x6d, 0x98, 0x89, 0xa4, 0x03, 0xdd, 0x7d, 0xc8, 0xea, 0xd6, 0x41,
		0xd2, 0x41, 0xea, 0x5b, 0x87, 0x60, 0xeb, 0x7f, 0xd6, 0xdb, 0x07, 0xf9, 0x06, 0xcf, 0xfa, 0x42,
		0x70, 0x8c, 0x3c, 0xfc, 0x1a, 0x91, 0x4f, 0x38, 0xc1, 0x60, 0x6a, 0x1c, 0xc2, 0x62, 0xcf, 0x31,
		0x0b, 0x61, 0xb1, 0x6d, 0x04, 0x22, 0xc2, 0x62, 0x5b, 0x6c, 0x08, 0x84, 0xc5, 0x52, 0x36, 0x14,
		0x61, 0x31, 0xfe, 0x92, 0x86, 0x49, 0x19, 0xce, 0x7b, 0xc2, 0x01, 0xb1, 0x0a, 0x02, 0x62, 0x2f,
		0xfc, 0x42, 0x40, 0x2c, 0x57, 0xaa, 0x1e, 0x01, 0x31, 0x5d, 0xbd, 0xc7, 0xea, 0xd6, 0x41, 0x40,
		0x2c, 0xf5, 0xad, 0x53, 0xaa, 0x20, 0x1c, 0xa6, 0x29, 0x11, 0xa4, 0x6b, 0x15, 0xc2, 0x61, 0x94,
		0x2d, 0xa1, 0xd2, 0xc6, 0x87, 0xc8, 0xec, 0x81, 0x0d, 0xbb, 0x78, 0xcc, 0x22, 0x58, 0x6f, 0xbd,
		0x5e, 0x58, 0xeb, 0x58, 0x5b, 0xa0, 0xd4, 0x8a, 0x6f, 0x87, 0xfc, 0xf0, 0x82, 0xf8, 0x7f, 0xeb,
		0x8c, 0x4e, 0x67, 0x0f, 0x2f, 0xfe, 0xf6, 0xfe, 0x3b, 0x85, 0x93, 0x0d, 0xe8, 0x41, 0x08, 0x01,
		0xf8, 0x20, 0x15, 0xcb, 0x27, 0x18, 0xc3, 0x27, 0x46, 0x52, 0xd1, 0xf9, 0xf2, 0x25, 0xcb, 0x08,
		0x9d, 0x2f, 0x5f, 0xb2, 0xd0, 0xd1, 0xf9, 0x72, 0x5b, 0x16, 0x86, 0xce, 0x97, 0x7c, 0x28, 0x33,
		0xb9, 0x58, 0x7b, 0x82, 0x5a, 0xae, 0xb0, 0x47, 0x81, 0x18, 0x51, 0xc2, 0xac, 0x45, 0x81, 0x1e,
		0xa1, 0x26, 0x57, 0xc6, 0xc9, 0x5c, 0x55, 0xbc, 0x7b, 0x37, 0xe3, 0xe7, 0x85, 0x29, 0x69, 0x00,
		0xb1, 0x24, 0x60, 0x81, 0xea, 0xce, 0xf2, 0xff, 0x12, 0xb7, 0x34, 0x48, 0xa4, 0xd1, 0x72, 0xc2,
		0xa8, 0x1e, 0x45, 0x44, 0x1a, 0xdd, 0x1f, 0x3b, 0x5e, 0xc3, 0x15, 0x53, 0x0f, 0x15, 0xd2, 0x20,
		0x90, 0xc6, 0xb1, 0x7d, 0xb3, 0x64, 0x51, 0xf1, 0x7d, 0xb9, 0x7c, 0x50, 0x2d, 0x97, 0xf7, 0xaa,
		0xfb, 0xd5, 0xbd, 0x5a, 0xa5, 0x52, 0x3c, 0x28, 0x12, 0x88, 0xb8, 0x1a, 0x9d, 0x60, 0x28, 0x02,
		0x31, 0x3c, 0x9c, 0x2e, 0x2a, 0x6f, 0xe2, 0xba, 0xb9, 0xde, 0x5b, 0xc4, 0x22, 0x4d, 0x9a, 0x44,
		0x98, 0x28, 0x8c, 0xb9, 0x61, 0x1b, 0x53, 0x32, 0x30, 0x5e, 0x57, 0x7f, 0x00, 0xc2, 0x78, 0xdd,
		0xad, 0x00, 0x07, 0x93, 0x76, 0x9f, 0x05, 0x2c, 0xb9, 0x19, 0xb9, 0xfb, 0x46, 0x63, 0xc8, 0x50,
		0x0d, 0x15, 0x3c, 0x20, 0x42, 0x01, 0x22, 0x90, 0x46, 0x02, 0xb9, 0x5b, 0x5f, 0xde, 0x06, 0x94,
		0xb8, 0xf9, 0x0c, 0x7f, 0x6c, 0xff, 0x67, 0x22, 0xe2, 0xd5, 0x25, 0x7b, 0xe3, 0xdd, 0xc7, 0xfc,
		0xef, 0x6d, 0x90, 0x0c, 0x3b, 0x6a, 0x66, 0xa4, 0x29, 0x3b, 0x11, 0x52, 0x79, 0xf2, 0x43, 0xe2,
		0x84, 0x47, 0xf5, 0x49, 0x0e, 0x99, 0x13, 0x1b, 0x32, 0x27, 0x33, 0x54, 0x4e, 0x60, 0xf4, 0xa6,
		0x57, 0xaa, 0x66, 0x86, 0xc5, 0xf3, 0xb6, 0xbc, 0xa1, 0x18, 0x9a, 0xae, 0xe3, 0x7d, 0x57, 0xb7,
		0xed, 0x96, 0xc7, 0x7f, 0xdd, 0x9b, 0xa3, 0x68, 0xc5, 0xab, 0x1d, 0xcc, 0xa9, 0x3c, 0x1d, 0x81,
		0x42, 0xfa, 0x01, 0xa9, 0x74, 0x03, 0x2a, 0xe9, 0x05, 0xe4, 0xd2, 0x09, 0xc8, 0xa5, 0x0f, 0x50,
		0x4b, 0x17, 0xc8, 0x57, 0x38, 0x51, 0xf5, 0xe0, 0x4b, 0x22, 0x53, 0xa7, 0x49, 0x4d, 0x9b, 0x26,
		0x32, 0x65, 0x9a, 0x4c, 0x8e, 0x1d, 0xa5, 0xdc, 0x3a, 0x92, 0x39, 0x75, 0xd4, 0x72, 0xe9, 0xc8,
		0xe6, 0xd0, 0x91, 0xcd, 0x9d, 0xa3, 0x9a, 0x33, 0x97, 0xef, 0x04, 0x1a, 0x2a, 0x53, 0xa1, 0x8d,
		0xa9, 0xb2, 0x32, 0x87, 0x76, 0x64, 0xd3, 0x4b, 0x51, 0xbf, 0x37, 0x0d, 0x89, 0xea, 0x94, 0x9d,
		0x28, 0x45, 0x67, 0x4a, 0xda, 0xa9, 0x52, 0x75, 0xae, 0xe4, 0x9d, 0x2c, 0x79, 0x67, 0x4b, 0xdd,
		0xe9, 0xd2, 0x70, 0xbe, 0x44, 0x9c, 0x70, 0xf2, 0xb2, 0xe8, 0x26, 0xaa, 0x4f, 0x3c, 0xc7, 0xf7,
		0x28, 0xa6, 0xa9, 0xd7, 0x08, 0xd9, 0x34, 0x7f, 0x7d, 0xb4, 0x9a, 0xbf, 0x10, 0xee, 0x30, 0x34,
		0xf4, 0xa3, 0x48, 0x0c, 0xcd, 0xff, 0x4c, 0xec, 0x21, 0x46, 0x15, 0xbd, 0x90, 0xe1, 0x60, 0x54,
		0xd1, 0xfd, 0x3f, 0xc4, 0xd8, 0x1f, 0x16, 0xee, 0x8d, 0x01, 0x22, 0x4d, 0x1c, 0x2f, 0xda, 0x2f,
		0x11, 0x06, 0xa3, 0x2a, 0x9a, 0x9e, 0xb1, 0x5f, 0x6d, 0xc9, 0x83, 0x43, 0xd3, 0xb3, 0xf4, 0xcc,
		0x44, 0xd3, 0x33, 0xdd, 0xdd, 0xc6, 0xea, 0xd6, 0x41, 0xd3, 0xb3, 0xd4, 0xb7, 0x4e, 0xb9, 0x54,
		0x2b, 0xd7, 0x0e, 0xaa, 0xa5, 0x1a, 0x7a, 0x9f, 0x69, 0x16, 0xdf, 0xa0, 0x6f, 0x15, 0x7a, 0x9f,
		0x51, 0x7e, 0x2e, 0x68, 0x9f, 0x94, 0x9c, 0x50, 0x39, 0x43, 0xa2, 0xe7, 0x53, 0xce, 0x10, 0xa7,
		0x53, 0x0f, 0x9a, 0x83, 0xd3, 0xa9, 0x17, 0x2c, 0x25, 0x9c, 0x4e, 0xbd, 0x64, 0xa1, 0xe3, 0x74,
		0x6a, 0x4b, 0x03, 0x71, 0x3a, 0xc5, 0x47, 0x87, 0x11, 0x3e, 0x9d, 0xa2, 0x79, 0x90, 0x40, 0xf1,
		0x00, 0x81, 0xec, 0xc1, 0x41, 0x4e, 0x0f, 0x0c, 0xc0, 0xef, 0x89, 0xf1, 0xfb, 0x88, 0x12, 0xc8,
		0xad, 0x32, 0xfc, 0xd8, 0x34, 0x70, 0x7c, 0x70, 0x7c, 0x70, 0x7c, 0x70, 0x7c, 0x70, 0x7c, 0x70,
		0xfc, 0x5c, 0x71, 0x7c, 0x67, 0x28, 0xbc, 0xc8, 0x89, 0x6e, 0x89, 0xb6, 0x4b, 0x25, 0x74, 0x66,
		0x62, 0x34, 0xe7, 0x8f, 0xea, 0xd0, 0x0e, 0x05, 0xdd, 0xe1, 0xad, 0x9d, 0xd3, 0x93, 0x4f, 0x5f,
		0x4b, 0x56, 0xb7, 0xf3, 0xa5, 0xd7, 0xe8, 0x5a, 0xad, 0x66, 0xfb, 0x5f, 0x56, 0xef, 0xcf, 0x93,
		0x06, 0x35, 0x7c, 0x8d, 0x4f, 0xc7, 0x42, 0x92, 0xe9, 0x0d, 0x44, 0x27, 0x7e, 0x2e, 0x5e, 0x70,
		0xaf, 0x5b, 0x6f, 0x9f, 0x36, 0x7b, 0x56, 0xbb, 0xd1, 0xfb, 0x77, 0xa7, 0xfb, 0xaf, 0xf8, 0x15,
		0x13, 0x1c, 0x53, 0xf9, 0x2b, 0xde, 0xeb, 0xcb, 0xde, 0xeb, 0x49, 0xa7, 0xd9, 0xee, 0x59, 0xbd,
		0x8e, 0x35, 0xfb, 0x80, 0xd7, 0xaa, 0xc7, 0x6b, 0x3d, 0xed, 0x7d, 0x39, 0xc4, 0x5e, 0xd5, 0xec,
		0xa5, 0x7e, 0x6d, 0x76, 0x7b, 0x5f, 0xea, 0x2d, 0xaa, 0xef, 0x93, 0x94, 0x45, 0x7d, 0x68, 0x12,
		0x62, 0x56, 0xdc, 0xa1, 0xff, 0x36, 0xfa, 0x6f, 0xff, 0xb4, 0xd7, 0xe5, 0x7d, 0x0b, 0xc0, 0xc2,
		0x4a, 0x8f, 0x26, 0x32, 0x73, 0xdc, 0x68, 0x35, 0xc2, 0xec, 0xc4, 0x8f, 0x6b, 0xfa, 0xa9, 0x31,
		0x7f, 0x5a, 0x2d, 0xc7, 0xfb, 0x4e, 0x61, 0x52, 0x9b, 0xc2, 0xde, 0xda, 0x0a, 0x3b, 0x38, 0x45,
		0xee, 0x75, 0x48, 0xa7, 0x31, 0x4c, 0x6c, 0x0d, 0xfa, 0xc2, 0xa0, 0x2f, 0xcc, 0x13, 0xeb, 0x04,
		0x7d, 0x61, 0x7e, 0xb6, 0x80, 0xd1, 0x17, 0xe6, 0xa5, 0x3c, 0x07, 0x7d, 0x61, 0xe8, 0x91, 0x4f,
		0x32, 0x7d, 0x61, 0x22, 0xf7, 0x9a, 0xe0, 0xd0, 0x52, 0xf7, 0x9a, 0xd8, 0x49, 0x7c, 0x11, 0x27,
		0xf1, 0xe4, 0x1d, 0x28, 0x69, 0x47, 0x4a, 0xd5, 0xa1, 0x92, 0x77, 0xac, 0xe4, 0x1d, 0x2c, 0x75,
		0x47, 0x4b, 0x2c, 0xea, 0x45, 0x04, 0xb7, 0xa8, 0x38, 0xe0, 0xc4, 0x20, 0x7b, 0xf8, 0xbf, 0xf6,
		0x40, 0x78, 0x83, 0x5b, 0x33, 0x24, 0x54, 0x04, 0xb3, 0x81, 0xa9, 0xab, 0x66, 0x12, 0xdb, 0x81,
		0xb4, 0x9c, 0x35, 0x59, 0xa7, 0x4d, 0xd9, 0x79, 0xb3, 0x70, 0xe2, 0xd4, 0x9d, 0x39, 0x1b, 0xa7,
		0xce, 0xc6, 0xb9, 0x73, 0x71, 0xf2, 0xb4, 0x9c, 0x3d, 0x31, 0xa7, 0x4f, 0xd6, 0xf9, 0x27, 0x86,
		0xd1, 0x68, 0x65, 0xfe, 0x24, 0x26, 0x53, 0x39, 0xfd, 0x61, 0x44, 0x02, 0xc8, 0x93, 0x01, 0x0e,
		0xa4, 0x80, 0x15, 0x39, 0xe0, 0x42, 0x12, 0xd8, 0x91, 0x05, 0x76, 0xa4, 0x81, 0x1b, 0x79, 0xa0,
		0x49, 0x22, 0x88, 0x92, 0x09, 0xf2, 0xa4, 0x22, 0x31, 0xf0, 0xc2, 0x1e, 0x7c, 0x9f, 0x8c, 0xe9,
		0xe3, 0xd0, 0x02, 0xdc, 0xe7, 0xf6, 0x12, 0xdf, 0xd3, 0x47, 0x62, 0x64, 0x4f, 0xdc, 0x78, 0x4b,
		0x8f, 0x6c, 0x37, 0x14, 0xd4, 0xed, 0x65, 0xd2, 0x35, 0x8b, 0x3a, 0x4d, 0xe2, 0x44, 0x97, 0x58,
		0xd2, 0x26, 0x6e, 0xf4, 0x89, 0x2d, 0x8d, 0x62, 0x4b, 0xa7, 0xb8, 0xd2, 0x2a, 0xda, 0xf4, 0x8a,
		0x38, 0xcd, 0x4a, 0x5e, 0x3a, 0xb9, 0x52, 0xca, 0xa7, 0xf9, 0x8c, 0xef, 0xbb, 0xc2, 0xf6, 0x38,
		0x60, 0xee, 0x22, 0x86, 0x52, 0x7c, 0x83, 0x0d, 0xa4, 0xd9, 0xe6, 0x31, 0x2e, 0x03, 0x9f, 0x93,
		0x0a, 0x98, 0x99, 0x0b, 0x11, 0x00, 0x11, 0x00, 0x11, 0x00, 0x11, 0x00, 0x11, 0x00, 0x11, 0x00,
		0x11, 0x00, 0x1e, 0x03, 0x11, 0x00, 0x11, 0x00, 0x11, 0xf0, 0xfa, 0x77, 0x7b, 0x35, 0x71, 0x23,
		0xc7, 0x8c, 0xfc, 0xb1, 0xef, 0xfa, 0x97, 0xb7, 0xe6, 0xac, 0xfb, 0xcf, 0xc8, 0x11, 0x01, 0x1f,
		0x61, 0xf0, 0xf8, 0x2d, 0x80, 0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x83, 0x7c,
		0x83, 0x7c, 0x83, 0x7c, 0xaf, 0xcc, 0x1f, 0x7c, 0xcf, 0x88, 0x7a, 0x57, 0x18, 0x98, 0x4a, 0x7b,
		0x3c, 0xe1, 0xfa, 0x17, 0x0f, 0x0f, 0xb6, 0xc3, 0x65, 0x7c, 0x21, 0x53, 0x6e, 0xbb, 0x61, 0x36,
		0x93, 0xf1, 0x86, 0x1b, 0x76, 0x33, 0x1a, 0xd5, 0xc6, 0xcc, 0xbb, 0xad, 0x6e, 0x45, 0xfb, 0x06,
		0x5b, 0x51, 0xf2, 0x56, 0x2c, 0x55, 0x2a, 0xd8, 0x8c, 0x20, 0xc2, 0xbc, 0xac, 0xec, 0x23, 0x54,
		0xaa, 0x9b, 0x33, 0x30, 0x42, 0x67, 0x48, 0x6b, 0x6c, 0xc9, 0x93, 0x32, 0x27, 0xb1, 0x18, 0x81,
		0xd0, 0x34, 0xcc, 0x44, 0x20, 0x34, 0xc3, 0xb5, 0x8a, 0x40, 0x68, 0x96, 0x1b, 0x0c, 0x81, 0x50,
		0xc9, 0x86, 0x23, 0x10, 0x9a, 0x3f, 0xa9, 0xc8, 0x30, 0x10, 0x1a, 0x06, 0x26, 0x13, 0x92, 0xb0,
		0x4c, 0x14, 0x8a, 0x65, 0x06, 0xb6, 0x36, 0xbc, 0xc9, 0xd5, 0x74, 0x31, 0xdc, 0x41, 0x0a, 0x68,
		0x29, 0x05, 0xae, 0xe7, 0xf1, 0x09, 0x46, 0x5a, 0x60, 0x66, 0x32, 0xc4, 0x00, 0xc4, 0x00, 0xc4,
		0x00, 0xc4, 0x00, 0xc4, 0x00, 0xc4, 0x00, 0xc4, 0x00, 0xc4, 0xc0, 0x4a, 0x56, 0xc4, 0x7e, 0x89,
		0x91, 0x0e, 0xa8, 0x22, 0x2d, 0x22, 0xe5, 0x2f, 0xa4, 0x45, 0x80, 0xdc, 0x3e, 0x60, 0x36, 0xd2,
		0x22, 0xe0, 0xde, 0x7e, 0xb6, 0x15, 0x91, 0x16, 0x21, 0x7d, 0x2b, 0x96, 0x4b, 0xb5, 0x72, 0xed,
		0xa0, 0x5a, 0xaa, 0x21, 0x3b, 0x02, 0x84, 0x98, 0x99, 0x95, 0xc8, 0x8e, 0xd0, 0xce, 0x27, 0x18,
		0x7f, 0x09, 0xe7, 0xf2, 0x5b, 0xc4, 0x27, 0x1e, 0x3a, 0xb7, 0x17, 0xc1, 0xd0, 0x34, 0xcc, 0x44,
		0x30, 0x34, 0xc3, 0x95, 0x8a, 0x60, 0x68, 0x96, 0x1b, 0x0c, 0xc1, 0x50, 0xc9, 0x86, 0x23, 0x18,
		0x9a, 0x3f, 0xb5, 0x88, 0x12, 0xb1, 0xcc, 0x29, 0x02, 0x4a, 0xc4, 0xd2, 0xfe, 0x42, 0x2c, 0x14,
		0xdc, 0xf6, 0x01, 0xb3, 0x11, 0x0b, 0x85, 0x77, 0xfb, 0xd9, 0x56, 0x44, 0x2c, 0x54, 0xfa, 0x56,
		0x44, 0x89, 0x18, 0x88, 0x30, 0x3b, 0x2b, 0x11, 0x04, 0xd5, 0xc9, 0x32, 0xaa, 0xc3, 0x48, 0xea,
		0x9e, 0xe7, 0x47, 0xf6, 0x14, 0x6a, 0x68, 0xcf, 0x24, 0x09, 0x07, 0xdf, 0xc4, 0x95, 0x3d, 0xb6,
		0xa3, 0x6f, 0x53, 0xf1, 0x55, 0xf0, 0xc7, 0xc2, 0x1b, 0xc4, 0x41, 0x45, 0xd3, 0x13, 0xd1, 0x5f,
		0x7e, 0xf0, 0xdd, 0x74, 0xbc, 0x30, 0xb2, 0xbd, 0x81, 0x28, 0xac, 0xff, 0x20, 0xdc, 0xf8, 0x49,
		0x61, 0x1c, 0xf8, 0x91, 0x3f, 0xf0, 0xdd, 0x30, 0xf9, 0x54, 0x98, 0xc5, 0x19, 0x0a, 0x76, 0x20,
		0xec, 0x30, 0xfe, 0xb3, 0xe0, 0x86, 0xc3, 0x8b, 0x82, 0x1b, 0xda, 0x71, 0xf6, 0x7b, 0x98, 0x7c,
		0x9a, 0x7e, 0x88, 0xbf, 0x2b, 0xf8, 0x63, 0xfb, 0x3f, 0x13, 0x61, 0x4e, 0x3f, 0x8a, 0x9b, 0x48,
		0x78, 0x43, 0x31, 0x34, 0x5d, 0xc7, 0xfb, 0x5e, 0x88, 0xdc, 0xeb, 0x70, 0xfa, 0x47, 0x61, 0x65,
		0x08, 0x6a, 0x81, 0xf2, 0x34, 0xb4, 0xd9, 0x43, 0x8e, 0x82, 0xc9, 0x20, 0xf2, 0xe6, 0x0a, 0xb7,
		0x93, 0x3c, 0xe3, 0xf6, 0xec, 0xf9, 0x35, 0xe7, 0x8f, 0xcf, 0x5a, 0xfb, 0x3e, 0x5c, 0xff, 0x81,
		0x75, 0xb2, 0x78, 0xbe, 0xc9, 0x27, 0xab, 0x13, 0x3f, 0x5f, 0xab, 0x3e, 0x7d, 0xbe, 0xf1, 0x9f,
		0x56, 0x2b, 0x1c, 0x5e, 0x58, 0xad, 0xd0, 0x9e, 0x6a, 0xff, 0x70, 0xf1, 0x61, 0xfa, 0x77, 0xfc,
		0x8d, 0xd5, 0x89, 0x9f, 0xee, 0xf4, 0x53, 0x63, 0xfe, 0x70, 0x5b, 0x8e, 0xf7, 0xdd, 0xea, 0xb9,
		0xd7, 0xe1, 0xf4, 0x0f, 0xab, 0xbe, 0x78, 0xb6, 0xa7, 0xce, 0xd0, 0x3a, 0x8d, 0x1f, 0xed, 0x1b,
		0xe0, 0x11, 0x3f, 0x8b, 0xa8, 0xcd, 0x7c, 0x24, 0x8e, 0x88, 0x3a, 0x20, 0x21, 0xc5, 0x09, 0xbd,
		0x6c, 0xb1, 0x8f, 0x16, 0xea, 0xd1, 0xc1, 0x16, 0x42, 0xb8, 0x42, 0x74, 0x5c, 0x2b, 0xe9, 0x31,
		0xad, 0x98, 0xd1, 0xfe, 0x42, 0xc3, 0x30, 0xa3, 0x7d, 0x4b, 0x23, 0x31, 0xa3, 0x3d, 0x25, 0x43,
		0x31, 0xa3, 0x1d, 0x7c, 0x5d, 0xde, 0x4b, 0x24, 0x3b, 0xa3, 0x9d, 0x74, 0x2f, 0xa0, 0x04, 0x92,
		0x09, 0x97, 0xf6, 0x13, 0x3f, 0x76, 0xc0, 0x84, 0xf6, 0xbc, 0x50, 0x03, 0x2e, 0x14, 0x81, 0x1d,
		0x55, 0x60, 0x47, 0x19, 0xb8, 0x51, 0x07, 0x9a, 0x14, 0x82, 0x28, 0x95, 0x48, 0x5e, 0x2e, 0xf9,
		0x6c, 0xb4, 0x04, 0x35, 0x67, 0xc3, 0x4c, 0xa2, 0xdb, 0x40, 0x8c, 0x28, 0xe3, 0xe6, 0x42, 0xcb,
		0x13, 0x3e, 0x86, 0x37, 0x9a, 0xf3, 0x47, 0x79, 0x68, 0x87, 0x8c, 0xda, 0xb6, 0x74, 0x4e, 0x4f,
		0x3e, 0x7d, 0x2d, 0x59, 0x8d, 0x3f, 0x7a, 0x8d, 0xf6, 0x51, 0xe3, 0xc8, 0x6a, 0x35, 0xdb, 0xff,
		0xb2, 0x4e, 0xbf, 0x1c, 0xf6, 0x5a, 0x5f, 0xad, 0xde, 0x9f, 0x27, 0x0d, 0xea, 0xc0, 0x1f, 0xa7,
		0x68, 0x84, 0x2c, 0x72, 0xfe, 0x98, 0x64, 0xac, 0x2f, 0x56, 0x46, 0xfd, 0xe8, 0xff, 0xd6, 0x3f,
		0x36, 0xda, 0x1f, 0xff, 0xb4, 0x4e, 0x9b, 0x47, 0xc8, 0x9f, 0xde, 0xee, 0xab, 0x0f, 0xcf, 0xce,
		0xdc, 0x2a, 0x04, 0x51, 0x7e, 0x4a, 0x67, 0x71, 0xe8, 0x99, 0xc1, 0xa1, 0x27, 0xd5, 0x84, 0x0f,
		0x5e, 0x87, 0x9d, 0x04, 0x73, 0x3b, 0x70, 0xca, 0xf9, 0xd0, 0xaa, 0x9a, 0x78, 0xdf, 0x3d, 0xff,
		0x2f, 0xcf, 0x8c, 0xdc, 0x6b, 0xba, 0x67, 0x9d, 0xcb, 0x46, 0xe2, 0xc4, 0xf3, 0x39, 0x66, 0xe1,
		0xc4, 0x73, 0x8b, 0xe5, 0x86, 0x13, 0xcf, 0x6d, 0x36, 0x04, 0x4e, 0x3c, 0xd3, 0xe6, 0x79, 0x38,
		0xf1, 0xe4, 0x4f, 0xd6, 0xc9, 0x9e, 0x78, 0xd2, 0x4c, 0x73, 0xda, 0xc0, 0x64, 0xca, 0x79, 0xd8,
		0x44, 0x49, 0x00, 0x79, 0x32, 0xc0, 0x81, 0x14, 0xb0, 0x22, 0x07, 0x5c, 0x48, 0x02, 0x3b, 0xb2,
		0xc0, 0x8e, 0x34, 0x70, 0x23, 0x0f, 0x34, 0x49, 0x04, 0x51, 0x32, 0x41, 0x9e, 0x54, 0x24, 0x06,
		0xba, 0xc2, 0xbb, 0x8c, 0xc3, 0x7f, 0x4c, 0x4e, 0xe6, 0xe6, 0xf6, 0xa2, 0x81, 0x58, 0x1e, 0x68,
		0x07, 0x27, 0xfa, 0xc1, 0x92, 0x86, 0x70, 0xa3, 0x23, 0x6c, 0x69, 0x09, 0x5b, 0x7a, 0xc2, 0x95,
		0xa6, 0xd0, 0xa6, 0x2b, 0xc4, 0x69, 0x4b, 0xf2, 0xd2, 0x79, 0x36, 0x10, 0x2b, 0x1e, 0x30, 0xea,
		0x20, 0x76, 0x80, 0x0e, 0x62, 0x29, 0x7f, 0xa1, 0x83, 0x18, 0xc8, 0xed, 0x03, 0x66, 0xa3, 0x83,
		0x18, 0xdc, 0xdb, 0xcf, 0xb6, 0x22, 0x3a, 0x88, 0x49, 0xdf, 0x8a, 0x07, 0x95, 0xca, 0x3e, 0x7a,
		0x88, 0x81, 0x0b, 0x33, 0xb3, 0x12, 0x3d, 0xc4, 0xb4, 0x73, 0x07, 0xb4, 0xcb, 0x4a, 0x37, 0x54,
		0x0e, 0x83, 0xc9, 0xd1, 0x88, 0x81, 0xa6, 0x6c, 0x28, 0x62, 0xa0, 0x19, 0x1b, 0x8d, 0x18, 0xa8,
		0x24, 0xc3, 0x11, 0x03, 0x05, 0x23, 0x60, 0x23, 0x12, 0x11, 0x03, 0xcd, 0x9e, 0x23, 0x20, 0x06,
		0x9a, 0xf6, 0x17, 0x62, 0xa0, 0x20, 0xb7, 0x0f, 0x98, 0x8d, 0x18, 0x28, 0xdc, 0xdb, 0xcf, 0xb6,
		0x22, 0x62, 0xa0, 0xd2, 0xb7, 0x22, 0x62, 0xa0, 0xe0, 0xc2, 0x0c, 0xad, 0x44, 0x0c, 0x54, 0x3b,
		0x77, 0x60, 0x5c, 0xcf, 0x21, 0x89, 0x49, 0x10, 0x74, 0x66, 0x2e, 0xa2, 0xa0, 0x69, 0x98, 0x89,
		0x28, 0x68, 0x86, 0x0b, 0x15, 0x51, 0xd0, 0x2c, 0x37, 0x18, 0xa2, 0xa0, 0x92, 0x0d, 0x47, 0x14,
		0x34, 0x7f, 0x32, 0x91, 0x61, 0x14, 0xf4, 0xc2, 0xf1, 0xec, 0xe0, 0x96, 0x51, 0x14, 0xb4, 0x06,
		0x4a, 0xad, 0x91, 0x65, 0x18, 0x4d, 0xb6, 0x9d, 0x9d, 0x3c, 0x7b, 0x53, 0x2d, 0xf5, 0xc1, 0xc1,
		0x60, 0xb2, 0x54, 0xfb, 0x55, 0x7d, 0x99, 0x3d, 0x59, 0xa2, 0xad, 0xab, 0xe8, 0x62, 0x11, 0x9a,
		0x7e, 0x30, 0x46, 0x43, 0xfe, 0x28, 0x88, 0x3e, 0x7d, 0xa9, 0xe1, 0x1e, 0x9a, 0xf5, 0x51, 0xb6,
		0x84, 0x08, 0xb2, 0x19, 0x2d, 0x27, 0x8c, 0xea, 0x51, 0x44, 0xab, 0xed, 0x80, 0x71, 0xec, 0x78,
		0x0d, 0x57, 0x5c, 0x09, 0x6f, 0x76, 0x5c, 0x44, 0xa8, 0xbd, 0xe2, 0xb1, 0x7d, 0xb3, 0x64, 0x59,
		0xf1, 0x7d, 0xb9, 0x7c, 0x50, 0x2d, 0x97, 0xf7, 0xaa, 0xfb, 0xd5, 0xbd, 0x5a, 0xa5, 0x52, 0x3c,
		0xa0, 0xd4, 0x5d, 0xdd, 0xe8, 0x04, 0x43, 0x11, 0x88, 0xe1, 0xe1, 0xad, 0xf1, 0x61, 0xc7, 0x9b,
		0xb8, 0x2e, 0x56, 0x3e, 0x7d, 0x5f, 0xce, 0xd3, 0x87, 0x1b, 0xa4, 0xe6, 0x3c, 0xf2, 0xf1, 0xd7,
		0x34, 0x9c, 0xb4, 0x7a, 0x97, 0xa8, 0xd6, 0x02, 0xc5, 0x90, 0x44, 0x0d, 0x8a, 0xf8, 0x41, 0x10,
		0x01, 0xf8, 0x61, 0x03, 0x3b, 0x6a, 0x21, 0x47, 0xdd, 0x46, 0x57, 0x73, 0x65, 0x45, 0xd0, 0x42,
		0x05, 0x52, 0x58, 0x41, 0x89, 0x42, 0x14, 0xe1, 0x80, 0x1e, 0x6a, 0x80, 0x43, 0xfe, 0xb6, 0x55,
		0xb0, 0x65, 0x8d, 0x64, 0x1d, 0x8e, 0xd5, 0x26, 0xac, 0x24, 0xc7, 0xa1, 0xeb, 0x06, 0x29, 0x82,
		0x31, 0xb5, 0x8d, 0x78, 0x95, 0xe7, 0x39, 0x51, 0xc8, 0x5f, 0x22, 0x95, 0x97, 0x44, 0x25, 0xdf,
		0x88, 0x5c, 0x1e, 0x11, 0xb9, 0xfc, 0x20, 0x6a, 0x79, 0x3f, 0xf9, 0xa2, 0x7f, 0xaa, 0x1b, 0xc9,
		0x12, 0xe9, 0x42, 0x4f, 0xaa, 0xdb, 0x3c, 0x91, 0xae, 0xf2, 0x64, 0x92, 0x77, 0x29, 0x25, 0xe7,
		0x92, 0x4c, 0xbe, 0xa5, 0x96, 0x5c, 0x4b, 0x36, 0x79, 0x96, 0x6c, 0x72, 0x2c, 0xd5, 0xe4, 0xd7,
		0x7c, 0x87, 0x5b, 0xa9, 0x74, 0x59, 0x37, 0xec, 0xe1, 0x30, 0x10, 0x61, 0x68, 0x8e, 0xec, 0x2b,
		0xc7, 0xbd, 0xa5, 0xb3, 0xcf, 0x17, 0x60, 0xb8, 0x66, 0x1f, 0x91, 0x3d, 0x45, 0xab, 0x46, 0x86,
		0x5c, 0x2d, 0x0c, 0xc5, 0x9a, 0x17, 0xd2, 0xb5, 0x2d, 0x54, 0x6b, 0x58, 0xc8, 0xd7, 0xaa, 0x90,
		0xaf, 0x49, 0xa1, 0x5e, 0x7b, 0x82, 0x54, 0xa4, 0xe5, 0x97, 0x45, 0xae, 0x66, 0xe4, 0x3e, 0x18,
		0xea, 0x4d, 0xae, 0x44, 0x30, 0x3b, 0x4d, 0x21, 0x84, 0x5b, 0x0b, 0x3d, 0x59, 0x26, 0x64, 0x53,
		0xc3, 0x9b, 0x5c, 0x4d, 0x5f, 0xe2, 0x1d, 0x12, 0x1b, 0xa8, 0x6c, 0x2e, 0xc3, 0x8e, 0x22, 0x7b,
		0xf0, 0x4d, 0x0c, 0x09, 0x12, 0xcc, 0x85, 0x65, 0x44, 0x20, 0xe8, 0x48, 0x8c, 0xec, 0x89, 0x1b,
		0xbb, 0x8b, 0x91, 0xed, 0x86, 0x02, 0x94, 0x17, 0x94, 0x17, 0x94, 0x17, 0x94, 0x17, 0x94, 0x17,
		0x94, 0x37, 0x5f, 0x94, 0xf7, 0xc2, 0xf7, 0x5d, 0x61, 0x93, 0xa4, 0xbb, 0x45, 0x50, 0x4b, 0x32,
		0xd4, 0xd2, 0xf3, 0x87, 0x82, 0x1e, 0xad, 0x8c, 0xad, 0x02, 0xa5, 0x04, 0xa5, 0x04, 0xa5, 0x04,
		0xa5, 0x04, 0xa5, 0x04, 0xa5, 0x04, 0xa5, 0x04, 0xa5, 0x04, 0xa5, 0xe4, 0x41, 0x29, 0xc7, 0xb4,
		0x1c, 0x6f, 0xb2, 0x7c, 0x69, 0x65, 0xbc, 0x80, 0xbe, 0x81, 0xbe, 0x81, 0xbe, 0x81, 0xbe, 0x81,
		0xbe, 0x81, 0xbe, 0xc9, 0x41, 0x2d, 0x67, 0x7c, 0x5d, 0x36, 0x17, 0x19, 0x61, 0x9e, 0x6f, 0xfe,
		0xd7, 0xf7, 0x04, 0x45, 0x2e, 0xf7, 0x9e, 0x90, 0x4d, 0x27, 0x76, 0x14, 0x89, 0xc0, 0x23, 0x37,
		0x07, 0xc6, 0x78, 0xfb, 0xf6, 0x6c, 0xcf, 0xac, 0xf5, 0xff, 0x3e, 0x2b, 0x9a, 0xb5, 0xfe, 0xec,
		0x63, 0x31, 0xfe, 0x6b, 0xf6, 0xb9, 0x74, 0xb6, 0x67, 0x96, 0x17, 0x9f, 0x2b, 0x67, 0x7b, 0x66,
		0xa5, 0xbf, 0x7b, 0x7e, 0xfe, 0x6e, 0xf7, 0xc7, 0xfe, 0xdd, 0xcb, 0xff, 0xe1, 0xdb, 0x7f, 0x9c,
		0x9d, 0x9f, 0x8f, 0x7f, 0xb4, 0xef, 0xa6, 0x7f, 0xb6, 0xee, 0xfa, 0xff, 0xdc, 0xfd, 0x8d, 0x1a,
		0x86, 0x4f, 0x0d, 0x3e, 0x3f, 0x7f, 0xd7, 0xff, 0x85, 0x0e, 0x2c, 0xf6, 0x21, 0x49, 0x88, 0x49,
		0x12, 0xd3, 0x15, 0xde, 0x65, 0x5c, 0xc7, 0x4c, 0x52, 0x99, 0x2c, 0xcc, 0x83, 0x40, 0x81, 0x40,
		0x81, 0x40, 0x81, 0x40, 0x81, 0x40, 0x81, 0x40, 0xc9, 0x95, 0x40, 0x99, 0x38, 0x5e, 0xf4, 0x9e,
		0xa0, 0x22, 0xa1, 0xd4, 0x11, 0x90, 0xe6, 0x58, 0x4a, 0x82, 0x9d, 0x74, 0x29, 0x8f, 0x99, 0x24,
		0x3e, 0x25, 0x88, 0xfa, 0xd8, 0x48, 0x0e, 0xf3, 0xe8, 0x08, 0x8e, 0x03, 0x20, 0x3d, 0xee, 0x91,
		0xcb, 0x96, 0xd8, 0x2f, 0x61, 0x4f, 0xf0, 0xe6, 0x61, 0xf4, 0xac, 0x41, 0xa4, 0x88, 0x0c, 0x66,
		0x1a, 0x81, 0x3f, 0x89, 0x44, 0xdc, 0x6e, 0x8e, 0x5e, 0x98, 0x68, 0xc9, 0x36, 0xc4, 0x88, 0x1e,
		0x32, 0x07, 0x31, 0xa2, 0x17, 0xac, 0x26, 0xc4, 0x88, 0x5e, 0xb2, 0xd0, 0x11, 0x23, 0xda, 0xd2,
		0x40, 0xc4, 0x88, 0xf8, 0xa8, 0x06, 0x54, 0x72, 0xbf, 0xd2, 0x11, 0xa2, 0x92, 0x9b, 0x32, 0xbd,
		0x44, 0x8b, 0x7a, 0xb4, 0xa8, 0x7f, 0x71, 0x5f, 0xe9, 0x99, 0xbb, 0x27, 0x33, 0xdc, 0x8f, 0x7a,
		0x9f, 0xe9, 0x19, 0xe3, 0xa5, 0x30, 0xb2, 0x4f, 0x61, 0xa3, 0x7a, 0x85, 0xed, 0x75, 0xe3, 0x61,
		0x0a, 0x64, 0xba, 0x76, 0x12, 0x18, 0xed, 0x80, 0xa6, 0x9d, 0x74, 0x35, 0x29, 0x9a, 0x76, 0x72,
		0xd6, 0x9e, 0x68, 0xda, 0x09, 0x02, 0xfa, 0x82, 0x97, 0x42, 0xa6, 0x69, 0x67, 0xe4, 0x5e, 0xd3,
		0x8b, 0xed, 0xd2, 0x19, 0xc1, 0x46, 0xc4, 0x61, 0x92, 0x73, 0x9c, 0x14, 0x1d, 0x28, 0x69, 0x47,
		0x4a, 0xd5, 0xa1, 0x92, 0x77, 0xac, 0xe4, 0x1d, 0x2c, 0x75, 0x47, 0x4b, 0x27, 0xe6, 0xb4, 0x43,
		0x28, 0xa8, 0x4b, 0xc5, 0x01, 0x27, 0x06, 0xad, 0xc5, 0x58, 0xcc, 0x60, 0x9e, 0xdb, 0x46, 0x0c,
		0x26, 0x1e, 0x99, 0xa8, 0x34, 0x37, 0x97, 0xd8, 0x8e, 0xa4, 0xe5, 0xbc, 0xc9, 0x3a, 0x71, 0xca,
		0xce, 0x9c, 0x85, 0x53, 0xa7, 0xee, 0xdc, 0xd9, 0x38, 0x79, 0x36, 0xce, 0x9e, 0x8b, 0xd3, 0xa7,
		0xe5, 0xfc, 0x89, 0x91, 0x00, 0xb2, 0x64, 0x20, 0x31, 0x8c, 0xc6, 0xdc, 0xa9, 0x27, 0x31, 0x99,
		0xca, 0x79, 0x10, 0x23, 0x12, 0x40, 0x9e, 0x0c, 0x70, 0x20, 0x05, 0xac, 0xc8, 0x01, 0x17, 0x92,
		0xc0, 0x8e, 0x2c, 0xb0, 0x23, 0x0d, 0xdc, 0xc8, 0x03, 0x4d, 0x12, 0x41, 0x94, 0x4c, 0x90, 0x27,
		0x15, 0x89, 0x81, 0x44, 0xe7, 0x75, 0x3d, 0x09, 0xf2, 0x24, 0xe7, 0x78, 0x3d, 0x45, 0x3f, 0xf6,
		0x88, 0x9b, 0x49, 0x9d, 0x86, 0x70, 0xa2, 0x23, 0x2c, 0x69, 0x09, 0x37, 0x7a, 0xc2, 0x96, 0xa6,
		0xb0, 0xa5, 0x2b, 0x5c, 0x69, 0x0b, 0x6d, 0xfa, 0x42, 0x9c, 0xc6, 0x24, 0x2f, 0x9d, 0x5c, 0x16,
		0xfc, 0x93, 0xa8, 0x4b, 0x33, 0x3b, 0xfe, 0xc9, 0x38, 0x45, 0x99, 0x81, 0xad, 0xb4, 0xb2, 0xe9,
		0xf9, 0x6d, 0x78, 0xc2, 0x9b, 0xdd, 0x70, 0xbc, 0x48, 0x04, 0xa6, 0x1d, 0x08, 0x9b, 0x8f, 0x24,
		0x58, 0xb2, 0x99, 0x38, 0x8c, 0x12, 0x1d, 0xa0, 0x01, 0xf9, 0x02, 0xf9, 0x02, 0xf9, 0x02, 0xf9,
		0x02, 0xf9, 0x02, 0x36, 0x03, 0xf9, 0x42, 0x02, 0x75, 0xe9, 0x0d, 0x18, 0x79, 0x52, 0xba, 0x14,
		0x21, 0x07, 0xb4, 0x93, 0x03, 0x63, 0x1e, 0x84, 0x85, 0xe6, 0x60, 0x13, 0xd0, 0x6a, 0xd0, 0x6a,
		0xd0, 0x6a, 0xd0, 0x6a, 0xd0, 0x6a, 0xb0, 0x02, 0xd0, 0x6a, 0x12, 0xa8, 0x1b, 0x0f, 0x7e, 0x61,
		0x03, 0x09, 0x14, 0xe7, 0xc0, 0x3c, 0xee, 0x84, 0x89, 0xce, 0x87, 0x79, 0xd4, 0x60, 0x99, 0x73,
		0x63, 0x0a, 0xf3, 0x8b, 0xed, 0xfe, 0xfd, 0xf6, 0xac, 0x68, 0x96, 0xfa, 0x8b, 0x6f, 0xf6, 0xcf,
		0xf6, 0xcc, 0x52, 0x7f, 0x77, 0x97, 0x3e, 0x52, 0xf6, 0xa1, 0xee, 0x34, 0x55, 0x77, 0xd4, 0x66,
		0xc1, 0x3c, 0x53, 0xe4, 0xd1, 0x9a, 0x11, 0x03, 0xad, 0x07, 0xad, 0x07, 0xad, 0x07, 0xad, 0x07,
		0xad, 0x07, 0x8e, 0x00, 0xad, 0x47, 0x02, 0x75, 0xa9, 0xcd, 0xd0, 0x79, 0x8a, 0x22, 0x54, 0x18,
		0x98, 0x4a, 0x73, 0xe6, 0xce, 0x63, 0x5f, 0x3c, 0x3c, 0xd8, 0x0e, 0xf5, 0x19, 0x3d, 0xcc, 0xb9,
		0xed, 0x86, 0xd9, 0xc4, 0x67, 0xfa, 0x3c, 0x6a, 0x37, 0x83, 0xb9, 0x26, 0x4c, 0xbd, 0xdb, 0xea,
		0x56, 0xb4, 0x6f, 0xb0, 0x15, 0x25, 0x6f, 0x45, 0xaa, 0xb3, 0x84, 0xb4, 0xdc, 0x8b, 0x6f, 0x60,
		0x65, 0x1a, 0x5f, 0x88, 0x88, 0x6a, 0xe7, 0x0b, 0x8c, 0xb8, 0x91, 0x95, 0x19, 0x3a, 0xff, 0x15,
		0x7c, 0xc2, 0xa1, 0x4b, 0x36, 0x23, 0x16, 0x9a, 0x86, 0x99, 0x88, 0x85, 0x66, 0xb8, 0x5a, 0x11,
		0x0b, 0xcd, 0x72, 0x83, 0x21, 0x16, 0x2a, 0xd9, 0x70, 0xc4, 0x42, 0xf3, 0xa7, 0x16, 0x99, 0xc6,
		0x42, 0x8b, 0x07, 0x8c, 0x82, 0xa1, 0x07, 0x08, 0x86, 0xa6, 0xfc, 0x85, 0x60, 0x28, 0xc8, 0xed,
		0x03, 0x66, 0x23, 0x18, 0x0a, 0xf7, 0xf6, 0xb3, 0xad, 0x88, 0x60, 0xa8, 0xf4, 0xad, 0x78, 0x50,
		0xa9, 0xec, 0x57, 0xb0, 0x1d, 0xc1, 0x85, 0x79, 0x59, 0x89, 0x78, 0xa8, 0x4e, 0x96, 0x51, 0x6d,
		0xac, 0x48, 0x6c, 0x78, 0xe7, 0xa3, 0x76, 0x32, 0x1b, 0xea, 0x19, 0xb9, 0xd7, 0xe1, 0xf4, 0x8f,
		0xc2, 0x83, 0xa3, 0x1d, 0x0a, 0x94, 0x7b, 0x3c, 0xef, 0xf0, 0x99, 0x05, 0xda, 0x73, 0xaf, 0xc3,
		0xe9, 0x1f, 0x6b, 0x3f, 0x8f, 0x85, 0x24, 0x85, 0x41, 0xa1, 0x7c, 0x20, 0x0a, 0x2d, 0xed, 0x19,
		0x83, 0xa4, 0x5e, 0xe0, 0x48, 0x71, 0x14, 0x09, 0x7f, 0x38, 0xa4, 0x05, 0x84, 0x74, 0xe0, 0x86,
		0x10, 0xd4, 0x2c, 0x0a, 0x71, 0x42, 0x67, 0x48, 0x77, 0x54, 0xd5, 0x92, 0x8d, 0x98, 0x4f, 0xf5,
		0x1c, 0xb3, 0x30, 0x9f, 0x6a, 0x8b, 0xd5, 0x86, 0xf9, 0x54, 0xdb, 0x6c, 0x08, 0xcc, 0xa7, 0x4a,
		0x9b, 0x07, 0x62, 0x3e, 0x15, 0x7f, 0x32, 0x8f, 0xf9, 0x54, 0xdb, 0x61, 0x32, 0xe6, 0x53, 0xe9,
		0x47, 0x06, 0x38, 0x90, 0x02, 0x56, 0xe4, 0x80, 0x0b, 0x49, 0x60, 0x47, 0x16, 0xd8, 0x91, 0x06,
		0x6e, 0xe4, 0x81, 0x26, 0x89, 0x20, 0x4a, 0x26, 0xc8, 0x93, 0x8a, 0xc4, 0x40, 0xdb, 0xbd, 0xf4,
		0x03, 0x27, 0xfa, 0x76, 0xc5, 0x68, 0x34, 0x55, 0x62, 0x32, 0xf2, 0xf0, 0xf3, 0x40, 0x3e, 0x38,
		0x91, 0x10, 0x96, 0x64, 0x84, 0x1b, 0x29, 0x61, 0x4b, 0x4e, 0xd8, 0x92, 0x14, 0xae, 0x64, 0x85,
		0x36, 0x69, 0x21, 0x4e, 0x5e, 0x92, 0x97, 0x8e, 0x9e, 0x24, 0x59, 0x53, 0x04, 0xf4, 0x24, 0x49,
		0xfb, 0x0b, 0x69, 0xf8, 0xe0, 0xb6, 0x0f, 0x98, 0x8d, 0x34, 0x7c, 0x78, 0xb7, 0x9f, 0x6d, 0x45,
		0xa4, 0xe1, 0x4b, 0xdf, 0x8a, 0xa5, 0x0a, 0x92, 0xf0, 0x41, 0x84, 0x99, 0x59, 0x89, 0x24, 0x7c,
		0xed, 0x9c, 0x81, 0x21, 0x6e, 0xc6, 0xae, 0x33, 0x70, 0x22, 0xd3, 0x9b, 0xb8, 0x2e, 0x9f, 0x70,
		0xe8, 0xaa, 0xd9, 0x98, 0xcc, 0x99, 0x43, 0xdf, 0x8a, 0x10, 0x6e, 0x96, 0x1b, 0x0c, 0x21, 0xdc,
		0x2c, 0x37, 0x18, 0x42, 0xb8, 0x92, 0x0d, 0x47, 0x08, 0x37, 0x7f, 0x22, 0x17, 0x93, 0x39, 0x25,
		0x90, 0x04, 0x4c, 0xe6, 0xd4, 0x50, 0x14, 0x5c, 0xd9, 0xe3, 0xb1, 0xe3, 0x5d, 0x9a, 0xa1, 0x08,
		0xae, 0x45, 0xc0, 0x47, 0x15, 0xac, 0xd9, 0x0d, 0x59, 0x00, 0x59, 0x00, 0x59, 0x00, 0x59, 0x00,
		0x59, 0x00, 0x59, 0x00, 0x59, 0x00, 0x66, 0x03, 0x59, 0x00, 0x59, 0x00, 0x59, 0xb0, 0x85, 0x2c,
		0x98, 0xb8, 0x91, 0x63, 0x46, 0xfe, 0xd8, 0x77, 0xfd, 0xcb, 0x5b, 0xd3, 0x19, 0x0a, 0x2f, 0x72,
		0x46, 0x0e, 0x2b, 0x85, 0xf0, 0xe8, 0x2d, 0x80, 0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x83,
		0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x83, 0x7c, 0x23, 0xad, 0x3a, 0x43, 0x53, 0x91, 0x56, 0x9d, 0xd1,
		0x83, 0x45, 0x5a, 0xb5, 0x3c, 0xb3, 0x91, 0x56, 0x0d, 0xef, 0xf6, 0xb3, 0xad, 0x88, 0xb4, 0x6a,
		0xe9, 0x5b, 0x11, 0x69, 0xd5, 0x20, 0xc2, 0xec, 0xac, 0x44, 0x5a, 0xb5, 0x76, 0xce, 0xc0, 0xf0,
		0x7c, 0x73, 0xfc, 0x6d, 0xcc, 0x27, 0x2e, 0x3a, 0xb7, 0x17, 0x19, 0x13, 0x39, 0xf4, 0xa6, 0x08,
		0xda, 0x66, 0xb9, 0xb3, 0x10, 0xb4, 0xcd, 0x72, 0x83, 0x21, 0x68, 0x2b, 0xd9, 0x70, 0x04, 0x6d,
		0xf3, 0x27, 0x6b, 0x91, 0x31, 0x21, 0x81, 0x24, 0x20, 0x63, 0x42, 0x43, 0x19, 0x10, 0x3a, 0x43,
		0x33, 0x1c, 0xf8, 0x63, 0x46, 0x13, 0xdf, 0xef, 0x4d, 0x06, 0xb9, 0x06, 0xb9, 0x06, 0xb9, 0x06,
		0xb9, 0x06, 0xb9, 0x06, 0xb9, 0x06, 0xb9, 0x06, 0xb9, 0xbe, 0x6f, 0xbe, 0xe0, 0x4d, 0xae, 0x44,
		0x30, 0x1b, 0x01, 0xc6, 0x88, 0x60, 0x97, 0x19, 0xd8, 0xda, 0xf0, 0x26, 0x71, 0x53, 0xe2, 0x3b,
		0x88, 0x01, 0x2d, 0xc5, 0xc0, 0xf5, 0xfc, 0xa0, 0x92, 0x91, 0x18, 0x98, 0x99, 0x0c, 0x31, 0x00,
		0x31, 0x00, 0x31, 0x00, 0x31, 0x00, 0x31, 0x00, 0x31, 0x00, 0x31, 0x00, 0x31, 0xb0, 0x92, 0x1e,
		0xbd, 0x5f, 0x62, 0xa4, 0x03, 0xaa, 0xc8, 0x8f, 0x4e, 0xf9, 0x0b, 0xf9, 0xd1, 0x20, 0xb7, 0x0f,
		0x98, 0x8d, 0xfc, 0x68, 0xb8, 0xb7, 0x9f, 0x6d, 0x45, 0xe4, 0x47, 0x4b, 0xdf, 0x8a, 0xe5, 0x52,
		0xad, 0x5c, 0x3b, 0xa8, 0x96, 0x6a, 0x48, 0x93, 0x06, 0x21, 0x66, 0x66, 0x25, 0xd2, 0xa4, 0xb5,
		0xf3, 0x09, 0xf7, 0xf1, 0x45, 0x33, 0xba, 0x1d, 0x73, 0x8c, 0x8b, 0xce, 0xec, 0x46, 0x70, 0x34,
		0x0d, 0x33, 0x11, 0x1c, 0xcd, 0x70, 0xc5, 0x22, 0x38, 0x9a, 0xe5, 0x06, 0x43, 0x70, 0x54, 0xb2,
		0xe1, 0x08, 0x8e, 0xe6, 0x4f, 0x3d, 0x22, 0x53, 0x42, 0x12, 0x51, 0x40, 0xa6, 0x44, 0x1e, 0x64,
		0x01, 0x46, 0x9a, 0xbf, 0xc4, 0xdf, 0x78, 0x9e, 0x1f, 0xcd, 0xf6, 0x31, 0xe9, 0xc9, 0xe6, 0xe1,
		0xe0, 0x9b, 0xb8, 0xb2, 0xc7, 0x76, 0xf4, 0x6d, 0x0a, 0x3f, 0x05, 0x7f, 0x2c, 0xbc, 0x41, 0x4c,
		0xab, 0x4d, 0x4f, 0x44, 0x7f, 0xf9, 0xc1, 0x77, 0xd3, 0xf1, 0xc2, 0xc8, 0xf6, 0x06, 0xa2, 0xb0,
		0xfe, 0x83, 0x70, 0xe3, 0x27, 0x85, 0x71, 0xe0, 0x47, 0xfe, 0xc0, 0x77, 0xc3, 0xe4, 0x53, 0x61,
		0xe6, 0x69, 0x0b, 0x76, 0x20, 0xec, 0x30, 0xfe, 0xb3, 0xe0, 0x86, 0xc3, 0x8b, 0x82, 0x1b, 0xda,
		0xb1, 0x14, 0x0a, 0x93, 0x4f, 0xd3, 0x0f, 0xf1, 0x77, 0x05, 0x7f, 0x6c, 0xff, 0x67, 0x22, 0xcc,
		0xe9, 0x47, 0x71, 0x13, 0x09, 0x6f, 0x28, 0x86, 0xe6, 0x8c, 0x26, 0x15, 0x22, 0xf7, 0x3a, 0x9c,
		0xfe, 0x51, 0x98, 0x7d, 0x6f, 0x86, 0xce, 0xb0, 0x10, 0x46, 0x76, 0x44, 0x59, 0x52, 0x19, 0x61,
		0x14, 0x4c, 0x06, 0x91, 0x37, 0x87, 0xf8, 0x4e, 0xf2, 0x88, 0xdb, 0xb3, 0xc7, 0xd7, 0x9c, 0x3f,
		0x3d, 0x6b, 0xed, 0xfb, 0x70, 0xfd, 0x07, 0xd6, 0xc9, 0xe2, 0xf1, 0x26, 0x9f, 0xac, 0x4e, 0xfc,
		0x78, 0xad, 0xfa, 0xf4, 0xf1, 0xc6, 0x7f, 0x5a, 0xad, 0x70, 0x78, 0x61, 0xb5, 0x42, 0x7b, 0xea,
		0xfc, 0xc2, 0xc5, 0x87, 0xe9, 0xdf, 0xf1, 0x37, 0x56, 0x27, 0x7e, 0xb8, 0xd3, 0x4f, 0x8d, 0xf9,
		0xb3, 0x9d, 0xa9, 0x13, 0xab, 0xe7, 0x5e, 0x87, 0xd3, 0x3f, 0xac, 0xd9, 0xf7, 0xa7, 0xce, 0xd0,
		0x3a, 0x8d, 0x9f, 0xec, 0x1b, 0xa0, 0x11, 0x3f, 0x8b, 0x88, 0xe1, 0x22, 0x75, 0x3c, 0xd4, 0x00,
		0x07, 0x09, 0x22, 0x20, 0x5b, 0xe4, 0xa3, 0x85, 0x79, 0x74, 0x90, 0x85, 0x10, 0xaa, 0xc4, 0x21,
		0x55, 0xd7, 0xbe, 0x10, 0xae, 0x79, 0xe1, 0x78, 0x43, 0xc7, 0xbb, 0x24, 0x07, 0x2c, 0x2b, 0xd1,
		0xdf, 0x55, 0x53, 0x89, 0xa1, 0xf3, 0x42, 0xc7, 0x11, 0x33, 0x8b, 0x6a, 0x80, 0x97, 0x72, 0x40,
		0x97, 0x45, 0x00, 0x97, 0x7a, 0xc0, 0x96, 0x4d, 0x80, 0x96, 0x4d, 0x40, 0x96, 0x4b, 0x00, 0x16,
		0x2c, 0xfe, 0x67, 0x2f, 0xf1, 0xc8, 0x09, 0x88, 0xd2, 0xf7, 0x58, 0xa9, 0x92, 0x85, 0x93, 0x84,
		0x08, 0x10, 0x0e, 0x55, 0x10, 0x25, 0x01, 0xe4, 0xc9, 0x00, 0x07, 0x52, 0xc0, 0x8a, 0x1c, 0x70,
		0x21, 0x09, 0xec, 0xc8, 0x02, 0x3b, 0xd2, 0xc0, 0x8d, 0x3c, 0xd0, 0x24, 0x11, 0x44, 0xc9, 0x04,
		0x79, 0x52, 0x91, 0x18, 0x78, 0xe5, 0x04, 0x81, 0x1f, 0x50, 0x8c, 0x30, 0x3c, 0x8a, 0xef, 0xf7,
		0x26, 0xa3, 0x43, 0x67, 0x16, 0x24, 0x09, 0xa9, 0x71, 0xf9, 0x21, 0x4d, 0x2c, 0xc9, 0x13, 0x37,
		0x12, 0xc5, 0x96, 0x4c, 0xb1, 0x25, 0x55, 0x5c, 0xc9, 0x15, 0x6d, 0x92, 0x45, 0x9c, 0x6c, 0x25,
		0x2f, 0x1d, 0x1d, 0x3a, 0x25, 0x44, 0x52, 0xd0, 0xa1, 0x53, 0xbb, 0xcd, 0x83, 0x99, 0xa6, 0x20,
		0xdf, 0x20, 0xdf, 0x20, 0xdf, 0x20, 0xdf, 0x20, 0xdf, 0x20, 0xdf, 0xe0, 0x0f, 0x39, 0x21, 0xdf,
		0x98, 0x69, 0x9a, 0xbe, 0xa9, 0xe8, 0xd9, 0x93, 0xd1, 0x83, 0x45, 0xcf, 0x1e, 0x79, 0x66, 0xa3,
		0x67, 0x0f, 0xbc, 0xdb, 0xcf, 0xb6, 0x22, 0x7a, 0xf6, 0x48, 0xdf, 0x8a, 0x98, 0x69, 0x0a, 0x22,
		0xcc, 0xce, 0x4a, 0x34, 0xeb, 0xd1, 0xce, 0x19, 0x18, 0x7f, 0x09, 0xe7, 0xf2, 0x5b, 0xc4, 0x27,
		0x2e, 0x3a, 0xb7, 0x17, 0x41, 0xd0, 0x34, 0xcc, 0x44, 0x10, 0x34, 0xc3, 0x95, 0x8a, 0x20, 0x68,
		0x96, 0x1b, 0x0c, 0x41, 0x50, 0xc9, 0x86, 0x23, 0x08, 0x9a, 0x3f, 0x99, 0x88, 0x20, 0x68, 0xe6,
		0x14, 0x01, 0x41, 0xd0, 0xb4, 0xbf, 0x10, 0x04, 0x05, 0xb7, 0x7d, 0xc0, 0x6c, 0x04, 0x41, 0xe1,
		0xdd, 0x7e, 0xb6, 0x15, 0x11, 0x04, 0x95, 0xbe, 0x15, 0x11, 0x04, 0x05, 0x11, 0x66, 0x67, 0x25,
		0x82, 0xa0, 0x3a, 0x59, 0x86, 0xd6, 0x84, 0xdb, 0xd9, 0xc9, 0xb5, 0x25, 0xd7, 0x46, 0xb7, 0x1f,
		0x74, 0x28, 0x4c, 0xb9, 0x4f, 0xd7, 0xa9, 0x33, 0x6c, 0x4d, 0x1f, 0xf0, 0xe1, 0xec, 0xf9, 0xa2,
		0x4f, 0x21, 0x73, 0x58, 0x32, 0xa6, 0x7b, 0x87, 0x7e, 0xf7, 0x8e, 0xd8, 0x4a, 0x34, 0xef, 0x78,
		0x8d, 0x79, 0x68, 0xde, 0x91, 0xe2, 0x3a, 0x44, 0xf3, 0x8e, 0x34, 0x37, 0x0e, 0x9a, 0x77, 0x64,
		0xcd, 0x37, 0xd1, 0xbc, 0x43, 0x5f, 0x31, 0x41, 0xbe, 0x79, 0x47, 0xe4, 0x5e, 0xf3, 0xc9, 0x40,
		0x99, 0x1a, 0xcb, 0x23, 0xfd, 0xa4, 0x88, 0xf4, 0x93, 0xdc, 0x10, 0x0f, 0x96, 0x04, 0x84, 0x1b,
		0x11, 0x61, 0x4b, 0x48, 0xd8, 0x12, 0x13, 0xae, 0x04, 0x85, 0x36, 0x51, 0x21, 0x4e, 0x58, 0xd8,
		0x10, 0x97, 0xc4, 0x50, 0x11, 0xf8, 0xe6, 0x95, 0x88, 0x02, 0x67, 0xc0, 0x07, 0xc3, 0x92, 0x71,
		0x56, 0xf7, 0xb6, 0x33, 0xc1, 0x02, 0x1e, 0xf4, 0x86, 0x1d, 0xcd, 0xe1, 0x48, 0x77, 0x58, 0xd3,
		0x1e, 0xae, 0xf4, 0x87, 0x3d, 0x0d, 0x62, 0x4f, 0x87, 0xb8, 0xd3, 0x22, 0x1e, 0xf4, 0x88, 0x09,
		0x4d, 0x62, 0x47, 0x97, 0x12, 0x83, 0x69, 0x77, 0x84, 0x7f, 0xd2, 0xd7, 0x50, 0x3f, 0x32, 0xd6,
		0x80, 0x3c, 0xb1, 0x25, 0x51, 0x9c, 0xc9, 0x94, 0x16, 0xa4, 0x8a, 0x3b, 0xb9, 0xd2, 0x86, 0x64,
		0x69, 0x43, 0xb6, 0x74, 0x21, 0x5d, 0xbc, 0xc8, 0x17, 0x33, 0x12, 0xc6, 0x96, 0x8c, 0x25, 0x86,
		0x33, 0x8b, 0x63, 0x3d, 0xea, 0xb4, 0x58, 0xc5, 0xb4, 0x1e, 0xa3, 0x69, 0x7b, 0x4c, 0xcd, 0xe7,
		0x4a, 0xd7, 0x74, 0xa0, 0x6d, 0x5a, 0xd1, 0x37, 0x5d, 0x68, 0x9c, 0x76, 0x74, 0x4e, 0x3b, 0x5a,
		0xa7, 0x1b, 0xbd, 0xe3, 0x49, 0xf3, 0x98, 0xd2, 0xbd, 0x64, 0xf1, 0xb0, 0xa9, 0x98, 0x7f, 0xd2,
		0x6b, 0x4c, 0x1c, 0x2f, 0xda, 0x67, 0xed, 0x32, 0xe6, 0x1c, 0xaa, 0xca, 0xf8, 0x16, 0x78, 0x95,
		0xde, 0x3f, 0xf6, 0xc5, 0xdb, 0x65, 0xef, 0x70, 0x2d, 0xd5, 0xd7, 0x54, 0x5c, 0x6c, 0xdc, 0x0e,
		0xd3, 0xd2, 0xfe, 0x47, 0xef, 0x87, 0x71, 0x95, 0xb1, 0x66, 0xee, 0x7c, 0x15, 0x02, 0xec, 0x1b,
		0x40, 0x00, 0x71, 0x08, 0x28, 0x97, 0x6a, 0xe5, 0xda, 0x41, 0xb5, 0x54, 0xab, 0x00, 0x0b, 0x20,
		0x48, 0x60, 0xfd, 0xf2, 0x57, 0xff, 0x0d, 0x9e, 0x37, 0x2c, 0x66, 0xee, 0x99, 0xb9, 0x74, 0x46,
		0x78, 0xd4, 0x7e, 0x7d, 0x3a, 0x26, 0x24, 0xff, 0xe9, 0x3e, 0x83, 0xb8, 0xc0, 0x31, 0x25, 0x66,
		0x47, 0x83, 0xee, 0x0a, 0xc9, 0x7f, 0x68, 0x04, 0xfe, 0x71, 0xfc, 0x2a, 0x28, 0x37, 0x5c, 0xe0,
		0x8f, 0x9c, 0x48, 0x5c, 0x04, 0xa6, 0x6b, 0x8e, 0xe5, 0x9c, 0x12, 0xe8, 0xb5, 0x43, 0x6f, 0x03,
		0xdd, 0xda, 0xf2, 0x82, 0x80, 0x71, 0x01, 0xd6, 0x1c, 0x43, 0x18, 0x96, 0x8e, 0xc5, 0x96, 0xa3,
		0x70, 0x2c, 0x0b, 0x73, 0x51, 0x38, 0x26, 0x71, 0x2d, 0xa3, 0x70, 0x4c, 0xe6, 0x46, 0x44, 0xe1,
		0x98, 0x6a, 0xca, 0x8d, 0xc2, 0x31, 0xb0, 0x8f, 0xc5, 0x62, 0xe0, 0x57, 0x38, 0x26, 0x2e, 0xa7,
		0x8b, 0x37, 0x64, 0x5c, 0x3b, 0xb6, 0xb8, 0x03, 0x94, 0x8f, 0x81, 0x4a, 0xe9, 0x45, 0xa9, 0xb4,
		0xa0, 0x56, 0xdc, 0x29, 0x96, 0x36, 0x54, 0x4b, 0x1b, 0xca, 0xa5, 0x0b, 0xf5, 0xe2, 0x45, 0xc1,
		0x98, 0x51, 0x31, 0xb6, 0x94, 0x6c, 0x9d, 0x9a, 0xf1, 0xaf, 0x1f, 0x5b, 0xdc, 0x08, 0xef, 0x02,
		0xb2, 0x22, 0x0a, 0xc8, 0x40, 0xdc, 0xf2, 0x4c, 0xe0, 0x74, 0x21, 0x72, 0xda, 0x11, 0x3a, 0xed,
		0x88, 0x9d, 0x6e, 0x04, 0x8f, 0x27, 0xd1, 0x63, 0x4a, 0xf8, 0xd8, 0x13, 0xbf, 0xe4, 0x06, 0x9c,
		0xf1, 0x75, 0xd9, 0xe4, 0xce, 0x02, 0x37, 0x5c, 0xe0, 0xca, 0x5d, 0x31, 0xc7, 0x27, 0xde, 0xd4,
		0x50, 0x1b, 0x8a, 0xa8, 0x13, 0x55, 0xd4, 0x92, 0x32, 0xea, 0x46, 0x1d, 0xb5, 0xa5, 0x90, 0xda,
		0x52, 0x49, 0x5d, 0x29, 0x25, 0x6f, 0x6a, 0xc9, 0x9c, 0x62, 0x6a, 0x43, 0x35, 0x93, 0x1b, 0xe1,
		0xd9, 0x47, 0xf4, 0x49, 0x1f, 0xca, 0xb5, 0x98, 0x42, 0x63, 0xd2, 0xa9, 0x1d, 0xf9, 0xd4, 0x91,
		0x84, 0x6a, 0x4d, 0x46, 0x75, 0x25, 0xa5, 0xda, 0x93, 0x53, 0xed, 0x49, 0xaa, 0xee, 0x64, 0x55,
		0x0f, 0xd2, 0xaa, 0x09, 0x79, 0xd5, 0x8e, 0xc4, 0x26, 0x37, 0x64, 0x0f, 0x87, 0x81, 0x08, 0x43,
		0xfd, 0x80, 0x7d, 0xe1, 0x8d, 0x17, 0x37, 0xa8, 0x19, 0xea, 0xe9, 0xd5, 0x51, 0x45, 0x5b, 0xa2,
		0xab, 0x33, 0xe1, 0xcd, 0x05, 0xf1, 0xd5, 0x9d, 0x00, 0xe7, 0x86, 0x08, 0xe7, 0x86, 0x10, 0xe7,
		0x85, 0x18, 0xeb, 0x45, 0x90, 0x35, 0x23, 0xca, 0xc9, 0x22, 0x64, 0xdf, 0xa1, 0xf6, 0x49, 0xaf,
		0x17, 0x9f, 0xd5, 0xcf, 0x59, 0xa6, 0xe9, 0xf9, 0xe6, 0x7f, 0x7d, 0x4f, 0xe8, 0xe8, 0x00, 0x17,
		0x21, 0xd5, 0xf7, 0x1a, 0xde, 0xdb, 0x89, 0x1d, 0x45, 0x22, 0xf0, 0xd8, 0xb7, 0xbe, 0x7d, 0xf4,
		0x06, 0xdf, 0xbe, 0x3d, 0xdb, 0x33, 0x6b, 0xfd, 0xbf, 0xcf, 0x8a, 0x66, 0xad, 0x3f, 0xfb, 0x58,
		0x8c, 0xff, 0x9a, 0x7d, 0x2e, 0x9d, 0xed, 0x99, 0xe5, 0xc5, 0xe7, 0xca, 0xd9, 0x9e, 0x59, 0xe9,
		0xef, 0x9e, 0x9f, 0xbf, 0xdb, 0xfd, 0xb1, 0x7f, 0xf7, 0xf2, 0x7f, 0xf8, 0xf6, 0x1f, 0x67, 0xe7,
		0xe7, 0xe3, 0x1f, 0xed, 0xbb, 0xe9, 0x9f, 0xad, 0xbb, 0xfe, 0x3f, 0x77, 0x7f, 0xd3, 0x95, 0x4b,
		0x4c, 0x6f, 0xfc, 0xfc, 0xfc, 0x5d, 0xff, 0x17, 0xfd, 0xdc, 0x6a, 0xff, 0x0d, 0x48, 0x02, 0xee,
		0x04, 0x34, 0xe7, 0x09, 0x8e, 0xcd, 0xbb, 0x3f, 0xe0, 0xa3, 0xf7, 0xa5, 0x69, 0xaf, 0xa9, 0xe9,
		0x0d, 0x15, 0x16, 0xc5, 0xd0, 0x8b, 0x0f, 0x85, 0xe5, 0x6c, 0xcb, 0x82, 0x4e, 0xc7, 0xe0, 0x3b,
		0x9a, 0x75, 0xab, 0x3a, 0xb1, 0xa3, 0x6f, 0xd6, 0xe9, 0xfc, 0xf5, 0x2d, 0x3e, 0x58, 0xcd, 0xf1,
		0x75, 0x79, 0xf1, 0x99, 0x61, 0x1b, 0x42, 0x7d, 0x81, 0x1e, 0xf9, 0x56, 0x70, 0x4d, 0x70, 0x49,
		0x5b, 0xbb, 0x24, 0x1d, 0x72, 0x9a, 0xf3, 0xe4, 0x84, 0x0c, 0x74, 0x9c, 0x07, 0x60, 0xbf, 0x78,
		0x7f, 0xe8, 0x90, 0x53, 0xaa, 0x55, 0x2e, 0x29, 0x0a, 0x97, 0x88, 0xdd, 0x08, 0x0a, 0x97, 0x88,
		0xdf, 0x14, 0x0a, 0x97, 0x98, 0xdc, 0x18, 0x0a, 0x97, 0xc0, 0xc9, 0xc0, 0xcb, 0x9e, 0xbb, 0xa8,
		0xb4, 0x29, 0x5c, 0x72, 0x7d, 0x3f, 0xd4, 0xb0, 0x70, 0x69, 0x76, 0x5b, 0xba, 0x24, 0x18, 0x8b,
		0x91, 0x3d, 0x71, 0x63, 0x00, 0x1b, 0xd9, 0x6e, 0xa8, 0x5b, 0x41, 0xd6, 0x1e, 0x0a, 0xb2, 0x40,
		0xae, 0x41, 0xb2, 0x41, 0xb6, 0x73, 0x47, 0xba, 0xb5, 0x27, 0xdf, 0xba, 0x93, 0x70, 0x3d, 0xc8,
		0xb8, 0x26, 0xa4, 0x3c, 0x59, 0x6c, 0xda, 0xe5, 0x97, 0x26, 0x5e, 0xeb, 0xc2, 0xf7, 0x5d, 0x61,
		0x7b, 0x3a, 0xf9, 0xac, 0x45, 0x44, 0xb5, 0x88, 0x03, 0x7a, 0x80, 0x40, 0x4a, 0x6b, 0x2a, 0xd2,
		0x09, 0x00, 0x92, 0xcd, 0x1f, 0xdf, 0x15, 0xa4, 0x1f, 0xa4, 0x1f, 0xa4, 0x1f, 0xa4, 0x1f, 0xa4,
		0x1f, 0xa4, 0x1f, 0xa4, 0x1f, 0x18, 0x1f, 0x58, 0x5f, 0x4e, 0xa4, 0x9f, 0x33, 0x14, 0x5e, 0xe4,
		0x44, 0xb7, 0x81, 0x18, 0xe9, 0x28, 0xff, 0x2a, 0x1a, 0xdd, 0x53, 0x73, 0xfe, 0xaa, 0x0e, 0xed,
		0x50, 0xe8, 0xdb, 0x44, 0xa5, 0x73, 0x7a, 0xf2, 0xe9, 0x6b, 0xc9, 0x6a, 0xfc, 0xd1, 0x3b, 0xe9,
		0x36, 0x3e, 0x35, 0xff, 0xb0, 0x0e, 0x9b, 0xed, 0xa3, 0x66, 0xfb, 0xb3, 0xd5, 0xe8, 0x76, 0xac,
		0x93, 0x7a, 0xef, 0x77, 0xeb, 0xb4, 0xf1, 0xf9, 0xb8, 0xd1, 0xee, 0x59, 0xbd, 0x3f, 0x4f, 0x1a,
		0xba, 0xb9, 0xed, 0xaf, 0xb6, 0x3b, 0x11, 0xa1, 0x96, 0xc5, 0xa1, 0x9a, 0x36, 0xb3, 0x58, 0xac,
		0xdb, 0xe6, 0xc9, 0xd7, 0xf2, 0x62, 0x69, 0x6a, 0xd8, 0xf9, 0xe0, 0x57, 0xac, 0x47, 0x5e, 0xeb,
		0xf1, 0x4b, 0xbb, 0xfd, 0xe5, 0xf8, 0xb0, 0xd1, 0x6d, 0x1c, 0x59, 0xcd, 0x76, 0xaf, 0xd1, 0xfd,
		0x54, 0xff, 0xd8, 0xd0, 0x78, 0x7d, 0x6a, 0x75, 0x47, 0x7d, 0xc8, 0x18, 0xdc, 0x05, 0xee, 0x40,
		0x17, 0xef, 0x83, 0xfa, 0x38, 0xce, 0xf5, 0x71, 0xba, 0x54, 0x69, 0xeb, 0x5f, 0x18, 0xa7, 0x41,
		0x45, 0x36, 0x4a, 0xe2, 0x54, 0xec, 0x8c, 0x89, 0xe7, 0x4d, 0xae, 0x2e, 0x44, 0x20, 0x86, 0xe6,
		0x37, 0x7f, 0xac, 0x4f, 0x6d, 0xdc, 0xda, 0x7d, 0xa1, 0x48, 0x8e, 0xc2, 0x6d, 0xa0, 0x48, 0x8e,
		0xf0, 0x8e, 0x41, 0x91, 0x1c, 0x65, 0x00, 0x40, 0x91, 0x1c, 0x37, 0xe1, 0x83, 0x22, 0x39, 0x30,
		0xb5, 0xb4, 0x17, 0x15, 0xa6, 0x7b, 0xd1, 0xf6, 0xa1, 0x98, 0xee, 0x05, 0xf2, 0x09, 0x12, 0x0a,
		0x32, 0x9a, 0x0b, 0x52, 0xaa, 0x3d, 0x39, 0xd5, 0x9e, 0xa4, 0xea, 0x4e, 0x56, 0xf5, 0x20, 0xad,
		0x9a, 0x90, 0x57, 0xed, 0x48, 0x6c, 0x72, 0x43, 0x8e, 0x17, 0x89, 0x60, 0x64, 0x0f, 0x84, 0xe9,
		0x0c, 0xf5, 0xcd, 0x4e, 0x5b, 0xb9, 0x4b, 0xcc, 0xf9, 0x02, 0xe5, 0x05, 0xf5, 0x05, 0x05, 0x06,
		0x15, 0xce, 0x27, 0x25, 0xce, 0x0d, 0x35, 0xce, 0x0b, 0x45, 0xd6, 0x8b, 0x2a, 0x6b, 0x46, 0x99,
		0x93, 0x45, 0xa8, 0xff, 0x9c, 0xaf, 0x89, 0xe3, 0x45, 0xfb, 0x25, 0x8d, 0x27, 0x7b, 0x55, 0x35,
		0xbc, 0xb5, 0xae, 0xed, 0x5d, 0x0a, 0x6d, 0xc7, 0x7a, 0xe9, 0x49, 0x51, 0xe2, 0x17, 0x77, 0xec,
		0x78, 0xda, 0x72, 0x30, 0xcd, 0xc5, 0xdd, 0xc6, 0x6d, 0xc6, 0xf5, 0x53, 0x39, 0xb8, 0xcf, 0x4f,
		0x81, 0x3d, 0x88, 0x1c, 0xdf, 0x3b, 0x72, 0x2e, 0x9d, 0x28, 0x9c, 0xde, 0xb0, 0xb6, 0xf7, 0x7b,
		0xf7, 0xab, 0xc6, 0xd0, 0x63, 0xdf, 0x00, 0x7a, 0x34, 0x83, 0x9e, 0x72, 0xa9, 0x56, 0xae, 0x1d,
		0x54, 0x4b, 0xb5, 0x0a, 0x30, 0x08, 0x82, 0x10, 0x77, 0x25, 0xf3, 0x0b, 0x93, 0x44, 0xe1, 0xc3,
		0xb3, 0x86, 0xbd, 0xc0, 0x9f, 0x44, 0x22, 0xd0, 0xfa, 0x94, 0xeb, 0xfe, 0x16, 0x71, 0xc4, 0xc5,
		0xe1, 0xb6, 0x70, 0xc4, 0xc5, 0x78, 0xb3, 0xe1, 0x88, 0x8b, 0x33, 0xa0, 0xe0, 0x88, 0x4b, 0xb3,
		0x1b, 0xc5, 0x11, 0x17, 0xf8, 0xa5, 0xf2, 0x45, 0xa8, 0xff, 0x11, 0x57, 0x3c, 0x75, 0xd6, 0x1e,
		0x0e, 0x03, 0x11, 0x86, 0xa6, 0xe7, 0x9b, 0xff, 0xf5, 0x3d, 0xa1, 0xf1, 0x81, 0x57, 0xf1, 0xbd,
		0x86, 0xf7, 0x76, 0x62, 0x47, 0x91, 0x08, 0x3c, 0x6d, 0xcf, 0xbc, 0x8c, 0xb7, 0x6f, 0xcf, 0xf6,
		0xcc, 0x5a, 0xff, 0xef, 0xb3, 0xa2, 0x59, 0xeb, 0xcf, 0x3e, 0x16, 0xe3, 0xbf, 0x66, 0x9f, 0x4b,
		0x67, 0x7b, 0x66, 0x79, 0xf1, 0xb9, 0x72, 0xb6, 0x67, 0x56, 0xfa, 0xbb, 0xe7, 0xe7, 0xef, 0x76,
		0x7f, 0xec, 0xdf, 0xbd, 0xfc, 0x1f, 0xbe, 0xfd, 0xc7, 0xd9, 0xf9, 0xf9, 0xf8, 0x47, 0xfb, 0x6e,
		0xfa, 0x67, 0xeb, 0xae, 0xff, 0xcf, 0xdd, 0xdf, 0x74, 0xe5, 0x12, 0xd3, 0x1b, 0x3f, 0x3f, 0x7f,
		0xd7, 0xff, 0xc5, 0x40, 0x00, 0x0a, 0x24, 0x01, 0x77, 0x92, 0x37, 0x9a, 0xa3, 0x5b, 0x3f, 0xa4,
		0xe4, 0xbe, 0x72, 0xd5, 0x17, 0x69, 0xb5, 0xb9, 0x48, 0x41, 0xa7, 0xaa, 0xcf, 0x9d, 0x5c, 0xb4,
		0x4b, 0xfa, 0x92, 0xbc, 0xc0, 0xdf, 0xfd, 0xb1, 0x0e, 0xcd, 0x93, 0xf4, 0x01, 0x7b, 0x34, 0x18,
		0x80, 0x7b, 0x82, 0x5b, 0x4a, 0xc1, 0x2d, 0xa1, 0x6f, 0x1f, 0x37, 0x47, 0x84, 0xfe, 0x7d, 0xb0,
		0x5c, 0x7b, 0x57, 0x63, 0xb4, 0x9c, 0x30, 0xaa, 0x47, 0x11, 0xef, 0x1a, 0x60, 0xe3, 0xd8, 0xf1,
		0x1a, 0xae, 0x88, 0x37, 0x33, 0xef, 0xc3, 0x67, 0xe3, 0xd8, 0xbe, 0x59, 0xba, 0x93, 0xe2, 0xfb,
		0x72, 0xf9, 0xa0, 0x5a, 0x2e, 0xef, 0x55, 0xf7, 0xab, 0x7b, 0xb5, 0x4a, 0xa5, 0x78, 0xc0, 0x79,
		0x90, 0x88, 0xd1, 0x09, 0x86, 0x53, 0x70, 0x3d, 0xbc, 0x35, 0x3e, 0xec, 0x78, 0x13, 0xd7, 0xc5,
		0x4e, 0x07, 0x99, 0x04, 0x89, 0xfc, 0x09, 0x89, 0x64, 0xcc, 0x1a, 0xb5, 0x67, 0x8b, 0x3c, 0xf9,
		0x21, 0x3f, 0x76, 0xc5, 0xcb, 0x62, 0x66, 0xde, 0x81, 0xbb, 0x57, 0xc8, 0x85, 0x37, 0x60, 0xe8,
		0x05, 0xb4, 0x45, 0x7f, 0x5e, 0xa8, 0xcf, 0x07, 0x3b, 0x79, 0x58, 0xca, 0x04, 0xdd, 0xb9, 0xa2,
		0xba, 0xce, 0x68, 0xce, 0x08, 0xc4, 0x75, 0x03, 0x6f, 0x1e, 0x98, 0x4d, 0x1f, 0x01, 0x19, 0xa0,
		0x9f, 0xb1, 0xb1, 0x13, 0xd9, 0x00, 0xe0, 0x7d, 0xdb, 0xea, 0x8d, 0x5b, 0x60, 0xe2, 0x75, 0x78,
		0xb5, 0xa8, 0x66, 0x57, 0xac, 0xc4, 0xb1, 0x08, 0x89, 0x75, 0x71, 0x11, 0xd7, 0xa2, 0x21, 0xf6,
		0xc5, 0x40, 0xec, 0x8b, 0x7c, 0xb8, 0x17, 0xef, 0x40, 0x8d, 0xa5, 0xb9, 0x18, 0xb8, 0xb5, 0x58,
		0x66, 0x3a, 0x0f, 0x84, 0xf5, 0xdc, 0x0f, 0xa6, 0xf3, 0x3d, 0xd8, 0x56, 0x7c, 0x73, 0xae, 0xe8,
		0xd6, 0xa2, 0x62, 0x9b, 0x7b, 0x45, 0xb6, 0x36, 0x15, 0xd7, 0xda, 0x54, 0x54, 0xeb, 0x52, 0x31,
		0x8d, 0x03, 0x4f, 0x90, 0xb1, 0x87, 0x48, 0x99, 0x33, 0x8c, 0x23, 0xd3, 0x7c, 0x11, 0x73, 0x39,
		0xc0, 0x15, 0xdf, 0x09, 0x53, 0x9c, 0xe1, 0xdd, 0xbc, 0x87, 0x7d, 0x93, 0x1e, 0x1d, 0x9a, 0xf1,
		0x68, 0xd5, 0x74, 0x47, 0x97, 0xe6, 0x3a, 0xda, 0x35, 0xd1, 0xd1, 0xae, 0x59, 0x8e, 0x6e, 0x4d,
		0x71, 0x50, 0xeb, 0x20, 0x73, 0xf1, 0xb0, 0x6f, 0x66, 0x73, 0xcf, 0xa0, 0x02, 0x93, 0x39, 0x89,
		0x5a, 0x26, 0x52, 0xc5, 0x32, 0xe3, 0x7b, 0x68, 0x78, 0x93, 0xab, 0xe9, 0xa2, 0xba, 0x43, 0x3a,
		0x30, 0xc0, 0xe7, 0x27, 0xd2, 0xed, 0x7a, 0xde, 0x95, 0x5b, 0x03, 0xed, 0x36, 0xbb, 0x15, 0x88,
		0x37, 0x88, 0x37, 0x88, 0x37, 0x88, 0x37, 0x88, 0x37, 0x88, 0x37, 0x88, 0x37, 0xf0, 0x27, 0x88,
		0xb7, 0x67, 0x7a, 0x0d, 0xf6, 0x43, 0xf5, 0x34, 0x18, 0x9e, 0xa7, 0xc9, 0x90, 0x3c, 0x0d, 0x7a,
		0x02, 0xe9, 0x34, 0xf4, 0x4e, 0xb3, 0xb1, 0x0e, 0xba, 0x0d, 0xb1, 0xd3, 0x71, 0x50, 0x94, 0x06,
		0x9d, 0x38, 0xb5, 0x1a, 0x3e, 0xa7, 0x2b, 0x04, 0xe8, 0x36, 0x4c, 0x4e, 0x4b, 0x2c, 0x40, 0xc7,
		0x32, 0x25, 0x5f, 0x7d, 0x84, 0xfe, 0x61, 0x31, 0x77, 0xcf, 0x8c, 0x4e, 0x20, 0xf4, 0x6a, 0xc7,
		0x37, 0xff, 0x13, 0xd7, 0xe6, 0xd6, 0xda, 0x94, 0x94, 0xaf, 0xff, 0x07, 0x86, 0xdd, 0xaa, 0xd1,
		0x14, 0x24, 0x97, 0x40, 0x8f, 0xa6, 0x20, 0x84, 0x81, 0x1d, 0xdd, 0x41, 0x94, 0x43, 0x39, 0xba,
		0x84, 0xe4, 0x06, 0x0e, 0x99, 0x15, 0xb8, 0xb2, 0x2c, 0x6c, 0x45, 0x37, 0x90, 0x8c, 0x0d, 0x46,
		0x37, 0x10, 0xc9, 0xc6, 0xa3, 0x1b, 0x88, 0xa2, 0x1b, 0x40, 0x37, 0x10, 0x70, 0x0e, 0x7d, 0x64,
		0x18, 0xbb, 0x6e, 0x20, 0x2c, 0x8b, 0x4e, 0x13, 0x57, 0xc3, 0xb0, 0x46, 0x82, 0xe9, 0x19, 0x22,
		0x7a, 0x81, 0x80, 0x52, 0xe5, 0x8b, 0x5a, 0x69, 0x43, 0xb1, 0xb4, 0xa1, 0x5a, 0xba, 0x50, 0x2e,
		0x5e, 0xd4, 0x8b, 0x19, 0x05, 0x4b, 0x16, 0x09, 0xdb, 0x9c, 0xe2, 0x04, 0xf5, 0x9d, 0xa1, 0xf0,
		0x22, 0x27, 0xba, 0x0d, 0xc4, 0x88, 0x23, 0xee, 0x2f, 0x62, 0x44, 0x0c, 0x93, 0x8a, 0x8c, 0xe6,
		0xfc, 0xd1, 0x1f, 0xda, 0xa1, 0x06, 0x75, 0x7d, 0x9d, 0xd3, 0x93, 0x4f, 0x5f, 0x4b, 0x56, 0xe3,
		0x8f, 0x5e, 0xa3, 0x7d, 0xd4, 0x38, 0xb2, 0x4e, 0xba, 0x8d, 0x4f, 0xcd, 0x3f, 0xac, 0xd3, 0xe6,
		0x91, 0xd5, 0xaa, 0x1f, 0x36, 0x5a, 0xd6, 0x61, 0xb3, 0x7d, 0xd4, 0x6c, 0x7f, 0xb6, 0x4e, 0xbf,
		0x1c, 0xf6, 0x5a, 0x5f, 0xad, 0xde, 0x9f, 0x27, 0x0d, 0xae, 0x4e, 0x2e, 0xce, 0x69, 0x0b, 0x59,
		0x27, 0x7f, 0x33, 0xaf, 0xd5, 0x5a, 0xac, 0xba, 0x46, 0xb7, 0x63, 0x9d, 0xd4, 0x7b, 0xbf, 0x33,
		0x2e, 0x02, 0xfa, 0x15, 0x6b, 0x48, 0xfd, 0x1a, 0x3a, 0x6e, 0xf4, 0xba, 0xcd, 0x8f, 0x58, 0x45,
		0x58, 0x45, 0xaf, 0x5d, 0x45, 0x53, 0x47, 0x77, 0x7c, 0xd2, 0x3a, 0x5d, 0xf5, 0x76, 0x28, 0x4e,
		0x94, 0xfb, 0xd5, 0x87, 0x40, 0x83, 0xb5, 0x8c, 0x2c, 0x45, 0xea, 0x57, 0xb6, 0x76, 0xeb, 0x98,
		0xfa, 0xc5, 0x2c, 0x83, 0x57, 0x9f, 0x74, 0x2f, 0x3e, 0x99, 0xba, 0x0c, 0x92, 0xbc, 0xde, 0x00,
		0x96, 0x5f, 0xbf, 0xa5, 0x58, 0x0d, 0xdd, 0xe7, 0x37, 0x5c, 0x5f, 0x8b, 0x21, 0xfa, 0xbc, 0x86,
		0xe5, 0x53, 0xdf, 0x71, 0xcc, 0x08, 0x90, 0x86, 0xc4, 0xc7, 0x60, 0x91, 0x16, 0xac, 0x05, 0xd5,
		0xa1, 0x4d, 0x72, 0xe8, 0x52, 0x07, 0x9a, 0x96, 0x11, 0x85, 0x56, 0x2e, 0x90, 0xaa, 0x19, 0x94,
		0x12, 0x86, 0x51, 0x1d, 0xe0, 0x93, 0x26, 0x74, 0xd2, 0x03, 0x26, 0x5a, 0x16, 0x11, 0x83, 0x48,
		0xea, 0xd0, 0xa8, 0x0f, 0x24, 0x12, 0x44, 0x43, 0xe6, 0x28, 0x48, 0x0b, 0x00, 0xe9, 0xc0, 0x0c,
		0x21, 0x88, 0x21, 0x5a, 0xbd, 0x48, 0xba, 0x4a, 0x91, 0x68, 0x35, 0x22, 0xd9, 0x94, 0x79, 0xca,
		0x29, 0xf1, 0x2c, 0x52, 0xde, 0xa9, 0xa7, 0xb4, 0xb3, 0x49, 0x59, 0x67, 0x93, 0x92, 0xce, 0x25,
		0xe5, 0x1c, 0xd4, 0xfd, 0x67, 0x2f, 0x91, 0x6a, 0x75, 0x1e, 0xed, 0x2a, 0x3c, 0x0e, 0xd5, 0x76,
		0xc4, 0xab, 0xea, 0xc8, 0x57, 0xcf, 0x71, 0xa8, 0x92, 0x63, 0x55, 0x0d, 0xc7, 0xa5, 0xea, 0x8d,
		0x5d, 0x75, 0x1b, 0xbb, 0x2a, 0x36, 0x6e, 0xd5, 0x6a, 0x38, 0x28, 0x79, 0xc9, 0xcb, 0x25, 0x5f,
		0x65, 0xc6, 0xac, 0x9a, 0x8c, 0x43, 0xd5, 0x18, 0xaf, 0xea, 0xb0, 0x27, 0xab, 0xc0, 0xd8, 0xd4,
		0x7c, 0x71, 0xaa, 0xed, 0x62, 0xd6, 0x7c, 0x6c, 0xa3, 0x14, 0xd0, 0x40, 0x2b, 0xba, 0xdc, 0x2d,
		0x82, 0xfb, 0xb2, 0x50, 0xbc, 0xfd, 0xfc, 0xbd, 0xfd, 0x75, 0xbf, 0xd0, 0xad, 0xb7, 0x3f, 0x37,
		0x0c, 0x24, 0x2b, 0x6f, 0xf5, 0xd5, 0x07, 0xcd, 0x67, 0x6e, 0x15, 0x22, 0xaa, 0x3f, 0xd5, 0xb6,
		0x48, 0x86, 0xc8, 0x26, 0x19, 0x82, 0x68, 0x21, 0x11, 0xbb, 0x04, 0x08, 0x7a, 0x75, 0x41, 0x48,
		0x7b, 0x78, 0x68, 0x5d, 0x4d, 0xbc, 0xef, 0x9e, 0xff, 0x97, 0x67, 0x46, 0xee, 0x35, 0xdd, 0xe4,
		0x87, 0x65, 0x23, 0x91, 0x02, 0xf1, 0x1c, 0xb3, 0x90, 0x02, 0xb1, 0xc5, 0x72, 0x43, 0x0a, 0xc4,
		0x36, 0x1b, 0x02, 0x29, 0x10, 0x69, 0x73, 0x3d, 0xa4, 0x40, 0xf0, 0x27, 0xec, 0x64, 0x53, 0x20,
		0x68, 0x4f, 0x6d, 0x60, 0x31, 0xa5, 0x81, 0xf8, 0x54, 0x06, 0x24, 0x41, 0xe4, 0x85, 0x1c, 0x70,
		0x21, 0x09, 0xec, 0xc8, 0x02, 0x3b, 0xd2, 0xc0, 0x8d, 0x3c, 0xd0, 0x24, 0x11, 0x44, 0xc9, 0x04,
		0x79, 0x52, 0x91, 0x18, 0xe8, 0x0a, 0xef, 0x32, 0x0e, 0x01, 0x32, 0x39, 0xaa, 0x9f, 0xdb, 0x4b,
		0x7c, 0x4f, 0xf3, 0x98, 0x64, 0xc0, 0x66, 0x72, 0x01, 0xa7, 0x49, 0x05, 0x2c, 0x27, 0x13, 0x70,
		0x9b, 0x44, 0xc0, 0x76, 0xf2, 0x00, 0xdb, 0x49, 0x03, 0x5c, 0x27, 0x0b, 0xa0, 0x63, 0xd7, 0x36,
		0x2f, 0x9d, 0xcd, 0xa4, 0x80, 0xfb, 0x83, 0x08, 0xc7, 0x8b, 0x8a, 0x07, 0x1c, 0x20, 0x77, 0xce,
		0x11, 0x0e, 0x18, 0x98, 0xda, 0xb5, 0xbd, 0x4b, 0xc1, 0xa6, 0x71, 0x3c, 0xa3, 0x46, 0x9f, 0xc7,
		0x8e, 0xc7, 0x70, 0xb0, 0x22, 0xcf, 0x31, 0x5d, 0x71, 0x8a, 0x2c, 0x43, 0xbb, 0x3f, 0x05, 0xf6,
		0x20, 0x72, 0x7c, 0xef, 0xc8, 0xb9, 0x74, 0x66, 0xad, 0x08, 0xf9, 0x74, 0x33, 0x66, 0xd4, 0xef,
		0xf5, 0xd8, 0xbe, 0xc1, 0x56, 0x94, 0xbc, 0x15, 0x0f, 0x2a, 0x95, 0xfd, 0x0a, 0xb6, 0x23, 0xb8,
		0x30, 0x2f, 0x2b, 0xfb, 0x68, 0x34, 0xa8, 0x9b, 0x3b, 0xe0, 0x31, 0xed, 0x95, 0xd3, 0x74, 0x57,
		0xc4, 0x40, 0x53, 0x36, 0x14, 0x31, 0xd0, 0x8c, 0x8d, 0x46, 0x0c, 0x54, 0x92, 0xe1, 0x88, 0x81,
		0x82, 0x11, 0xb0, 0x11, 0x89, 0x88, 0x81, 0x66, 0xcf, 0x11, 0x10, 0x03, 0x4d, 0xfb, 0x0b, 0x31,
		0x50, 0x90, 0xdb, 0x07, 0xcc, 0x46, 0x0c, 0x14, 0xee, 0xed, 0x67, 0x5b, 0x11, 0x31, 0x50, 0xe9,
		0x5b, 0x11, 0x31, 0x50, 0x70, 0x61, 0x86, 0x56, 0x22, 0x06, 0xaa, 0x9d, 0x3b, 0x30, 0xae, 0xe7,
		0x90, 0xc4, 0x24, 0x08, 0x3a, 0x33, 0x17, 0x51, 0xd0, 0x34, 0xcc, 0x44, 0x14, 0x34, 0xc3, 0x85,
		0x8a, 0x28, 0x68, 0x96, 0x1b, 0x0c, 0x51, 0x50, 0xc9, 0x86, 0x23, 0x0a, 0x9a, 0x3f, 0x99, 0xc8,
		0x30, 0x0a, 0x7a, 0xe1, 0x78, 0x76, 0x70, 0xcb, 0x28, 0x0a, 0x5a, 0x03, 0xa5, 0xd6, 0xc8, 0x32,
		0xcc, 0x2f, 0xdc, 0xce, 0x4e, 0xae, 0xfd, 0xa9, 0x96, 0x3a, 0xe1, 0x90, 0x1f, 0x7a, 0xcf, 0xad,
		0x67, 0xd5, 0x97, 0xd9, 0xb3, 0x25, 0x3e, 0xd6, 0x1e, 0x9d, 0xfa, 0x58, 0x21, 0x23, 0x3a, 0xf5,
		0x65, 0x8f, 0x84, 0xe8, 0xd7, 0x97, 0x22, 0xf6, 0xa1, 0x69, 0x1f, 0x65, 0x4b, 0x88, 0xa0, 0x9b,
		0xd1, 0x72, 0xc2, 0xa8, 0x1e, 0x45, 0xb4, 0xda, 0x0f, 0x18, 0xc7, 0x8e, 0xd7, 0x70, 0xc5, 0x95,
		0xf0, 0x66, 0xc7, 0x46, 0x84, 0xda, 0x2c, 0x1e, 0xdb, 0x37, 0x4b, 0x96, 0x15, 0xdf, 0x97, 0xcb,
		0x07, 0xd5, 0x72, 0x79, 0xaf, 0xba, 0x5f, 0xdd, 0xab, 0x55, 0x2a, 0xc5, 0x03, 0x4a, 0x63, 0x17,
		0x8c, 0x4e, 0x30, 0x14, 0x81, 0x18, 0x1e, 0xde, 0x1a, 0x1f, 0x76, 0xbc, 0x89, 0xeb, 0x62, 0xe5,
		0xd3, 0xf7, 0xe7, 0x5c, 0xfd, 0xb8, 0x41, 0x6a, 0x04, 0x2c, 0x27, 0x9f, 0x4d, 0xc3, 0x51, 0xab,
		0x77, 0x8b, 0x6a, 0x2d, 0x50, 0x0c, 0x4b, 0xd4, 0xe0, 0x88, 0x23, 0x0c, 0x11, 0x80, 0x20, 0x46,
		0xd0, 0xa3, 0x16, 0x76, 0xd4, 0x6d, 0x76, 0x35, 0x57, 0x56, 0x04, 0x2f, 0x54, 0x60, 0x85, 0x19,
		0x9c, 0x28, 0x44, 0x12, 0x1e, 0x08, 0xa2, 0x06, 0x3c, 0xe4, 0x6f, 0x5d, 0x05, 0xdb, 0xd6, 0xb8,
		0x0c, 0xec, 0x41, 0xbc, 0x2a, 0x95, 0xed, 0xd8, 0xe4, 0x70, 0xf4, 0xde, 0x14, 0x45, 0xf0, 0xa5,
		0xb6, 0x21, 0xaf, 0xf2, 0x7c, 0x27, 0x0a, 0x79, 0x4c, 0xa4, 0xf2, 0x93, 0xa8, 0xe4, 0x1d, 0x91,
		0xcb, 0x27, 0x22, 0x97, 0x27, 0x44, 0x2d, 0xff, 0x27, 0x5f, 0xb4, 0x4f, 0x75, 0x43, 0x59, 0x23,
		0xd6, 0x63, 0xca, 0x77, 0x69, 0xd2, 0x08, 0x41, 0xbd, 0x3a, 0x24, 0xd2, 0x5b, 0x9e, 0x4c, 0x0a,
		0x2f, 0xa5, 0x14, 0x5d, 0x92, 0x29, 0xb8, 0xd4, 0x52, 0x6c, 0xc9, 0xa6, 0xd0, 0x92, 0x4d, 0x91,
		0xa5, 0x9a, 0x02, 0x9b, 0xef, 0x40, 0x2b, 0x95, 0x5e, 0xeb, 0x06, 0xa5, 0x49, 0x6d, 0xcb, 0x9e,
		0x92, 0xca, 0xb6, 0xa6, 0x35, 0x8c, 0x85, 0x5c, 0xed, 0x0b, 0xc5, 0x1a, 0x17, 0xd2, 0xb5, 0x2c,
		0x54, 0x6b, 0x56, 0xc8, 0xd7, 0xa6, 0x90, 0xaf, 0x41, 0xa1, 0x5e, 0x6b, 0x82, 0x94, 0x23, 0x8a,
		0x0e, 0x38, 0x31, 0x88, 0xe6, 0xe4, 0x34, 0xd2, 0x13, 0xd3, 0x30, 0x2e, 0x95, 0xbf, 0xb3, 0x66,
		0xe1, 0xb4, 0xa9, 0x3b, 0x6f, 0x36, 0x4e, 0x9c, 0x8d, 0x33, 0xe7, 0xe2, 0xd4, 0x69, 0x39, 0x77,
		0x62, 0x4e, 0x9e, 0xac, 0xb3, 0x4f, 0x0c, 0x73, 0xc6, 0xa6, 0xe3, 0x45, 0x22, 0x18, 0xd9, 0x03,
		0x61, 0xda, 0xc3, 0x61, 0x20, 0xc2, 0x90, 0xfe, 0xf4, 0xd4, 0x07, 0xad, 0xa6, 0x3d, 0x4c, 0x75,
		0x0f, 0xc3, 0x54, 0xb5, 0xa3, 0x0c, 0xac, 0xa8, 0x03, 0x17, 0x0a, 0xc1, 0x8e, 0x4a, 0xb0, 0xa3,
		0x14, 0xdc, 0xa8, 0x05, 0x4d, 0x8a, 0x41, 0x94, 0x6a, 0x24, 0x2f, 0x97, 0x7c, 0x0f, 0x8a, 0x25,
		0x6f, 0x7e, 0x5d, 0x5e, 0x78, 0x71, 0xd3, 0xf3, 0xcd, 0xff, 0xfa, 0x1e, 0xe9, 0x3a, 0xf0, 0x85,
		0xe8, 0x7f, 0x4f, 0xd8, 0xc6, 0x13, 0x3b, 0x8a, 0x44, 0xe0, 0x91, 0x6f, 0xc1, 0x6b, 0xbc, 0x7d,
		0x7b, 0xb6, 0x67, 0xd6, 0xfa, 0x7f, 0x9f, 0x15, 0xcd, 0x5a, 0x7f, 0xf6, 0xb1, 0x18, 0xff, 0x35,
		0xfb, 0x5c, 0x3a, 0xdb, 0x33, 0xcb, 0x8b, 0xcf, 0x95, 0xb3, 0x3d, 0xb3, 0xd2, 0xdf, 0x3d, 0x3f,
		0x7f, 0xb7, 0xfb, 0x63, 0xff, 0xee, 0xe5, 0xff, 0xf0, 0xed, 0x3f, 0xce, 0xce, 0xcf, 0xc7, 0x3f,
		0xda, 0x77, 0xd3, 0x3f, 0x5b, 0x77, 0xfd, 0x7f, 0xee, 0xfe, 0x46, 0xdd, 0xa7, 0x4c, 0x6f, 0xe0,
		0xfc, 0xfc, 0x5d, 0xff, 0x17, 0xba, 0xb0, 0xdc, 0x47, 0x5f, 0x01, 0xae, 0x8e, 0xc2, 0x18, 0x8b,
		0xc0, 0xf1, 0x87, 0xf4, 0x05, 0xdf, 0xdc, 0x4e, 0x48, 0x3c, 0x48, 0x3c, 0x48, 0x3c, 0x48, 0x3c,
		0x48, 0x3c, 0x48, 0x3c, 0x48, 0x3c, 0x46, 0x12, 0x6f, 0xe2, 0x78, 0xd1, 0x7e, 0x89, 0x81, 0xa8,
		0xab, 0x12, 0x36, 0x91, 0xc7, 0x50, 0x15, 0x06, 0x4d, 0x2f, 0x39, 0x0d, 0x51, 0x61, 0x36, 0xb1,
		0x81, 0xdb, 0xd0, 0x14, 0x8e, 0xd3, 0x19, 0x18, 0x0c, 0x49, 0x61, 0x35, 0x1c, 0x85, 0xeb, 0x16,
		0x2b, 0x97, 0x6a, 0xe5, 0xda, 0x41, 0xb5, 0x54, 0xab, 0x60, 0xaf, 0xe5, 0x8b, 0x90, 0xd2, 0xb7,
		0x0e, 0x41, 0x41, 0xb6, 0x58, 0x6e, 0x04, 0xc2, 0x0e, 0x09, 0x37, 0x3c, 0x4e, 0x44, 0xc5, 0xdc,
		0x4e, 0x04, 0x05, 0x5f, 0x63, 0x1e, 0x82, 0x82, 0x29, 0xae, 0x44, 0x04, 0x05, 0xd3, 0xdc, 0x38,
		0x08, 0x0a, 0x66, 0x6c, 0x30, 0x82, 0x82, 0xfa, 0xaa, 0x30, 0x46, 0x41, 0x41, 0xe1, 0x4d, 0xae,
		0x44, 0x30, 0xeb, 0xca, 0xc5, 0x20, 0xdd, 0xa3, 0x4c, 0xd8, 0xc6, 0x86, 0x37, 0xb9, 0x9a, 0xbe,
		0xf4, 0x3b, 0xd0, 0x6e, 0xb6, 0xb4, 0x3b, 0xa2, 0xbc, 0x71, 0xef, 0x2b, 0xa3, 0xa7, 0x56, 0x82,
		0x72, 0x83, 0x72, 0x83, 0x72, 0x83, 0x72, 0x83, 0x72, 0x83, 0x72, 0x83, 0x72, 0x73, 0x4a, 0xb5,
		0x1e, 0x0a, 0x2f, 0x72, 0xa2, 0xdb, 0x40, 0x8c, 0x38, 0x50, 0x6e, 0xc2, 0x07, 0x1b, 0x46, 0x73,
		0xfe, 0x28, 0x0f, 0xed, 0x90, 0xd1, 0x18, 0xe8, 0xcf, 0xdd, 0xfa, 0xc7, 0x86, 0xd5, 0x3a, 0xad,
		0x5b, 0xbd, 0xd6, 0x57, 0xab, 0xf7, 0xe7, 0x49, 0xe3, 0x94, 0x3a, 0xd6, 0xc7, 0xc7, 0x5d, 0x21,
		0xf9, 0xbc, 0x87, 0x1d, 0x16, 0xb9, 0x0f, 0x0f, 0x2c, 0x86, 0x93, 0x46, 0xb7, 0xd9, 0x39, 0x32,
		0x70, 0xec, 0x9d, 0xd3, 0xf7, 0xdf, 0x6d, 0x9c, 0xf6, 0xea, 0xdd, 0x9e, 0xd5, 0x6d, 0xd4, 0x4f,
		0x3b, 0x6d, 0xac, 0x83, 0xbc, 0xae, 0x83, 0xe6, 0x89, 0xd5, 0x6c, 0xf7, 0x1a, 0xdd, 0x4f, 0xd3,
		0x6f, 0xea, 0x47, 0x47, 0xdd, 0xc6, 0xe9, 0x29, 0x06, 0x55, 0x6f, 0xf7, 0xd5, 0x07, 0xc3, 0x67,
		0x6e, 0x15, 0xfa, 0x5a, 0xfc, 0x54, 0xd6, 0x62, 0x1a, 0xe8, 0x36, 0xf3, 0x36, 0x92, 0xc1, 0x02,
		0xf7, 0x73, 0x40, 0xa9, 0x4e, 0x41, 0xa6, 0x3a, 0x90, 0xe3, 0xf3, 0xf4, 0x11, 0x4e, 0x3f, 0x24,
		0xb3, 0x3f, 0x09, 0x0e, 0x3b, 0x26, 0x34, 0xf6, 0x93, 0x50, 0x23, 0xca, 0xe5, 0x91, 0xb7, 0x64,
		0xdb, 0xce, 0xd1, 0x9d, 0xcb, 0x8b, 0xe6, 0x73, 0x2f, 0x34, 0x0c, 0xcd, 0xe7, 0xb6, 0x34, 0x12,
		0xcd, 0xe7, 0x52, 0x32, 0x14, 0xcd, 0xe7, 0x40, 0xd2, 0xe5, 0xbd, 0x44, 0xb2, 0xcd, 0xe7, 0x68,
		0x76, 0x9c, 0xdd, 0xc0, 0x64, 0xaa, 0x94, 0x9c, 0x30, 0x09, 0x20, 0x4f, 0x06, 0x38, 0x90, 0x02,
		0x56, 0xe4, 0x80, 0x0b, 0x49, 0x60, 0x47, 0x16, 0xd8, 0x91, 0x06, 0x6e, 0xe4, 0x81, 0x26, 0x89,
		0x20, 0x4a, 0x26, 0xc8, 0x93, 0x8a, 0xc4, 0x40, 0x57, 0x78, 0x97, 0x71, 0xd8, 0x8f, 0xc9, 0xc9,
		0xfc, 0xdc, 0x5e, 0xe2, 0x7b, 0x9a, 0x47, 0xa9, 0x2c, 0x79, 0xda, 0xc1, 0x89, 0x7e, 0xb0, 0xa4,
		0x21, 0xdc, 0xe8, 0x08, 0x5b, 0x5a, 0xc2, 0x96, 0x9e, 0x70, 0xa5, 0x29, 0xb4, 0xe9, 0x0a, 0x71,
		0xda, 0x92, 0xbc, 0x74, 0xf2, 0x29, 0x9b, 0x1b, 0xa8, 0x3b, 0x71, 0xbc, 0xa8, 0x78, 0xc0, 0x01,
		0x72, 0xe7, 0x1c, 0xe1, 0x80, 0x81, 0xa9, 0x3c, 0x5a, 0x2a, 0x2d, 0xbe, 0x78, 0xb8, 0xb0, 0x1d,
		0x6e, 0x2d, 0x96, 0x98, 0x91, 0xdb, 0x0d, 0xb3, 0x99, 0xb5, 0x5c, 0x4a, 0xec, 0x66, 0xd8, 0x0e,
		0x86, 0x89, 0x7b, 0x5b, 0xdd, 0x8a, 0x8c, 0x5a, 0x31, 0xe9, 0xb2, 0x15, 0x0f, 0x2a, 0x95, 0xfd,
		0x0a, 0xb6, 0x23, 0xb8, 0x30, 0x2f, 0x2b, 0xfb, 0xe8, 0x76, 0xa5, 0x9b, 0x3b, 0xa0, 0x5d, 0x56,
		0xbe, 0xa1, 0x72, 0x08, 0x97, 0x97, 0x33, 0xf3, 0x4d, 0x88, 0x81, 0x66, 0xb9, 0x4e, 0x11, 0x03,
		0xcd, 0x72, 0x83, 0x21, 0x06, 0x2a, 0xd9, 0x70, 0xc4, 0x40, 0xf3, 0x27, 0x12, 0x11, 0x03, 0xcd,
		0x9e, 0x23, 0x20, 0x06, 0x9a, 0xf6, 0x17, 0x62, 0xa0, 0x20, 0xb7, 0x0f, 0x98, 0x8d, 0x18, 0x28,
		0xdc, 0xdb, 0xcf, 0xb6, 0x22, 0x62, 0xa0, 0xd2, 0xb7, 0x22, 0x62, 0xa0, 0xe0, 0xc2, 0x0c, 0xad,
		0x44, 0x0c, 0x54, 0x3b, 0x77, 0x60, 0x5c, 0xcf, 0x21, 0x89, 0x49, 0x10, 0x74, 0x66, 0x2e, 0xa2,
		0xa0, 0x69, 0x98, 0x89, 0x28, 0x68, 0x86, 0x0b, 0x15, 0x51, 0xd0, 0x2c, 0x37, 0x18, 0xa2, 0xa0,
		0x92, 0x0d, 0x47, 0x14, 0x34, 0x7f, 0x32, 0x91, 0x61, 0x14, 0xf4, 0xc2, 0xf1, 0xec, 0xe0, 0x96,
		0x51, 0x14, 0xb4, 0x06, 0x4a, 0xad, 0x91, 0x65, 0x54, 0x2b, 0xd2, 0x88, 0xf7, 0xa2, 0x4a, 0xec,
		0xe4, 0xd7, 0x93, 0x6a, 0xa9, 0x07, 0x4e, 0x81, 0x72, 0x31, 0xfc, 0x0e, 0xab, 0x3e, 0x55, 0x5f,
		0x66, 0x4f, 0x95, 0x68, 0xcb, 0x2a, 0xba, 0x18, 0x84, 0x66, 0x1f, 0x8c, 0x51, 0x90, 0x37, 0xfa,
		0xa1, 0x2f, 0x5f, 0x2a, 0x78, 0x87, 0xe6, 0x7c, 0x94, 0x2d, 0x21, 0x82, 0x68, 0x46, 0xcb, 0x09,
		0xa3, 0x7a, 0x14, 0xd1, 0x6a, 0x33, 0x60, 0x1c, 0x3b, 0x5e, 0xc3, 0x15, 0x57, 0xc2, 0x9b, 0x1d,
		0x0f, 0x11, 0x6a, 0xa7, 0x78, 0x6c, 0xdf, 0x2c, 0x59, 0x56, 0x7c, 0x5f, 0x2e, 0x1f, 0x54, 0xcb,
		0xe5, 0xbd, 0xea, 0x7e, 0x75, 0xaf, 0x56, 0xa9, 0x14, 0x0f, 0x28, 0x4d, 0x53, 0x30, 0x3a, 0xc1,
		0x50, 0x04, 0x62, 0x78, 0x78, 0x6b, 0x7c, 0xd8, 0xf1, 0x26, 0xae, 0x8b, 0x95, 0x4f, 0xdf, 0x87,
		0xf3, 0xf3, 0xdd, 0x84, 0xfc, 0x35, 0x1b, 0x3f, 0x4d, 0xc3, 0x39, 0xab, 0x77, 0x85, 0x6a, 0x2d,
		0x50, 0x0c, 0x45, 0xd4, 0x20, 0x88, 0x17, 0xf4, 0x10, 0x80, 0x1d, 0x16, 0x70, 0xa3, 0x16, 0x6a,
		0xd4, 0x6d, 0x70, 0x35, 0x57, 0x56, 0x04, 0x29, 0x54, 0xa0, 0x84, 0x0d, 0x84, 0x28, 0x44, 0x0f,
		0xea, 0xa8, 0xa1, 0x06, 0x30, 0xe4, 0x6f, 0x57, 0x05, 0x5b, 0xd5, 0x08, 0xfc, 0x49, 0x24, 0x02,
		0xd3, 0xf1, 0x46, 0x7e, 0x70, 0xa5, 0x76, 0xbb, 0x26, 0x27, 0x9d, 0x0f, 0xd8, 0xa4, 0x08, 0xc4,
		0xd4, 0xb6, 0xd9, 0x55, 0x9e, 0xc5, 0x44, 0x21, 0x3b, 0x89, 0x54, 0xd6, 0x11, 0x95, 0x6c, 0x22,
		0x72, 0x59, 0x42, 0xe4, 0xb2, 0x7f, 0xa8, 0x65, 0xf5, 0xe4, 0x8b, 0xfc, 0xa9, 0x6e, 0x13, 0x6b,
		0xc4, 0x7a, 0x4c, 0xf9, 0x2e, 0x4d, 0xda, 0x1b, 0xa8, 0x57, 0x87, 0x44, 0x3a, 0xc6, 0x93, 0x49,
		0xcc, 0xa5, 0x94, 0x78, 0x4b, 0x32, 0xb1, 0x96, 0x5a, 0xe2, 0x2c, 0xd9, 0xc4, 0x58, 0xb2, 0x89,
		0xaf, 0x54, 0x13, 0x5b, 0xf3, 0x1d, 0x62, 0xa5, 0xd2, 0x41, 0xdd, 0xa0, 0x34, 0x7f, 0x6d, 0xd9,
		0x53, 0x52, 0xd9, 0xd6, 0xb4, 0x46, 0xac, 0x90, 0xab, 0x68, 0xa1, 0x58, 0xb9, 0x42, 0xba, 0x42,
		0x85, 0x6a, 0x25, 0x0a, 0xf9, 0x8a, 0x13, 0xf2, 0x95, 0x25, 0xd4, 0x2b, 0x48, 0x90, 0x60, 0x44,
		0xd1, 0x01, 0x27, 0x06, 0x2d, 0xc5, 0x39, 0x6d, 0xd7, 0x1c, 0xd8, 0x63, 0xfb, 0xc2, 0x71, 0x9d,
		0xc8, 0x11, 0x21, 0xdd, 0xf9, 0xa8, 0x3f, 0xb1, 0x19, 0xe3, 0x52, 0x39, 0xba, 0x73, 0xca, 0x6e,
		0x9d, 0x85, 0x7b, 0xa7, 0xee, 0xe6, 0xd9, 0xb8, 0x7b, 0x36, 0x6e, 0x9f, 0x8b, 0xfb, 0xa7, 0x45,
		0x03, 0x88, 0xd1, 0x01, 0xb2, 0xb4, 0x20, 0x31, 0x0c, 0xe3, 0x52, 0x75, 0x25, 0x01, 0xe4, 0xc9,
		0x00, 0x07, 0x52, 0xc0, 0x8a, 0x1c, 0x70, 0x21, 0x09, 0xec, 0xc8, 0x02, 0x3b, 0xd2, 0xc0, 0x8d,
		0x3c, 0xd0, 0x24, 0x11, 0x44, 0xc9, 0x04, 0x79, 0x52, 0x91, 0x18, 0x28, 0x6e, 0xc6, 0x22, 0x70,
		0xa6, 0xeb, 0xcf, 0x76, 0xcd, 0x88, 0x51, 0xb3, 0xac, 0x75, 0xc3, 0x89, 0xef, 0xf2, 0x23, 0x31,
		0xb2, 0x27, 0x6e, 0xbc, 0xc9, 0x47, 0xb6, 0x1b, 0xa2, 0xcd, 0x57, 0x3e, 0x88, 0x13, 0x27, 0x02,
		0xc5, 0x92, 0x48, 0x71, 0x23, 0x54, 0x6c, 0x89, 0x15, 0x5b, 0x82, 0xc5, 0x95, 0x68, 0xd1, 0x26,
		0x5c, 0xc4, 0x89, 0x57, 0xf2, 0xd2, 0x19, 0xb6, 0xf9, 0xf2, 0x7d, 0x57, 0xd8, 0x1e, 0xa3, 0x3e,
		0x5f, 0xc5, 0x22, 0x1a, 0x7d, 0xe9, 0xb6, 0x79, 0x8c, 0xb8, 0x2e, 0x69, 0x34, 0x71, 0xcd, 0x40,
		0x84, 0x91, 0x1d, 0x44, 0xb3, 0x33, 0x3e, 0x97, 0x91, 0x42, 0x78, 0xf4, 0x0e, 0x20, 0x15, 0x20,
		0x15, 0x20, 0x15, 0x20, 0x15, 0x20, 0x15, 0x20, 0x15, 0x20, 0x15, 0xc0, 0x76, 0x20, 0x15, 0x20,
		0x15, 0x20, 0x15, 0x52, 0x94, 0x0a, 0xdf, 0x84, 0x3b, 0x16, 0x01, 0x63, 0xa5, 0x30, 0xbf, 0x01,
		0x08, 0x05, 0x08, 0x05, 0x08, 0x05, 0x08, 0x05, 0x08, 0x05, 0x08, 0x05, 0x08, 0x05, 0x70, 0x1d,
		0x08, 0x05, 0x08, 0x05, 0x08, 0x85, 0xd7, 0xbf, 0xdb, 0xb1, 0xef, 0x78, 0x91, 0x19, 0xf9, 0xe6,
		0xec, 0x83, 0x7f, 0x2d, 0x02, 0xd3, 0xb5, 0x3d, 0x3e, 0x42, 0xe1, 0xb1, 0x1b, 0x80, 0x50, 0x80,
		0x50, 0x80, 0x50, 0x80, 0x50, 0x80, 0x50, 0x80, 0x50, 0x80, 0x50, 0x00, 0xd7, 0x81, 0x50, 0x80,
		0x50, 0x80, 0x50, 0x78, 0xfd, 0xbb, 0x0d, 0xa3, 0xc9, 0x85, 0x39, 0xeb, 0x02, 0xcb, 0x47, 0x1c,
		0x2c, 0x1b, 0x0d, 0x41, 0x00, 0x41, 0x00, 0x41, 0x00, 0x41, 0x00, 0x41, 0x00, 0x41, 0x00, 0x41,
		0x00, 0x4e, 0x03, 0x41, 0x00, 0x41, 0x00, 0x41, 0xf0, 0xfa, 0x77, 0x1b, 0x05, 0xf6, 0x68, 0xe4,
		0x0c, 0x4c, 0xe1, 0x5d, 0x3a, 0x9e, 0x10, 0x81, 0xe3, 0x5d, 0xf2, 0x11, 0x06, 0x0f, 0x19, 0x0f,
		0x81, 0x00, 0x81, 0x00, 0x81, 0x00, 0x81, 0x00, 0x81, 0x00, 0x81, 0x00, 0x81, 0x00, 0x8e, 0x03,
		0x81, 0x00, 0x81, 0x40, 0x5e, 0x20, 0xa0, 0xf5, 0xd3, 0x4b, 0xf0, 0x9b, 0xe6, 0x34, 0xef, 0x0d,
		0x3b, 0x89, 0xcf, 0xc7, 0xdc, 0x9c, 0x05, 0x98, 0x8c, 0xf9, 0x2e, 0x3c, 0xde, 0x84, 0xba, 0x40,
		0xb9, 0x1b, 0xe5, 0x0e, 0xe1, 0x91, 0x9b, 0xdd, 0xf8, 0x71, 0x37, 0xef, 0x1f, 0x6c, 0x32, 0x20,
		0xdc, 0x6a, 0x2e, 0x3f, 0xed, 0x8f, 0x4b, 0x0f, 0xdb, 0x3a, 0x8d, 0x1f, 0xf6, 0x1b, 0x60, 0x16,
		0x3f, 0x8b, 0xa8, 0x75, 0xe1, 0x25, 0x8e, 0x9a, 0x7a, 0xa2, 0x25, 0xc5, 0x2e, 0xea, 0x1a, 0xe1,
		0x23, 0x2d, 0x64, 0xa4, 0x83, 0x3f, 0x84, 0xb0, 0xc7, 0xf0, 0xfc, 0xa1, 0x30, 0xed, 0xe1, 0x95,
		0xe3, 0x39, 0x61, 0x14, 0xd8, 0x91, 0x73, 0x2d, 0xcc, 0xc8, 0xbe, 0x24, 0x3c, 0x81, 0xe3, 0x51,
		0x8b, 0x31, 0x7f, 0xe3, 0x39, 0x66, 0x61, 0xfe, 0xc6, 0x16, 0x6b, 0x0f, 0xf3, 0x37, 0xb6, 0xd9,
		0x10, 0x98, 0xbf, 0x91, 0x36, 0x69, 0xc4, 0xfc, 0x0d, 0xfe, 0xcc, 0x1f, 0xf3, 0x37, 0xb6, 0xc3,
		0x64, 0xcc, 0xdf, 0xd0, 0x8f, 0x0c, 0x70, 0x20, 0x05, 0xac, 0xc8, 0x01, 0x17, 0x92, 0xc0, 0x8e,
		0x2c, 0xb0, 0x23, 0x0d, 0xdc, 0xc8, 0x03, 0x4d, 0x12, 0x41, 0x94, 0x4c, 0x90, 0x27, 0x15, 0x89,
		0x81, 0x1c, 0x42, 0x0e, 0x8f, 0x22, 0x3d, 0xfd, 0xe8, 0xc3, 0x63, 0x44, 0x04, 0x89, 0x62, 0xf9,
		0x21, 0x26, 0x2c, 0x09, 0x0a, 0x37, 0xa2, 0xc2, 0x96, 0xb0, 0xb0, 0x25, 0x2e, 0x5c, 0x09, 0x0c,
		0x6d, 0x22, 0x43, 0x9c, 0xd0, 0x24, 0x2f, 0x9d, 0x5f, 0xa2, 0xd8, 0xc4, 0xf1, 0xa2, 0xfd, 0x12,
		0xa3, 0x3c, 0xb1, 0x2a, 0x03, 0x53, 0xbb, 0xb6, 0x77, 0x39, 0x7d, 0xba, 0x67, 0x2c, 0xa0, 0x8a,
		0x87, 0x0b, 0x8b, 0x1f, 0xec, 0xb1, 0xe3, 0xb1, 0xf1, 0xb9, 0xcc, 0xc8, 0xed, 0x86, 0xd9, 0x5f,
		0x6d, 0x77, 0x22, 0x18, 0xda, 0xfd, 0x29, 0xb0, 0x07, 0x91, 0xe3, 0x7b, 0x47, 0xce, 0xa5, 0x13,
		0x4d, 0x65, 0xdb, 0x1e, 0x1b, 0xfb, 0xef, 0x7e, 0x65, 0xb4, 0x15, 0xed, 0x1b, 0x6c, 0x45, 0xc9,
		0x5b, 0xb1, 0x5c, 0xaa, 0x95, 0x6b, 0x07, 0xd5, 0x52, 0xad, 0x82, 0x3d, 0x09, 0x42, 0xcc, 0xcb,
		0xca, 0x3e, 0x84, 0xc5, 0x16, 0x1b, 0xa8, 0xe5, 0x84, 0x51, 0x3d, 0x8a, 0x02, 0x1e, 0xe2, 0xe2,
		0xd8, 0xf1, 0x1a, 0xae, 0x98, 0xaa, 0xdf, 0x90, 0x07, 0xda, 0x4e, 0xbd, 0xd9, 0x92, 0xc5, 0xc5,
		0xf7, 0xe5, 0xf2, 0x41, 0xb5, 0x5c, 0xde, 0xab, 0xee, 0x57, 0xf7, 0x6a, 0x95, 0x4a, 0xf1, 0xa0,
		0xc8, 0x00, 0x71, 0x8d, 0x4e, 0x30, 0x14, 0x81, 0x18, 0x1e, 0xde, 0x1a, 0x1f, 0x76, 0xbc, 0x89,
		0xeb, 0xa2, 0xa0, 0x46, 0x23, 0xcb, 0x50, 0x50, 0xb3, 0x9d, 0x9d, 0x8c, 0x53, 0xc4, 0x1f, 0xcb,
		0x29, 0x45, 0x39, 0x4d, 0xfa, 0xe9, 0xe2, 0x6d, 0x7f, 0x28, 0xea, 0x2b, 0x8f, 0xba, 0x67, 0x5f,
		0xa2, 0x96, 0x86, 0xb1, 0x45, 0xa8, 0xa5, 0xc9, 0x3d, 0x50, 0xa2, 0x92, 0x26, 0x3b, 0x68, 0x44,
		0x19, 0x0d, 0x79, 0xd8, 0x31, 0x42, 0x71, 0x39, 0x95, 0x36, 0x71, 0x1b, 0x54, 0xc7, 0xbb, 0x34,
		0x6d, 0xf7, 0xd2, 0x0f, 0x9c, 0xe8, 0xdb, 0x15, 0xdd, 0x3a, 0x9a, 0xc7, 0x4d, 0x46, 0x21, 0xcd,
		0x73, 0xcc, 0x42, 0x21, 0xcd, 0x16, 0x8b, 0x0f, 0x85, 0x34, 0xdb, 0x6c, 0x08, 0x14, 0xd2, 0xa4,
		0xcd, 0x18, 0x51, 0x48, 0xc3, 0x9f, 0xf6, 0xa3, 0x90, 0x66, 0x4b, 0x42, 0x80, 0x42, 0x1a, 0xed,
		0xc8, 0x00, 0x07, 0x52, 0xc0, 0x8a, 0x1c, 0x70, 0x21, 0x09, 0xec, 0xc8, 0x02, 0x3b, 0xd2, 0xc0,
		0x8d, 0x3c, 0xd0, 0x24, 0x11, 0x44, 0xc9, 0x04, 0x79, 0x52, 0x71, 0x4f, 0x2e, 0x26, 0xe3, 0xb1,
		0x1f, 0x44, 0x62, 0x78, 0x2f, 0xe0, 0x19, 0x55, 0xd2, 0x3c, 0x68, 0x3d, 0x4a, 0x69, 0xf2, 0x40,
		0x49, 0x38, 0x51, 0x13, 0x96, 0x14, 0x85, 0x1b, 0x55, 0x61, 0x4b, 0x59, 0xd8, 0x52, 0x17, 0xae,
		0x14, 0x86, 0x36, 0x95, 0x21, 0x4e, 0x69, 0x92, 0x97, 0xce, 0xaf, 0x94, 0xc6, 0x19, 0x0a, 0x2f,
		0x72, 0xa2, 0xdb, 0x40, 0x8c, 0x38, 0xf5, 0x5d, 0xe6, 0x90, 0xd9, 0xd6, 0x9c, 0x3f, 0xda, 0x43,
		0x3b, 0x64, 0xe4, 0x29, 0x16, 0x0b, 0xe3, 0xb4, 0x6b, 0xd5, 0x5b, 0x9f, 0x3b, 0xdd, 0x66, 0xef,
		0xf7, 0x63, 0x2e, 0xce, 0x22, 0x4e, 0x39, 0x0f, 0xd9, 0xd4, 0x30, 0xed, 0xb0, 0xaa, 0x63, 0x5a,
		0x5d, 0x1d, 0x27, 0x9f, 0x0c, 0x54, 0xa8, 0x60, 0x39, 0x2c, 0x96, 0x43, 0xaf, 0xdb, 0xfc, 0xd8,
		0xb3, 0x78, 0xad, 0x0a, 0x16, 0x96, 0xf6, 0xc1, 0x18, 0xb5, 0x66, 0x8c, 0xa8, 0x91, 0xc8, 0xd8,
		0x62, 0xd4, 0x48, 0x00, 0x0f, 0x48, 0x5b, 0x86, 0x1a, 0x89, 0xed, 0xec, 0x64, 0x9c, 0xfa, 0xfb,
		0x68, 0xbe, 0x20, 0x8a, 0x24, 0xd2, 0xcf, 0x04, 0x3e, 0x9d, 0x3d, 0xec, 0xee, 0xec, 0x59, 0xd7,
		0x17, 0x8f, 0x1a, 0x55, 0x12, 0x7c, 0x2d, 0x42, 0x95, 0x04, 0xa0, 0x12, 0x65, 0x12, 0x19, 0x82,
		0x23, 0xea, 0x24, 0xc8, 0x03, 0xcf, 0x46, 0xd1, 0x41, 0xe8, 0x0c, 0x4d, 0xd7, 0xbe, 0x10, 0xae,
		0x19, 0xcc, 0x3b, 0x3a, 0x31, 0xa9, 0x96, 0x58, 0x37, 0x1c, 0x35, 0x13, 0xcf, 0x31, 0x0b, 0x35,
		0x13, 0x5b, 0x2c, 0x41, 0xd4, 0x4c, 0x6c, 0xb3, 0x21, 0x50, 0x33, 0x91, 0x36, 0x7f, 0x44, 0xcd,
		0x04, 0x7f, 0x11, 0x40, 0xb6, 0x66, 0x62, 0xca, 0xa5, 0xe9, 0x97, 0x4c, 0xc4, 0x56, 0xa2, 0x62,
		0x42, 0x27, 0x2a, 0xc0, 0x81, 0x12, 0xb0, 0xa2, 0x06, 0x5c, 0x28, 0x02, 0x3b, 0xaa, 0xc0, 0x8e,
		0x32, 0x70, 0xa3, 0x0e, 0x34, 0x29, 0x04, 0x51, 0x2a, 0x41, 0x9e, 0x52, 0x2c, 0x53, 0x0b, 0x3e,
		0x05, 0x12, 0x53, 0x63, 0x79, 0xd4, 0x43, 0x14, 0x51, 0x0f, 0x91, 0x1b, 0xe2, 0xc1, 0x92, 0x80,
		0x70, 0x23, 0x22, 0x6c, 0x09, 0x09, 0x5b, 0x62, 0xc2, 0x95, 0xa0, 0xd0, 0x26, 0x2a, 0xc4, 0x09,
		0x0b, 0x1b, 0xe2, 0x92, 0x18, 0x9a, 0x9c, 0x3d, 0xf0, 0x4b, 0xd4, 0xbf, 0x37, 0x9d, 0x09, 0x12,
		0xf0, 0x20, 0x37, 0xec, 0x48, 0x0e, 0x47, 0xb2, 0xc3, 0x9a, 0xf4, 0x70, 0x25, 0x3f, 0xec, 0x49,
		0x10, 0x7b, 0x32, 0xc4, 0x9d, 0x14, 0xf1, 0x20, 0x47, 0x4c, 0x48, 0x12, 0x3b, 0xb2, 0x74, 0x4f,
		0x9a, 0x48, 0x37, 0xe1, 0x7a, 0x9a, 0x38, 0x11, 0xcf, 0xb1, 0xd5, 0x80, 0x3c, 0xb1, 0x25, 0x51,
		0x9c, 0xc9, 0x94, 0x16, 0xa4, 0x8a, 0x3b, 0xb9, 0xd2, 0x86, 0x64, 0x69, 0x43, 0xb6, 0x74, 0x21,
		0x5d, 0xbc, 0xc8, 0x17, 0x33, 0x12, 0xc6, 0x96, 0x8c, 0x25, 0x86, 0x0b, 0x2f, 0x0a, 0x6e, 0xe3,
		0x1c, 0x7b, 0xbe, 0x98, 0xb9, 0x70, 0x5c, 0x4b, 0xf7, 0xc2, 0x14, 0x6b, 0x78, 0xce, 0x6e, 0x64,
		0x4f, 0xdb, 0x74, 0xa0, 0x6f, 0x5a, 0xd1, 0x38, 0x5d, 0xe8, 0x9c, 0x76, 0xb4, 0x4e, 0x3b, 0x7a,
		0xa7, 0x1b, 0xcd, 0xe3, 0x49, 0xf7, 0x98, 0xd2, 0xbe, 0x64, 0xf1, 0xf4, 0x38, 0xf3, 0xa7, 0x15,
		0xaf, 0x11, 0x06, 0x71, 0x61, 0x15, 0x63, 0x12, 0xb5, 0x4c, 0xa4, 0x8a, 0x65, 0xc6, 0xf7, 0xd0,
		0xf0, 0x26, 0xf1, 0xf0, 0x22, 0xa6, 0x5b, 0xf9, 0x0d, 0xc0, 0x27, 0xfb, 0x35, 0x32, 0x72, 0x82,
		0x30, 0x32, 0xaf, 0xe7, 0xb3, 0xd3, 0x99, 0xeb, 0xb7, 0xe5, 0x9b, 0x81, 0x80, 0x83, 0x80, 0x83,
		0x80, 0x83, 0x80, 0x83, 0x80, 0x83, 0x80, 0x83, 0x80, 0x03, 0x87, 0x82, 0x80, 0x7b, 0xa6, 0xd7,
		0x98, 0x38, 0x5e, 0xb4, 0x5f, 0xd2, 0x40, 0xbb, 0x55, 0x19, 0xdf, 0x42, 0x77, 0xde, 0x4a, 0xe5,
		0x8c, 0x35, 0xa4, 0xf2, 0x76, 0xd9, 0x3b, 0xf3, 0x0e, 0xa4, 0xec, 0xb9, 0x87, 0x26, 0xe2, 0x62,
		0xe3, 0x76, 0xbe, 0xce, 0x55, 0xab, 0x2e, 0xf7, 0xf3, 0x29, 0xb0, 0x07, 0x91, 0xe3, 0x7b, 0x47,
		0xce, 0xa5, 0x33, 0x6b, 0x78, 0xcb, 0xfe, 0xbe, 0xee, 0x7e, 0xd5, 0x00, 0x02, 0xec, 0x1b, 0x40,
		0x00, 0x71, 0x08, 0x28, 0x97, 0x6a, 0xe5, 0xda, 0x41, 0xb5, 0x54, 0xab, 0x00, 0x0b, 0x20, 0x48,
		0x60, 0xfd, 0xf2, 0x57, 0x1f, 0xe1, 0x7f, 0x58, 0xcc, 0xdd, 0x33, 0x73, 0x69, 0x0f, 0xfe, 0xa8,
		0xfd, 0x1a, 0xf5, 0xc2, 0x5d, 0x6b, 0x9c, 0xb9, 0xf4, 0x3f, 0x2e, 0xfe, 0x43, 0x81, 0x63, 0xad,
		0xc3, 0x8e, 0x0e, 0xad, 0x74, 0x4f, 0x9d, 0x61, 0x6b, 0xfa, 0x06, 0xe2, 0x00, 0xc2, 0xd2, 0xff,
		0x34, 0xff, 0x31, 0xe5, 0xee, 0xe3, 0xfc, 0x71, 0x15, 0xf5, 0x69, 0x40, 0xfc, 0x9c, 0x21, 0x3d,
		0xa7, 0xba, 0x69, 0xcd, 0xb1, 0x9d, 0x07, 0xaa, 0xd3, 0xc7, 0x48, 0x06, 0xf8, 0xc8, 0xac, 0x14,
		0x96, 0x65, 0x09, 0x2c, 0xfa, 0x86, 0x64, 0x6c, 0x30, 0xfa, 0x86, 0x48, 0x36, 0x1e, 0x7d, 0x43,
		0x14, 0xdd, 0x00, 0xfa, 0x86, 0x80, 0x73, 0xe8, 0xa3, 0xcb, 0xd8, 0xf5, 0x0d, 0x89, 0xb5, 0x8b,
		0x19, 0x3a, 0xff, 0x65, 0xdc, 0x3c, 0x64, 0xe9, 0x1e, 0x78, 0x76, 0x10, 0xd9, 0x43, 0x07, 0x11,
		0xd0, 0x2a, 0x9d, 0xe9, 0x15, 0x77, 0x9a, 0xa5, 0x0d, 0xdd, 0xd2, 0x86, 0x76, 0xe9, 0x42, 0xbf,
		0x78, 0xd1, 0x30, 0x66, 0x74, 0x2c, 0x59, 0x24, 0x6c, 0x33, 0x90, 0xf9, 0x67, 0x1e, 0x33, 0xce,
		0x38, 0x66, 0x9e, 0x69, 0xcc, 0x38, 0xdf, 0x5e, 0x87, 0xcc, 0x62, 0x4d, 0xd2, 0x09, 0x75, 0xc9,
		0x24, 0xd6, 0x29, 0x6b, 0x90, 0x71, 0xe6, 0xb0, 0x16, 0x19, 0xc3, 0xba, 0x6d, 0xed, 0xe2, 0x41,
		0xb5, 0x5a, 0x2d, 0x15, 0x0f, 0xb0, 0xc3, 0x21, 0x07, 0xf2, 0x65, 0x75, 0x1f, 0xd9, 0x5e, 0x79,
		0xf7, 0x50, 0x06, 0xcb, 0xfe, 0x8c, 0xf7, 0x13, 0xd4, 0xf8, 0x35, 0x13, 0x42, 0xd8, 0x5b, 0xb2,
		0xe1, 0x08, 0x7b, 0x2b, 0xbe, 0x09, 0x84, 0xbd, 0x89, 0xdc, 0x08, 0xc2, 0xde, 0x60, 0x34, 0xb9,
		0xd1, 0xdd, 0x3a, 0x84, 0xbd, 0x3d, 0xc7, 0xf7, 0x18, 0x47, 0xbd, 0x8b, 0x35, 0x86, 0xb6, 0xcf,
		0x97, 0x0d, 0xa2, 0xde, 0x8a, 0x16, 0xbd, 0x33, 0x14, 0x5e, 0xe4, 0x44, 0xb7, 0x81, 0x18, 0xe9,
		0xd0, 0x26, 0x94, 0x71, 0xd9, 0xb9, 0xd1, 0x9c, 0xbf, 0x8a, 0x43, 0x3b, 0xd4, 0xa0, 0xcf, 0xda,
		0x62, 0x81, 0x75, 0x4e, 0x4f, 0x3e, 0x59, 0xdd, 0xa6, 0x75, 0xda, 0xb5, 0x4e, 0x9b, 0x47, 0x56,
		0xab, 0x7e, 0xd8, 0x68, 0x59, 0xbd, 0xd6, 0x57, 0xab, 0xf7, 0xe7, 0x49, 0xe3, 0xd4, 0xd0, 0x21,
		0xaa, 0x19, 0xb2, 0x6f, 0x10, 0xb4, 0xa3, 0x45, 0x93, 0xa0, 0x95, 0x75, 0xb7, 0xbe, 0xde, 0x0c,
		0xf4, 0x6d, 0x50, 0xfa, 0xd5, 0x47, 0x7c, 0x1c, 0xfa, 0x21, 0x17, 0x94, 0x4a, 0x78, 0x93, 0x2b,
		0x11, 0xcc, 0x0a, 0x66, 0xd1, 0x79, 0x5d, 0xe9, 0x3d, 0xa0, 0xf3, 0x3a, 0x40, 0x5e, 0x87, 0xe7,
		0x8b, 0xc2, 0x99, 0x34, 0x51, 0x01, 0x0d, 0x0d, 0x08, 0x37, 0x34, 0x60, 0xd6, 0xb0, 0x46, 0xdb,
		0x66, 0x06, 0x7c, 0xfa, 0xd3, 0xa0, 0x93, 0x41, 0x1a, 0xeb, 0x78, 0xe2, 0x7d, 0xf7, 0xfc, 0xbf,
		0x3c, 0x33, 0x72, 0xaf, 0xf9, 0xf5, 0x33, 0x58, 0x36, 0x1e, 0x5d, 0x0d, 0xb2, 0x30, 0x17, 0x5d,
		0x0d, 0x24, 0x2e, 0x67, 0x74, 0x35, 0x90, 0xb9, 0x11, 0xd1, 0xd5, 0x40, 0x35, 0x1f, 0x47, 0x57,
		0x03, 0x70, 0x90, 0xc5, 0x62, 0x60, 0xd7, 0xd5, 0x80, 0x57, 0x0b, 0xa8, 0x0d, 0x5f, 0xc3, 0xb1,
		0x43, 0x28, 0x33, 0xf2, 0xc4, 0x96, 0x44, 0x71, 0x26, 0x53, 0x5a, 0x90, 0x2a, 0xee, 0xe4, 0x4a,
		0x1b, 0x92, 0xa5, 0x0d, 0xd9, 0xd2, 0x85, 0x74, 0xf1, 0x22, 0x5f, 0xcc, 0x48, 0x18, 0x5b, 0x32,
		0x96, 0x18, 0xee, 0x0a, 0xef, 0x32, 0x0e, 0x93, 0x33, 0x9f, 0xa4, 0x3b, 0xbf, 0x0f, 0x0c, 0xd1,
		0x05, 0x5d, 0xcb, 0x17, 0x6d, 0xd3, 0x8a, 0xbe, 0xe9, 0x42, 0xe3, 0xb4, 0xa3, 0x73, 0xda, 0xd1,
		0x3a, 0xdd, 0xe8, 0x1d, 0x4f, 0x9a, 0xc7, 0x94, 0xee, 0x25, 0x8b, 0x47, 0xaf, 0x21, 0xba, 0xc5,
		0x03, 0x0d, 0xd2, 0xf0, 0x0e, 0x30, 0x44, 0x57, 0xf1, 0x17, 0x86, 0xe8, 0x42, 0x5c, 0x64, 0x78,
		0x3b, 0x18, 0xa2, 0x0b, 0x77, 0x2e, 0x03, 0x02, 0x30, 0x44, 0x97, 0x3c, 0x04, 0x1c, 0x54, 0x2a,
		0xfb, 0x98, 0x9f, 0x0b, 0x2d, 0x02, 0xeb, 0x57, 0xbe, 0x30, 0x3f, 0x17, 0x6e, 0xee, 0x31, 0x98,
		0x89, 0x38, 0x2b, 0x56, 0xce, 0xfd, 0xb5, 0x34, 0xf1, 0xc5, 0x88, 0xf5, 0x53, 0xda, 0x07, 0x88,
		0xf5, 0x53, 0xda, 0xd8, 0x88, 0xf5, 0x13, 0xbf, 0x21, 0xc4, 0xfa, 0xc1, 0x9a, 0x5e, 0xbd, 0x78,
		0x10, 0xeb, 0x27, 0xc7, 0xa1, 0x10, 0xeb, 0x57, 0xfd, 0x85, 0x58, 0x3f, 0xc4, 0x45, 0x86, 0xb7,
		0x83, 0x58, 0x3f, 0xdc, 0xb9, 0x0c, 0x08, 0x40, 0xac, 0x9f, 0x3c, 0x04, 0x20, 0xd6, 0x0f, 0x2d,
		0x02, 0xeb, 0x37, 0xbe, 0x10, 0xeb, 0x87, 0x9b, 0x7b, 0x0c, 0x66, 0xae, 0xe7, 0xd0, 0xc9, 0x3c,
		0xd8, 0x3f, 0xbb, 0x0d, 0x44, 0xfb, 0x55, 0x98, 0x8f, 0x68, 0x3f, 0xa1, 0x8d, 0x80, 0x68, 0x3f,
		0xa5, 0x8d, 0x8d, 0x68, 0x3f, 0xf1, 0x1b, 0x42, 0xb4, 0x1f, 0xbc, 0xe9, 0xd5, 0x8b, 0x47, 0x9f,
		0x68, 0xff, 0x85, 0xe3, 0xd9, 0xc1, 0xad, 0x06, 0xd1, 0xfe, 0x1a, 0xa4, 0x0e, 0x2c, 0xe6, 0x0e,
		0x30, 0x5c, 0x7b, 0xaa, 0x26, 0xf6, 0xe7, 0xa1, 0xb7, 0xea, 0x52, 0x97, 0xc4, 0x02, 0xc7, 0xb6,
		0x3f, 0x3b, 0x1a, 0xf7, 0x5b, 0xfd, 0x32, 0x7b, 0x37, 0xcc, 0x5a, 0xaf, 0xf2, 0xc3, 0x56, 0x34,
		0x6b, 0x03, 0xea, 0xe7, 0x0e, 0xed, 0xd1, 0x4f, 0x9b, 0x10, 0xbe, 0xa3, 0xa9, 0x76, 0x1e, 0x2c,
		0x24, 0x8e, 0xe0, 0x46, 0xcb, 0x09, 0xa3, 0x7a, 0x14, 0xf1, 0x68, 0xef, 0x64, 0x1c, 0x3b, 0x5e,
		0xc3, 0x15, 0xd3, 0x5d, 0x16, 0xf2, 0x08, 0xda, 0x1b, 0xc7, 0xf6, 0xcd, 0x92, 0xc5, 0xc5, 0xf7,
		0xe5, 0xf2, 0x41, 0xb5, 0x5c, 0xde, 0xab, 0xee, 0x57, 0xf7, 0x6a, 0x95, 0x4a, 0xf1, 0x80, 0xc3,
		0xa4, 0x42, 0xa3, 0x13, 0x0c, 0x45, 0x20, 0x86, 0x87, 0xb7, 0xc6, 0x87, 0x1d, 0x6f, 0xe2, 0xba,
		0xd8, 0x71, 0xf9, 0xe1, 0x4a, 0x79, 0xe0, 0x48, 0x0c, 0x78, 0x91, 0xa6, 0x7c, 0x88, 0x36, 0x09,
		0xa2, 0x4b, 0x2d, 0x68, 0x5a, 0x46, 0x14, 0x7a, 0xb9, 0x40, 0xae, 0xee, 0x50, 0x4b, 0x18, 0x66,
		0x35, 0x84, 0x57, 0x9a, 0xd0, 0x4a, 0x0f, 0xb8, 0x68, 0x59, 0x44, 0x0c, 0x42, 0xa9, 0x43, 0xa7,
		0xc6, 0x90, 0x49, 0x10, 0x2d, 0xf5, 0x42, 0x49, 0x5a, 0x00, 0x49, 0x07, 0x86, 0x08, 0x41, 0x10,
		0xd1, 0xa1, 0x2a, 0xa4, 0x87, 0xa6, 0x10, 0x1d, 0x8a, 0x42, 0x36, 0xd7, 0x96, 0x72, 0x0e, 0x2d,
		0x8b, 0xdc, 0x58, 0xea, 0x39, 0xaf, 0x6c, 0x72, 0x59, 0xd9, 0xe4, 0xa8, 0x72, 0xc9, 0x3d, 0x05,
		0xb5, 0xff, 0xd9, 0x4b, 0xa4, 0x3a, 0xd4, 0x83, 0x76, 0x13, 0x2f, 0x0e, 0x4d, 0xba, 0x88, 0x97,
		0xe5, 0x90, 0x2f, 0xbb, 0xe1, 0x50, 0x56, 0xc3, 0xaa, 0x6c, 0x86, 0x4b, 0x59, 0x0c, 0xbb, 0xb2,
		0x17, 0x76, 0x65, 0x2d, 0xdc, 0xca, 0x56, 0x70, 0xd0, 0xf2, 0x92, 0x97, 0x4b, 0xbe, 0xac, 0x64,
		0x69, 0x52, 0xbc, 0xe3, 0x7b, 0x94, 0x11, 0x73, 0xa1, 0xe2, 0x6b, 0x84, 0x6d, 0x9c, 0xbf, 0x6e,
		0xda, 0x3d, 0x9e, 0x18, 0xa4, 0x58, 0x2c, 0x16, 0xa5, 0x33, 0x14, 0x5e, 0xe4, 0x44, 0xb7, 0x81,
		0x18, 0x71, 0x48, 0x49, 0x58, 0x2c, 0x51, 0x0e, 0x29, 0x4c, 0xcd, 0xf9, 0xa3, 0x3d, 0xb4, 0x43,
		0x3e, 0x85, 0x6f, 0xc9, 0xc2, 0xe8, 0x36, 0xad, 0xd6, 0x69, 0xdd, 0xea, 0xb5, 0xbe, 0x5a, 0xbd,
		0x3f, 0x4f, 0x1a, 0xa7, 0x4c, 0x12, 0x79, 0x67, 0xdd, 0x6d, 0x42, 0x56, 0x6d, 0xe0, 0x98, 0x8e,
		0xef, 0xee, 0x36, 0xad, 0x4f, 0x5f, 0xda, 0x1f, 0x7b, 0xcd, 0x4e, 0xbb, 0xde, 0xb2, 0x3e, 0xd6,
		0x4f, 0xea, 0x87, 0xcd, 0x56, 0xb3, 0xd7, 0x6c, 0x9c, 0x32, 0x1a, 0xa0, 0xff, 0x2b, 0x56, 0x49,
		0xe6, 0xab, 0xe4, 0xb4, 0x6b, 0x9d, 0x36, 0x8f, 0xac, 0x56, 0xfd, 0xb0, 0xd1, 0xb2, 0xba, 0xf5,
		0xf6, 0xe7, 0x06, 0x16, 0x08, 0x16, 0xc8, 0xea, 0x02, 0xa9, 0xb7, 0x3e, 0x77, 0xba, 0xcd, 0xde,
		0xef, 0xc7, 0x58, 0x1a, 0x58, 0x1a, 0x4b, 0x4b, 0xa3, 0xdd, 0x39, 0x6a, 0x58, 0xf5, 0xa3, 0xe3,
		0x66, 0xdb, 0xea, 0xd5, 0x3f, 0x63, 0x71, 0x60, 0x71, 0x2c, 0x2d, 0x8e, 0x66, 0xfb, 0x53, 0xa7,
		0x7b, 0x5c, 0xe7, 0xcd, 0x40, 0x58, 0x58, 0xda, 0x47, 0x4d, 0x96, 0xce, 0x70, 0xc0, 0x28, 0x60,
		0x21, 0xbc, 0xc9, 0x95, 0x08, 0x66, 0xe9, 0x81, 0x8c, 0x02, 0x16, 0x65, 0x06, 0xb6, 0x36, 0xbc,
		0xc9, 0x95, 0xf1, 0x61, 0xe7, 0xc7, 0x1d, 0x2a, 0x24, 0x34, 0x02, 0x49, 0xa4, 0x3f, 0xb3, 0x82,
		0x66, 0xa4, 0x3f, 0x67, 0x98, 0xfe, 0x4c, 0xb4, 0xf3, 0x0c, 0xc7, 0x24, 0x67, 0x7a, 0x9d, 0x62,
		0x90, 0xce, 0xfc, 0xd0, 0xd2, 0x5a, 0xee, 0xc5, 0x41, 0x36, 0xa9, 0x99, 0x6e, 0xc3, 0x10, 0xa4,
		0x36, 0xbf, 0xd0, 0x30, 0xa4, 0x36, 0x6f, 0x69, 0x24, 0x52, 0x9b, 0x53, 0x32, 0x14, 0xa9, 0xcd,
		0xa0, 0xed, 0xf2, 0x5e, 0x22, 0xd9, 0xd4, 0x66, 0x9a, 0xf5, 0x4c, 0x1b, 0x98, 0x4c, 0xb9, 0x2b,
		0x24, 0x51, 0x12, 0x40, 0x9e, 0x0c, 0x70, 0x20, 0x05, 0xac, 0xc8, 0x01, 0x17, 0x92, 0xc0, 0x8e,
		0x2c, 0xb0, 0x23, 0x0d, 0xdc, 0xc8, 0x03, 0x4d, 0x12, 0x41, 0x94, 0x4c, 0x90, 0x27, 0x15, 0x89,
		0x81, 0xae, 0xf0, 0x2e, 0xe3, 0x40, 0x20, 0x71, 0x1c, 0x5a, 0x80, 0xfb, 0xdc, 0x5e, 0xe2, 0x7b,
		0x9a, 0xc7, 0x88, 0x23, 0x36, 0xa3, 0x8c, 0x38, 0x8d, 0x2c, 0x62, 0x39, 0x9a, 0x88, 0xdb, 0x08,
		0x22, 0xb6, 0xa3, 0x86, 0xd8, 0x8e, 0x14, 0xe2, 0x3a, 0x3a, 0x08, 0x59, 0x25, 0xdb, 0xbc, 0x74,
		0x36, 0x23, 0x7f, 0xf8, 0x0d, 0xf2, 0x67, 0x34, 0xb0, 0x9f, 0xd9, 0x60, 0x7e, 0x46, 0xb3, 0x04,
		0x38, 0x0e, 0xda, 0x67, 0x3a, 0xbf, 0x93, 0xeb, 0xe0, 0x7c, 0xce, 0x93, 0xb1, 0x19, 0xe5, 0x50,
		0xb3, 0x1c, 0x78, 0xcf, 0x7d, 0x2b, 0x32, 0x1c, 0x60, 0xcf, 0x7a, 0x3b, 0x62, 0x7a, 0x48, 0x2a,
		0x5f, 0x7d, 0xa4, 0xd7, 0xea, 0xe6, 0x0e, 0x68, 0xf7, 0x8f, 0xda, 0x50, 0x39, 0x84, 0xfb, 0x48,
		0x31, 0xf3, 0x4d, 0x88, 0x81, 0x66, 0xb9, 0x4e, 0x11, 0x03, 0xcd, 0x72, 0x83, 0x21, 0x06, 0x2a,
		0xd9, 0x70, 0xc4, 0x40, 0xf3, 0x27, 0x12, 0x11, 0x03, 0xcd, 0x9e, 0x23, 0x20, 0x06, 0x9a, 0xf6,
		0x17, 0x62, 0xa0, 0x20, 0xb7, 0x0f, 0x98, 0x8d, 0x18, 0x28, 0xdc, 0xdb, 0xcf, 0xb6, 0x22, 0x62,
		0xa0, 0xd2, 0xb7, 0x22, 0x62, 0xa0, 0xe0, 0xc2, 0x0c, 0xad, 0x44, 0x0c, 0x54, 0x3b, 0x77, 0x60,
		0x5c, 0xcf, 0x21, 0x89, 0x49, 0x10, 0x74, 0x66, 0x2e, 0xa2, 0xa0, 0x69, 0x98, 0x89, 0x28, 0x68,
		0x86, 0x0b, 0x15, 0x51, 0xd0, 0x2c, 0x37, 0x18, 0xa2, 0xa0, 0x92, 0x0d, 0x47, 0x14, 0x34, 0x7f,
		0x32, 0x91, 0x61, 0x14, 0xf4, 0xc2, 0xf1, 0xec, 0xe0, 0x96, 0x51, 0x14, 0xb4, 0x06, 0x4a, 0xad,
		0x91, 0x65, 0x98, 0x6b, 0xbe, 0x9d, 0x9d, 0x8c, 0xbb, 0x54, 0x2d, 0x35, 0xc3, 0x29, 0x50, 0xae,
		0x8a, 0xdf, 0xe1, 0xd9, 0xb9, 0xea, 0xcb, 0xec, 0xf1, 0x12, 0x6d, 0x62, 0x45, 0x17, 0x95, 0xd0,
		0xfe, 0x83, 0x31, 0x2e, 0x6a, 0x82, 0x87, 0xe8, 0xdd, 0x97, 0x2e, 0x02, 0xa2, 0x81, 0x1f, 0x65,
		0x4b, 0x88, 0x60, 0x9c, 0xd1, 0x72, 0xc2, 0xa8, 0x1e, 0x45, 0xb4, 0x5a, 0x11, 0x18, 0xc7, 0x8e,
		0xd7, 0x70, 0xc5, 0x95, 0xf0, 0x66, 0x47, 0x48, 0x84, 0x5a, 0x2e, 0x1e, 0xdb, 0x37, 0x4b, 0x96,
		0x15, 0xdf, 0x97, 0xcb, 0x07, 0xd5, 0x72, 0x79, 0xaf, 0xba, 0x5f, 0xdd, 0xab, 0x55, 0x2a, 0xc5,
		0x03, 0x4a, 0xd3, 0xab, 0x8c, 0x4e, 0x30, 0x14, 0x81, 0x18, 0x1e, 0xde, 0x1a, 0x1f, 0x76, 0xbc,
		0x89, 0xeb, 0x62, 0xe5, 0xd3, 0xf7, 0xea, 0x8c, 0xbd, 0x39, 0x21, 0x0f, 0xce, 0xcf, 0x73, 0xd3,
		0x70, 0xd7, 0xea, 0x9d, 0xa3, 0x5a, 0x0b, 0x14, 0x83, 0x13, 0x35, 0x50, 0x62, 0x0a, 0x46, 0x04,
		0x80, 0x88, 0x17, 0x00, 0xa9, 0x05, 0x1f, 0x75, 0x5b, 0x5e, 0xcd, 0x95, 0x15, 0x81, 0x0c, 0x15,
		0x70, 0xe1, 0x07, 0x2a, 0x0a, 0xf1, 0x84, 0x0d, 0x8e, 0xa8, 0x81, 0x10, 0xf9, 0x1b, 0x58, 0xc1,
		0xe6, 0x55, 0xdc, 0xe6, 0x97, 0x44, 0x1b, 0x5f, 0xc5, 0x6d, 0x7a, 0x95, 0x67, 0x41, 0x51, 0xc8,
		0x6e, 0x22, 0x95, 0xb5, 0x44, 0x25, 0x1b, 0x89, 0x5c, 0x96, 0x11, 0xb9, 0xec, 0x21, 0x6a, 0x59,
		0x41, 0xf9, 0x22, 0x7d, 0xaa, 0xdb, 0xcc, 0x1a, 0xe1, 0xc0, 0x27, 0x90, 0x1f, 0x74, 0xef, 0xc4,
		0x62, 0x73, 0x14, 0xef, 0x08, 0x1a, 0xa9, 0xbf, 0x64, 0x52, 0x7b, 0x29, 0xa5, 0xee, 0x92, 0x4c,
		0xcd, 0xa5, 0x96, 0x7a, 0x4b, 0x36, 0xb5, 0x96, 0x6c, 0xea, 0x2c, 0xd5, 0xd4, 0xd8, 0x7c, 0x87,
		0x5b, 0xc9, 0xa4, 0xae, 0x12, 0x1d, 0x81, 0x4b, 0x69, 0xc4, 0x2d, 0x91, 0x11, 0xb6, 0x0a, 0x83,
		0x95, 0x0a, 0xc5, 0x16, 0x89, 0x1e, 0x58, 0x94, 0x7a, 0x5c, 0x81, 0xc2, 0x81, 0xc2, 0x81, 0xc2,
		0x81, 0xc2, 0x81, 0xc2, 0x81, 0xc2, 0xad, 0xa1, 0x8e, 0x33, 0x14, 0x5e, 0xe4, 0x44, 0xb7, 0x81,
		0x18, 0x51, 0xa2, 0x70, 0x04, 0x12, 0xd3, 0x8c, 0xe6, 0xfc, 0xd1, 0x1c, 0xda, 0x21, 0x21, 0x24,
		0x5c, 0xbc, 0xb8, 0xce, 0xe9, 0xc9, 0x27, 0xab, 0x73, 0x52, 0xff, 0xff, 0x7f, 0x69, 0x58, 0xad,
		0xd3, 0xba, 0xd5, 0xfb, 0xf3, 0xa4, 0x41, 0x05, 0x14, 0xe3, 0x9e, 0x20, 0x21, 0xa9, 0x26, 0x53,
		0x44, 0xe7, 0x4d, 0x4f, 0xdf, 0xe2, 0xd7, 0x92, 0xd5, 0xf8, 0xa3, 0xd7, 0x68, 0x1f, 0x35, 0x8e,
		0xac, 0x56, 0xb3, 0xfd, 0x2f, 0x03, 0xe3, 0xc3, 0xd9, 0xbc, 0xbf, 0xcf, 0xdd, 0xfa, 0xc7, 0x78,
		0xff, 0xe1, 0xa5, 0xf1, 0xdd, 0x74, 0x27, 0xdd, 0xc6, 0xa7, 0xe6, 0x1f, 0x78, 0x83, 0x7c, 0xde,
		0x60, 0xaf, 0x5b, 0xff, 0xf4, 0xa9, 0xf9, 0xd1, 0x6a, 0xb4, 0x3f, 0x37, 0xdb, 0x8d, 0x46, 0xb7,
		0xd9, 0xfe, 0x8c, 0xd7, 0xc7, 0xe7, 0xf5, 0x75, 0x3b, 0x5f, 0x7a, 0x8d, 0xae, 0xd5, 0x6c, 0x7f,
		0xea, 0x74, 0x8f, 0xeb, 0xbd, 0x66, 0xa7, 0x6d, 0xa0, 0xe2, 0x66, 0xe5, 0xab, 0x9f, 0x77, 0xa1,
		0x86, 0x03, 0x77, 0x39, 0x51, 0x02, 0x64, 0x59, 0x3e, 0x27, 0xcb, 0x52, 0x75, 0xf5, 0x3b, 0xd5,
		0xc4, 0x4a, 0x85, 0x75, 0xeb, 0xf9, 0x48, 0xa6, 0x8c, 0x02, 0x7b, 0x34, 0x72, 0x06, 0xa6, 0xf0,
		0x2e, 0x1d, 0x4f, 0x88, 0xc0, 0xf1, 0x2e, 0xd5, 0xa7, 0x56, 0x3e, 0x64, 0x14, 0x12, 0x2d, 0x95,
		0x18, 0x80, 0x44, 0xcb, 0x35, 0x63, 0x90, 0x68, 0xf9, 0x88, 0x41, 0x48, 0xb4, 0x04, 0xef, 0xbb,
		0x7f, 0xf8, 0xca, 0x13, 0x2d, 0xe3, 0xca, 0x37, 0x3a, 0x67, 0xf4, 0xea, 0xeb, 0xf0, 0x14, 0xbb,
		0x32, 0x32, 0x2e, 0x8d, 0x92, 0x6b, 0x23, 0xe9, 0xe2, 0xa8, 0xb9, 0x3a, 0xb2, 0x2e, 0x8f, 0xac,
		0xeb, 0xa3, 0xea, 0x02, 0x89, 0x84, 0x7e, 0x14, 0xe3, 0x8e, 0x6a, 0xd7, 0xb8, 0xec, 0x22, 0xe9,
		0x1d, 0x3b, 0xd3, 0xe9, 0x9c, 0x41, 0xc4, 0x61, 0x92, 0x73, 0x9c, 0x14, 0x1d, 0x28, 0x69, 0x47,
		0x4a, 0xd5, 0xa1, 0x92, 0x77, 0xac, 0xe4, 0x1d, 0x2c, 0x75, 0x47, 0x4b, 0xc3, 0xe1, 0x12, 0x71,
		0xbc, 0xe4, 0x1c, 0x70, 0x62, 0x90, 0xeb, 0x78, 0xdf, 0xe9, 0xa1, 0xc2, 0x02, 0x4a, 0x63, 0xeb,
		0x88, 0xed, 0x37, 0x5a, 0xae, 0x99, 0xac, 0x8b, 0xa6, 0xec, 0xaa, 0x59, 0xb8, 0x6c, 0xea, 0xae,
		0x9b, 0x8d, 0x0b, 0x67, 0xe3, 0xca, 0xb9, 0xb8, 0x74, 0x5a, 0xae, 0x9d, 0x98, 0x8b, 0x27, 0xeb,
		0xea, 0x13, 0xc3, 0xc2, 0xc9, 0x85, 0x49, 0x22, 0x44, 0xfd, 0x24, 0x2c, 0x27, 0x96, 0x12, 0xdd,
		0xa7, 0x34, 0xa9, 0x00, 0x79, 0x4a, 0xc0, 0x81, 0x1a, 0xb0, 0xa2, 0x08, 0x5c, 0xa8, 0x02, 0x3b,
		0xca, 0xc0, 0x8e, 0x3a, 0x70, 0xa3, 0x10, 0x34, 0xa9, 0x04, 0x51, 0x4a, 0x41, 0x9e, 0x5a, 0xac,
		0x53, 0x0c, 0x3e, 0x73, 0x4a, 0x17, 0x06, 0xf3, 0x98, 0x54, 0x5a, 0xc4, 0xa4, 0xd2, 0xdc, 0x10,
		0x10, 0x96, 0x44, 0x84, 0x1b, 0x21, 0x61, 0x4b, 0x4c, 0xd8, 0x12, 0x14, 0xae, 0x44, 0x85, 0x36,
		0x61, 0x21, 0x4e, 0x5c, 0xd8, 0x10, 0x98, 0xc4, 0x50, 0x7b, 0x78, 0xe5, 0x78, 0x4e, 0x18, 0x05,
		0x76, 0xe4, 0x5c, 0x0b, 0xf3, 0x32, 0xf0, 0x27, 0xe3, 0x90, 0x0f, 0x9c, 0x2d, 0x7c, 0xc6, 0xc3,
		0xb7, 0xc1, 0x04, 0x21, 0x78, 0x90, 0x1e, 0x76, 0xe4, 0x87, 0x23, 0x09, 0x62, 0x4d, 0x86, 0xb8,
		0x92, 0x22, 0xf6, 0xe4, 0x88, 0x3d, 0x49, 0xe2, 0x4e, 0x96, 0x78, 0x90, 0x26, 0x26, 0xe4, 0x89,
		0x1d, 0x89, 0x5a, 0x25, 0x53, 0x33, 0xf2, 0xc1, 0x0f, 0xfc, 0x56, 0xa8, 0xd4, 0xfc, 0x26, 0x98,
		0xa1, 0x07, 0x2f, 0x22, 0xc5, 0x96, 0x50, 0x71, 0x26, 0x56, 0x5a, 0x10, 0x2c, 0xee, 0x44, 0x4b,
		0x1b, 0xc2, 0xa5, 0x0d, 0xf1, 0xd2, 0x85, 0x80, 0xf1, 0x22, 0x62, 0xcc, 0x08, 0x19, 0x5b, 0x62,
		0x96, 0x18, 0x7e, 0xe1, 0x44, 0xa6, 0xe3, 0x0d, 0xc5, 0x0d, 0x5f, 0xc8, 0x5c, 0xf8, 0xad, 0xfb,
		0x5b, 0x61, 0x8a, 0x34, 0x34, 0xda, 0x5a, 0xe7, 0x8e, 0xb4, 0xe9, 0x40, 0xde, 0xb4, 0x22, 0x71,
		0xba, 0x90, 0x39, 0xed, 0x48, 0x9d, 0x76, 0xe4, 0x4e, 0x37, 0x92, 0xc7, 0x93, 0xec, 0x31, 0x25,
		0x7d, 0xc9, 0xe2, 0x21, 0xd3, 0x06, 0x7d, 0x6b, 0xaf, 0xe1, 0x0a, 0x7b, 0x44, 0xa3, 0x75, 0xfa,
		0xb6, 0x24, 0xaa, 0x58, 0x65, 0x7c, 0x0f, 0x27, 0xf3, 0xc6, 0x81, 0xef, 0xde, 0xcd, 0x5a, 0xf5,
		0x15, 0xee, 0xa9, 0xed, 0x1b, 0xc0, 0x11, 0xa0, 0xe8, 0xe1, 0x55, 0xa3, 0x76, 0x52, 0x71, 0x6a,
		0x18, 0xa4, 0xba, 0x39, 0x65, 0x2a, 0xe8, 0x03, 0x09, 0x07, 0x09, 0x07, 0x09, 0x07, 0x09, 0x07,
		0x09, 0x07, 0x09, 0x07, 0x09, 0x47, 0x7f, 0xf1, 0x70, 0x8d, 0xdf, 0x27, 0x37, 0xc0, 0x3f, 0x8e,
		0xbf, 0xe1, 0xff, 0xb8, 0xc7, 0xf3, 0xd7, 0x49, 0xe1, 0x1e, 0xf3, 0xdb, 0xe0, 0x4e, 0x0e, 0x75,
		0x22, 0x89, 0x5a, 0x92, 0x45, 0xdd, 0x48, 0xa3, 0xb6, 0xe4, 0x51, 0x5b, 0x12, 0xa9, 0x2b, 0x99,
		0xe4, 0x4d, 0x2a, 0x99, 0x93, 0xcb, 0x64, 0x51, 0xb1, 0x3f, 0x27, 0xd8, 0xf0, 0x3a, 0x13, 0xc7,
		0x8b, 0xde, 0xeb, 0xe0, 0x71, 0xe6, 0x14, 0xad, 0xa2, 0xc1, 0xad, 0x74, 0x6d, 0xef, 0x52, 0x90,
		0x1a, 0x56, 0xba, 0xcd, 0x97, 0x1e, 0x0c, 0x20, 0x7e, 0x31, 0xc7, 0x8e, 0xa7, 0x0d, 0xa5, 0xd1,
		0x4c, 0xdb, 0x6c, 0xdc, 0x56, 0x3c, 0xf2, 0x57, 0xc3, 0xfb, 0xfa, 0x14, 0xd8, 0x83, 0xc8, 0xf1,
		0xbd, 0x23, 0xe7, 0xd2, 0x89, 0xc2, 0xe9, 0x0d, 0x6a, 0x73, 0x7f, 0x77, 0xbf, 0x6a, 0x04, 0x15,
		0xf6, 0x0d, 0xa0, 0x82, 0x19, 0x54, 0xec, 0x17, 0x81, 0x15, 0xd0, 0x41, 0xb8, 0x8b, 0x97, 0x7c,
		0xf5, 0xdf, 0xe0, 0xf9, 0xc3, 0x57, 0xbe, 0x0c, 0x96, 0x42, 0x11, 0xe9, 0x73, 0xc6, 0x31, 0xbd,
		0x19, 0xe6, 0x51, 0x8d, 0x23, 0x31, 0xb2, 0x27, 0x6e, 0x1c, 0x29, 0x1b, 0xd9, 0x6e, 0x28, 0x70,
		0x5a, 0x43, 0xe2, 0x36, 0x70, 0x5a, 0x43, 0x78, 0xdb, 0xe3, 0xb4, 0x86, 0x32, 0x00, 0xe0, 0xb4,
		0x86, 0xd9, 0x8d, 0xe1, 0xb4, 0x06, 0x1c, 0x33, 0xf5, 0x45, 0xa5, 0xdf, 0x69, 0xcd, 0x85, 0xef,
		0xbb, 0xc2, 0xf6, 0x34, 0x3a, 0xaf, 0x29, 0x16, 0x21, 0x20, 0x61, 0xb9, 0xee, 0x90, 0x64, 0xd4,
		0x3d, 0xcf, 0x8f, 0xec, 0xc8, 0xf1, 0x79, 0x1f, 0x20, 0x19, 0xe1, 0xe0, 0x9b, 0xb8, 0xb2, 0xc7,
		0xf3, 0xea, 0xa6, 0x82, 0x3f, 0x16, 0xde, 0x20, 0x96, 0x29, 0xa6, 0x27, 0xa2, 0xbf, 0xfc, 0xe0,
		0xbb, 0xe9, 0x78, 0x61, 0x64, 0x7b, 0x03, 0x51, 0x58, 0xff, 0x41, 0xb8, 0xf1, 0x93, 0xc2, 0x38,
		0xf0, 0x23, 0x7f, 0xe0, 0xbb, 0x61, 0xf2, 0xa9, 0x30, 0xf3, 0xfc, 0x05, 0x3b, 0x10, 0x76, 0x18,
		0xff, 0x59, 0x70, 0xc3, 0xe1, 0x45, 0xc1, 0x0d, 0x6d, 0x33, 0xba, 0x1d, 0x8b, 0x30, 0xf9, 0x34,
		0xfd, 0x10, 0x7f, 0x57, 0xf0, 0xc7, 0xf6, 0x7f, 0x26, 0xc2, 0x9c, 0x7e, 0x8c, 0x02, 0x7b, 0x34,
		0x72, 0x06, 0xa6, 0xf0, 0x2e, 0x1d, 0x4f, 0x88, 0xc0, 0xf1, 0x2e, 0x0b, 0x91, 0x7b, 0x1d, 0x4e,
		0xff, 0x28, 0xb8, 0x8e, 0xf7, 0xbd, 0xb0, 0x98, 0x4e, 0xb2, 0xf8, 0x50, 0x78, 0xb0, 0xcb, 0x66,
		0x61, 0xa9, 0x61, 0x54, 0x81, 0x73, 0x39, 0xcb, 0xec, 0xa5, 0x45, 0xc1, 0x64, 0x10, 0x79, 0x73,
		0x1f, 0xd2, 0x49, 0xde, 0x59, 0x7b, 0xf6, 0x3e, 0x9a, 0xf3, 0xd7, 0x61, 0xad, 0x7d, 0x1f, 0xae,
		0xff, 0xc0, 0x3a, 0x59, 0xbc, 0xaf, 0xe4, 0x93, 0xd5, 0x89, 0xdf, 0x97, 0x55, 0x9f, 0xbe, 0xaf,
		0xf8, 0x4f, 0xab, 0x15, 0x0e, 0x2f, 0xac, 0x56, 0x68, 0x4f, 0xbd, 0x6f, 0xb8, 0xf8, 0x30, 0xfd,
		0x3b, 0xfe, 0xc6, 0xea, 0xc4, 0x6f, 0x6b, 0xfa, 0xa9, 0x37, 0x7b, 0x59, 0x8d, 0xfb, 0x77, 0x65,
		0xf5, 0xdc, 0xeb, 0x70, 0xfa, 0x87, 0xd5, 0x72, 0xbc, 0xef, 0xd6, 0xe9, 0xe4, 0x22, 0xfe, 0xc1,
		0xec, 0x6f, 0xab, 0xbe, 0xf2, 0xa6, 0x3e, 0xc7, 0x2f, 0x6a, 0xf6, 0xc3, 0xf8, 0xb3, 0x75, 0x1a,
		0xbf, 0x27, 0x94, 0xd7, 0xc1, 0x62, 0xee, 0x6e, 0x63, 0x2a, 0x60, 0x39, 0xe7, 0x4f, 0x1b, 0x2d,
		0x27, 0x8c, 0xea, 0x51, 0xc4, 0xb4, 0xa3, 0xce, 0xb1, 0xe3, 0x35, 0x5c, 0x31, 0x95, 0xa3, 0x21,
		0xcf, 0xe8, 0x9b, 0x71, 0x6c, 0xdf, 0x2c, 0xdd, 0x41, 0xf1, 0x7d, 0xb9, 0x7c, 0x50, 0x2d, 0x97,
		0xf7, 0xaa, 0xfb, 0xd5, 0xbd, 0x5a, 0xa5, 0x52, 0x3c, 0x28, 0x32, 0x4c, 0x93, 0x32, 0x3a, 0xc1,
		0x50, 0x04, 0x62, 0x78, 0x38, 0xdd, 0x1a, 0xde, 0xc4, 0x75, 0x81, 0x40, 0x20, 0xac, 0x20, 0xaa,
		0x6c, 0x3b, 0x9b, 0xe6, 0x88, 0x9a, 0xf2, 0x22, 0xa5, 0x77, 0x68, 0x4d, 0x9d, 0x47, 0xe8, 0xe7,
		0x0a, 0xf9, 0x79, 0x81, 0x7a, 0x4e, 0xc3, 0x12, 0x34, 0x86, 0x75, 0x1e, 0x58, 0x4e, 0x1f, 0x19,
		0x19, 0xa0, 0x22, 0xb3, 0x7e, 0x3c, 0x2c, 0xfb, 0xef, 0x60, 0x50, 0x50, 0xc6, 0x06, 0x63, 0x50,
		0x90, 0x64, 0xe3, 0x31, 0x28, 0x48, 0xd1, 0x0d, 0x60, 0x50, 0x10, 0x38, 0x87, 0x3e, 0x6a, 0x8c,
		0xdd, 0xa0, 0xa0, 0xa9, 0x94, 0x31, 0x9d, 0x21, 0xdf, 0x21, 0x41, 0x8b, 0x1b, 0xe0, 0x39, 0x20,
		0x68, 0x0f, 0x03, 0x82, 0x40, 0xa8, 0x74, 0x26, 0x56, 0xdc, 0x09, 0x96, 0x36, 0x44, 0x4b, 0x1b,
		0xc2, 0xa5, 0x0b, 0xf1, 0xe2, 0x45, 0xc0, 0x98, 0x11, 0xb1, 0x64, 0x91, 0xb0, 0xcd, 0x26, 0x4e,
		0x50, 0x7f, 0xe8, 0x47, 0x91, 0x18, 0x9a, 0xff, 0x99, 0xd8, 0x43, 0x8e, 0xb8, 0xbf, 0x88, 0x14,
		0xbd, 0x67, 0x68, 0xfb, 0x89, 0x1d, 0x45, 0x22, 0xf0, 0xd8, 0x36, 0x75, 0x31, 0xde, 0xbe, 0x3d,
		0xdb, 0x33, 0x6b, 0xfd, 0xbf, 0xcf, 0x8a, 0x66, 0xad, 0x3f, 0xfb, 0x58, 0x8c, 0xff, 0x9a, 0x7d,
		0x2e, 0x9d, 0xed, 0x99, 0xe5, 0xc5, 0xe7, 0xca, 0xd9, 0x9e, 0x59, 0xe9, 0xef, 0x9e, 0x9f, 0xbf,
		0xdb, 0xfd, 0xb1, 0x7f, 0xf7, 0xf2, 0x7f, 0xc8, 0x0f, 0x79, 0xfb, 0x38, 0xe0, 0xcd, 0xbb, 0x8f,
		0x98, 0xc9, 0xc7, 0x88, 0xa3, 0x93, 0x58, 0x55, 0xc0, 0xf1, 0x2d, 0x40, 0x03, 0x43, 0x03, 0x43,
		0x03, 0x43, 0x03, 0x43, 0x03, 0x43, 0x03, 0x43, 0x03, 0x83, 0xdf, 0x68, 0xa3, 0x81, 0x85, 0x37,
		0xb9, 0x12, 0xc1, 0x2c, 0xcb, 0x8d, 0xb1, 0x06, 0x2e, 0x33, 0xb4, 0xbd, 0xe1, 0x4d, 0xae, 0xa6,
		0x8b, 0xe7, 0x0e, 0x62, 0x09, 0x62, 0xc9, 0x1f, 0xd8, 0xae, 0xe9, 0x8c, 0x4d, 0x7b, 0x38, 0x0c,
		0x44, 0x18, 0x32, 0xd6, 0x4c, 0xeb, 0x77, 0x02, 0xe9, 0x04, 0xe9, 0x04, 0xe9, 0x04, 0xe9, 0x04,
		0xe9, 0x04, 0xe9, 0x04, 0xe9, 0x04, 0xb6, 0xa3, 0x8d, 0x74, 0x72, 0xc6, 0xd7, 0xe5, 0x05, 0xcb,
		0x31, 0x3d, 0xdf, 0xfc, 0xaf, 0xef, 0x09, 0x9c, 0x23, 0x4a, 0x66, 0x0f, 0x38, 0x47, 0x7c, 0xfe,
		0x3f, 0x7c, 0xfb, 0x8f, 0xb3, 0xf3, 0xf3, 0xf1, 0x8f, 0xf6, 0xdd, 0xf4, 0xcf, 0xd6, 0x5d, 0xff,
		0x9f, 0xbb, 0xbf, 0x71, 0xf5, 0x95, 0xd3, 0x1b, 0x3b, 0x3f, 0x7f, 0xd7, 0xff, 0x05, 0x67, 0xa3,
		0x70, 0x2b, 0xcb, 0x0b, 0x03, 0x9d, 0x36, 0x14, 0xdf, 0x01, 0x3a, 0x6d, 0x80, 0xc6, 0xea, 0x8f,
		0x35, 0xc6, 0x95, 0x7d, 0xe3, 0x5c, 0x4d, 0xae, 0xcc, 0x0b, 0xdb, 0x1b, 0xfe, 0xe5, 0x0c, 0xe3,
		0x5a, 0x6b, 0xa6, 0x11, 0xbb, 0xcd, 0x5b, 0x41, 0xc8, 0x4e, 0x86, 0xd9, 0x08, 0xd9, 0x29, 0x5c,
		0xf4, 0x08, 0xd9, 0xa9, 0xdc, 0xb0, 0x08, 0xd9, 0x11, 0xbb, 0x11, 0x84, 0xec, 0xc0, 0x77, 0x9e,
		0x5c, 0x24, 0x1a, 0x84, 0xec, 0x84, 0x10, 0x23, 0xd7, 0xb7, 0xa3, 0xfd, 0x12, 0xe3, 0x48, 0x5d,
		0x8d, 0xa1, 0xe9, 0x2d, 0xe1, 0x5d, 0xc6, 0x24, 0x99, 0x67, 0x9c, 0x8e, 0x71, 0x8b, 0x6a, 0x1d,
		0x86, 0xb4, 0xea, 0x32, 0xc2, 0x68, 0x31, 0x59, 0xb1, 0xcc, 0xfc, 0x3e, 0x34, 0x1a, 0xa4, 0xc8,
		0x79, 0x70, 0x9c, 0x0e, 0x43, 0x55, 0xb1, 0xb5, 0xb1, 0xb5, 0xa1, 0x06, 0x58, 0x5b, 0x8d, 0x6a,
		0xbf, 0xdc, 0xbb, 0xa6, 0x24, 0x88, 0x1c, 0x88, 0x50, 0x04, 0xd7, 0xf6, 0x85, 0x2b, 0x74, 0x0a,
		0x8d, 0x3f, 0x78, 0x57, 0x88, 0x92, 0xcb, 0x30, 0x1b, 0x51, 0x72, 0x85, 0xeb, 0x1f, 0x51, 0x72,
		0x95, 0x1b, 0x16, 0x51, 0x72, 0x62, 0x37, 0x82, 0x28, 0x39, 0x58, 0xd0, 0x93, 0x8b, 0x04, 0x51,
		0x72, 0x1a, 0x44, 0x07, 0x51, 0x72, 0xe9, 0x5f, 0x88, 0x92, 0x83, 0xe2, 0xa7, 0x70, 0x1b, 0x08,
		0xa5, 0xc1, 0x09, 0xa7, 0xb9, 0xb5, 0x11, 0x25, 0xc7, 0xd6, 0xc6, 0xd6, 0xd6, 0x43, 0x0d, 0xf0,
		0xb5, 0x1a, 0x51, 0xf2, 0xdc, 0xbb, 0x26, 0xe3, 0x4a, 0x44, 0x81, 0x33, 0x60, 0x1c, 0x0f, 0x9f,
		0xd9, 0x8f, 0xc8, 0xb7, 0x0c, 0xb3, 0x11, 0xf9, 0x56, 0xb8, 0xd2, 0xff, 0x3f, 0xf6, 0xde, 0xfc,
		0xb7, 0x6d, 0x24, 0xdb, 0x1e, 0xff, 0x3d, 0x7f, 0x85, 0x21, 0xbc, 0x07, 0x58, 0x33, 0xa1, 0xb5,
		0x58, 0x92, 0x17, 0xe0, 0xa1, 0xe1, 0xc4, 0x4a, 0x8f, 0x3f, 0xed, 0xed, 0x6b, 0x3b, 0x99, 0x6e,
		0x38, 0x1a, 0x81, 0x96, 0x4a, 0x0e, 0x5f, 0x28, 0x4a, 0x43, 0x52, 0x99, 0xf8, 0xc5, 0xfa, 0xdf,
		0xbf, 0x10, 0x25, 0xd1, 0x5a, 0x13, 0x8b, 0xac, 0x5b, 0x75, 0x8b, 0x3a, 0x41, 0x23, 0x6d, 0x3b,
		0x16, 0xd7, 0x5b, 0xe7, 0x9e, 0x7b, 0xea, 0x2e, 0x50, 0xbe, 0x75, 0x2e, 0x58, 0x28, 0xdf, 0xcc,
		0x6e, 0x04, 0xca, 0x37, 0x98, 0xcd, 0x2f, 0x8d, 0xc4, 0x7c, 0xe5, 0x7b, 0xe0, 0x78, 0x66, 0x8b,
		0xde, 0x07, 0x06, 0x5e, 0xfa, 0x8d, 0xed, 0x3d, 0x0a, 0x68, 0xde, 0xea, 0x1f, 0x3c, 0x34, 0x6f,
		0x3e, 0xb7, 0x31, 0x15, 0xc6, 0x8a, 0x10, 0xc6, 0xe0, 0x7e, 0x25, 0x2c, 0x6d, 0x68, 0xde, 0xec,
		0x96, 0x76, 0xa5, 0x7c, 0x54, 0x39, 0xaa, 0x1d, 0x94, 0x8f, 0xaa, 0x58, 0xe3, 0x08, 0x08, 0xb6,
		0xeb, 0xaa, 0x21, 0x7e, 0x6f, 0xbd, 0x8f, 0xca, 0xf9, 0xa2, 0xdb, 0x0b, 0x45, 0x26, 0x9a, 0x1c,
		0x2f, 0xdf, 0x0a, 0x24, 0x71, 0x15, 0x97, 0x0d, 0x49, 0x5c, 0xa3, 0xd1, 0x43, 0x12, 0xd7, 0xb9,
		0x60, 0x21, 0x89, 0x33, 0xbb, 0x11, 0x48, 0xe2, 0xe0, 0x3b, 0xbf, 0x34, 0x12, 0x74, 0x39, 0x66,
		0xc6, 0x78, 0xd0, 0xe5, 0x58, 0xc7, 0x0d, 0xa0, 0xcb, 0x71, 0xa2, 0xc7, 0x86, 0x2e, 0xc7, 0x70,
		0x2b, 0x2b, 0x0d, 0x03, 0x5d, 0x8e, 0x35, 0xdf, 0x01, 0xba, 0x1c, 0x83, 0xc6, 0x66, 0x1f, 0x6b,
		0x72, 0x66, 0x8f, 0x6f, 0xc6, 0xe4, 0x66, 0x65, 0x97, 0x0d, 0x61, 0x4e, 0xa3, 0x9d, 0x43, 0x98,
		0xd3, 0xb9, 0x60, 0x21, 0xcc, 0x31, 0xbb, 0x11, 0x08, 0x73, 0x60, 0x35, 0xbf, 0x34, 0x92, 0x0c,
		0xe4, 0xaa, 0x7a, 0x86, 0xcf, 0x6c, 0x36, 0xb1, 0x41, 0xc3, 0xc4, 0x6c, 0x90, 0xaa, 0xaa, 0xc9,
		0xe8, 0x9d, 0xb6, 0xf0, 0x42, 0x27, 0x7c, 0xf2, 0x45, 0x27, 0x67, 0x70, 0x7a, 0xde, 0x74, 0x09,
		0x18, 0x9c, 0x09, 0x96, 0x3b, 0x9b, 0xbc, 0x8a, 0x77, 0x76, 0x20, 0xcc, 0xcf, 0x35, 0x9c, 0x1a,
		0xd8, 0xd5, 0xed, 0xf5, 0x87, 0xe6, 0x5d, 0xbd, 0x79, 0x7e, 0x76, 0xf9, 0x47, 0xf3, 0xee, 0xfc,
		0x53, 0xf3, 0xee, 0xaf, 0xeb, 0x7a, 0x2e, 0x0b, 0x19, 0x88, 0x81, 0xb1, 0xb8, 0x95, 0x0d, 0x0c,
		0x5b, 0x69, 0x6e, 0x53, 0x4b, 0xbb, 0x38, 0xf9, 0xf3, 0xec, 0xe2, 0xe3, 0x45, 0xf3, 0xdd, 0xc9,
		0xe5, 0xe9, 0x3f, 0xcf, 0x4e, 0xef, 0xfe, 0x91, 0x33, 0xfe, 0x3e, 0x87, 0x6f, 0x61, 0x6c, 0x3c,
		0x8d, 0x2d, 0x82, 0x34, 0xd8, 0x17, 0xec, 0x8b, 0xc8, 0xbe, 0xce, 0x4e, 0x61, 0x5d, 0xb0, 0x2e,
		0x6a, 0x57, 0x79, 0x53, 0xbf, 0xad, 0xdf, 0x7c, 0x3a, 0x79, 0x77, 0x5e, 0x87, 0xd7, 0x84, 0xdd,
		0xd1, 0xdb, 0xdd, 0xc9, 0xe9, 0xc5, 0xd9, 0x65, 0xf3, 0xf7, 0x9b, 0xab, 0x8f, 0xd7, 0x30, 0x33,
		0x98, 0x19, 0x95, 0x99, 0x9d, 0x5f, 0xbd, 0x3f, 0x39, 0x6f, 0x9e, 0xc1, 0xc6, 0x60, 0x63, 0x64,
		0x36, 0xf6, 0xf1, 0x72, 0xec, 0x3c, 0xeb, 0xa7, 0x70, 0x9d, 0xb0, 0x37, 0x05, 0x94, 0xad, 0x7e,
		0x77, 0x73, 0xf6, 0x1e, 0x16, 0x06, 0x0b, 0xa3, 0xb2, 0xb0, 0x9b, 0xfa, 0xc5, 0xd5, 0x5d, 0x3d,
		0x1b, 0x6e, 0xd3, 0xe8, 0x3b, 0x68, 0xa0, 0x14, 0x1c, 0x90, 0x94, 0x65, 0x18, 0x8a, 0xa1, 0x47,
		0x78, 0x83, 0xae, 0xf0, 0xed, 0xd0, 0xcc, 0x5d, 0xf8, 0xf8, 0x76, 0xa6, 0x5b, 0x91, 0x06, 0x77,
		0x64, 0xce, 0xd5, 0xbd, 0x41, 0x37, 0x77, 0xbc, 0xf3, 0x03, 0xdd, 0x1c, 0x00, 0xf2, 0x26, 0x3f,
		0x5f, 0x93, 0x52, 0xc3, 0x07, 0xde, 0x57, 0xaf, 0xf7, 0x1f, 0xcf, 0x32, 0x3b, 0x45, 0x7c, 0xee,
		0x2e, 0x90, 0x2a, 0xae, 0xe2, 0xb2, 0x91, 0x2a, 0xae, 0xd1, 0xde, 0x91, 0x2a, 0xae, 0x73, 0xc1,
		0x22, 0x55, 0x9c, 0xd9, 0x8d, 0x20, 0x55, 0x1c, 0x2c, 0xe7, 0x97, 0x46, 0x92, 0x8d, 0xb6, 0xc6,
		0xa5, 0x9a, 0xc1, 0xb9, 0xe2, 0x35, 0xb4, 0x35, 0x56, 0xfc, 0x07, 0x6d, 0x8d, 0x41, 0xee, 0x25,
		0xdc, 0x06, 0xda, 0x1a, 0xc3, 0xfd, 0xca, 0x5c, 0xda, 0x68, 0x6b, 0xcc, 0x6e, 0x69, 0xd7, 0xaa,
		0xd5, 0x7d, 0x74, 0x34, 0x46, 0x2c, 0xb0, 0x65, 0x57, 0x0d, 0x0d, 0x7c, 0xeb, 0xdd, 0x53, 0xac,
		0x1e, 0x7f, 0x9b, 0x40, 0xa1, 0xe1, 0x22, 0xf8, 0xf8, 0x36, 0xa0, 0x82, 0xab, 0xb8, 0x6c, 0xa8,
		0xe0, 0x1a, 0x0d, 0x1e, 0x2a, 0xb8, 0xce, 0x05, 0x0b, 0x15, 0x9c, 0xd9, 0x8d, 0x40, 0x05, 0x07,
		0xcf, 0xf9, 0xa5, 0x91, 0x98, 0xaf, 0x82, 0x3f, 0x38, 0x9e, 0xed, 0x3f, 0x19, 0xac, 0x82, 0x1f,
		0x21, 0xe4, 0xd8, 0xe2, 0x2b, 0x35, 0x04, 0x30, 0x72, 0x27, 0x9e, 0xd7, 0x0b, 0xc7, 0x69, 0x91,
		0x26, 0xc1, 0x45, 0x2e, 0x68, 0x7d, 0x11, 0x5d, 0xbb, 0x6f, 0x87, 0x5f, 0x46, 0x60, 0x51, 0xe8,
		0xf5, 0x85, 0xd7, 0x8a, 0x48, 0xba, 0xe5, 0x89, 0xf0, 0x3f, 0x3d, 0xff, 0xab, 0xe5, 0x78, 0x41,
		0x68, 0x7b, 0x2d, 0x51, 0x58, 0xfc, 0x41, 0xb0, 0xf4, 0x93, 0x42, 0xdf, 0xef, 0x85, 0xbd, 0x56,
		0xcf, 0x0d, 0xe2, 0xaf, 0x0a, 0x63, 0xbf, 0x5a, 0xb0, 0x7d, 0x61, 0x07, 0xd1, 0xdf, 0x05, 0x37,
		0x68, 0x3f, 0x14, 0xdc, 0xc0, 0x8e, 0xd2, 0x8f, 0x82, 0xf8, 0xab, 0xd1, 0x17, 0xd1, 0x77, 0x85,
		0x5e, 0xdf, 0xfe, 0xf7, 0x40, 0x58, 0xa3, 0x2f, 0x43, 0xdf, 0xee, 0x74, 0x9c, 0x96, 0x25, 0xbc,
		0x47, 0xc7, 0x13, 0xc2, 0x77, 0xbc, 0xc7, 0x42, 0xe8, 0x7e, 0x0b, 0x46, 0x7f, 0x15, 0x5c, 0xc7,
		0xfb, 0x5a, 0x08, 0x06, 0x0f, 0x56, 0xf4, 0x93, 0xc9, 0x17, 0x85, 0x20, 0xb4, 0x43, 0x93, 0xe2,
		0xb9, 0x5c, 0x10, 0xfa, 0x83, 0x56, 0xe8, 0x4d, 0x5b, 0xb1, 0xc4, 0x6f, 0xe0, 0x72, 0xfc, 0x74,
		0xcf, 0x26, 0x0f, 0xb7, 0xb9, 0xf0, 0x7d, 0xb0, 0xf8, 0x83, 0xe6, 0xf5, 0xf4, 0xe9, 0xc7, 0x5f,
		0x35, 0xaf, 0xa2, 0xa7, 0xdf, 0x3c, 0x19, 0x3d, 0xfd, 0xe8, 0xef, 0xe6, 0x79, 0xd0, 0x7e, 0x68,
		0x9e, 0x07, 0xf6, 0xc8, 0xb3, 0x05, 0xd3, 0x2f, 0x46, 0xff, 0x8f, 0xbe, 0x69, 0x5e, 0x45, 0xcf,
		0x7e, 0xf4, 0xd5, 0xdd, 0xf8, 0xd1, 0xd7, 0x5f, 0x9e, 0x7c, 0xf3, 0xce, 0xfd, 0x16, 0x8c, 0xfe,
		0x6a, 0x9e, 0x3b, 0xde, 0xd7, 0xe6, 0xed, 0xe0, 0x21, 0xfa, 0xc1, 0xf8, 0xff, 0xcd, 0xdb, 0xe8,
		0xb9, 0xbf, 0x01, 0xf4, 0x6d, 0x09, 0xec, 0xc5, 0x02, 0x4a, 0x30, 0x78, 0x08, 0xdd, 0x6f, 0xc6,
		0xc0, 0xde, 0x92, 0x00, 0x34, 0xb9, 0x7e, 0x43, 0x1c, 0xcd, 0x34, 0x73, 0xdd, 0x90, 0xcb, 0x35,
		0x4d, 0xf1, 0x31, 0x51, 0xe9, 0x31, 0x5a, 0xe1, 0x31, 0x55, 0xd9, 0x31, 0x5e, 0xd1, 0x31, 0x5e,
		0xc9, 0x31, 0x5d, 0xc1, 0x41, 0x00, 0x26, 0xd3, 0x18, 0x4e, 0x1d, 0xdf, 0xb0, 0xc8, 0x2b, 0xe2,
		0xcb, 0xc6, 0x6e, 0x9f, 0x99, 0x16, 0x66, 0x19, 0x48, 0x9e, 0x8c, 0x25, 0x51, 0x26, 0x93, 0xa9,
		0x4c, 0x90, 0x2a, 0xd3, 0xc9, 0x55, 0x66, 0x48, 0x56, 0x66, 0xc8, 0x56, 0x56, 0x48, 0x97, 0x59,
		0xe4, 0xcb, 0x30, 0x12, 0x66, 0x2c, 0x19, 0x8b, 0x2f, 0xdc, 0x15, 0xde, 0x63, 0x24, 0x85, 0x1b,
		0x8a, 0x97, 0x53, 0xa7, 0x35, 0xb9, 0x0f, 0x43, 0x31, 0xc6, 0xec, 0x5c, 0x61, 0x63, 0xe9, 0x5a,
		0x16, 0x68, 0x5b, 0xa6, 0xe8, 0x5b, 0x56, 0x68, 0x5c, 0xe6, 0xe8, 0x5c, 0xe6, 0x68, 0x5d, 0xd6,
		0xe8, 0x9d, 0x99, 0x34, 0xcf, 0x50, 0xba, 0x17, 0x1b, 0x8f, 0xb1, 0xd9, 0x52, 0x4b, 0x5e, 0xc3,
		0xd8, 0xda, 0xe1, 0x45, 0x0e, 0x55, 0x33, 0xf8, 0x16, 0xcc, 0xae, 0x25, 0x9e, 0xfe, 0x31, 0xbf,
		0xf7, 0x64, 0x26, 0x6a, 0x8b, 0x33, 0x12, 0x5c, 0x2c, 0xdd, 0x4e, 0x46, 0x6a, 0x8d, 0xe3, 0xfb,
		0xc9, 0x50, 0x51, 0xa2, 0xe1, 0xee, 0x7c, 0x1e, 0x02, 0x32, 0x50, 0x83, 0x9c, 0x75, 0x08, 0xc8,
		0x40, 0x4d, 0x72, 0xa6, 0x61, 0xe0, 0x0d, 0xae, 0x5e, 0xc7, 0x9f, 0x06, 0x6a, 0xc3, 0xe1, 0xe6,
		0xd6, 0xc0, 0x4c, 0x68, 0x72, 0xc4, 0x1a, 0x47, 0xab, 0x06, 0xf6, 0xf1, 0xcc, 0x88, 0x2f, 0x86,
		0xd6, 0xcf, 0x69, 0x1d, 0x40, 0xeb, 0xe7, 0xb4, 0xb0, 0xa1, 0xf5, 0x33, 0xbf, 0x21, 0x68, 0xfd,
		0x60, 0x4d, 0x89, 0x8d, 0x07, 0x5a, 0x3f, 0x3b, 0x0e, 0x05, 0xad, 0x5f, 0xf7, 0x1f, 0x68, 0xfd,
		0x08, 0x2e, 0x08, 0x6f, 0x07, 0x5a, 0x3f, 0xdc, 0xb9, 0x0a, 0x08, 0x80, 0xd6, 0xcf, 0x1e, 0x02,
		0xa0, 0xf5, 0x23, 0x16, 0xc1, 0xd5, 0x2f, 0xfd, 0x81, 0xd6, 0x0f, 0x37, 0xb7, 0x0e, 0x66, 0xcc,
		0xec, 0x57, 0xba, 0x14, 0xae, 0x9a, 0xd8, 0xaf, 0x34, 0x23, 0xde, 0x18, 0x6a, 0x3f, 0xa7, 0x85,
		0x00, 0xb5, 0x9f, 0xd3, 0xc2, 0x86, 0xda, 0xcf, 0xfc, 0x86, 0xa0, 0xf6, 0x83, 0x37, 0x25, 0x36,
		0x9e, 0xec, 0xa8, 0xfd, 0xc6, 0xf6, 0x43, 0x5d, 0xe4, 0x50, 0x47, 0x08, 0x75, 0x70, 0xc5, 0xa6,
		0x03, 0x8c, 0xa9, 0x7d, 0x53, 0xe3, 0xeb, 0xcf, 0x5e, 0xff, 0xd4, 0xf9, 0xb6, 0x88, 0x05, 0x13,
		0xfb, 0xfc, 0xec, 0x64, 0xa8, 0xad, 0xea, 0xc7, 0xf1, 0xeb, 0xb8, 0x8d, 0xde, 0x86, 0x49, 0x4d,
		0x56, 0xcd, 0xc3, 0x4f, 0x34, 0x64, 0x03, 0xb2, 0x67, 0x1f, 0xd1, 0xd1, 0x1a, 0x5b, 0x2f, 0x86,
		0xa3, 0x45, 0xf6, 0xd6, 0xe0, 0x60, 0x6e, 0xe0, 0xf9, 0x22, 0x10, 0xfe, 0x37, 0xd1, 0xb6, 0x1e,
		0x6c, 0xaf, 0xfd, 0x1f, 0xa7, 0x1d, 0x7e, 0x09, 0x4c, 0xec, 0x94, 0xbd, 0xea, 0x36, 0xd0, 0x30,
		0x9b, 0xe2, 0x72, 0xd1, 0x30, 0x5b, 0xa1, 0x61, 0xa3, 0x61, 0xb6, 0xca, 0x85, 0x88, 0x86, 0xd9,
		0xba, 0x29, 0x39, 0x1a, 0x66, 0x83, 0x97, 0x4c, 0x8d, 0xc1, 0xb8, 0x86, 0xd9, 0xab, 0x58, 0x88,
		0xc9, 0xe3, 0x67, 0x57, 0xdc, 0x0d, 0xda, 0x69, 0x83, 0x62, 0x65, 0x8b, 0x6a, 0x65, 0x82, 0x72,
		0x99, 0x4e, 0xbd, 0x32, 0x43, 0xc1, 0x32, 0x43, 0xc5, 0xb2, 0x42, 0xc9, 0xcc, 0xa2, 0x66, 0x86,
		0x51, 0x34, 0x63, 0xa9, 0x5a, 0x7c, 0xe1, 0x7d, 0xdf, 0xe9, 0xf9, 0x4e, 0xf8, 0x64, 0x7e, 0xd6,
		0x6d, 0x7c, 0x27, 0x48, 0xbc, 0x05, 0x65, 0xdb, 0x2e, 0xea, 0x96, 0x29, 0x0a, 0x97, 0x15, 0x2a,
		0x97, 0x39, 0x4a, 0x97, 0x39, 0x6a, 0x97, 0x35, 0x8a, 0x67, 0x26, 0xd5, 0x33, 0x94, 0xf2, 0xc5,
		0xc6, 0x93, 0x9d, 0xc4, 0x5b, 0x57, 0xd8, 0x1d, 0x5f, 0x74, 0x32, 0x90, 0x79, 0x5b, 0x3a, 0x30,
		0xf8, 0x1e, 0xae, 0x27, 0x89, 0x2d, 0x7b, 0x7b, 0xe3, 0xd4, 0xbe, 0x42, 0xcc, 0x6c, 0x91, 0x4f,
		0x0c, 0x24, 0x5a, 0x63, 0x34, 0x66, 0xce, 0xaa, 0x5c, 0x82, 0x20, 0x53, 0x73, 0x59, 0x77, 0xcc,
		0x15, 0xdb, 0x11, 0xc1, 0x21, 0x82, 0x43, 0x04, 0x87, 0x08, 0x0e, 0x11, 0x1c, 0x38, 0xd3, 0x76,
		0x46, 0x70, 0xa6, 0x8a, 0xf7, 0xf1, 0x0d, 0x18, 0x2f, 0xe2, 0x2f, 0xb9, 0x3f, 0xc3, 0xc5, 0xfc,
		0x45, 0x4a, 0x68, 0x78, 0x6f, 0x2b, 0xe3, 0xa9, 0x61, 0x96, 0x28, 0x62, 0x26, 0xa9, 0x62, 0xd6,
		0x28, 0x63, 0x66, 0xa9, 0x63, 0x66, 0x29, 0x64, 0x56, 0xa9, 0xa4, 0xd9, 0x94, 0xd2, 0x70, 0x6a,
		0x19, 0x1b, 0x95, 0xf1, 0x9b, 0x04, 0x4b, 0x5e, 0x67, 0xe0, 0x78, 0xe1, 0x61, 0x16, 0x3c, 0xce,
		0x84, 0xa2, 0x65, 0xa0, 0x55, 0x67, 0x46, 0x5a, 0x74, 0x4f, 0xff, 0x64, 0x83, 0x01, 0xec, 0x64,
		0xad, 0x65, 0x77, 0xc6, 0x62, 0x9b, 0xa5, 0xdb, 0xca, 0x58, 0x0b, 0xef, 0xf8, 0xbe, 0x32, 0xd8,
		0xc3, 0x37, 0x23, 0xec, 0x60, 0x1e, 0x2a, 0x32, 0xd4, 0xda, 0x7b, 0x5b, 0xa0, 0xe2, 0x00, 0x50,
		0x81, 0x30, 0x08, 0x77, 0xb1, 0xc9, 0x9f, 0x06, 0xda, 0xaf, 0xc3, 0x55, 0x6e, 0x08, 0x4b, 0x99,
		0x28, 0x2f, 0x5d, 0x1f, 0x50, 0x9b, 0x5f, 0x6e, 0x9a, 0x51, 0xbf, 0x8f, 0xed, 0x0f, 0xce, 0xeb,
		0x06, 0xdb, 0x1f, 0x9c, 0x01, 0x00, 0xdb, 0x1f, 0x86, 0xdd, 0x18, 0xb6, 0x3f, 0xc0, 0xda, 0xa4,
		0x1b, 0x55, 0xf6, 0xb6, 0x3f, 0x1c, 0x21, 0x44, 0xc7, 0xed, 0xd9, 0xe1, 0x7e, 0x39, 0x43, 0x9b,
		0x20, 0x47, 0x19, 0xb8, 0x95, 0x73, 0xe1, 0x3d, 0x46, 0x71, 0x01, 0x76, 0x41, 0x98, 0xbd, 0x19,
		0xec, 0x82, 0x98, 0x73, 0x5b, 0x53, 0x69, 0xb3, 0x02, 0x69, 0x13, 0x24, 0x41, 0x03, 0x54, 0x60,
		0x17, 0x04, 0x50, 0x01, 0xa8, 0x40, 0x34, 0x94, 0xed, 0xbb, 0xc0, 0x2e, 0x08, 0xae, 0x3c, 0xf3,
		0x0e, 0xde, 0xf4, 0x09, 0x42, 0xf1, 0x7d, 0x64, 0x71, 0xee, 0xc4, 0x8a, 0xb6, 0xf1, 0x2b, 0x7f,
		0x5a, 0x30, 0xb9, 0x32, 0x7b, 0x27, 0x53, 0x93, 0x2a, 0xa6, 0x2f, 0xe7, 0x5d, 0xfc, 0xc6, 0x56,
		0xfd, 0xd0, 0xc4, 0x41, 0x44, 0xe6, 0xc2, 0x33, 0xba, 0x2b, 0x92, 0x06, 0x4e, 0xe2, 0xc9, 0xe0,
		0xa2, 0xc0, 0xdc, 0xb9, 0x13, 0x84, 0x27, 0x61, 0x68, 0x68, 0x87, 0xc8, 0x0b, 0xc7, 0xab, 0xbb,
		0xa2, 0x2b, 0xbc, 0x71, 0x0c, 0x64, 0x60, 0x6f, 0x94, 0x0b, 0xfb, 0xfb, 0xcc, 0x1d, 0x94, 0x0e,
		0x2b, 0x95, 0xda, 0x41, 0xa5, 0x52, 0x3c, 0xd8, 0x3f, 0x28, 0x1e, 0x55, 0xab, 0xa5, 0x5a, 0xc9,
		0xc0, 0xdc, 0xff, 0xdc, 0x95, 0xdf, 0x16, 0xbe, 0x68, 0xbf, 0x1b, 0xad, 0x0c, 0x6f, 0xe0, 0xba,
		0x00, 0x20, 0x30, 0x58, 0x30, 0xd7, 0x6c, 0xe4, 0x50, 0x6d, 0x1b, 0x57, 0xc5, 0xb8, 0xcc, 0x6d,
		0xbe, 0x52, 0x8c, 0xcb, 0x04, 0xf8, 0x4b, 0x00, 0x7f, 0x4c, 0xcd, 0x64, 0x81, 0xef, 0x18, 0x9e,
		0xb9, 0x0d, 0x57, 0xc8, 0x1c, 0xb3, 0xcd, 0x0a, 0xb9, 0xcd, 0x0b, 0xb1, 0x33, 0x11, 0x52, 0x9b,
		0x15, 0x42, 0x73, 0x5f, 0x71, 0x86, 0xb1, 0xa3, 0xec, 0xb1, 0x22, 0x03, 0xf8, 0x4f, 0x46, 0x78,
		0x0f, 0x6f, 0x8a, 0xc3, 0x97, 0x38, 0xf0, 0xbc, 0x32, 0xa6, 0xc0, 0x6a, 0x0a, 0xa0, 0x66, 0x07,
		0x48, 0x19, 0x03, 0xa8, 0xe9, 0xc0, 0xc9, 0x13, 0x31, 0xf9, 0xe1, 0x11, 0xaf, 0x2b, 0x62, 0x86,
		0x8c, 0xdc, 0x11, 0xd1, 0x78, 0x24, 0x64, 0x08, 0x80, 0xa6, 0x02, 0x1f, 0x2f, 0xc0, 0xe3, 0x03,
		0x2b, 0x8c, 0x20, 0x25, 0xe7, 0xf5, 0xda, 0xc2, 0xb2, 0xc3, 0xd0, 0x77, 0x1e, 0x06, 0x0c, 0x67,
		0xa7, 0xc4, 0xa5, 0x86, 0x0b, 0xd7, 0xc9, 0x0c, 0x94, 0x79, 0x0e, 0x3d, 0x61, 0xdb, 0xb2, 0x81,
		0x73, 0x0b, 0x06, 0x23, 0x5a, 0x2a, 0x70, 0x6f, 0x91, 0x60, 0x4c, 0xcb, 0x03, 0x63, 0x5a, 0x18,
		0x98, 0xd2, 0x92, 0x00, 0xe4, 0xfd, 0x67, 0x2f, 0x91, 0xeb, 0x90, 0x8d, 0x5c, 0x1c, 0xfe, 0xb3,
		0x45, 0x94, 0x78, 0x38, 0x1a, 0x6f, 0xa1, 0x82, 0xf9, 0xfc, 0x33, 0xf6, 0x5d, 0x9c, 0x4c, 0xe8,
		0xce, 0x64, 0x54, 0xd7, 0x25, 0x53, 0xba, 0x29, 0x19, 0xd7, 0x25, 0xc9, 0xb8, 0xee, 0x47, 0xa6,
		0x75, 0x35, 0xc2, 0x4e, 0x49, 0x16, 0xa8, 0xc5, 0x22, 0xc5, 0xe0, 0x0f, 0x44, 0x0b, 0x4c, 0x83,
		0x3b, 0x0c, 0x99, 0x31, 0x70, 0xd5, 0x98, 0xf6, 0x91, 0x26, 0xb5, 0x87, 0x34, 0xb2, 0xfd, 0xa3,
		0x69, 0xed, 0x1d, 0x8d, 0x6d, 0xdf, 0x68, 0x6c, 0x7b, 0x46, 0x53, 0xdb, 0x2f, 0x22, 0x5b, 0x35,
		0xcb, 0x04, 0xe6, 0x85, 0xc8, 0x18, 0x35, 0x65, 0xde, 0xc8, 0xa9, 0xf2, 0x86, 0x4d, 0x91, 0x37,
		0xae, 0x37, 0xb6, 0x89, 0x3d, 0xb0, 0x8d, 0xee, 0x75, 0x6d, 0x6a, 0x4f, 0x6b, 0xe3, 0x7b, 0x57,
		0x1b, 0xdf, 0xa3, 0xda, 0xf4, 0x5e, 0xd4, 0x28, 0xbf, 0xdc, 0x46, 0x92, 0x14, 0x5f, 0xb0, 0xdb,
		0x6b, 0xd9, 0xae, 0xe5, 0xf4, 0xbf, 0x55, 0x2c, 0xbb, 0xdd, 0xf6, 0x45, 0x10, 0x88, 0xc0, 0x3c,
		0x14, 0x9c, 0xba, 0x9e, 0x95, 0x77, 0x63, 0x5a, 0x1f, 0x19, 0x23, 0x1b, 0x70, 0x1a, 0x3b, 0x7e,
		0xc4, 0xe4, 0x71, 0x23, 0x99, 0x18, 0x2f, 0x62, 0xfa, 0x38, 0x91, 0xcc, 0x8c, 0x0f, 0xc9, 0xcc,
		0xb8, 0x90, 0xac, 0x8c, 0x07, 0x41, 0xbf, 0x36, 0x4a, 0x23, 0x31, 0x76, 0xdc, 0xc7, 0xcb, 0x78,
		0x8f, 0x11, 0xcf, 0x31, 0x16, 0x72, 0x62, 0x0d, 0xe9, 0xd0, 0xc0, 0x6b, 0xbf, 0xb6, 0xc3, 0x50,
		0xf8, 0x9e, 0xb1, 0x03, 0x3c, 0x72, 0xbb, 0xbb, 0xf7, 0x45, 0xeb, 0xa8, 0xf1, 0x7c, 0x5f, 0xb2,
		0x8e, 0x1a, 0xe3, 0x2f, 0x4b, 0xd1, 0xff, 0xc6, 0x5f, 0x97, 0xef, 0x8b, 0x56, 0x65, 0xfa, 0x75,
		0xf5, 0xbe, 0x68, 0x55, 0x1b, 0xf9, 0xcf, 0x9f, 0xf7, 0xf2, 0x3f, 0xf6, 0x87, 0x9b, 0x7f, 0xb0,
		0x30, 0x39, 0x59, 0xfe, 0x79, 0xf7, 0xbe, 0x64, 0x95, 0x1b, 0xd3, 0x6f, 0xf6, 0xef, 0x8b, 0x56,
		0xb9, 0x91, 0xcf, 0x9b, 0x87, 0xcc, 0x0d, 0x20, 0x33, 0xa1, 0x6d, 0xa2, 0x15, 0xa5, 0xe6, 0x3b,
		0x40, 0x2b, 0x4a, 0x30, 0xc1, 0xec, 0x63, 0xcd, 0x8b, 0x5a, 0x54, 0xcb, 0x94, 0xf6, 0x55, 0x83,
		0xf6, 0xa5, 0xf8, 0xb2, 0xa1, 0x7d, 0x69, 0xb4, 0x7b, 0x68, 0x5f, 0x3a, 0x17, 0x2c, 0xb4, 0x2f,
		0x66, 0x37, 0x02, 0xed, 0x0b, 0xac, 0xe7, 0x97, 0x46, 0x92, 0x09, 0xed, 0xab, 0x06, 0xed, 0x4b,
		0x0f, 0x69, 0x30, 0x5f, 0xfb, 0x3a, 0x7e, 0xbe, 0x2f, 0x5a, 0x47, 0xb6, 0xd5, 0x39, 0xb1, 0x3e,
		0x34, 0x7e, 0x14, 0xdf, 0x56, 0x86, 0xf9, 0xe3, 0xfc, 0xee, 0xe2, 0xcf, 0x8e, 0xf3, 0x3f, 0x8a,
		0x6f, 0xab, 0xc3, 0xdd, 0xdd, 0x15, 0xff, 0xf2, 0xdb, 0xaa, 0x63, 0xe4, 0x9f, 0x77, 0x77, 0x77,
		0x27, 0xaa, 0xd7, 0x9c, 0x12, 0x76, 0x5f, 0x2c, 0x35, 0x7e, 0x8b, 0xbe, 0x1c, 0xff, 0x1d, 0x6b,
		0x69, 0xaf, 0xfa, 0xe5, 0x7c, 0x7e, 0x77, 0x56, 0x42, 0x1b, 0xfd, 0xff, 0x47, 0x79, 0x98, 0x7f,
		0xde, 0x2d, 0xdd, 0x17, 0xad, 0x52, 0x2c, 0xa7, 0x95, 0x46, 0x07, 0x39, 0x1c, 0xfd, 0xba, 0xa9,
		0x4e, 0x78, 0x77, 0xf7, 0xfe, 0x5f, 0xc7, 0x8d, 0xbf, 0x1f, 0xe7, 0x7f, 0xd4, 0x86, 0xd3, 0xaf,
		0xa3, 0xbf, 0xf3, 0xcf, 0xbb, 0x7b, 0x7f, 0xfb, 0xfc, 0x79, 0x6f, 0xef, 0x6f, 0xf9, 0xf1, 0x43,
		0x9e, 0xfc, 0xde, 0xdf, 0xc6, 0xff, 0xfa, 0xdb, 0xf1, 0xf1, 0xd2, 0x8f, 0xf2, 0xbb, 0x85, 0xbd,
		0xbf, 0x43, 0x5a, 0x84, 0xe3, 0x9b, 0xb3, 0x30, 0x48, 0x8b, 0x9a, 0xef, 0x00, 0xd2, 0x22, 0x88,
		0x76, 0xf6, 0xb1, 0x26, 0x17, 0x9a, 0x48, 0xb0, 0x63, 0x72, 0x1d, 0x5d, 0x3d, 0xa4, 0x43, 0x15,
		0x97, 0x0d, 0xe9, 0x50, 0xa3, 0x9d, 0x43, 0x3a, 0xd4, 0xb9, 0x60, 0x21, 0x1d, 0x32, 0xbb, 0x11,
		0x48, 0x87, 0x60, 0x35, 0xbf, 0x34, 0x12, 0xf3, 0xa5, 0xc3, 0x81, 0xe7, 0xf4, 0x3c, 0x93, 0x45,
		0xc3, 0x23, 0x03, 0xaf, 0x7d, 0x62, 0x36, 0x66, 0x2a, 0x86, 0x06, 0x8f, 0x83, 0x8f, 0xf5, 0xf2,
		0xb6, 0xf0, 0x42, 0x27, 0x7c, 0xf2, 0x45, 0xc7, 0xe4, 0xf9, 0xe8, 0xd3, 0x25, 0x50, 0x35, 0xf8,
		0x1e, 0xce, 0x26, 0xaf, 0xe2, 0x9d, 0x1d, 0x98, 0x4b, 0xdf, 0x96, 0x0c, 0xec, 0xae, 0xde, 0xbc,
		0xbc, 0x3a, 0xad, 0x37, 0x4f, 0xee, 0xee, 0x6e, 0xce, 0xde, 0x7d, 0xbc, 0xab, 0x37, 0xef, 0xce,
		0x3f, 0x35, 0xef, 0xfe, 0xba, 0xae, 0x1b, 0x6c, 0x6f, 0xd1, 0x1d, 0x7e, 0xb2, 0xdd, 0x41, 0x94,
		0x18, 0x74, 0x6f, 0xf4, 0x7d, 0x98, 0x0d, 0x64, 0x2b, 0x6d, 0x2e, 0x32, 0xb8, 0xb3, 0xeb, 0x4f,
		0x95, 0xe6, 0xf9, 0xd5, 0xfb, 0x93, 0xf3, 0xe6, 0xc9, 0xe9, 0xe9, 0x4d, 0xfd, 0xf6, 0x36, 0x67,
		0xfc, 0x5d, 0x0e, 0xdf, 0xc2, 0xd4, 0x78, 0x9a, 0x5a, 0x2d, 0x73, 0xa6, 0x66, 0xf4, 0x1d, 0x34,
		0xde, 0xe0, 0xb9, 0x03, 0x98, 0xb6, 0x81, 0xc0, 0x0b, 0x6f, 0xd0, 0x15, 0xfe, 0x78, 0xb0, 0x4c,
		0x06, 0x08, 0x7c, 0xc5, 0xe0, 0x7b, 0xa8, 0x7b, 0x83, 0xee, 0x88, 0xb8, 0x1b, 0xba, 0x84, 0x91,
		0x12, 0x81, 0xe7, 0x6b, 0xd0, 0x95, 0x62, 0xf2, 0x3e, 0xed, 0x75, 0x9b, 0x3c, 0x10, 0x6c, 0x7e,
		0xea, 0xd0, 0xf2, 0x0c, 0x7e, 0x93, 0x7a, 0xea, 0xed, 0x18, 0x3a, 0x49, 0xec, 0xb2, 0xd7, 0x16,
		0x27, 0xd3, 0x57, 0xb0, 0x38, 0x7c, 0xff, 0x36, 0x7a, 0x01, 0x98, 0xb6, 0xbf, 0x2d, 0x48, 0x98,
		0x1b, 0x78, 0x5f, 0xbd, 0xde, 0x7f, 0x3c, 0x2b, 0x18, 0x3c, 0x98, 0xd0, 0x4c, 0x7c, 0x89, 0x66,
		0x2f, 0x5c, 0x3f, 0xda, 0x71, 0x52, 0x5c, 0x2e, 0xda, 0x71, 0x2a, 0xb4, 0x68, 0xb4, 0xe3, 0x54,
		0xb9, 0x10, 0xd1, 0x8e, 0x53, 0x37, 0x0d, 0x47, 0x3b, 0x4e, 0x30, 0x91, 0xa9, 0x31, 0x18, 0xd7,
		0x8e, 0xd3, 0xac, 0xde, 0xe5, 0x4b, 0xbe, 0xc6, 0xb4, 0x78, 0xcb, 0x40, 0xf2, 0x64, 0x2c, 0x89,
		0x32, 0x99, 0x4c, 0x65, 0x82, 0x54, 0x99, 0x4e, 0xae, 0x32, 0x43, 0xb2, 0x32, 0x43, 0xb6, 0xb2,
		0x42, 0xba, 0xcc, 0x22, 0x5f, 0x86, 0x91, 0x30, 0x63, 0xc9, 0x58, 0x7c, 0xe1, 0xae, 0xf0, 0x1e,
		0x23, 0x75, 0xdc, 0x50, 0xbc, 0x8c, 0x3b, 0x44, 0x8d, 0xef, 0xc3, 0x50, 0x8c, 0x31, 0xb3, 0xc0,
		0xcb, 0x78, 0xba, 0x96, 0x05, 0xda, 0x96, 0x29, 0xfa, 0x96, 0x15, 0x1a, 0x97, 0x39, 0x3a, 0x97,
		0x39, 0x5a, 0x97, 0x35, 0x7a, 0x67, 0x26, 0xcd, 0x33, 0x94, 0xee, 0xc5, 0xc6, 0x63, 0x6c, 0xc1,
		0xd8, 0x92, 0xd7, 0x18, 0x38, 0x5e, 0x58, 0xaa, 0x65, 0x20, 0xfb, 0xae, 0x66, 0xf0, 0x2d, 0xdc,
		0xd8, 0xde, 0xa3, 0x30, 0xbe, 0x18, 0xc3, 0xfc, 0xec, 0xf8, 0xdc, 0x85, 0xe3, 0x19, 0xcf, 0x3d,
		0x32, 0x12, 0x5c, 0x2c, 0xdd, 0x4e, 0x54, 0xb2, 0x94, 0xa1, 0xfb, 0xf9, 0xe0, 0xdb, 0xad, 0xd0,
		0xe9, 0x79, 0xa7, 0xce, 0xa3, 0x33, 0xee, 0x7d, 0x84, 0x12, 0x1f, 0x0e, 0x10, 0x60, 0x7f, 0x07,
		0x04, 0x30, 0x87, 0x80, 0x5a, 0xb5, 0xba, 0x5f, 0x05, 0x0c, 0x20, 0x16, 0xc1, 0xd5, 0xcf, 0xfe,
		0x69, 0xa0, 0x76, 0x03, 0x6e, 0x6e, 0x0d, 0xcc, 0x84, 0x26, 0x47, 0xac, 0x26, 0x37, 0x71, 0xcb,
		0x88, 0x2f, 0x86, 0xd6, 0xcf, 0x69, 0x1d, 0x40, 0xeb, 0xe7, 0xb4, 0xb0, 0xa1, 0xf5, 0x33, 0xbf,
		0x21, 0x68, 0xfd, 0x60, 0x4d, 0x89, 0x8d, 0x07, 0x5a, 0x3f, 0x3b, 0x0e, 0x05, 0xad, 0x5f, 0xf7,
		0x1f, 0x68, 0xfd, 0x08, 0x2e, 0x08, 0x6f, 0x07, 0x5a, 0x3f, 0xdc, 0xb9, 0x0a, 0x08, 0x80, 0xd6,
		0xcf, 0x1e, 0x02, 0xa0, 0xf5, 0x23, 0x16, 0xc1, 0xd5, 0x2f, 0xfd, 0x81, 0xd6, 0x0f, 0x37, 0xb7,
		0x0e, 0x66, 0xbe, 0x4d, 0xa0, 0xd3, 0x70, 0xb1, 0x7f, 0x7c, 0x1b, 0x50, 0xfb, 0x75, 0x5c, 0x3e,
		0xd4, 0x7e, 0x46, 0x0b, 0x01, 0x6a, 0x3f, 0xa7, 0x85, 0x0d, 0xb5, 0x9f, 0xf9, 0x0d, 0x41, 0xed,
		0x07, 0x6f, 0x4a, 0x6c, 0x3c, 0xd9, 0x51, 0xfb, 0x1f, 0x1c, 0xcf, 0xf6, 0x9f, 0x32, 0xa0, 0xf6,
		0x1f, 0x21, 0xd4, 0xc1, 0x15, 0x9b, 0x0e, 0x30, 0xa6, 0xb6, 0x52, 0x8d, 0xaf, 0x3f, 0xcb, 0x2d,
		0x55, 0xe7, 0x1b, 0x24, 0x16, 0x4c, 0xec, 0xf8, 0xb3, 0x93, 0xc5, 0x4e, 0xab, 0x1f, 0xc7, 0xef,
		0xe5, 0x36, 0x7a, 0x2d, 0x26, 0xf5, 0x5d, 0x35, 0x0f, 0x52, 0xd1, 0xa3, 0x0d, 0x60, 0xbf, 0x4d,
		0x20, 0x8f, 0x06, 0xda, 0x4c, 0x60, 0x1d, 0x8d, 0xb4, 0xb7, 0xe1, 0x0a, 0x99, 0x03, 0x77, 0xee,
		0xdc, 0x09, 0xc2, 0x91, 0xbd, 0x1a, 0x01, 0xd7, 0xb9, 0x0b, 0xc7, 0xab, 0xbb, 0xa2, 0x2b, 0xbc,
		0xf1, 0x26, 0xb2, 0x01, 0x2d, 0xd4, 0x2f, 0xec, 0xef, 0x33, 0x57, 0x5c, 0x3a, 0xac, 0x54, 0x6a,
		0x07, 0x95, 0x4a, 0xf1, 0x60, 0xff, 0xa0, 0x78, 0x54, 0xad, 0x96, 0x6a, 0x26, 0x0c, 0xbf, 0xcc,
		0x5d, 0xf9, 0x6d, 0xe1, 0x8b, 0xf6, 0xbb, 0xa7, 0xdc, 0xf1, 0x8e, 0x37, 0x70, 0x5d, 0xac, 0xb8,
		0xed, 0xa1, 0x48, 0x59, 0xa6, 0x46, 0x06, 0x70, 0xa1, 0xac, 0x71, 0x20, 0xde, 0xac, 0x87, 0x2f,
		0x97, 0xe0, 0x79, 0x65, 0x4c, 0xb1, 0xd6, 0x14, 0x8c, 0xcd, 0x22, 0xb6, 0x32, 0xc6, 0xd4, 0xcc,
		0x60, 0x29, 0x4f, 0x10, 0xe5, 0x07, 0x51, 0xbc, 0xae, 0x88, 0x19, 0x58, 0x72, 0x07, 0xc9, 0x0c,
		0x81, 0x23, 0x43, 0x4c, 0x34, 0x1e, 0x0b, 0x79, 0x61, 0x20, 0x1f, 0xa4, 0x61, 0x84, 0x32, 0x39,
		0xbf, 0x37, 0x08, 0x85, 0x6f, 0xd9, 0xed, 0xb6, 0x2f, 0x82, 0x80, 0x1d, 0xca, 0xc4, 0x19, 0x23,
		0x0b, 0xd7, 0xc9, 0x0c, 0xa7, 0x79, 0x8e, 0x34, 0x61, 0x9b, 0x29, 0xcb, 0x39, 0x03, 0xd6, 0x88,
		0xcc, 0x56, 0xee, 0x19, 0xab, 0xc6, 0x64, 0xa2, 0x1a, 0x93, 0x61, 0x6a, 0x4a, 0xe6, 0x28, 0xf8,
		0xfc, 0xcf, 0x5e, 0x22, 0xd7, 0x91, 0x1c, 0xcc, 0xe7, 0xa0, 0x19, 0x31, 0xef, 0x8c, 0xf9, 0x5c,
		0x33, 0xf6, 0x65, 0x33, 0x26, 0x94, 0xc5, 0x18, 0x55, 0xf6, 0x62, 0x4a, 0x59, 0x8b, 0x71, 0x65,
		0x2b, 0xc6, 0x95, 0xa5, 0x98, 0x56, 0x76, 0x82, 0x9d, 0x94, 0x2c, 0x90, 0x8a, 0xf8, 0x02, 0xb9,
		0x8a, 0x0b, 0x6b, 0xd1, 0x9d, 0xa7, 0xca, 0xb0, 0x8e, 0x70, 0x30, 0xcf, 0xb1, 0x31, 0xa6, 0x5e,
		0xd7, 0xa4, 0xba, 0x5c, 0x23, 0xeb, 0x6f, 0x4d, 0xab, 0xb3, 0x35, 0xb6, 0x9e, 0xd6, 0xd8, 0xba,
		0x59, 0x53, 0xeb, 0x63, 0x91, 0xe0, 0x9a, 0xe6, 0xa5, 0x1b, 0x53, 0xd7, 0x1a, 0xa3, 0xae, 0xd3,
		0xff, 0x56, 0x99, 0xee, 0x45, 0x58, 0x5e, 0xcf, 0xfa, 0xbf, 0x9e, 0x67, 0x42, 0x51, 0x56, 0x2c,
		0x51, 0x1c, 0x1a, 0x70, 0xad, 0xd7, 0x76, 0x18, 0x0a, 0xdf, 0x33, 0xa6, 0x1d, 0x65, 0x6e, 0x77,
		0xf7, 0xbe, 0x68, 0x1d, 0x35, 0x9e, 0xef, 0x4b, 0xd6, 0x51, 0x63, 0xfc, 0x65, 0x29, 0xfa, 0xdf,
		0xf8, 0xeb, 0xf2, 0x7d, 0xd1, 0xaa, 0x4c, 0xbf, 0xae, 0xde, 0x17, 0xad, 0x6a, 0x23, 0xff, 0xf9,
		0xf3, 0x5e, 0xfe, 0xc7, 0xfe, 0x70, 0xf3, 0x0f, 0xee, 0xfe, 0xf7, 0xfd, 0xe7, 0xcf, 0xfd, 0x1f,
		0x97, 0xc3, 0xd1, 0xdf, 0xe7, 0xc3, 0xc6, 0xdf, 0xf3, 0xbf, 0x99, 0xe2, 0x9b, 0x46, 0x37, 0xf2,
		0xf9, 0xf3, 0x5e, 0xe3, 0x6f, 0xfc, 0x61, 0xbd, 0x81, 0x4c, 0x48, 0xc4, 0xef, 0xf4, 0x9c, 0x07,
		0x99, 0x90, 0xe4, 0xc9, 0x3e, 0xf3, 0xe9, 0x03, 0xec, 0xab, 0xa8, 0x4d, 0x4c, 0xfd, 0xb9, 0x89,
		0x1e, 0xf1, 0xc9, 0xf8, 0x09, 0x73, 0x2e, 0x88, 0x46, 0x12, 0xa4, 0x51, 0x38, 0x89, 0x24, 0x48,
		0x65, 0xb8, 0x88, 0x24, 0x48, 0xf9, 0x48, 0x88, 0x24, 0x48, 0xf6, 0x28, 0xc3, 0x34, 0xfb, 0x81,
		0x75, 0xd6, 0x03, 0x52, 0x1e, 0x37, 0x95, 0x33, 0x90, 0xf2, 0x98, 0xee, 0x22, 0x91, 0xf2, 0x28,
		0xe9, 0x42, 0x91, 0xf2, 0x08, 0xf6, 0xae, 0xee, 0x25, 0xb2, 0x4d, 0x79, 0x64, 0x3d, 0x75, 0xd4,
		0x84, 0xa9, 0xa2, 0xcc, 0xf3, 0x0f, 0x90, 0xf0, 0xb8, 0x2d, 0xd4, 0xc0, 0x14, 0x8a, 0x60, 0x1c,
		0x55, 0x30, 0x8e, 0x32, 0x98, 0x46, 0x1d, 0x78, 0x52, 0x08, 0xa6, 0x54, 0x22, 0x7e, 0xb9, 0xec,
		0xf3, 0x05, 0x5e, 0xf2, 0x04, 0xda, 0xc2, 0x0b, 0x9d, 0xf0, 0xc9, 0x17, 0x1d, 0xce, 0xb8, 0x39,
		0x8d, 0xe5, 0x19, 0x37, 0xba, 0xca, 0x9d, 0x4d, 0x1e, 0xe5, 0x3b, 0x3b, 0x10, 0xe6, 0x64, 0x92,
		0x5e, 0xdd, 0x5e, 0x7f, 0x68, 0xde, 0xd5, 0x9b, 0xe7, 0xb7, 0x27, 0xcd, 0xbb, 0xf3, 0x4f, 0xcd,
		0xbb, 0xbf, 0xae, 0xeb, 0xdc, 0xc1, 0x3e, 0x9a, 0x6e, 0x16, 0x18, 0x91, 0x77, 0x61, 0x48, 0x1e,
		0xe1, 0xd4, 0x1a, 0xee, 0xea, 0xcd, 0x9b, 0xab, 0x8f, 0x77, 0xf5, 0x9b, 0xe6, 0xd9, 0xf5, 0xa7,
		0x5a, 0xf3, 0xe4, 0xf4, 0xf4, 0xa6, 0x7e, 0x7b, 0x6b, 0x40, 0x7a, 0xdb, 0x5b, 0x58, 0x82, 0x74,
		0x4b, 0xb8, 0xba, 0xbe, 0x3b, 0x7b, 0x7f, 0x72, 0xde, 0xbc, 0xbc, 0x3a, 0xad, 0x37, 0xaf, 0x6f,
		0xae, 0xae, 0xeb, 0x37, 0x77, 0x7f, 0xc1, 0x16, 0xb6, 0xd2, 0x16, 0xce, 0xcf, 0x2e, 0xff, 0xc0,
		0xab, 0xdf, 0xda, 0x57, 0xdf, 0x3c, 0xbf, 0x7a, 0x7f, 0x72, 0x0e, 0x03, 0xd8, 0x66, 0x46, 0x00,
		0x32, 0xb0, 0xcd, 0x46, 0x10, 0x91, 0x80, 0x93, 0xbb, 0xbb, 0x9b, 0xb3, 0x77, 0x1f, 0xef, 0xea,
		0x28, 0x78, 0x48, 0xf7, 0xa7, 0x01, 0xa1, 0xc7, 0xf0, 0xab, 0xc2, 0x9e, 0xda, 0xcf, 0x80, 0x03,
		0x19, 0x71, 0x74, 0x19, 0x71, 0x5c, 0x53, 0x83, 0x4d, 0x4c, 0x84, 0x63, 0x98, 0x04, 0x8c, 0x04,
		0xb8, 0x55, 0xb6, 0x35, 0x9d, 0x3f, 0x13, 0xba, 0xdf, 0xf8, 0xa6, 0xc1, 0xcd, 0x5e, 0x24, 0x92,
		0xe1, 0x5e, 0x73, 0x59, 0x48, 0x86, 0x4b, 0x61, 0x6e, 0x48, 0x86, 0x4b, 0xb3, 0x20, 0x90, 0x0c,
		0x27, 0x9b, 0xf3, 0x21, 0x19, 0xce, 0x7c, 0xe2, 0x8e, 0xfe, 0x7f, 0xe9, 0x30, 0x19, 0xfd, 0xff,
		0xb2, 0x47, 0x06, 0x4c, 0x20, 0x05, 0x46, 0x91, 0x03, 0x53, 0x48, 0x82, 0x71, 0x64, 0xc1, 0x38,
		0xd2, 0x60, 0x1a, 0x79, 0xe0, 0x49, 0x22, 0x98, 0x92, 0x09, 0xf6, 0xa4, 0x22, 0xbe, 0x40, 0x57,
		0x78, 0x8f, 0x91, 0x14, 0x68, 0x48, 0xd2, 0xd6, 0xe4, 0x7a, 0xd1, 0xfd, 0x6f, 0x1b, 0x68, 0x87,
		0x49, 0xf4, 0xc3, 0x48, 0x1a, 0x62, 0x1a, 0x1d, 0x31, 0x96, 0x96, 0x18, 0x4b, 0x4f, 0x4c, 0xa5,
		0x29, 0xbc, 0xe9, 0x0a, 0x73, 0xda, 0x12, 0xbf, 0x74, 0xf3, 0xba, 0xff, 0x0d, 0x1c, 0x2f, 0x2c,
		0xd5, 0x0c, 0xea, 0xf7, 0x57, 0x33, 0xe0, 0x52, 0x6f, 0x6c, 0xef, 0x51, 0x18, 0xd3, 0xec, 0xcf,
		0x0c, 0x17, 0xb6, 0x33, 0x19, 0xc8, 0x6e, 0x8c, 0xcf, 0x35, 0x8c, 0xdc, 0x2e, 0x5d, 0x76, 0x54,
		0x3a, 0x61, 0xe0, 0x75, 0x7f, 0xf0, 0xed, 0x56, 0xe8, 0xf4, 0xbc, 0x53, 0xe7, 0xd1, 0x19, 0xcf,
		0xed, 0x37, 0xe6, 0xfa, 0x87, 0x6f, 0x0d, 0x5a, 0x8a, 0xf6, 0x77, 0x2c, 0x45, 0xc5, 0x4b, 0xb1,
		0x56, 0xad, 0xee, 0x57, 0xb1, 0x1c, 0xc1, 0x85, 0xcd, 0xba, 0x4a, 0xb4, 0x9e, 0xcd, 0x9c, 0x3b,
		0xe0, 0xdd, 0x71, 0x64, 0x29, 0xca, 0x61, 0xdc, 0x79, 0xc4, 0x30, 0xdf, 0x04, 0x0d, 0x94, 0xd2,
		0x4e, 0xa1, 0x81, 0x52, 0x2e, 0x30, 0x68, 0xa0, 0x8a, 0x2f, 0x1c, 0x1a, 0xe8, 0xf6, 0x05, 0x89,
		0xd0, 0x40, 0xe9, 0x39, 0x02, 0x34, 0x50, 0xd9, 0x7f, 0xa0, 0x81, 0x82, 0xdc, 0xae, 0xb8, 0x6c,
		0x68, 0xa0, 0x70, 0x6f, 0x3f, 0x5b, 0x8a, 0xd0, 0x40, 0x95, 0x2f, 0x45, 0x68, 0xa0, 0xe0, 0xc2,
		0x06, 0x5e, 0x25, 0x34, 0xd0, 0xcc, 0xb9, 0x83, 0xdc, 0xb7, 0x09, 0x24, 0x19, 0x22, 0x82, 0x8e,
		0x2f, 0x17, 0x2a, 0xa8, 0x8c, 0xcb, 0x84, 0x0a, 0x4a, 0x68, 0xa8, 0x50, 0x41, 0x29, 0x17, 0x18,
		0x54, 0x50, 0xc5, 0x17, 0x0e, 0x15, 0x74, 0xfb, 0xc2, 0x44, 0x03, 0x55, 0xd0, 0x07, 0xc7, 0xb3,
		0xfd, 0x27, 0x83, 0x54, 0xd0, 0x23, 0x50, 0xea, 0x0c, 0x5d, 0x19, 0x26, 0xda, 0xa6, 0xbb, 0x4e,
		0x93, 0xfb, 0x54, 0xcd, 0x74, 0xc3, 0xc1, 0x38, 0x5b, 0x82, 0xde, 0x55, 0x1f, 0xc7, 0xcf, 0x97,
		0x69, 0x1b, 0x2b, 0xbe, 0xb8, 0x84, 0x06, 0x20, 0x06, 0x23, 0x63, 0x56, 0x10, 0x11, 0xfd, 0xfb,
		0x24, 0x63, 0x20, 0x9a, 0xf8, 0x71, 0xbe, 0x12, 0x26, 0x28, 0x97, 0x3b, 0x77, 0x82, 0xf0, 0x24,
		0x0c, 0x79, 0xb5, 0x23, 0xc8, 0x5d, 0x38, 0x5e, 0xdd, 0x15, 0x5d, 0xe1, 0x8d, 0xb7, 0x91, 0x18,
		0xb5, 0x5d, 0xbc, 0xb0, 0xbf, 0xcf, 0x5c, 0x59, 0xe9, 0xb0, 0x52, 0xa9, 0x1d, 0x54, 0x2a, 0xc5,
		0x83, 0xfd, 0x83, 0xe2, 0x51, 0xb5, 0x5a, 0xaa, 0x71, 0x1a, 0xc8, 0x93, 0xbb, 0xf2, 0xdb, 0xc2,
		0x17, 0xed, 0x77, 0x4f, 0xb9, 0xe3, 0x1d, 0x6f, 0xe0, 0xba, 0xb0, 0x7c, 0xfe, 0x7e, 0xdd, 0x64,
		0x7f, 0x9e, 0x63, 0x35, 0x20, 0xdc, 0x34, 0xdf, 0xcd, 0xc3, 0x61, 0xeb, 0x77, 0x8f, 0x7a, 0xaf,
		0x40, 0x33, 0x3c, 0x71, 0x83, 0x25, 0x53, 0xe1, 0x88, 0x01, 0x14, 0x19, 0x06, 0x41, 0x7a, 0xe1,
		0x47, 0xdf, 0xa2, 0xd7, 0x73, 0x66, 0x4d, 0x30, 0xc3, 0x05, 0x5e, 0x0c, 0x84, 0x15, 0x8d, 0x88,
		0x62, 0x0e, 0x92, 0xe8, 0x01, 0x11, 0xf5, 0x4b, 0x58, 0xc3, 0xf2, 0x65, 0xd1, 0xf1, 0x9f, 0x51,
		0x67, 0x7f, 0xcd, 0xcd, 0x7b, 0xb5, 0xe7, 0x46, 0x71, 0xc8, 0x79, 0x62, 0x95, 0xcb, 0xc4, 0x25,
		0x47, 0x89, 0x5d, 0xee, 0x11, 0xbb, 0x9c, 0x22, 0x6e, 0xb9, 0x42, 0xdb, 0x45, 0x01, 0x75, 0x37,
		0x9f, 0x65, 0xd2, 0xb9, 0x9e, 0x55, 0x87, 0x7a, 0x26, 0x9d, 0xe8, 0xd9, 0x24, 0xfc, 0x72, 0x4a,
		0xe8, 0x65, 0x99, 0xb0, 0xcb, 0x2d, 0x21, 0x97, 0x6d, 0xc2, 0x2d, 0xdb, 0x84, 0x5a, 0xae, 0x09,
		0xb3, 0xdb, 0x2d, 0xbf, 0x72, 0xe9, 0xcc, 0xce, 0xad, 0x03, 0x3b, 0xcf, 0x4e, 0xeb, 0xcc, 0xea,
		0x68, 0xd8, 0xd5, 0xcb, 0x70, 0xac, 0x8b, 0x61, 0x5d, 0xff, 0xc2, 0xb5, 0xce, 0x85, 0x7d, 0x3d,
		0x0b, 0xfb, 0xba, 0x15, 0xee, 0xf5, 0x29, 0x48, 0x4b, 0x9a, 0x7d, 0x59, 0xec, 0xea, 0x4a, 0xf8,
		0x76, 0xd1, 0x61, 0xd8, 0x2d, 0x87, 0x69, 0x57, 0x1c, 0x86, 0xc9, 0xbb, 0x9c, 0xbb, 0xdc, 0x30,
		0x2f, 0x52, 0xe6, 0xde, 0xb5, 0xc6, 0x84, 0x76, 0x18, 0x0c, 0xab, 0x91, 0x58, 0x77, 0x9b, 0x31,
		0x65, 0x49, 0x30, 0xee, 0x1e, 0x63, 0xc4, 0xb2, 0x40, 0xea, 0xfc, 0xca, 0x3f, 0x0d, 0x64, 0x28,
		0x72, 0x81, 0x4d, 0x5e, 0x9d, 0xa9, 0x39, 0x76, 0xa0, 0x86, 0x36, 0xf4, 0x8b, 0x0b, 0x82, 0x36,
		0xb4, 0xe1, 0xc5, 0x41, 0x1b, 0x4a, 0x78, 0x81, 0xd0, 0x86, 0xb2, 0xc0, 0x00, 0xa0, 0x0d, 0xfd,
		0x0a, 0xb5, 0xa0, 0x0d, 0xbd, 0xe2, 0x92, 0xa0, 0x0d, 0xbd, 0x36, 0x10, 0x86, 0x36, 0x94, 0x3a,
		0x10, 0x86, 0x36, 0x64, 0x3a, 0xdc, 0xcf, 0x2f, 0x09, 0x68, 0x43, 0xa9, 0x97, 0x04, 0xb4, 0xa1,
		0x8c, 0xa8, 0x31, 0x3b, 0xd0, 0x86, 0x18, 0x3e, 0x0f, 0x0e, 0xda, 0x10, 0xaf, 0x8e, 0xbd, 0x2c,
		0x3b, 0xf3, 0x42, 0x1d, 0xfa, 0xc5, 0x05, 0x41, 0x1d, 0xda, 0xf0, 0xe2, 0xa0, 0x0e, 0x25, 0xbc,
		0x40, 0xa8, 0x43, 0x59, 0xe0, 0x00, 0x50, 0x87, 0x7e, 0x85, 0x5a, 0xec, 0x3a, 0xcf, 0xf2, 0xea,
		0x30, 0x8b, 0xc6, 0x23, 0x68, 0x3c, 0x32, 0x7b, 0x3d, 0xcc, 0x3b, 0x04, 0x70, 0x6c, 0xe6, 0xca,
		0xb5, 0x4f, 0x00, 0xaf, 0xc6, 0xac, 0x68, 0x35, 0xb2, 0x55, 0x80, 0x62, 0x10, 0x90, 0xa0, 0xc5,
		0xc8, 0x4f, 0xa0, 0x63, 0x6b, 0x5a, 0x8b, 0xbc, 0xc9, 0x30, 0x38, 0xe8, 0x06, 0x05, 0xe6, 0x60,
		0xa0, 0x01, 0x00, 0x98, 0x2e, 0x7c, 0xb5, 0xab, 0x5d, 0xdd, 0x9a, 0x53, 0xb8, 0xde, 0x72, 0x7e,
		0x6f, 0x10, 0x0a, 0x3f, 0xb2, 0x2b, 0xd5, 0x6b, 0x2d, 0x0e, 0x7a, 0x67, 0xae, 0x41, 0x31, 0xd2,
		0xe8, 0xe9, 0xa8, 0xa0, 0x4d, 0xc8, 0xd5, 0x29, 0xd8, 0xb2, 0x10, 0x66, 0x75, 0x0b, 0xb0, 0x6c,
		0x84, 0x56, 0x36, 0x82, 0x2a, 0x17, 0xe1, 0x34, 0xdb, 0x8c, 0x4a, 0x57, 0xc7, 0x02, 0xcd, 0x6d,
		0x7c, 0x58, 0xb4, 0xef, 0x41, 0x0f, 0x3a, 0xf4, 0xa0, 0x63, 0xe5, 0x84, 0xd8, 0x39, 0x23, 0x76,
		0x4e, 0x89, 0x9b, 0x73, 0xda, 0x4e, 0x6d, 0x50, 0x7b, 0x0f, 0x3a, 0xd7, 0xf1, 0xbe, 0x5a, 0x6d,
		0x3b, 0xb4, 0xf9, 0xf4, 0xa1, 0x7b, 0xb9, 0x24, 0x1e, 0xbd, 0xe8, 0x8a, 0xe8, 0x45, 0xc7, 0xc6,
		0xc9, 0xb1, 0x74, 0x76, 0xdc, 0x9c, 0x1e, 0x5b, 0xe7, 0xc7, 0xd6, 0x09, 0x72, 0x75, 0x86, 0x7a,
		0x9d, 0xa2, 0x66, 0xe7, 0x18, 0xbf, 0x14, 0x36, 0xa9, 0x2c, 0x33, 0x5d, 0xbf, 0x9d, 0x9e, 0xc7,
		0x01, 0x71, 0xa6, 0x71, 0xd7, 0x11, 0x83, 0x6b, 0x99, 0xbc, 0x26, 0x1e, 0xf5, 0x4c, 0x0c, 0xf3,
		0x9e, 0xda, 0xbd, 0x30, 0x14, 0x6d, 0xeb, 0xdf, 0x03, 0xbb, 0xcd, 0x30, 0xf9, 0xa9, 0x74, 0xc8,
		0xe8, 0x9a, 0xae, 0xed, 0x30, 0x14, 0xbe, 0xc7, 0xae, 0x3a, 0x2e, 0xb7, 0xbb, 0x7b, 0x5f, 0xb4,
		0x8e, 0x1a, 0xcf, 0xf7, 0x25, 0xeb, 0xa8, 0x31, 0xfe, 0xb2, 0x14, 0xfd, 0x6f, 0xfc, 0x75, 0xf9,
		0xbe, 0x68, 0x55, 0xa6, 0x5f, 0x57, 0xef, 0x8b, 0x56, 0xb5, 0x91, 0xff, 0xfc, 0x79, 0x2f, 0xff,
		0x63, 0x7f, 0xb8, 0xf9, 0x07, 0x73, 0xa8, 0x69, 0xe0, 0xe4, 0x86, 0x18, 0x23, 0xcb, 0xc0, 0xf1,
		0xc2, 0xfd, 0x32, 0x43, 0x50, 0x39, 0x40, 0xbd, 0xad, 0x31, 0xd6, 0x14, 0x3f, 0x28, 0xd4, 0xdb,
		0x26, 0xbf, 0x3c, 0xd4, 0xdb, 0x66, 0x05, 0xe6, 0xe7, 0x97, 0x04, 0xea, 0x6d, 0x53, 0x2f, 0x89,
		0x4a, 0xf9, 0xa8, 0x72, 0x54, 0x3b, 0x28, 0x1f, 0xa1, 0xe8, 0xd6, 0x50, 0x1d, 0x80, 0xef, 0xd5,
		0xa0, 0xe8, 0x96, 0xc3, 0x73, 0xd0, 0x98, 0x50, 0xfe, 0x56, 0xf3, 0x0e, 0x8a, 0xd3, 0x66, 0xb6,
		0x7f, 0xe2, 0xb4, 0xb1, 0x7b, 0xb2, 0x83, 0xdd, 0x93, 0x5f, 0x98, 0x0a, 0x76, 0x4f, 0x7e, 0x66,
		0xc0, 0xd8, 0x3d, 0xd9, 0xf0, 0xc2, 0xb0, 0x7b, 0xc2, 0x2f, 0x9e, 0x61, 0xb8, 0x7b, 0xc2, 0x4b,
		0x08, 0xe7, 0x24, 0x80, 0xb3, 0x13, 0xbe, 0xb7, 0x4c, 0xf0, 0x06, 0x7f, 0x56, 0x6f, 0x61, 0x5d,
		0x11, 0xfa, 0x4e, 0x8b, 0x0f, 0x7d, 0x9e, 0x5c, 0x0f, 0xd8, 0x33, 0xd8, 0x33, 0xd8, 0x33, 0xd8,
		0x33, 0xd8, 0x33, 0xd8, 0x33, 0x2f, 0xd4, 0x09, 0xfa, 0x1d, 0x8b, 0x85, 0x93, 0xda, 0xe1, 0xd5,
		0x59, 0x99, 0xd9, 0x0e, 0x2f, 0xa3, 0x3c, 0x01, 0x8e, 0x3b, 0xba, 0x4c, 0xb7, 0xad, 0xb8, 0xee,
		0xe0, 0x72, 0xde, 0x9d, 0x62, 0xb4, 0x63, 0xcb, 0x72, 0xa7, 0x96, 0xbb, 0xa9, 0x33, 0xec, 0x84,
		0xcc, 0xda, 0xdc, 0xb1, 0xd9, 0x08, 0xb1, 0x44, 0xd3, 0xb2, 0xf0, 0x06, 0xdd, 0x07, 0xe1, 0x5b,
		0xae, 0xe3, 0x7d, 0x0d, 0xf8, 0x48, 0x26, 0x73, 0x57, 0x05, 0xe1, 0x04, 0xc2, 0x09, 0x84, 0x13,
		0x08, 0x27, 0x10, 0x4e, 0x20, 0x9c, 0xf0, 0x2a, 0xda, 0xe2, 0x32, 0x95, 0x0a, 0x9a, 0x09, 0x34,
		0x13, 0x68, 0x26, 0xd0, 0x4c, 0xa0, 0x99, 0x40, 0x33, 0x81, 0x66, 0x02, 0xcd, 0x04, 0x9a, 0x89,
		0x0a, 0xcd, 0x24, 0xec, 0x05, 0x93, 0x6d, 0x33, 0x7e, 0xca, 0xc9, 0xec, 0xb5, 0x41, 0x3f, 0x81,
		0x7e, 0x02, 0xfd, 0x04, 0xfa, 0x09, 0xf4, 0x13, 0xe8, 0x27, 0xd0, 0x4f, 0xa0, 0x9f, 0x40, 0x3f,
		0x81, 0x7e, 0x82, 0x80, 0x12, 0xfa, 0x09, 0xf4, 0x13, 0xe8, 0x27, 0xd0, 0x4f, 0xa0, 0x9f, 0x28,
		0x5f, 0x16, 0x21, 0x07, 0x26, 0x1a, 0xb3, 0xd0, 0xe8, 0x6a, 0xa0, 0x91, 0x40, 0x23, 0x81, 0x46,
		0x02, 0x8d, 0x04, 0x1a, 0x09, 0x34, 0x12, 0x56, 0xa8, 0xe3, 0xb4, 0x85, 0x17, 0x3a, 0xe1, 0x93,
		0x2f, 0x3a, 0x9c, 0x4a, 0xdb, 0x19, 0x30, 0xed, 0xdc, 0xd9, 0xe4, 0xd1, 0xbc, 0xb3, 0x03, 0x46,
		0x48, 0x38, 0x7d, 0x71, 0x37, 0x57, 0x1f, 0xef, 0xea, 0x37, 0xcd, 0xf3, 0xdb, 0x93, 0xe6, 0xdd,
		0x5f, 0xd7, 0xf5, 0x5b, 0x2e, 0x80, 0x18, 0xc5, 0x4b, 0x01, 0xab, 0xb6, 0x95, 0xcc, 0x02, 0xdd,
		0x15, 0x6f, 0xf0, 0xba, 0x7c, 0x9d, 0x83, 0x52, 0x61, 0xe2, 0x9b, 0xbb, 0xbd, 0xfb, 0xf8, 0xae,
		0x79, 0x59, 0xbf, 0xfb, 0xe7, 0xd5, 0xcd, 0x1f, 0x78, 0x85, 0x46, 0xbe, 0xc2, 0xbb, 0x9b, 0x93,
		0xcb, 0xdb, 0xb3, 0x3b, 0xbc, 0x45, 0xa3, 0xdf, 0xe2, 0xa7, 0xb3, 0x9b, 0xbb, 0x8f, 0x27, 0xe7,
		0xcd, 0xf3, 0xb3, 0x4b, 0x4e, 0xaf, 0x90, 0xc5, 0x95, 0x34, 0xb6, 0x9d, 0xf6, 0x63, 0x38, 0x98,
		0x9a, 0x98, 0x53, 0xef, 0x8c, 0xf0, 0xf8, 0x3a, 0x38, 0xce, 0x0a, 0x7f, 0x99, 0xa7, 0x5c, 0xd0,
		0x39, 0xf8, 0x72, 0x87, 0xdd, 0xe4, 0xf0, 0x9b, 0xe8, 0xc1, 0x8c, 0xbe, 0xba, 0x8d, 0x9e, 0xcb,
		0x9b, 0xed, 0x58, 0xa7, 0x1a, 0xd6, 0x68, 0x24, 0x45, 0x07, 0x56, 0xaf, 0x63, 0x05, 0xc2, 0xff,
		0xe6, 0xb4, 0x18, 0xcc, 0x80, 0x5d, 0xba, 0x22, 0x8c, 0x83, 0xd5, 0x72, 0x01, 0x18, 0x07, 0xbb,
		0x70, 0x31, 0x18, 0x07, 0xbb, 0xe6, 0x82, 0x30, 0x0e, 0x16, 0x8c, 0xef, 0xe5, 0xe1, 0x6b, 0x1f,
		0x07, 0x3b, 0x72, 0x20, 0x1c, 0x3c, 0xda, 0x4a, 0xcf, 0xa6, 0xdf, 0xb1, 0x31, 0x71, 0x70, 0x6c,
		0x1c, 0x1d, 0x27, 0x87, 0xc7, 0xd2, 0xf1, 0x71, 0x73, 0x80, 0x6c, 0x1d, 0x21, 0x5b, 0x87, 0xc8,
		0xd5, 0x31, 0x32, 0x91, 0x82, 0x34, 0xe3, 0x8e, 0x6e, 0x87, 0x39, 0xa3, 0x01, 0x8c, 0x82, 0x6d,
		0x76, 0xdb, 0x9a, 0xba, 0xb5, 0x11, 0x86, 0x4e, 0x93, 0x9d, 0xf3, 0xe4, 0xe8, 0x44, 0x59, 0x3b,
		0x53, 0xae, 0x4e, 0x95, 0xbd, 0x73, 0x65, 0xef, 0x64, 0xb9, 0x3b, 0x5b, 0x1e, 0x4e, 0x97, 0x89,
		0xf3, 0x65, 0xe7, 0x84, 0xe3, 0x0b, 0x62, 0x32, 0x52, 0x60, 0x2d, 0x98, 0xb2, 0xe9, 0xde, 0xbc,
		0xca, 0x3d, 0x73, 0xab, 0x18, 0xe1, 0xe6, 0xa6, 0x39, 0xbb, 0x6b, 0x23, 0xdc, 0x36, 0x77, 0xf7,
		0x6d, 0x8c, 0x1b, 0x37, 0xc6, 0x9d, 0x9b, 0xe2, 0xd6, 0x79, 0xb9, 0x77, 0x66, 0x6e, 0x3e, 0x7e,
		0x89, 0x6c, 0xb2, 0xae, 0xd7, 0xa3, 0x1e, 0xab, 0x11, 0x09, 0xeb, 0x1c, 0x6d, 0x8d, 0xe1, 0xa5,
		0xf1, 0x1c, 0x92, 0x3f, 0xfd, 0xc3, 0xd3, 0x4f, 0xec, 0x70, 0x1f, 0x9a, 0xcf, 0x9c, 0xe1, 0x2d,
		0x5d, 0x26, 0xf3, 0x21, 0xfa, 0xf1, 0x75, 0x1a, 0x30, 0x30, 0x9c, 0xa9, 0x0f, 0x99, 0x5f, 0x3a,
		0x8c, 0x87, 0xeb, 0x9b, 0xba, 0x74, 0x18, 0x96, 0xd7, 0x1b, 0xbd, 0x7c, 0xde, 0xe0, 0xaa, 0x5e,
		0xf3, 0xa7, 0xf1, 0x06, 0xcf, 0x87, 0x39, 0xfc, 0xe6, 0xc2, 0x5e, 0xc0, 0x57, 0x19, 0x1b, 0x5d,
		0x1c, 0x64, 0xb1, 0xd7, 0x5c, 0x16, 0x64, 0xb1, 0x34, 0x01, 0x22, 0x64, 0xb1, 0x14, 0x0b, 0x02,
		0xb2, 0x98, 0xe4, 0x0b, 0x85, 0x2c, 0x66, 0x7e, 0x48, 0x63, 0x80, 0x2c, 0x36, 0x70, 0xbc, 0xf0,
		0x90, 0xb1, 0x20, 0x56, 0x85, 0x20, 0xb6, 0xe1, 0x1f, 0x08, 0x62, 0x5b, 0x15, 0xd5, 0x43, 0x10,
		0xcb, 0xaa, 0xf7, 0x98, 0x5f, 0x3a, 0x10, 0xc4, 0xa4, 0x2f, 0x9d, 0x72, 0x15, 0x72, 0x58, 0x46,
		0x89, 0x20, 0xdf, 0xab, 0x82, 0x1c, 0xc6, 0xf9, 0x4a, 0xb8, 0xa4, 0xcf, 0x31, 0x29, 0xf3, 0x5f,
		0xba, 0x2e, 0xe6, 0x65, 0xff, 0x8b, 0xb5, 0xce, 0x85, 0x85, 0x12, 0xb1, 0x02, 0xa7, 0xdc, 0xf7,
		0x1d, 0xc6, 0x7d, 0x02, 0xa2, 0x5f, 0xb8, 0xea, 0xdc, 0x8e, 0x1f, 0x5b, 0xf4, 0xed, 0xcb, 0x77,
		0x1a, 0x9b, 0x08, 0xf0, 0x43, 0x0d, 0x06, 0x88, 0xc1, 0x4a, 0xbe, 0x67, 0x28, 0xdb, 0x33, 0xe3,
		0xa5, 0x28, 0x32, 0xd9, 0xc4, 0x8c, 0x50, 0x64, 0xb2, 0x89, 0xa1, 0xa3, 0xc8, 0x24, 0x2d, 0xf1,
		0x42, 0x91, 0x89, 0x39, 0x2c, 0x99, 0x9d, 0xbc, 0x1e, 0xa3, 0x96, 0x2b, 0xec, 0x0e, 0x8f, 0x7e,
		0xbf, 0x8b, 0x4e, 0xb0, 0x74, 0xc0, 0xe8, 0x9a, 0xae, 0x27, 0x81, 0xc4, 0xde, 0xde, 0x98, 0x99,
		0x17, 0x46, 0xa4, 0x01, 0xc4, 0x92, 0xc1, 0x15, 0xe8, 0x2e, 0xe2, 0xfe, 0x43, 0x3c, 0xf1, 0x20,
		0x91, 0xb9, 0x73, 0x27, 0x08, 0x4f, 0xc2, 0x90, 0x49, 0x4d, 0xf9, 0x85, 0xe3, 0xd5, 0x5d, 0x31,
		0xf2, 0x50, 0x01, 0x0f, 0x02, 0x99, 0xbb, 0xb0, 0xbf, 0xcf, 0x5c, 0x51, 0xe9, 0xb0, 0x52, 0xa9,
		0x1d, 0x54, 0x2a, 0xc5, 0x83, 0xfd, 0x83, 0xe2, 0x51, 0xb5, 0x5a, 0xaa, 0xb1, 0x68, 0x34, 0x7e,
		0xe5, 0xb7, 0x85, 0x2f, 0xda, 0xef, 0x46, 0x46, 0xe5, 0x0d, 0x5c, 0x77, 0xab, 0xd7, 0x16, 0x33,
		0x71, 0xc9, 0x74, 0x51, 0x89, 0x43, 0x2b, 0x19, 0x03, 0x65, 0xa4, 0x1c, 0xfa, 0xd5, 0x66, 0x1f,
		0x73, 0xd0, 0xaf, 0x36, 0x19, 0xc6, 0xa0, 0x75, 0xed, 0x2f, 0xb0, 0x64, 0x6b, 0x7a, 0xd8, 0xbe,
		0xc9, 0x30, 0x4a, 0xe8, 0x46, 0x07, 0xe6, 0xa8, 0xa0, 0x01, 0x04, 0x98, 0x2e, 0x7e, 0xb5, 0xab,
		0x5d, 0xdd, 0x9a, 0x53, 0xb8, 0xde, 0x34, 0x75, 0x23, 0xd3, 0xda, 0x75, 0x4c, 0x53, 0x77, 0x31,
		0x6d, 0x1b, 0x3c, 0x3a, 0x37, 0x72, 0x58, 0x6c, 0xd8, 0xe8, 0xde, 0x98, 0x61, 0xb3, 0x01, 0xc3,
		0x66, 0xa3, 0x85, 0xcb, 0x86, 0x4a, 0xb6, 0x79, 0x94, 0xae, 0x6e, 0x5b, 0x39, 0xbb, 0xfd, 0x4d,
		0xf8, 0xa1, 0x13, 0x38, 0xde, 0xa3, 0x35, 0x26, 0x2e, 0xfa, 0x07, 0x1e, 0xac, 0xb8, 0x26, 0xbd,
		0x23, 0x0f, 0x8a, 0x18, 0x79, 0x80, 0x91, 0x07, 0x3b, 0x18, 0x79, 0x60, 0x80, 0xbb, 0xe2, 0xe6,
		0xb6, 0xb6, 0x53, 0x34, 0xd4, 0xbe, 0xaf, 0x1f, 0xa3, 0x46, 0xbb, 0x17, 0x86, 0xa2, 0x6d, 0xfd,
		0x7b, 0x60, 0xb7, 0x75, 0xe2, 0xc6, 0x34, 0x8e, 0x39, 0xd4, 0x78, 0x0d, 0xd7, 0x76, 0x18, 0x0a,
		0xdf, 0xd3, 0x5e, 0xf7, 0x96, 0xdb, 0xdd, 0xbd, 0x2f, 0x5a, 0x47, 0x8d, 0xe7, 0xfb, 0x92, 0x75,
		0xd4, 0x18, 0x7f, 0x59, 0x8a, 0xfe, 0x37, 0xfe, 0xba, 0x7c, 0x5f, 0xb4, 0x2a, 0xd3, 0xaf, 0xab,
		0xf7, 0x45, 0xab, 0xda, 0xc8, 0x7f, 0xfe, 0xbc, 0x97, 0xff, 0xb1, 0x3f, 0xdc, 0xfc, 0x83, 0xfa,
		0x56, 0x7c, 0x03, 0x43, 0xba, 0xe8, 0x58, 0xeb, 0x23, 0x83, 0xb9, 0x5c, 0xa3, 0x8b, 0x00, 0x2f,
		0x05, 0x2f, 0x05, 0x2f, 0x05, 0x2f, 0x05, 0x2f, 0x05, 0x2f, 0xdd, 0x08, 0x35, 0x06, 0x8e, 0x17,
		0x96, 0x6a, 0x0c, 0x28, 0xa9, 0xc6, 0x86, 0xa5, 0x4c, 0xfa, 0x30, 0xf0, 0x48, 0x0a, 0x64, 0x34,
		0x45, 0x8a, 0x57, 0xb1, 0x0d, 0xb3, 0x3e, 0x09, 0x1c, 0x4b, 0xba, 0x87, 0x3c, 0xb2, 0x48, 0x61,
		0xc2, 0xbf, 0x30, 0x61, 0x46, 0x0d, 0x3c, 0x59, 0x9a, 0xf1, 0x96, 0x26, 0x14, 0x42, 0x29, 0xa0,
		0x33, 0xf3, 0xd6, 0x17, 0xd1, 0xfa, 0x1a, 0x0c, 0xba, 0xfa, 0xe5, 0x82, 0xf8, 0x4a, 0xa0, 0x19,
		0x40, 0x33, 0x80, 0x66, 0x00, 0xcd, 0x00, 0x9a, 0x01, 0x34, 0x03, 0x68, 0x06, 0xd0, 0x0c, 0xa0,
		0x19, 0x40, 0x33, 0x80, 0x66, 0x00, 0x13, 0x86, 0x66, 0x00, 0xcd, 0x00, 0x9a, 0x01, 0x03, 0xcd,
		0xc0, 0x75, 0xbc, 0xaf, 0x56, 0x54, 0xee, 0x60, 0x39, 0x6d, 0xfd, 0xc2, 0xc1, 0xfc, 0xe5, 0x40,
		0x3d, 0x80, 0x7a, 0x00, 0xf5, 0x00, 0xea, 0x01, 0xd4, 0x03, 0xa8, 0x07, 0x1b, 0xa1, 0x06, 0x32,
		0x61, 0x5f, 0xc0, 0x1c, 0x99, 0xb0, 0xe0, 0xaa, 0xd9, 0xe0, 0xaa, 0x81, 0xf8, 0xf7, 0x40, 0x78,
		0x2d, 0x61, 0x79, 0x83, 0xee, 0x03, 0x87, 0xe2, 0xad, 0xc5, 0x0b, 0x02, 0x5f, 0x05, 0x5f, 0x05,
		0x5f, 0x05, 0x5f, 0x05, 0x5f, 0x05, 0x5f, 0xdd, 0x08, 0x35, 0x1c, 0x2f, 0xdc, 0x2f, 0x33, 0x60,
		0xaa, 0xfb, 0xd8, 0xec, 0xc2, 0x66, 0xd7, 0xca, 0x10, 0x86, 0xd9, 0x4e, 0x41, 0xb9, 0x54, 0x39,
		0xa8, 0x1c, 0xee, 0xd7, 0x2a, 0x87, 0xd8, 0x2e, 0x60, 0x06, 0xab, 0xf3, 0xb6, 0x8c, 0x5d, 0xaf,
		0xd7, 0xdb, 0xf2, 0x01, 0x6c, 0x99, 0x17, 0x31, 0xd1, 0x7f, 0xf6, 0x06, 0x3a, 0x07, 0x9a, 0x8f,
		0x8c, 0xe8, 0x1c, 0xb8, 0xa2, 0x73, 0xa0, 0xae, 0xe1, 0x56, 0xbc, 0x9a, 0x06, 0x6a, 0x98, 0x4e,
		0x95, 0xd1, 0x86, 0x81, 0x83, 0x6e, 0xd7, 0xf6, 0x9f, 0xa2, 0x4e, 0x94, 0xfa, 0xda, 0x06, 0xce,
		0x5c, 0x04, 0x9a, 0x07, 0x92, 0x9e, 0x18, 0xcd, 0x03, 0xd1, 0x3c, 0x70, 0x7c, 0x21, 0x68, 0x1e,
		0xb8, 0x4d, 0x54, 0x4a, 0x5b, 0xf3, 0x40, 0x3d, 0x1d, 0x69, 0x97, 0x5d, 0x8c, 0xc6, 0x99, 0xa0,
		0x9a, 0xc5, 0x20, 0x6c, 0x34, 0x61, 0xa3, 0x89, 0xb9, 0x33, 0x62, 0xe7, 0x94, 0xb8, 0x39, 0x27,
		0xbd, 0x8a, 0x8a, 0xae, 0x8d, 0x26, 0x5d, 0x4e, 0x2b, 0xbe, 0x80, 0x69, 0x0c, 0xdf, 0xb5, 0x83,
		0xaf, 0xfa, 0x57, 0xeb, 0x14, 0xc2, 0xe6, 0xae, 0x4a, 0xf7, 0x08, 0x37, 0x16, 0xda, 0x30, 0x9b,
		0x69, 0xbb, 0x9c, 0xa6, 0xec, 0xb2, 0x9c, 0xae, 0xcb, 0x6d, 0xaa, 0x2e, 0xdb, 0x69, 0xba, 0x6c,
		0xa7, 0xe8, 0x72, 0x9d, 0x9e, 0xbb, 0xdd, 0xa3, 0x34, 0xd9, 0x4c, 0xc9, 0x9d, 0xab, 0x44, 0x3e,
		0xe4, 0x80, 0x38, 0x13, 0x17, 0xc5, 0x61, 0x42, 0x25, 0x8f, 0x5c, 0x8d, 0xe9, 0x1f, 0x46, 0x23,
		0x95, 0x39, 0xe5, 0x6e, 0x30, 0xe3, 0x36, 0x4b, 0x97, 0xc5, 0xac, 0x70, 0x39, 0xbe, 0x2e, 0x86,
		0xdb, 0xdf, 0x4c, 0xd0, 0x79, 0xde, 0xd4, 0x19, 0xa5, 0x76, 0x98, 0x62, 0xea, 0xfb, 0x65, 0xd8,
		0xba, 0x19, 0x3c, 0x88, 0xcf, 0x55, 0x34, 0x30, 0x7a, 0x36, 0xfb, 0x08, 0x8b, 0xd1, 0xb3, 0x3f,
		0x4b, 0x15, 0x79, 0xd9, 0x56, 0x2f, 0xe8, 0xdc, 0xff, 0xd8, 0xe1, 0x97, 0x3e, 0x32, 0x7e, 0x32,
		0x9a, 0x32, 0x49, 0xf4, 0xad, 0x54, 0x1d, 0xd5, 0x67, 0x4b, 0x53, 0x8f, 0xb5, 0xef, 0x05, 0x32,
		0x99, 0xc3, 0x8c, 0x6d, 0x41, 0x6c, 0x0b, 0xce, 0x5f, 0x0c, 0xb6, 0x05, 0xd7, 0x5c, 0x10, 0xb6,
		0x05, 0xc1, 0xf9, 0x5e, 0x1e, 0xbe, 0xf6, 0x6d, 0xc1, 0x91, 0x03, 0xe1, 0xe0, 0xd1, 0x56, 0x7a,
		0x36, 0xfd, 0x8e, 0x8d, 0x89, 0x83, 0x63, 0xe3, 0xe8, 0x38, 0x39, 0x3c, 0x96, 0x8e, 0x8f, 0x9b,
		0x03, 0x64, 0xeb, 0x08, 0xd9, 0x3a, 0x44, 0xae, 0x8e, 0x91, 0x87, 0x1c, 0xa5, 0x7b, 0x73, 0x50,
		0xb7, 0xc3, 0x9c, 0x11, 0x01, 0x74, 0x26, 0x83, 0xae, 0xc5, 0x40, 0xdd, 0xe2, 0x08, 0x43, 0xa7,
		0xc9, 0xce, 0x79, 0x72, 0x74, 0xa2, 0xac, 0x9d, 0x29, 0x57, 0xa7, 0xca, 0xde, 0xb9, 0xb2, 0x77,
		0xb2, 0xdc, 0x9d, 0x2d, 0x0f, 0xa7, 0xcb, 0xc4, 0xf9, 0xb2, 0x73, 0xc2, 0xf1, 0x05, 0x75, 0x45,
		0xe8, 0x3b, 0x2d, 0x7e, 0xb8, 0x30, 0x05, 0xd3, 0xc9, 0xf5, 0xbd, 0xc5, 0x4e, 0xb9, 0x81, 0x6e,
		0x9a, 0xb3, 0xbb, 0x36, 0xc2, 0x6d, 0x73, 0x77, 0xdf, 0xc6, 0xb8, 0x71, 0x63, 0xdc, 0xb9, 0x29,
		0x6e, 0x9d, 0x97, 0x7b, 0x67, 0xe6, 0xe6, 0xe3, 0x97, 0xc8, 0x26, 0x21, 0x77, 0x3d, 0xea, 0x05,
		0xfd, 0x8e, 0xc5, 0xd2, 0xc9, 0xee, 0xf0, 0x98, 0x23, 0xb4, 0xf6, 0xd2, 0x78, 0xa5, 0xf1, 0x2e,
		0xfe, 0xe1, 0xe9, 0x27, 0x76, 0xb8, 0xa6, 0xf9, 0x1a, 0xc2, 0xf0, 0x96, 0x2e, 0x93, 0x69, 0x1a,
		0xf0, 0xd2, 0x75, 0x32, 0x4e, 0x95, 0x64, 0xee, 0x43, 0xe6, 0x97, 0x8e, 0xfd, 0x1d, 0x4b, 0x47,
		0xf2, 0xd2, 0x61, 0x34, 0x37, 0x29, 0x13, 0xcb, 0xe7, 0x0d, 0xae, 0xea, 0x35, 0x7f, 0x1a, 0x6f,
		0xf0, 0x7c, 0x98, 0xc3, 0x6f, 0x2e, 0xec, 0x05, 0x7c, 0x95, 0xb1, 0xd1, 0xc5, 0x41, 0x16, 0x7b,
		0xcd, 0x65, 0x41, 0x16, 0x4b, 0x13, 0x20, 0x42, 0x16, 0x4b, 0xb1, 0x20, 0x20, 0x8b, 0x49, 0xbe,
		0x50, 0xc8, 0x62, 0xe6, 0x87, 0x34, 0x06, 0xc8, 0x62, 0x5c, 0xea, 0xd6, 0xd7, 0xb9, 0xd8, 0x2a,
		0x04, 0xb1, 0x0d, 0xff, 0x40, 0x10, 0xdb, 0xaa, 0xa8, 0x1e, 0x82, 0x58, 0x56, 0xbd, 0xc7, 0xfc,
		0xd2, 0x81, 0x20, 0x26, 0x7d, 0xe9, 0x94, 0xab, 0x90, 0xc3, 0x32, 0x4a, 0x04, 0xf9, 0x5e, 0x15,
		0xe4, 0x30, 0xce, 0x57, 0xc2, 0x25, 0x7d, 0x8e, 0x49, 0xa1, 0xff, 0xd2, 0x75, 0x71, 0x2f, 0xfc,
		0x5f, 0x2c, 0x76, 0x2e, 0x2c, 0xd4, 0x88, 0x15, 0x38, 0x25, 0xbf, 0xef, 0x70, 0xee, 0x14, 0x10,
		0xfd, 0xc6, 0x55, 0xe7, 0x76, 0xfc, 0xdc, 0xa2, 0x6f, 0x5f, 0xbe, 0xd3, 0xd8, 0x46, 0x80, 0x1f,
		0x6e, 0x70, 0x98, 0xa0, 0xc5, 0x49, 0xc0, 0x67, 0x28, 0xdc, 0x73, 0x1b, 0xea, 0x85, 0x32, 0x93,
		0x0d, 0xcc, 0x08, 0x65, 0x26, 0x9b, 0x18, 0x3a, 0xca, 0x4c, 0xd2, 0x52, 0x2f, 0x94, 0x99, 0x98,
		0xc3, 0x93, 0xd9, 0x09, 0xec, 0x31, 0x6a, 0xb9, 0xc2, 0xee, 0xf8, 0xa2, 0xc3, 0x09, 0xb3, 0xa6,
		0xb5, 0x96, 0x07, 0x8c, 0xae, 0xe9, 0x7a, 0x12, 0x4a, 0xec, 0xed, 0x8d, 0xa9, 0x79, 0x61, 0x44,
		0x1a, 0x40, 0x2c, 0x19, 0x5c, 0x81, 0xee, 0x32, 0xee, 0x3f, 0xc4, 0x13, 0x0f, 0x12, 0x99, 0x3b,
		0x77, 0x82, 0xf0, 0x24, 0x0c, 0x99, 0x54, 0x95, 0x5f, 0x38, 0x5e, 0xdd, 0x15, 0x23, 0x0f, 0x15,
		0xf0, 0x20, 0x90, 0xb9, 0x0b, 0xfb, 0xfb, 0xcc, 0x15, 0x95, 0x0e, 0x2b, 0x95, 0xda, 0x41, 0xa5,
		0x52, 0x3c, 0xd8, 0x3f, 0x28, 0x1e, 0x55, 0xab, 0xa5, 0x5a, 0x89, 0x43, 0x33, 0xea, 0x2b, 0xbf,
		0x2d, 0x7c, 0xd1, 0x7e, 0x37, 0x32, 0x2a, 0x6f, 0xe0, 0xba, 0x5b, 0xbd, 0xb6, 0x98, 0xc9, 0x4b,
		0xc6, 0xcb, 0x4a, 0x1c, 0xba, 0xc9, 0x98, 0x28, 0x24, 0xe5, 0xd0, 0xb5, 0x36, 0xfb, 0xa8, 0x83,
		0xae, 0xb5, 0x09, 0x51, 0x06, 0x0d, 0x6c, 0x7f, 0x85, 0x26, 0x39, 0x0c, 0x3e, 0x37, 0x1f, 0x27,
		0x30, 0xf8, 0xfc, 0xe7, 0xb8, 0x80, 0xf1, 0xe7, 0xf1, 0xf2, 0xcf, 0xec, 0x0c, 0xf4, 0x37, 0x19,
		0x5a, 0xd7, 0xd3, 0xc8, 0xdd, 0x75, 0xbc, 0xaf, 0x56, 0x24, 0xea, 0x58, 0x4e, 0x5b, 0x91, 0x11,
		0xeb, 0x89, 0xd5, 0xf5, 0xc5, 0xe4, 0xac, 0x62, 0x6f, 0x3d, 0x31, 0xb6, 0x2a, 0xab, 0xd6, 0xe4,
		0xa5, 0x38, 0x7a, 0x27, 0x85, 0x1e, 0x89, 0x95, 0x27, 0x52, 0xe3, 0x7e, 0xe8, 0x9d, 0x01, 0xed,
		0x19, 0x88, 0x17, 0xa4, 0xea, 0x85, 0xc8, 0x6d, 0x01, 0x2a, 0x58, 0x7c, 0x6c, 0x16, 0x1d, 0xed,
		0x82, 0xa3, 0x5b, 0x06, 0x84, 0x4b, 0x40, 0x51, 0x57, 0x59, 0xa5, 0xdd, 0x62, 0x15, 0x75, 0x81,
		0x55, 0x96, 0x76, 0xa3, 0x32, 0x9d, 0x46, 0x4b, 0x9a, 0x8c, 0xea, 0xf4, 0x17, 0x6d, 0x69, 0x2d,
		0xda, 0xd2, 0x55, 0x74, 0xa5, 0xa1, 0x98, 0x4d, 0x0d, 0x54, 0x75, 0x1d, 0x8d, 0x46, 0x4f, 0xa8,
		0xb3, 0xfe, 0xd9, 0x81, 0x17, 0xaa, 0x0c, 0x5f, 0x6d, 0xc6, 0xa4, 0xf2, 0x8c, 0x48, 0x1d, 0x19,
		0x8f, 0x5a, 0x33, 0x1a, 0x75, 0x65, 0x2c, 0x6a, 0xcf, 0x48, 0xd4, 0x9e, 0x71, 0xa8, 0x3b, 0xa3,
		0x30, 0x5b, 0xe2, 0xa2, 0xf2, 0x8c, 0xbf, 0x78, 0xd5, 0x3a, 0x6d, 0xe1, 0x85, 0x4e, 0xf8, 0xa4,
		0x36, 0xab, 0x2f, 0xe6, 0xc6, 0x2a, 0x85, 0xbc, 0xb3, 0xc9, 0xad, 0xbe, 0xb3, 0x03, 0x0d, 0x88,
		0x31, 0x7d, 0xe0, 0x57, 0xb7, 0xd7, 0x1f, 0x9a, 0xe7, 0xb7, 0x27, 0xcd, 0xbb, 0xbf, 0xae, 0xeb,
		0xaa, 0x51, 0x23, 0x2a, 0x12, 0x0d, 0xb4, 0x54, 0xf9, 0x6b, 0x1e, 0x18, 0x79, 0xfb, 0xf1, 0xe2,
		0xe2, 0xe4, 0xe6, 0xaf, 0xe6, 0xc9, 0xed, 0xbb, 0x9b, 0xd1, 0xe3, 0xcf, 0x6d, 0xc3, 0xe0, 0x4e,
		0xcd, 0xcf, 0xfc, 0xb2, 0x7e, 0xf7, 0xcf, 0xab, 0x9b, 0x3f, 0xf0, 0xb8, 0xd5, 0x3c, 0xee, 0x93,
		0xdb, 0x66, 0xfd, 0xcf, 0xbb, 0xfa, 0xcd, 0xe5, 0xc9, 0x39, 0x1e, 0xb9, 0x9a, 0x47, 0x7e, 0x73,
		0xf5, 0xf1, 0xae, 0x0e, 0x3c, 0x51, 0xe8, 0x3a, 0x3f, 0x95, 0x9b, 0x27, 0xb7, 0xcd, 0xdb, 0xf7,
		0x57, 0xd7, 0xf5, 0xe6, 0xd5, 0xf5, 0xc9, 0xff, 0xf7, 0xb1, 0x8e, 0xa7, 0xaf, 0xf4, 0xe9, 0x9f,
		0x9f, 0x5d, 0xfe, 0x81, 0xe7, 0xaf, 0x91, 0xc1, 0x9c, 0x5d, 0x37, 0xe1, 0x58, 0xd5, 0xf2, 0x98,
		0xdb, 0xdb, 0x93, 0x26, 0xbc, 0xab, 0x36, 0xbc, 0xbf, 0xa9, 0x9f, 0x70, 0x40, 0x1c, 0xa5, 0x67,
		0x6c, 0x64, 0x4d, 0x49, 0x81, 0xc8, 0xff, 0x53, 0x9b, 0xdf, 0xe2, 0xfd, 0x7f, 0x55, 0xdd, 0x4b,
		0x58, 0x24, 0x00, 0x28, 0x68, 0x32, 0x62, 0x66, 0x06, 0x80, 0x92, 0xcd, 0x27, 0x95, 0x9b, 0x4e,
		0x8a, 0x36, 0x9b, 0xb0, 0xff, 0x2f, 0xed, 0xa4, 0xd8, 0xff, 0xa7, 0x3e, 0x31, 0xf6, 0xff, 0x13,
		0x3c, 0x34, 0x65, 0x9b, 0x43, 0x1a, 0xda, 0x3c, 0xa8, 0x6c, 0xdf, 0xb0, 0xa2, 0x2d, 0xc3, 0xe8,
		0xc9, 0x9a, 0xea, 0x8b, 0xdf, 0x18, 0x64, 0xcb, 0x71, 0xdf, 0x03, 0x3a, 0xb7, 0xab, 0xa6, 0x48,
		0x42, 0x5d, 0x51, 0x84, 0xd6, 0x22, 0x08, 0x35, 0x45, 0x0f, 0x54, 0xc6, 0xa6, 0x28, 0x96, 0x62,
		0x14, 0x43, 0xe5, 0x48, 0x53, 0x73, 0xb5, 0x47, 0x4d, 0x34, 0x18, 0x2d, 0x1f, 0x41, 0xe5, 0x1e,
		0x51, 0xf2, 0xf2, 0xa0, 0x5e, 0x16, 0xfa, 0x97, 0x03, 0xc1, 0x2a, 0xd0, 0x69, 0xfd, 0x72, 0xad,
		0x5e, 0x9e, 0x6d, 0x4a, 0xb4, 0x4b, 0xa2, 0xbc, 0x7f, 0xd2, 0x3c, 0x7f, 0xa2, 0xbc, 0x7e, 0xb2,
		0x38, 0x9e, 0x32, 0x6e, 0x57, 0x12, 0xa7, 0x53, 0xc7, 0xe5, 0xca, 0xe2, 0x70, 0x65, 0x71, 0xb7,
		0xaa, 0x38, 0x9b, 0xb7, 0xbf, 0xa3, 0xca, 0x9b, 0x9f, 0xe4, 0x4c, 0x76, 0x1c, 0x41, 0x17, 0x6b,
		0x2c, 0xe4, 0x67, 0x46, 0xe7, 0xa2, 0x0a, 0xcd, 0x48, 0x65, 0x4a, 0x72, 0x79, 0x52, 0x85, 0x2c,
		0xa9, 0x54, 0x8e, 0x54, 0x25, 0x43, 0x2a, 0x97, 0x1f, 0x95, 0xcb, 0x8e, 0xaa, 0xe5, 0x46, 0xb3,
		0x24, 0x19, 0x72, 0x59, 0xf1, 0x65, 0xd5, 0x04, 0xfd, 0x8e, 0x35, 0xe2, 0xeb, 0x16, 0x39, 0x9a,
		0xcd, 0x11, 0xb4, 0x23, 0xc2, 0x73, 0x4c, 0x9e, 0x1e, 0x6d, 0x1e, 0xb5, 0x42, 0xc9, 0x77, 0xe0,
		0x78, 0xe1, 0x7e, 0x59, 0xa1, 0xe2, 0xab, 0x42, 0xf0, 0x55, 0x3b, 0xd3, 0x4e, 0x6d, 0x6b, 0x16,
		0x0d, 0x35, 0x4f, 0x5a, 0xc6, 0x0d, 0xe8, 0x9a, 0x09, 0xa7, 0x73, 0x4c, 0xd5, 0x50, 0x6d, 0xaf,
		0x9d, 0xad, 0x33, 0xa5, 0x4a, 0xf9, 0xa8, 0x72, 0x54, 0x3b, 0x28, 0x1f, 0x55, 0xb7, 0xc8, 0xa6,
		0x32, 0x92, 0xe6, 0xd5, 0x30, 0x79, 0x2f, 0x57, 0xa1, 0x43, 0x6f, 0xf7, 0xc2, 0x50, 0xb4, 0xad,
		0x7f, 0x0f, 0xec, 0xb6, 0xca, 0x7d, 0xdc, 0x43, 0x35, 0xfb, 0xb8, 0xa1, 0xf0, 0x3d, 0x65, 0x8e,
		0x3d, 0xb7, 0xbb, 0x7b, 0x5f, 0xb4, 0x8e, 0x1a, 0xcf, 0xf7, 0x25, 0xeb, 0xa8, 0x31, 0xfe, 0xb2,
		0x14, 0xfd, 0x6f, 0xfc, 0x75, 0xf9, 0xbe, 0x68, 0x55, 0xa6, 0x5f, 0x57, 0xef, 0x8b, 0x56, 0xb5,
		0x91, 0xff, 0xfc, 0x79, 0x2f, 0xff, 0x63, 0x7f, 0xb8, 0xf9, 0x07, 0x73, 0xa6, 0xaf, 0xa0, 0x37,
		0x66, 0x5d, 0x37, 0x76, 0x81, 0xe4, 0xae, 0x15, 0x5d, 0xbb, 0x40, 0x54, 0x59, 0xa4, 0x3a, 0x76,
		0x80, 0x08, 0x92, 0x44, 0x25, 0x6e, 0xff, 0xbc, 0x61, 0x64, 0xd6, 0x54, 0xe6, 0xac, 0xcb, 0x8c,
		0x73, 0x52, 0xf7, 0xd6, 0x54, 0x1b, 0xae, 0x1c, 0x93, 0x4d, 0x6f, 0x60, 0x12, 0x8c, 0x2b, 0xd7,
		0xed, 0xbb, 0xf2, 0xa6, 0x0f, 0xc6, 0xac, 0x2c, 0x3a, 0xaa, 0x24, 0xd3, 0x97, 0xbb, 0x0f, 0x29,
		0x5d, 0xa8, 0xa7, 0x10, 0xe6, 0x49, 0x85, 0x78, 0x2a, 0xe1, 0x9d, 0x5c, 0x68, 0x27, 0x17, 0xd6,
		0xa9, 0x85, 0x74, 0x5e, 0x2e, 0x45, 0xf6, 0xbe, 0x61, 0xae, 0x35, 0x5d, 0x59, 0x44, 0x59, 0x0e,
		0x93, 0xe3, 0x23, 0xcd, 0x01, 0x69, 0x0e, 0x3a, 0x61, 0x48, 0x19, 0x1c, 0xa9, 0x82, 0x25, 0x33,
		0x02, 0x3a, 0xb2, 0x34, 0x87, 0xd0, 0xb7, 0x3b, 0x1d, 0xa7, 0x65, 0x09, 0xef, 0xd1, 0xf1, 0x84,
		0xf0, 0x1d, 0xef, 0xd1, 0x12, 0x9e, 0xfd, 0xe0, 0x8a, 0x36, 0x7d, 0xde, 0xc3, 0xcf, 0x4e, 0x8e,
		0x44, 0x08, 0xd5, 0x00, 0xa8, 0x14, 0x08, 0x55, 0x01, 0xa2, 0x72, 0x60, 0x54, 0x0e, 0x90, 0xaa,
		0x81, 0x92, 0x56, 0x03, 0x34, 0x3f, 0x11, 0xe2, 0xa1, 0xd7, 0x73, 0x85, 0xed, 0xa9, 0xc8, 0x7d,
		0x28, 0x41, 0x2c, 0xe5, 0xab, 0x2e, 0xe9, 0x54, 0x99, 0xba, 0x7d, 0x37, 0x28, 0x90, 0x44, 0x0c,
		0x1a, 0x44, 0xa7, 0x8b, 0xbe, 0x1b, 0x34, 0x27, 0x8e, 0x15, 0xd9, 0xf2, 0x69, 0xe1, 0xc9, 0xc8,
		0x6c, 0xf9, 0x32, 0xc2, 0x48, 0x84, 0x91, 0x08, 0x23, 0x11, 0x46, 0x22, 0x8c, 0x44, 0x18, 0x89,
		0x30, 0x12, 0x61, 0x24, 0xc2, 0x48, 0x84, 0x91, 0x08, 0x23, 0x95, 0x84, 0x91, 0x19, 0xc9, 0xb9,
		0x89, 0xa2, 0x48, 0xe4, 0xdc, 0xe8, 0x36, 0x67, 0x5d, 0x66, 0x6c, 0x6e, 0xce, 0xcd, 0xc8, 0x70,
		0xb3, 0x94, 0x73, 0x23, 0x57, 0xdf, 0x20, 0xd1, 0x35, 0xc8, 0xb2, 0x6e, 0xca, 0xc8, 0xba, 0x41,
		0xd6, 0x8d, 0x52, 0xba, 0x9d, 0xf1, 0xac, 0x1b, 0xc2, 0x2a, 0x7d, 0xfa, 0xea, 0x7c, 0x22, 0x15,
		0x01, 0xd9, 0x37, 0xba, 0x54, 0x02, 0xc8, 0xa6, 0xd9, 0x0c, 0xed, 0xc8, 0xa2, 0x7e, 0xd5, 0xd5,
		0xf3, 0x94, 0x55, 0xf3, 0xb4, 0xd5, 0xf2, 0x0a, 0x14, 0x17, 0xf2, 0xea, 0x78, 0x05, 0x55, 0xf1,
		0x8a, 0xaa, 0xe1, 0x15, 0x94, 0x38, 0xaa, 0xac, 0x7e, 0x57, 0x3d, 0x32, 0x56, 0x71, 0xb5, 0xbb,
		0x8e, 0x8a, 0x64, 0x05, 0xd5, 0xed, 0x4a, 0xab, 0xda, 0x75, 0x99, 0x88, 0xea, 0x2a, 0x76, 0x2d,
		0xb6, 0x82, 0x5a, 0x55, 0xfa, 0x95, 0xa3, 0xc0, 0x81, 0xaa, 0xa9, 0x46, 0x57, 0x51, 0x85, 0xae,
		0xac, 0xfa, 0x3c, 0x23, 0x55, 0xe7, 0xa6, 0x54, 0x6d, 0x37, 0x20, 0xfd, 0xbf, 0x26, 0xe6, 0xcb,
		0x8e, 0xf4, 0x2f, 0x7b, 0xf3, 0x4a, 0xb1, 0xf6, 0x2f, 0x71, 0xbf, 0x8a, 0x87, 0xf8, 0xff, 0xcd,
		0xf1, 0xc3, 0x81, 0xed, 0x5a, 0xae, 0xe3, 0x7d, 0x25, 0xa8, 0xbc, 0x9d, 0x3f, 0x3c, 0x4a, 0x70,
		0x59, 0xaa, 0x71, 0xd8, 0x0c, 0xd0, 0xa5, 0xb6, 0x65, 0x7c, 0x33, 0x60, 0x76, 0xf5, 0xd3, 0x6d,
		0x07, 0xcc, 0x9d, 0x05, 0xe5, 0xb8, 0xd8, 0x10, 0xd0, 0x09, 0x49, 0xca, 0xa0, 0x49, 0x15, 0x44,
		0xd1, 0x70, 0x7f, 0x63, 0xf2, 0xa8, 0x89, 0xba, 0x08, 0x2c, 0x2d, 0x2a, 0xb2, 0xda, 0x20, 0x42,
		0x18, 0x23, 0x87, 0x33, 0x15, 0xb0, 0xa6, 0x14, 0xde, 0x54, 0xc1, 0x9c, 0x72, 0xb8, 0x53, 0x0e,
		0x7b, 0xaa, 0xe1, 0x8f, 0x4e, 0x02, 0x21, 0x94, 0x18, 0xc9, 0x60, 0x31, 0x3e, 0x81, 0x2f, 0xba,
		0xbd, 0x50, 0x58, 0x7e, 0x6f, 0x10, 0x0a, 0xdf, 0x72, 0xda, 0xea, 0x66, 0xc9, 0x2e, 0x9d, 0x19,
		0x73, 0x65, 0xb9, 0x41, 0xaa, 0x16, 0x68, 0x55, 0x0d, 0xb1, 0xda, 0xa0, 0x56, 0x1b, 0xe4, 0xea,
		0x82, 0x5e, 0x5a, 0x08, 0x26, 0x86, 0xe2, 0xf8, 0xa1, 0xa9, 0x9f, 0x2b, 0xeb, 0xf4, 0xbf, 0x55,
		0x2c, 0xbb, 0xdd, 0xf6, 0x45, 0x10, 0x58, 0x5e, 0xcf, 0xfa, 0xbf, 0x9e, 0x27, 0xd0, 0x9c, 0x38,
		0xe5, 0x09, 0x55, 0x6e, 0x13, 0xed, 0xfe, 0xf7, 0xfd, 0xe7, 0xcf, 0xfd, 0x1f, 0x97, 0xc3, 0xd1,
		0xdf, 0xe7, 0xc3, 0xc6, 0xdf, 0xf3, 0xbf, 0xa9, 0xc2, 0x96, 0xd1, 0x85, 0x7c, 0xfe, 0xbc, 0xd7,
		0xf8, 0x1b, 0x1a, 0x24, 0x67, 0x83, 0x11, 0x66, 0x78, 0x4a, 0xeb, 0xdc, 0x5e, 0xc3, 0xdc, 0x77,
		0x05, 0xd2, 0xe8, 0x7a, 0x47, 0xfd, 0x36, 0xd4, 0xa7, 0xf1, 0xcd, 0x9d, 0x8f, 0xee, 0x74, 0xf6,
		0x1b, 0x92, 0xae, 0x1c, 0x74, 0x86, 0x4e, 0x60, 0xe4, 0xea, 0x22, 0x12, 0xd5, 0x91, 0x08, 0x4a,
		0xdc, 0x21, 0xe2, 0x40, 0xc4, 0xd9, 0x42, 0x97, 0xad, 0xae, 0xc4, 0xdd, 0x15, 0x76, 0xc7, 0x17,
		0x1d, 0x15, 0xb9, 0x62, 0x07, 0xb4, 0xb9, 0x62, 0x11, 0xeb, 0xd8, 0xdb, 0x9b, 0x38, 0xfe, 0xc2,
		0x12, 0x44, 0x6f, 0xb1, 0x83, 0xa4, 0x69, 0x67, 0xb5, 0x64, 0x4b, 0x54, 0x55, 0xea, 0x3b, 0x2a,
		0xf7, 0x33, 0xca, 0x70, 0x85, 0x70, 0x85, 0x70, 0x85, 0x6c, 0x5c, 0x21, 0xf9, 0x7e, 0x86, 0xdd,
		0xfe, 0x5f, 0xbb, 0x25, 0xbc, 0xd6, 0x93, 0x45, 0x0b, 0x93, 0x4b, 0xab, 0x74, 0xf1, 0xc4, 0xd8,
		0xcd, 0xe0, 0x06, 0xa8, 0x5a, 0x80, 0x55, 0x35, 0xc0, 0x6a, 0x03, 0x5a, 0x6d, 0x80, 0xab, 0x0b,
		0x78, 0x69, 0x01, 0x98, 0x18, 0x88, 0xd5, 0xc5, 0x26, 0x4b, 0xab, 0x6e, 0x5c, 0x8e, 0x1b, 0x3e,
		0xd1, 0xc6, 0x29, 0x4b, 0x4c, 0x53, 0x41, 0xb5, 0x57, 0xee, 0x6c, 0x72, 0x6b, 0xef, 0xec, 0x40,
		0xe1, 0x4a, 0x9f, 0x3e, 0xd8, 0xab, 0xdb, 0xeb, 0x0f, 0xcd, 0xcb, 0xfa, 0xd9, 0xef, 0xff, 0x78,
		0x77, 0x75, 0xd3, 0xbc, 0xbd, 0x3b, 0xb9, 0xab, 0xe7, 0x54, 0xd6, 0xd6, 0x05, 0xca, 0x36, 0x6f,
		0x76, 0x94, 0x8e, 0x8d, 0x9e, 0x7b, 0xc8, 0x67, 0x97, 0x67, 0x77, 0xb9, 0x2c, 0x4e, 0x34, 0xd6,
		0xf4, 0x3c, 0x4f, 0xee, 0xee, 0xea, 0x17, 0xd7, 0x78, 0xa4, 0x12, 0x1f, 0xe9, 0x87, 0x8f, 0xe7,
		0xe7, 0x78, 0x9e, 0xf2, 0x9e, 0x67, 0xfd, 0xcf, 0xdb, 0xbb, 0x93, 0x1b, 0x98, 0xa8, 0xc4, 0x47,
		0x7a, 0x7a, 0xf5, 0xcf, 0x4b, 0x3c, 0x4f, 0x79, 0xcf, 0xf3, 0xee, 0x9f, 0x57, 0xcd, 0x7f, 0x9e,
		0xfc, 0x85, 0x47, 0x2a, 0xef, 0x91, 0x9e, 0x5f, 0x9d, 0x9c, 0x9e, 0x5d, 0xfe, 0x8e, 0x47, 0x2a,
		0x13, 0x48, 0xdf, 0xff, 0xe3, 0xe4, 0xf2, 0xf7, 0x7a, 0x2e, 0x63, 0xd3, 0xfb, 0x1b, 0xe8, 0xe7,
		0xa0, 0xde, 0xa6, 0x73, 0x0f, 0x76, 0xeb, 0xeb, 0xa0, 0x6f, 0xb5, 0x45, 0xe0, 0x3c, 0x7a, 0x76,
		0x28, 0xda, 0x93, 0xdd, 0x21, 0x75, 0x92, 0xdf, 0xda, 0x2b, 0x80, 0xf6, 0xb7, 0xd1, 0x89, 0xa0,
		0xfd, 0xc9, 0x36, 0x10, 0x68, 0x7f, 0xd0, 0xfe, 0x7e, 0xfd, 0xd0, 0xd4, 0x6b, 0x7f, 0x6a, 0xfa,
		0xd9, 0x2c, 0x02, 0x25, 0x12, 0x98, 0xf9, 0xf6, 0xb9, 0x51, 0xc3, 0xa1, 0xcc, 0x64, 0x38, 0x6d,
		0x61, 0xb7, 0xad, 0xd0, 0xe9, 0x2a, 0xdc, 0xc5, 0x7c, 0x39, 0x25, 0x38, 0x0c, 0x38, 0x0c, 0x38,
		0x0c, 0x38, 0x0c, 0x38, 0xcc, 0xc2, 0xaa, 0x1b, 0xa1, 0x63, 0xe8, 0xb4, 0xbe, 0x06, 0xb5, 0x8a,
		0x42, 0x0e, 0xa3, 0x82, 0xc2, 0x7c, 0xf4, 0xc6, 0xfd, 0x29, 0x73, 0x9e, 0xed, 0xf5, 0x02, 0xd1,
		0xea, 0x79, 0xed, 0x40, 0xc5, 0x2d, 0xaa, 0xe9, 0xb0, 0xab, 0x5e, 0xfc, 0x52, 0xda, 0x71, 0x57,
		0xb1, 0x67, 0x5d, 0x3a, 0xad, 0xe2, 0x0e, 0xbc, 0xf1, 0x79, 0x35, 0x74, 0x57, 0x55, 0x84, 0x6d,
		0xf3, 0xa6, 0xa4, 0xb0, 0x33, 0x2f, 0x17, 0x53, 0x2a, 0x1d, 0x56, 0x2a, 0xb5, 0x83, 0x4a, 0xa5,
		0x78, 0xb0, 0x7f, 0x50, 0x3c, 0xaa, 0x56, 0x4b, 0xb5, 0x52, 0x75, 0x8b, 0xac, 0xeb, 0x4d, 0x36,
		0xce, 0x82, 0xc8, 0x6e, 0x55, 0x64, 0xa7, 0x4d, 0xb4, 0x86, 0x5a, 0x8d, 0x48, 0x0f, 0x91, 0x1e,
		0x22, 0x3d, 0x44, 0x7a, 0xbf, 0x86, 0x4a, 0xa8, 0xd5, 0xd2, 0x4e, 0x08, 0xb5, 0x3a, 0xeb, 0x9c,
		0xc6, 0xb5, 0x83, 0xd0, 0x12, 0x41, 0x68, 0x3f, 0xb8, 0x4e, 0xf0, 0x45, 0xa8, 0x56, 0xae, 0x57,
		0x9f, 0x1e, 0xdc, 0x06, 0xdc, 0x06, 0xdc, 0x06, 0xdc, 0x06, 0xdc, 0x66, 0x61, 0xd5, 0x41, 0xc5,
		0x96, 0x7d, 0x5e, 0xa8, 0xd8, 0xe6, 0x79, 0xd6, 0xa5, 0xd3, 0x42, 0xc5, 0xa6, 0x35, 0x25, 0xa8,
		0xd8, 0x50, 0xb1, 0x8d, 0x3c, 0x0b, 0x22, 0xbe, 0x65, 0xb3, 0xea, 0xf5, 0x47, 0x46, 0x65, 0xbb,
		0x56, 0xcb, 0xee, 0xdb, 0x0f, 0x8e, 0xeb, 0x84, 0x8e, 0x08, 0xd4, 0x45, 0x7c, 0xab, 0x4f, 0x8f,
		0x88, 0x0f, 0x11, 0x1f, 0x22, 0x3e, 0x44, 0x7c, 0x88, 0xf8, 0x16, 0x56, 0xdd, 0x17, 0xf1, 0xdd,
		0x0a, 0x42, 0xdf, 0xf1, 0x1e, 0x21, 0x66, 0xa7, 0x3c, 0x61, 0x24, 0x49, 0xdb, 0x56, 0xe7, 0xc4,
		0xfa, 0xd0, 0xf8, 0x51, 0x1e, 0xee, 0x1e, 0xcf, 0x7f, 0x9f, 0xff, 0x5b, 0xfe, 0x37, 0x68, 0xd0,
		0x3a, 0x18, 0x49, 0xdf, 0x77, 0x7a, 0xbe, 0x13, 0x3e, 0xa9, 0x23, 0x21, 0xf1, 0x19, 0xc1, 0x3b,
		0xc0, 0x3b, 0xc0, 0x3b, 0xc0, 0x3b, 0xc0, 0x3b, 0x16, 0x56, 0xdd, 0xc0, 0xf1, 0xc2, 0x43, 0x85,
		0x94, 0xa3, 0x0a, 0xad, 0x37, 0xf9, 0x8d, 0x41, 0xeb, 0xa5, 0x3f, 0x2f, 0xb4, 0xde, 0xcc, 0x9a,
		0x52, 0xb9, 0x0a, 0x69, 0xd7, 0xb8, 0xb3, 0x20, 0x90, 0x5a, 0x36, 0x2b, 0x8c, 0x05, 0x44, 0x60,
		0x85, 0xc0, 0x0a, 0x81, 0x15, 0x02, 0x2b, 0xbe, 0x81, 0x15, 0xc6, 0x02, 0x12, 0x9c, 0x10, 0x63,
		0x01, 0x41, 0xaf, 0x54, 0xd0, 0xab, 0xd0, 0xb7, 0xbd, 0xae, 0x13, 0x04, 0x4e, 0xcf, 0xb3, 0xfe,
		0x3d, 0x10, 0x03, 0x61, 0xb9, 0xc2, 0x7b, 0x8c, 0xc6, 0xde, 0x28, 0x23, 0x5a, 0x6b, 0xaf, 0x01,
		0x94, 0x0b, 0x94, 0x0b, 0x94, 0x0b, 0x94, 0x0b, 0x94, 0x6b, 0x61, 0xd5, 0x0d, 0x1c, 0x2f, 0xdc,
		0x2f, 0x2b, 0x24, 0x59, 0x07, 0x10, 0xb3, 0x93, 0xdf, 0x18, 0xc4, 0x6c, 0xfa, 0xf3, 0x42, 0xcc,
		0xce, 0xac, 0x29, 0x55, 0xca, 0x47, 0x95, 0xa3, 0xda, 0x41, 0xf9, 0x08, 0x9a, 0xb6, 0x71, 0x67,
		0x41, 0xd0, 0xb5, 0x6c, 0x56, 0xd1, 0x5c, 0x36, 0xab, 0xf5, 0x65, 0xe4, 0xee, 0x14, 0xa6, 0x29,
		0xcf, 0x9f, 0x16, 0xa1, 0x15, 0x42, 0x2b, 0x84, 0x56, 0x08, 0xad, 0x10, 0x5a, 0x21, 0xb4, 0x42,
		0x68, 0x85, 0xd0, 0x0a, 0xa1, 0x15, 0x42, 0x2b, 0x84, 0x56, 0x08, 0xad, 0x14, 0x84, 0x56, 0x46,
		0x0d, 0x0a, 0x3f, 0xf1, 0xbc, 0x5e, 0x68, 0x8f, 0x4c, 0x95, 0x76, 0x5e, 0x78, 0xd0, 0xfa, 0x22,
		0xba, 0x76, 0xdf, 0x8e, 0x76, 0xde, 0x72, 0x85, 0x5e, 0x5f, 0x78, 0xad, 0x28, 0xb8, 0xb1, 0x3c,
		0x11, 0xfe, 0xa7, 0xe7, 0x7f, 0xb5, 0x1c, 0x2f, 0x08, 0x6d, 0xaf, 0x25, 0x0a, 0x8b, 0x3f, 0x08,
		0x96, 0x7e, 0x52, 0xe8, 0xfb, 0xbd, 0xb0, 0xd7, 0xea, 0xb9, 0x41, 0xfc, 0x55, 0x61, 0xcc, 0x37,
		0x0b, 0xb6, 0x2f, 0xec, 0x20, 0xfa, 0xbb, 0xf0, 0xcd, 0xf1, 0xc3, 0x81, 0xed, 0x5a, 0xae, 0xe3,
		0x7d, 0x0d, 0xe6, 0xbe, 0x2b, 0x50, 0x8f, 0x0e, 0xcf, 0x05, 0xa1, 0x3f, 0x68, 0x85, 0xde, 0x74,
		0x62, 0x6c, 0x7c, 0xb7, 0x97, 0xe3, 0x3b, 0x39, 0x9b, 0xdc, 0x48, 0x73, 0xe1, 0xfb, 0x60, 0xf1,
		0x07, 0xcd, 0xeb, 0xe9, 0x9d, 0xc6, 0x5f, 0x35, 0xaf, 0xa2, 0x3b, 0x6d, 0x9e, 0x8c, 0xee, 0x34,
		0xfa, 0xbb, 0xf9, 0x69, 0x7c, 0x6f, 0xe7, 0xa3, 0x1b, 0x9d, 0xfd, 0xa6, 0x79, 0x1b, 0xdd, 0xe7,
		0x1b, 0x33, 0xcc, 0x5c, 0xee, 0x11, 0x25, 0x2f, 0x98, 0x51, 0x40, 0xa7, 0x20, 0x6d, 0x2e, 0x77,
		0xee, 0x04, 0xe1, 0x49, 0x18, 0xd2, 0x34, 0x2a, 0x1d, 0xd1, 0xc9, 0xba, 0x2b, 0x46, 0x51, 0x5a,
		0x40, 0xe3, 0x95, 0x47, 0x2c, 0x63, 0xe6, 0x0c, 0x6a, 0x7a, 0x32, 0xe4, 0xae, 0xfc, 0xb6, 0xf0,
		0x45, 0xfb, 0xdd, 0xe8, 0x0d, 0x79, 0x03, 0xd7, 0x65, 0x6d, 0x48, 0xc4, 0x88, 0xcb, 0x0b, 0x69,
		0x09, 0x30, 0x96, 0x09, 0xb6, 0xca, 0x45, 0x55, 0x79, 0xd8, 0x27, 0xe7, 0x48, 0x92, 0x8c, 0x9e,
		0xca, 0xd8, 0xb5, 0x1b, 0xb9, 0x44, 0xbb, 0xd6, 0x68, 0xcf, 0x72, 0x6c, 0x38, 0xbd, 0xc5, 0xa5,
		0x3b, 0x42, 0x4a, 0x5b, 0x9d, 0x7a, 0x76, 0xa7, 0x2d, 0xbc, 0xd0, 0xe9, 0x38, 0xa9, 0x3b, 0x75,
		0xcb, 0xf5, 0xe1, 0xf2, 0x7d, 0xb6, 0x12, 0x1f, 0x2d, 0xd7, 0x27, 0xa7, 0x7d, 0xc5, 0x92, 0x61,
		0x48, 0x03, 0xfc, 0x48, 0x00, 0x1c, 0xb5, 0x40, 0x93, 0x0e, 0x5b, 0x92, 0x23, 0x42, 0xb2, 0x4f,
		0x26, 0x34, 0x30, 0x59, 0x86, 0xa5, 0xd6, 0xa0, 0x52, 0xd8, 0x92, 0x32, 0x1b, 0x4a, 0x66, 0x3e,
		0x9b, 0xbf, 0xfc, 0x04, 0x2f, 0x3e, 0xf7, 0xe8, 0xf6, 0x1e, 0x6c, 0x37, 0xf1, 0x0b, 0x8f, 0xb7,
		0x62, 0x26, 0xc7, 0x49, 0x68, 0x7a, 0xd3, 0xf2, 0x80, 0x84, 0x1f, 0x4f, 0xbb, 0xb5, 0x2c, 0x63,
		0xcb, 0x58, 0xea, 0x56, 0xb0, 0xac, 0x2d, 0x5e, 0xe9, 0x5b, 0xb7, 0xd2, 0xb7, 0x64, 0x65, 0x6f,
		0xb5, 0xaa, 0x85, 0xcc, 0x53, 0x27, 0x1d, 0x31, 0xca, 0xb5, 0xa6, 0x96, 0x9b, 0xf2, 0x3d, 0x4f,
		0x8d, 0x6f, 0x72, 0xbc, 0xb4, 0x2c, 0x32, 0xd5, 0x72, 0x94, 0xb6, 0x2c, 0x65, 0x2e, 0x4f, 0x92,
		0x65, 0x2a, 0x7b, 0xb9, 0x92, 0x2d, 0x5b, 0xb2, 0xe5, 0x4b, 0xb5, 0x8c, 0x79, 0x44, 0x53, 0x69,
		0x97, 0x77, 0x7c, 0xa0, 0x2f, 0x4e, 0x5b, 0x58, 0xa1, 0x6f, 0x7b, 0x81, 0x13, 0x5a, 0x3d, 0xcf,
		0x7d, 0x9a, 0x52, 0x21, 0x79, 0x39, 0x65, 0x2f, 0x3d, 0xdb, 0xd6, 0x9f, 0x4b, 0xd2, 0xbb, 0x96,
		0xbb, 0x11, 0x2a, 0x3d, 0x31, 0x8c, 0x22, 0x01, 0x8c, 0x34, 0xd1, 0x8b, 0x2a, 0xa1, 0x8b, 0x3c,
		0x71, 0x8b, 0x3c, 0x41, 0x8b, 0x3a, 0x11, 0x8b, 0x97, 0xc0, 0x28, 0x3d, 0x81, 0x2a, 0xb6, 0xda,
		0x87, 0x5e, 0xcf, 0x15, 0xb6, 0x27, 0xd3, 0x66, 0xa7, 0x1c, 0xa1, 0xc4, 0x45, 0x77, 0x93, 0xe0,
		0xc6, 0x9d, 0xc7, 0xbe, 0x15, 0x7c, 0xe9, 0xf9, 0x61, 0x6b, 0x10, 0x12, 0x20, 0xf3, 0xfc, 0xe1,
		0x01, 0xc6, 0x00, 0x63, 0x80, 0x31, 0xc0, 0x18, 0x60, 0xbc, 0xfa, 0x9e, 0xdc, 0xde, 0xa3, 0x65,
		0xb7, 0xff, 0xd7, 0x6e, 0x09, 0xaf, 0xf5, 0x24, 0xbd, 0x04, 0xe3, 0x65, 0x06, 0xd8, 0xca, 0xd3,
		0x00, 0x9c, 0x01, 0xce, 0x00, 0x67, 0x80, 0x33, 0xc0, 0x79, 0xf5, 0x3d, 0xc9, 0x6f, 0xf2, 0xf6,
		0xd2, 0x63, 0x44, 0x72, 0x3a, 0x1a, 0x40, 0x18, 0x20, 0x0c, 0x10, 0x36, 0x0a, 0x84, 0x69, 0x86,
		0x28, 0x53, 0x34, 0x21, 0x23, 0x6b, 0x36, 0x66, 0xe8, 0xf0, 0xe3, 0x46, 0x86, 0x7c, 0x5c, 0x30,
		0xe8, 0x76, 0x6d, 0xff, 0x69, 0x9c, 0x1f, 0x6d, 0xb5, 0x7a, 0x41, 0x68, 0x75, 0x7b, 0x6d, 0x21,
		0xdf, 0xe3, 0xad, 0x3b, 0x91, 0xa4, 0x75, 0x7a, 0x2a, 0x3a, 0xf6, 0xc0, 0x8d, 0x30, 0xe9, 0xe6,
		0xc3, 0xfb, 0xf2, 0x7e, 0xf9, 0xb0, 0xf9, 0xfe, 0xea, 0xe2, 0xfa, 0xe4, 0xee, 0xec, 0xdd, 0x79,
		0x1d, 0x4e, 0x16, 0x4e, 0x16, 0x4e, 0x76, 0x1b, 0x9d, 0xac, 0xf0, 0x06, 0x5d, 0xe1, 0x8f, 0xf3,
		0xbd, 0x08, 0x9c, 0x6c, 0x45, 0xe2, 0x31, 0xeb, 0xde, 0xa0, 0x3b, 0x7a, 0x08, 0x43, 0xe4, 0xf8,
		0x1a, 0x9c, 0x00, 0x3a, 0x4e, 0x11, 0x2b, 0x48, 0x49, 0x51, 0xd9, 0x51, 0x94, 0xbf, 0xf7, 0x7b,
		0x74, 0xcd, 0xcd, 0x89, 0x3b, 0xd2, 0x95, 0x06, 0x9a, 0x22, 0x91, 0xec, 0xd1, 0xb7, 0x5b, 0xa2,
		0x33, 0x70, 0x2d, 0x5f, 0x04, 0xa1, 0xed, 0x87, 0xf2, 0x52, 0x8d, 0x96, 0x8e, 0x8c, 0xa4, 0x23,
		0xa5, 0x4c, 0x01, 0x49, 0x47, 0x48, 0x3a, 0xfa, 0xe9, 0x81, 0x24, 0xe5, 0x16, 0x2e, 0x19, 0xb1,
		0x34, 0x00, 0x97, 0xb8, 0xec, 0x11, 0x38, 0x20, 0x70, 0x40, 0xe0, 0x40, 0x01, 0x23, 0xf1, 0x01,
		0x85, 0x67, 0x3f, 0xb8, 0x42, 0xfe, 0x54, 0x97, 0x99, 0x80, 0x64, 0x7c, 0x02, 0xd9, 0xc5, 0xee,
		0x24, 0x6d, 0x5b, 0xc8, 0xda, 0xd9, 0x51, 0xb6, 0xaf, 0x53, 0xd2, 0xae, 0x8e, 0xba, 0x3d, 0x9d,
		0xb2, 0x76, 0x74, 0xca, 0xda, 0xcf, 0xa9, 0x6a, 0x37, 0xc7, 0xbb, 0x29, 0x05, 0x59, 0xfb, 0x38,
		0xc2, 0xbd, 0xdd, 0x25, 0x16, 0x53, 0xe2, 0x5a, 0x49, 0x2f, 0x91, 0x60, 0x7c, 0x11, 0x6e, 0x5f,
		0xf8, 0x51, 0x6a, 0x39, 0x9d, 0x33, 0x98, 0x3d, 0x09, 0x1c, 0x02, 0x1c, 0x02, 0x1c, 0x02, 0x1c,
		0x02, 0x1c, 0x02, 0x5a, 0xab, 0x6c, 0x76, 0x5c, 0xc5, 0xd2, 0xf6, 0xa2, 0x24, 0x5a, 0x90, 0x2a,
		0x95, 0xec, 0xa8, 0xd5, 0xbc, 0x7f, 0x9f, 0xdc, 0xcc, 0xcd, 0xf8, 0x5e, 0xa4, 0x68, 0xe0, 0xf2,
		0xac, 0x4f, 0xca, 0x06, 0x7f, 0xd4, 0x51, 0x4e, 0xfe, 0x76, 0xbe, 0xc4, 0x86, 0x7c, 0x64, 0xf2,
		0x58, 0x19, 0xf2, 0x18, 0xe4, 0x31, 0xc8, 0x63, 0x90, 0xc7, 0x10, 0x0d, 0x21, 0x1a, 0x42, 0x34,
		0x84, 0x68, 0x08, 0xf2, 0x18, 0xe4, 0x31, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0x38,
		0x04, 0xc8, 0x63, 0x2a, 0xe4, 0x31, 0xd9, 0xa3, 0x0b, 0x34, 0xaa, 0x63, 0x12, 0xa7, 0x13, 0x20,
		0x3f, 0x99, 0x95, 0x95, 0x9a, 0x95, 0xa9, 0xbc, 0x60, 0x97, 0x26, 0xa6, 0x2c, 0x3b, 0x5e, 0x28,
		0x7c, 0xcb, 0xf6, 0x85, 0x6d, 0xf5, 0xfd, 0x5e, 0xdf, 0x7e, 0x8c, 0x6c, 0xc9, 0xea, 0xf7, 0x5c,
		0xa7, 0xe5, 0x48, 0x68, 0x01, 0xf1, 0xd2, 0x8f, 0xe7, 0x17, 0x27, 0x42, 0x42, 0xb3, 0x52, 0x62,
		0x8c, 0x84, 0x66, 0x24, 0x34, 0x27, 0x06, 0x86, 0x27, 0x82, 0x76, 0x5d, 0x3f, 0x3d, 0x1d, 0xd2,
		0x9f, 0x59, 0x46, 0xd5, 0xd8, 0xdf, 0xd1, 0x15, 0x35, 0x67, 0x7c, 0x7f, 0x47, 0x72, 0x35, 0xc5,
		0xd2, 0x62, 0x90, 0x9e, 0x2a, 0x40, 0x00, 0x2f, 0x10, 0xf3, 0x20, 0xe6, 0x41, 0xcc, 0xa3, 0x10,
		0xf3, 0x64, 0xc3, 0x55, 0x7c, 0xe0, 0xf6, 0xb8, 0xf9, 0x83, 0xe5, 0x74, 0xfb, 0x3d, 0x3f, 0x94,
		0xcd, 0x95, 0xd6, 0xae, 0xb1, 0xd5, 0xa7, 0x25, 0xb2, 0xa0, 0xd9, 0x06, 0x17, 0xf5, 0xff, 0x57,
		0x7f, 0x7f, 0xd7, 0xbc, 0xb9, 0xfa, 0x78, 0x57, 0xa7, 0x3a, 0x1d, 0xed, 0x1c, 0x60, 0x32, 0x6c,
		0x55, 0x81, 0xb1, 0xab, 0xb0, 0xd6, 0xef, 0xf7, 0x5c, 0xca, 0xf1, 0xa4, 0xc4, 0x88, 0xab, 0x1c,
		0x79, 0x95, 0x23, 0xf0, 0x3a, 0x24, 0x8e, 0x5e, 0x1c, 0x46, 0x0b, 0xef, 0x90, 0x6e, 0xb6, 0xac,
		0x45, 0xce, 0x31, 0x64, 0x5a, 0xe1, 0xe8, 0xc4, 0x84, 0xab, 0x87, 0xa0, 0x5d, 0xc7, 0xd2, 0x39,
		0xe4, 0xb6, 0xef, 0xa0, 0x37, 0x24, 0x02, 0x23, 0xca, 0xb5, 0x83, 0x30, 0x92, 0x12, 0x14, 0xb8,
		0xde, 0xe9, 0x99, 0xe0, 0xfe, 0x38, 0xb8, 0x3f, 0xb2, 0x50, 0x03, 0x0e, 0xd0, 0xd4, 0x50, 0x04,
		0x2e, 0xf0, 0xe7, 0xab, 0xc6, 0x15, 0x76, 0xc7, 0x17, 0x1d, 0x15, 0x6e, 0xef, 0x80, 0xf0, 0x1c,
		0xd7, 0x93, 0x1d, 0xcb, 0xbd, 0xbd, 0xc2, 0xec, 0x7f, 0x33, 0x63, 0x78, 0x67, 0xc6, 0xb4, 0x6e,
		0xb1, 0x6b, 0x54, 0x1c, 0x9a, 0x2a, 0x09, 0x49, 0xe1, 0x24, 0x11, 0x23, 0x22, 0x46, 0x84, 0x83,
		0x84, 0x83, 0x7c, 0x85, 0x83, 0x2c, 0x4c, 0x0c, 0xe9, 0xd8, 0xef, 0x0d, 0x42, 0xc7, 0x7b, 0x9c,
		0x60, 0x73, 0xfc, 0xe3, 0x49, 0x28, 0xdc, 0x16, 0x1d, 0xc7, 0x73, 0x42, 0xa7, 0xe7, 0x05, 0xeb,
		0xff, 0x29, 0xfe, 0x97, 0x28, 0xd9, 0xc6, 0x28, 0xfb, 0x91, 0x3a, 0x6a, 0x7d, 0xed, 0x59, 0xa4,
		0x8f, 0x60, 0x5f, 0x7f, 0x26, 0x05, 0xa3, 0xd9, 0xd7, 0x9e, 0x7c, 0x76, 0x64, 0x3b, 0x31, 0xe8,
		0x4f, 0x57, 0xe5, 0x20, 0x48, 0x3d, 0x6e, 0x9f, 0x8b, 0x23, 0x5b, 0x74, 0x66, 0xbd, 0xf1, 0xd3,
		0xb4, 0x1e, 0x9e, 0x88, 0x6f, 0x50, 0x8b, 0x53, 0x5b, 0x72, 0x6c, 0xd1, 0x9b, 0x24, 0x3d, 0xe5,
		0xd0, 0x34, 0x9f, 0x69, 0x44, 0x24, 0x11, 0xf8, 0x2d, 0x45, 0x22, 0x5b, 0x7c, 0x26, 0xc4, 0x0f,
		0x10, 0xd9, 0x10, 0x41, 0x40, 0x64, 0x43, 0x0c, 0x01, 0x91, 0x8d, 0xe7, 0x11, 0x65, 0xa7, 0xaa,
		0x10, 0x15, 0x23, 0xbd, 0x38, 0x71, 0xb5, 0xe5, 0x1e, 0xbf, 0x28, 0x02, 0xf8, 0xe9, 0xbf, 0x3f,
		0x15, 0x48, 0xb2, 0xf6, 0x76, 0xd4, 0x96, 0x8c, 0x9c, 0x8d, 0xee, 0xf0, 0xc4, 0x17, 0xf6, 0xf5,
		0xcb, 0xfd, 0x5d, 0x4f, 0x6e, 0x7f, 0xfd, 0x3f, 0x3e, 0x49, 0x6d, 0x08, 0x24, 0xdf, 0xf4, 0x65,
		0x96, 0x74, 0x93, 0x6d, 0xde, 0x52, 0x6f, 0xda, 0xa2, 0x98, 0x5b, 0x31, 0x5f, 0x44, 0xfe, 0x27,
		0x57, 0x3e, 0xb8, 0xed, 0xc5, 0xdc, 0x74, 0x7c, 0x8f, 0x92, 0xe7, 0xcd, 0xf2, 0xbb, 0xb1, 0xff,
		0x2b, 0xc4, 0x50, 0xb9, 0x05, 0x8e, 0x87, 0x4c, 0xd0, 0xa0, 0x16, 0x32, 0xe0, 0x78, 0xe0, 0x78,
		0xe0, 0x78, 0xe0, 0x78, 0xb2, 0xe4, 0x78, 0x62, 0xa8, 0xdc, 0x06, 0xc7, 0x23, 0xb5, 0x35, 0xea,
		0xb2, 0xd7, 0x91, 0xdc, 0xf8, 0x63, 0x47, 0x45, 0xad, 0x5b, 0x19, 0x2e, 0x07, 0x2e, 0x07, 0x2e,
		0x27, 0xf5, 0x43, 0x40, 0xad, 0x5b, 0x9a, 0x87, 0x87, 0x5a, 0x37, 0x26, 0x18, 0xbb, 0x0a, 0x6b,
		0x91, 0xc7, 0xc8, 0x1c, 0x81, 0xd7, 0x21, 0x31, 0xf2, 0x18, 0x15, 0x84, 0x04, 0x6b, 0x91, 0x13,
		0xb5, 0x6e, 0xda, 0x0c, 0x09, 0xb5, 0x6e, 0x70, 0x7f, 0xfc, 0x43, 0x0d, 0x38, 0x40, 0x53, 0x43,
		0x11, 0xb8, 0x40, 0x5d, 0xea, 0x98, 0x0a, 0x95, 0x6c, 0x95, 0x5a, 0x86, 0x5a, 0xb7, 0x9f, 0x3c,
		0x27, 0xd4, 0xba, 0x21, 0x46, 0x44, 0x8c, 0x88, 0x18, 0x11, 0x0e, 0x72, 0x4b, 0x1d, 0x24, 0x6a,
		0xdd, 0x76, 0x50, 0xeb, 0x26, 0xf9, 0xe4, 0xa8, 0x75, 0x93, 0xe9, 0xcc, 0x50, 0xeb, 0x66, 0x84,
		0x67, 0xdb, 0x41, 0xad, 0x1b, 0x6a, 0xdd, 0x20, 0xb2, 0x21, 0x82, 0x80, 0xc8, 0x86, 0x18, 0x02,
		0x22, 0x1b, 0x6a, 0xdd, 0x76, 0x50, 0xeb, 0x46, 0x5b, 0xeb, 0x46, 0x91, 0xb4, 0xb7, 0x63, 0x46,
		0xa9, 0x9b, 0xc4, 0xe9, 0x5e, 0xf2, 0x0d, 0x9f, 0xd7, 0xe0, 0x85, 0x3f, 0xc4, 0xd3, 0x2c, 0x69,
		0xdc, 0x91, 0xbc, 0x45, 0x4b, 0xa3, 0x1c, 0xd0, 0x29, 0x05, 0x4a, 0x95, 0x81, 0x39, 0x25, 0xc0,
		0x1b, 0xb8, 0x2e, 0xa6, 0x18, 0x32, 0x03, 0x51, 0x33, 0x87, 0x1d, 0x26, 0x84, 0x4d, 0x8c, 0x43,
		0xcc, 0xc0, 0x38, 0x44, 0xda, 0x21, 0x79, 0x8c, 0x0c, 0xd9, 0xc4, 0x51, 0x89, 0xdd, 0xbe, 0x2b,
		0x71, 0x1e, 0x62, 0x74, 0x34, 0x0c, 0x3d, 0x54, 0x2a, 0xc2, 0x60, 0xe8, 0x21, 0x86, 0x1e, 0xfe,
		0xf4, 0x40, 0x92, 0xe7, 0x8e, 0xd1, 0xcc, 0x1b, 0xc3, 0x18, 0x43, 0x8c, 0x31, 0x54, 0xa4, 0xb1,
		0x62, 0x8c, 0x61, 0xaa, 0x03, 0x86, 0xbe, 0xdd, 0xe9, 0x38, 0x2d, 0x4b, 0x78, 0x8f, 0x8e, 0x27,
		0x84, 0xef, 0x78, 0x8f, 0x96, 0xf8, 0x1e, 0x0a, 0x2f, 0x70, 0x7a, 0x5e, 0x40, 0x57, 0xf1, 0xf9,
		0x8b, 0xf3, 0xa2, 0xfb, 0x00, 0x4a, 0x41, 0x75, 0xc2, 0x96, 0x32, 0xf8, 0x52, 0x05, 0x63, 0x66,
		0xe8, 0xeb, 0xf4, 0xdd, 0x07, 0x1e, 0x7a, 0x3d, 0x57, 0xd8, 0x1e, 0x65, 0xf7, 0x81, 0x12, 0x74,
		0xe1, 0xed, 0x51, 0xff, 0x46, 0x31, 0xb2, 0xfc, 0xae, 0x7f, 0x0a, 0x25, 0x90, 0x8b, 0xbe, 0x1b,
		0x48, 0x6d, 0xdd, 0x27, 0x41, 0x9f, 0x93, 0x10, 0x46, 0x3b, 0x8f, 0x7d, 0xcb, 0x6d, 0xf7, 0xad,
		0xe0, 0xc9, 0x6b, 0x11, 0x8c, 0x82, 0x9f, 0x3d, 0x3a, 0x42, 0x26, 0x84, 0x4c, 0x08, 0x99, 0xb6,
		0x27, 0x64, 0xc2, 0xe4, 0x77, 0x84, 0x40, 0x08, 0x81, 0x10, 0x02, 0xd1, 0x84, 0x40, 0x64, 0xdd,
		0x70, 0x84, 0x67, 0x3f, 0xb8, 0xa2, 0x4d, 0x9f, 0x1f, 0x3c, 0x3d, 0x11, 0xd2, 0x83, 0x55, 0x03,
		0x9b, 0x52, 0x80, 0x53, 0x05, 0x74, 0xca, 0x01, 0x4f, 0x39, 0xf0, 0xa9, 0x06, 0x40, 0x1a, 0x20,
		0x24, 0x02, 0x44, 0x7a, 0x6d, 0x48, 0xa1, 0x46, 0x44, 0xac, 0x15, 0xd1, 0xbd, 0x58, 0x8a, 0x8a,
		0x95, 0x7e, 0x2f, 0x08, 0xad, 0x40, 0x04, 0x81, 0xd3, 0xf3, 0xac, 0x41, 0xdf, 0x6a, 0x0b, 0xd7,
		0x56, 0x50, 0x03, 0xbf, 0xfa, 0xb4, 0x70, 0x56, 0x70, 0x56, 0x70, 0x56, 0x70, 0x56, 0xc6, 0x39,
		0xab, 0x81, 0xe3, 0x85, 0xfb, 0x65, 0x05, 0xbe, 0x8a, 0xb2, 0x92, 0xe5, 0xc6, 0xf6, 0x1e, 0x47,
		0x77, 0x73, 0x4f, 0x6a, 0xb2, 0x0a, 0xea, 0x86, 0x2f, 0x1c, 0x4f, 0x49, 0x81, 0xb2, 0x02, 0xe7,
		0xb2, 0x74, 0xba, 0x4f, 0xb6, 0x3b, 0x10, 0x0a, 0xcf, 0xf7, 0xc1, 0xb7, 0x5b, 0xa1, 0xd3, 0xf3,
		0x4e, 0x9d, 0x47, 0x67, 0x9c, 0x86, 0x4f, 0x7e, 0xde, 0xa1, 0x82, 0x62, 0xeb, 0x0b, 0xfb, 0x7b,
		0xe6, 0x4d, 0xa4, 0x52, 0x3e, 0xaa, 0x1c, 0xd5, 0x0e, 0xca, 0x47, 0xd5, 0x0c, 0xdb, 0x8a, 0xa1,
		0x45, 0xf2, 0x0d, 0x54, 0x02, 0xca, 0x60, 0x3f, 0xd9, 0xaa, 0x04, 0x8c, 0xb6, 0xb1, 0x67, 0x77,
		0x35, 0x33, 0x31, 0xc9, 0x2e, 0xda, 0xdb, 0x3e, 0x7b, 0xec, 0x9f, 0xb7, 0xfb, 0xb7, 0x4f, 0x5e,
		0x6b, 0x8b, 0x26, 0xd4, 0x61, 0x5e, 0xc3, 0x72, 0x8c, 0x8c, 0x79, 0x0d, 0x6a, 0x63, 0x61, 0xec,
		0x50, 0x65, 0xd3, 0xf5, 0x61, 0x87, 0x4a, 0x2b, 0xe9, 0x86, 0xe8, 0xc7, 0x0d, 0xe8, 0x94, 0x03,
		0x9e, 0x72, 0xe0, 0x53, 0x0d, 0x80, 0xb4, 0x51, 0x10, 0x76, 0xa8, 0x36, 0x60, 0x63, 0xd8, 0xa1,
		0xc2, 0x0e, 0x15, 0x9c, 0x15, 0x9c, 0x15, 0x9c, 0x15, 0x9c, 0x55, 0xb2, 0x55, 0x83, 0x1d, 0xaa,
		0x57, 0xff, 0xc1, 0x0e, 0x55, 0xaa, 0xd3, 0x61, 0x87, 0x4a, 0x8e, 0x89, 0x60, 0x87, 0x2a, 0x1b,
		0xb6, 0x82, 0x1d, 0x2a, 0xda, 0x90, 0x03, 0x3b, 0x54, 0x3a, 0x77, 0xa8, 0x32, 0xd0, 0x7f, 0x72,
		0x71, 0x83, 0x0a, 0x7d, 0x25, 0x75, 0x9b, 0xb7, 0x76, 0xb3, 0x36, 0xb8, 0x8a, 0xf8, 0xc5, 0x90,
		0xb3, 0x54, 0x49, 0x2c, 0x77, 0x2b, 0x95, 0x64, 0x0b, 0x95, 0xac, 0x76, 0xb8, 0x8c, 0xda, 0x61,
		0xd4, 0x0e, 0x2b, 0x15, 0x55, 0xd0, 0x6e, 0x89, 0x44, 0x83, 0x41, 0xbb, 0x25, 0xc5, 0xf0, 0xa4,
		0x04, 0xa6, 0xa8, 0xe1, 0x4a, 0x19, 0x6c, 0x29, 0x83, 0x2f, 0x55, 0x30, 0x66, 0x46, 0x88, 0x88,
		0x76, 0x4b, 0x08, 0x97, 0x0c, 0x0c, 0x97, 0x64, 0x07, 0xfe, 0xaa, 0xe3, 0x24, 0x89, 0x51, 0x3e,
		0x9a, 0xa1, 0x6b, 0x37, 0x47, 0xb3, 0x3a, 0x9e, 0x8f, 0x0c, 0xd0, 0xc4, 0xce, 0xe6, 0x72, 0xa2,
		0x70, 0xa9, 0xd1, 0xb7, 0xf4, 0xde, 0xe6, 0x65, 0xf4, 0x36, 0xe7, 0x41, 0x4b, 0xd1, 0xdb, 0x5c,
		0x4b, 0x94, 0x9c, 0xfb, 0xe2, 0xb4, 0x85, 0x15, 0xfa, 0xb6, 0x17, 0x38, 0xa1, 0xd5, 0xf3, 0xdc,
		0xa7, 0x29, 0x6a, 0x07, 0xf2, 0xf5, 0xb7, 0x9f, 0x9c, 0x4b, 0xae, 0x28, 0x57, 0x44, 0x43, 0x3f,
		0x88, 0x72, 0x10, 0xe5, 0xe4, 0x85, 0x32, 0xd2, 0xa3, 0x56, 0xc2, 0x68, 0x55, 0x72, 0x94, 0xca,
		0xa7, 0xb7, 0x6a, 0xf0, 0xa5, 0xe7, 0x87, 0xad, 0x41, 0x18, 0xd0, 0x34, 0x57, 0x7d, 0x39, 0x3c,
		0xc0, 0x18, 0x60, 0x0c, 0x30, 0x06, 0x18, 0x03, 0x8c, 0x57, 0xdf, 0x93, 0xdb, 0x7b, 0xb4, 0xec,
		0xf6, 0xff, 0xda, 0x2d, 0xe1, 0xb5, 0x9e, 0xac, 0xd6, 0x17, 0xdb, 0x7b, 0x14, 0x04, 0xa0, 0xbc,
		0xfa, 0x34, 0x00, 0x67, 0x80, 0x33, 0xc0, 0x19, 0xe0, 0x0c, 0x70, 0x5e, 0x7d, 0x4f, 0x7e, 0x6f,
		0x10, 0x0a, 0xdf, 0x72, 0xda, 0xf2, 0x01, 0xf9, 0xe5, 0xd0, 0x00, 0x61, 0x80, 0x30, 0x40, 0x78,
		0x0b, 0x41, 0xb8, 0xdd, 0x0b, 0x43, 0xd1, 0xb6, 0xfe, 0x3d, 0xb0, 0xdb, 0x14, 0x40, 0x7c, 0x28,
		0xf1, 0x98, 0xd7, 0x76, 0x18, 0x0a, 0xdf, 0x93, 0x5e, 0x40, 0x95, 0xdb, 0xdd, 0xbd, 0x2f, 0x5a,
		0x47, 0x8d, 0xe7, 0xfb, 0x92, 0x75, 0xd4, 0x18, 0x7f, 0x59, 0x8a, 0xfe, 0x37, 0xfe, 0xba, 0x7c,
		0x5f, 0xb4, 0x2a, 0xd3, 0xaf, 0xab, 0xf7, 0x45, 0xab, 0xda, 0xc8, 0x7f, 0xfe, 0xbc, 0x97, 0xff,
		0xb1, 0x3f, 0xdc, 0xfc, 0x83, 0xf2, 0x2c, 0xb4, 0x91, 0xa5, 0xfc, 0xd8, 0x41, 0xb7, 0x6b, 0xfb,
		0x4f, 0x56, 0xe4, 0x90, 0xac, 0x56, 0x2f, 0x08, 0xad, 0x6e, 0xaf, 0x4d, 0x91, 0x31, 0xbb, 0xe6,
		0x44, 0xb2, 0x72, 0xfd, 0x44, 0xc7, 0x1e, 0xb8, 0x11, 0x26, 0xdd, 0x7c, 0x78, 0x5f, 0xde, 0x2f,
		0x1f, 0x36, 0xdf, 0x5f, 0x5d, 0x5c, 0x9f, 0xdc, 0x9d, 0xbd, 0x3b, 0xaf, 0xc3, 0xc9, 0xc2, 0xc9,
		0xc2, 0xc9, 0x6e, 0xa3, 0x93, 0x15, 0xde, 0xa0, 0x2b, 0xfc, 0x71, 0x8a, 0x0a, 0x81, 0x93, 0xad,
		0x48, 0x3c, 0x66, 0xdd, 0x1b, 0x74, 0x47, 0x0f, 0x61, 0x88, 0xd4, 0x22, 0xf3, 0x53, 0x8b, 0x64,
		0x25, 0xb9, 0x29, 0xcc, 0x2d, 0x92, 0x90, 0xd7, 0xa6, 0x27, 0xb9, 0x28, 0x74, 0xba, 0xc2, 0x0f,
		0xe4, 0x65, 0x17, 0x4d, 0x8e, 0xc7, 0x2c, 0xbd, 0xa8, 0x88, 0xf4, 0x22, 0x1e, 0x1c, 0x00, 0xe9,
		0x45, 0x9b, 0x11, 0x73, 0x59, 0xe9, 0x45, 0x6e, 0x60, 0x5b, 0x8f, 0xc2, 0x9b, 0x7a, 0x73, 0xf9,
		0x7b, 0x24, 0xf3, 0xc7, 0xc7, 0x5c, 0x50, 0x84, 0x0c, 0x08, 0x19, 0xd8, 0x86, 0x0c, 0x98, 0x0b,
		0xba, 0x83, 0xb9, 0xa0, 0xea, 0x60, 0x87, 0x1a, 0x7e, 0x94, 0xc1, 0x90, 0x32, 0x38, 0x52, 0x05,
		0x4b, 0x72, 0xe1, 0x49, 0x32, 0x4c, 0x91, 0xc1, 0x55, 0x7c, 0x60, 0xc7, 0x73, 0x42, 0xc7, 0x76,
		0x55, 0x35, 0xb7, 0x9c, 0x3f, 0x1d, 0x9a, 0x5a, 0xaa, 0x06, 0x39, 0xa5, 0x60, 0xa7, 0x0a, 0xf4,
		0x94, 0x83, 0x9f, 0x72, 0x10, 0x54, 0x0d, 0x86, 0x34, 0xa0, 0x48, 0x04, 0x8e, 0xf1, 0xc3, 0x41,
		0x53, 0xcb, 0x8d, 0x4e, 0x81, 0xa6, 0x96, 0xfc, 0x9c, 0xcb, 0xd2, 0xe9, 0xd0, 0xd4, 0x52, 0x8e,
		0x89, 0xa0, 0xa9, 0x65, 0x36, 0x6c, 0x05, 0x4d, 0x2d, 0x49, 0xaf, 0x97, 0xa2, 0x8f, 0x7e, 0xd7,
		0xfe, 0xee, 0x74, 0x07, 0x5d, 0x55, 0x21, 0xc6, 0xfc, 0xe9, 0x10, 0x62, 0x20, 0xc4, 0x40, 0x88,
		0x81, 0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0x10, 0x62, 0x20, 0xc4, 0x40,
		0x88, 0xa1, 0x35, 0xc4, 0x40, 0xdf, 0x7c, 0x75, 0x79, 0x84, 0xe3, 0x5c, 0xb4, 0xc2, 0x7c, 0x6e,
		0x4a, 0x26, 0xa6, 0x3b, 0xdf, 0x45, 0x77, 0xd6, 0x3c, 0x0f, 0xec, 0xdf, 0xe3, 0x1b, 0xc3, 0x88,
		0x67, 0x59, 0xec, 0x13, 0x23, 0x9e, 0x91, 0x6c, 0xc0, 0x27, 0x18, 0x46, 0xb2, 0x81, 0x52, 0x1f,
		0x88, 0x64, 0x03, 0x36, 0x4c, 0x1c, 0x4a, 0x20, 0x37, 0xd0, 0x53, 0x0e, 0x7e, 0xca, 0x41, 0x50,
		0x35, 0x18, 0xd2, 0x86, 0x46, 0x50, 0x02, 0x5f, 0x8d, 0x61, 0x50, 0x02, 0x5f, 0x23, 0xf3, 0x40,
		0x09, 0x34, 0x5a, 0xdd, 0x81, 0x12, 0x28, 0xc5, 0x44, 0xa0, 0x04, 0xf2, 0x3d, 0x3a, 0x92, 0x0d,
		0x90, 0x6c, 0x80, 0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0x10, 0x62, 0x20,
		0xc4, 0x40, 0x88, 0x81, 0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x29, 0x66, 0x12, 0xed, 0xa9, 0x5b,
		0x21, 0xa5, 0x73, 0x9e, 0xef, 0x25, 0x33, 0x3e, 0x17, 0x82, 0x0b, 0x04, 0x17, 0x08, 0x2e, 0x10,
		0x5c, 0x18, 0x17, 0x5c, 0xd0, 0xf4, 0xd0, 0x5b, 0x07, 0x64, 0x32, 0x7b, 0xea, 0x2d, 0x9d, 0x43,
		0x6e, 0x8f, 0x3d, 0x05, 0xee, 0x0f, 0xb9, 0x76, 0xba, 0x73, 0xed, 0x28, 0x32, 0xa9, 0x76, 0x18,
		0xa4, 0xda, 0x49, 0x1c, 0x63, 0x2b, 0xdf, 0x5a, 0x31, 0x7d, 0x59, 0x95, 0x7d, 0x9b, 0x39, 0x88,
		0x79, 0x95, 0x45, 0xe7, 0x32, 0xd4, 0x95, 0xbb, 0x6b, 0x7f, 0xb7, 0xba, 0x22, 0xf4, 0x9d, 0x96,
		0xfc, 0x3e, 0x77, 0x33, 0xc7, 0x46, 0x8f, 0x3b, 0x96, 0x21, 0x05, 0x7a, 0xdc, 0xe9, 0x0a, 0x09,
		0xd0, 0xe3, 0x2e, 0xd5, 0x62, 0x40, 0x8f, 0x3b, 0xa4, 0x9d, 0x33, 0x52, 0x2e, 0x90, 0x76, 0xae,
		0x34, 0x1c, 0x24, 0x4c, 0x3b, 0x6f, 0xb9, 0x83, 0xb6, 0x50, 0x91, 0x70, 0x3e, 0x3e, 0x11, 0xa4,
		0x5a, 0xd5, 0xc0, 0xa6, 0x14, 0xe0, 0x54, 0x01, 0x9d, 0x72, 0xc0, 0x53, 0x0e, 0x7c, 0xaa, 0x01,
		0x90, 0x4e, 0x69, 0xdb, 0xc9, 0x84, 0x54, 0xeb, 0xb4, 0x85, 0x17, 0x3a, 0xe1, 0x93, 0x2f, 0x3a,
		0x2a, 0xa4, 0x5a, 0xc2, 0x8d, 0xdd, 0xdc, 0xd9, 0xe4, 0x56, 0xde, 0xd9, 0x81, 0x82, 0x15, 0x3a,
		0x7d, 0x80, 0x17, 0x27, 0x7f, 0x36, 0x2f, 0xea, 0x77, 0x37, 0x67, 0xef, 0x9b, 0x67, 0x97, 0xef,
		0xcf, 0x3f, 0x9e, 0xd6, 0xa9, 0x97, 0x6a, 0xb4, 0x5b, 0x1e, 0x90, 0xa7, 0xbd, 0xec, 0x28, 0x49,
		0x7d, 0xf9, 0xc5, 0xb3, 0x6c, 0xde, 0xde, 0x7d, 0x7c, 0x97, 0xcb, 0x42, 0x02, 0x87, 0xfe, 0x47,
		0x79, 0xf7, 0xd7, 0x75, 0xbd, 0xdc, 0xac, 0xff, 0x79, 0x57, 0xbf, 0xb9, 0x3c, 0x39, 0xcf, 0x19,
		0x9e, 0xe9, 0xd0, 0x80, 0xab, 0x88, 0x5e, 0xf8, 0xb9, 0x13, 0x84, 0x27, 0x61, 0xe8, 0xd3, 0xba,
		0x8b, 0x0b, 0xc7, 0xab, 0xbb, 0x62, 0xe4, 0xaf, 0x03, 0xda, 0xbc, 0xa0, 0xdc, 0x85, 0xfd, 0x7d,
		0xe6, 0x4c, 0xa5, 0xc3, 0x4a, 0xa5, 0x76, 0x50, 0xa9, 0x14, 0x0f, 0xf6, 0x0f, 0x8a, 0x47, 0xd5,
		0x6a, 0xa9, 0x46, 0xea, 0x42, 0xae, 0xfc, 0xb6, 0xf0, 0x45, 0xfb, 0xdd, 0x53, 0xee, 0x78, 0xc7,
		0x1b, 0xb8, 0xee, 0x16, 0xe7, 0xbc, 0x04, 0x22, 0xa4, 0x0f, 0x9f, 0x46, 0x27, 0x41, 0xe8, 0x84,
		0xd0, 0x09, 0xa1, 0x13, 0x42, 0x27, 0xe3, 0x42, 0x27, 0xf9, 0x33, 0xf1, 0xd7, 0x86, 0x4d, 0xa5,
		0x2d, 0x4f, 0xbe, 0xec, 0x0d, 0x42, 0x35, 0x99, 0x97, 0xa3, 0x13, 0xc1, 0x21, 0xc1, 0x21, 0xc1,
		0x21, 0xc1, 0x21, 0x19, 0xe7, 0x90, 0x06, 0x8e, 0x17, 0xd6, 0x2a, 0x0a, 0xfc, 0xd1, 0x21, 0x6a,
		0xba, 0x5e, 0x15, 0x32, 0xa3, 0xa6, 0x4b, 0xd2, 0xf9, 0x50, 0xd3, 0x65, 0xac, 0x89, 0xa8, 0x55,
		0x70, 0xb4, 0x5b, 0x0d, 0xaa, 0xbb, 0xcc, 0x0b, 0x30, 0x7c, 0xe7, 0xf1, 0x51, 0xf8, 0x0a, 0x02,
		0x8c, 0xc9, 0x89, 0x10, 0x60, 0x20, 0xc0, 0x40, 0x80, 0x81, 0x00, 0xc3, 0xb8, 0x00, 0x03, 0xc9,
		0x02, 0x29, 0x1f, 0xe0, 0xcc, 0xae, 0xec, 0xdd, 0xcd, 0xd9, 0xef, 0xbf, 0xd7, 0x6f, 0x90, 0x2c,
		0x20, 0xe1, 0x59, 0x5e, 0x5d, 0x36, 0x6f, 0xff, 0xba, 0xbd, 0xab, 0x5f, 0x34, 0xdf, 0x5d, 0x5d,
		0xdd, 0x61, 0x67, 0x3b, 0x1b, 0xb8, 0x86, 0x9d, 0x6d, 0x89, 0x27, 0x37, 0x75, 0x67, 0x1b, 0xe5,
		0xac, 0xca, 0xcb, 0xfd, 0x5e, 0xca, 0xbd, 0xb2, 0x34, 0x36, 0xe2, 0xc2, 0xfe, 0x7e, 0x11, 0xdd,
		0x14, 0x46, 0x46, 0xc8, 0xf2, 0xc0, 0x18, 0x19, 0x81, 0xda, 0x1d, 0x3e, 0xd1, 0x29, 0x6a, 0x77,
		0x94, 0xfa, 0x3e, 0xd4, 0xee, 0x40, 0x8e, 0x83, 0x1c, 0x07, 0x39, 0x0e, 0x72, 0x1c, 0xe4, 0xb8,
		0x0c, 0xc8, 0x71, 0xa8, 0xdd, 0x91, 0xfe, 0x2c, 0x51, 0xbb, 0x23, 0xef, 0x51, 0xa2, 0x76, 0x27,
		0x8b, 0xae, 0x02, 0x0a, 0xa7, 0xc4, 0x93, 0xa3, 0x76, 0xe7, 0x45, 0xf7, 0x41, 0xed, 0x0e, 0x42,
		0x27, 0x84, 0x4e, 0x08, 0x9d, 0x10, 0x3a, 0xad, 0x59, 0x35, 0xa8, 0xdd, 0x51, 0xe2, 0x88, 0x50,
		0xbb, 0x03, 0x87, 0x04, 0x87, 0x04, 0x87, 0x04, 0x87, 0xf4, 0xab, 0x55, 0x83, 0xda, 0x1d, 0x46,
		0x6a, 0x0c, 0x6a, 0x77, 0x24, 0x9e, 0x0f, 0xb5, 0x3b, 0xc6, 0x9a, 0x08, 0x6a, 0x77, 0x4c, 0x38,
		0x3a, 0x6a, 0x77, 0x50, 0xbb, 0x83, 0x00, 0x03, 0x01, 0x06, 0x02, 0x0c, 0x04, 0x18, 0xeb, 0x57,
		0x0d, 0x92, 0x05, 0x52, 0x3e, 0x40, 0xd4, 0xee, 0x90, 0x3c, 0x4b, 0xd4, 0xee, 0x64, 0x11, 0xd7,
		0xb0, 0xb3, 0x2d, 0xf1, 0xe4, 0xa8, 0xdd, 0x41, 0xed, 0xce, 0xe6, 0xb5, 0x3b, 0xd9, 0x19, 0x43,
		0xf7, 0x52, 0xba, 0x83, 0x11, 0x74, 0xba, 0xed, 0x5b, 0xbb, 0x5d, 0x1b, 0x3d, 0x7e, 0x2e, 0xb6,
		0xe4, 0x2c, 0x8d, 0x9e, 0x0b, 0xfa, 0x1d, 0xf9, 0x33, 0xe7, 0x46, 0x07, 0xc5, 0xb0, 0x39, 0x96,
		0x5a, 0x09, 0x86, 0xcd, 0xe9, 0xd2, 0x3a, 0x30, 0x6c, 0x2e, 0xd5, 0x62, 0xc0, 0xb0, 0x39, 0x14,
		0xac, 0x32, 0x80, 0x21, 0x65, 0x70, 0xa4, 0x0a, 0x96, 0xcc, 0x08, 0xf8, 0x08, 0x0b, 0x56, 0x9d,
		0xd0, 0xb1, 0x5d, 0xab, 0x2d, 0x5c, 0xfb, 0x49, 0x45, 0xd9, 0xea, 0xec, 0xe9, 0xb0, 0x1f, 0xa5,
		0x1a, 0xe4, 0x94, 0x82, 0x9d, 0x2a, 0xd0, 0x53, 0x0e, 0x7e, 0xca, 0x41, 0x50, 0x35, 0x18, 0xd2,
		0xe9, 0x6a, 0x3b, 0x99, 0x49, 0x78, 0xdb, 0x2f, 0x2b, 0xd8, 0x8a, 0x3a, 0x40, 0xc2, 0xdb, 0xaf,
		0x6f, 0x04, 0x09, 0x6f, 0xf2, 0xce, 0x87, 0x84, 0x37, 0x63, 0x4d, 0xa4, 0x52, 0x3e, 0xaa, 0x1c,
		0xd5, 0x0e, 0xca, 0x47, 0x48, 0x73, 0x63, 0x77, 0xf4, 0x6d, 0x4e, 0x73, 0xeb, 0xda, 0xdf, 0x9d,
		0xee, 0xa0, 0xab, 0x2a, 0xc4, 0x98, 0x3f, 0x1d, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0x10, 0x62,
		0x20, 0xc4, 0x40, 0x88, 0x81, 0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x84, 0x18, 0x08, 0x31, 0xb4,
		0x86, 0x18, 0xc8, 0xac, 0x53, 0x9e, 0x81, 0x14, 0xf4, 0x3b, 0x59, 0x6a, 0x87, 0x7d, 0xdb, 0xef,
		0xa0, 0x11, 0xb6, 0x2c, 0xa2, 0x89, 0x46, 0xd8, 0xc8, 0x2b, 0xe0, 0x13, 0xf7, 0x22, 0xaf, 0x40,
		0xa9, 0xbb, 0x43, 0x5e, 0x01, 0x1b, 0xd2, 0x0d, 0xd1, 0x8f, 0x1b, 0xe8, 0x29, 0x07, 0x3f, 0xe5,
		0x20, 0xa8, 0x1a, 0x0c, 0x69, 0xa3, 0x20, 0x88, 0x7e, 0xaf, 0xc6, 0x30, 0x88, 0x7e, 0xaf, 0x51,
		0x74, 0x20, 0xfa, 0x19, 0x2d, 0xe4, 0x40, 0xf4, 0x93, 0x62, 0x22, 0x10, 0xfd, 0xf8, 0x1e, 0x1d,
		0x79, 0x05, 0xc8, 0x2b, 0x40, 0x88, 0x81, 0x10, 0x03, 0x21, 0x06, 0x42, 0x0c, 0x84, 0x18, 0x08,
		0x31, 0x10, 0x62, 0x20, 0xc4, 0x40, 0x88, 0x81, 0x10, 0x03, 0x21, 0x86, 0x14, 0x33, 0x89, 0xb6,
		0xcf, 0xad, 0x90, 0xd2, 0x39, 0xcf, 0x4d, 0x01, 0x98, 0x9c, 0x0b, 0xc1, 0x05, 0x82, 0x0b, 0x04,
		0x17, 0x08, 0x2e, 0x8c, 0x0b, 0x2e, 0x84, 0x37, 0xe8, 0x0a, 0x7f, 0x9c, 0x3e, 0xa5, 0xa0, 0x4f,
		0x67, 0x85, 0xf0, 0x1c, 0x75, 0x6f, 0xd0, 0x1d, 0x3d, 0xb4, 0x21, 0xd2, 0xea, 0x64, 0xac, 0xcf,
		0xcc, 0xa6, 0xd5, 0x65, 0xa7, 0x53, 0xdd, 0x6d, 0xbf, 0x83, 0x1e, 0x75, 0xda, 0x4d, 0x5a, 0x9f,
		0x29, 0x1b, 0xdd, 0x9c, 0xee, 0xb6, 0xdf, 0x61, 0xd3, 0x96, 0xee, 0x8d, 0x46, 0xf3, 0x94, 0x6d,
		0x96, 0x7a, 0xcc, 0x31, 0x27, 0xa3, 0xb3, 0x9f, 0x62, 0x13, 0x4c, 0x67, 0x7e, 0xc9, 0x8d, 0x26,
		0xd9, 0x27, 0x13, 0x9a, 0x99, 0x2c, 0xf3, 0x52, 0x6c, 0x56, 0x29, 0xec, 0x49, 0x9d, 0x1d, 0x25,
		0x33, 0xa0, 0xcd, 0x5f, 0xff, 0x66, 0x9f, 0xd8, 0xd0, 0x50, 0xd2, 0x1a, 0x88, 0x2a, 0xc3, 0x48,
		0x60, 0x11, 0x0a, 0x2c, 0x61, 0x33, 0x13, 0x78, 0xfd, 0x8b, 0xdc, 0xe0, 0x25, 0xe6, 0xfa, 0x4e,
		0x77, 0xe3, 0x37, 0x17, 0x07, 0x80, 0xa3, 0x0f, 0x6f, 0x68, 0x30, 0xc9, 0x4a, 0x05, 0x12, 0xab,
		0x4d, 0x69, 0x54, 0xa4, 0x59, 0x75, 0x68, 0xf3, 0x3b, 0x95, 0x21, 0xf9, 0x48, 0x93, 0x72, 0xa4,
		0x49, 0x34, 0x8b, 0xd2, 0xcb, 0xe8, 0xb9, 0x30, 0x83, 0xa4, 0xa4, 0x49, 0xee, 0xb9, 0x89, 0xf3,
		0x48, 0xfc, 0xb2, 0xa6, 0xe6, 0x92, 0xca, 0x09, 0xa5, 0xac, 0xa5, 0x49, 0x2d, 0xcb, 0xca, 0x90,
		0x5d, 0xd3, 0x2f, 0x1c, 0xd9, 0x9a, 0xa9, 0x74, 0x4d, 0x54, 0xba, 0xe6, 0x29, 0x65, 0x61, 0xe9,
		0x21, 0x89, 0x69, 0xab, 0x4a, 0x64, 0x35, 0xd3, 0x95, 0xdb, 0x3c, 0x57, 0x52, 0x51, 0x9b, 0xb4,
		0x7d, 0x12, 0x99, 0xfb, 0x21, 0xf2, 0x16, 0xa8, 0xec, 0x85, 0x4a, 0xb6, 0x60, 0xc9, 0x16, 0x2e,
		0xc9, 0x02, 0xe6, 0x21, 0x2e, 0xc8, 0x2a, 0x17, 0x8b, 0x93, 0x29, 0x1f, 0xfd, 0xde, 0xa0, 0x1f,
		0xc8, 0xef, 0xc0, 0xbf, 0x70, 0x7c, 0xb9, 0xcd, 0xf8, 0x8b, 0x5b, 0xda, 0x8c, 0x5f, 0x0e, 0x30,
		0x50, 0x01, 0x04, 0x39, 0x50, 0x90, 0x03, 0x06, 0x29, 0x70, 0xf0, 0x14, 0xd1, 0xa5, 0x6f, 0x4d,
		0xd2, 0xe5, 0x39, 0x12, 0xe4, 0x35, 0x12, 0xe5, 0x31, 0x12, 0xec, 0xaf, 0x51, 0xe6, 0x29, 0x52,
		0xe7, 0xa5, 0x10, 0xe7, 0x21, 0xaa, 0xc8, 0x25, 0xa3, 0xc8, 0x6d, 0xa2, 0xcc, 0x2b, 0x54, 0xf5,
		0x4a, 0xa9, 0xf3, 0x06, 0x95, 0xbc, 0x5b, 0xa6, 0xbb, 0xad, 0x0d, 0x6c, 0xa7, 0x99, 0xb8, 0x9d,
		0xd6, 0x77, 0xba, 0xd3, 0xbd, 0x34, 0x69, 0x1d, 0x7f, 0x48, 0x95, 0xef, 0x6b, 0xa7, 0x3b, 0xdd,
		0x48, 0x93, 0xd1, 0xd3, 0x27, 0xc5, 0x46, 0x5a, 0x0a, 0x55, 0xca, 0x17, 0x5e, 0x5b, 0xfc, 0xdf,
		0xb7, 0xde, 0x20, 0xb0, 0xfa, 0x3d, 0x67, 0x3c, 0x68, 0x53, 0x92, 0x76, 0xb1, 0x7c, 0x68, 0xc8,
		0x18, 0x90, 0x31, 0x20, 0x63, 0x70, 0x90, 0x31, 0x16, 0xd7, 0xa6, 0x7c, 0x21, 0x63, 0xe9, 0x0c,
		0x98, 0x2b, 0x08, 0x29, 0x03, 0x52, 0x06, 0x43, 0x29, 0x43, 0xfa, 0x44, 0x41, 0xbb, 0xdd, 0xf6,
		0x45, 0x10, 0xd0, 0x75, 0xfe, 0x9b, 0x9e, 0x80, 0xa6, 0xf7, 0x5f, 0x11, 0x33, 0x05, 0x09, 0x21,
		0x87, 0x1a, 0x7a, 0x94, 0x41, 0x90, 0x32, 0x28, 0x52, 0x02, 0x49, 0x44, 0x41, 0xbd, 0x64, 0x8b,
		0x27, 0x2b, 0x08, 0x89, 0xed, 0xdd, 0x15, 0x76, 0xc7, 0x17, 0x1d, 0x0a, 0x83, 0x9f, 0x32, 0x17,
		0x82, 0xfa, 0xf2, 0xdc, 0xf5, 0x24, 0x2e, 0xdf, 0xdb, 0x9b, 0x04, 0xcf, 0x85, 0x29, 0x46, 0x6e,
		0x41, 0x9f, 0x59, 0x4c, 0xb0, 0x85, 0xb7, 0x81, 0xb7, 0x81, 0xb7, 0x31, 0xa6, 0xc7, 0x2c, 0x15,
		0x41, 0x56, 0x44, 0x94, 0x89, 0x09, 0x33, 0x39, 0x94, 0xa9, 0x80, 0x34, 0x75, 0xd0, 0xa6, 0x0a,
		0xe2, 0x94, 0x43, 0x9d, 0x72, 0xc8, 0x53, 0x0a, 0x7d, 0x34, 0x10, 0x48, 0x04, 0x85, 0xf4, 0x04,
		0x7c, 0x69, 0xbd, 0x38, 0xfd, 0x6f, 0x15, 0x8b, 0x16, 0xbf, 0xe6, 0x68, 0xd8, 0x21, 0xe1, 0x39,
		0xae, 0xed, 0x30, 0x14, 0xbe, 0x47, 0xde, 0xf7, 0x29, 0xb7, 0xbb, 0x7b, 0x5f, 0xb4, 0x8e, 0x1a,
		0xcf, 0xf7, 0x25, 0xeb, 0xa8, 0x31, 0xfe, 0xb2, 0x14, 0xfd, 0x6f, 0xfc, 0x75, 0xf9, 0xbe, 0x68,
		0x55, 0xa6, 0x5f, 0x57, 0xef, 0x8b, 0x56, 0xb5, 0x91, 0xff, 0xfc, 0x79, 0x2f, 0xff, 0x63, 0x7f,
		0xb8, 0xf9, 0x07, 0x77, 0xff, 0xfb, 0xfe, 0xf3, 0xe7, 0xfe, 0x8f, 0xcb, 0xe1, 0xe8, 0xef, 0xf3,
		0x61, 0xe3, 0xef, 0xf9, 0xdf, 0x72, 0xe8, 0xe5, 0x42, 0xd1, 0x2e, 0x72, 0xe0, 0x86, 0x4e, 0xcb,
		0x0e, 0x42, 0xd9, 0x49, 0x87, 0x6b, 0xd7, 0xde, 0xd2, 0x19, 0xc1, 0x1f, 0xc0, 0x1f, 0xc0, 0x1f,
		0xc0, 0x1f, 0x0c, 0xe2, 0x0f, 0x41, 0xe8, 0x3b, 0xde, 0xa3, 0x12, 0xe6, 0x80, 0x46, 0x2b, 0x32,
		0xd6, 0x8c, 0xe9, 0x8d, 0x56, 0x66, 0xf2, 0x97, 0x96, 0x32, 0x5f, 0x96, 0x7e, 0x62, 0xe8, 0x50,
		0xb3, 0x99, 0x94, 0xa7, 0x9b, 0xf8, 0x8e, 0xae, 0xa3, 0x5b, 0x5c, 0xfc, 0x01, 0xe6, 0x9c, 0xc9,
		0x43, 0x32, 0xcc, 0x39, 0x83, 0xfa, 0xcc, 0x82, 0x52, 0x41, 0x7d, 0x56, 0xe7, 0x10, 0xa1, 0x3e,
		0x23, 0x7a, 0x44, 0xf4, 0x88, 0xe8, 0x11, 0xd1, 0xa3, 0x86, 0xe8, 0x11, 0xea, 0x73, 0x82, 0x13,
		0x41, 0x7d, 0xd6, 0x1d, 0xe1, 0x43, 0x7d, 0x06, 0x7f, 0x00, 0x7f, 0x00, 0x7f, 0x00, 0x7f, 0xd0,
		0xcc, 0x1f, 0xa0, 0x3e, 0x9b, 0x15, 0x6c, 0x6f, 0x99, 0xfa, 0x6c, 0x64, 0xef, 0xef, 0x4d, 0xc4,
		0x67, 0xb4, 0x03, 0xdf, 0xc4, 0x21, 0xca, 0x17, 0x6b, 0x72, 0xe7, 0x4e, 0x10, 0x9e, 0x84, 0xa1,
		0xe4, 0xca, 0xa2, 0x0b, 0xc7, 0xab, 0xbb, 0x62, 0xe4, 0xdc, 0x02, 0xb9, 0xc4, 0x2a, 0x77, 0x61,
		0x7f, 0x9f, 0x39, 0x72, 0xe9, 0xb0, 0x52, 0xa9, 0x1d, 0x54, 0x2a, 0xc5, 0x83, 0xfd, 0x83, 0xe2,
		0x51, 0xb5, 0x5a, 0xaa, 0x95, 0x24, 0x36, 0x6a, 0xc8, 0x5d, 0xf9, 0x6d, 0xe1, 0x8b, 0xf6, 0xbb,
		0xd1, 0x83, 0xf7, 0x06, 0xae, 0x8b, 0xf6, 0xf0, 0xca, 0x21, 0xd0, 0x94, 0x9e, 0xf1, 0x1b, 0x80,
		0x1e, 0xda, 0xc8, 0x9b, 0xde, 0xf7, 0x42, 0x76, 0xc7, 0x04, 0x9d, 0xd6, 0x69, 0x62, 0x33, 0x8c,
		0x20, 0x8a, 0x41, 0x03, 0xeb, 0x7f, 0x7b, 0x8e, 0x27, 0xda, 0xf2, 0x3a, 0x61, 0x2c, 0x1c, 0x97,
		0x59, 0x1b, 0x8c, 0x32, 0xda, 0x60, 0x30, 0xd0, 0x0f, 0xd0, 0x06, 0xe3, 0xf5, 0x77, 0x24, 0xad,
		0x0d, 0x46, 0x20, 0xd9, 0x38, 0xe6, 0x17, 0x3c, 0x5a, 0x5e, 0x30, 0x14, 0x1e, 0xd1, 0xf2, 0x42,
		0x8b, 0x70, 0x88, 0x96, 0x17, 0xe9, 0xd6, 0x01, 0x5a, 0x5e, 0xec, 0x20, 0x0d, 0x4c, 0x37, 0x04,
		0x29, 0x83, 0x22, 0x25, 0x90, 0x64, 0x86, 0x32, 0x8d, 0x96, 0x17, 0xeb, 0xa0, 0xe0, 0xa5, 0xe5,
		0x45, 0x24, 0x67, 0x6f, 0x53, 0xc7, 0x0b, 0x64, 0x1c, 0x4b, 0x0f, 0x63, 0xe1, 0x6a, 0xe0, 0x6a,
		0x90, 0x71, 0x8c, 0x8c, 0x63, 0xf5, 0x6c, 0x99, 0x9c, 0x35, 0xab, 0x80, 0x34, 0x75, 0xd0, 0xa6,
		0x0a, 0xe2, 0x94, 0x43, 0x9d, 0x72, 0xc8, 0x53, 0x0a, 0x7d, 0x34, 0x10, 0x48, 0x04, 0x85, 0xf4,
		0xec, 0x7b, 0x69, 0xbd, 0x20, 0xe3, 0x38, 0xc1, 0x89, 0x90, 0x71, 0xac, 0x79, 0xed, 0x51, 0x64,
		0x1c, 0x47, 0x59, 0xbf, 0xf4, 0x5c, 0x61, 0x7c, 0x1a, 0x30, 0x05, 0x30, 0x05, 0x30, 0x05, 0x30,
		0x05, 0x30, 0x05, 0x30, 0x05, 0x30, 0x05, 0xc3, 0x98, 0xc2, 0xa0, 0x1f, 0x84, 0xbe, 0xb0, 0xbb,
		0x96, 0xe3, 0x85, 0xc2, 0xef, 0xd8, 0x2d, 0x61, 0x39, 0x6d, 0x7a, 0xe6, 0xb0, 0xfa, 0xb4, 0x60,
		0x12, 0x60, 0x12, 0x60, 0x12, 0x60, 0x12, 0x26, 0x31, 0x09, 0x7a, 0xfc, 0xda, 0x41, 0xad, 0x12,
		0x6a, 0x95, 0xd6, 0x67, 0x3c, 0xcf, 0x67, 0xc6, 0x4e, 0xbe, 0x35, 0xbe, 0x3c, 0x69, 0xec, 0x25,
		0x82, 0xff, 0x17, 0xdd, 0xd4, 0xe4, 0x3b, 0x94, 0x24, 0x6d, 0xe4, 0xfd, 0x50, 0x92, 0x84, 0x92,
		0x24, 0x6a, 0xc4, 0xd3, 0x8f, 0x74, 0x06, 0x56, 0x21, 0xad, 0xc2, 0x36, 0x54, 0x1e, 0x99, 0x5e,
		0x79, 0x24, 0xb5, 0x42, 0x45, 0x9b, 0x39, 0x1a, 0x59, 0x73, 0x14, 0x74, 0x25, 0x16, 0x1a, 0x05,
		0x5d, 0x0c, 0xd9, 0x55, 0xa8, 0x13, 0xa0, 0xba, 0x08, 0xd5, 0x45, 0xeb, 0x0f, 0x24, 0x79, 0x2e,
		0x19, 0xcd, 0x3c, 0x32, 0x54, 0x17, 0xa1, 0xba, 0x08, 0xd5, 0x45, 0x52, 0xc3, 0x15, 0xe9, 0xd5,
		0x45, 0x41, 0xd0, 0xb5, 0x7c, 0xdb, 0x7b, 0x14, 0x84, 0x05, 0x46, 0x33, 0xe7, 0x40, 0x8d, 0x11,
		0x12, 0xbf, 0xb5, 0x01, 0x91, 0x32, 0x40, 0x52, 0x02, 0x4c, 0x66, 0x28, 0xca, 0xa8, 0x31, 0x5a,
		0x07, 0x05, 0x71, 0xf0, 0xdd, 0xb2, 0xec, 0x96, 0x7b, 0x6c, 0xb7, 0xdc, 0x99, 0x2f, 0xad, 0x40,
		0x84, 0xc1, 0xc2, 0xf7, 0xd3, 0x6f, 0x27, 0x53, 0x78, 0x27, 0xdf, 0x45, 0x61, 0x30, 0xa4, 0xdf,
		0x6d, 0x91, 0xfa, 0x82, 0xae, 0xfc, 0xf9, 0x1e, 0xca, 0x04, 0x95, 0xa0, 0x2b, 0x75, 0x74, 0x87,
		0x04, 0x55, 0x4f, 0x8a, 0x1a, 0x25, 0xb3, 0x60, 0x8e, 0xa4, 0x50, 0x8e, 0x2c, 0x10, 0x2b, 0x23,
		0x10, 0x43, 0x20, 0x86, 0x40, 0x0c, 0x81, 0x18, 0x02, 0x31, 0x04, 0x62, 0x08, 0xc4, 0x10, 0x88,
		0x21, 0x10, 0x43, 0x20, 0xb6, 0x35, 0x81, 0x98, 0xec, 0x5c, 0x32, 0x95, 0x71, 0x98, 0xc4, 0x94,
		0x31, 0x24, 0x57, 0x68, 0x35, 0x43, 0x93, 0x32, 0x2a, 0x82, 0xae, 0x91, 0x79, 0x14, 0x52, 0x22,
		0x7c, 0xa9, 0x91, 0x3d, 0x3a, 0xb5, 0xea, 0x24, 0xcc, 0xc8, 0xa5, 0x60, 0x00, 0xdb, 0x12, 0x73,
		0x29, 0x06, 0x5e, 0x28, 0xfc, 0x80, 0x22, 0x9b, 0x62, 0x72, 0x64, 0xe4, 0x53, 0x40, 0xc6, 0x83,
		0x8c, 0xb7, 0x0d, 0x32, 0xde, 0x43, 0xaf, 0x17, 0x06, 0xa1, 0x6f, 0xf7, 0xad, 0xae, 0x08, 0x02,
		0x9b, 0x54, 0xce, 0x5b, 0x71, 0x2e, 0xc8, 0x7a, 0x90, 0xf5, 0x20, 0xeb, 0x41, 0xd6, 0x93, 0x68,
		0xef, 0x03, 0xc7, 0x0b, 0xf7, 0xcb, 0x84, 0xaa, 0x1e, 0x85, 0xa8, 0x77, 0x63, 0x7b, 0x8f, 0x82,
		0xac, 0xf5, 0x03, 0x61, 0xfd, 0xec, 0x85, 0xe3, 0x29, 0x28, 0x01, 0x27, 0x2d, 0xfc, 0x8f, 0x4f,
		0xf3, 0xc9, 0x76, 0x07, 0x42, 0xc1, 0x79, 0x3e, 0xf8, 0x76, 0x2b, 0x74, 0x7a, 0xde, 0xa9, 0xf3,
		0xe8, 0x8c, 0x4b, 0xe5, 0xe8, 0xca, 0xbd, 0x09, 0x4b, 0x99, 0x2f, 0xec, 0xef, 0x99, 0x7b, 0xf5,
		0x95, 0xf2, 0x51, 0xe5, 0xa8, 0x76, 0x50, 0x3e, 0xaa, 0x66, 0xc8, 0x06, 0x0c, 0x29, 0x35, 0x6f,
		0x6c, 0x41, 0xb7, 0xea, 0x2f, 0xc2, 0x75, 0x7b, 0x0a, 0xa8, 0xf6, 0xc2, 0x79, 0x40, 0xb3, 0x41,
		0xb3, 0x41, 0xb3, 0x41, 0xb3, 0x41, 0xb3, 0x41, 0xb3, 0x41, 0xb3, 0x41, 0xb3, 0x41, 0xb3, 0x41,
		0xb3, 0xb3, 0x4c, 0xb3, 0xff, 0xb7, 0xe7, 0x78, 0x56, 0xdf, 0x1f, 0x78, 0x42, 0x01, 0xd7, 0x5e,
		0x75, 0x32, 0x10, 0x6e, 0x10, 0x6e, 0x10, 0x6e, 0x10, 0x6e, 0x10, 0x6e, 0x10, 0x6e, 0x10, 0x6e,
		0x10, 0x6e, 0x10, 0x6e, 0x10, 0x6e, 0x76, 0x84, 0x1b, 0x49, 0xf6, 0xb2, 0xb3, 0x9b, 0xa3, 0xe1,
		0x9b, 0x92, 0xb3, 0xe8, 0x76, 0x54, 0x26, 0x3c, 0x8f, 0x6e, 0xa0, 0xf9, 0x7e, 0x7a, 0x03, 0x19,
		0xaa, 0x7a, 0xee, 0xda, 0xdf, 0x9d, 0xee, 0xa0, 0x6b, 0x45, 0xa3, 0x6e, 0x08, 0x52, 0x27, 0x17,
		0x8e, 0x2f, 0x37, 0x81, 0xb2, 0x88, 0x04, 0x4a, 0xc6, 0x71, 0x1d, 0x12, 0x28, 0x0d, 0x72, 0x33,
		0xd2, 0xe3, 0x34, 0xba, 0xf8, 0x8c, 0x20, 0x2e, 0x23, 0x8a, 0xc7, 0x08, 0xa2, 0x5e, 0xca, 0xf8,
		0x8b, 0x7a, 0x90, 0x08, 0x71, 0xbc, 0xa5, 0x82, 0x63, 0x53, 0x8c, 0xa8, 0xa1, 0x8c, 0xab, 0x54,
		0xbd, 0x52, 0xea, 0x38, 0x4a, 0xc9, 0xbb, 0x65, 0x1a, 0x8f, 0x34, 0x32, 0x44, 0x37, 0x3d, 0xe1,
		0x3c, 0x7e, 0x79, 0xe8, 0xf9, 0x56, 0x14, 0x0c, 0xc8, 0xa7, 0x9b, 0x0b, 0xc7, 0x07, 0xdd, 0x04,
		0xdd, 0x04, 0xdd, 0xdc, 0x3a, 0xba, 0x79, 0x48, 0xc0, 0x36, 0xab, 0x60, 0x9b, 0x60, 0x9b, 0x60,
		0x9b, 0x2c, 0x5e, 0x69, 0xb9, 0x0a, 0x9a, 0x99, 0x5d, 0x9a, 0x89, 0x26, 0x22, 0x69, 0x64, 0x76,
		0x93, 0xda, 0x88, 0xa4, 0xef, 0x5d, 0x93, 0xa2, 0x91, 0xc8, 0x1b, 0x85, 0xe6, 0x25, 0xcb, 0xac,
		0x54, 0x9a, 0x53, 0x2e, 0x55, 0xa7, 0x15, 0x15, 0x06, 0x94, 0xcc, 0x74, 0x36, 0x7f, 0xf1, 0x09,
		0x5e, 0xfa, 0xcb, 0xdc, 0xcc, 0xe4, 0x7b, 0x2a, 0xcb, 0x33, 0x38, 0x93, 0xee, 0x9f, 0xa4, 0x6c,
		0x38, 0x91, 0x3a, 0x60, 0x95, 0x11, 0xa0, 0xca, 0x0b, 0x48, 0x65, 0x05, 0xa0, 0xd2, 0x03, 0x4e,
		0xe9, 0x01, 0xa6, 0xd4, 0x80, 0x52, 0x2d, 0x60, 0xa6, 0x6d, 0xe8, 0xf0, 0xb2, 0x68, 0xe4, 0x35,
		0x7c, 0x7a, 0x39, 0x24, 0x06, 0x68, 0xa9, 0xd3, 0x8d, 0xd0, 0xf4, 0x09, 0x4d, 0x9f, 0xd6, 0x1f,
		0x08, 0x03, 0xb4, 0x64, 0x1c, 0x10, 0x02, 0x32, 0x04, 0x64, 0x35, 0x4a, 0x03, 0xe3, 0x86, 0x4f,
		0x7e, 0x5b, 0xf8, 0x96, 0xdf, 0x1b, 0x84, 0xc2, 0xa7, 0xec, 0xf5, 0x34, 0x7b, 0x1a, 0xc9, 0xaf,
		0xff, 0x54, 0x74, 0xec, 0x81, 0x1b, 0xbd, 0xfd, 0x8e, 0xed, 0x06, 0x02, 0xe5, 0x36, 0x28, 0xb7,
		0xd1, 0x07, 0x77, 0xca, 0x60, 0x4f, 0x09, 0xfc, 0xc9, 0x17, 0x5c, 0x77, 0x8c, 0x2c, 0xb7, 0x79,
		0xe8, 0xf5, 0x5c, 0x61, 0x7b, 0x94, 0xdd, 0xe1, 0x4b, 0x5b, 0x50, 0x89, 0xf9, 0x10, 0xf8, 0xd6,
		0xd8, 0x17, 0x10, 0xfa, 0x9a, 0x97, 0x73, 0xc0, 0xd1, 0xc0, 0xd1, 0xc0, 0xd1, 0xc0, 0xd1, 0xc0,
		0xd1, 0x6c, 0x9b, 0xa3, 0x69, 0x0b, 0xbb, 0x6d, 0x85, 0x4e, 0x97, 0xd2, 0xd1, 0xcc, 0x9c, 0x03,
		0x8e, 0x00, 0x8e, 0x00, 0x8e, 0x00, 0x8e, 0x40, 0xa2, 0xbd, 0x0f, 0x1c, 0x2f, 0x2c, 0xd5, 0x08,
		0xfd, 0x40, 0x0d, 0x05, 0xfe, 0x2f, 0x17, 0x9e, 0xc5, 0x02, 0xff, 0x12, 0x0a, 0xfc, 0x5f, 0xf5,
		0xea, 0x33, 0x58, 0xe0, 0x5f, 0xab, 0x56, 0xf7, 0x51, 0xdb, 0xaf, 0xfc, 0xa8, 0xdb, 0xd0, 0x4c,
		0xab, 0xed, 0x5b, 0x7d, 0xdf, 0xe9, 0xf9, 0x4e, 0xf8, 0x44, 0x48, 0xad, 0x67, 0x4e, 0x02, 0x6e,
		0x0d, 0x6e, 0x0d, 0x6e, 0x0d, 0x6e, 0x4d, 0x03, 0x2f, 0x56, 0x38, 0x3a, 0x1b, 0xda, 0x68, 0x81,
		0x65, 0x27, 0xa4, 0x5a, 0x68, 0xa3, 0xb5, 0xb5, 0x2c, 0x1b, 0x6d, 0xb4, 0x40, 0xb5, 0x29, 0xa9,
		0xb6, 0xf0, 0xec, 0x07, 0x57, 0xb4, 0xe9, 0x68, 0xf6, 0xf4, 0x04, 0xd8, 0x27, 0x05, 0x85, 0x07,
		0x85, 0x07, 0x85, 0x37, 0x88, 0xc2, 0x63, 0x9f, 0x54, 0xca, 0xbd, 0x8e, 0x27, 0x03, 0x45, 0x25,
		0x1e, 0xdf, 0x6c, 0x97, 0x7a, 0x02, 0x51, 0x7c, 0x1e, 0x38, 0x04, 0x38, 0x04, 0x38, 0x04, 0x38,
		0x04, 0x89, 0xf6, 0xde, 0x77, 0xba, 0x31, 0xbe, 0x50, 0x8b, 0x3a, 0x04, 0xf1, 0x5e, 0xee, 0xa3,
		0x37, 0x0e, 0xed, 0x72, 0x81, 0x68, 0xf5, 0xbc, 0x76, 0x90, 0x83, 0x70, 0x94, 0x6d, 0xe1, 0x08,
		0xdb, 0xb3, 0x5b, 0x2b, 0x1c, 0x91, 0x75, 0x72, 0x81, 0x62, 0xb4, 0xdd, 0x8a, 0x51, 0x5c, 0xab,
		0x6d, 0x39, 0x84, 0xb2, 0xd1, 0xdc, 0x59, 0x40, 0xe5, 0x41, 0xe5, 0x41, 0xe5, 0x41, 0xe5, 0xcd,
		0xc0, 0x97, 0x39, 0x81, 0xe7, 0x70, 0xbb, 0x66, 0xdf, 0xd1, 0xab, 0x3c, 0xab, 0x4e, 0x06, 0xff,
		0x00, 0xff, 0x00, 0xff, 0x00, 0xff, 0x00, 0xa9, 0x07, 0x52, 0x0f, 0xa4, 0x1e, 0x48, 0x3d, 0x90,
		0x7a, 0x20, 0xf5, 0x40, 0xea, 0x49, 0xff, 0xda, 0x89, 0x46, 0x98, 0x2d, 0x39, 0x5b, 0x92, 0x51,
		0x66, 0xa0, 0xf3, 0xa0, 0xf3, 0xa0, 0xf3, 0xa0, 0xf3, 0x18, 0x65, 0x0d, 0x7e, 0x2d, 0x81, 0x64,
		0x21, 0x07, 0x7f, 0x6b, 0xf9, 0x35, 0x72, 0xf0, 0x41, 0xb3, 0x49, 0x69, 0x76, 0xaf, 0x2d, 0x08,
		0xc9, 0xf5, 0xe8, 0xe8, 0xa0, 0xd4, 0xa0, 0xd4, 0xa0, 0xd4, 0xa0, 0xd4, 0x12, 0xed, 0xdd, 0x69,
		0x0b, 0x2f, 0x74, 0xc2, 0x27, 0x5f, 0x74, 0x28, 0x37, 0x50, 0x29, 0xc4, 0xf1, 0xb3, 0xc9, 0xa5,
		0xbf, 0xb3, 0x03, 0xc2, 0x65, 0x35, 0x7d, 0x50, 0xd7, 0x67, 0x17, 0xcd, 0x8b, 0xab, 0xd3, 0x7a,
		0x8e, 0x72, 0x76, 0x57, 0x40, 0x16, 0x27, 0xd0, 0xc6, 0x0a, 0x2b, 0x9f, 0x54, 0xf3, 0xb4, 0x7e,
		0x79, 0x5b, 0xcf, 0x99, 0x48, 0x80, 0x55, 0x3f, 0xa9, 0xdb, 0xeb, 0x93, 0x1b, 0xd2, 0x47, 0x45,
		0x72, 0xe4, 0xc6, 0xd6, 0xcc, 0x7e, 0xe3, 0xd5, 0xdb, 0x5d, 0xf2, 0x0c, 0xb6, 0xf8, 0xb8, 0x4a,
		0x86, 0x67, 0xbd, 0x0c, 0x6b, 0x7a, 0xf9, 0xb2, 0x20, 0x75, 0x9a, 0xc4, 0x8e, 0x8a, 0x09, 0x5b,
		0x67, 0xf1, 0x6d, 0xbc, 0x7c, 0xd9, 0x9c, 0x30, 0xdf, 0x0c, 0xcd, 0xa3, 0x1e, 0xd7, 0xfd, 0x5a,
		0x0f, 0x9d, 0xb6, 0xfc, 0x11, 0x22, 0x33, 0xc7, 0xc6, 0x18, 0x11, 0x19, 0x81, 0x8b, 0xbc, 0x27,
		0xb9, 0x83, 0x31, 0x22, 0x1b, 0x04, 0x26, 0xa3, 0xe7, 0x8e, 0x31, 0x22, 0xaf, 0x3b, 0xa0, 0xe4,
		0x79, 0x44, 0x4b, 0xcb, 0x40, 0xba, 0x27, 0x21, 0x00, 0x96, 0xcc, 0x28, 0x25, 0x72, 0x01, 0x07,
		0x4a, 0x09, 0x4b, 0x40, 0x32, 0x43, 0x29, 0x91, 0x0d, 0x54, 0x0b, 0x0c, 0xa8, 0x4d, 0x2f, 0x30,
		0xd0, 0xb4, 0x58, 0x59, 0x84, 0x30, 0xaa, 0xd1, 0xe3, 0x54, 0x50, 0xa6, 0x02, 0xd2, 0xd4, 0x41,
		0x9b, 0x2a, 0x88, 0x53, 0x0e, 0x75, 0xca, 0x21, 0x4f, 0x29, 0xf4, 0xd1, 0xca, 0x28, 0x44, 0x3a,
		0x16, 0x9d, 0x78, 0xbc, 0xb4, 0x5e, 0xe8, 0x5a, 0xac, 0x2c, 0x31, 0xb0, 0x92, 0x21, 0x3b, 0x9e,
		0xbc, 0xbd, 0x25, 0x91, 0x82, 0xc4, 0x40, 0x49, 0x7a, 0x11, 0x15, 0x0a, 0x24, 0xa1, 0x80, 0x3e,
		0x71, 0xa9, 0x1e, 0xdd, 0xd9, 0xbb, 0x4e, 0x5b, 0xaa, 0xcc, 0x24, 0xdf, 0x5e, 0x87, 0x52, 0x55,
		0x3c, 0x3b, 0x24, 0xdc, 0x54, 0x1f, 0x1f, 0xde, 0xb0, 0x58, 0xb1, 0x8c, 0x58, 0x11, 0xb1, 0x22,
		0x62, 0x45, 0xc4, 0x8a, 0x88, 0x15, 0x11, 0x2b, 0x22, 0x56, 0x44, 0xac, 0x88, 0x58, 0x11, 0xb1,
		0x22, 0x62, 0xc5, 0x74, 0xb1, 0x22, 0x45, 0x24, 0xc0, 0x21, 0x54, 0xbc, 0x8d, 0xee, 0x0b, 0x59,
		0x35, 0xfa, 0xec, 0x9c, 0x85, 0x7d, 0x1b, 0x9f, 0x59, 0x13, 0x5b, 0x74, 0x96, 0x92, 0x6b, 0x48,
		0x7a, 0xb0, 0x51, 0xf6, 0x46, 0x92, 0x1c, 0x18, 0x18, 0x97, 0x60, 0x23, 0xb7, 0x32, 0x00, 0x09,
		0x36, 0xaf, 0x25, 0xea, 0x52, 0x33, 0xff, 0x79, 0x79, 0x1d, 0xe9, 0xc4, 0x3b, 0xb6, 0x57, 0x57,
		0xd8, 0x1d, 0xb9, 0x59, 0xfd, 0x31, 0xb1, 0x96, 0x58, 0x26, 0x9b, 0xbb, 0x9e, 0x38, 0xc6, 0xbd,
		0xbd, 0x89, 0x60, 0x5f, 0x98, 0x03, 0xae, 0x4c, 0xc2, 0xfd, 0xe8, 0xb5, 0x10, 0xe2, 0xbd, 0xbc,
		0xb7, 0xbe, 0xed, 0x19, 0x95, 0x4e, 0x07, 0x78, 0xaf, 0x01, 0xef, 0x9d, 0x0e, 0xf2, 0x29, 0x5f,
		0x79, 0x40, 0xe4, 0x53, 0x12, 0xc2, 0x0b, 0x25, 0xcc, 0x90, 0xc3, 0x0d, 0x35, 0xec, 0x28, 0x83,
		0x1f, 0x65, 0x30, 0xa4, 0x02, 0x8e, 0xcc, 0xd0, 0xfc, 0xc8, 0x76, 0xc8, 0x62, 0x92, 0x42, 0xbf,
		0x47, 0xf6, 0x72, 0x2a, 0xec, 0x92, 0xa9, 0x06, 0x35, 0x65, 0xe0, 0xa6, 0x0a, 0xe4, 0x94, 0x83,
		0x9d, 0x72, 0xd0, 0x53, 0x09, 0x7e, 0x34, 0x20, 0x48, 0x04, 0x86, 0x74, 0xa1, 0xba, 0xc2, 0xd0,
		0x5d, 0x45, 0x28, 0xbf, 0x36, 0xb4, 0x2f, 0x44, 0x66, 0x74, 0x3c, 0xa3, 0x51, 0x2f, 0xfc, 0x60,
		0xf2, 0x7d, 0xa4, 0x29, 0x9b, 0xb2, 0x67, 0x47, 0xb1, 0x57, 0x34, 0x78, 0x50, 0xe8, 0x1f, 0xe7,
		0xce, 0x06, 0x17, 0x09, 0x17, 0x09, 0x17, 0x09, 0x17, 0x09, 0x17, 0xc9, 0xd4, 0x45, 0xde, 0xbf,
		0xb8, 0xc8, 0xff, 0x69, 0x0d, 0x7c, 0x5f, 0x78, 0xe1, 0x6e, 0xbe, 0xb0, 0xb7, 0xf7, 0xa2, 0x96,
		0x37, 0x26, 0x1f, 0x99, 0xc5, 0xf5, 0x60, 0xc5, 0xcf, 0xe2, 0x23, 0xb7, 0xc5, 0xf7, 0x1c, 0x32,
		0x64, 0x24, 0xbc, 0xc4, 0xfa, 0xf7, 0x90, 0xa6, 0x71, 0x0f, 0xbd, 0x60, 0xd3, 0x6b, 0x59, 0xe2,
		0x7b, 0x78, 0x1c, 0x0a, 0x57, 0x74, 0x45, 0xe8, 0x3f, 0x59, 0x3d, 0xcf, 0x6a, 0x7d, 0x89, 0x3a,
		0x96, 0x2a, 0x11, 0x71, 0xa2, 0xa9, 0xef, 0x0a, 0x54, 0x1c, 0xee, 0x02, 0x4e, 0x03, 0x49, 0x5b,
		0xaf, 0x4c, 0x6a, 0x99, 0xdb, 0xe6, 0xca, 0x5a, 0x8d, 0x4f, 0xfc, 0xd5, 0x8d, 0xe8, 0xa0, 0xcc,
		0x47, 0x5a, 0xa4, 0x83, 0x32, 0x1f, 0x6c, 0x61, 0xb0, 0x08, 0x59, 0xb0, 0x85, 0xa1, 0x8c, 0x94,
		0x61, 0x0b, 0x03, 0xfa, 0x0c, 0xf4, 0x19, 0xe8, 0x33, 0xd0, 0x67, 0xa0, 0xcf, 0x28, 0xd0, 0x67,
		0xb0, 0x85, 0xb1, 0x83, 0x2d, 0x0c, 0xb8, 0x48, 0xb8, 0x48, 0xb8, 0x48, 0xb8, 0x48, 0xb8, 0x48,
		0x6c, 0x61, 0x98, 0x15, 0x2d, 0x6f, 0x8b, 0x5e, 0x9c, 0xad, 0x3a, 0xdf, 0x39, 0xb9, 0x18, 0xa5,
		0xbe, 0xba, 0xad, 0x9d, 0x8b, 0x95, 0x1b, 0x5f, 0xed, 0x3b, 0x6b, 0xd7, 0x59, 0xaa, 0x00, 0xf3,
		0x84, 0xf3, 0xf8, 0xe5, 0xa1, 0xe7, 0x07, 0xf2, 0xab, 0xbf, 0x5e, 0x0e, 0xcd, 0xbc, 0xf2, 0xab,
		0x8c, 0x52, 0x5f, 0x83, 0x02, 0x15, 0x94, 0xfa, 0x32, 0xae, 0xfd, 0x9a, 0xae, 0x79, 0xba, 0x9d,
		0xd3, 0xf8, 0x0c, 0xa8, 0xff, 0xc2, 0xe4, 0x41, 0xed, 0x6a, 0x09, 0x26, 0x0f, 0xaa, 0x0b, 0x08,
		0xc9, 0xb6, 0x4f, 0xa7, 0x90, 0x62, 0xd9, 0xed, 0xb6, 0x2f, 0x82, 0x80, 0x5e, 0x25, 0x5e, 0x3a,
		0x23, 0x94, 0x62, 0xd5, 0x20, 0xa7, 0x0e, 0xec, 0x54, 0x81, 0x9e, 0x72, 0xf0, 0x53, 0x0e, 0x82,
		0x4a, 0xc1, 0x90, 0x4e, 0x77, 0xdb, 0x81, 0x56, 0xbc, 0x19, 0x27, 0x53, 0xa1, 0x15, 0xef, 0xed,
		0x8d, 0x95, 0xb8, 0xc2, 0x12, 0x36, 0x6f, 0xf3, 0xde, 0x29, 0x49, 0x16, 0xe4, 0x92, 0x29, 0x51,
		0x49, 0xa0, 0x84, 0xc4, 0x9e, 0x4c, 0x45, 0x80, 0x0f, 0x84, 0x0f, 0x84, 0x0f, 0x64, 0x19, 0x28,
		0xc4, 0x27, 0x68, 0xd3, 0x87, 0x0a, 0x4b, 0x4b, 0xb3, 0x4d, 0x1d, 0x2c, 0x28, 0x0a, 0x1a, 0x94,
		0x05, 0x0f, 0x2a, 0x01, 0x54, 0x3d, 0x90, 0xaa, 0x06, 0x54, 0x6d, 0xc0, 0xaa, 0x0d, 0x60, 0xb5,
		0x00, 0x2d, 0x2d, 0xe0, 0x12, 0x03, 0xaf, 0xba, 0x20, 0x64, 0x69, 0xbd, 0x39, 0xfd, 0x6f, 0x15,
		0x45, 0xf8, 0x38, 0x47, 0x2a, 0x0f, 0x15, 0x9c, 0xeb, 0xda, 0x0e, 0x43, 0xe1, 0x7b, 0x24, 0xe5,
		0x9c, 0x2b, 0x4f, 0xb8, 0xbb, 0x7b, 0x5f, 0xb4, 0x8e, 0x1a, 0xcf, 0xf7, 0x25, 0xeb, 0xa8, 0x31,
		0xfe, 0xb2, 0x14, 0xfd, 0x6f, 0xfc, 0x75, 0xf9, 0xbe, 0x68, 0x55, 0xa6, 0x5f, 0x57, 0xef, 0x8b,
		0x56, 0xb5, 0x91, 0xff, 0xfc, 0x79, 0x2f, 0xff, 0x63, 0x7f, 0xb8, 0xf9, 0x07, 0x77, 0xff, 0xfb,
		0xfe, 0xf3, 0xe7, 0xfe, 0x8f, 0xcb, 0xe1, 0xe8, 0xef, 0xf3, 0x61, 0xe3, 0xef, 0xf9, 0xdf, 0xe8,
		0x57, 0x57, 0xe3, 0x8d, 0x99, 0x6b, 0x97, 0x70, 0xdd, 0xe6, 0xba, 0xbd, 0xb6, 0x50, 0xc7, 0x66,
		0xa2, 0xb3, 0x81, 0xc7, 0x80, 0xc7, 0x80, 0xc7, 0x80, 0xc7, 0x80, 0xc7, 0xbc, 0xf0, 0x98, 0xb6,
		0xf0, 0x42, 0x27, 0x7c, 0xa2, 0x15, 0x56, 0x97, 0x68, 0x4c, 0x55, 0xc1, 0xb9, 0xce, 0x26, 0xb7,
		0xf6, 0xce, 0x0e, 0x14, 0x2e, 0xf3, 0xe9, 0x83, 0xbd, 0x3e, 0xbb, 0x68, 0x5e, 0x5c, 0x9d, 0xd6,
		0x55, 0xad, 0xf2, 0x4f, 0xb6, 0x3b, 0x10, 0x81, 0x32, 0xce, 0xb6, 0x43, 0xd6, 0x9a, 0xe3, 0xd5,
		0x4f, 0xb6, 0x79, 0x5a, 0xbf, 0xbc, 0xad, 0xe7, 0x94, 0x5d, 0xc4, 0xf0, 0xed, 0xd6, 0x3c, 0xd9,
		0xdb, 0xeb, 0x93, 0x1b, 0xa5, 0x8f, 0x56, 0xc9, 0x99, 0x1a, 0xa6, 0x7b, 0x1f, 0x23, 0x79, 0xbe,
		0xb2, 0x64, 0x87, 0x25, 0x73, 0x56, 0x94, 0xf4, 0x00, 0xfe, 0x0f, 0xfe, 0x0f, 0xfe, 0x0f, 0xfe,
		0x6f, 0x26, 0xff, 0x87, 0x8e, 0x29, 0xef, 0x84, 0xd0, 0x31, 0xb7, 0x99, 0xdf, 0x88, 0x20, 0xb4,
		0x1f, 0x5c, 0x27, 0xf8, 0x42, 0x38, 0xfd, 0x7a, 0x3d, 0xc7, 0x99, 0x3d, 0x3b, 0x78, 0x0e, 0x78,
		0x0e, 0x78, 0x0e, 0x78, 0x0e, 0x78, 0x4e, 0xbc, 0xde, 0x42, 0xa7, 0x2b, 0x42, 0xa7, 0xf5, 0x35,
		0xa8, 0x55, 0x14, 0xd2, 0x1c, 0x15, 0x2c, 0xe7, 0xa3, 0xe7, 0x44, 0xad, 0x77, 0x73, 0x9e, 0xed,
		0xf5, 0x02, 0xd1, 0xea, 0x79, 0x6d, 0x25, 0x4c, 0xee, 0x26, 0xea, 0x90, 0xab, 0x8a, 0x5b, 0xa9,
		0x53, 0xc4, 0x72, 0x17, 0x8e, 0xa7, 0x0c, 0x2d, 0x15, 0xfb, 0xd4, 0xa5, 0xd3, 0x46, 0xaa, 0xb1,
		0x86, 0xf3, 0x7e, 0xf0, 0xed, 0x56, 0xe8, 0xf4, 0xbc, 0x53, 0xe7, 0x71, 0x6c, 0xbd, 0xc5, 0x2c,
		0xca, 0xb8, 0xb9, 0x0b, 0xfb, 0xfb, 0xd6, 0x99, 0x52, 0xe9, 0xb0, 0x52, 0xa9, 0x1d, 0x54, 0x2a,
		0xc5, 0x83, 0xfd, 0x83, 0xe2, 0x51, 0xb5, 0x5a, 0xaa, 0xa9, 0xd8, 0xed, 0x61, 0x63, 0x5d, 0x6f,
		0xb2, 0x71, 0x16, 0x44, 0x7a, 0x3f, 0x8b, 0xf4, 0xbe, 0xf7, 0x1d, 0x5f, 0xe8, 0x50, 0xb2, 0xa7,
		0x67, 0x46, 0x84, 0x87, 0x08, 0x0f, 0x11, 0x1e, 0x22, 0x3c, 0x44, 0x78, 0x88, 0xf0, 0x10, 0xe1,
		0x21, 0xc2, 0x43, 0x84, 0x87, 0x08, 0x0f, 0x11, 0x1e, 0x22, 0xbc, 0x6d, 0x88, 0xf0, 0x8c, 0x2a,
		0x0d, 0x25, 0x6e, 0x2a, 0x1a, 0x9f, 0x47, 0x5f, 0xdb, 0xc5, 0xb8, 0xeb, 0x5e, 0xfc, 0x55, 0x81,
		0xb2, 0xbc, 0x7e, 0x47, 0x5b, 0x47, 0xc6, 0xcb, 0xe9, 0x8d, 0xc6, 0x5f, 0x51, 0xf4, 0x1b, 0xa5,
		0x33, 0x73, 0xde, 0xcd, 0x96, 0xfe, 0x10, 0x4f, 0x0a, 0x72, 0xf6, 0x72, 0xe7, 0x4e, 0x10, 0x9e,
		0x84, 0x21, 0x51, 0x63, 0xa7, 0x0b, 0xc7, 0xab, 0xbb, 0x62, 0x14, 0x29, 0x06, 0x34, 0xfe, 0x79,
		0xc4, 0x37, 0x66, 0xce, 0xa0, 0xc6, 0x13, 0xe7, 0xae, 0xfc, 0xb6, 0xf0, 0x45, 0xfb, 0xdd, 0xe8,
		0x0d, 0x79, 0x03, 0xd7, 0x45, 0x1b, 0x67, 0x26, 0x48, 0x9b, 0x99, 0x2e, 0xce, 0xcb, 0xd8, 0x8a,
		0x2e, 0xce, 0x1a, 0x8d, 0x9d, 0x83, 0x91, 0x1b, 0xdf, 0xc1, 0x39, 0xb6, 0xe9, 0x2c, 0xb5, 0x6f,
		0x96, 0xdb, 0xa0, 0x89, 0xa4, 0x21, 0x13, 0xda, 0x36, 0xa3, 0x6d, 0x33, 0xda, 0x36, 0x4b, 0x75,
		0x33, 0xd2, 0xdb, 0x36, 0x3f, 0xf4, 0x46, 0x94, 0xd2, 0xf2, 0x7b, 0x83, 0x50, 0x10, 0xf6, 0x6e,
		0x9e, 0x3f, 0x8d, 0xec, 0xf6, 0xb0, 0xa2, 0x63, 0x0f, 0xdc, 0xe8, 0xed, 0x47, 0x23, 0xbc, 0x89,
		0x1a, 0x44, 0x17, 0xd1, 0x20, 0x1a, 0x0d, 0xa2, 0x19, 0xc1, 0x9e, 0x12, 0xf8, 0x33, 0x43, 0xb3,
		0x20, 0xdb, 0xe4, 0x9c, 0x01, 0xb0, 0x9e, 0x2b, 0x6c, 0x8f, 0xc2, 0xe0, 0xa7, 0x2c, 0xa9, 0xb4,
		0x05, 0xc3, 0xd5, 0x1f, 0x02, 0xdf, 0x1a, 0xfb, 0x02, 0x42, 0x5f, 0xf3, 0x72, 0x0e, 0x38, 0x1a,
		0x38, 0x1a, 0x38, 0x1a, 0x38, 0x1a, 0x38, 0x9a, 0x6d, 0x73, 0x34, 0xad, 0xde, 0xc0, 0x0b, 0x85,
		0x1f, 0xd0, 0xb9, 0x99, 0xf8, 0x0c, 0x18, 0x47, 0x03, 0x27, 0x00, 0x27, 0xb0, 0x45, 0x4e, 0x80,
		0x6c, 0x1c, 0xcd, 0x43, 0xaf, 0x17, 0x06, 0xa1, 0x6f, 0xf7, 0xad, 0xae, 0x08, 0x02, 0xfb, 0x51,
		0x28, 0x18, 0x48, 0xb3, 0xe2, 0x9c, 0x18, 0x49, 0xa3, 0x1a, 0xe8, 0xd4, 0x01, 0x9e, 0x2a, 0xe0,
		0x53, 0x0e, 0x80, 0xca, 0x81, 0x50, 0x29, 0x20, 0xd2, 0x00, 0x23, 0x11, 0x40, 0xd2, 0xb3, 0xe5,
		0xa5, 0xf5, 0x32, 0x70, 0xbc, 0x70, 0xbf, 0xac, 0x60, 0x22, 0x0d, 0xe5, 0x40, 0x1a, 0x35, 0x69,
		0xde, 0x0a, 0x2a, 0x01, 0x54, 0xa6, 0x75, 0x2b, 0xce, 0xc1, 0x55, 0x9d, 0xc6, 0xad, 0x23, 0xc1,
		0x56, 0x41, 0xda, 0xb6, 0xd2, 0x74, 0x6d, 0x5d, 0x26, 0x52, 0x29, 0x1f, 0x55, 0x8e, 0x6a, 0x07,
		0xe5, 0xa3, 0x6a, 0x86, 0x6d, 0xc5, 0xd0, 0xe4, 0xe5, 0xc6, 0x16, 0xcf, 0xf6, 0xfa, 0x22, 0x5c,
		0xb7, 0xa7, 0x30, 0xc4, 0x58, 0x38, 0x1f, 0xc2, 0x0b, 0x84, 0x17, 0x08, 0x2f, 0x10, 0x5e, 0x20,
		0xbc, 0x40, 0x78, 0x81, 0xf0, 0x02, 0xe1, 0x05, 0xc2, 0x0b, 0x84, 0x17, 0x08, 0x2f, 0xb2, 0x13,
		0x5e, 0xfc, 0x6f, 0xcf, 0xf1, 0xac, 0xbe, 0x3f, 0xf0, 0x84, 0xc2, 0x18, 0x63, 0xd5, 0x49, 0x11,
		0x68, 0x20, 0xd0, 0x40, 0xa0, 0x81, 0x40, 0x03, 0x81, 0x06, 0x02, 0x0d, 0x04, 0x1a, 0x08, 0x34,
		0x10, 0x68, 0x20, 0xd0, 0x40, 0xa0, 0xa1, 0x29, 0xd0, 0x40, 0xab, 0x02, 0x2d, 0x55, 0xdc, 0x51,
		0x3d, 0x6f, 0x81, 0x28, 0x57, 0x75, 0x47, 0x5b, 0x49, 0x77, 0xd4, 0xef, 0xa5, 0xf9, 0x7e, 0x7a,
		0x5b, 0x5b, 0x90, 0xd0, 0xdc, 0x16, 0x76, 0xdb, 0x0a, 0x9d, 0x2e, 0x65, 0xe5, 0xcc, 0xcc, 0x39,
		0x50, 0xd9, 0x82, 0xa4, 0x66, 0xed, 0xb1, 0x30, 0x92, 0x9a, 0xd5, 0xb9, 0x40, 0xfa, 0xca, 0x96,
		0x51, 0x6c, 0x5b, 0xaa, 0x11, 0x16, 0xb6, 0xd4, 0x08, 0x0e, 0x4d, 0x1b, 0xcb, 0x12, 0x2a, 0x0a,
		0x2a, 0x62, 0x57, 0x55, 0xed, 0xc9, 0xe3, 0x7e, 0x97, 0xc4, 0xe7, 0x51, 0x18, 0x77, 0x50, 0xb6,
		0xc7, 0x57, 0x11, 0x93, 0xaa, 0x7e, 0xf5, 0xb5, 0x6a, 0x75, 0xbf, 0x9a, 0xa1, 0xd7, 0x6f, 0x48,
		0xd8, 0xd6, 0xd8, 0x06, 0x66, 0xed, 0x5b, 0x7d, 0xdf, 0xe9, 0xf9, 0x4e, 0xf8, 0x44, 0x48, 0xad,
		0x67, 0x4e, 0x02, 0x6e, 0x0d, 0x6e, 0x0d, 0x6e, 0x0d, 0x6e, 0x4d, 0x03, 0x2f, 0x56, 0x38, 0x3a,
		0x1b, 0x1d, 0xcb, 0x3e, 0x00, 0xcb, 0xce, 0x36, 0xcb, 0x2e, 0x82, 0x65, 0x6f, 0x2b, 0xcb, 0x56,
		0xb5, 0xd3, 0x03, 0xaa, 0xbd, 0x9d, 0x54, 0x5b, 0x78, 0xf6, 0x83, 0x4b, 0x30, 0x95, 0x3b, 0xf6,
		0x83, 0xd3, 0x13, 0xa0, 0xf1, 0x13, 0x28, 0x3c, 0x28, 0x3c, 0x28, 0xbc, 0x41, 0x14, 0x1e, 0x8d,
		0x9f, 0xa4, 0xdc, 0xeb, 0xb8, 0xd8, 0x30, 0xda, 0x00, 0xff, 0x66, 0xbb, 0x74, 0x9e, 0x66, 0xe1,
		0x3c, 0x70, 0x08, 0x70, 0x08, 0x70, 0x08, 0x70, 0x08, 0x12, 0xed, 0xbd, 0xef, 0x74, 0x63, 0x7c,
		0xa1, 0x16, 0x75, 0x28, 0x86, 0xd5, 0xc4, 0xd3, 0x32, 0xe9, 0x26, 0x65, 0x42, 0x38, 0xe2, 0xa4,
		0x1e, 0x60, 0x7b, 0x76, 0x6b, 0x85, 0xa3, 0x72, 0x15, 0x8a, 0x11, 0x14, 0x23, 0x02, 0x3a, 0x1f,
		0x67, 0xb2, 0x5a, 0x0e, 0xa1, 0x6c, 0x34, 0x77, 0x16, 0x50, 0x79, 0x50, 0x79, 0x50, 0x79, 0x50,
		0x79, 0x33, 0xf0, 0x65, 0x4e, 0xe0, 0x39, 0xdc, 0x02, 0x8f, 0x30, 0x53, 0xe9, 0x4d, 0xaf, 0xf2,
		0xac, 0x3a, 0x19, 0xfc, 0x03, 0xfc, 0x03, 0xfc, 0x03, 0xfc, 0x03, 0xa4, 0x1e, 0x48, 0x3d, 0x90,
		0x7a, 0x20, 0xf5, 0x40, 0xea, 0x81, 0xd4, 0x03, 0xa9, 0x27, 0xfd, 0x6b, 0xef, 0xda, 0xdf, 0x9d,
		0xee, 0xa0, 0x6b, 0x3d, 0xfa, 0xbd, 0x41, 0x9f, 0x70, 0x70, 0xcf, 0xc2, 0x79, 0x40, 0xe7, 0x41,
		0xe7, 0x41, 0xe7, 0x41, 0xe7, 0x25, 0xda, 0x3b, 0x59, 0x17, 0x27, 0xe4, 0xe0, 0x6f, 0x09, 0xbf,
		0x46, 0x0e, 0xfe, 0xd6, 0xf2, 0x6b, 0xe4, 0xe0, 0x83, 0x66, 0x93, 0xd2, 0xec, 0x5e, 0x5b, 0x10,
		0x92, 0xeb, 0xd1, 0xd1, 0x41, 0xa9, 0x41, 0xa9, 0x41, 0xa9, 0x41, 0xa9, 0x25, 0xda, 0xbb, 0xd3,
		0x16, 0x5e, 0xe8, 0x84, 0x4f, 0xbe, 0xe8, 0x50, 0x6e, 0xa0, 0x52, 0x88, 0xe3, 0x67, 0x93, 0x4b,
		0x7f, 0x67, 0x07, 0x82, 0xbe, 0x11, 0xf6, 0xf5, 0xd9, 0x45, 0xf3, 0xe2, 0xea, 0xb4, 0x4e, 0xb5,
		0xaa, 0x22, 0x9a, 0x12, 0x90, 0x76, 0x77, 0x25, 0xe6, 0x73, 0x8b, 0x4f, 0xaa, 0x79, 0x5a, 0xbf,
		0xbc, 0xad, 0xe7, 0x4c, 0x24, 0xc0, 0xaa, 0x9f, 0xd4, 0xed, 0xf5, 0xc9, 0x0d, 0xe9, 0xa3, 0x22,
		0x39, 0x72, 0x83, 0x3b, 0x1a, 0xbf, 0xe1, 0x75, 0x24, 0x49, 0x06, 0x4b, 0xd5, 0x55, 0x53, 0x77,
		0x37, 0x4d, 0x89, 0xc8, 0xaa, 0xb1, 0x79, 0xa6, 0x9c, 0x45, 0x9c, 0xde, 0xe0, 0xd2, 0x1d, 0x21,
		0xa5, 0xa9, 0x8e, 0xc8, 0xa8, 0xe4, 0xfc, 0xac, 0xdc, 0xb9, 0x13, 0x84, 0x27, 0x61, 0x28, 0xa7,
		0x4d, 0x67, 0xee, 0xc2, 0xf1, 0xea, 0xae, 0x18, 0xb1, 0xcb, 0x40, 0x4e, 0xa4, 0x92, 0xbb, 0xb0,
		0xbf, 0xcf, 0x1c, 0xb1, 0x74, 0x58, 0xa9, 0xd4, 0x0e, 0x2a, 0x95, 0xe2, 0xc1, 0xfe, 0x41, 0xf1,
		0xa8, 0x5a, 0x2d, 0xd5, 0x64, 0x70, 0xa0, 0xdc, 0x95, 0xdf, 0x16, 0xbe, 0x68, 0xbf, 0x1b, 0x3d,
		0x5d, 0x6f, 0xe0, 0xba, 0x5a, 0x5f, 0xb2, 0x64, 0x1c, 0xd2, 0x87, 0x3f, 0x12, 0x90, 0x47, 0x0b,
		0xe2, 0xa4, 0xc3, 0x9a, 0xe4, 0x08, 0x91, 0xec, 0x93, 0x09, 0xcd, 0x4d, 0x96, 0x99, 0xa9, 0x36,
		0xaf, 0x14, 0x46, 0xa5, 0xd0, 0x98, 0x92, 0x99, 0xd0, 0xe6, 0x06, 0xb0, 0xd9, 0x27, 0x36, 0x34,
		0x95, 0xb4, 0x26, 0xa2, 0xc4, 0x34, 0x12, 0xd8, 0x03, 0xb5, 0x1d, 0x6c, 0xf6, 0xf2, 0x5f, 0xff,
		0x0a, 0x37, 0x78, 0x7d, 0xb9, 0x31, 0xf5, 0xdb, 0xf4, 0xad, 0xc5, 0x21, 0x54, 0x12, 0xe6, 0x18,
		0xab, 0x12, 0x1b, 0x7e, 0x2c, 0x16, 0x36, 0xcb, 0x1b, 0x7e, 0x30, 0x85, 0x70, 0x39, 0x2b, 0x4c,
		0x7a, 0x22, 0x1c, 0xd9, 0x58, 0x12, 0x43, 0x4a, 0x29, 0x3e, 0x4a, 0x13, 0x17, 0xa5, 0x89, 0x87,
		0x8b, 0xe2, 0xe0, 0xf4, 0xd9, 0x30, 0x03, 0xa6, 0x53, 0x27, 0x19, 0x5f, 0xcd, 0xb5, 0xc7, 0x9d,
		0x71, 0xac, 0xae, 0x08, 0x7d, 0xa7, 0x95, 0xfc, 0xc5, 0xbd, 0xb4, 0xa0, 0x9f, 0x3b, 0x5e, 0xc2,
		0x87, 0x9e, 0x6e, 0xc7, 0x20, 0xf5, 0xce, 0x80, 0x8c, 0x1d, 0x00, 0x39, 0x0b, 0x4a, 0xd6, 0xc2,
		0x92, 0xbe, 0xc0, 0xa4, 0x2f, 0x34, 0xe9, 0x0b, 0x4e, 0x0f, 0x89, 0x4c, 0xad, 0xa4, 0xcb, 0x4b,
		0x42, 0x91, 0x90, 0x6c, 0x22, 0x29, 0xa9, 0x44, 0x4e, 0x1c, 0x2d, 0x4d, 0x84, 0x92, 0xbc, 0x21,
		0x29, 0x3b, 0xe9, 0x83, 0x62, 0x63, 0x7f, 0x28, 0x47, 0x78, 0x60, 0xff, 0x0a, 0x64, 0x27, 0x5f,
		0x90, 0xbc, 0x0b, 0x4d, 0xd1, 0x74, 0x43, 0x55, 0x08, 0x96, 0x80, 0x37, 0xa6, 0x6d, 0x2c, 0x28,
		0xa9, 0x81, 0x20, 0x88, 0x07, 0x88, 0xc7, 0xd6, 0x13, 0x8f, 0xf4, 0x8d, 0xec, 0x52, 0x36, 0xac,
		0x53, 0x03, 0x39, 0xe3, 0x8c, 0x84, 0x8e, 0x93, 0x62, 0x20, 0xd7, 0x42, 0x76, 0x43, 0x74, 0x2c,
		0x00, 0x0f, 0x80, 0x07, 0xc0, 0x93, 0x62, 0x15, 0xa5, 0xcd, 0x11, 0x92, 0x91, 0x0b, 0x24, 0x37,
		0xe7, 0x27, 0xbe, 0xc1, 0xb3, 0xcb, 0xdb, 0xbb, 0x93, 0xf3, 0xf3, 0xe6, 0xf5, 0xcd, 0xd5, 0xdd,
		0xd5, 0xfb, 0xab, 0xf3, 0xe6, 0xdd, 0x5f, 0xd7, 0x69, 0x13, 0x7d, 0x64, 0x26, 0xf4, 0x48, 0xe2,
		0xf6, 0xd3, 0xdb, 0x3d, 0x3d, 0xbb, 0xa9, 0xbf, 0xbf, 0x3b, 0xff, 0xab, 0xf9, 0xfe, 0xea, 0xf2,
		0xb2, 0xfe, 0xfe, 0xae, 0x7e, 0x9a, 0xe3, 0x10, 0xc8, 0x48, 0xbe, 0xcb, 0x77, 0xbf, 0x5f, 0x67,
		0xf1, 0xb6, 0xce, 0x7e, 0xbf, 0xc8, 0xe4, 0x7d, 0x5d, 0x9f, 0x5d, 0x64, 0xf1, 0xb6, 0x6e, 0xef,
		0x4e, 0xee, 0xce, 0xde, 0x67, 0xf1, 0xce, 0xae, 0x6e, 0xaf, 0x3f, 0x64, 0xf5, 0xbe, 0xf6, 0x33,
		0x89, 0x1c, 0xb7, 0x67, 0xb7, 0x59, 0xbc, 0xaf, 0xf3, 0xab, 0xf7, 0x27, 0xe7, 0xcd, 0x93, 0xdf,
		0x7f, 0xbf, 0xa9, 0xff, 0x7e, 0x72, 0x27, 0x21, 0x8b, 0x32, 0x9d, 0x10, 0xd4, 0x50, 0xcd, 0x0f,
		0x95, 0x44, 0x65, 0x93, 0x3d, 0xe8, 0x94, 0xf1, 0x58, 0x74, 0x14, 0x44, 0x62, 0x88, 0xc4, 0x10,
		0x89, 0x25, 0xb2, 0x9b, 0x20, 0xf4, 0x1d, 0xef, 0x51, 0x46, 0x10, 0x76, 0x88, 0xbc, 0x1f, 0x15,
		0x79, 0x3f, 0x49, 0x13, 0x9b, 0x49, 0x33, 0x7f, 0x12, 0xe4, 0x29, 0xd3, 0xe5, 0xfe, 0x38, 0x2d,
		0xcb, 0xef, 0x0d, 0x42, 0x11, 0xa4, 0xcb, 0x01, 0x7a, 0x39, 0x8c, 0xe2, 0x5c, 0xa0, 0xa2, 0x9e,
		0x5c, 0x20, 0xb7, 0xd7, 0xb2, 0x7c, 0xa4, 0x02, 0xad, 0xf2, 0x0e, 0x93, 0x47, 0x93, 0x95, 0x4c,
		0xa0, 0xb1, 0x75, 0xa7, 0xe7, 0x5e, 0x93, 0xe3, 0xa4, 0x63, 0x5f, 0xa5, 0x8c, 0xb0, 0xaf, 0xc4,
		0xcb, 0x07, 0xe4, 0x2b, 0xe9, 0xf2, 0xd2, 0xc3, 0xbd, 0x92, 0x2e, 0xbb, 0xf8, 0x00, 0xad, 0xa9,
		0xe5, 0x4a, 0xd2, 0x9a, 0x27, 0xc7, 0x4b, 0x5b, 0x5f, 0x93, 0x6a, 0x39, 0x4a, 0x5b, 0x96, 0x32,
		0x97, 0x27, 0xc9, 0x32, 0x95, 0xbd, 0x5c, 0xc9, 0x96, 0x2d, 0xd9, 0xf2, 0xa5, 0x5a, 0xc6, 0x72,
		0xc4, 0x92, 0xb4, 0x25, 0x48, 0x69, 0x97, 0x77, 0x7c, 0xa0, 0xb6, 0x08, 0x5a, 0xbe, 0xd3, 0x97,
		0x5a, 0x54, 0x39, 0x93, 0x7c, 0xfb, 0x72, 0xf0, 0xb7, 0x2c, 0xf3, 0xb4, 0x64, 0xf7, 0xec, 0xa0,
		0xe8, 0xd5, 0x41, 0x02, 0x0c, 0x54, 0x00, 0x41, 0x0e, 0x14, 0xe4, 0x80, 0x41, 0x0d, 0x1c, 0x72,
		0x00, 0x44, 0x12, 0x90, 0xc8, 0xd3, 0x6a, 0xe8, 0xb4, 0x1b, 0xc9, 0x5a, 0x8e, 0xfc, 0xf7, 0x20,
		0x23, 0x99, 0xb5, 0x2f, 0x17, 0x37, 0x5e, 0x3a, 0x81, 0x4b, 0x75, 0xd2, 0x40, 0x5f, 0xa0, 0x2f,
		0xd0, 0xd7, 0x24, 0xf4, 0x75, 0xfa, 0x96, 0x74, 0x03, 0x88, 0x01, 0xf8, 0x48, 0xe2, 0x31, 0x27,
		0x8f, 0x40, 0x6e, 0x17, 0x20, 0xca, 0x06, 0x52, 0xfd, 0x6f, 0x15, 0x8b, 0xac, 0xe1, 0xd8, 0x8b,
		0x8f, 0x23, 0x38, 0xf6, 0xb5, 0x1d, 0x86, 0xc2, 0xf7, 0xc8, 0x7a, 0x2e, 0xe5, 0x76, 0x77, 0xef,
		0x8b, 0xd6, 0x51, 0xe3, 0xf9, 0xbe, 0x64, 0x1d, 0x35, 0xc6, 0x5f, 0x96, 0xa2, 0xff, 0x8d, 0xbf,
		0x2e, 0xdf, 0x17, 0xad, 0xca, 0xf4, 0xeb, 0xea, 0x7d, 0xd1, 0xaa, 0x36, 0xf2, 0x9f, 0x3f, 0xef,
		0xe5, 0x7f, 0xec, 0x0f, 0x37, 0xff, 0x60, 0x61, 0x72, 0xb2, 0xfc, 0xf3, 0xee, 0x7d, 0xc9, 0x2a,
		0x37, 0xa6, 0xdf, 0xec, 0xdf, 0x17, 0xad, 0x72, 0x23, 0x9f, 0x97, 0xdf, 0x5c, 0xa8, 0x41, 0xf1,
		0x4a, 0xae, 0x6e, 0xcf, 0xfe, 0x24, 0x7f, 0x2f, 0xff, 0xe2, 0xf4, 0x62, 0xfe, 0x2b, 0xc7, 0xbd,
		0xdd, 0xe6, 0x5b, 0x83, 0xb0, 0xa8, 0x06, 0x2c, 0xfa, 0x19, 0x16, 0xd9, 0x56, 0xe7, 0xc4, 0xfa,
		0xd0, 0xf8, 0x51, 0x7a, 0x5b, 0x19, 0x1e, 0xe7, 0x7f, 0x1c, 0x0c, 0x17, 0x7f, 0xf8, 0xbc, 0xea,
		0xd7, 0x4a, 0x6f, 0x0f, 0x86, 0xc7, 0x6b, 0xfe, 0xa5, 0x36, 0x3c, 0x7e, 0xe5, 0x31, 0xaa, 0xc3,
		0xdd, 0xa5, 0x5f, 0x1d, 0xfd, 0xbc, 0xbc, 0xee, 0x03, 0x95, 0x35, 0x1f, 0xd8, 0x5f, 0xf7, 0x81,
		0xfd, 0x35, 0x1f, 0x58, 0x7b, 0x49, 0xe5, 0x35, 0x1f, 0xa8, 0x0e, 0x9f, 0x97, 0x7e, 0x7f, 0x77,
		0xf5, 0xaf, 0xd6, 0x86, 0xf9, 0xe7, 0x75, 0xff, 0x76, 0x30, 0x7c, 0x3e, 0xce, 0xe7, 0x0b, 0xbb,
		0xa5, 0x11, 0x2e, 0x1c, 0x8e, 0xa1, 0xa2, 0xd4, 0x58, 0x42, 0x90, 0x31, 0x22, 0x00, 0xa0, 0x97,
		0x00, 0x1a, 0xd6, 0xca, 0xd6, 0x5a, 0xf9, 0x7b, 0xad, 0x37, 0xbc, 0xae, 0x8b, 0x87, 0xbc, 0x12,
		0x88, 0xd0, 0x0a, 0xed, 0x47, 0xf9, 0xfa, 0xca, 0xf4, 0xc0, 0x10, 0x58, 0x20, 0xb0, 0x40, 0x60,
		0xd9, 0x42, 0x81, 0x25, 0xb4, 0x1f, 0x65, 0x4f, 0x58, 0x84, 0xbe, 0x82, 0x99, 0x37, 0x6a, 0x9e,
		0x76, 0x7c, 0xe1, 0x98, 0x79, 0xb3, 0xf9, 0x79, 0x30, 0xf3, 0x86, 0xed, 0xab, 0xc7, 0xcc, 0x1b,
		0x7d, 0x47, 0xdd, 0x56, 0x11, 0xee, 0x8b, 0xf8, 0x6e, 0x49, 0xdf, 0xeb, 0xce, 0x88, 0x06, 0x37,
		0x1b, 0x76, 0x2f, 0x46, 0xf3, 0xe5, 0x61, 0xfe, 0x6f, 0xf9, 0xdf, 0x10, 0x56, 0x2b, 0x0f, 0xab,
		0xd1, 0x43, 0x7b, 0xd3, 0x8a, 0x96, 0xb8, 0xd8, 0x62, 0xf2, 0x5d, 0x41, 0x4a, 0x52, 0xeb, 0x8e,
		0x8a, 0xba, 0x17, 0xa7, 0x75, 0x13, 0x5d, 0xf9, 0xe4, 0x9b, 0xe6, 0x44, 0x19, 0xd0, 0xd5, 0x48,
		0x3b, 0x45, 0x02, 0xba, 0x27, 0xbe, 0x87, 0xd6, 0x97, 0x9e, 0x84, 0x89, 0xbe, 0x2f, 0xe5, 0x99,
		0xf1, 0x21, 0x91, 0x9e, 0xac, 0x54, 0xa6, 0x41, 0x7a, 0x32, 0xd2, 0x93, 0x5f, 0xb5, 0xd8, 0xe5,
		0x0b, 0xb7, 0xf1, 0x91, 0xe5, 0x2a, 0xb7, 0x25, 0x28, 0xb7, 0x92, 0x0e, 0x0e, 0xe5, 0x56, 0x31,
		0x64, 0xc8, 0xa5, 0xba, 0xb2, 0x94, 0x5b, 0x59, 0x50, 0x12, 0x1f, 0x50, 0x52, 0x61, 0xd3, 0xda,
		0xc5, 0x20, 0x8d, 0x13, 0x12, 0xc2, 0x0b, 0x19, 0xcc, 0x50, 0xc2, 0x8d, 0x12, 0xd8, 0xa1, 0x86,
		0x1f, 0x65, 0x30, 0xa4, 0x0c, 0x8e, 0x54, 0xc1, 0x12, 0x8d, 0x62, 0x25, 0x7b, 0x72, 0xa9, 0x6c,
		0xb8, 0x8a, 0x0f, 0xec, 0x78, 0x6d, 0xf1, 0x9d, 0x7e, 0xdc, 0xe7, 0xf8, 0x34, 0x44, 0x16, 0x42,
		0xab, 0x02, 0x93, 0x81, 0x99, 0x0a, 0x50, 0x53, 0x0a, 0x6e, 0xaa, 0x40, 0x4e, 0x39, 0xd8, 0x29,
		0x07, 0x3d, 0xd5, 0xe0, 0x47, 0x03, 0x82, 0x44, 0x60, 0x18, 0x3f, 0x1c, 0xb2, 0x71, 0xce, 0x4b,
		0xab, 0x86, 0x4c, 0x80, 0x5f, 0x22, 0x62, 0x87, 0x86, 0x6c, 0xc7, 0x10, 0xbc, 0xd3, 0x5c, 0xca,
		0xe1, 0x3c, 0xaf, 0x7e, 0x9b, 0xa9, 0x86, 0xf6, 0xc0, 0x1b, 0xc1, 0x1b, 0xc1, 0x1b, 0xc1, 0x1b,
		0x69, 0xf4, 0x46, 0x64, 0x39, 0x4c, 0x8b, 0x18, 0x76, 0x40, 0x78, 0x0a, 0xda, 0x9c, 0xa6, 0xe9,
		0x1f, 0xda, 0x25, 0xbf, 0xa3, 0x2a, 0xc7, 0x49, 0x91, 0x73, 0x59, 0x3a, 0x9d, 0xa2, 0x9c, 0xa7,
		0xf8, 0x7c, 0x0a, 0xf3, 0x5e, 0x88, 0xe1, 0x60, 0xde, 0x44, 0x14, 0xe4, 0x42, 0xe9, 0x36, 0x11,
		0x55, 0xb9, 0x51, 0x5a, 0x6d, 0xe5, 0x8d, 0x99, 0x47, 0x6f, 0x6c, 0x71, 0x50, 0x21, 0x7d, 0xab,
		0x6f, 0xad, 0x5b, 0x96, 0xbc, 0xf5, 0x87, 0xc0, 0x02, 0x81, 0x05, 0x02, 0x0b, 0x04, 0x16, 0x2a,
		0x03, 0x0b, 0x4f, 0x5e, 0x4b, 0xb5, 0x9f, 0x41, 0x98, 0xcc, 0x0a, 0x94, 0x75, 0x8f, 0xcb, 0xf8,
		0xb8, 0x62, 0xa6, 0xd5, 0x8a, 0xdd, 0x6e, 0xfb, 0x22, 0x08, 0x72, 0x0a, 0xa8, 0xaa, 0x82, 0x37,
		0xa4, 0xf6, 0x4d, 0xa9, 0x7b, 0x63, 0x2b, 0xde, 0xdc, 0xb7, 0x8a, 0xc2, 0x77, 0xb7, 0xf4, 0x0e,
		0x0f, 0x15, 0x9e, 0x93, 0x3a, 0xd9, 0x7b, 0xed, 0x89, 0x55, 0xf6, 0x1e, 0xc9, 0x29, 0xbb, 0xb5,
		0x86, 0xca, 0x57, 0xa7, 0xa2, 0x07, 0xc1, 0xda, 0xb3, 0x2b, 0x6d, 0x1e, 0xf3, 0x5f, 0x0a, 0xdf,
		0xa0, 0x92, 0x33, 0x0d, 0xdf, 0x66, 0x18, 0x3c, 0x6b, 0x00, 0x4f, 0x25, 0xe0, 0x89, 0xbe, 0x20,
		0xea, 0xfb, 0x82, 0xc0, 0x95, 0x90, 0xb9, 0x12, 0x98, 0xb3, 0x7a, 0x73, 0xce, 0x9e, 0x63, 0x7d,
		0x63, 0xf6, 0x7d, 0x10, 0x13, 0x03, 0x85, 0xf1, 0xaf, 0xdb, 0x6b, 0xd9, 0xae, 0xd5, 0x16, 0x1d,
		0xc7, 0x13, 0x6d, 0x8b, 0x58, 0x64, 0x5d, 0x49, 0x05, 0x14, 0xec, 0x68, 0xc8, 0x9d, 0xc4, 0xbc,
		0xf1, 0x33, 0x1e, 0xcf, 0x7c, 0x3c, 0xad, 0x7f, 0x38, 0xbb, 0xac, 0x9f, 0x36, 0x2f, 0xeb, 0x7f,
		0xde, 0x35, 0xff, 0x71, 0x75, 0x9d, 0x53, 0xb9, 0x85, 0x14, 0x28, 0xf5, 0x17, 0x3f, 0xd4, 0x7a,
		0xa6, 0xf9, 0xe7, 0x7c, 0x7e, 0x76, 0xf9, 0x87, 0x3a, 0xbc, 0x1c, 0xbe, 0xcd, 0xfa, 0x53, 0x3d,
		0xbd, 0xb9, 0xba, 0x56, 0xf8, 0x3c, 0xdf, 0x64, 0xc3, 0xcb, 0x61, 0x33, 0x93, 0xf6, 0x7a, 0x29,
		0x36, 0x33, 0x7d, 0xd1, 0x1a, 0xf8, 0x84, 0x0e, 0x22, 0x5e, 0x52, 0xd3, 0x13, 0x11, 0x6d, 0x69,
		0x9c, 0x8a, 0x8e, 0x3d, 0x70, 0xa3, 0xed, 0x9e, 0x8e, 0xed, 0xd2, 0x9d, 0x07, 0x5b, 0xa6, 0xaf,
		0x7f, 0xe5, 0xd8, 0x32, 0x4d, 0x73, 0x42, 0x6c, 0x99, 0x32, 0xe2, 0x26, 0x0a, 0xb7, 0x4c, 0x1f,
		0x7a, 0x3d, 0x57, 0xd8, 0x4a, 0x36, 0x4d, 0x4b, 0xa6, 0x38, 0x3e, 0xd6, 0x95, 0x74, 0x92, 0x3b,
		0xc4, 0x2c, 0x1d, 0x5f, 0x4f, 0xc7, 0x98, 0xb8, 0xd5, 0x48, 0xfc, 0x55, 0x81, 0xa4, 0x60, 0x78,
		0x47, 0x47, 0x53, 0x99, 0x4b, 0xf1, 0x3d, 0xfc, 0x47, 0xaf, 0x1f, 0x4c, 0xbf, 0x90, 0xd2, 0x65,
		0x86, 0xce, 0x6a, 0x25, 0x5a, 0x6c, 0x4e, 0x78, 0xf6, 0x83, 0x2b, 0xac, 0x87, 0x4e, 0x9b, 0xae,
		0xb2, 0x7c, 0xe6, 0x1c, 0xa8, 0x2e, 0x57, 0x51, 0x5d, 0x2e, 0xff, 0x49, 0xef, 0xa0, 0xb4, 0x5c,
		0x02, 0x87, 0x1a, 0xbd, 0x17, 0xd4, 0x95, 0xcb, 0x39, 0x30, 0x51, 0x3b, 0x8c, 0xa5, 0xe5, 0x44,
		0xe6, 0xe5, 0x08, 0x01, 0x2c, 0xb3, 0xf1, 0x23, 0x0d, 0xb0, 0x21, 0x78, 0x34, 0x12, 0xf8, 0xcc,
		0x8c, 0x1c, 0xa9, 0x00, 0x71, 0x81, 0xd1, 0xb5, 0xe9, 0xad, 0x78, 0x9e, 0xde, 0xb5, 0xa9, 0x6d,
		0x58, 0x51, 0x2b, 0x66, 0x6a, 0xc8, 0x54, 0x09, 0x9d, 0xea, 0x21, 0x54, 0x35, 0x94, 0x6a, 0x83,
		0x54, 0x6d, 0xd0, 0xaa, 0x05, 0x62, 0x69, 0xa1, 0x96, 0x18, 0x72, 0xd5, 0x89, 0x76, 0x1a, 0xc4,
		0x3b, 0x45, 0x22, 0x1e, 0xbd, 0x01, 0x98, 0xe5, 0xc5, 0x89, 0x45, 0x3e, 0x7e, 0x62, 0xdf, 0x8b,
		0x86, 0x53, 0x20, 0x8d, 0x88, 0x78, 0xe8, 0x7f, 0xf5, 0xe8, 0x6e, 0xdf, 0x75, 0xda, 0x24, 0x4a,
		0x20, 0x9d, 0xc9, 0x0f, 0x49, 0xc4, 0x58, 0x3b, 0x54, 0xb0, 0x21, 0x3c, 0x3e, 0x8d, 0xe1, 0x61,
		0x76, 0x19, 0x61, 0x36, 0xc2, 0x6c, 0x84, 0xd9, 0x08, 0xb3, 0x11, 0x66, 0x23, 0xcc, 0x46, 0x98,
		0x8d, 0x30, 0x1b, 0x61, 0x36, 0xc2, 0x6c, 0x84, 0xd9, 0x08, 0xb3, 0x13, 0x84, 0xd9, 0x94, 0x01,
		0x11, 0xb7, 0x28, 0xfb, 0x36, 0xba, 0x57, 0xa4, 0x9f, 0xf1, 0x5f, 0x32, 0x1c, 0x97, 0x4a, 0x26,
		0x53, 0xd0, 0xe2, 0xc5, 0xb1, 0x0d, 0x59, 0x68, 0x34, 0x43, 0x02, 0x48, 0x87, 0x03, 0x10, 0x05,
		0x4a, 0x98, 0x6c, 0xa2, 0x2b, 0xd6, 0xc1, 0x64, 0x93, 0x6c, 0x3a, 0x44, 0xb2, 0x70, 0xe4, 0xa5,
		0x80, 0x58, 0xd8, 0x1d, 0x5f, 0x74, 0x28, 0xc7, 0xe7, 0x1e, 0xd0, 0x8c, 0xcf, 0x8d, 0x7c, 0xf8,
		0xde, 0xde, 0x64, 0x4b, 0xa7, 0x30, 0xc6, 0xc9, 0xad, 0xf0, 0x37, 0xa1, 0xf0, 0x3b, 0x76, 0x4b,
		0x58, 0xa3, 0xf7, 0x46, 0xe8, 0x77, 0x66, 0x4f, 0x83, 0xdc, 0x67, 0x15, 0xfe, 0xc7, 0xe9, 0xc0,
		0xf7, 0x30, 0xf4, 0x3d, 0x4e, 0x07, 0x99, 0xcf, 0x92, 0x0e, 0x8c, 0xcc, 0x67, 0x8d, 0x30, 0xa6,
		0x02, 0xce, 0x94, 0xc1, 0x9a, 0x2a, 0x78, 0x53, 0x0e, 0x73, 0xca, 0xe1, 0x4e, 0x25, 0xec, 0xd1,
		0x29, 0x5b, 0x3b, 0x26, 0x6f, 0xc8, 0xc6, 0x64, 0x4b, 0xdd, 0x96, 0xec, 0xcb, 0x29, 0xb1, 0x29,
		0xcb, 0x0d, 0x3c, 0x95, 0x83, 0xa8, 0x6a, 0x30, 0xd5, 0x06, 0xaa, 0xda, 0xc0, 0x55, 0x07, 0xc8,
		0xd2, 0x82, 0x2d, 0x31, 0xe8, 0xd2, 0x6b, 0x20, 0x1a, 0x34, 0x11, 0x95, 0x1a, 0xc9, 0x5a, 0xcd,
		0xa4, 0x10, 0x99, 0xdd, 0x71, 0xec, 0x00, 0x82, 0xc5, 0x1f, 0x4c, 0xbe, 0x8f, 0x36, 0x10, 0x4c,
		0xdd, 0x2a, 0xa6, 0xdc, 0x7b, 0x1c, 0x3c, 0x68, 0xf0, 0xd7, 0x73, 0x67, 0x85, 0xcb, 0x86, 0xcb,
		0x86, 0xcb, 0x86, 0xcb, 0x86, 0xcb, 0x86, 0xcb, 0x8e, 0x7e, 0x70, 0xff, 0xe2, 0xb2, 0xff, 0xa7,
		0x35, 0xf0, 0x7d, 0xe1, 0x85, 0xbb, 0xf9, 0xc2, 0xde, 0x5e, 0x21, 0xfe, 0x8d, 0xc6, 0xe4, 0x23,
		0xb3, 0x7e, 0x24, 0x58, 0xf1, 0xb3, 0xf8, 0xc8, 0xd2, 0xb7, 0x53, 0x14, 0x7a, 0x7f, 0xa3, 0xd4,
		0x85, 0xfa, 0xf7, 0x90, 0xb6, 0xbf, 0xab, 0x3a, 0x61, 0xac, 0xd7, 0xb2, 0xc4, 0xf7, 0xf0, 0x38,
		0x14, 0xae, 0xe8, 0x8a, 0xd0, 0x7f, 0xb2, 0x7a, 0x9e, 0xd5, 0xfa, 0x12, 0x0d, 0x33, 0x55, 0x2a,
		0x96, 0x45, 0x7d, 0x13, 0x15, 0xaa, 0x65, 0xa6, 0x09, 0x65, 0x0d, 0xe4, 0x3c, 0xca, 0x49, 0xe4,
		0x9a, 0xdb, 0x25, 0xdd, 0x86, 0xea, 0xc2, 0xb3, 0xe9, 0x0d, 0xdf, 0x88, 0x0e, 0x0a, 0x0c, 0x51,
		0x60, 0xb8, 0x41, 0x94, 0x57, 0xc6, 0x6e, 0x16, 0x9b, 0x68, 0x0e, 0xbb, 0x59, 0xdb, 0xcb, 0x37,
		0xb1, 0x9b, 0x05, 0x69, 0x0c, 0xd2, 0x18, 0xa4, 0x31, 0x48, 0x63, 0x90, 0xc6, 0xb6, 0x40, 0x1a,
		0xc3, 0x6e, 0xd6, 0xcf, 0x23, 0x18, 0xec, 0x66, 0xc1, 0x65, 0xc3, 0x65, 0xc3, 0x65, 0xc3, 0x65,
		0xc3, 0x65, 0x33, 0x71, 0xd9, 0xd8, 0xcd, 0x32, 0x57, 0x5d, 0xd8, 0xf2, 0x2d, 0x80, 0xec, 0x77,
		0x3e, 0x98, 0xdb, 0x01, 0x40, 0xf3, 0x03, 0x53, 0x16, 0x0e, 0xd3, 0x05, 0x93, 0xc9, 0xfe, 0x07,
		0xb3, 0x4b, 0x64, 0x1b, 0x4a, 0x52, 0x69, 0x76, 0xc1, 0x48, 0x77, 0xbf, 0xc8, 0x4b, 0x50, 0xcb,
		0x68, 0x81, 0xa0, 0x34, 0xb2, 0x43, 0x0b, 0x84, 0x6c, 0xba, 0x45, 0xb2, 0x52, 0x54, 0x9a, 0xbe,
		0x2d, 0x4b, 0x6b, 0x8a, 0xa2, 0x7f, 0x8b, 0x22, 0x69, 0x0b, 0x23, 0x5c, 0xb9, 0xca, 0x57, 0x18,
		0xe1, 0xba, 0xdd, 0x41, 0xb6, 0xba, 0x11, 0xae, 0x41, 0xe8, 0x3b, 0xde, 0xa3, 0x8a, 0x09, 0xae,
		0x87, 0x5b, 0x9c, 0x46, 0xd6, 0x15, 0xa1, 0xef, 0xb4, 0xe8, 0x9d, 0xd1, 0xe4, 0x3c, 0xf0, 0x46,
		0xf0, 0x46, 0xf0, 0x46, 0xf0, 0x46, 0xc6, 0x79, 0xa3, 0x81, 0xe3, 0x85, 0xfb, 0x65, 0x05, 0xde,
		0x88, 0x70, 0x3b, 0x24, 0x77, 0x13, 0xd5, 0x43, 0x50, 0x16, 0x7c, 0xec, 0x90, 0x17, 0x7d, 0x44,
		0x37, 0x72, 0xe1, 0x78, 0x0a, 0x37, 0x6a, 0x95, 0xec, 0xe2, 0xc7, 0xa7, 0xfb, 0x64, 0xbb, 0x03,
		0xa1, 0xf0, 0x7c, 0x1f, 0x7c, 0xbb, 0x15, 0x3a, 0x3d, 0xef, 0xd4, 0x79, 0x74, 0xa2, 0x72, 0xa0,
		0x22, 0xfd, 0xae, 0xac, 0x82, 0x2d, 0xbf, 0x0b, 0xfb, 0x7b, 0xe6, 0x4d, 0xa4, 0x52, 0x3e, 0xaa,
		0x1c, 0xd5, 0x0e, 0xca, 0x47, 0xd5, 0x0c, 0xdb, 0x8a, 0xa1, 0x7b, 0xa7, 0x8d, 0x2d, 0x0e, 0x2a,
		0xa6, 0x1b, 0x2e, 0xf4, 0x61, 0x45, 0x7c, 0x26, 0x04, 0x16, 0x08, 0x2c, 0x10, 0x58, 0x20, 0xb0,
		0x30, 0x2f, 0xb0, 0xf0, 0x9c, 0x9e, 0xa7, 0x42, 0xe5, 0x3a, 0x22, 0x3c, 0xc7, 0xe4, 0x71, 0x19,
		0x1f, 0x57, 0xc4, 0x5b, 0x27, 0x7d, 0xcb, 0x6e, 0xb7, 0x7d, 0x11, 0x04, 0x2a, 0x33, 0xe1, 0x8e,
		0x14, 0x9c, 0x4b, 0xc9, 0x9b, 0x52, 0xf7, 0xc6, 0x56, 0xbc, 0xb9, 0x6f, 0x15, 0x85, 0xef, 0x6e,
		0xe9, 0x1d, 0x1e, 0x2a, 0x3c, 0xe7, 0xb5, 0x1d, 0x86, 0xc2, 0xf7, 0x94, 0xbd, 0xce, 0xf8, 0xc4,
		0xbb, 0xbb, 0xf7, 0x45, 0xeb, 0xa8, 0xf1, 0x7c, 0x5f, 0xb2, 0x8e, 0x1a, 0xe3, 0x2f, 0x4b, 0xd1,
		0xff, 0xc6, 0x5f, 0x97, 0xef, 0x8b, 0x56, 0x65, 0xfa, 0x75, 0xf5, 0xbe, 0x68, 0x55, 0x1b, 0xf9,
		0xcf, 0x9f, 0xf7, 0xf2, 0x3f, 0xf6, 0x87, 0x9b, 0x7f, 0x30, 0xa7, 0xec, 0xd6, 0x1a, 0x2a, 0x5f,
		0xdd, 0xd5, 0xed, 0xd9, 0x9f, 0xda, 0xde, 0xdf, 0xbf, 0x54, 0xbe, 0xc0, 0xff, 0x52, 0xf8, 0x06,
		0x95, 0x9c, 0x69, 0xf8, 0x36, 0xc3, 0xe0, 0x59, 0x03, 0x78, 0x2a, 0x01, 0x4f, 0xdb, 0xea, 0x9c,
		0x58, 0x1f, 0x1a, 0x3f, 0x4a, 0x6f, 0x2b, 0xc3, 0xe3, 0xfc, 0x8f, 0x83, 0xe1, 0xe2, 0x0f, 0x9f,
		0x57, 0xfd, 0x5a, 0xe9, 0xed, 0xc1, 0xf0, 0x78, 0xcd, 0xbf, 0xd4, 0x86, 0xc7, 0xaf, 0x3c, 0x46,
		0x75, 0xb8, 0xbb, 0xf4, 0xab, 0xa3, 0x9f, 0x97, 0xd7, 0x7d, 0xa0, 0xb2, 0xe6, 0x03, 0xfb, 0xeb,
		0x3e, 0xb0, 0xbf, 0xe6, 0x03, 0x6b, 0x2f, 0xa9, 0xbc, 0xe6, 0x03, 0xd5, 0xe1, 0xf3, 0xd2, 0xef,
		0xef, 0xae, 0xfe, 0xd5, 0xda, 0x30, 0xff, 0xbc, 0xee, 0xdf, 0x0e, 0x86, 0xcf, 0xc7, 0x79, 0xb8,
		0x12, 0x3a, 0x57, 0x02, 0x73, 0x56, 0x6f, 0xce, 0xd9, 0x73, 0xac, 0x6f, 0xcc, 0xbe, 0x0f, 0x62,
		0x62, 0xa0, 0xb2, 0x0c, 0xac, 0xd7, 0xb2, 0x5d, 0xab, 0x2d, 0x3a, 0x8e, 0x27, 0xda, 0x16, 0xb1,
		0xc8, 0xba, 0x92, 0x0a, 0x28, 0xd8, 0xd1, 0xc8, 0x9d, 0xb5, 0x85, 0x17, 0x3a, 0xe1, 0xd3, 0x3b,
		0x3b, 0x50, 0x58, 0xf7, 0x39, 0x7d, 0xc6, 0xe7, 0x57, 0xef, 0x4f, 0xce, 0x9b, 0xa7, 0xf5, 0x0f,
		0x67, 0x97, 0xf5, 0xd3, 0xe6, 0x65, 0xfd, 0xcf, 0xbb, 0xe6, 0x3f, 0xae, 0xae, 0x73, 0x2a, 0xb7,
		0x90, 0x02, 0xa5, 0xfe, 0xe2, 0x87, 0x5a, 0xcf, 0x34, 0xff, 0x9c, 0xcf, 0xcf, 0x2e, 0xff, 0x50,
		0x87, 0x97, 0xc3, 0xb7, 0x59, 0x7f, 0xaa, 0xa7, 0x37, 0x57, 0xd7, 0x0a, 0x9f, 0xe7, 0x9b, 0x6c,
		0x78, 0x39, 0x6c, 0x66, 0xd2, 0x5e, 0x2f, 0xc5, 0x66, 0xa6, 0x2f, 0x5a, 0x03, 0x3f, 0x50, 0xd0,
		0x6a, 0x6f, 0x7a, 0x22, 0xaa, 0xe6, 0x5b, 0xa2, 0x63, 0x0f, 0xdc, 0x68, 0xbb, 0x27, 0x6a, 0x52,
		0x8a, 0x2d, 0xd3, 0x35, 0xf1, 0x14, 0xb6, 0x4c, 0x13, 0xbe, 0x78, 0x6c, 0x99, 0x9a, 0x80, 0xe7,
		0xe6, 0x6f, 0x99, 0x3e, 0xf4, 0x7a, 0xae, 0xb0, 0x95, 0x6c, 0x9a, 0x96, 0x50, 0x60, 0x2e, 0x63,
		0xdd, 0x6c, 0x4b, 0x81, 0x39, 0x55, 0x0f, 0x06, 0xfd, 0x85, 0xe5, 0x04, 0xed, 0x16, 0x24, 0x56,
		0x94, 0xbf, 0x61, 0x64, 0xf5, 0x23, 0x3f, 0x28, 0xbb, 0xfc, 0x32, 0x77, 0xee, 0x04, 0xe1, 0x49,
		0x18, 0xca, 0x2d, 0x48, 0xcd, 0x5d, 0x38, 0x5e, 0xdd, 0x15, 0x23, 0x8f, 0x16, 0xc8, 0x25, 0x54,
		0xb9, 0x0b, 0xfb, 0xfb, 0xcc, 0x91, 0x4b, 0x87, 0x95, 0x4a, 0xed, 0xa0, 0x52, 0x29, 0x1e, 0xec,
		0x1f, 0x14, 0x8f, 0xaa, 0xd5, 0x52, 0x4d, 0xa6, 0xbe, 0x93, 0xbb, 0xf2, 0xdb, 0xc2, 0x17, 0xed,
		0x77, 0xa3, 0xc7, 0xee, 0x0d, 0x5c, 0x97, 0x95, 0x35, 0x10, 0x61, 0x1f, 0x1b, 0xcc, 0xcb, 0x49,
		0xed, 0xe6, 0xa0, 0x17, 0xe5, 0xe4, 0xe0, 0x5b, 0x7a, 0x34, 0x4a, 0x77, 0x84, 0x94, 0x96, 0x2b,
		0xdb, 0x62, 0x75, 0x5b, 0xaa, 0x04, 0x03, 0xd5, 0x66, 0x98, 0xe9, 0x0c, 0x32, 0xb9, 0x19, 0xa5,
		0x30, 0xa1, 0x69, 0xec, 0x97, 0xd6, 0x74, 0x62, 0xb6, 0x2f, 0x25, 0x96, 0x94, 0xa4, 0x4a, 0x48,
		0x53, 0x1f, 0x64, 0xaa, 0x0c, 0x24, 0x6a, 0x82, 0x6c, 0xd5, 0x80, 0x4c, 0x1d, 0x20, 0x53, 0x01,
		0xa8, 0xa2, 0x7d, 0xbd, 0xe0, 0x2e, 0x2d, 0x4a, 0x27, 0x68, 0x19, 0x29, 0xb3, 0x25, 0x64, 0xdc,
		0xf2, 0x71, 0x6f, 0x6f, 0x32, 0x1c, 0xa7, 0x30, 0x31, 0x3b, 0x03, 0x21, 0x55, 0x4e, 0x97, 0x2b,
		0xa9, 0x5d, 0xad, 0x24, 0x75, 0xb1, 0x92, 0xd6, 0xb5, 0x0a, 0x80, 0x0a, 0x40, 0xd5, 0x02, 0xa8,
		0xb2, 0xba, 0x44, 0xe5, 0xda, 0x22, 0x68, 0xf9, 0x4e, 0x5f, 0x6a, 0xa4, 0x18, 0x5b, 0xf2, 0xec,
		0xc1, 0x65, 0xc9, 0x1c, 0x52, 0xf7, 0x79, 0xa4, 0xef, 0xeb, 0x50, 0xec, 0xe3, 0x90, 0xee, 0xdb,
		0x50, 0xed, 0xd3, 0x90, 0xef, 0xcb, 0x90, 0xef, 0xc3, 0x50, 0xef, 0xbb, 0xf0, 0x92, 0x0f, 0xa5,
		0xef, 0xa3, 0xd0, 0x75, 0x54, 0x92, 0xdc, 0x41, 0x49, 0x82, 0x70, 0x22, 0xc1, 0x4f, 0xf7, 0xe5,
		0xe2, 0x86, 0xdc, 0x38, 0x16, 0xe8, 0x0b, 0xf4, 0x05, 0xfa, 0x1a, 0x89, 0xbe, 0x4e, 0xdf, 0x92,
		0x6e, 0x00, 0x14, 0xa5, 0xa3, 0x34, 0x25, 0xa2, 0x84, 0xbd, 0x83, 0xa3, 0x92, 0x4f, 0xb2, 0x8c,
		0x13, 0xca, 0xe2, 0x24, 0xf2, 0x22, 0x24, 0xa5, 0x95, 0x9a, 0x85, 0xc9, 0xc9, 0xf2, 0xcf, 0xbb,
		0xf7, 0x25, 0xab, 0xdc, 0x98, 0x7e, 0xb3, 0x7f, 0x5f, 0xb4, 0xca, 0x0d, 0x8a, 0xf2, 0x9b, 0x06,
		0xc5, 0x2b, 0x51, 0x51, 0x4e, 0xa3, 0xb6, 0x02, 0xf3, 0x57, 0x2f, 0x86, 0xa0, 0x90, 0xa4, 0xc1,
		0x39, 0x1f, 0x85, 0x16, 0x8b, 0x6a, 0xc0, 0xa2, 0x9f, 0x61, 0x11, 0x2a, 0xc5, 0xd4, 0x57, 0x8a,
		0x15, 0x76, 0x4b, 0x23, 0x5c, 0x38, 0x1c, 0x43, 0x45, 0xa9, 0xb1, 0x84, 0x20, 0x63, 0x44, 0x00,
		0x40, 0x2f, 0x01, 0x34, 0xac, 0x95, 0xad, 0xb5, 0xf2, 0xf7, 0x5a, 0x6f, 0x78, 0x5d, 0x17, 0x0f,
		0x79, 0x25, 0x10, 0xa1, 0x15, 0xda, 0x8f, 0xf2, 0xf5, 0x95, 0xe9, 0x81, 0x21, 0xb0, 0x40, 0x60,
		0x81, 0xc0, 0xb2, 0x85, 0x02, 0x4b, 0x68, 0x3f, 0x5a, 0xe1, 0xe8, 0xe8, 0xd0, 0x57, 0xa4, 0x3e,
		0x57, 0xb2, 0xd6, 0xd7, 0x84, 0x2d, 0xaf, 0x89, 0x5b, 0x5d, 0x13, 0x16, 0xb9, 0xa8, 0x68, 0x6d,
		0xad, 0x6a, 0x30, 0xb5, 0xa2, 0x56, 0xd6, 0x2a, 0xdb, 0x12, 0x53, 0x0e, 0x44, 0x57, 0xd1, 0xb2,
		0x5a, 0xf5, 0xab, 0x57, 0xd5, 0xa2, 0x5a, 0xa9, 0x0d, 0x18, 0x52, 0x14, 0xb6, 0xad, 0x22, 0xdc,
		0x17, 0xf1, 0xdd, 0x22, 0x9b, 0x1e, 0x64, 0xb8, 0x06, 0x37, 0x1b, 0x76, 0x2f, 0x46, 0xf3, 0xe5,
		0x61, 0xfe, 0x6f, 0xf9, 0xdf, 0x10, 0x56, 0x2b, 0x0f, 0xab, 0x51, 0xee, 0x91, 0xba, 0xdc, 0x43,
		0x56, 0xe5, 0xa5, 0xf2, 0x52, 0x0f, 0x09, 0x85, 0x95, 0x29, 0x92, 0x92, 0xdf, 0x28, 0xb4, 0xb8,
		0x69, 0x61, 0x64, 0xaa, 0x28, 0x5d, 0x4e, 0x25, 0xa4, 0xbc, 0xca, 0x47, 0xd2, 0x4a, 0x47, 0x39,
		0x95, 0x8d, 0x49, 0x5f, 0x97, 0x24, 0x60, 0xd0, 0x03, 0x08, 0xb9, 0x54, 0xe9, 0xf6, 0x4a, 0x21,
		0x20, 0xd9, 0xe2, 0xdf, 0x7c, 0xe9, 0x6e, 0xf6, 0x89, 0x0d, 0xad, 0x26, 0xad, 0xb5, 0x28, 0xb6,
		0x92, 0x04, 0xe6, 0xa1, 0xcc, 0x2c, 0x36, 0xb3, 0x87, 0xd7, 0xbf, 0xd5, 0xd7, 0xfd, 0xe6, 0x2b,
		0xdf, 0x7b, 0x5c, 0xe5, 0x1e, 0xf5, 0xd0, 0xeb, 0x38, 0xc2, 0xdf, 0x89, 0x9e, 0xcc, 0x2b, 0x3f,
		0x9d, 0x08, 0xc5, 0x93, 0xa3, 0xb6, 0x54, 0x94, 0x4e, 0x86, 0xca, 0xaf, 0x7d, 0xae, 0x09, 0xd7,
		0x11, 0xf9, 0xfa, 0xd9, 0x60, 0xc5, 0x50, 0xae, 0x94, 0xd7, 0x2d, 0x8e, 0x5f, 0x9b, 0xfa, 0xcf,
		0x7f, 0xe3, 0x17, 0x2f, 0x6b, 0xd3, 0x97, 0x44, 0xf5, 0x72, 0x5e, 0xf1, 0x4e, 0x08, 0xde, 0xc5,
		0xcf, 0x5f, 0xc1, 0xfa, 0x07, 0xfb, 0x93, 0x87, 0x9a, 0x8b, 0x50, 0xd9, 0x72, 0x9d, 0xee, 0x58,
		0xbb, 0xf9, 0xf9, 0x23, 0x7d, 0xe9, 0x98, 0x36, 0xfb, 0xa9, 0x5f, 0xbc, 0xb2, 0xd7, 0xd5, 0xab,
		0xbd, 0x7a, 0x9f, 0x6e, 0x93, 0xfd, 0xb7, 0xd9, 0x7d, 0x35, 0xcf, 0xb1, 0xdc, 0xfd, 0xd7, 0xbc,
		0xb7, 0x0d, 0xb7, 0xcb, 0x12, 0x6f, 0x83, 0x25, 0xde, 0xde, 0x5a, 0xdc, 0xb6, 0x1a, 0xdf, 0x19,
		0xf1, 0xc2, 0x7b, 0x6d, 0xb5, 0xd5, 0xac, 0x69, 0xbc, 0xfe, 0x19, 0xae, 0xb0, 0xab, 0xd7, 0x3e,
		0xc5, 0xcd, 0xca, 0x21, 0x37, 0xde, 0x0e, 0x4e, 0xb2, 0xdd, 0x9b, 0xc4, 0xec, 0x92, 0x9a, 0x5f,
		0x6a, 0x33, 0x4c, 0x6d, 0x8e, 0x29, 0xcd, 0x92, 0x86, 0x24, 0x6d, 0x5a, 0x1c, 0x98, 0xb3, 0x3b,
		0xce, 0xe6, 0xcf, 0x7c, 0xfa, 0x9e, 0x47, 0x1f, 0xde, 0xf0, 0x61, 0x25, 0xdb, 0x0d, 0x48, 0x9c,
		0xcd, 0x90, 0x26, 0x6b, 0x21, 0x8d, 0x39, 0xa7, 0x35, 0x6b, 0x69, 0xe6, 0x2d, 0xcd, 0xcc, 0x25,
		0x99, 0xbb, 0x9a, 0xd8, 0x30, 0xf1, 0x9e, 0xbf, 0x84, 0x26, 0x03, 0x69, 0x9a, 0x0a, 0xac, 0x68,
		0x22, 0x30, 0x5a, 0x63, 0x54, 0xf1, 0xd9, 0x06, 0xf0, 0xdc, 0x9a, 0x2e, 0xc0, 0x84, 0x50, 0x31,
		0xf9, 0x7c, 0x32, 0xb4, 0x28, 0x01, 0x2d, 0x80, 0x16, 0x74, 0x68, 0x91, 0xb4, 0xa2, 0x3e, 0x91,
		0xf3, 0x94, 0xe0, 0x44, 0x53, 0x3a, 0xd3, 0xd4, 0xcb, 0x44, 0xc6, 0x72, 0x91, 0xb9, 0x6c, 0x64,
		0x2d, 0x1f, 0xe9, 0xcb, 0x48, 0xfa, 0x72, 0x92, 0xbc, 0xac, 0x92, 0x4b, 0xbb, 0x69, 0x64, 0xfe,
		0xd4, 0x09, 0x79, 0x2f, 0xc5, 0x2f, 0x93, 0x79, 0x1a, 0xe9, 0xba, 0x01, 0xc9, 0x18, 0x01, 0x22,
		0x77, 0xb4, 0x47, 0x7c, 0x83, 0x27, 0xa7, 0xa7, 0x37, 0xf5, 0xdb, 0xdb, 0xe6, 0x87, 0x93, 0x8b,
		0xb3, 0xf3, 0xbf, 0xd2, 0x5a, 0xa1, 0xc4, 0x11, 0x1c, 0x92, 0x53, 0xa9, 0x2f, 0xae, 0xcf, 0x6f,
		0x73, 0x1c, 0xb2, 0xc5, 0x25, 0xdf, 0xd7, 0xd9, 0xf5, 0xa7, 0x5a, 0x16, 0xef, 0xeb, 0xbc, 0xdc,
		0xac, 0xdf, 0xfd, 0xa3, 0x7e, 0x73, 0x59, 0xbf, 0xcb, 0xe8, 0x6b, 0xab, 0xe8, 0x6e, 0x13, 0xd4,
		0x50, 0x8d, 0xe6, 0x6f, 0x14, 0xbc, 0xb7, 0x9c, 0xed, 0xda, 0x7e, 0xd7, 0x0a, 0xbf, 0xf8, 0x22,
		0xf8, 0xd2, 0x73, 0xdb, 0x12, 0xd8, 0xd3, 0xc2, 0x01, 0xc1, 0xa4, 0xc0, 0xa4, 0xc0, 0xa4, 0x36,
		0xb6, 0x99, 0xd4, 0x29, 0xf7, 0x12, 0x52, 0xeb, 0x25, 0xa5, 0xd0, 0x4b, 0xc8, 0x28, 0x93, 0x99,
		0x12, 0x2f, 0xbb, 0xae, 0x4b, 0x72, 0x8a, 0x3b, 0x45, 0x1a, 0xb3, 0x8c, 0xaa, 0x3d, 0x99, 0xa9,
		0xe9, 0x54, 0xaf, 0x40, 0x76, 0xaa, 0x39, 0xc9, 0xbb, 0xd0, 0x94, 0xe8, 0xd7, 0x60, 0x4c, 0x42,
		0xba, 0xf6, 0x77, 0xa7, 0x3b, 0xe8, 0xa6, 0x27, 0x1f, 0xd3, 0x03, 0x81, 0x74, 0x80, 0x74, 0x80,
		0x74, 0x80, 0x74, 0x80, 0x74, 0x80, 0x74, 0x80, 0x74, 0x80, 0x74, 0xac, 0x7a, 0xcc, 0xff, 0xb1,
		0x7d, 0xcf, 0xf1, 0x1e, 0xad, 0x9e, 0xe7, 0x3e, 0xa5, 0x67, 0x1e, 0x73, 0x47, 0x4b, 0x08, 0xe4,
		0x92, 0xe6, 0x73, 0x82, 0xc6, 0x80, 0xc6, 0x6c, 0x35, 0x8d, 0x49, 0x3f, 0x1d, 0x32, 0xe5, 0xf4,
		0x47, 0x54, 0x66, 0xfc, 0x2c, 0x79, 0x79, 0x36, 0x67, 0x77, 0xf6, 0x9b, 0x42, 0xa2, 0x94, 0x94,
		0x1d, 0xa9, 0x29, 0xce, 0x51, 0xfd, 0xc5, 0x79, 0x74, 0x69, 0x33, 0x5f, 0x37, 0x27, 0x90, 0xc8,
		0x20, 0xed, 0x27, 0xd9, 0x20, 0x90, 0x54, 0x83, 0x3f, 0x52, 0x27, 0xfd, 0x94, 0x91, 0xf4, 0x83,
		0xa4, 0x9f, 0x5f, 0xb3, 0x1f, 0x24, 0xfd, 0x80, 0x6e, 0x81, 0x6e, 0x99, 0x47, 0xb7, 0x90, 0xf4,
		0xb3, 0xb9, 0x6e, 0x80, 0xa4, 0x1f, 0x85, 0xf7, 0x85, 0xa4, 0x1f, 0x53, 0x5f, 0x1b, 0x92, 0x7e,
		0x48, 0xa4, 0x2f, 0x24, 0xfd, 0x80, 0x49, 0x81, 0x49, 0xf1, 0x63, 0x52, 0xd8, 0x7f, 0x9b, 0xbd,
		0x10, 0xec, 0xbf, 0xe9, 0x76, 0xe8, 0xd8, 0x7f, 0xc3, 0xfe, 0x1b, 0x19, 0x09, 0x89, 0xf4, 0x60,
		0xd7, 0x15, 0xed, 0x69, 0x43, 0x9e, 0xd4, 0x2c, 0x64, 0xe9, 0x88, 0xa0, 0x21, 0xa0, 0x21, 0xa0,
		0x21, 0xa0, 0x21, 0xa0, 0x21, 0xa0, 0x21, 0xa0, 0x21, 0xa0, 0x21, 0xab, 0x1e, 0x33, 0x72, 0x8f,
		0x41, 0x3a, 0x40, 0x3a, 0x40, 0x3a, 0x40, 0x3a, 0x40, 0x3a, 0x40, 0x3a, 0x40, 0x3a, 0x94, 0x90,
		0x8e, 0x78, 0xa7, 0xc4, 0x12, 0xdf, 0x5b, 0x42, 0xb4, 0x85, 0x84, 0x3d, 0x98, 0x15, 0xc7, 0x04,
		0x15, 0x01, 0x15, 0x01, 0x15, 0xd9, 0xd8, 0x66, 0x4c, 0xcc, 0x1f, 0x46, 0x01, 0x04, 0x00, 0x0c,
		0x00, 0x06, 0x00, 0x43, 0x01, 0xc4, 0x4a, 0xb3, 0x30, 0xa3, 0x00, 0x22, 0xe9, 0x08, 0x23, 0xf2,
		0xfa, 0x87, 0x04, 0x23, 0x8a, 0x34, 0x4f, 0xa5, 0x78, 0x7d, 0x3e, 0x37, 0x26, 0x51, 0xc8, 0x5e,
		0x36, 0x8a, 0x96, 0x8b, 0x96, 0x79, 0x14, 0xab, 0x17, 0x08, 0x66, 0x52, 0xcc, 0xbf, 0x26, 0xa5,
		0x63, 0x29, 0x66, 0x5e, 0x09, 0xc5, 0x60, 0x8a, 0x40, 0x3c, 0x8e, 0xd6, 0x6a, 0x94, 0x53, 0xe0,
		0x78, 0x8f, 0xaf, 0x9f, 0x4d, 0xb1, 0xf8, 0x41, 0x33, 0xc6, 0x53, 0x04, 0x7e, 0x26, 0x67, 0x53,
		0x04, 0x3e, 0x9b, 0xc1, 0x14, 0x81, 0xff, 0xf8, 0x10, 0x6c, 0x3e, 0x92, 0x62, 0xfc, 0xb1, 0x6c,
		0x0c, 0xa3, 0x78, 0x95, 0x91, 0xa5, 0x0d, 0x5f, 0xf8, 0x4d, 0xa2, 0x78, 0x8d, 0x11, 0xd2, 0xb0,
		0xa2, 0x8d, 0xc7, 0x50, 0x8c, 0xac, 0x2d, 0x45, 0x99, 0xe9, 0xe8, 0xd3, 0xdb, 0xd1, 0x5a, 0x7e,
		0x23, 0x53, 0x96, 0x15, 0x91, 0xf3, 0x2f, 0x31, 0xdd, 0xc4, 0xd4, 0xd5, 0xc4, 0x80, 0x89, 0xeb,
		0x4b, 0x13, 0x4e, 0x5a, 0x58, 0x32, 0x96, 0xc4, 0xe5, 0xed, 0x29, 0x96, 0x07, 0x5b, 0x4d, 0x2b,
		0xd1, 0xb2, 0x81, 0xa0, 0x95, 0x64, 0x59, 0xe9, 0x51, 0xb3, 0x92, 0x2e, 0xb7, 0xf8, 0x00, 0x6d,
		0x3b, 0xb4, 0xfb, 0xae, 0xed, 0x09, 0x2b, 0x4c, 0x2b, 0x8c, 0xcd, 0x19, 0xdf, 0xc2, 0x71, 0x53,
		0xbe, 0x1f, 0x39, 0x1b, 0xbb, 0xa9, 0x97, 0xa7, 0xcc, 0x65, 0x2a, 0x7d, 0xb9, 0xca, 0x5e, 0xb6,
		0x64, 0xcb, 0x97, 0x6c, 0x19, 0x53, 0x2c, 0xe7, 0x74, 0xcb, 0x3a, 0xe5, 0xf2, 0x96, 0x27, 0x5a,
		0xaf, 0xe0, 0x8e, 0x96, 0xd4, 0x25, 0x3a, 0xe7, 0x3d, 0x2b, 0x12, 0x8e, 0x55, 0xf7, 0xc6, 0xe9,
		0x82, 0xba, 0x12, 0x1b, 0x52, 0xbc, 0xb2, 0x9c, 0xd3, 0xff, 0x56, 0xb3, 0xc6, 0x6b, 0x25, 0x45,
		0xc5, 0xc5, 0xd2, 0x3b, 0x9b, 0x3f, 0x2c, 0x20, 0x15, 0x90, 0x0a, 0x48, 0x65, 0x04, 0xa9, 0x33,
		0xcb, 0x53, 0x26, 0x98, 0x1e, 0x4a, 0x38, 0xd6, 0xb5, 0x1d, 0x86, 0xc2, 0xf7, 0xa4, 0xb4, 0xc3,
		0x88, 0x0e, 0xb8, 0xbb, 0x7b, 0xfc, 0x7c, 0x5f, 0xb4, 0x8e, 0x6c, 0xab, 0x73, 0x62, 0x7d, 0x68,
		0xfc, 0x28, 0xbe, 0xad, 0x0c, 0xf3, 0xc7, 0xf9, 0xdd, 0xc5, 0x9f, 0x1d, 0xe7, 0x7f, 0x14, 0xdf,
		0x56, 0x87, 0xbb, 0xbb, 0x2b, 0xfe, 0xe5, 0xb7, 0x55, 0xc7, 0xc8, 0x3f, 0xef, 0xee, 0xee, 0x96,
		0xab, 0xf7, 0x45, 0xab, 0xda, 0x78, 0x2e, 0xdf, 0x17, 0xad, 0x4a, 0x63, 0xf4, 0x3b, 0x8d, 0xe7,
		0xfb, 0x62, 0xa9, 0xf1, 0x5b, 0xf4, 0xe5, 0xf8, 0xef, 0xfc, 0xe7, 0xcf, 0x7b, 0xf9, 0x1f, 0xfb,
		0xc3, 0xd7, 0xfd, 0x72, 0x3e, 0xbf, 0x5b, 0x18, 0x5f, 0x43, 0x23, 0xff, 0x3c, 0xfe, 0xff, 0x8f,
		0xf2, 0x30, 0xff, 0xbc, 0x5b, 0xba, 0x2f, 0x5a, 0xa5, 0xc6, 0xf4, 0x1f, 0x4a, 0xa3, 0x83, 0x1c,
		0x8e, 0x7e, 0x5d, 0xd6, 0x82, 0xdc, 0xdd, 0xbd, 0xff, 0xd7, 0x71, 0xe3, 0xef, 0xc7, 0xf9, 0x1f,
		0xb5, 0xe1, 0xf4, 0xeb, 0xe8, 0xef, 0xfc, 0xf3, 0xee, 0xde, 0xdf, 0x3e, 0x7f, 0xde, 0xdb, 0xfb,
		0x5b, 0x7e, 0x7c, 0xd3, 0x93, 0xdf, 0xfb, 0xdb, 0xf8, 0x5f, 0x7f, 0x3b, 0x3e, 0x5e, 0xfa, 0x51,
		0x7e, 0xb7, 0xb0, 0xf7, 0xf7, 0x7c, 0xfa, 0x85, 0xd7, 0xd0, 0xba, 0xf0, 0x12, 0x6d, 0x04, 0xae,
		0x3d, 0x5a, 0xe2, 0x0d, 0xc2, 0xf5, 0x47, 0x94, 0xb8, 0x71, 0xb8, 0xf6, 0x24, 0x89, 0x36, 0x14,
		0x79, 0x91, 0x1c, 0xb7, 0xd7, 0xb2, 0x5d, 0xcb, 0x69, 0xcb, 0xe3, 0x37, 0xf1, 0x11, 0x41, 0x6d,
		0x40, 0x6d, 0x40, 0x6d, 0x38, 0x45, 0x8b, 0xa1, 0xff, 0xeb, 0xbd, 0xd5, 0xcd, 0x58, 0x8d, 0x81,
		0x88, 0xd7, 0xed, 0xbb, 0x81, 0xe5, 0xda, 0x0f, 0xc2, 0xb5, 0x1e, 0xdc, 0x5e, 0xeb, 0xab, 0xc4,
		0xd0, 0x6e, 0xf9, 0xd0, 0xc0, 0x40, 0x60, 0x20, 0x30, 0x90, 0x11, 0x06, 0x26, 0x1f, 0x8d, 0xbe,
		0x16, 0x04, 0x0f, 0xe4, 0x84, 0x76, 0xd3, 0xd1, 0xe9, 0xb3, 0xff, 0x8d, 0x00, 0xa5, 0xf0, 0xe8,
		0xf6, 0x1e, 0x6c, 0xb7, 0xe0, 0x8b, 0x40, 0xf8, 0xdf, 0x44, 0x7b, 0x0e, 0x60, 0x56, 0xfe, 0x74,
		0x3a, 0x7d, 0x3d, 0x66, 0x62, 0x88, 0x14, 0x10, 0x29, 0xa4, 0xf8, 0x64, 0xd2, 0x6d, 0xad, 0x94,
		0x99, 0xc4, 0xf1, 0x71, 0xe4, 0xe6, 0xde, 0x2d, 0xa4, 0x9a, 0x15, 0xa2, 0x5c, 0xa1, 0xe8, 0xef,
		0x42, 0xaa, 0x5d, 0xe7, 0x1d, 0xa9, 0x89, 0x7a, 0xb7, 0xe3, 0xab, 0xbc, 0x19, 0x5f, 0x64, 0xf3,
		0x76, 0x74, 0x91, 0xd1, 0xdf, 0x89, 0xfa, 0xab, 0x27, 0x7f, 0xff, 0x49, 0x8a, 0x65, 0x52, 0xc7,
		0x94, 0xb2, 0x62, 0xc9, 0xac, 0x15, 0xb7, 0x20, 0x11, 0x40, 0x39, 0x0f, 0x32, 0xb5, 0xac, 0x25,
		0x3d, 0xcf, 0x91, 0xc1, 0x6f, 0x66, 0x79, 0x8d, 0x14, 0x52, 0xa2, 0x06, 0xc0, 0x92, 0x0d, 0x8e,
		0x58, 0x11, 0x6f, 0x27, 0x2b, 0x51, 0xd9, 0x91, 0x99, 0xc3, 0x54, 0x06, 0x74, 0x01, 0xba, 0x14,
		0x40, 0x17, 0x72, 0x98, 0xa0, 0xc8, 0x40, 0x91, 0x81, 0x22, 0xb3, 0xb9, 0x97, 0x44, 0x0e, 0x13,
		0xd9, 0x2b, 0x43, 0x0e, 0x13, 0x20, 0x15, 0x90, 0xba, 0x75, 0x90, 0x8a, 0x1c, 0x26, 0xe4, 0x30,
		0xad, 0x78, 0x50, 0xc8, 0x61, 0x9a, 0x7f, 0x22, 0xd8, 0x99, 0x40, 0x0e, 0xd3, 0x1a, 0xf5, 0x0c,
		0x39, 0x4c, 0xa0, 0x36, 0xa0, 0x36, 0xc8, 0x61, 0x62, 0x8a, 0x78, 0xc8, 0x61, 0x02, 0x06, 0x02,
		0x03, 0xb7, 0x15, 0x03, 0x91, 0xc3, 0x84, 0x48, 0x01, 0x91, 0x42, 0x92, 0x5b, 0x08, 0x9c, 0xff,
		0x93, 0xb8, 0xb3, 0x14, 0x1d, 0x0d, 0xde, 0x11, 0xde, 0x11, 0xde, 0x91, 0x91, 0x77, 0x4c, 0x3d,
		0x1c, 0x63, 0x71, 0x6d, 0xca, 0xf0, 0x8d, 0x72, 0x86, 0x65, 0x4c, 0xff, 0xc8, 0x31, 0xff, 0x1d,
		0xd9, 0xc3, 0x33, 0x24, 0x83, 0xda, 0xd2, 0x61, 0x25, 0x0f, 0xd3, 0x88, 0x8f, 0x4b, 0x30, 0xc8,
		0x41, 0xd2, 0xf2, 0x58, 0x74, 0xf2, 0xc6, 0xbd, 0x2a, 0xd9, 0x43, 0x37, 0x94, 0xbc, 0xb3, 0x37,
		0x3c, 0x8e, 0xd2, 0x30, 0x90, 0x60, 0x0d, 0x02, 0x21, 0x51, 0x86, 0x8d, 0x8e, 0x06, 0x82, 0x05,
		0x82, 0x05, 0x82, 0x05, 0x82, 0x05, 0x82, 0x05, 0x82, 0x05, 0x82, 0x05, 0x82, 0x95, 0x01, 0x82,
		0x85, 0x2a, 0xbc, 0x9f, 0x55, 0xe1, 0xa5, 0x29, 0x9b, 0xd8, 0x51, 0x54, 0x84, 0x97, 0x60, 0xc8,
		0x47, 0xf2, 0xb7, 0x4f, 0xdb, 0xeb, 0x77, 0x32, 0x04, 0x24, 0x61, 0xca, 0x43, 0x3a, 0x69, 0x3c,
		0xbd, 0x14, 0x4e, 0x22, 0x7d, 0xa7, 0x93, 0xba, 0xcd, 0x1e, 0xb8, 0xb3, 0x7e, 0x61, 0x6a, 0x1d,
		0xb6, 0xb3, 0x76, 0x29, 0x9a, 0x31, 0x69, 0x87, 0xc7, 0x74, 0x98, 0x95, 0xef, 0x56, 0xcb, 0x68,
		0x98, 0x55, 0xaf, 0x53, 0xda, 0x60, 0x98, 0xd7, 0x0c, 0x54, 0xf1, 0xdd, 0x64, 0x73, 0x25, 0x5c,
		0xcc, 0x95, 0x50, 0xaa, 0x00, 0x6c, 0xf7, 0x5c, 0x09, 0x37, 0xd5, 0x5c, 0x09, 0x17, 0x73, 0x25,
		0x08, 0xc5, 0x2e, 0xcc, 0x95, 0xc0, 0x5c, 0x09, 0xb5, 0x1a, 0x32, 0x6a, 0xb2, 0xb5, 0x68, 0xc3,
		0xa8, 0xc9, 0x46, 0x4d, 0xb6, 0xea, 0x65, 0x2a, 0x7d, 0xb9, 0xca, 0x5e, 0xb6, 0x64, 0xcb, 0x97,
		0x6c, 0x19, 0x53, 0x2c, 0x67, 0x39, 0x5a, 0x24, 0x6a, 0xb2, 0x37, 0x3e, 0x56, 0x46, 0x6a, 0xb2,
		0x49, 0x2a, 0xb2, 0x01, 0xa7, 0x80, 0x53, 0xc0, 0x29, 0x27, 0x38, 0x45, 0x3d, 0x36, 0xea, 0xb1,
		0x57, 0x3c, 0xa8, 0xcc, 0xd5, 0x63, 0xa3, 0xfa, 0x17, 0x8e, 0x14, 0x8e, 0x14, 0x8e, 0x94, 0x2e,
		0x2e, 0x41, 0xf5, 0xef, 0x8a, 0xea, 0x5f, 0xba, 0xe2, 0x5f, 0x20, 0x20, 0x10, 0x10, 0x08, 0xc8,
		0x09, 0x01, 0x51, 0xfb, 0xab, 0x10, 0xa3, 0x91, 0xa7, 0xb7, 0x22, 0x65, 0xc4, 0x8d, 0xd2, 0x81,
		0x5c, 0xde, 0xdd, 0xf2, 0xdd, 0x28, 0x3b, 0xc8, 0x45, 0xb7, 0x7c, 0x75, 0xde, 0x1a, 0xdb, 0x9b,
		0x4a, 0xbc, 0x30, 0xb6, 0x37, 0xe5, 0x79, 0x57, 0x74, 0xcb, 0x97, 0x01, 0x60, 0xe8, 0x96, 0x0f,
		0xe8, 0x02, 0x74, 0x6d, 0x76, 0xe1, 0xc8, 0xcc, 0x40, 0xfc, 0x8f, 0xf8, 0x1f, 0xf1, 0xff, 0xe6,
		0x5e, 0x12, 0x99, 0x19, 0x74, 0xc2, 0x2a, 0x32, 0x33, 0x00, 0xa7, 0x80, 0xd3, 0x6d, 0x82, 0x53,
		0x64, 0x66, 0x20, 0x33, 0x63, 0xc5, 0x83, 0x42, 0x66, 0x86, 0x0c, 0x77, 0x8a, 0xcc, 0x0c, 0x38,
		0x52, 0x38, 0xd2, 0x2d, 0x89, 0x4b, 0x90, 0x99, 0x81, 0xcc, 0x0c, 0x20, 0x20, 0x10, 0x70, 0x6b,
		0x11, 0x10, 0x99, 0x19, 0x0a, 0x31, 0x1a, 0x99, 0x19, 0x3f, 0xcb, 0xcc, 0x60, 0xdc, 0x41, 0x29,
		0x4e, 0xcc, 0x40, 0x07, 0xa5, 0xe9, 0xc7, 0xd1, 0x41, 0x29, 0xed, 0x0b, 0xe0, 0xde, 0x41, 0x69,
		0xba, 0x30, 0x79, 0x75, 0x50, 0x9a, 0x2e, 0x45, 0x74, 0x50, 0x4a, 0xf9, 0x6e, 0x79, 0x74, 0x50,
		0x72, 0xd5, 0x76, 0x50, 0x0a, 0x85, 0xd5, 0xef, 0xb9, 0x4e, 0xcb, 0x11, 0x09, 0xfa, 0x28, 0xcd,
		0x7e, 0x98, 0xb8, 0x9b, 0x52, 0x59, 0x55, 0x37, 0xa5, 0x8d, 0x3c, 0x6e, 0x96, 0xfa, 0x29, 0x6d,
		0xe2, 0xc6, 0x35, 0x77, 0x54, 0x9a, 0xda, 0xdd, 0x53, 0xf2, 0xb6, 0x4a, 0x2f, 0x87, 0xd8, 0x96,
		0xde, 0x4a, 0x89, 0xa8, 0xe4, 0x36, 0x74, 0x57, 0x4a, 0xc2, 0x5f, 0xb9, 0xf6, 0x57, 0xb2, 0xbd,
		0xb6, 0xd3, 0xb6, 0x47, 0xc6, 0x6d, 0x87, 0x5f, 0x02, 0x09, 0x8d, 0x96, 0x16, 0x0e, 0x88, 0x8e,
		0x4b, 0x29, 0x16, 0x93, 0x6c, 0x21, 0xca, 0xc4, 0xcc, 0xbe, 0xa4, 0xc1, 0xe2, 0x8e, 0x79, 0xb9,
		0x7d, 0xf3, 0x6b, 0x47, 0x9e, 0x86, 0xbc, 0x70, 0x5c, 0x39, 0x0a, 0x72, 0x29, 0xf3, 0x0a, 0x72,
		0x28, 0xa0, 0x21, 0x93, 0x68, 0xc8, 0x69, 0x96, 0x34, 0x0f, 0x15, 0x39, 0xed, 0x52, 0x8f, 0x0f,
		0xd4, 0x76, 0x82, 0x96, 0xef, 0x74, 0x1d, 0xcf, 0x0e, 0x7b, 0xbe, 0x3c, 0x23, 0x89, 0xb3, 0x7a,
		0xe7, 0x0e, 0x2f, 0xe9, 0x7d, 0xca, 0x9d, 0x6c, 0x20, 0x0d, 0x08, 0x28, 0x00, 0x81, 0x10, 0x18,
		0xa8, 0x00, 0x82, 0x1c, 0x28, 0xc8, 0x01, 0x83, 0x16, 0x38, 0xe4, 0x00, 0x88, 0x24, 0x20, 0x89,
		0x6f, 0x55, 0xda, 0xb6, 0xd4, 0x92, 0xc5, 0xca, 0xdb, 0x9e, 0x5a, 0x62, 0x00, 0x07, 0x12, 0x8f,
		0x39, 0xb3, 0x5d, 0x15, 0xed, 0x62, 0x14, 0xe6, 0xa1, 0x8b, 0xc9, 0xe4, 0x10, 0x09, 0xaf, 0x3b,
		0xd7, 0xf3, 0x9d, 0xc7, 0xf1, 0x5d, 0x59, 0x76, 0xbb, 0x4d, 0x00, 0xfa, 0x8b, 0x27, 0x00, 0xec,
		0x03, 0xf6, 0x01, 0xfb, 0x80, 0x7d, 0x23, 0x60, 0x7f, 0x11, 0xbc, 0x32, 0x0a, 0xfc, 0x81, 0x47,
		0x8b, 0xfb, 0x81, 0x07, 0xd8, 0x07, 0xec, 0x03, 0xf6, 0x01, 0xfb, 0xe6, 0xc1, 0x7e, 0xe0, 0x65,
		0x09, 0xf5, 0xfb, 0x7e, 0x2f, 0xec, 0xb5, 0x7a, 0xae, 0x35, 0xbe, 0x45, 0xf9, 0xb0, 0xbf, 0x78,
		0x02, 0xe0, 0x3e, 0x70, 0x1f, 0xb8, 0x0f, 0xdc, 0x37, 0x02, 0xf7, 0x17, 0xc1, 0x2b, 0x43, 0xc0,
		0x3f, 0x4d, 0x19, 0x73, 0x9d, 0x20, 0x0c, 0xe4, 0xc3, 0xfe, 0xfc, 0xe1, 0xe5, 0x82, 0x7e, 0x09,
		0xa0, 0x0f, 0xd0, 0x07, 0xe8, 0xcb, 0xb1, 0x59, 0x59, 0x7b, 0x85, 0x2b, 0x81, 0x45, 0xbe, 0x6d,
		0xad, 0xc2, 0x17, 0xd9, 0xe6, 0x25, 0x17, 0x66, 0xc8, 0xe0, 0x86, 0x12, 0x76, 0x14, 0xc0, 0x0f,
		0x35, 0x0c, 0x29, 0x83, 0x23, 0x65, 0xb0, 0xa4, 0x06, 0x9e, 0xe4, 0xc2, 0x94, 0x64, 0xb8, 0x22,
		0x83, 0xad, 0xf8, 0xc0, 0x12, 0xfa, 0x02, 0xfc, 0x72, 0x31, 0xa5, 0xee, 0x14, 0xa0, 0x28, 0x2c,
		0x56, 0x06, 0x61, 0x2a, 0xa0, 0x4c, 0x21, 0xa4, 0xa9, 0x82, 0x36, 0xe5, 0x10, 0xa7, 0x1c, 0xea,
		0xd4, 0x42, 0x1e, 0x0d, 0xf4, 0x11, 0x41, 0x20, 0x5d, 0xd8, 0xae, 0x30, 0x8c, 0x57, 0x11, 0xd6,
		0xff, 0x3a, 0xcc, 0x4f, 0x5b, 0x31, 0xac, 0xce, 0x8e, 0x08, 0x6c, 0x28, 0xe7, 0x89, 0xef, 0xa1,
		0xf5, 0xa5, 0xd7, 0x0f, 0xe8, 0x1d, 0xdf, 0xcb, 0xa9, 0x68, 0xfd, 0x5f, 0x09, 0xfe, 0x0f, 0xfe,
		0x0f, 0xfe, 0x6f, 0x3b, 0xfc, 0x1f, 0x55, 0x28, 0xb0, 0x04, 0x90, 0xf4, 0x76, 0xbc, 0x88, 0x93,
		0xd4, 0x66, 0x4c, 0x0b, 0x97, 0xca, 0x60, 0x53, 0x25, 0x7c, 0x6a, 0x80, 0x51, 0xd5, 0x70, 0xaa,
		0x0d, 0x56, 0xb5, 0xc1, 0xab, 0x1e, 0x98, 0xa5, 0x85, 0x5b, 0x62, 0xd8, 0x55, 0x06, 0xbf, 0x2f,
		0xca, 0x8c, 0xd7, 0x16, 0xdf, 0xd5, 0x19, 0x7f, 0x2c, 0xd6, 0x44, 0xa7, 0x55, 0x64, 0x7f, 0xb4,
		0xfa, 0x8d, 0x36, 0x60, 0xd6, 0x01, 0xd0, 0x1a, 0x81, 0x5a, 0x17, 0x60, 0x6b, 0x07, 0x6e, 0xed,
		0x00, 0xae, 0x17, 0xc8, 0xd5, 0x00, 0xba, 0x22, 0x60, 0x57, 0xa7, 0x2f, 0x69, 0xd4, 0x9b, 0x74,
		0xe8, 0x4f, 0xaf, 0xd0, 0xa3, 0x22, 0x97, 0xf3, 0x26, 0x1b, 0xa6, 0xaa, 0xc0, 0x4c, 0x73, 0x8e,
		0x17, 0x0a, 0xbf, 0x63, 0xb7, 0x84, 0x35, 0x32, 0x17, 0x0d, 0x14, 0x61, 0xf6, 0xf4, 0x6a, 0xa9,
		0x42, 0x09, 0x54, 0x81, 0x84, 0x2a, 0x38, 0x1d, 0x10, 0x85, 0x2d, 0x24, 0x0a, 0x4e, 0x07, 0x34,
		0x81, 0x77, 0x1c, 0x18, 0x9f, 0x30, 0xdd, 0x80, 0xbf, 0xd4, 0x18, 0x91, 0xb6, 0x9b, 0xa9, 0x01,
		0xa0, 0xbf, 0x0c, 0xfe, 0x65, 0xc5, 0x27, 0xd6, 0xe0, 0x04, 0xb4, 0x3b, 0x03, 0xdd, 0x4e, 0x81,
		0x8d, 0x73, 0x60, 0xe3, 0x24, 0x38, 0x38, 0x0b, 0xb5, 0x4e, 0x43, 0xb1, 0xf3, 0xd0, 0xe6, 0x44,
		0x96, 0x23, 0x08, 0x7d, 0xcb, 0x6d, 0x29, 0x9a, 0xd0, 0xb5, 0xdc, 0xd4, 0x8a, 0x90, 0xda, 0x23,
		0x0d, 0x4e, 0x4e, 0x87, 0x8d, 0xf3, 0xe1, 0xe2, 0x84, 0xd8, 0x39, 0x23, 0x76, 0x4e, 0x89, 0x93,
		0x73, 0xd2, 0xe3, 0xa4, 0x34, 0x39, 0xab, 0xf8, 0xc1, 0x2b, 0x17, 0x48, 0xd7, 0xa2, 0x85, 0x7a,
		0xc1, 0x74, 0x6d, 0x84, 0x72, 0xa0, 0xf1, 0x1a, 0xae, 0xe3, 0xb6, 0xea, 0xa3, 0x65, 0x70, 0x1c,
		0x3b, 0xd4, 0x60, 0xf1, 0x07, 0x93, 0xef, 0xa3, 0xbe, 0xe7, 0x6f, 0xb6, 0x63, 0xa1, 0x68, 0x58,
		0x24, 0xb9, 0x60, 0xf0, 0xc0, 0x88, 0x5f, 0xcd, 0x5d, 0x0d, 0x28, 0x16, 0x28, 0x16, 0x28, 0x16,
		0x28, 0x16, 0x28, 0x16, 0x28, 0x16, 0x28, 0x16, 0x01, 0xc5, 0xba, 0x7f, 0xa1, 0x58, 0xff, 0xd3,
		0x1a, 0xf8, 0xbe, 0xf0, 0xc2, 0xdd, 0x7c, 0x61, 0x6f, 0xaf, 0x10, 0xff, 0x46, 0x63, 0xf2, 0x91,
		0x59, 0xbf, 0x1c, 0xac, 0xf8, 0x59, 0x7c, 0x64, 0x65, 0x9b, 0xe3, 0x0c, 0xd8, 0x5a, 0xa6, 0xd5,
		0x3e, 0x49, 0x13, 0xec, 0x92, 0xf3, 0x52, 0xd2, 0x21, 0x4c, 0x33, 0xd3, 0x84, 0xe2, 0xaf, 0x9f,
		0x0a, 0x0b, 0x13, 0x28, 0x16, 0xbe, 0x2f, 0xcc, 0xf5, 0xcd, 0x98, 0xfb, 0xae, 0x10, 0x17, 0xcf,
		0xc4, 0x5f, 0x15, 0xe6, 0x12, 0x0f, 0x0a, 0x3a, 0x76, 0xa4, 0x76, 0x28, 0xa7, 0x47, 0xdd, 0x89,
		0xeb, 0xc9, 0x03, 0x9c, 0x7e, 0xf9, 0xd4, 0x7c, 0x3f, 0x7d, 0x5e, 0x23, 0x04, 0x0a, 0xe6, 0xbf,
		0x9d, 0x7e, 0xfe, 0x7c, 0xf4, 0xf0, 0x66, 0xbf, 0x69, 0x5e, 0x8a, 0xef, 0xe1, 0x3f, 0x7a, 0xfd,
		0x60, 0xfa, 0x45, 0xf3, 0x6c, 0xfa, 0xe4, 0x6e, 0x44, 0x27, 0xcd, 0xd0, 0x3f, 0xfe, 0x0b, 0x3b,
		0x5b, 0xbb, 0xcc, 0x9a, 0x20, 0x23, 0x63, 0x50, 0xa1, 0x32, 0xb5, 0xc5, 0x70, 0x70, 0x40, 0x1a,
		0xde, 0x26, 0xaf, 0x5a, 0x65, 0x46, 0x86, 0x96, 0x4c, 0x0c, 0x6d, 0x69, 0x77, 0x65, 0x64, 0xe8,
		0x67, 0x48, 0x7b, 0x41, 0xe2, 0x1d, 0x32, 0xf4, 0xe5, 0x3d, 0x4a, 0xe5, 0xa9, 0x77, 0xad, 0xde,
		0x60, 0xe4, 0x22, 0x03, 0x7d, 0xd9, 0x77, 0xf1, 0x15, 0x6c, 0x59, 0x02, 0x5e, 0x71, 0x3b, 0x13,
		0xf0, 0x14, 0xbb, 0x05, 0xdd, 0xee, 0x81, 0x8d, 0x9b, 0x60, 0xe3, 0x2e, 0x78, 0xb8, 0x8d, 0xed,
		0x90, 0xe5, 0xb4, 0x25, 0xe1, 0xf5, 0x06, 0xa1, 0xe5, 0xda, 0x0f, 0xc2, 0x15, 0x6d, 0xab, 0xd7,
		0x0a, 0x45, 0x18, 0xe8, 0xdf, 0x2d, 0x5e, 0x71, 0x4d, 0xd8, 0x33, 0xd6, 0x72, 0x01, 0xcc, 0xf6,
		0x8c, 0x35, 0xb9, 0x24, 0x2e, 0xae, 0x89, 0x9d, 0x8b, 0x62, 0xe7, 0xaa, 0x78, 0xb9, 0x2c, 0x3d,
		0xae, 0x4b, 0x93, 0x0b, 0x8b, 0x1f, 0x3d, 0x9f, 0x7d, 0xe3, 0x49, 0xc0, 0x52, 0xab, 0x30, 0xd8,
		0x39, 0x3e, 0xd4, 0x78, 0x09, 0x37, 0xb6, 0xf7, 0x38, 0x7a, 0x20, 0xf7, 0x5a, 0xd7, 0xa4, 0x5e,
		0xcc, 0x8c, 0x1e, 0xc4, 0x85, 0xe3, 0x69, 0x07, 0x6f, 0x26, 0xdc, 0x62, 0xe9, 0x72, 0x3e, 0xd9,
		0xee, 0x40, 0x30, 0xba, 0x9e, 0x0f, 0xbe, 0xdd, 0x0a, 0x9d, 0x9e, 0x77, 0xea, 0x3c, 0x3a, 0x11,
		0x29, 0x2d, 0x6a, 0xbf, 0xae, 0xe1, 0x5b, 0x06, 0x26, 0x6c, 0x7f, 0x87, 0x09, 0xff, 0xc2, 0x84,
		0x4b, 0x87, 0x95, 0x4a, 0xed, 0xa0, 0x52, 0x29, 0x1e, 0xec, 0x1f, 0x14, 0x8f, 0xaa, 0xd5, 0x52,
		0xad, 0x54, 0x85, 0x55, 0xf3, 0x62, 0x27, 0xfa, 0xcf, 0xde, 0x40, 0xf6, 0xb9, 0x12, 0x55, 0xa1,
		0xff, 0x95, 0x9b, 0xa6, 0x10, 0x5d, 0x11, 0x14, 0x05, 0x28, 0x0a, 0x50, 0x14, 0xa0, 0x28, 0x40,
		0x51, 0x80, 0xa2, 0x00, 0x45, 0x01, 0x8a, 0x02, 0x14, 0x05, 0x28, 0x0a, 0x50, 0x14, 0x60, 0xc2,
		0x50, 0x14, 0xa0, 0x28, 0x40, 0x51, 0x60, 0xa9, 0x28, 0x70, 0xca, 0x4f, 0x40, 0x5e, 0x02, 0x54,
		0x04, 0xa8, 0x08, 0x50, 0x11, 0xa0, 0x22, 0x40, 0x45, 0x80, 0x8a, 0x00, 0x15, 0x01, 0x2a, 0x02,
		0x54, 0x04, 0xa8, 0x08, 0x30, 0x61, 0xa8, 0x08, 0x50, 0x11, 0xa0, 0x22, 0x70, 0x56, 0x11, 0xf8,
		0xe4, 0x23, 0x20, 0x0f, 0x01, 0x0a, 0x02, 0x14, 0x04, 0x28, 0x08, 0x50, 0x10, 0xa0, 0x20, 0x40,
		0x41, 0x80, 0x82, 0x00, 0x05, 0x01, 0x0a, 0x02, 0x14, 0x04, 0x98, 0x30, 0x14, 0x04, 0x28, 0x08,
		0x50, 0x10, 0xb8, 0x9d, 0x11, 0x9d, 0x5a, 0x0d, 0x6b, 0xbf, 0x38, 0x1e, 0xec, 0xab, 0xa9, 0x6b,
		0xd1, 0x8e, 0xa1, 0x7d, 0x18, 0xa3, 0xbe, 0xac, 0xcd, 0xf7, 0xd3, 0x87, 0x96, 0xd5, 0x06, 0xad,
		0x0a, 0xdb, 0xdd, 0x09, 0xaf, 0x65, 0xf7, 0x83, 0x81, 0x3b, 0xb2, 0xe2, 0x2f, 0xc2, 0x6e, 0x0b,
		0x5f, 0x5f, 0x0b, 0xaf, 0x15, 0xd7, 0xa2, 0xa7, 0x99, 0x57, 0x11, 0xcd, 0xbc, 0xd4, 0xbd, 0xf5,
		0x5e, 0xcb, 0xb2, 0x3b, 0x21, 0x7a, 0x79, 0xa1, 0x97, 0xd7, 0x92, 0x7c, 0x38, 0xb2, 0x0b, 0xf0,
		0x36, 0xa9, 0x4f, 0x58, 0x9b, 0x4a, 0xb8, 0x02, 0xe5, 0x9d, 0x9e, 0x37, 0xc1, 0x79, 0x2b, 0x1c,
		0x5d, 0x96, 0x06, 0x08, 0x98, 0x76, 0x6f, 0xac, 0x68, 0x38, 0x77, 0xdd, 0x1b, 0x74, 0x47, 0xaf,
		0x62, 0x08, 0x1a, 0x93, 0xfa, 0x59, 0x8e, 0x67, 0x80, 0x68, 0x63, 0x2e, 0xe3, 0xd3, 0x83, 0xac,
		0x80, 0xac, 0x80, 0xac, 0x80, 0xac, 0x80, 0xac, 0x64, 0x86, 0xac, 0x0c, 0x1c, 0x2f, 0xd4, 0xb2,
		0x8f, 0xa9, 0x71, 0xff, 0x52, 0xf3, 0xbe, 0xa5, 0xc6, 0x0d, 0x6c, 0x0e, 0xfb, 0x94, 0x4c, 0x36,
		0x77, 0xb8, 0xec, 0x4b, 0x72, 0xda, 0xb9, 0xd1, 0xb8, 0x0f, 0xc9, 0x62, 0xff, 0x91, 0x9b, 0x69,
		0xf2, 0xdb, 0x6f, 0x64, 0x65, 0xad, 0x5b, 0xb2, 0xcf, 0xd6, 0x40, 0xf8, 0x9c, 0x3e, 0x7c, 0xee,
		0x5b, 0x76, 0xbb, 0xed, 0x8b, 0x40, 0xe3, 0x00, 0x8f, 0x99, 0x6b, 0x40, 0x20, 0x8d, 0x40, 0x1a,
		0x81, 0x34, 0x02, 0x69, 0x04, 0xd2, 0x99, 0x09, 0xa4, 0xb5, 0xa1, 0xfb, 0x2c, 0xc2, 0x97, 0x8e,
		0x34, 0x9c, 0x7b, 0xf2, 0xec, 0xb7, 0x2e, 0x98, 0x7e, 0x79, 0xf3, 0xdf, 0x2a, 0x1a, 0xdf, 0xfd,
		0x92, 0x0d, 0x1c, 0xea, 0x1d, 0x92, 0x1e, 0x0a, 0xdf, 0xd3, 0x9e, 0x13, 0x9e, 0xdb, 0xdd, 0xbd,
		0x2f, 0x5a, 0x47, 0x8d, 0xe7, 0xfb, 0x92, 0x75, 0xd4, 0x18, 0x7f, 0x59, 0x8a, 0xfe, 0x37, 0xfe,
		0xba, 0x7c, 0x5f, 0xb4, 0x2a, 0xd3, 0xaf, 0xab, 0xf7, 0x45, 0xab, 0xda, 0xc8, 0x7f, 0xfe, 0xbc,
		0x97, 0xff, 0xb1, 0x3f, 0xdc, 0xfc, 0x83, 0xfa, 0x0a, 0x40, 0x1a, 0x3a, 0x5f, 0xf5, 0xd5, 0xed,
		0xd9, 0x9f, 0x6c, 0xde, 0xf7, 0xbf, 0x54, 0xbe, 0xf0, 0xff, 0xca, 0x6d, 0x5b, 0x72, 0xe9, 0xdb,
		0x2d, 0x06, 0xf7, 0x1a, 0xc0, 0x9d, 0x25, 0xb8, 0xdb, 0x56, 0xe7, 0xc4, 0xfa, 0xd0, 0xf8, 0x51,
		0x7a, 0x5b, 0x19, 0x1e, 0xe7, 0x7f, 0x1c, 0x0c, 0x17, 0x7f, 0xf8, 0xbc, 0xea, 0xd7, 0x4a, 0x6f,
		0x0f, 0x86, 0xc7, 0x6b, 0xfe, 0xa5, 0x36, 0x3c, 0x7e, 0xe5, 0x31, 0xaa, 0xc3, 0xdd, 0xa5, 0x5f,
		0x1d, 0xfd, 0xbc, 0xbc, 0xee, 0x03, 0x95, 0x35, 0x1f, 0xd8, 0x5f, 0xf7, 0x81, 0xfd, 0x35, 0x1f,
		0x58, 0x7b, 0x49, 0xe5, 0x35, 0x1f, 0xa8, 0x0e, 0x9f, 0x97, 0x7e, 0x7f, 0x77, 0xf5, 0xaf, 0xd6,
		0x86, 0xf9, 0xe7, 0x75, 0xff, 0x76, 0x30, 0x7c, 0x3e, 0xce, 0xc3, 0xd5, 0xf1, 0x71, 0x75, 0x30,
		0x7f, 0xf5, 0xe6, 0xbf, 0x7d, 0x8e, 0x1f, 0x6a, 0xb7, 0x79, 0x14, 0x2a, 0xd7, 0xb5, 0x5b, 0xfa,
		0xe5, 0xee, 0xd9, 0x8b, 0x80, 0xde, 0x4d, 0xeb, 0x9f, 0xa0, 0x77, 0x43, 0xef, 0x86, 0xde, 0xad,
		0xd1, 0x73, 0x6d, 0x9f, 0xde, 0xad, 0x0f, 0xde, 0x75, 0xc7, 0xc3, 0xda, 0xe3, 0xe0, 0xdc, 0x2c,
		0x41, 0x5d, 0xe4, 0xbd, 0xe5, 0x61, 0xfe, 0x47, 0x75, 0xa8, 0x7e, 0xbd, 0x35, 0x74, 0xbc, 0x08,
		0x0e, 0x71, 0x59, 0xee, 0x5f, 0xbf, 0x7e, 0x1d, 0x1a, 0xe2, 0x06, 0xf0, 0xe8, 0xf4, 0x6f, 0xb6,
		0xe7, 0x3b, 0x8f, 0x8e, 0x67, 0xf5, 0xfd, 0x5e, 0xd8, 0x6b, 0xf5, 0x5c, 0x7d, 0x5c, 0x7a, 0xf1,
		0x42, 0xc0, 0xa7, 0xc1, 0xa7, 0xc1, 0xa7, 0xc1, 0xa7, 0xc1, 0xa7, 0x33, 0xc3, 0xa7, 0x9d, 0xb6,
		0xf0, 0x42, 0x27, 0x7c, 0xf2, 0x45, 0x47, 0x27, 0x9f, 0xd6, 0x90, 0x5f, 0x9c, 0x3b, 0x9b, 0xdc,
		0xfa, 0x3b, 0x3b, 0x10, 0xfa, 0x5b, 0xc3, 0x9e, 0x5d, 0xde, 0xde, 0x9d, 0x9c, 0x9f, 0x37, 0xaf,
		0x6f, 0xae, 0xee, 0xae, 0xde, 0x5f, 0x9d, 0x37, 0xef, 0xfe, 0xba, 0xae, 0xeb, 0x82, 0xa0, 0x28,
		0x13, 0x3c, 0xd0, 0xba, 0xe7, 0xa0, 0x39, 0x25, 0x7f, 0xfa, 0x5a, 0x4e, 0xcf, 0x6e, 0xea, 0xef,
		0xef, 0xce, 0xff, 0x6a, 0xbe, 0xbf, 0xba, 0xbc, 0xac, 0xbf, 0xbf, 0xab, 0x9f, 0xe6, 0xb6, 0xb1,
		0x4e, 0x82, 0xc9, 0xdb, 0x78, 0xf7, 0xfb, 0x35, 0x1e, 0xbf, 0x46, 0x8c, 0xfa, 0xfd, 0x02, 0xcf,
		0x5f, 0xe3, 0xf3, 0xbf, 0x3e, 0xbb, 0xc0, 0xe3, 0xd7, 0xf7, 0xf8, 0x6f, 0xef, 0x4e, 0xee, 0xce,
		0xde, 0xe3, 0x0d, 0xe8, 0x7b, 0x03, 0x57, 0xb7, 0xd7, 0x1f, 0xf0, 0xfc, 0xf5, 0x3e, 0xff, 0x7d,
		0xbc, 0x00, 0x8d, 0x1e, 0xf8, 0xf6, 0xec, 0x16, 0xcf, 0x5f, 0xdf, 0xf3, 0x3f, 0xbf, 0x7a, 0x7f,
		0x72, 0xde, 0x3c, 0xf9, 0xfd, 0xf7, 0x9b, 0xfa, 0xef, 0x27, 0x77, 0xf5, 0x6d, 0xeb, 0xc1, 0xdf,
		0xc8, 0xba, 0xfe, 0x93, 0xc9, 0xfd, 0x84, 0xfe, 0x20, 0xf8, 0x22, 0xda, 0x56, 0xb7, 0xef, 0x06,
		0x96, 0x6b, 0x3f, 0x08, 0xd7, 0x0a, 0x42, 0xbb, 0xf5, 0x55, 0xdf, 0xbe, 0xc2, 0xba, 0x0b, 0xc2,
		0xfe, 0x02, 0xe9, 0x89, 0xb1, 0xbf, 0x80, 0xfd, 0x05, 0xec, 0x2f, 0x68, 0xf5, 0x2f, 0xdb, 0x97,
		0xaf, 0x13, 0x63, 0x3c, 0xea, 0x53, 0xb7, 0x82, 0x2e, 0xcf, 0xb5, 0xf8, 0xda, 0x2f, 0x33, 0x28,
		0x5e, 0x3a, 0xc0, 0xa8, 0x22, 0x8c, 0x2a, 0x62, 0x40, 0xfc, 0xd6, 0x5e, 0x4e, 0xdc, 0x77, 0xa9,
		0x86, 0xa9, 0x2e, 0x0c, 0xa5, 0x87, 0x17, 0x1b, 0xc6, 0xac, 0xa2, 0x5f, 0xdb, 0x70, 0xb1, 0x72,
		0x58, 0x3d, 0xc0, 0x78, 0x22, 0x66, 0xc2, 0x8d, 0xfe, 0xb3, 0xa3, 0x82, 0x5c, 0x2d, 0xfd, 0x12,
		0xde, 0xa0, 0x2b, 0xfc, 0xf1, 0x24, 0x21, 0x06, 0x05, 0xe4, 0x15, 0x8d, 0xd7, 0xa0, 0xa7, 0x21,
		0xbc, 0xbe, 0x25, 0xd7, 0xc8, 0x74, 0x4c, 0x7b, 0xee, 0x04, 0xe1, 0x49, 0x18, 0xfa, 0x7a, 0xe2,
		0xda, 0x0b, 0xc7, 0xab, 0xbb, 0xa2, 0x2b, 0xbc, 0xb1, 0x3b, 0xd1, 0x10, 0x57, 0x5e, 0xd8, 0xdf,
		0x67, 0xae, 0x80, 0x47, 0xaf, 0xce, 0xdc, 0x95, 0xdf, 0x16, 0xbe, 0x68, 0xbf, 0x7b, 0xd2, 0x9f,
		0x48, 0x37, 0x08, 0x94, 0xcf, 0x37, 0x8a, 0xaf, 0x81, 0xc1, 0x40, 0xed, 0x59, 0x9d, 0xb1, 0x37,
		0x7e, 0x2b, 0xd6, 0xc3, 0x93, 0x4e, 0x17, 0xc0, 0x69, 0x98, 0xf6, 0x9c, 0xe6, 0x18, 0x59, 0x0a,
		0xa6, 0x26, 0x1a, 0x7d, 0x36, 0x35, 0x67, 0x52, 0xe4, 0xe3, 0x74, 0x4d, 0x7f, 0xcc, 0xc8, 0xd4,
		0x47, 0x85, 0x20, 0x67, 0xec, 0x90, 0x47, 0x35, 0x78, 0x47, 0xbf, 0x2a, 0x69, 0xcf, 0x40, 0xbc,
		0xde, 0x47, 0x3e, 0x5a, 0xd5, 0x78, 0x23, 0xb5, 0x7c, 0x59, 0x3d, 0x3f, 0x66, 0xc1, 0x87, 0xe7,
		0xf8, 0xaf, 0x37, 0x70, 0x5d, 0xa3, 0xad, 0x53, 0xb1, 0x17, 0x32, 0xde, 0xfb, 0x28, 0xf0, 0x3b,
		0x06, 0xfa, 0x1b, 0x5a, 0x4f, 0x43, 0x87, 0xff, 0x34, 0x47, 0x26, 0x5a, 0xb3, 0xaa, 0xd6, 0xaa,
		0xa9, 0x6b, 0x94, 0x70, 0x69, 0x1a, 0xb4, 0x24, 0x69, 0x96, 0xa2, 0xfc, 0x85, 0x42, 0xb0, 0x48,
		0x72, 0x81, 0xd3, 0xa6, 0xeb, 0x46, 0x16, 0x8b, 0x4e, 0xd1, 0x59, 0x88, 0x96, 0xf8, 0x54, 0x42,
		0x27, 0x3a, 0x3c, 0x75, 0x3a, 0xa2, 0x8a, 0xb4, 0xc3, 0xd9, 0xf4, 0xc2, 0xc0, 0x27, 0x8d, 0x04,
		0x55, 0x69, 0x7c, 0xca, 0xf3, 0x05, 0x95, 0xeb, 0x74, 0x8b, 0xf9, 0x7f, 0xd1, 0x8b, 0x83, 0x5b,
		0x8f, 0x1e, 0xcd, 0xa9, 0xe3, 0x13, 0xfb, 0x73, 0xa7, 0x4d, 0x6f, 0xc2, 0x33, 0xe8, 0x48, 0x6d,
		0xbc, 0xb4, 0x20, 0xa9, 0x0c, 0x2c, 0x55, 0x82, 0xa6, 0x06, 0xf0, 0x54, 0x0d, 0xa2, 0xda, 0xc0,
		0x54, 0x1b, 0xa8, 0xea, 0x01, 0xd7, 0x6c, 0xa8, 0x72, 0xd4, 0xa0, 0x1b, 0x9f, 0x48, 0xed, 0x54,
		0x75, 0x2d, 0xd3, 0xd4, 0x15, 0xe7, 0xa7, 0x29, 0x2f, 0xaa, 0xd1, 0x51, 0x4c, 0xa3, 0x01, 0xa8,
		0x75, 0x01, 0xb6, 0x76, 0xe0, 0xd6, 0x0e, 0xe0, 0x7a, 0x81, 0x5c, 0x0d, 0xa0, 0x2b, 0x02, 0xf6,
		0xf8, 0x51, 0x2a, 0x2f, 0x87, 0x89, 0x57, 0xac, 0x2b, 0xec, 0x8e, 0xda, 0x16, 0x5b, 0x31, 0x23,
		0x56, 0x58, 0xfe, 0x90, 0xbb, 0x9e, 0xe8, 0x83, 0x7b, 0x7b, 0xe3, 0x1d, 0xd9, 0xc2, 0xd8, 0xe5,
		0x64, 0x65, 0xcf, 0x51, 0x89, 0xce, 0x6f, 0x87, 0x42, 0x3d, 0x35, 0x50, 0xb9, 0x7f, 0xae, 0x28,
		0x56, 0x5b, 0xa6, 0x06, 0x65, 0x50, 0x03, 0x50, 0x03, 0x50, 0x03, 0x50, 0x03, 0x8d, 0xb1, 0x9f,
		0xa6, 0x18, 0x50, 0x6b, 0x2c, 0xa8, 0x29, 0x26, 0xd4, 0x16, 0x1b, 0xea, 0x74, 0x04, 0x0c, 0x1c,
		0x82, 0x6e, 0xc7, 0xc0, 0xc6, 0x41, 0xb0, 0x71, 0x14, 0x3c, 0x1c, 0x86, 0x5a, 0xc7, 0xa1, 0xd8,
		0x81, 0xe8, 0x8b, 0x31, 0x97, 0x56, 0xfc, 0xc0, 0xf1, 0xc2, 0x5a, 0x45, 0x63, 0xbb, 0x05, 0x1d,
		0xc3, 0x51, 0xf4, 0x16, 0xda, 0x6b, 0x2c, 0xf7, 0xe0, 0x50, 0x58, 0xcf, 0xa4, 0x18, 0x39, 0x2e,
		0x42, 0xd6, 0x7d, 0x1d, 0x8c, 0xca, 0x8e, 0x35, 0xd6, 0xcd, 0xb3, 0xa8, 0x97, 0xe7, 0x66, 0x9a,
		0x3c, 0xea, 0xf5, 0xd8, 0x5a, 0x2b, 0x2a, 0x74, 0x8d, 0xbe, 0x3f, 0xa5, 0xd3, 0x46, 0xfb, 0x6e,
		0x60, 0x85, 0x2d, 0x8d, 0x93, 0x46, 0x27, 0x17, 0xa0, 0x98, 0x60, 0x9e, 0x8a, 0x8e, 0x3d, 0x70,
		0x23, 0x0a, 0x5f, 0x44, 0x00, 0x8f, 0x00, 0x1e, 0x01, 0x3c, 0x02, 0x78, 0x04, 0xf0, 0x59, 0x0b,
		0xe0, 0x0f, 0x35, 0xc6, 0xef, 0x55, 0xc4, 0xef, 0x88, 0xdf, 0x11, 0xbf, 0x23, 0x7e, 0x47, 0xfc,
		0xbe, 0x64, 0x9a, 0x07, 0x30, 0x4d, 0x04, 0xeb, 0x08, 0xd6, 0x93, 0x05, 0xeb, 0xa1, 0xab, 0x3b,
		0x5a, 0x0f, 0x5d, 0x84, 0xeb, 0x08, 0xd7, 0x11, 0xae, 0x23, 0x5c, 0x47, 0xb8, 0x8e, 0x70, 0x1d,
		0xe1, 0x3a, 0xc2, 0x75, 0x84, 0xeb, 0x08, 0xd7, 0x11, 0xae, 0x67, 0xd5, 0x34, 0xcb, 0x55, 0xec,
		0xae, 0x23, 0x60, 0x47, 0xc0, 0xbe, 0xb1, 0xd9, 0x7e, 0x9b, 0x2c, 0x20, 0x4d, 0xd1, 0xfa, 0xf8,
		0xf4, 0x08, 0x97, 0x11, 0x2e, 0x23, 0x5c, 0x46, 0xb8, 0x8c, 0x70, 0x39, 0x43, 0xe1, 0x72, 0xe0,
		0x5b, 0x81, 0xd3, 0xb6, 0xc2, 0xd1, 0x85, 0x60, 0x24, 0xe0, 0x56, 0x04, 0xcd, 0x2c, 0x86, 0x41,
		0x72, 0xb0, 0x00, 0x1e, 0x96, 0xa0, 0xdf, 0x22, 0x96, 0x2c, 0x43, 0xfb, 0xb0, 0xc8, 0x45, 0xeb,
		0x38, 0x60, 0x70, 0x29, 0x3c, 0x86, 0x47, 0xf2, 0xb1, 0x96, 0x17, 0xa5, 0x83, 0xd1, 0x30, 0x49,
		0x66, 0xca, 0xc7, 0x5a, 0x25, 0x84, 0xcb, 0x70, 0x49, 0x8e, 0xc2, 0x88, 0x66, 0x52, 0xf6, 0x73,
		0x5b, 0x67, 0x34, 0x74, 0xd2, 0x18, 0x5b, 0xe7, 0x34, 0x84, 0xd2, 0x08, 0x83, 0x7f, 0x83, 0xab,
		0xd8, 0xd1, 0x36, 0xa4, 0x92, 0x09, 0xec, 0x30, 0xa2, 0x83, 0x3c, 0x86, 0x57, 0x2e, 0x45, 0x0c,
		0x15, 0x06, 0xd7, 0xa2, 0x77, 0x98, 0xa5, 0xfe, 0xa5, 0x8a, 0x39, 0xb2, 0x6a, 0x97, 0xa2, 0xd3,
		0xff, 0x56, 0xb3, 0xec, 0x76, 0xdb, 0x17, 0x41, 0xc0, 0x21, 0x6a, 0x3f, 0xd4, 0x78, 0x0d, 0xd7,
		0x76, 0x18, 0x0a, 0xdf, 0xd3, 0x1e, 0x92, 0xe5, 0x76, 0x77, 0xef, 0x8b, 0xd6, 0x91, 0x6d, 0x75,
		0x4e, 0xac, 0x0f, 0x8d, 0x1f, 0xa5, 0xb7, 0x95, 0xe1, 0x71, 0xfe, 0xc7, 0xc1, 0x70, 0xf1, 0x87,
		0xcf, 0xab, 0x7e, 0xad, 0xf4, 0xf6, 0x60, 0x78, 0xbc, 0xe6, 0x5f, 0x6a, 0xc3, 0xe3, 0x57, 0x1e,
		0xa3, 0x3a, 0xdc, 0x5d, 0xfa, 0xd5, 0xd1, 0xcf, 0xcb, 0xeb, 0x3e, 0x50, 0x59, 0xf3, 0x81, 0xfd,
		0x75, 0x1f, 0xd8, 0x5f, 0xf3, 0x81, 0xb5, 0x97, 0x54, 0x5e, 0xf3, 0x81, 0xea, 0xf0, 0x79, 0xe9,
		0xf7, 0x77, 0x57, 0xff, 0x6a, 0x6d, 0x98, 0x7f, 0x5e, 0xf7, 0x6f, 0x07, 0xc3, 0xe7, 0xe3, 0x7c,
		0x3e, 0xa7, 0x0f, 0xf8, 0x74, 0x1a, 0xfe, 0xd5, 0xed, 0xd9, 0x9f, 0x6c, 0xac, 0xff, 0x5f, 0x30,
		0x7f, 0x5d, 0xe6, 0xff, 0x5f, 0xb9, 0x6d, 0x73, 0xfc, 0xc8, 0x5e, 0x30, 0xea, 0x4c, 0x98, 0xd4,
		0xca, 0x69, 0x0e, 0x57, 0xe0, 0xb4, 0x83, 0xd1, 0x5f, 0x98, 0xcf, 0xba, 0x3c, 0x9c, 0xeb, 0xd6,
		0x69, 0x07, 0xa3, 0xbf, 0x30, 0x97, 0x95, 0xcd, 0xea, 0xc6, 0x5c, 0x56, 0x99, 0x67, 0xc4, 0x5c,
		0x56, 0xb3, 0x7d, 0x8e, 0xa1, 0xbe, 0x06, 0xd3, 0x58, 0x67, 0xbd, 0x0b, 0xa6, 0xb0, 0x2a, 0x58,
		0xa1, 0x98, 0xc2, 0xba, 0x76, 0x45, 0x6e, 0xf7, 0x00, 0xd6, 0xd1, 0x2a, 0xdc, 0xea, 0xe1, 0xab,
		0xa4, 0xd3, 0x2c, 0x94, 0x4c, 0xaf, 0x50, 0x36, 0x7e, 0xb5, 0x8c, 0xf1, 0xab, 0xaf, 0x39, 0x15,
		0xc6, 0xaf, 0x4a, 0x73, 0x5a, 0x18, 0xbf, 0xba, 0xee, 0xd1, 0x90, 0x8f, 0x5f, 0x6d, 0xf5, 0x06,
		0x5e, 0x28, 0xfc, 0x40, 0xdd, 0x0c, 0xd6, 0xf8, 0x8c, 0x18, 0xc4, 0xca, 0x0d, 0x3e, 0x35, 0xc0,
		0xa8, 0x6a, 0x38, 0xd5, 0x06, 0xab, 0xda, 0xe0, 0x55, 0x0f, 0xcc, 0x66, 0x43, 0x86, 0x53, 0x36,
		0x88, 0xb5, 0x37, 0x08, 0xc7, 0xf5, 0x08, 0xa2, 0x6d, 0xf5, 0x5a, 0xa1, 0x08, 0x03, 0xf5, 0xa3,
		0xd7, 0x56, 0x5c, 0x03, 0x46, 0xb4, 0x9a, 0x06, 0xdd, 0x1a, 0x21, 0x5c, 0x17, 0x94, 0x6b, 0x87,
		0x74, 0xed, 0xd0, 0xae, 0x17, 0xe2, 0xd5, 0x40, 0xbd, 0x22, 0xc8, 0x8f, 0x1f, 0xa5, 0xbe, 0x11,
		0xad, 0x13, 0x82, 0xac, 0x74, 0x72, 0x8e, 0x86, 0x89, 0x39, 0x9a, 0xaa, 0x8a, 0x34, 0x14, 0x9c,
		0xea, 0xac, 0x12, 0xd2, 0x5c, 0x21, 0xa1, 0xbb, 0x35, 0x0f, 0x87, 0x5a, 0x07, 0x0d, 0x29, 0xbb,
		0x5a, 0x8b, 0x75, 0xb8, 0x98, 0x1c, 0x9f, 0x09, 0x37, 0x2c, 0xac, 0x30, 0xa3, 0xd9, 0x5c, 0x0d,
		0xcc, 0xf4, 0x4e, 0x14, 0x65, 0xf6, 0xbf, 0xea, 0x8e, 0x31, 0xa3, 0x2b, 0x40, 0x84, 0x89, 0x08,
		0x13, 0x11, 0x26, 0x22, 0x4c, 0x44, 0x98, 0x88, 0x30, 0x11, 0x61, 0x22, 0xc2, 0x44, 0x84, 0x89,
		0x08, 0x13, 0x11, 0x26, 0x22, 0x4c, 0x44, 0x98, 0xc6, 0x46, 0x98, 0x3a, 0xf7, 0x2f, 0xb1, 0x6f,
		0x89, 0xa8, 0x12, 0x51, 0x25, 0xa2, 0x4a, 0x44, 0x95, 0x88, 0x2a, 0x11, 0x55, 0x22, 0xaa, 0x44,
		0x54, 0x89, 0xa8, 0x12, 0x51, 0x25, 0xa2, 0x4a, 0x44, 0x95, 0xa6, 0x47, 0x95, 0xfa, 0xf6, 0x2b,
		0xb1, 0x4f, 0x89, 0x88, 0x12, 0x11, 0x25, 0x22, 0x4a, 0x44, 0x94, 0x88, 0x28, 0x11, 0x51, 0x22,
		0xa2, 0x44, 0x44, 0x89, 0x88, 0x12, 0x11, 0x25, 0x22, 0x4a, 0x44, 0x94, 0x26, 0x9e, 0x01, 0xbd,
		0xb1, 0xb4, 0x76, 0xe2, 0x09, 0xed, 0x50, 0x14, 0x14, 0xb5, 0x00, 0xd8, 0x31, 0xa4, 0x37, 0xcf,
		0xe8, 0x99, 0x34, 0xdf, 0x4f, 0x9f, 0x89, 0xa9, 0x7d, 0xb2, 0x08, 0x5b, 0xad, 0x38, 0x6d, 0x75,
		0xed, 0x29, 0xc8, 0xfb, 0xb6, 0x29, 0x22, 0x05, 0x68, 0x4c, 0x61, 0xa6, 0x86, 0x83, 0xc6, 0x14,
		0x68, 0x4c, 0xc1, 0x48, 0x93, 0x51, 0x3f, 0x18, 0x51, 0xe1, 0xe0, 0x43, 0xc5, 0xc2, 0x8b, 0x42,
		0x05, 0x4d, 0x87, 0xd0, 0xa2, 0x6b, 0x6c, 0xb9, 0x26, 0x61, 0x45, 0x67, 0x28, 0xab, 0x72, 0x00,
		0xbf, 0x0e, 0x01, 0x45, 0xb7, 0x29, 0x55, 0xca, 0x47, 0x95, 0xa3, 0xda, 0x41, 0xf9, 0xa8, 0xba,
		0x45, 0x36, 0x95, 0x11, 0xf9, 0xa0, 0x81, 0x00, 0x6a, 0x39, 0x80, 0xf2, 0xbe, 0xd9, 0xae, 0xd3,
		0xb6, 0x7c, 0x61, 0x07, 0x0a, 0x84, 0x89, 0x97, 0x60, 0x6a, 0xfe, 0xbc, 0x08, 0xac, 0x10, 0x58,
		0x21, 0xb0, 0x42, 0x60, 0x85, 0xc0, 0x6a, 0xb6, 0x67, 0xb4, 0x1f, 0x0a, 0x6b, 0x0a, 0x94, 0x81,
		0xab, 0x06, 0x2b, 0x77, 0x14, 0x4f, 0x13, 0x55, 0x34, 0x2d, 0xd4, 0x4c, 0xef, 0x1c, 0xbd, 0x7a,
		0x75, 0x4e, 0x79, 0x7c, 0x3a, 0xf8, 0x62, 0xf8, 0x62, 0xf8, 0x62, 0xf8, 0x62, 0xf8, 0xe2, 0x99,
		0x15, 0xf7, 0xd0, 0xeb, 0xb9, 0xc2, 0x56, 0xea, 0x7c, 0x4b, 0x70, 0x88, 0x4b, 0xcf, 0xe6, 0x3f,
		0xc2, 0x79, 0xfc, 0x12, 0xaa, 0xf3, 0x88, 0x93, 0xf3, 0xc1, 0x25, 0xc2, 0x25, 0xc2, 0x25, 0xc2,
		0x25, 0xc2, 0x25, 0x62, 0xdf, 0x4f, 0xe6, 0x1f, 0xec, 0xfb, 0x91, 0x9c, 0x16, 0xfb, 0x7e, 0xb4,
		0xa6, 0x84, 0x7d, 0xbf, 0xed, 0xb0, 0x29, 0xec, 0xfb, 0xe9, 0x0d, 0xa4, 0x30, 0x60, 0x74, 0xc5,
		0x79, 0x0c, 0x4c, 0x6b, 0xde, 0xf2, 0x09, 0xa3, 0x74, 0xc3, 0xe3, 0x09, 0x46, 0x8c, 0xbe, 0x61,
		0xbc, 0xd6, 0xe2, 0xe1, 0xef, 0xb2, 0x45, 0x7a, 0xda, 0x49, 0xef, 0xf4, 0x93, 0xdd, 0xb5, 0x4c,
		0x72, 0xa7, 0x9d, 0xdc, 0x2e, 0xdb, 0x74, 0x88, 0xe1, 0xd9, 0x2c, 0x58, 0xce, 0x91, 0x0c, 0x12,
		0x66, 0x0e, 0xc4, 0x72, 0x21, 0x58, 0x1e, 0x50, 0xca, 0x39, 0x92, 0xa4, 0xf5, 0x42, 0xb5, 0x4e,
		0xd8, 0xaf, 0x0f, 0x89, 0x4b, 0x82, 0xe7, 0x52, 0x90, 0x63, 0xfe, 0xe9, 0x8d, 0x55, 0x82, 0xa1,
		0x4a, 0x1e, 0x5a, 0x4e, 0x32, 0xa4, 0x5c, 0xf2, 0x94, 0x5d, 0xe9, 0x43, 0xc8, 0x29, 0x36, 0x29,
		0x08, 0x37, 0x23, 0xa8, 0x36, 0x1d, 0xc8, 0x37, 0x17, 0xc8, 0x37, 0x11, 0x68, 0x37, 0x0b, 0x78,
		0x39, 0x27, 0xd9, 0x53, 0x67, 0x73, 0x76, 0x2b, 0x74, 0xbe, 0x11, 0x58, 0xd5, 0x74, 0x21, 0x4c,
		0x8e, 0x2f, 0x3b, 0x0c, 0x22, 0xd1, 0x02, 0xc9, 0xf6, 0x47, 0x29, 0xf7, 0x43, 0x15, 0xec, 0x7f,
		0x52, 0xef, 0x77, 0x2a, 0xdb, 0xdf, 0x54, 0xb6, 0x9f, 0xa9, 0x66, 0xff, 0x92, 0xb7, 0x54, 0x41,
		0xb6, 0x1f, 0xa9, 0x20, 0x25, 0x87, 0x28, 0x05, 0x47, 0x62, 0xc8, 0xf4, 0x56, 0xb6, 0x0b, 0xb0,
		0x02, 0xc7, 0x6b, 0x91, 0x3b, 0x82, 0xc9, 0x59, 0xe0, 0x0e, 0xe0, 0x0e, 0xe0, 0x0e, 0xe0, 0x0e,
		0xa4, 0x5a, 0x7c, 0xe8, 0x74, 0x45, 0xe8, 0xb4, 0xbe, 0x06, 0x24, 0x4d, 0x01, 0x09, 0x9b, 0xff,
		0xe5, 0x3e, 0x7a, 0xe3, 0x9d, 0xdd, 0x9c, 0x67, 0x7b, 0xbd, 0x40, 0xb4, 0x7a, 0x5e, 0x9b, 0xa2,
		0x01, 0x0e, 0x71, 0x6e, 0x0b, 0xe1, 0x96, 0x9f, 0x8a, 0xdc, 0x15, 0x55, 0x49, 0x98, 0x8a, 0x72,
		0x53, 0x54, 0xe6, 0x0d, 0x50, 0x26, 0xfc, 0xaa, 0xc8, 0x35, 0x51, 0xfd, 0xea, 0xd5, 0x37, 0xdd,
		0x53, 0x6a, 0x0d, 0x86, 0xec, 0xf4, 0x36, 0xb6, 0x87, 0xdb, 0x87, 0xbe, 0xed, 0x05, 0xce, 0xe8,
		0xfd, 0x07, 0xe4, 0x0c, 0x7f, 0xf6, 0x5c, 0xe0, 0xf9, 0xe0, 0xf9, 0xe0, 0xf9, 0xe0, 0xf9, 0x52,
		0x2d, 0x9e, 0xb2, 0xf5, 0x37, 0x25, 0xcb, 0x07, 0xfb, 0x06, 0xfb, 0x06, 0xfb, 0x06, 0xfb, 0x06,
		0xfb, 0xde, 0x16, 0xf6, 0xdd, 0x76, 0x82, 0x96, 0xef, 0x74, 0x1d, 0xcf, 0x0e, 0x7b, 0x3e, 0x1d,
		0xf1, 0x9e, 0x3f, 0x0d, 0x38, 0x37, 0x38, 0x37, 0x38, 0x37, 0x38, 0xb7, 0x54, 0x8b, 0x27, 0x2b,
		0xf5, 0x24, 0x2c, 0xed, 0x04, 0xe1, 0x06, 0xe1, 0x06, 0xe1, 0x66, 0xf0, 0xea, 0x55, 0x95, 0x4e,
		0x82, 0x66, 0x6f, 0x27, 0xcd, 0x16, 0x9e, 0xdb, 0xa7, 0x63, 0xd7, 0xd1, 0xd1, 0x41, 0xaa, 0x41,
		0xaa, 0x41, 0xaa, 0x41, 0xaa, 0xa5, 0x23, 0x8b, 0x15, 0x8e, 0x4e, 0x43, 0x98, 0xc1, 0x48, 0xd0,
		0xc1, 0x93, 0xa8, 0x63, 0x27, 0x4f, 0xe7, 0x32, 0x29, 0x62, 0x22, 0x72, 0x2e, 0xd1, 0xd1, 0xe1,
		0x5c, 0xe0, 0x5c, 0xe0, 0x5c, 0xe0, 0x5c, 0xa4, 0x5a, 0x7c, 0x10, 0xfa, 0x8e, 0xf7, 0x48, 0xe9,
		0x59, 0x0e, 0xb7, 0x00, 0xfd, 0x7b, 0xbe, 0xf3, 0x38, 0xd6, 0xd5, 0x2d, 0xbb, 0xdd, 0x26, 0xd4,
		0xf0, 0x17, 0x4f, 0x04, 0x9f, 0x00, 0x9f, 0x00, 0x9f, 0x00, 0x9f, 0x20, 0xd5, 0xe2, 0x9d, 0xfe,
		0xb7, 0x5a, 0x04, 0x2f, 0x22, 0x08, 0x48, 0x3d, 0x03, 0xc1, 0xb1, 0xaf, 0xed, 0x30, 0x14, 0xbe,
		0x47, 0x26, 0xe7, 0xe7, 0x76, 0x77, 0xef, 0x8b, 0xd6, 0x91, 0x6d, 0x75, 0x4e, 0xac, 0x0f, 0x8d,
		0x1f, 0xa5, 0xb7, 0x95, 0xe1, 0x71, 0xfe, 0xc7, 0xc1, 0x70, 0xf1, 0x87, 0xcf, 0xab, 0x7e, 0xad,
		0xf4, 0xf6, 0x60, 0x78, 0xbc, 0xe6, 0x5f, 0x6a, 0xc3, 0xe3, 0x57, 0x1e, 0xa3, 0x3a, 0xdc, 0x5d,
		0xfa, 0xd5, 0xd1, 0xcf, 0xcb, 0xeb, 0x3e, 0x50, 0x59, 0xf3, 0x81, 0xfd, 0x75, 0x1f, 0xd8, 0x5f,
		0xf3, 0x81, 0xb5, 0x97, 0x54, 0x5e, 0xf3, 0x81, 0xea, 0xf0, 0x79, 0xe9, 0xf7, 0x77, 0x57, 0xff,
		0x6a, 0x6d, 0x98, 0x7f, 0x5e, 0xf7, 0x6f, 0x07, 0xc3, 0xe7, 0xe3, 0x7c, 0x5e, 0xfe, 0x42, 0x6f,
		0x50, 0x18, 0xe0, 0xd5, 0xed, 0xd9, 0x9f, 0xe4, 0x56, 0xf8, 0x2f, 0x98, 0xa1, 0x2e, 0x33, 0xfc,
		0xaf, 0x1c, 0xd4, 0xf7, 0x94, 0x14, 0x39, 0xf0, 0xd4, 0x30, 0xe4, 0xc0, 0x03, 0x41, 0x06, 0x41,
		0x06, 0x41, 0x06, 0x41, 0x96, 0x6b, 0xf1, 0x48, 0x73, 0x59, 0xfa, 0x83, 0x34, 0x97, 0x57, 0x9d,
		0x06, 0x69, 0x2e, 0x9b, 0xbd, 0x7a, 0xa4, 0xb9, 0x98, 0x61, 0x03, 0x48, 0x73, 0x61, 0x43, 0xb4,
		0x47, 0x44, 0x46, 0xf8, 0x82, 0xb4, 0x4b, 0xcb, 0xcc, 0x39, 0x40, 0xb0, 0x41, 0xb0, 0x41, 0xb0,
		0x41, 0xb0, 0x41, 0xb0, 0x41, 0xb0, 0x41, 0xb0, 0x41, 0xb0, 0x41, 0xb0, 0x41, 0xb0, 0xb3, 0x4e,
		0xb0, 0x7b, 0x61, 0xaf, 0xd5, 0x73, 0xad, 0xb1, 0xd4, 0x4c, 0xc9, 0xb2, 0xe7, 0x4f, 0x04, 0xaa,
		0x0d, 0xaa, 0x0d, 0xaa, 0x0d, 0xaa, 0x2d, 0xd5, 0xe2, 0x47, 0x4f, 0xd5, 0x8a, 0x91, 0x06, 0x69,
		0xe6, 0xbc, 0x7d, 0xcf, 0x37, 0xdb, 0x75, 0xda, 0x74, 0x1e, 0x67, 0x7c, 0x78, 0xf8, 0x19, 0xf8,
		0x19, 0xf8, 0x19, 0xf8, 0x19, 0xa9, 0x16, 0xbf, 0xcd, 0x5d, 0xd8, 0x31, 0xb8, 0x4a, 0xd3, 0xe0,
		0x2a, 0xc9, 0x43, 0x35, 0x19, 0x0d, 0xac, 0x92, 0x37, 0x2b, 0x53, 0xc2, 0xa4, 0xaa, 0x37, 0x1a,
		0xed, 0x7a, 0x3a, 0xeb, 0x72, 0x21, 0x58, 0xde, 0x99, 0xcf, 0x03, 0xdb, 0x59, 0x28, 0x9c, 0xd8,
		0x91, 0xd9, 0x0c, 0x49, 0xee, 0x54, 0x4c, 0xf9, 0x53, 0x30, 0x95, 0x4c, 0xbd, 0x94, 0x3b, 0xe5,
		0x32, 0xad, 0x51, 0x48, 0x06, 0x39, 0x86, 0xe0, 0x96, 0x93, 0x32, 0x1e, 0x8e, 0x07, 0x9c, 0xa5,
		0x03, 0xb2, 0xe4, 0xf0, 0x93, 0xec, 0x93, 0x09, 0x6d, 0x53, 0x96, 0x4d, 0x72, 0xb0, 0xc5, 0x14,
		0xc6, 0xa7, 0xd1, 0xe8, 0x92, 0x99, 0xd9, 0xe6, 0x46, 0x92, 0xc0, 0x40, 0x72, 0xad, 0x9e, 0x9b,
		0xa2, 0xf7, 0xdf, 0x4c, 0xd3, 0x5b, 0x37, 0xb1, 0x3b, 0x4b, 0x19, 0xa8, 0xa7, 0x0e, 0xc8, 0x65,
		0x04, 0xde, 0x12, 0x03, 0x6c, 0x59, 0x81, 0xb4, 0xf4, 0x80, 0x59, 0x7a, 0x60, 0x2c, 0x37, 0x00,
		0x56, 0x0b, 0xaa, 0xa9, 0x03, 0xd7, 0xd8, 0x62, 0x5c, 0x61, 0x77, 0x7c, 0xd1, 0x49, 0x63, 0x31,
		0xd3, 0x40, 0x34, 0x45, 0x76, 0x41, 0xee, 0x7a, 0x82, 0xeb, 0x7b, 0x7b, 0xe3, 0xf0, 0xa5, 0x30,
		0x5e, 0xd2, 0x8c, 0xa1, 0x4b, 0x78, 0xed, 0x7e, 0xcf, 0x89, 0xac, 0x27, 0x25, 0x7a, 0xc5, 0x47,
		0x02, 0x80, 0x01, 0xc0, 0x00, 0x60, 0x19, 0x01, 0xb0, 0x78, 0x55, 0x33, 0xc6, 0xb0, 0x74, 0x83,
		0xb2, 0xa5, 0x0c, 0xc6, 0x4e, 0x39, 0x08, 0x3b, 0xf5, 0xe0, 0x6b, 0xa0, 0x17, 0xd0, 0x6b, 0xe3,
		0x4b, 0x4f, 0x3b, 0x68, 0x5a, 0xd6, 0x60, 0x69, 0xb9, 0x83, 0xa4, 0x25, 0x6d, 0x59, 0x4a, 0xdb,
		0xa2, 0x94, 0xb9, 0x25, 0x49, 0xb0, 0x05, 0x29, 0x7b, 0xcb, 0x91, 0x6c, 0x8b, 0x91, 0x6c, 0x4b,
		0x91, 0x66, 0x0b, 0x51, 0xaf, 0xae, 0x2e, 0x6d, 0x4b, 0x90, 0x60, 0x0b, 0x50, 0xd2, 0x96, 0x5f,
		0x0a, 0xe5, 0xf0, 0x6d, 0x5a, 0xc8, 0x93, 0x34, 0x48, 0x99, 0x62, 0x70, 0x32, 0xe0, 0x0f, 0xf0,
		0x07, 0xf8, 0x93, 0x0e, 0x7f, 0x72, 0x07, 0x0f, 0x4b, 0x1c, 0x41, 0x46, 0x35, 0x58, 0x58, 0x72,
		0x45, 0x8c, 0xc4, 0x5c, 0x05, 0x8a, 0x8a, 0x17, 0xaa, 0x3c, 0x37, 0xa2, 0x8a, 0x16, 0xca, 0xea,
		0x05, 0x99, 0x19, 0x8f, 0x14, 0x15, 0x2a, 0xd4, 0xaf, 0x8a, 0x7e, 0x74, 0x18, 0xe9, 0xdb, 0x63,
		0x92, 0x56, 0xd2, 0x30, 0x97, 0xdb, 0xc9, 0x1c, 0xa4, 0x4b, 0x37, 0x38, 0x17, 0x3c, 0x0f, 0x3c,
		0x0f, 0x3c, 0x4f, 0x3a, 0xcf, 0x93, 0x39, 0x78, 0x56, 0x26, 0xcb, 0x03, 0x1b, 0x03, 0x1b, 0x03,
		0x1b, 0x03, 0x1b, 0xdb, 0x1e, 0x36, 0xf6, 0x10, 0x48, 0x28, 0x96, 0x7a, 0x91, 0x2f, 0x83, 0xd4,
		0xb5, 0x51, 0x60, 0x5c, 0x60, 0x5c, 0x60, 0x5c, 0xd2, 0x19, 0x57, 0xe0, 0x5b, 0x81, 0xd3, 0x96,
		0x55, 0xbc, 0x1a, 0x6f, 0x2e, 0x1c, 0x49, 0x38, 0xd6, 0xe4, 0x66, 0xd9, 0x71, 0xae, 0xe9, 0xa3,
		0xeb, 0xf6, 0xdd, 0xc0, 0x72, 0xed, 0x07, 0xe1, 0xca, 0xac, 0x93, 0x91, 0xf8, 0x04, 0x69, 0x9e,
		0xa4, 0xfc, 0x27, 0xba, 0xf4, 0x64, 0xd1, 0xc3, 0x48, 0xc1, 0xd3, 0x26, 0x8d, 0x21, 0x14, 0x11,
		0xd5, 0xf5, 0xc4, 0xb5, 0x86, 0x26, 0x46, 0xba, 0x82, 0x12, 0xed, 0xef, 0xbe, 0x58, 0x39, 0xac,
		0x1e, 0xa0, 0x83, 0x91, 0xf2, 0xa3, 0x36, 0x38, 0xd7, 0x69, 0x93, 0x4e, 0x99, 0x1c, 0x74, 0x85,
		0x3f, 0x2e, 0x4f, 0x42, 0x03, 0x10, 0xa9, 0xa6, 0xd5, 0xe0, 0x54, 0xff, 0x4d, 0xc0, 0x21, 0x89,
		0xe6, 0x05, 0x51, 0xcc, 0x09, 0x22, 0x9b, 0x0f, 0x84, 0xb9, 0x40, 0x19, 0x98, 0x0b, 0xd4, 0x90,
		0x69, 0x68, 0x94, 0x73, 0x80, 0x30, 0xff, 0x27, 0x13, 0xf3, 0x7f, 0x1a, 0xd0, 0x76, 0x13, 0xaf,
		0x80, 0x74, 0x05, 0xb3, 0x4b, 0x3e, 0x2c, 0x4d, 0xe1, 0x2c, 0xd4, 0x5d, 0xa8, 0xbb, 0x50, 0x77,
		0xc9, 0xd4, 0x5d, 0x69, 0x42, 0x9a, 0x44, 0xe1, 0x0c, 0x9b, 0xe9, 0x32, 0xc5, 0x0e, 0x6c, 0xa6,
		0x1b, 0xf3, 0xaa, 0xa8, 0x9a, 0x6b, 0x63, 0x0b, 0x9d, 0x2b, 0xcd, 0x8a, 0x92, 0x99, 0x02, 0x99,
		0x4c, 0x6b, 0x72, 0x44, 0x39, 0x64, 0xab, 0x04, 0xb2, 0x05, 0xb2, 0xb5, 0xad, 0x64, 0x2b, 0x6d,
		0xf9, 0x6d, 0x7c, 0x20, 0xc7, 0x1b, 0x6f, 0x02, 0x8b, 0xb6, 0xd5, 0x6b, 0x85, 0x22, 0x0c, 0xe4,
		0x19, 0x4a, 0xac, 0x12, 0x2e, 0x9d, 0x42, 0xd2, 0x7b, 0x95, 0xeb, 0xf1, 0xa4, 0xf7, 0x15, 0xa6,
		0xe8, 0x27, 0x4c, 0xd8, 0x47, 0x98, 0xaa, 0x7f, 0x30, 0x79, 0xdf, 0x60, 0xf2, 0x7e, 0xc1, 0xb4,
		0x7d, 0x82, 0x79, 0x35, 0x89, 0x95, 0xde, 0x0f, 0x98, 0x24, 0x3b, 0x7a, 0x11, 0x02, 0x64, 0x6e,
		0x14, 0xd0, 0x64, 0x42, 0x10, 0x6c, 0xe0, 0x51, 0x66, 0x3e, 0x10, 0xef, 0x7a, 0x53, 0x4f, 0x6b,
		0x52, 0xb1, 0xbf, 0x4d, 0x90, 0xd8, 0x40, 0x9a, 0xd0, 0xa0, 0xea, 0x95, 0xd2, 0x67, 0x5d, 0x2b,
		0x7d, 0xcb, 0xd9, 0xde, 0x5a, 0x7e, 0xc3, 0x60, 0x15, 0xcc, 0x12, 0xc4, 0xfe, 0x57, 0x62, 0x06,
		0x1a, 0x9d, 0x00, 0xfc, 0x13, 0xfc, 0x13, 0xfc, 0x13, 0xfc, 0x13, 0xfc, 0x13, 0xfc, 0x13, 0xfc,
		0x13, 0xfc, 0x13, 0xfc, 0x73, 0xdb, 0xf9, 0x27, 0xa1, 0xf6, 0x09, 0xcd, 0x13, 0x9c, 0x13, 0x9c,
		0x13, 0x9c, 0x13, 0x9c, 0x13, 0x9c, 0x13, 0x9c, 0x13, 0x9c, 0x13, 0x9c, 0x13, 0x9c, 0x33, 0x22,
		0x86, 0x64, 0x5a, 0x27, 0x34, 0x4e, 0xf0, 0x4d, 0xf0, 0x4d, 0xf0, 0x4d, 0xf0, 0x4d, 0xf0, 0x4d,
		0xf0, 0x4d, 0xf0, 0x4d, 0xf0, 0x4d, 0xf0, 0xcd, 0xde, 0x20, 0x24, 0x4f, 0xf4, 0x5c, 0x71, 0x0e,
		0xb0, 0x50, 0xb0, 0x50, 0xb0, 0x50, 0xb0, 0x50, 0xb0, 0x50, 0xb0, 0x50, 0xb0, 0x50, 0xb0, 0x50,
		0xb0, 0x50, 0xb0, 0x50, 0xd2, 0x54, 0xcf, 0xa5, 0x33, 0x80, 0x81, 0x82, 0x81, 0x82, 0x81, 0x82,
		0x81, 0x82, 0x81, 0x82, 0x81, 0x82, 0x81, 0x82, 0x81, 0x82, 0x81, 0x6e, 0x3d, 0x03, 0xa5, 0xd4,
		0x3f, 0xa1, 0x7b, 0x82, 0x75, 0x82, 0x75, 0x82, 0x75, 0x82, 0x75, 0x82, 0x75, 0x82, 0x75, 0x82,
		0x75, 0x82, 0x75, 0x82, 0x75, 0x8e, 0x99, 0x21, 0x9d, 0xde, 0x09, 0x9d, 0x13, 0x8c, 0x13, 0x8c,
		0x13, 0x8c, 0x13, 0x8c, 0x13, 0x8c, 0x13, 0x8c, 0x13, 0x8c, 0x13, 0x8c, 0xd3, 0x70, 0xc6, 0xa9,
		0xb5, 0xb5, 0xe8, 0x89, 0xe7, 0xf5, 0xc2, 0xf1, 0x38, 0x28, 0x29, 0x1d, 0x46, 0x83, 0xd6, 0x17,
		0xd1, 0xb5, 0xfb, 0x76, 0xf8, 0x65, 0xe4, 0xb1, 0x0a, 0xbd, 0xbe, 0xf0, 0x5a, 0x11, 0x2b, 0xb4,
		0x3c, 0x11, 0xfe, 0xa7, 0xe7, 0x7f, 0xb5, 0x1c, 0x2f, 0x08, 0x6d, 0xaf, 0x25, 0x0a, 0x8b, 0x3f,
		0x08, 0x96, 0x7e, 0x52, 0x08, 0xc4, 0xe3, 0x88, 0x35, 0x58, 0x7e, 0x6f, 0x10, 0x3a, 0xde, 0x63,
		0x21, 0x14, 0x56, 0xbf, 0xe7, 0x3a, 0x2d, 0x47, 0x04, 0xf1, 0xd7, 0x4f, 0x85, 0x20, 0xb4, 0x43,
		0x51, 0x90, 0xd4, 0x70, 0x78, 0x7c, 0x17, 0xa1, 0x3f, 0x68, 0x85, 0xde, 0xc4, 0xef, 0x5e, 0xc5,
		0x37, 0x71, 0x39, 0xbe, 0xc0, 0xb3, 0xc9, 0xf5, 0x35, 0x17, 0xbe, 0x0f, 0x16, 0x7f, 0xd0, 0xbc,
		0x1d, 0xdf, 0xc0, 0xcd, 0xf8, 0xfa, 0x9b, 0x77, 0xe2, 0x7a, 0x72, 0xf9, 0xd3, 0x2f, 0x9f, 0x9a,
		0xb7, 0xa3, 0xab, 0x6f, 0xbe, 0x9f, 0x5e, 0xbd, 0x81, 0xcd, 0xa3, 0x85, 0xd7, 0xee, 0xf7, 0x9c,
		0x88, 0xdc, 0x49, 0x6a, 0x1e, 0x1d, 0x1f, 0x11, 0x93, 0x3a, 0x14, 0xc6, 0x31, 0x68, 0x1e, 0x8d,
		0x49, 0x1d, 0xaf, 0xb1, 0xb8, 0xd1, 0x53, 0xb1, 0xa6, 0x4b, 0x14, 0xe3, 0x98, 0x13, 0x3c, 0x41,
		0xa7, 0xff, 0xad, 0x82, 0x51, 0x7a, 0xd1, 0x74, 0xaf, 0xc6, 0xf3, 0x7d, 0xc9, 0x3a, 0x6a, 0x8c,
		0xbf, 0x2c, 0x45, 0xff, 0x1b, 0x7f, 0x5d, 0xbe, 0x2f, 0x5a, 0x95, 0xe9, 0xd7, 0xd5, 0xfb, 0xa2,
		0x55, 0x6d, 0xe4, 0x3f, 0x7f, 0xde, 0xcb, 0xff, 0xd8, 0x1f, 0x6e, 0xfe, 0xc1, 0x2d, 0x1e, 0x1e,
		0xa7, 0xe6, 0x01, 0xf3, 0x1b, 0x97, 0x86, 0x39, 0x9a, 0xfc, 0x17, 0x3f, 0x06, 0x1b, 0x62, 0x8e,
		0xa6, 0x42, 0x28, 0x84, 0xb9, 0x61, 0x8e, 0xe6, 0x96, 0x0e, 0x78, 0x9a, 0x68, 0x19, 0x92, 0xe2,
		0xf3, 0xe8, 0x68, 0x88, 0xcd, 0x11, 0x9b, 0x23, 0x36, 0xe7, 0x16, 0x9b, 0x87, 0xbe, 0xe3, 0x3d,
		0xca, 0x8c, 0xc7, 0x0f, 0x75, 0xa1, 0xdd, 0x1b, 0x85, 0x6f, 0x44, 0x96, 0x0e, 0xae, 0x4f, 0xff,
		0x4e, 0xf1, 0xca, 0xd5, 0xcb, 0xdd, 0xc9, 0xd6, 0xed, 0xe6, 0x16, 0xb1, 0xd9, 0x27, 0x36, 0xb4,
		0x9d, 0x11, 0x84, 0xc6, 0x33, 0xa5, 0x77, 0x12, 0x4a, 0xd6, 0xb9, 0x73, 0x27, 0x08, 0x4f, 0xc2,
		0x30, 0xd9, 0x80, 0xb7, 0xdc, 0x85, 0xe3, 0xd5, 0x5d, 0x31, 0x7a, 0xe6, 0x41, 0x32, 0x17, 0x98,
		0xbb, 0xb0, 0xbf, 0xcf, 0x1c, 0x41, 0xce, 0xd6, 0x63, 0xee, 0xca, 0x6f, 0x0b, 0x5f, 0xb4, 0xdf,
		0x8d, 0x9e, 0x8f, 0x37, 0x70, 0x5d, 0xd2, 0xd7, 0x90, 0x72, 0xe9, 0xea, 0x58, 0xb2, 0x09, 0x16,
		0xab, 0xca, 0x45, 0xba, 0xd9, 0xf2, 0x7c, 0xfd, 0x22, 0x7b, 0xdd, 0x6f, 0xbe, 0xf2, 0xfd, 0x27,
		0x7d, 0xef, 0xea, 0xde, 0xf7, 0x06, 0x6f, 0x59, 0xc1, 0xdb, 0x7d, 0xdd, 0x4b, 0xfd, 0xf5, 0x2b,
		0xfa, 0xf9, 0x6f, 0xfc, 0xe2, 0xe5, 0x6d, 0xfa, 0xd2, 0x68, 0x5f, 0xd6, 0x2b, 0x5e, 0x10, 0xd5,
		0x8b, 0xf9, 0xf9, 0xdb, 0x58, 0xff, 0x8c, 0x7f, 0xf2, 0x7c, 0x73, 0x63, 0x1e, 0xf0, 0xab, 0xc7,
		0x3a, 0x43, 0x15, 0x7f, 0x4d, 0x1b, 0x5e, 0x39, 0x7e, 0xf7, 0x25, 0x0a, 0x2b, 0xff, 0xe2, 0x17,
		0x37, 0x88, 0xb2, 0x66, 0xa3, 0x28, 0x4f, 0x84, 0xa3, 0x97, 0xf8, 0x9a, 0x17, 0xb6, 0x61, 0xa0,
		0x94, 0x38, 0x10, 0x4a, 0x1c, 0xe8, 0x2c, 0x06, 0x32, 0xd3, 0x7b, 0x23, 0x5e, 0x79, 0xaf, 0x1d,
		0x22, 0x9b, 0x6b, 0x8b, 0xa0, 0xe5, 0x3b, 0xfd, 0x8d, 0x80, 0x35, 0x7e, 0x57, 0xb3, 0x1f, 0x7e,
		0xe5, 0xe3, 0xd8, 0x4c, 0x08, 0xd8, 0x38, 0xe0, 0x4f, 0x12, 0xd8, 0x27, 0x33, 0xbd, 0xb4, 0xb1,
		0x7a, 0xea, 0x98, 0x3c, 0x75, 0xec, 0x9d, 0xd8, 0x34, 0x69, 0x3c, 0xfc, 0xc6, 0xe1, 0x71, 0xf2,
		0x30, 0x78, 0xc3, 0x70, 0xf7, 0x15, 0x6e, 0xf2, 0x15, 0x50, 0x25, 0x3c, 0xfb, 0xc1, 0x15, 0xed,
		0xcd, 0x57, 0xd9, 0xf4, 0x83, 0x58, 0x61, 0x58, 0x61, 0x9a, 0x56, 0xd8, 0x43, 0xaf, 0xe7, 0x0a,
		0xdb, 0x4b, 0xb2, 0xc4, 0x4a, 0xea, 0x97, 0xd8, 0x74, 0xbf, 0xd5, 0xea, 0xd8, 0x5d, 0xc7, 0x1d,
		0xb1, 0xe1, 0xa4, 0x6b, 0x6e, 0xf9, 0x48, 0x19, 0x59, 0x84, 0x8e, 0xe5, 0xee, 0x6f, 0xe7, 0x12,
		0x8c, 0xee, 0xdc, 0xb8, 0x05, 0xe8, 0xb4, 0x85, 0x17, 0x3a, 0xe1, 0x93, 0x2f, 0x3a, 0x49, 0x16,
		0xe1, 0x06, 0xb2, 0x4e, 0xee, 0x6c, 0x72, 0xaa, 0x77, 0x76, 0x90, 0xe0, 0x85, 0x4f, 0x2f, 0xf8,
		0xe4, 0xf4, 0xf4, 0xa6, 0x7e, 0x7b, 0xdb, 0xfc, 0x70, 0x72, 0x71, 0x76, 0xfe, 0xd7, 0xa6, 0x6f,
		0x3d, 0x4a, 0x8e, 0x0f, 0x12, 0x6d, 0x0d, 0x27, 0x93, 0x73, 0xe3, 0xeb, 0xbe, 0xb8, 0x3e, 0xbf,
		0xdd, 0x5c, 0xb0, 0x4c, 0x20, 0x44, 0xa7, 0xbc, 0xce, 0xb3, 0xeb, 0x4f, 0x35, 0x13, 0xae, 0xf3,
		0xbc, 0xdc, 0xac, 0xdf, 0xfd, 0xa3, 0x7e, 0x73, 0x59, 0xbf, 0x33, 0xe4, 0xb1, 0x56, 0x72, 0xc4,
		0xca, 0x73, 0x43, 0x13, 0xfa, 0x24, 0x12, 0x9f, 0x93, 0x8b, 0xce, 0x52, 0xc5, 0xe6, 0x64, 0x22,
		0xb3, 0x1c, 0x56, 0xd1, 0x0d, 0x07, 0x9b, 0x13, 0x88, 0xd1, 0x87, 0x40, 0xd8, 0x41, 0xd8, 0x35,
		0xf1, 0x85, 0x81, 0xe3, 0x85, 0xa5, 0x5a, 0x02, 0xaa, 0x50, 0xdb, 0xe0, 0x23, 0xc9, 0x4a, 0x3f,
		0x93, 0x6d, 0x7c, 0x25, 0xde, 0xa8, 0x4d, 0x99, 0x7a, 0x92, 0xb6, 0xf4, 0x52, 0x46, 0xd1, 0xdd,
		0x30, 0xd9, 0x4e, 0x9f, 0xf6, 0x47, 0x56, 0xab, 0x56, 0xf7, 0xab, 0x1a, 0x1f, 0x1b, 0xd1, 0xc6,
		0x56, 0x43, 0xa1, 0xef, 0xd9, 0x28, 0x93, 0x2b, 0x49, 0xc6, 0x16, 0xbc, 0x0f, 0xbc, 0xcf, 0x96,
		0x0a, 0xb2, 0x7e, 0x6f, 0x10, 0x0a, 0xab, 0xed, 0x04, 0xa1, 0xe3, 0x3d, 0x0e, 0x9c, 0xe0, 0x8b,
		0xf0, 0x37, 0x5f, 0x6a, 0xab, 0x0e, 0x82, 0x95, 0x87, 0x95, 0xa7, 0x69, 0xe5, 0x25, 0x37, 0xc7,
		0x9d, 0x84, 0x65, 0x79, 0xc9, 0xca, 0xef, 0x12, 0x90, 0xc0, 0xd4, 0x49, 0x8f, 0x69, 0x6a, 0x66,
		0x52, 0xd7, 0xc6, 0xe4, 0x76, 0x47, 0x6c, 0x28, 0x2a, 0x9f, 0x7a, 0xae, 0x55, 0xab, 0xf7, 0x45,
		0xab, 0x3c, 0x29, 0xaa, 0xaa, 0x55, 0x5f, 0x2a, 0xac, 0x7e, 0x94, 0x87, 0xcf, 0xb5, 0x99, 0x6f,
		0xf7, 0xa3, 0xe4, 0xfc, 0xea, 0xe4, 0xbb, 0xca, 0x70, 0xa6, 0x48, 0xeb, 0x47, 0xf1, 0xed, 0xfe,
		0xf0, 0xb9, 0x98, 0x3f, 0xde, 0xad, 0x94, 0x8f, 0x2a, 0x47, 0xb5, 0x83, 0xf2, 0xd1, 0xf8, 0xe8,
		0xd3, 0x6f, 0xef, 0x8b, 0xd6, 0xe1, 0xe4, 0x14, 0x93, 0x1f, 0xdd, 0x17, 0xad, 0xd2, 0xcb, 0x79,
		0xc6, 0x3f, 0xbc, 0x2f, 0x5a, 0xb5, 0x97, 0x93, 0x45, 0x3f, 0x9b, 0x3f, 0xe3, 0xe8, 0x47, 0x2f,
		0x87, 0xfa, 0x51, 0x8d, 0x7e, 0x72, 0x5f, 0xb4, 0xf6, 0x27, 0x3f, 0xa8, 0x8d, 0x7e, 0x30, 0xf3,
		0x0b, 0x07, 0xc3, 0xe7, 0xca, 0xcc, 0x89, 0x0e, 0x87, 0xcf, 0xfb, 0xe3, 0xaf, 0x8e, 0x16, 0xae,
		0xfe, 0x70, 0x74, 0xf5, 0x9b, 0x6b, 0x2d, 0x8d, 0x24, 0x2f, 0x4f, 0x46, 0xbd, 0x49, 0xee, 0x5f,
		0xbb, 0x78, 0x87, 0xab, 0xde, 0x61, 0x92, 0xaa, 0x8f, 0x06, 0x65, 0x92, 0xe0, 0x16, 0x82, 0x8b,
		0xc2, 0xe2, 0xcf, 0x63, 0xaa, 0x55, 0x60, 0x18, 0x16, 0x64, 0xe1, 0x91, 0x63, 0xe9, 0xea, 0x5f,
		0xba, 0x26, 0x43, 0x3f, 0xb0, 0x60, 0x8c, 0x05, 0x78, 0x87, 0x7a, 0xc0, 0x85, 0xa5, 0x66, 0x17,
		0xc5, 0x60, 0xbe, 0xe5, 0xb4, 0x13, 0xaa, 0x09, 0xd1, 0x47, 0xa1, 0x21, 0x40, 0x43, 0xd0, 0xa4,
		0x21, 0xb4, 0x7b, 0x61, 0x28, 0xda, 0xd6, 0xbf, 0x07, 0x76, 0x3b, 0x91, 0x84, 0xb7, 0xc1, 0x67,
		0x92, 0x62, 0x2f, 0xd3, 0x76, 0x32, 0x2a, 0x51, 0x26, 0xdc, 0xe4, 0xfd, 0xc6, 0xef, 0x76, 0x83,
		0xfe, 0x4d, 0xc0, 0x16, 0x60, 0x8b, 0x74, 0x6c, 0x31, 0x2e, 0x8f, 0xed, 0xb2, 0x7e, 0xf7, 0xcf,
		0xab, 0x9b, 0x3f, 0x9a, 0x67, 0x97, 0xb7, 0x77, 0x27, 0x97, 0xef, 0xeb, 0xcd, 0xbb, 0xbf, 0xae,
		0xeb, 0xe6, 0xa4, 0xb3, 0x9d, 0x97, 0xaf, 0xcb, 0xd7, 0x66, 0xe4, 0x89, 0x9d, 0xef, 0x9b, 0x71,
		0x9d, 0x9f, 0x6e, 0xcf, 0x4c, 0xb8, 0xd0, 0xd3, 0xfa, 0x87, 0x93, 0x8f, 0xe7, 0x77, 0xb1, 0xe1,
		0x1a, 0xf1, 0x70, 0xf7, 0x3f, 0xdd, 0x7c, 0x30, 0x2e, 0xfd, 0x2e, 0xdb, 0x45, 0x94, 0xaf, 0x6c,
		0x37, 0x20, 0xb1, 0x74, 0xf2, 0xd7, 0x3d, 0x03, 0x92, 0x55, 0x4c, 0x86, 0xf6, 0x83, 0x2b, 0xac,
		0x56, 0xcf, 0xf3, 0x44, 0x94, 0x5a, 0x12, 0xbc, 0xbe, 0x7a, 0x72, 0xf9, 0xa3, 0x92, 0x2b, 0x29,
		0x8b, 0xa8, 0xa4, 0x24, 0xe3, 0x40, 0x8a, 0x2a, 0x29, 0x17, 0x6d, 0x24, 0x01, 0x39, 0x5f, 0x3c,
		0xc2, 0x66, 0x44, 0xbd, 0x04, 0xa2, 0x0e, 0xa2, 0x9e, 0xcc, 0x78, 0xe3, 0x0f, 0xcc, 0xd5, 0x3b,
		0x3d, 0x25, 0xa7, 0xcd, 0x0b, 0xc7, 0xd9, 0xb4, 0xd7, 0x4a, 0xa2, 0xfc, 0xc3, 0xc4, 0xdd, 0xc1,
		0xd2, 0x74, 0x03, 0x4b, 0x67, 0xe8, 0x69, 0x0d, 0x5e, 0x9a, 0xe1, 0x4b, 0x5b, 0x00, 0xd2, 0x16,
		0x42, 0x32, 0x72, 0xb7, 0x69, 0x3b, 0x99, 0xc4, 0x3d, 0xb9, 0xe2, 0xf7, 0xee, 0x0a, 0xbb, 0xb3,
		0x59, 0x34, 0xbb, 0x84, 0xdb, 0x07, 0xc9, 0xf6, 0x9d, 0x22, 0x7e, 0xb7, 0xb7, 0x57, 0x18, 0xf3,
		0xac, 0xc2, 0xc2, 0x92, 0xa3, 0xea, 0xea, 0xb2, 0x01, 0x8a, 0xb7, 0xa6, 0xeb, 0x31, 0x21, 0x88,
		0x4c, 0x3e, 0x9f, 0x0c, 0x3c, 0x4a, 0x00, 0x0f, 0x80, 0x07, 0x2d, 0x78, 0x6c, 0xea, 0x5d, 0x65,
		0x79, 0x59, 0xb9, 0xde, 0x36, 0xa5, 0xd7, 0x4d, 0xbd, 0x80, 0x64, 0x2c, 0x24, 0xb9, 0x0b, 0x4a,
		0xd6, 0xc2, 0x92, 0xbe, 0xc0, 0xa4, 0x2f, 0x34, 0xe9, 0x0b, 0x2e, 0xd9, 0xc2, 0x4b, 0xa1, 0x38,
		0xed, 0x48, 0xe9, 0xac, 0x29, 0xc1, 0x9b, 0xcb, 0xf0, 0xea, 0xab, 0xbc, 0x7b, 0xfc, 0x5f, 0x14,
		0x1d, 0x06, 0xe3, 0xff, 0xdd, 0xf7, 0xfd, 0x5e, 0xd8, 0x6b, 0xf5, 0xdc, 0xff, 0x69, 0x0d, 0x7c,
		0x5f, 0x78, 0xe1, 0x6e, 0x7e, 0xf4, 0x2b, 0x81, 0xdf, 0xb2, 0xa6, 0xff, 0xd2, 0x90, 0xc1, 0x0b,
		0x92, 0xbf, 0xce, 0x24, 0x35, 0x4b, 0x6d, 0xd1, 0xb1, 0x07, 0x6e, 0x68, 0x39, 0xdd, 0x7e, 0xcf,
		0x0f, 0xa7, 0xdd, 0xf3, 0x52, 0xa3, 0xe3, 0xea, 0xc3, 0x26, 0x34, 0xb5, 0xd3, 0xf1, 0xc1, 0x46,
		0xc7, 0xbd, 0xa9, 0xff, 0xbf, 0xfa, 0xfb, 0xbb, 0xe6, 0xcd, 0xd5, 0xc7, 0xbb, 0x3a, 0x30, 0x37,
		0xc2, 0x0d, 0xbf, 0xdf, 0x73, 0x01, 0xb8, 0x09, 0x00, 0x37, 0x7a, 0x70, 0x5b, 0x87, 0xb6, 0xd3,
		0x95, 0x39, 0x5e, 0x92, 0x69, 0x87, 0x0b, 0xc5, 0xc8, 0x5b, 0x49, 0x71, 0x8c, 0xba, 0x37, 0xe8,
		0x8e, 0x6e, 0x6e, 0xc8, 0x19, 0x27, 0x9d, 0x20, 0x52, 0x0a, 0xbb, 0x22, 0xf4, 0x9d, 0x08, 0xf1,
		0xfb, 0xf6, 0x63, 0xba, 0x76, 0xc6, 0x2f, 0xaf, 0x64, 0xfd, 0xb1, 0xd3, 0x23, 0x66, 0xc7, 0x76,
		0x03, 0x01, 0xa8, 0x04, 0x3d, 0x05, 0x3d, 0x4d, 0x66, 0x37, 0x9b, 0xf7, 0xe1, 0x5a, 0x0b, 0x92,
		0x25, 0xce, 0x00, 0x17, 0x84, 0x31, 0x8f, 0x95, 0x00, 0x69, 0xb3, 0x47, 0x03, 0xf8, 0x00, 0x7c,
		0x00, 0x3e, 0x59, 0x8e, 0x8d, 0xa7, 0x71, 0x6f, 0xbc, 0xe4, 0x19, 0x03, 0x9d, 0xe4, 0x48, 0x57,
		0x4a, 0x84, 0x8b, 0x90, 0x14, 0x38, 0xb7, 0xbd, 0x21, 0x29, 0x33, 0x90, 0x2b, 0x4c, 0x5e, 0xc4,
		0xf1, 0xa4, 0x89, 0xfd, 0x74, 0x0a, 0xcc, 0xf4, 0xc7, 0x93, 0xc8, 0xb9, 0x2d, 0x3a, 0x8e, 0xe7,
		0x44, 0x99, 0x49, 0xeb, 0xff, 0x29, 0xfe, 0x97, 0x28, 0x49, 0x4b, 0xe9, 0xfb, 0x49, 0x35, 0xf7,
		0x24, 0x3e, 0x4a, 0xea, 0xf9, 0x27, 0x2f, 0x47, 0x22, 0x98, 0x83, 0x12, 0x1f, 0x7c, 0xb6, 0x55,
		0x9d, 0xa4, 0x11, 0x6c, 0x83, 0x60, 0xa3, 0x3e, 0x0e, 0x94, 0x40, 0xb6, 0x08, 0x66, 0xbd, 0xf1,
		0xdd, 0x5a, 0x0f, 0x4f, 0x32, 0xe6, 0x50, 0x51, 0xcc, 0x13, 0x9b, 0x03, 0xb6, 0xe8, 0x49, 0x9a,
		0x35, 0xe4, 0x4a, 0x09, 0x13, 0x99, 0xdd, 0x3a, 0x48, 0x4f, 0x44, 0xe6, 0x8e, 0x06, 0x1e, 0x82,
		0x90, 0x0b, 0x21, 0x17, 0x42, 0x2e, 0x02, 0xa0, 0xdb, 0xa2, 0x51, 0x63, 0x4b, 0x29, 0xe8, 0x4b,
		0x3f, 0x29, 0x24, 0xca, 0x97, 0xda, 0x91, 0x9a, 0xbc, 0x7f, 0x37, 0xba, 0xa6, 0xf7, 0x2f, 0x17,
		0xb9, 0xf8, 0x83, 0xe6, 0x04, 0x96, 0x19, 0x64, 0xa7, 0xa5, 0x12, 0x19, 0x65, 0x88, 0x8b, 0x48,
		0x73, 0xd5, 0xe6, 0xb9, 0x90, 0xe6, 0xaa, 0xce, 0x13, 0x49, 0x4e, 0x73, 0x9d, 0x5b, 0x70, 0x0c,
		0x60, 0x24, 0x15, 0x71, 0x96, 0x41, 0x98, 0x01, 0x23, 0x80, 0x11, 0xc0, 0xc8, 0xa6, 0x30, 0x32,
		0xb7, 0xe0, 0x38, 0xc0, 0xc8, 0xab, 0xc6, 0x39, 0xae, 0xc7, 0x8f, 0x04, 0x53, 0xa1, 0x53, 0x67,
		0xca, 0x97, 0x01, 0x1c, 0x00, 0x8e, 0x57, 0x5d, 0x25, 0x32, 0xe5, 0x21, 0x4d, 0x41, 0x9a, 0x82,
		0x34, 0xa5, 0x5e, 0x9a, 0x42, 0xa6, 0xfc, 0x26, 0x62, 0x06, 0x32, 0xe5, 0x55, 0x61, 0x2e, 0xd2,
		0x12, 0x12, 0x02, 0x2e, 0x32, 0xe5, 0x91, 0x29, 0xff, 0x7a, 0x9c, 0x44, 0xa6, 0x3c, 0xe8, 0x29,
		0xe8, 0x29, 0x32, 0xe5, 0xd3, 0x80, 0x24, 0x32, 0xe5, 0x01, 0x3e, 0x00, 0x1f, 0x80, 0x4f, 0xe6,
		0x62, 0x63, 0x64, 0xca, 0x23, 0x53, 0x1e, 0x21, 0x29, 0x42, 0xd2, 0x4c, 0x80, 0x1c, 0x32, 0xe5,
		0x67, 0x8e, 0x82, 0x4c, 0xf9, 0x34, 0xc7, 0x42, 0xa6, 0x3c, 0x32, 0xe5, 0xd7, 0x3f, 0x23, 0x64,
		0xca, 0x23, 0xe4, 0x42, 0xc8, 0x05, 0x36, 0x62, 0x56, 0xc8, 0x85, 0x4c, 0xf9, 0xd9, 0x4c, 0xf9,
		0x24, 0xe9, 0x52, 0x3b, 0x6a, 0x13, 0xe5, 0x5f, 0xd1, 0x06, 0x3f, 0xf9, 0x4b, 0x96, 0xdb, 0x65,
		0xfa, 0x0f, 0xf1, 0xb4, 0xe8, 0xca, 0x76, 0x66, 0xa5, 0xc4, 0x9d, 0x44, 0x59, 0x37, 0xc9, 0xa8,
		0x70, 0x72, 0xea, 0x2b, 0x95, 0xea, 0xce, 0x51, 0x5b, 0x6f, 0xe0, 0xba, 0x52, 0x1f, 0x78, 0xc2,
		0xf5, 0xa6, 0x7c, 0x9d, 0xe5, 0x36, 0x4a, 0x80, 0x54, 0xb4, 0xb2, 0x72, 0x98, 0xea, 0x51, 0xd8,
		0x74, 0x9e, 0x05, 0xed, 0x1b, 0x22, 0x1b, 0xf6, 0xb1, 0xe9, 0x84, 0x0f, 0x8c, 0xf5, 0xc0, 0x58,
		0x8f, 0x95, 0x86, 0x94, 0x70, 0x96, 0x07, 0x06, 0x78, 0x60, 0x80, 0x47, 0x3a, 0x4f, 0x8f, 0x01,
		0x1e, 0xd4, 0x0a, 0x04, 0x2a, 0x0b, 0x88, 0x95, 0x05, 0x94, 0x24, 0xfd, 0x4a, 0x29, 0xc0, 0x00,
		0x8f, 0x14, 0xde, 0x10, 0xe0, 0x01, 0xf0, 0x48, 0x0a, 0x1e, 0x28, 0x4b, 0xc2, 0x3e, 0x00, 0xf6,
		0x01, 0x32, 0xb5, 0x0f, 0x90, 0x6c, 0xc0, 0xf4, 0x5a, 0x1f, 0x94, 0x66, 0x77, 0x3b, 0xd5, 0x00,
		0xea, 0xb5, 0x37, 0x78, 0x72, 0x7a, 0x7a, 0x53, 0xbf, 0xbd, 0x6d, 0x7e, 0x38, 0xb9, 0x38, 0x3b,
		0xff, 0x2b, 0xad, 0x1d, 0xa6, 0x98, 0x4c, 0xbd, 0xf8, 0x27, 0xfd, 0x66, 0xf9, 0xdc, 0x7d, 0x5e,
		0x5c, 0x9f, 0xdf, 0xe6, 0x52, 0x1f, 0x72, 0xf8, 0x96, 0xdb, 0x7d, 0x9d, 0x5d, 0x7f, 0xaa, 0x65,
		0xf1, 0xbe, 0xce, 0xcb, 0xcd, 0xfa, 0xdd, 0x3f, 0xea, 0x37, 0x97, 0xf5, 0xbb, 0x8c, 0xbe, 0xb6,
		0x8a, 0x84, 0xfb, 0x4a, 0x75, 0x84, 0x46, 0x26, 0xf3, 0x29, 0xe4, 0xe5, 0x52, 0x20, 0x8f, 0x02,
		0xfc, 0x09, 0xfc, 0x29, 0x9d, 0xdd, 0x30, 0xce, 0xa3, 0x98, 0x2e, 0xef, 0x20, 0xfe, 0x6a, 0xaa,
		0x9c, 0x8c, 0x49, 0x5f, 0xc7, 0x49, 0x9a, 0xb0, 0x86, 0x7c, 0x8a, 0x5f, 0x6e, 0x16, 0xce, 0xe7,
		0xaf, 0xe8, 0x4f, 0x9d, 0x98, 0x6c, 0xeb, 0x32, 0xea, 0x27, 0x98, 0xbe, 0x09, 0x18, 0x1a, 0x80,
		0x41, 0x30, 0x83, 0xda, 0x4e, 0xe1, 0x57, 0x56, 0xa8, 0xed, 0x68, 0xfe, 0x85, 0xe6, 0x5f, 0x00,
		0x0d, 0x15, 0xa0, 0x01, 0x95, 0x1d, 0x51, 0x22, 0xa2, 0xc4, 0x4c, 0x45, 0x89, 0x50, 0xd9, 0x37,
		0x3a, 0x2a, 0x54, 0x76, 0x0d, 0x72, 0x2d, 0x54, 0x76, 0x23, 0x5f, 0x1b, 0x54, 0x76, 0x8a, 0xf7,
		0x06, 0x95, 0x1d, 0xfc, 0x09, 0xfc, 0x89, 0x0d, 0x7f, 0x82, 0xca, 0xce, 0x20, 0x2e, 0x65, 0xac,
		0xb2, 0x33, 0xa9, 0x4f, 0x9c, 0x8a, 0xec, 0xe6, 0xd5, 0x22, 0xa2, 0xf4, 0x30, 0xfb, 0xa5, 0x87,
		0x93, 0xc5, 0xa2, 0xaf, 0xc8, 0x70, 0xb2, 0x3c, 0x50, 0x50, 0x38, 0x7d, 0x21, 0xea, 0xab, 0x08,
		0x49, 0x6a, 0x07, 0xbf, 0xb9, 0xb6, 0xb7, 0x41, 0xe9, 0xe0, 0xf8, 0xd7, 0xcd, 0xa8, 0x1c, 0x1c,
		0x5d, 0x6b, 0x26, 0xcb, 0x06, 0xa3, 0x1b, 0xe3, 0x52, 0x33, 0x18, 0x5d, 0xcc, 0xc6, 0x25, 0x83,
		0xaf, 0x7c, 0x37, 0x3b, 0x06, 0x54, 0x0c, 0x6e, 0x70, 0x2b, 0x3b, 0x99, 0x2a, 0x17, 0x7c, 0x9d,
		0x19, 0xd2, 0x50, 0x9f, 0x8d, 0x6b, 0x05, 0x51, 0xde, 0x43, 0x67, 0xd2, 0xb2, 0x82, 0x7b, 0xfe,
		0xbb, 0x8e, 0x9b, 0x99, 0xbc, 0x9a, 0xd0, 0x2e, 0xf1, 0x96, 0xe3, 0x84, 0x97, 0xa4, 0x94, 0xc8,
		0xa2, 0xa3, 0x40, 0x1e, 0x4b, 0xb1, 0x6c, 0xa0, 0x8d, 0x25, 0x5b, 0x56, 0xa6, 0x0b, 0x63, 0x41,
		0xe8, 0x3b, 0xde, 0xa3, 0x0c, 0x5d, 0xec, 0x90, 0x73, 0x0b, 0xc1, 0xd0, 0x0e, 0x07, 0x81, 0x84,
		0xe6, 0x81, 0xe3, 0xe3, 0xa4, 0x1f, 0x37, 0x71, 0xf2, 0xfe, 0xee, 0xec, 0x13, 0x46, 0xf3, 0x00,
		0xb2, 0x00, 0x59, 0x1b, 0x5b, 0x8c, 0xf0, 0x06, 0x5d, 0xe1, 0xa7, 0x19, 0xfc, 0xb2, 0xb3, 0x4d,
		0x23, 0x79, 0x46, 0x46, 0x62, 0x39, 0xed, 0xf4, 0xe0, 0x37, 0x3d, 0x10, 0x40, 0x0b, 0xa0, 0x05,
		0xd0, 0x52, 0xba, 0x78, 0x66, 0x17, 0x50, 0x2d, 0xc5, 0x21, 0x6e, 0x6c, 0xef, 0x51, 0xa4, 0x4e,
		0x8b, 0x92, 0xd0, 0xa5, 0xfb, 0xc2, 0xf1, 0xa4, 0xb4, 0xfb, 0x96, 0x80, 0x2c, 0x4b, 0x87, 0x8b,
		0x92, 0xc7, 0x36, 0x17, 0x4c, 0xd6, 0x1e, 0xef, 0x83, 0x6f, 0x47, 0x6d, 0xf7, 0x4e, 0x9d, 0x47,
		0x67, 0xbc, 0x51, 0xc5, 0x21, 0x91, 0x28, 0x77, 0x61, 0x7f, 0x67, 0xff, 0x0a, 0x2a, 0xc5, 0xa3,
		0x0a, 0xe3, 0xb7, 0xa0, 0xa9, 0x59, 0x7b, 0x03, 0xd9, 0x00, 0xd2, 0xf7, 0xd3, 0xa2, 0x3d, 0xa5,
		0xe8, 0x6f, 0x0e, 0x15, 0x77, 0x9f, 0x46, 0x57, 0x13, 0xfd, 0xcd, 0xa8, 0xde, 0xae, 0x2b, 0xba,
		0x0f, 0xc2, 0x0f, 0x92, 0xcb, 0xd7, 0xd3, 0x03, 0x40, 0xbf, 0x26, 0x24, 0x86, 0xd0, 0xaf, 0x77,
		0x54, 0xea, 0xd7, 0x63, 0x9b, 0x4e, 0x1f, 0x5c, 0x4d, 0x8e, 0x93, 0x2e, 0xb6, 0x2a, 0xa5, 0x8d,
		0xad, 0xca, 0x88, 0xad, 0x10, 0x5b, 0x29, 0x8a, 0xad, 0x92, 0x2e, 0xb9, 0x19, 0x6f, 0x9b, 0xa4,
		0x88, 0x73, 0xad, 0xdd, 0x25, 0x4d, 0x01, 0x94, 0xb8, 0x10, 0xa5, 0x2d, 0x48, 0x99, 0x0b, 0x73,
		0xd5, 0x02, 0x75, 0x3a, 0x32, 0x26, 0x2a, 0x49, 0x1c, 0xfb, 0x44, 0xb2, 0x5c, 0xc9, 0x96, 0xed,
		0xba, 0xe5, 0xeb, 0x74, 0x74, 0xd7, 0x62, 0xa4, 0x0c, 0x2c, 0x53, 0x2f, 0xea, 0xf8, 0x40, 0x8e,
		0x17, 0x0a, 0xbf, 0x63, 0xcb, 0x34, 0x8f, 0xb8, 0x96, 0x2e, 0x3e, 0xf4, 0x5b, 0x96, 0xc1, 0x6f,
		0x5a, 0xa5, 0x93, 0x12, 0x04, 0xc8, 0xc0, 0x80, 0x0a, 0x14, 0xc8, 0xc1, 0x81, 0x1c, 0x24, 0x28,
		0xc1, 0x42, 0x0e, 0x68, 0x48, 0x54, 0xa5, 0x76, 0xa4, 0xa8, 0xae, 0x6b, 0xad, 0xf5, 0xff, 0x67,
		0xef, 0x4f, 0x9b, 0x1a, 0x47, 0xd2, 0x36, 0x50, 0xf8, 0x3b, 0xbf, 0xc2, 0xa1, 0xe8, 0x0f, 0x30,
		0x0f, 0x2a, 0xb0, 0xc1, 0xa6, 0x20, 0xe2, 0x8d, 0x0e, 0x77, 0x15, 0x5d, 0xc3, 0x3b, 0x2c, 0x75,
		0x80, 0xee, 0x67, 0x7a, 0xc0, 0x4d, 0xa8, 0xec, 0x84, 0xd2, 0x69, 0x23, 0xf3, 0x48, 0x72, 0x4d,
		0xd1, 0x85, 0xff, 0xfb, 0x09, 0xcb, 0xb2, 0xbc, 0xca, 0xce, 0xe5, 0xce, 0xd4, 0xe2, 0x8b, 0x98,
		0x69, 0x96, 0xb2, 0x52, 0x52, 0xe6, 0xbd, 0x5c, 0xf7, 0xfe, 0xc5, 0x09, 0x98, 0x9d, 0xf0, 0xbf,
		0xad, 0x56, 0x11, 0x92, 0xaa, 0xfc, 0x8f, 0x08, 0xd7, 0x9c, 0x9e, 0xb6, 0xe9, 0x3e, 0x9e, 0x24,
		0xcf, 0x1e, 0xcc, 0xff, 0x21, 0xfe, 0x5d, 0x7e, 0x80, 0x26, 0x3d, 0x4d, 0x64, 0xab, 0x8a, 0x14,
		0xfd, 0x4b, 0xe6, 0xfc, 0x4d, 0xb1, 0x5b, 0x24, 0xfe, 0xbe, 0x47, 0x81, 0x43, 0xb5, 0x79, 0xa3,
		0x2e, 0x46, 0xcf, 0x1a, 0x7f, 0x97, 0xa9, 0x53, 0xa1, 0x23, 0x92, 0x01, 0xe6, 0xc4, 0x9a, 0x98,
		0x13, 0xcb, 0x5d, 0xd1, 0x42, 0xb5, 0xd3, 0x44, 0x8c, 0x6b, 0x8a, 0x61, 0x55, 0x1c, 0x15, 0xfa,
		0x59, 0x14, 0x95, 0x83, 0x26, 0x48, 0x21, 0x2f, 0xc1, 0x82, 0xf8, 0xec, 0xd1, 0x62, 0xcb, 0x88,
		0xb7, 0x05, 0x91, 0x02, 0x62, 0xd3, 0x07, 0x99, 0xee, 0x6b, 0xc9, 0x05, 0x99, 0xee, 0x88, 0x12,
		0x64, 0xc3, 0x56, 0xd9, 0xc0, 0x6e, 0x64, 0xba, 0x8b, 0xa2, 0x0a, 0x64, 0xba, 0x43, 0x64, 0x41,
		0x64, 0x95, 0x42, 0x64, 0x21, 0xd3, 0x5d, 0xe8, 0x19, 0x91, 0xe9, 0x0e, 0xa1, 0x05, 0xa1, 0x85,
		0x4c, 0x77, 0x64, 0xba, 0x73, 0x2e, 0x87, 0x4c, 0xf7, 0xdc, 0x1c, 0x01, 0x32, 0xdd, 0x97, 0x7d,
		0x21, 0xd3, 0x5d, 0xab, 0xf7, 0x3a, 0xfb, 0xae, 0x77, 0x53, 0xbe, 0x6b, 0xbd, 0x3d, 0xef, 0x04,
		0x3c, 0xd7, 0xb2, 0x30, 0x52, 0x51, 0x03, 0x16, 0x75, 0xaa, 0x0c, 0xbc, 0xd7, 0xa4, 0xf0, 0x0f,
		0xf3, 0x64, 0x96, 0x13, 0xeb, 0xc2, 0x3c, 0x99, 0x31, 0x97, 0x15, 0xa9, 0x4b, 0xa6, 0x98, 0x64,
		0x40, 0x57, 0x4c, 0x6a, 0x95, 0xaa, 0x4d, 0x95, 0x66, 0xd2, 0x13, 0x73, 0xa2, 0x3c, 0xd1, 0x11,
		0x33, 0x3e, 0x0c, 0xa3, 0x0d, 0x31, 0xa3, 0xfd, 0x97, 0xee, 0x87, 0xb9, 0x25, 0xb0, 0xc5, 0x63,
		0xf9, 0xb1, 0x22, 0xfa, 0xc7, 0x27, 0x2c, 0xf8, 0x85, 0x83, 0x92, 0x30, 0xe0, 0x63, 0xfe, 0xb4,
		0x97, 0xe5, 0xa4, 0x23, 0x5a, 0xfa, 0x59, 0x41, 0x39, 0x64, 0x14, 0xb3, 0x9c, 0x56, 0x16, 0x29,
		0x61, 0xf6, 0x2f, 0x73, 0xdb, 0xb4, 0x6e, 0x7b, 0x94, 0xb6, 0x65, 0xc9, 0x2e, 0x48, 0xbf, 0xfd,
		0xec, 0xdb, 0x4e, 0xde, 0x69, 0xea, 0x7d, 0x2c, 0xbf, 0xd7, 0x0f, 0x5d, 0xef, 0xc9, 0x7e, 0xe9,
		0x75, 0xdd, 0xf6, 0xe2, 0xc4, 0xa9, 0x04, 0x75, 0xcc, 0x7d, 0x6e, 0x6e, 0x47, 0x96, 0xe7, 0x7d,
		0xa4, 0x22, 0xe3, 0x55, 0xc8, 0x77, 0x1a, 0xd9, 0xfa, 0x2f, 0x4b, 0x87, 0x2e, 0xac, 0x43, 0xae,
		0xdc, 0xc8, 0x94, 0x1b, 0x79, 0xce, 0x23, 0xcb, 0xe8, 0xc1, 0x04, 0xa9, 0x26, 0x2d, 0x6f, 0xc1,
		0xea, 0xb0, 0x47, 0xd7, 0x63, 0x1d, 0x3b, 0x60, 0x61, 0x7a, 0xdc, 0x30, 0xd9, 0x96, 0x99, 0x4f,
		0xa7, 0x09, 0xab, 0x95, 0x69, 0x38, 0x6b, 0x0d, 0x16, 0x1e, 0xc3, 0x84, 0xe3, 0x98, 0x44, 0x0d,
		0x0d, 0x61, 0x83, 0x42, 0xd8, 0x70, 0xe0, 0x3b, 0x46, 0x39, 0x05, 0xb1, 0x2e, 0x2d, 0xc5, 0xf2,
		0x98, 0xfb, 0xf4, 0xf5, 0x4b, 0xcf, 0x5f, 0x7d, 0xce, 0x0b, 0xfb, 0x3b, 0x7b, 0x59, 0x31, 0x7a,
		0x2e, 0xaf, 0x21, 0x08, 0x59, 0x0b, 0x34, 0xfb, 0x9e, 0xcb, 0xab, 0x09, 0x86, 0x06, 0xc4, 0x71,
		0xf7, 0x5c, 0x9e, 0xa6, 0x0c, 0xf1, 0xde, 0xcb, 0x33, 0x57, 0x97, 0xa3, 0x07, 0x33, 0x27, 0xd9,
		0xa9, 0x3a, 0x40, 0xf2, 0xd7, 0x83, 0x99, 0x8f, 0x2c, 0xf5, 0x18, 0xd6, 0xe8, 0xc1, 0xac, 0xd3,
		0xb7, 0x27, 0x48, 0xd2, 0x9b, 0xe3, 0xdb, 0x13, 0x23, 0x79, 0x33, 0xbe, 0x3d, 0xd5, 0xb1, 0xaf,
		0x64, 0xf3, 0x5e, 0x91, 0x37, 0xa1, 0xc2, 0x3c, 0x54, 0x4c, 0x44, 0xce, 0x4c, 0xe4, 0x4c, 0x45,
		0xcb, 0x5c, 0x72, 0x4c, 0x26, 0xc9, 0x6c, 0xea, 0x0e, 0xf5, 0x05, 0x8a, 0x71, 0x5f, 0x6c, 0x35,
		0xfe, 0x99, 0x51, 0x34, 0xc7, 0x0a, 0x6b, 0xc4, 0xef, 0x94, 0x79, 0xea, 0xc4, 0x64, 0x67, 0xbe,
		0x1d, 0x12, 0xec, 0xcd, 0xc2, 0x1e, 0xbd, 0x27, 0x58, 0xeb, 0xb3, 0x13, 0x86, 0xcc, 0xf7, 0x48,
		0x46, 0xcd, 0x46, 0x0b, 0x6e, 0x6f, 0xdf, 0xed, 0xdb, 0xc7, 0xad, 0xb7, 0xbb, 0xaa, 0x7d, 0xdc,
		0x1a, 0xfd, 0x58, 0x8d, 0xbe, 0x8d, 0x7e, 0xae, 0xdd, 0xed, 0xdb, 0x87, 0xe3, 0x9f, 0xeb, 0x77,
		0xfb, 0x76, 0xbd, 0xb5, 0x73, 0x7f, 0xff, 0x6e, 0xe7, 0xc7, 0xc1, 0x40, 0xfc, 0x42, 0xf5, 0x42,
		0xe1, 0x16, 0xc5, 0x16, 0x5e, 0xdd, 0x9c, 0xfd, 0x9b, 0x7c, 0x1f, 0xff, 0x34, 0xb9, 0x91, 0x3f,
		0x11, 0xec, 0x64, 0x96, 0xc5, 0xd2, 0xb4, 0xcc, 0xda, 0xd8, 0x30, 0x66, 0x75, 0xec, 0xc7, 0xa6,
		0xfd, 0x6b, 0xeb, 0x47, 0x75, 0xf7, 0x70, 0x70, 0xb2, 0xf3, 0xe3, 0x68, 0x30, 0xff, 0xc7, 0xb7,
		0x65, 0x1f, 0xab, 0xee, 0x1e, 0x0d, 0x4e, 0x52, 0xfe, 0xa5, 0x31, 0x38, 0xe1, 0x5c, 0xa3, 0x3e,
		0xd8, 0x5e, 0xf8, 0xe8, 0xf0, 0xef, 0xb5, 0xb4, 0x0b, 0x0e, 0x53, 0x2e, 0x38, 0x48, 0xbb, 0xe0,
		0x20, 0xe5, 0x82, 0xd4, 0x47, 0xaa, 0xa5, 0x5c, 0x50, 0x1f, 0xbc, 0x2d, 0x7c, 0x7e, 0x7b, 0xf9,
		0x47, 0x1b, 0x83, 0x9d, 0xb7, 0xb4, 0x7f, 0x3b, 0x1a, 0xbc, 0x9d, 0xec, 0x6c, 0x82, 0xe8, 0x02,
		0x59, 0x99, 0x27, 0xab, 0xec, 0x05, 0xb9, 0xe9, 0x5c, 0x39, 0xb4, 0x43, 0x58, 0xbf, 0x38, 0x4d,
		0x3b, 0x04, 0x23, 0x35, 0x10, 0xa8, 0x32, 0x85, 0x15, 0x0f, 0x2b, 0x3e, 0x3b, 0x2b, 0xbe, 0x80,
		0x55, 0xa6, 0x05, 0xcd, 0x7d, 0x9e, 0x4d, 0x09, 0xd8, 0x9b, 0xfb, 0x75, 0x3a, 0x4e, 0xbd, 0x37,
		0x13, 0xc4, 0x9c, 0xf9, 0x4d, 0x43, 0xb3, 0xef, 0xeb, 0xd1, 0x83, 0x7c, 0x8e, 0x9e, 0xe3, 0x61,
		0xf6, 0xb7, 0x8f, 0xa3, 0xa7, 0xba, 0x61, 0x61, 0xf0, 0x70, 0x19, 0x3f, 0xc6, 0xfc, 0x2f, 0x39,
		0xea, 0xf8, 0x2d, 0xa5, 0x4c, 0x54, 0x94, 0x48, 0x51, 0x73, 0xa0, 0x11, 0x27, 0x21, 0x55, 0x02,
		0xc8, 0x81, 0x4e, 0x73, 0x5f, 0xcc, 0xe5, 0x40, 0x8b, 0x77, 0xfb, 0x43, 0xb3, 0x9f, 0x8c, 0x9b,
		0xfd, 0x40, 0x54, 0x14, 0x48, 0x54, 0x20, 0xa4, 0x0a, 0x63, 0x0c, 0xc6, 0x18, 0x42, 0xaa, 0x08,
		0xa9, 0xf2, 0x1a, 0xad, 0x08, 0xa9, 0xaa, 0x3e, 0x2e, 0x42, 0xaa, 0x08, 0xa9, 0x2e, 0x30, 0x2b,
		0x42, 0xaa, 0x88, 0x7d, 0x21, 0xa4, 0xaa, 0x2c, 0xba, 0x40, 0x56, 0x08, 0xa9, 0x6a, 0xbf, 0x2f,
		0x42, 0xaa, 0x1c, 0x8b, 0x23, 0xa4, 0x0a, 0x2b, 0x1e, 0x56, 0x3c, 0xac, 0x78, 0x2e, 0xef, 0x30,
		0x42, 0xaa, 0x33, 0x44, 0x91, 0xf3, 0x90, 0x2a, 0x79, 0x57, 0x29, 0xe5, 0x88, 0xaa, 0xde, 0xd6,
		0x52, 0x3a, 0x1a, 0xc5, 0x08, 0x68, 0x0b, 0x74, 0x89, 0xa1, 0xe6, 0x14, 0xdd, 0x1c, 0x42, 0xd1,
		0x2c, 0x46, 0x95, 0x27, 0xca, 0xd6, 0x31, 0x46, 0xf6, 0x60, 0x54, 0x1a, 0xc6, 0xc8, 0x9c, 0x81,
		0x74, 0xbb, 0x98, 0x15, 0x0d, 0x0e, 0x46, 0xe0, 0x45, 0xb0, 0xb0, 0x7f, 0xfa, 0x22, 0x94, 0xf5,
		0xa3, 0xac, 0x7f, 0x91, 0x98, 0xc4, 0x8b, 0xfa, 0xa7, 0xae, 0x45, 0x49, 0xbf, 0x49, 0x4b, 0x04,
		0x25, 0xfd, 0x28, 0xe9, 0xd7, 0x6b, 0x7c, 0x23, 0xff, 0x24, 0x0b, 0x53, 0x4f, 0x3a, 0xff, 0xe4,
		0xb9, 0xd7, 0x21, 0xf0, 0x59, 0x45, 0xab, 0xc0, 0x67, 0x05, 0x9f, 0x15, 0x7c, 0x56, 0x82, 0x14,
		0x83, 0xc9, 0x2d, 0x70, 0xb1, 0x43, 0x5c, 0x41, 0x5c, 0xc1, 0xc5, 0x0e, 0x17, 0xbb, 0xac, 0x9f,
		0x6a, 0xca, 0x43, 0x33, 0xf5, 0x73, 0x86, 0x15, 0x4b, 0x23, 0x19, 0x35, 0xfb, 0x23, 0xaa, 0x95,
		0x50, 0xad, 0x04, 0x13, 0x50, 0xa3, 0x28, 0x42, 0xb5, 0x12, 0xb9, 0xa0, 0x18, 0x11, 0x1f, 0x0b,
		0xe4, 0x85, 0x45, 0xb2, 0x02, 0x7c, 0x46, 0x10, 0x18, 0x65, 0xf1, 0x19, 0xbd, 0xa8, 0x99, 0x20,
		0x73, 0xcc, 0xa1, 0x68, 0x88, 0x55, 0x61, 0x88, 0xc1, 0x10, 0x2b, 0x8a, 0x21, 0x26, 0xcb, 0x72,
		0xc9, 0x02, 0x92, 0x11, 0x8c, 0x54, 0xc2, 0x93, 0xb6, 0x11, 0x08, 0x59, 0x91, 0x8c, 0x25, 0x29,
		0x59, 0x53, 0x03, 0x8b, 0x52, 0xb3, 0xaa, 0x36, 0x96, 0xd5, 0xc6, 0xba, 0x7a, 0x58, 0x58, 0x8d,
		0x95, 0x15, 0x59, 0x9a, 0x8c, 0xb5, 0x93, 0x85, 0xdc, 0x17, 0xfb, 0x85, 0x8e, 0x7e, 0x2b, 0x73,
		0x65, 0x8e, 0xb4, 0x04, 0x42, 0x3c, 0xe3, 0x94, 0x4a, 0x00, 0xe8, 0x10, 0x04, 0x1a, 0x05, 0x82,
		0x2e, 0xc1, 0xa0, 0x5d, 0x40, 0x68, 0x17, 0x14, 0x7a, 0x05, 0x06, 0x8d, 0xe0, 0x20, 0x12, 0x20,
		0xc9, 0xab, 0x5e, 0x38, 0x5e, 0xc7, 0x09, 0x7b, 0xfe, 0x2b, 0xe1, 0xbc, 0x65, 0x65, 0x07, 0xb0,
		0x31, 0x91, 0x52, 0x21, 0x2a, 0xa4, 0x4e, 0xdb, 0x82, 0x3b, 0x52, 0xba, 0xa4, 0xe5, 0xd3, 0xca,
		0x42, 0xe1, 0xb5, 0x16, 0x6e, 0xad, 0x10, 0x97, 0x76, 0x2e, 0x73, 0xe8, 0x90, 0x16, 0xe5, 0x2d,
		0xdc, 0xc0, 0x64, 0x79, 0xf1, 0x5e, 0x7c, 0xb3, 0x9d, 0xb7, 0xed, 0xbb, 0xaa, 0x5d, 0x6b, 0x8d,
		0x7f, 0x39, 0xb8, 0xdb, 0xb7, 0x6b, 0x2d, 0x8a, 0x62, 0xc8, 0xf9, 0xaf, 0x96, 0x8e, 0x23, 0xd1,
		0x51, 0x2c, 0xb9, 0x70, 0x97, 0x3f, 0xf3, 0x74, 0x30, 0x3f, 0x69, 0x38, 0x19, 0xd2, 0x15, 0x07,
		0xbb, 0x05, 0x92, 0x45, 0x0d, 0xc8, 0xa2, 0x55, 0xb2, 0x08, 0xf5, 0xc2, 0xe6, 0xeb, 0x85, 0xf7,
		0xb6, 0xab, 0x43, 0xb9, 0xf0, 0x7e, 0x24, 0x2a, 0xaa, 0xad, 0x05, 0x09, 0x32, 0x92, 0x08, 0x10,
		0xd0, 0x0b, 0x02, 0x1a, 0xd4, 0x9a, 0x5b, 0x6a, 0xcd, 0xbf, 0xd6, 0xda, 0xca, 0xd7, 0x73, 0xa9,
		0x3f, 0x0f, 0x81, 0x1e, 0xb6, 0x9e, 0x9d, 0xe0, 0xaf, 0x2e, 0xf3, 0x9e, 0xc2, 0xaf, 0xb6, 0xef,
		0x78, 0x4f, 0x8c, 0xde, 0x77, 0xb3, 0x70, 0x07, 0xb8, 0x70, 0xe0, 0xc2, 0x81, 0x0b, 0x27, 0x97,
		0x2e, 0x1c, 0x7d, 0xee, 0x16, 0xe5, 0xfc, 0x3b, 0x13, 0xe0, 0x5b, 0x1b, 0xe8, 0x4e, 0x0c, 0xcc,
		0xff, 0xb9, 0xbf, 0x7f, 0x77, 0x7f, 0xff, 0x6e, 0xf4, 0xf3, 0xce, 0x1b, 0xfb, 0xee, 0xb4, 0x43,
		0x4a, 0xd5, 0xd9, 0xa2, 0xdc, 0x0c, 0x9d, 0xc8, 0xce, 0xdc, 0x8e, 0xe4, 0x45, 0x59, 0x67, 0x1a,
		0xe4, 0x51, 0x4c, 0xf7, 0x5c, 0x58, 0x4f, 0x67, 0xfa, 0xe7, 0x38, 0xf5, 0x28, 0xfe, 0x61, 0x8f,
		0x24, 0xd4, 0x5b, 0xd1, 0x96, 0x1e, 0xfa, 0x39, 0x7e, 0xdc, 0xf8, 0x07, 0xa9, 0x74, 0x51, 0x3a,
		0x62, 0x51, 0x20, 0x14, 0xc2, 0x00, 0x1e, 0xb9, 0x97, 0x9d, 0x08, 0xed, 0x21, 0x52, 0x9f, 0x33,
		0x14, 0x87, 0x48, 0x7d, 0x16, 0xe8, 0x8c, 0x20, 0x71, 0x36, 0x15, 0x8e, 0x1d, 0xd1, 0xb4, 0xdc,
		0x9c, 0x4b, 0xac, 0x9d, 0xc8, 0x91, 0x02, 0xca, 0x55, 0x72, 0x1b, 0x5b, 0x97, 0x6d, 0x0d, 0x29,
		0x0b, 0x29, 0x0b, 0x29, 0xbb, 0xb9, 0x52, 0x76, 0x41, 0x9c, 0x14, 0x50, 0xd8, 0xca, 0x0d, 0x6a,
		0x59, 0xe1, 0xb7, 0x90, 0x6b, 0xf5, 0xb6, 0xf4, 0xd4, 0xa8, 0xc4, 0x6a, 0x0d, 0x62, 0x15, 0x62,
		0xb5, 0x60, 0x62, 0x15, 0x69, 0xa6, 0xea, 0xcb, 0x21, 0x46, 0x81, 0x18, 0x85, 0x41, 0x81, 0x41,
		0xe7, 0xfc, 0xac, 0x20, 0xcd, 0x14, 0x69, 0xa6, 0xd4, 0x1b, 0x8b, 0x34, 0xd3, 0xb4, 0x1b, 0x20,
		0xcd, 0x54, 0xf8, 0x48, 0x90, 0x66, 0x4a, 0x71, 0x32, 0x48, 0x33, 0x85, 0x2c, 0x5a, 0x2a, 0x8b,
		0x90, 0xb8, 0x87, 0x34, 0xd3, 0xe2, 0x08, 0x68, 0x50, 0x2b, 0xd2, 0x4c, 0xb3, 0x35, 0x96, 0x2a,
		0x48, 0x33, 0x15, 0xd4, 0xc1, 0x48, 0x33, 0x85, 0x0b, 0x07, 0x2e, 0x9c, 0x62, 0xb8, 0x70, 0x90,
		0x66, 0x8a, 0x34, 0x53, 0x33, 0xc8, 0x0e, 0x69, 0xa6, 0x26, 0x19, 0xbc, 0xd0, 0x69, 0xa6, 0x14,
		0x91, 0xde, 0x8a, 0xb1, 0x2c, 0x53, 0x89, 0x81, 0x5f, 0x74, 0xa4, 0x62, 0xb6, 0xf7, 0x54, 0x3c,
		0x30, 0x2c, 0xf1, 0xa4, 0x57, 0x88, 0xa0, 0x1e, 0xc6, 0x91, 0x1a, 0x3b, 0x42, 0x22, 0xb9, 0x60,
		0x52, 0x1e, 0x58, 0x4a, 0x39, 0x28, 0xfa, 0x25, 0x80, 0x85, 0x36, 0xd4, 0x86, 0x08, 0x22, 0x37,
		0x8d, 0xa8, 0xc7, 0x14, 0x90, 0x87, 0x0e, 0xb3, 0x72, 0x69, 0x56, 0x4a, 0x69, 0x55, 0xca, 0xbd,
		0x65, 0x6b, 0xe8, 0x2d, 0x9b, 0xa9, 0xe9, 0x8b, 0x79, 0x44, 0xeb, 0xbd, 0x58, 0x98, 0x47, 0x84,
		0xbe, 0xb2, 0x99, 0x7a, 0x8e, 0x30, 0x8f, 0x08, 0xf3, 0x88, 0xb8, 0x37, 0x1d, 0xf3, 0x88, 0x20,
		0xae, 0x20, 0xae, 0x32, 0x71, 0x54, 0x63, 0x1e, 0x91, 0x31, 0x43, 0x30, 0xb3, 0x71, 0xff, 0x4b,
		0xad, 0x40, 0x8c, 0xfa, 0x27, 0xf4, 0xc1, 0x61, 0xd4, 0xbf, 0x0a, 0x67, 0x98, 0x1c, 0xf3, 0xbf,
		0x8c, 0x17, 0x36, 0x78, 0xc4, 0x3f, 0xff, 0x70, 0x7b, 0xe2, 0xdd, 0xd7, 0x31, 0xde, 0x3f, 0x74,
		0x9e, 0x04, 0x67, 0xfb, 0x27, 0x57, 0x60, 0xb0, 0x3f, 0x06, 0xfb, 0xcf, 0x91, 0x91, 0xf8, 0x54,
		0xff, 0xf1, 0x85, 0x18, 0xe9, 0x6f, 0xd2, 0xd2, 0xc0, 0x48, 0x7f, 0x8c, 0xf4, 0x87, 0x0b, 0x1d,
		0x2e, 0x74, 0xf8, 0xa4, 0xe0, 0x93, 0x82, 0x4f, 0x0a, 0x3e, 0x29, 0x43, 0x9e, 0xef, 0x21, 0xd8,
		0xfb, 0xe6, 0x74, 0xfb, 0x04, 0xa2, 0x66, 0xb2, 0x14, 0xe4, 0x0d, 0xe4, 0x0d, 0xe4, 0x8d, 0x04,
		0xfb, 0x84, 0xc3, 0xd5, 0x08, 0x24, 0x8e, 0x42, 0x29, 0x3c, 0x4d, 0xe9, 0x3b, 0x61, 0x2b, 0x9d,
		0xbe, 0xeb, 0x85, 0x07, 0x35, 0xc2, 0x76, 0x51, 0x14, 0xdd, 0xa2, 0xae, 0xe3, 0xb2, 0x1d, 0x9a,
		0xfc, 0x6c, 0xc2, 0xd4, 0xff, 0x0b, 0xd7, 0xd3, 0x50, 0x4e, 0x42, 0x5a, 0xf5, 0x93, 0x2c, 0xfb,
		0x7b, 0xac, 0x77, 0xa8, 0xd7, 0xfd, 0xd5, 0x77, 0xda, 0xa1, 0xdb, 0xf3, 0x3e, 0xba, 0x4f, 0xee,
		0xc8, 0x05, 0x4e, 0x57, 0x39, 0x42, 0x98, 0xea, 0x7f, 0xe1, 0x7c, 0x2f, 0xdc, 0x51, 0x1d, 0xd6,
		0x8e, 0x0f, 0x8f, 0x1b, 0x47, 0xb5, 0xe3, 0x7a, 0x81, 0xce, 0x2c, 0x27, 0xc5, 0x08, 0xad, 0x2c,
		0x8b, 0x11, 0x08, 0x05, 0xf2, 0x57, 0xf6, 0xdd, 0x26, 0xab, 0x2c, 0xa2, 0xac, 0x28, 0x22, 0xaf,
		0x24, 0xb2, 0x66, 0x2a, 0x80, 0xe7, 0x0b, 0x7f, 0x6b, 0x83, 0x9d, 0x7f, 0xec, 0xfc, 0x6c, 0x65,
		0x4d, 0x17, 0x5b, 0x66, 0xef, 0x3b, 0x40, 0x79, 0xc1, 0xfa, 0xc5, 0x69, 0xca, 0x0b, 0x90, 0x94,
		0xb0, 0x18, 0xe9, 0x1b, 0x87, 0xba, 0xc6, 0x3f, 0xc8, 0xf7, 0xc3, 0x57, 0x8e, 0x02, 0xde, 0x3a,
		0x4f, 0x53, 0xdf, 0xa5, 0x3a, 0xdd, 0xeb, 0xc9, 0x46, 0x97, 0xf2, 0x1c, 0xaa, 0x78, 0x0c, 0x25,
		0x51, 0x07, 0x1c, 0xe9, 0x70, 0xa4, 0x1b, 0xb0, 0xb4, 0x09, 0x3a, 0x0f, 0xab, 0x74, 0x1a, 0x5e,
		0xd2, 0x59, 0x38, 0x62, 0x31, 0x94, 0xad, 0x48, 0x89, 0x0a, 0x94, 0xad, 0x40, 0x54, 0xac, 0x7b,
		0x44, 0xc4, 0xdc, 0xe0, 0x03, 0xd7, 0xc3, 0x46, 0xe4, 0xec, 0x44, 0xcb, 0x56, 0x6a, 0x46, 0x21,
		0x62, 0x6e, 0x88, 0xb9, 0x41, 0xde, 0x40, 0xde, 0x6c, 0x8e, 0xbc, 0x41, 0xcc, 0x6d, 0xf9, 0xbe,
		0x20, 0xe6, 0x26, 0xe8, 0x94, 0x44, 0xcc, 0x0d, 0x31, 0x37, 0xc4, 0xdc, 0x54, 0x15, 0x02, 0xfd,
		0x2a, 0x88, 0xb9, 0xad, 0x04, 0xc9, 0x88, 0xb9, 0x19, 0xa6, 0x4b, 0xc4, 0xdc, 0x10, 0x73, 0x13,
		0x42, 0xe9, 0xb9, 0x8c, 0xb9, 0x65, 0x56, 0x02, 0x3c, 0x17, 0x72, 0x43, 0xf1, 0x2f, 0x21, 0xb7,
		0xa2, 0xf8, 0x57, 0x8e, 0x1b, 0x4c, 0x96, 0xfd, 0xce, 0xd2, 0xff, 0x06, 0x17, 0xfc, 0x72, 0x56,
		0xbc, 0x52, 0x6e, 0xba, 0x74, 0xa9, 0xef, 0x96, 0xc0, 0xae, 0xf2, 0xee, 0x26, 0xc9, 0x2e, 0xae,
		0xd8, 0x3c, 0xd5, 0x4d, 0x5b, 0xbe, 0x59, 0x8b, 0x5b, 0xb1, 0x64, 0x1b, 0xac, 0xd1, 0x93, 0xda,
		0xd1, 0x93, 0xba, 0xc3, 0x9d, 0x48, 0xaf, 0x84, 0x4e, 0xf0, 0xf1, 0x92, 0x6b, 0x52, 0x36, 0x78,
		0x75, 0xfc, 0x71, 0xad, 0x43, 0x93, 0xc7, 0x61, 0x29, 0xe0, 0x90, 0xe4, 0x75, 0x38, 0x0a, 0x3b,
		0x14, 0x85, 0x1d, 0x86, 0x62, 0x0e, 0x41, 0x31, 0xa2, 0x5e, 0x17, 0x8f, 0x5b, 0x3c, 0x3e, 0xfe,
		0xda, 0xf7, 0xc5, 0x4b, 0x51, 0x04, 0x8f, 0x22, 0xf8, 0xf1, 0x07, 0x05, 0xeb, 0x8a, 0xe5, 0xea,
		0x89, 0x51, 0x02, 0xaf, 0x46, 0x7a, 0xca, 0x24, 0xa8, 0x46, 0x8a, 0x7a, 0x00, 0xbf, 0x70, 0x09,
		0x3c, 0xb2, 0xf6, 0xf4, 0x90, 0xb3, 0x2a, 0x59, 0x93, 0x91, 0x37, 0x19, 0x99, 0xd3, 0x90, 0xbb,
		0x19, 0x07, 0x86, 0x7a, 0xd6, 0x9e, 0xb4, 0xdb, 0x53, 0x32, 0x17, 0x20, 0x2b, 0x0f, 0x81, 0x69,
		0xa3, 0x76, 0x11, 0x32, 0x2f, 0xfe, 0x49, 0x3c, 0xbb, 0x5a, 0xca, 0x70, 0x18, 0x7d, 0xfb, 0x38,
		0x79, 0x92, 0x85, 0xbf, 0x08, 0x65, 0x57, 0x73, 0x58, 0xbc, 0x1c, 0xc0, 0x4b, 0x48, 0x1e, 0xcb,
		0xc8, 0x61, 0x41, 0xf9, 0x0b, 0xd8, 0xb0, 0x09, 0xb0, 0x41, 0x58, 0x5e, 0x2a, 0x64, 0x37, 0xcb,
		0x64, 0x35, 0x2b, 0x65, 0x33, 0xd3, 0x30, 0xa6, 0x58, 0xd6, 0xb2, 0x54, 0xb6, 0xb2, 0x34, 0xa2,
		0xaf, 0x81, 0x35, 0x81, 0xe8, 0x81, 0xe8, 0x81, 0xe8, 0x81, 0xe8, 0x81, 0xe8, 0x73, 0x89, 0xe8,
		0x45, 0x63, 0xb7, 0xba, 0x00, 0xbd, 0x40, 0xec, 0x96, 0x10, 0x36, 0x8c, 0xa3, 0x9b, 0x32, 0xd8,
		0x61, 0x74, 0x2d, 0x5c, 0x82, 0x00, 0x10, 0xa6, 0x00, 0x44, 0x42, 0x76, 0x8a, 0x35, 0x7a, 0xd1,
		0x12, 0xe8, 0x8d, 0x09, 0x28, 0x51, 0x96, 0x3a, 0xbd, 0x51, 0xde, 0x6a, 0xa0, 0x5e, 0x3f, 0x33,
		0x5e, 0x48, 0xad, 0x7a, 0xa6, 0x8a, 0xea, 0x99, 0x0a, 0xaa, 0x67, 0x0a, 0x52, 0x3d, 0x23, 0xcb,
		0x74, 0xc9, 0x02, 0x92, 0xbd, 0x9a, 0x53, 0x09, 0x4f, 0xba, 0x83, 0x07, 0x21, 0x2b, 0x92, 0xb1,
		0x24, 0x25, 0x6b, 0x6a, 0x60, 0x51, 0x6a, 0x56, 0xd5, 0xc6, 0xb2, 0xda, 0x58, 0x57, 0x0f, 0x0b,
		0xab, 0xb1, 0xb2, 0x22, 0x4b, 0x93, 0xb1, 0x76, 0xb2, 0x50, 0x6c, 0x36, 0xfa, 0x2c, 0xe8, 0x77,
		0x43, 0x3a, 0x22, 0x99, 0xcb, 0xd9, 0x89, 0x97, 0x27, 0x3a, 0x4f, 0xda, 0x2a, 0x1c, 0x32, 0x41,
		0xa0, 0x43, 0x20, 0x68, 0x14, 0x0c, 0xba, 0x04, 0x84, 0x76, 0x41, 0xa1, 0x5d, 0x60, 0xe8, 0x15,
		0x1c, 0x34, 0x02, 0x84, 0x48, 0x90, 0xa8, 0xfb, 0xfa, 0xc4, 0x44, 0x80, 0x6a, 0x0d, 0x6e, 0x2a,
		0x18, 0x38, 0x24, 0x5c, 0x53, 0x6d, 0x8e, 0x25, 0xfd, 0x39, 0x67, 0xab, 0x6a, 0x88, 0x66, 0xd8,
		0x1b, 0xf4, 0x79, 0x46, 0xee, 0xbb, 0xc9, 0x8f, 0x7b, 0xb1, 0xe9, 0xb7, 0x47, 0x02, 0x3f, 0xb5,
		0x7b, 0x4a, 0xa3, 0xa7, 0x9f, 0xfc, 0xf8, 0xd0, 0x1c, 0x3d, 0xbd, 0x54, 0xd7, 0x39, 0x3a, 0x4a,
		0x52, 0xa0, 0x22, 0x2b, 0x60, 0xa1, 0x1d, 0x3a, 0x84, 0x76, 0xc4, 0x78, 0x41, 0x18, 0x12, 0x30,
		0x24, 0x60, 0x48, 0xe4, 0xc3, 0x90, 0x20, 0xf2, 0x15, 0xe8, 0xf1, 0x19, 0x10, 0xb3, 0x3c, 0x4c,
		0x07, 0x98, 0x0e, 0x30, 0x1d, 0xa8, 0x45, 0x48, 0xb2, 0xe0, 0x73, 0xaf, 0xa3, 0x81, 0xa6, 0xc6,
		0x6c, 0x10, 0xad, 0xbe, 0x5b, 0x88, 0xbe, 0x20, 0xd4, 0xe2, 0x45, 0xa7, 0x98, 0x31, 0x20, 0x6e,
		0x74, 0x8b, 0x1d, 0x63, 0xe2, 0xc7, 0x98, 0x18, 0x32, 0x23, 0x8e, 0x68, 0xc5, 0x12, 0xb1, 0x78,
		0xd2, 0xe7, 0xe1, 0x58, 0xa0, 0x78, 0xe6, 0xf5, 0x9f, 0x99, 0xef, 0x70, 0x94, 0x26, 0xe6, 0xc5,
		0xd5, 0xa1, 0xc9, 0xe5, 0x41, 0x4f, 0x10, 0xf9, 0xd2, 0x78, 0xc4, 0x2e, 0x91, 0x1c, 0xb8, 0x46,
		0x62, 0x8b, 0x7a, 0x8f, 0x14, 0x6d, 0x67, 0xe6, 0x2a, 0xb9, 0x61, 0xe1, 0xad, 0xf3, 0x44, 0xe2,
		0x31, 0x21, 0xf4, 0xe2, 0x11, 0x98, 0xe0, 0xae, 0xd7, 0x75, 0x3d, 0x46, 0x6f, 0x64, 0xc5, 0xeb,
		0xc2, 0xc8, 0x82, 0x91, 0x05, 0x23, 0x6b, 0x33, 0x8c, 0x2c, 0x62, 0x7f, 0x8d, 0x5e, 0xbf, 0x8d,
		0x26, 0xd1, 0x02, 0x43, 0x0b, 0x86, 0x16, 0x0c, 0x2d, 0x6a, 0x43, 0x8b, 0x5a, 0x54, 0x25, 0x0b,
		0x53, 0xc4, 0x90, 0xd6, 0x72, 0x93, 0x7a, 0x5c, 0xc9, 0xb0, 0x97, 0x48, 0xbb, 0x10, 0x33, 0x21,
		0xcc, 0x0c, 0x0a, 0x35, 0x53, 0xc2, 0xcd, 0xb8, 0x90, 0x33, 0x2e, 0xec, 0xcc, 0x0a, 0x3d, 0x3d,
		0xc2, 0x4f, 0x93, 0x10, 0xd4, 0xef, 0x75, 0x5a, 0x26, 0xb8, 0xa8, 0xb3, 0x6b, 0x52, 0xe1, 0xd7,
		0xb1, 0xc6, 0x7b, 0x90, 0x74, 0xc8, 0x5f, 0xf7, 0xa5, 0x97, 0xe5, 0x2b, 0x5a, 0x3a, 0xec, 0xf3,
		0x9e, 0xce, 0x91, 0x81, 0x5b, 0xd1, 0x76, 0xe8, 0xcf, 0xfe, 0xb4, 0x92, 0x17, 0xd3, 0xd1, 0xe1,
		0x3f, 0x63, 0x60, 0x90, 0x7a, 0x5b, 0x4d, 0x13, 0x02, 0xd6, 0xde, 0x57, 0x63, 0x37, 0xfa, 0x8c,
		0xc4, 0xfc, 0x72, 0x52, 0x72, 0xbe, 0x6f, 0x1c, 0x29, 0xe9, 0x9a, 0x60, 0x90, 0x6b, 0x9a, 0xda,
		0x2a, 0xc7, 0x5d, 0x5a, 0x5b, 0x05, 0xe6, 0x3c, 0x83, 0x0a, 0x9d, 0x74, 0x42, 0x03, 0x37, 0xe4,
		0x7a, 0x6f, 0xe0, 0x5e, 0xd4, 0x13, 0x1e, 0xd6, 0xde, 0xd0, 0xc8, 0x04, 0x88, 0x8c, 0xe9, 0x7e,
		0xab, 0x58, 0xcf, 0xad, 0xcb, 0x10, 0x22, 0x99, 0x50, 0xc1, 0x03, 0xdf, 0x68, 0x26, 0x58, 0xf0,
		0x68, 0x77, 0x6d, 0x13, 0x2e, 0xd6, 0xde, 0x9c, 0x64, 0x02, 0x86, 0x79, 0xca, 0xcd, 0xb7, 0xdf,
		0x52, 0x53, 0x54, 0x3f, 0x59, 0x3f, 0xfb, 0xe8, 0xfe, 0x28, 0xcc, 0xbb, 0xa7, 0x25, 0x34, 0x53,
		0xc9, 0x38, 0xd8, 0x7f, 0x16, 0xbd, 0x1b, 0x69, 0xcc, 0x9f, 0x9e, 0x6c, 0x07, 0xa4, 0x89, 0x15,
		0x32, 0x23, 0xbd, 0xb9, 0x51, 0x8e, 0xec, 0xe4, 0x17, 0x2e, 0x30, 0xa3, 0x2b, 0x7c, 0x57, 0x43,
		0xf8, 0x6e, 0xfa, 0x16, 0x08, 0xdf, 0x09, 0xeb, 0x00, 0x84, 0xef, 0x10, 0xbe, 0xcb, 0xc4, 0xb5,
		0x82, 0xf0, 0x5d, 0xbe, 0x84, 0x9b, 0x71, 0x21, 0x67, 0x5c, 0xd8, 0x99, 0x15, 0x7a, 0x7a, 0xed,
		0x61, 0x84, 0xef, 0x44, 0xe0, 0x17, 0xc2, 0x77, 0xfc, 0xe7, 0x82, 0xf0, 0x5d, 0x01, 0x4e, 0x6b,
		0xda, 0xff, 0x83, 0xf0, 0x9d, 0xe6, 0xfb, 0x22, 0x7c, 0x57, 0x5a, 0x52, 0x42, 0xf8, 0xae, 0xb8,
		0x77, 0x41, 0xf8, 0x8e, 0x4f, 0xa1, 0x23, 0x7c, 0x47, 0x76, 0x43, 0x84, 0xef, 0x72, 0xf7, 0xdc,
		0x08, 0xdf, 0x71, 0x6b, 0x77, 0x84, 0xef, 0x32, 0x5d, 0x11, 0xe1, 0x3b, 0xc9, 0xf0, 0x9d, 0x8e,
		0xc8, 0x4c, 0x25, 0x1f, 0xd1, 0x3b, 0x89, 0x31, 0xff, 0xe6, 0x88, 0x16, 0x35, 0xe8, 0x26, 0xc9,
		0xbc, 0x24, 0x35, 0xe8, 0x23, 0xc2, 0x2e, 0x53, 0x0d, 0xba, 0xcf, 0x1e, 0x99, 0xcf, 0xbc, 0xb6,
		0x86, 0x32, 0xf4, 0xc9, 0xd2, 0xa8, 0x44, 0x57, 0xde, 0x4c, 0x54, 0xa2, 0x4f, 0x6e, 0x80, 0x4a,
		0x74, 0x54, 0xa2, 0xa3, 0x12, 0x1d, 0xa9, 0x2c, 0xd9, 0x89, 0x20, 0x63, 0xa2, 0xc8, 0x8c, 0x48,
		0x2a, 0x86, 0x49, 0xa8, 0x33, 0x95, 0xc5, 0x0e, 0x58, 0x68, 0x24, 0x9d, 0x25, 0xba, 0x11, 0x52,
		0x5a, 0x4c, 0x0b, 0x35, 0x83, 0xc2, 0xcd, 0x94, 0x90, 0x33, 0x2e, 0xec, 0x8c, 0x0b, 0x3d, 0xb3,
		0xc2, 0x4f, 0x9f, 0xa7, 0xad, 0x52, 0x8a, 0x94, 0x16, 0xf1, 0x39, 0xe5, 0xd2, 0x28, 0x4c, 0x63,
		0xd2, 0xc4, 0xf4, 0x1c, 0xf4, 0xb4, 0xff, 0x45, 0x2e, 0x0e, 0xd6, 0x19, 0x8a, 0xea, 0x60, 0x2f,
		0x96, 0xd9, 0xc9, 0x0f, 0xe2, 0xd3, 0xd3, 0xb3, 0x27, 0x40, 0xb8, 0x7a, 0xb3, 0xf5, 0x81, 0x25,
		0x9e, 0x90, 0x72, 0x16, 0x6b, 0x5c, 0x8f, 0x5f, 0x0f, 0xf5, 0x1a, 0x54, 0xc2, 0x16, 0xf5, 0x1a,
		0x30, 0x72, 0x61, 0xe4, 0xc2, 0xc8, 0x85, 0x91, 0x0b, 0x23, 0x17, 0x46, 0x2e, 0x8c, 0x5c, 0x18,
		0xb9, 0x30, 0x72, 0x61, 0xe4, 0xc2, 0xc8, 0x2d, 0x84, 0x91, 0x5b, 0xc6, 0x94, 0xa6, 0x89, 0x8d,
		0x8b, 0xac, 0xa6, 0xac, 0x89, 0x3e, 0x4f, 0xc4, 0x5e, 0x92, 0xc4, 0xa6, 0x84, 0xbc, 0xcb, 0x94,
		0xdb, 0x44, 0xeb, 0xa3, 0xd1, 0xe2, 0x9b, 0xd1, 0x96, 0xd3, 0x54, 0x43, 0x4e, 0x53, 0x91, 0xcc,
		0x0f, 0xe4, 0x34, 0x61, 0x84, 0x61, 0xfe, 0xbd, 0x24, 0xc8, 0x67, 0xca, 0xc6, 0x0b, 0x02, 0x57,
		0x6f, 0x19, 0x4d, 0x42, 0x8c, 0x30, 0x5c, 0xb1, 0x36, 0x46, 0x18, 0xc2, 0xd0, 0x1a, 0x1a, 0x5a,
		0xd4, 0xbe, 0x84, 0x2c, 0x8d, 0x2c, 0x42, 0xcf, 0xc1, 0xa0, 0xe0, 0x83, 0xea, 0x89, 0x09, 0x36,
		0x7b, 0x42, 0xb5, 0x48, 0xec, 0xd5, 0xac, 0x48, 0x53, 0x8d, 0x28, 0xe5, 0x49, 0x49, 0x81, 0x8c,
		0x88, 0xac, 0x7b, 0x52, 0xab, 0x9e, 0xc8, 0x9a, 0x27, 0xb3, 0xe2, 0x29, 0x61, 0xb5, 0x06, 0x18,
		0x4d, 0x0d, 0x9b, 0xb5, 0xc1, 0x64, 0x6d, 0xb0, 0x58, 0x0f, 0x0c, 0xce, 0x56, 0xb4, 0x53, 0x59,
		0xdf, 0x56, 0x2c, 0x88, 0x7d, 0x16, 0xf4, 0xbb, 0x21, 0xbd, 0x1b, 0x6f, 0x76, 0x79, 0x5a, 0x77,
		0xde, 0x3e, 0x4a, 0x14, 0xe1, 0xce, 0x83, 0x3b, 0x6f, 0x2b, 0x9f, 0x76, 0xf2, 0x72, 0x11, 0x40,
		0xdd, 0xaf, 0x51, 0x87, 0x79, 0x4c, 0x6c, 0x16, 0xc3, 0x8a, 0xc8, 0x8d, 0x15, 0x41, 0x64, 0xe6,
		0x66, 0x63, 0x43, 0xa8, 0xdb, 0xb5, 0x0a, 0x26, 0xc4, 0x96, 0x41, 0xca, 0xa3, 0xa2, 0xb8, 0xec,
		0x28, 0xcd, 0x52, 0xb2, 0xb8, 0x8c, 0xd3, 0x96, 0x1c, 0x55, 0x89, 0xd3, 0x84, 0x04, 0x3d, 0x58,
		0xed, 0x9e, 0xd7, 0x19, 0xbd, 0x93, 0x34, 0x2d, 0x4c, 0x57, 0xb5, 0x8f, 0xd7, 0x92, 0xa4, 0x4c,
		0x35, 0xd3, 0x53, 0x19, 0x69, 0x52, 0x20, 0x4b, 0x42, 0x24, 0x49, 0x85, 0x1c, 0xc9, 0x91, 0x22,
		0x39, 0x32, 0xa4, 0x45, 0x82, 0x66, 0xa5, 0xa9, 0xaa, 0xa9, 0x48, 0xd5, 0x6c, 0x82, 0xb6, 0xb9,
		0x04, 0xb9, 0x17, 0x68, 0x1f, 0x5e, 0x20, 0x78, 0x81, 0x36, 0xd5, 0x0b, 0xd4, 0x76, 0xba, 0xdd,
		0x18, 0xfd, 0xd0, 0xfb, 0x80, 0xa6, 0x17, 0x87, 0x07, 0x08, 0x1e, 0x20, 0x78, 0x80, 0x36, 0xcc,
		0x03, 0x44, 0x5f, 0xef, 0xa1, 0xa3, 0xbe, 0x63, 0x75, 0x3d, 0x47, 0x7c, 0xf8, 0x27, 0x4b, 0x6c,
		0xc3, 0xd4, 0x7f, 0x4a, 0xfe, 0x85, 0xae, 0xc2, 0x23, 0x1f, 0x39, 0xbf, 0xae, 0x17, 0x84, 0x91,
		0x50, 0xf7, 0x7b, 0x61, 0xaf, 0xdd, 0xeb, 0xda, 0xec, 0xff, 0xe8, 0xd5, 0xc6, 0xb2, 0x9b, 0x40,
		0x7d, 0x40, 0x7d, 0x40, 0x7d, 0x6c, 0x98, 0xfa, 0x70, 0x3b, 0xcc, 0x0b, 0xdd, 0xf0, 0x55, 0x93,
		0x0a, 0x21, 0xec, 0x5a, 0x6e, 0x9d, 0xc5, 0x8f, 0xfa, 0x8b, 0x13, 0x68, 0xcc, 0x65, 0x3e, 0xbb,
		0xbc, 0xb9, 0x6d, 0x9e, 0x9f, 0x3f, 0x7c, 0xbe, 0xbe, 0xba, 0xbd, 0xfa, 0x70, 0x75, 0xfe, 0x70,
		0xfb, 0xc7, 0xe7, 0x53, 0x6a, 0xde, 0x88, 0xe6, 0x9b, 0x04, 0x5a, 0x06, 0x23, 0x68, 0xae, 0x8d,
		0xff, 0x78, 0x76, 0x7d, 0xfa, 0xe1, 0xf6, 0xfc, 0x8f, 0x87, 0x0f, 0x57, 0x97, 0x97, 0xa7, 0x1f,
		0x6e, 0x4f, 0x3f, 0x6a, 0x48, 0x7a, 0xdd, 0x2d, 0xda, 0xae, 0xfc, 0xf2, 0xe9, 0x33, 0xb6, 0xa1,
		0x62, 0x9d, 0x7d, 0xba, 0xc0, 0x3e, 0x9c, 0x54, 0xac, 0xcf, 0x67, 0x17, 0xd8, 0x86, 0x8a, 0x75,
		0x73, 0xdb, 0xbc, 0x3d, 0xfb, 0x80, 0x9d, 0xa8, 0x58, 0x57, 0x37, 0x9f, 0x7f, 0xc5, 0x3e, 0x8c,
		0xf6, 0xe1, 0x00, 0x1b, 0x51, 0xb1, 0xce, 0x6e, 0xce, 0x6e, 0xb0, 0x0f, 0x15, 0xeb, 0xfc, 0xea,
		0x43, 0xf3, 0xfc, 0xa1, 0xf9, 0xe9, 0xd3, 0xf5, 0xe9, 0xa7, 0xe6, 0xed, 0x69, 0xde, 0x0b, 0x68,
		0x5a, 0x79, 0xb3, 0x2f, 0x90, 0xfe, 0x32, 0xb3, 0x9e, 0xf9, 0xa4, 0x84, 0x49, 0xd8, 0x9b, 0xae,
		0x33, 0xa2, 0xd1, 0x34, 0x85, 0x0f, 0xc9, 0x0b, 0x90, 0xf4, 0x3e, 0xcc, 0x26, 0x93, 0xfe, 0xd9,
		0x09, 0xdb, 0x5f, 0x6d, 0xd7, 0x0b, 0x99, 0xff, 0xe8, 0xb4, 0x09, 0x73, 0xea, 0xe7, 0x17, 0x46,
		0x5c, 0xd5, 0xa0, 0x0f, 0x0c, 0x71, 0x55, 0xc4, 0x55, 0x57, 0x2c, 0x44, 0x3c, 0xa7, 0x43, 0xcf,
		0x7c, 0x0e, 0x8c, 0xfc, 0x81, 0x3b, 0xbc, 0x02, 0x77, 0x38, 0xa9, 0x7d, 0x42, 0xdf, 0x1e, 0x83,
		0x0e, 0x39, 0xa4, 0xf2, 0x02, 0x15, 0x86, 0x48, 0x13, 0x30, 0x68, 0x94, 0x31, 0x2b, 0x78, 0xdc,
		0x47, 0xb4, 0xc9, 0xc8, 0x50, 0x1c, 0xa5, 0x89, 0x25, 0xf7, 0x11, 0x4d, 0x32, 0xa8, 0xa9, 0x5d,
		0x5f, 0xcb, 0x4f, 0x9d, 0xad, 0x3e, 0x93, 0x94, 0x90, 0xbd, 0x88, 0x2c, 0x4e, 0x12, 0x01, 0x19,
		0xcc, 0xff, 0x21, 0xfe, 0x9d, 0xbe, 0x95, 0x67, 0x4e, 0x1b, 0xf3, 0xf7, 0xbf, 0x18, 0xd0, 0x47,
		0x33, 0x77, 0x81, 0x4a, 0x82, 0x4a, 0x82, 0x4a, 0x82, 0x4a, 0x82, 0x4a, 0xe2, 0x54, 0x49, 0x77,
		0x13, 0x95, 0xf4, 0xff, 0x6b, 0xf7, 0x7d, 0x9f, 0x79, 0xe1, 0xf6, 0xce, 0xde, 0xbb, 0x77, 0x7b,
		0xc9, 0x27, 0x5a, 0xf1, 0x25, 0xd3, 0x72, 0x36, 0x58, 0xf2, 0xb7, 0x64, 0xe5, 0x0e, 0xfb, 0x8e,
		0x9e, 0xbc, 0x5c, 0xec, 0x5b, 0x9a, 0x56, 0x51, 0x53, 0xc1, 0x83, 0x39, 0x47, 0x33, 0xfd, 0x98,
		0xa5, 0xac, 0x82, 0x0a, 0x17, 0xc3, 0x17, 0x3b, 0x1b, 0xbf, 0x17, 0xe9, 0x7c, 0x25, 0xf4, 0xe8,
		0xcd, 0xda, 0x09, 0x89, 0x1e, 0xbd, 0x70, 0x42, 0xc2, 0x09, 0x09, 0x27, 0x24, 0x2c, 0x3e, 0x58,
		0x7c, 0xb0, 0xf8, 0x60, 0xf1, 0xc1, 0x09, 0x09, 0x27, 0x24, 0x9c, 0x90, 0x50, 0x49, 0x50, 0x49,
		0x50, 0x49, 0x50, 0x49, 0x70, 0x42, 0xc2, 0x09, 0x59, 0x68, 0x27, 0x64, 0xa1, 0x5b, 0xd7, 0xa7,
		0xfb, 0x20, 0xd1, 0xc5, 0x5e, 0x17, 0x19, 0xe7, 0x8a, 0x7c, 0x0b, 0x9c, 0x89, 0x3f, 0x4b, 0xb0,
		0xc5, 0xcd, 0xc8, 0xf7, 0x98, 0xfb, 0xf4, 0xf5, 0x4b, 0xcf, 0x27, 0x99, 0xdb, 0x3d, 0x97, 0x94,
		0x3f, 0xb3, 0x36, 0xf2, 0xf2, 0x79, 0xb0, 0x3f, 0xf2, 0xf2, 0x91, 0x97, 0x9f, 0xfa, 0x4a, 0xc8,
		0xcb, 0xcf, 0x93, 0x5b, 0x00, 0x21, 0x31, 0x33, 0x86, 0x3f, 0x42, 0x62, 0xb9, 0x1e, 0x5b, 0x19,
		0x69, 0xfa, 0x80, 0x85, 0x76, 0xef, 0x45, 0xad, 0x4f, 0x31, 0x27, 0xa8, 0x98, 0xbe, 0x15, 0xfc,
		0x91, 0x18, 0x68, 0xb9, 0xc1, 0x1e, 0x49, 0x0c, 0xb4, 0x34, 0x22, 0x66, 0x6c, 0x9f, 0x05, 0xa1,
		0xef, 0xb6, 0x43, 0xd6, 0xa1, 0x9e, 0xdf, 0xb1, 0x80, 0x75, 0xb4, 0x8e, 0xb9, 0xd4, 0xb0, 0xf6,
		0x47, 0xf6, 0xe8, 0x8c, 0x26, 0x27, 0x59, 0xcd, 0xcb, 0x3f, 0x36, 0x21, 0xec, 0x46, 0x6a, 0x30,
		0xa7, 0x12, 0x21, 0xa1, 0xe9, 0x0c, 0x35, 0x07, 0x35, 0x07, 0x35, 0x07, 0x35, 0x37, 0x47, 0xf1,
		0x05, 0x0f, 0xbd, 0x2d, 0xed, 0x52, 0xfc, 0xee, 0xdd, 0x5e, 0xe4, 0x8c, 0x66, 0x9d, 0xa1, 0xdc,
		0x0c, 0xf6, 0xa6, 0xa5, 0xe8, 0xec, 0x6f, 0x7b, 0xb9, 0xce, 0x12, 0x41, 0x1c, 0xcd, 0x4c, 0x20,
		0x62, 0x86, 0x22, 0xca, 0x95, 0xcf, 0x7f, 0x19, 0xbf, 0xda, 0x0d, 0x0b, 0x91, 0xd1, 0xcf, 0x2b,
		0x13, 0x91, 0xd1, 0x0f, 0xf7, 0x25, 0xdc, 0x97, 0x70, 0x5f, 0xc2, 0x7d, 0x09, 0xbb, 0x0e, 0x76,
		0x1d, 0xec, 0x3a, 0xb8, 0x2f, 0xe1, 0xbe, 0x84, 0xfb, 0x12, 0xee, 0x4b, 0xa8, 0x39, 0xa8, 0x39,
		0xa8, 0x39, 0xb8, 0x2f, 0xe1, 0xbe, 0x84, 0xfb, 0x32, 0xaf, 0xee, 0xcb, 0x52, 0x55, 0x02, 0x4c,
		0x7b, 0x2f, 0x51, 0x0b, 0xa0, 0x8b, 0x96, 0xf3, 0x46, 0xc3, 0x45, 0x2f, 0x07, 0x98, 0xa2, 0xda,
		0xe2, 0x16, 0x04, 0x8c, 0x40, 0x98, 0x8e, 0x72, 0x80, 0xa9, 0x95, 0x51, 0x0c, 0x60, 0x10, 0xd2,
		0xa3, 0x18, 0x00, 0xc5, 0x00, 0x2b, 0x16, 0x42, 0x31, 0x40, 0x4e, 0xad, 0x7c, 0x44, 0xd3, 0x32,
		0xb0, 0xe2, 0x11, 0x4d, 0x53, 0x58, 0x10, 0xd1, 0x34, 0xb8, 0x19, 0xe1, 0x66, 0x84, 0x9b, 0xb1,
		0x3c, 0x6e, 0x46, 0x44, 0xd3, 0x44, 0xf4, 0xc9, 0xc6, 0x45, 0xd3, 0x08, 0x8d, 0xe5, 0x54, 0x12,
		0x24, 0x33, 0x9b, 0xa1, 0xe2, 0xa0, 0xe2, 0xa0, 0xe2, 0xa0, 0xe2, 0xe6, 0x28, 0x7e, 0x13, 0x22,
		0x69, 0x13, 0x19, 0x3a, 0xfd, 0x73, 0x9c, 0xf2, 0x8d, 0x60, 0x1a, 0x3f, 0x43, 0x96, 0x37, 0x98,
		0xb6, 0x40, 0x16, 0x65, 0x89, 0xa5, 0x8d, 0xb4, 0x26, 0xea, 0x00, 0x04, 0x44, 0x22, 0xea, 0x00,
		0xe0, 0xb9, 0x84, 0xe7, 0x12, 0x9e, 0x4b, 0x78, 0x2e, 0x61, 0xd6, 0xc1, 0xac, 0x83, 0x59, 0x07,
		0xcf, 0x25, 0x3c, 0x97, 0xf0, 0x5c, 0xc2, 0x73, 0x09, 0x15, 0x07, 0x15, 0x07, 0x15, 0x07, 0xcf,
		0x25, 0x3c, 0x97, 0xf0, 0x5c, 0xe6, 0xd2, 0x73, 0x59, 0xaa, 0x22, 0x80, 0x89, 0xe3, 0x12, 0x25,
		0x00, 0xba, 0xe8, 0x38, 0x5f, 0xf4, 0x5b, 0xf4, 0x02, 0x80, 0x84, 0x62, 0x8b, 0x9b, 0xfe, 0x1f,
		0x3a, 0x4f, 0x3a, 0x72, 0xff, 0xc7, 0xcb, 0x22, 0xf1, 0xdf, 0x20, 0x8e, 0x47, 0xe2, 0x3f, 0x12,
		0xff, 0x57, 0x2c, 0x84, 0xc4, 0xff, 0x9c, 0x9a, 0xf6, 0x08, 0x9f, 0x65, 0x60, 0xba, 0x23, 0x7c,
		0xa6, 0xb0, 0x20, 0xc2, 0x67, 0xf0, 0x2d, 0xc2, 0xb7, 0x08, 0xdf, 0x62, 0x79, 0x7c, 0x8b, 0x08,
		0x9f, 0x89, 0xe8, 0x93, 0x8d, 0x0b, 0x9f, 0x51, 0x99, 0xc9, 0xa9, 0xf4, 0x47, 0x63, 0x30, 0x43,
		0xb9, 0x41, 0xb9, 0x41, 0xb9, 0x41, 0xb9, 0xcd, 0x51, 0xfc, 0x26, 0x04, 0xce, 0x62, 0x01, 0x9a,
		0xfc, 0x80, 0x58, 0x19, 0x3f, 0x0f, 0x96, 0x37, 0x56, 0x36, 0x26, 0x86, 0x72, 0xa5, 0xf8, 0xdf,
		0x3a, 0x4f, 0xc8, 0xef, 0x17, 0x90, 0x7f, 0xc8, 0xef, 0x87, 0x83, 0x12, 0x0e, 0x4a, 0x38, 0x28,
		0xe1, 0xa0, 0x84, 0x0d, 0x07, 0x1b, 0x0e, 0x36, 0x1c, 0x1c, 0x94, 0x70, 0x50, 0xc2, 0x41, 0x09,
		0x07, 0x25, 0x94, 0x1b, 0x94, 0x1b, 0x94, 0x1b, 0x1c, 0x94, 0x70, 0x50, 0xc2, 0x41, 0x99, 0xb1,
		0x83, 0xb2, 0x54, 0x99, 0xfc, 0xb1, 0x7f, 0x12, 0x69, 0xfc, 0xba, 0x28, 0x38, 0x47, 0x94, 0x5b,
		0xf4, 0x1c, 0xfe, 0x11, 0xad, 0x16, 0x31, 0x81, 0x9f, 0xc6, 0x59, 0x4e, 0xea, 0x24, 0x27, 0x4f,
		0xd8, 0xaf, 0x21, 0x61, 0x3f, 0x0f, 0xf0, 0x1b, 0x09, 0xfb, 0x22, 0xce, 0x07, 0xb2, 0x84, 0x7d,
		0xa7, 0xdb, 0x8d, 0x05, 0xb7, 0x86, 0xac, 0xfd, 0xa9, 0xc5, 0x69, 0x23, 0x63, 0xfb, 0x48, 0xdd,
		0xcf, 0xb3, 0xad, 0x8e, 0xc8, 0x58, 0x91, 0x4c, 0x1f, 0x72, 0xdb, 0x5b, 0xa3, 0xcd, 0xad, 0xc3,
		0xd6, 0x5e, 0x6d, 0x63, 0xc7, 0x87, 0x7f, 0xb2, 0x04, 0xd6, 0xa6, 0xfe, 0x53, 0xf2, 0x2f, 0x74,
		0xf6, 0x77, 0x3e, 0x92, 0x27, 0x5c, 0x2f, 0x08, 0x23, 0xa1, 0xee, 0xf7, 0xc2, 0x5e, 0xbb, 0xd7,
		0xb5, 0xd9, 0xff, 0xd1, 0xab, 0x8d, 0x65, 0x37, 0x81, 0xfa, 0x80, 0xfa, 0x80, 0xfa, 0xd8, 0x30,
		0xf5, 0xe1, 0x76, 0x98, 0x17, 0xba, 0xe1, 0xab, 0x26, 0x15, 0x52, 0x27, 0x5c, 0xf3, 0x2c, 0x7e,
		0xd4, 0x5f, 0x9c, 0x80, 0xe9, 0x0b, 0x90, 0x9d, 0x5d, 0xde, 0xdc, 0x36, 0xcf, 0xcf, 0x1f, 0x3e,
		0x5f, 0x5f, 0xdd, 0x5e, 0x7d, 0xb8, 0x3a, 0x7f, 0xb8, 0xfd, 0xe3, 0xf3, 0x29, 0x35, 0x6f, 0xfc,
		0xee, 0x74, 0xfb, 0x2c, 0xb0, 0x4e, 0x2a, 0x77, 0xe4, 0xde, 0x6c, 0x4d, 0x11, 0xa1, 0xf1, 0xf6,
		0x7c, 0x3c, 0xbb, 0x3e, 0xfd, 0x70, 0x7b, 0xfe, 0xc7, 0xc3, 0x87, 0xab, 0xcb, 0xcb, 0xd3, 0x0f,
		0xb7, 0xa7, 0x1f, 0x35, 0x84, 0x51, 0x76, 0x8b, 0xb6, 0x2b, 0xbf, 0x7c, 0xfa, 0x8c, 0x6d, 0xa8,
		0x58, 0x67, 0x9f, 0x2e, 0xb0, 0x0f, 0x27, 0x15, 0xeb, 0xf3, 0xd9, 0x05, 0xb6, 0xa1, 0x62, 0xdd,
		0xdc, 0x36, 0x6f, 0xcf, 0x3e, 0x60, 0x27, 0x2a, 0xd6, 0xd5, 0xcd, 0xe7, 0x5f, 0xb1, 0x0f, 0xa3,
		0x7d, 0x38, 0xc0, 0x46, 0x54, 0xac, 0xb3, 0x9b, 0xb3, 0x1b, 0xec, 0x43, 0xc5, 0x3a, 0xbf, 0xfa,
		0xd0, 0x3c, 0x7f, 0x68, 0x7e, 0xfa, 0x74, 0x7d, 0xfa, 0xa9, 0x79, 0x7b, 0x9a, 0xf7, 0x94, 0x8c,
		0x56, 0xde, 0xec, 0x0b, 0xc4, 0x53, 0x67, 0xd6, 0xcb, 0x34, 0x9e, 0x4a, 0x15, 0xfb, 0xcf, 0x2a,
		0x8e, 0x4a, 0x10, 0xe7, 0x57, 0x88, 0xa0, 0x6e, 0x19, 0xa4, 0x3f, 0x2a, 0xba, 0xcb, 0x94, 0xde,
		0x2c, 0xa5, 0x98, 0x73, 0x16, 0x14, 0x26, 0x47, 0x5b, 0xe2, 0x94, 0x21, 0x41, 0x15, 0xaa, 0x5d,
		0xb5, 0x68, 0xba, 0x68, 0x29, 0xc6, 0xdd, 0x95, 0x7d, 0xa5, 0x14, 0xbe, 0x51, 0x42, 0x5f, 0x28,
		0x95, 0xef, 0x93, 0xdc, 0xd7, 0x49, 0xee, 0xdb, 0xa4, 0xf5, 0x65, 0x9a, 0x95, 0xa5, 0xaa, 0x71,
		0x72, 0x2b, 0x16, 0x43, 0x44, 0xf9, 0x2f, 0xd1, 0x6a, 0x34, 0xe9, 0x2f, 0xfb, 0xe8, 0x57, 0x69,
		0x92, 0x4d, 0xb5, 0xb1, 0xab, 0x36, 0xb6, 0xd5, 0xc3, 0xbe, 0xf9, 0x80, 0xe6, 0x64, 0x21, 0x87,
		0xa9, 0xcc, 0x34, 0xdf, 0xf5, 0x28, 0x8a, 0xf7, 0x13, 0x35, 0xf9, 0x1e, 0x60, 0x35, 0xef, 0x60,
		0x55, 0xad, 0x5d, 0x83, 0x69, 0xa0, 0x2a, 0xdd, 0x87, 0xc1, 0x0c, 0x48, 0x55, 0xd2, 0x94, 0x14,
		0x1a, 0x52, 0x51, 0x33, 0x02, 0xa0, 0x02, 0xa0, 0x9a, 0x97, 0x9f, 0xca, 0x9a, 0x8c, 0x30, 0xd7,
		0x8a, 0x22, 0xb7, 0x6a, 0x3a, 0x97, 0x4a, 0x79, 0xa0, 0x88, 0x19, 0xc1, 0xa5, 0x96, 0xe3, 0x4e,
		0x92, 0xdb, 0x4e, 0x66, 0x5b, 0xd7, 0x20, 0xba, 0x20, 0xba, 0x60, 0x5b, 0xc3, 0xb6, 0x86, 0x6d,
		0x0d, 0xdb, 0x1a, 0xb6, 0x35, 0x6c, 0xeb, 0x6c, 0x6c, 0x6b, 0xd5, 0x68, 0xa3, 0x51, 0xd3, 0x5a,
		0x21, 0xb4, 0x28, 0x01, 0x50, 0xb7, 0x34, 0x52, 0xce, 0x50, 0x80, 0x4a, 0xaa, 0x42, 0xeb, 0xdc,
		0x0d, 0xc2, 0x66, 0x18, 0xca, 0xa9, 0x74, 0xeb, 0xc2, 0xf5, 0x4e, 0xbb, 0xa3, 0x9d, 0x95, 0x53,
		0x7b, 0xd6, 0x85, 0xf3, 0x7d, 0x6a, 0x85, 0xea, 0xfb, 0xc3, 0xc3, 0xc6, 0xd1, 0xe1, 0xe1, 0xfe,
		0xd1, 0xc1, 0xd1, 0xfe, 0x71, 0xbd, 0x5e, 0x6d, 0xc8, 0x64, 0xeb, 0x5a, 0x57, 0x7e, 0x87, 0xf9,
		0xac, 0xf3, 0xcb, 0xab, 0x3a, 0xbc, 0xef, 0x07, 0xcc, 0x97, 0x45, 0xf7, 0x04, 0x7a, 0x72, 0x5a,
		0x37, 0xf6, 0x46, 0x6f, 0x65, 0x7f, 0x51, 0xa9, 0xaa, 0x23, 0xd5, 0x89, 0x33, 0x7a, 0x30, 0xda,
		0xa9, 0x52, 0xb0, 0x93, 0xa2, 0x00, 0x36, 0x2f, 0x78, 0x2d, 0x29, 0xf3, 0xd7, 0x98, 0xa8, 0x15,
		0xa3, 0x0a, 0xfe, 0xb3, 0xe5, 0xfb, 0x24, 0xe7, 0xe9, 0xcb, 0x9e, 0xba, 0xa9, 0xd3, 0x16, 0x38,
		0x63, 0xfd, 0x67, 0xcb, 0x77, 0xa2, 0xeb, 0xcf, 0x67, 0xf5, 0x27, 0xd6, 0x9c, 0x9c, 0x80, 0xda,
		0x13, 0x53, 0x73, 0xe2, 0x6a, 0x8d, 0x44, 0x8d, 0xcd, 0xa8, 0x2d, 0xaf, 0xdf, 0xed, 0x2a, 0x6d,
		0x8e, 0x20, 0x39, 0x6b, 0x25, 0x63, 0x0e, 0xda, 0xd5, 0x44, 0xb3, 0xab, 0x09, 0x35, 0x9d, 0xfc,
		0x96, 0xff, 0x4b, 0xca, 0x9e, 0xf3, 0xee, 0x35, 0xe1, 0x1e, 0xaf, 0xd8, 0x51, 0x9a, 0x9d, 0x5c,
		0xbe, 0x71, 0x8b, 0xdb, 0x32, 0xfb, 0x97, 0xb9, 0x0d, 0x5a, 0xb7, 0x31, 0xb2, 0x1b, 0xb2, 0xe4,
		0xed, 0x65, 0xde, 0x7a, 0xf6, 0x1d, 0x27, 0x6f, 0x32, 0xf5, 0x16, 0x56, 0xf0, 0x1a, 0x84, 0xec,
		0x79, 0xe1, 0xe9, 0x27, 0x46, 0xee, 0xe8, 0xdf, 0xe7, 0xde, 0x7b, 0xb9, 0x5f, 0x37, 0xd5, 0x41,
		0xb4, 0xca, 0xe1, 0x33, 0xed, 0xc0, 0x09, 0x5e, 0x97, 0x1d, 0xfc, 0x3a, 0x9c, 0xc9, 0xed, 0x5f,
		0xe1, 0xc6, 0x86, 0xf3, 0xfe, 0x8f, 0xe1, 0x73, 0x09, 0x52, 0x46, 0x9a, 0x17, 0xd1, 0x72, 0x1c,
		0x27, 0xfd, 0x4d, 0xc6, 0x7b, 0x31, 0xfc, 0x50, 0xca, 0xa3, 0xad, 0x76, 0xa9, 0xaf, 0xf5, 0xd1,
		0xf1, 0xf8, 0xde, 0xa6, 0x8f, 0x24, 0xfd, 0x49, 0x44, 0x4c, 0x00, 0x61, 0x17, 0x98, 0x30, 0x8c,
		0x9f, 0x3f, 0xb2, 0xe1, 0x73, 0x13, 0x49, 0xbf, 0x75, 0x0e, 0x61, 0xcb, 0x69, 0xb7, 0x7b, 0x7d,
		0x6f, 0xc8, 0x77, 0xeb, 0x37, 0x22, 0x39, 0xe1, 0xc9, 0x35, 0xeb, 0x50, 0x00, 0x57, 0x0c, 0x85,
		0xdb, 0x39, 0x2b, 0xe2, 0x7c, 0xe5, 0x27, 0x04, 0x59, 0x9b, 0x50, 0xda, 0x37, 0x2a, 0x6d, 0xe7,
		0x09, 0x11, 0x0a, 0x0d, 0x8e, 0xe3, 0x8d, 0x28, 0x88, 0x26, 0xc4, 0xca, 0x25, 0xc0, 0x0a, 0x06,
		0xe5, 0x84, 0xbd, 0xfe, 0x32, 0xde, 0x7d, 0x71, 0x42, 0x53, 0x75, 0x42, 0x28, 0x3b, 0xe5, 0x95,
		0x1d, 0x0d, 0x52, 0x84, 0xa8, 0xc7, 0x34, 0x14, 0x0d, 0x79, 0x4d, 0x49, 0x2f, 0xfb, 0x99, 0x85,
		0x5f, 0x7b, 0x1d, 0xf1, 0xfd, 0x5f, 0x14, 0x84, 0xe3, 0xa5, 0x44, 0x9d, 0x83, 0x52, 0xc1, 0x2d,
		0xe9, 0x60, 0x96, 0x4a, 0xf0, 0x4a, 0x9e, 0xcc, 0xa9, 0x7c, 0x6e, 0x64, 0xb1, 0x28, 0x32, 0x3f,
		0x9b, 0x12, 0x1b, 0x98, 0xf1, 0x97, 0x49, 0x87, 0x8e, 0x26, 0x5e, 0x56, 0x8f, 0xcf, 0x4a, 0x4c,
		0x95, 0xd5, 0xc7, 0x12, 0xd7, 0xc6, 0x8f, 0x2d, 0xd7, 0xee, 0x80, 0x20, 0x61, 0x82, 0xa6, 0xcd,
		0x05, 0x45, 0x5b, 0x0b, 0xda, 0x36, 0x16, 0xc9, 0x0b, 0x36, 0x9b, 0xcd, 0x87, 0x8b, 0xd3, 0xdb,
		0x7f, 0x5e, 0x7d, 0xa4, 0x68, 0x58, 0x41, 0xd9, 0xa0, 0x82, 0xb8, 0x73, 0xd1, 0x6d, 0xf3, 0x43,
		0xf3, 0xc3, 0xcd, 0x43, 0xf3, 0xfc, 0xdc, 0xca, 0x43, 0xbb, 0x26, 0xe2, 0xb7, 0x8b, 0xea, 0x61,
		0xcb, 0xf8, 0x62, 0xd7, 0xcd, 0x8f, 0x67, 0xbf, 0x51, 0x1d, 0x9b, 0xd2, 0x0a, 0xad, 0x62, 0x84,
		0xa6, 0x09, 0x84, 0x9e, 0x72, 0x52, 0x80, 0x62, 0x32, 0x80, 0xf8, 0x7e, 0xb5, 0xb4, 0xea, 0x4e,
		0xc4, 0x5f, 0xd7, 0x20, 0x03, 0xc4, 0x5f, 0x39, 0xb1, 0x61, 0x8e, 0xe3, 0xaf, 0xa5, 0x89, 0xe8,
		0x8d, 0xbc, 0xbd, 0x7b, 0xf1, 0x37, 0xc7, 0x71, 0xf6, 0x26, 0xe6, 0x99, 0x78, 0x65, 0x49, 0xaa,
		0xcf, 0xfa, 0x26, 0x5a, 0xff, 0x21, 0xfe, 0xd6, 0x74, 0x9c, 0x87, 0x66, 0x72, 0x1b, 0xa1, 0x92,
		0x10, 0x8e, 0x08, 0x1c, 0x87, 0xcf, 0x8a, 0x7d, 0x8b, 0xc5, 0x83, 0xa0, 0xdb, 0x25, 0xbe, 0x0e,
		0x6e, 0x17, 0xb8, 0x5d, 0xcc, 0xb8, 0x5d, 0x22, 0x82, 0x93, 0x77, 0xb5, 0x8c, 0x2e, 0x97, 0x73,
		0xaf, 0x54, 0xe1, 0x5e, 0x81, 0x7b, 0x45, 0x0f, 0x44, 0x94, 0x4d, 0xb8, 0x47, 0xff, 0x88, 0x8a,
		0x86, 0x1a, 0x17, 0x39, 0xc6, 0xa1, 0xc4, 0xa4, 0x95, 0x42, 0x96, 0xb8, 0x48, 0x31, 0x56, 0x26,
		0x56, 0xae, 0x7a, 0x85, 0x4b, 0xa4, 0x48, 0x46, 0x93, 0x33, 0xc9, 0x9c, 0x69, 0x53, 0x6b, 0xa2,
		0xda, 0x45, 0x3f, 0xa3, 0x52, 0x33, 0xac, 0x36, 0xc6, 0xd5, 0xc6, 0xc0, 0x5a, 0x18, 0x99, 0xc6,
		0x5d, 0x96, 0xbf, 0x5a, 0x17, 0xda, 0x96, 0xd5, 0x94, 0xad, 0xaa, 0xf5, 0xb4, 0xa8, 0x9e, 0xf1,
		0xf1, 0x37, 0x3f, 0x7c, 0xb8, 0xfa, 0xed, 0xf2, 0xf6, 0xec, 0xf2, 0xd3, 0xc3, 0xe9, 0xef, 0xa7,
		0x97, 0xb7, 0x94, 0xed, 0xa9, 0x75, 0xb4, 0xa5, 0xd6, 0xd4, 0xa5, 0x7b, 0xe9, 0x56, 0x9c, 0x5f,
		0x7d, 0x3a, 0xbb, 0xb4, 0xf2, 0x38, 0xd7, 0xd7, 0xe4, 0x2e, 0x7c, 0xb8, 0xba, 0xb8, 0x68, 0x5e,
		0x7e, 0xcc, 0x5b, 0x2b, 0xfc, 0x56, 0xd6, 0x72, 0x2c, 0x93, 0xe1, 0x6e, 0x3e, 0x6b, 0x8f, 0x14,
		0x10, 0x11, 0x32, 0x89, 0xd7, 0x03, 0x2a, 0x01, 0x2a, 0x01, 0x2a, 0xc9, 0x15, 0x2a, 0x61, 0x5e,
		0xff, 0x99, 0xf9, 0x4e, 0x28, 0x97, 0x5c, 0x91, 0x8a, 0x4a, 0x08, 0x46, 0xf6, 0x4f, 0x46, 0xf4,
		0xa3, 0xa4, 0x57, 0x60, 0x1d, 0xc9, 0xc8, 0xc4, 0xc8, 0x11, 0x3f, 0xfa, 0xa6, 0xb1, 0x01, 0xd6,
		0xca, 0xb0, 0xc5, 0x69, 0xf4, 0x0c, 0xa3, 0x6f, 0x05, 0x68, 0x6b, 0x45, 0x60, 0xc2, 0xd3, 0x99,
		0xee, 0x65, 0x6b, 0x71, 0x05, 0x1f, 0x5a, 0xe9, 0x7d, 0x68, 0x1b, 0xd0, 0xe0, 0x6a, 0x8a, 0xad,
		0xd1, 0xe6, 0x8a, 0x6b, 0xff, 0x4b, 0xd2, 0xe6, 0x0a, 0xe2, 0xab, 0xf4, 0xe2, 0x0b, 0x21, 0x00,
		0x18, 0xdb, 0x30, 0xb6, 0x61, 0x6c, 0x0b, 0xd0, 0x1b, 0x42, 0x00, 0x08, 0x01, 0x20, 0x04, 0x80,
		0x10, 0x80, 0x31, 0x0f, 0x16, 0x42, 0x00, 0x40, 0x25, 0x40, 0x25, 0x40, 0x25, 0xab, 0x6d, 0x06,
		0x84, 0x00, 0xf2, 0x61, 0x51, 0xe6, 0x29, 0x04, 0xa0, 0xad, 0x4f, 0x27, 0x7f, 0x04, 0xa0, 0x7c,
		0xdd, 0x37, 0xa5, 0xad, 0xf3, 0xf2, 0xd7, 0x80, 0xad, 0x6d, 0x66, 0xa6, 0x7a, 0x04, 0xfa, 0x3a,
		0x36, 0x72, 0x33, 0x15, 0x65, 0x0f, 0x46, 0x6e, 0x36, 0xb2, 0x50, 0x87, 0x95, 0x76, 0x2a, 0xda,
		0xeb, 0xb0, 0x46, 0xe7, 0x60, 0xb2, 0x0e, 0x4b, 0xcc, 0x95, 0x2f, 0xe5, 0xba, 0x97, 0xae, 0xc2,
		0xaa, 0xa1, 0x0a, 0x8b, 0x12, 0xf3, 0xa2, 0xf9, 0x0d, 0x9a, 0xdf, 0xa0, 0x3a, 0x0b, 0xcd, 0x6f,
		0xb8, 0x64, 0x35, 0x9a, 0xdf, 0xa0, 0xf9, 0x8d, 0x71, 0xaf, 0x2f, 0x9a, 0xdf, 0x14, 0xfb, 0xc5,
		0xd0, 0xfc, 0xc6, 0xbc, 0xd0, 0x43, 0xf3, 0x9b, 0x0d, 0x73, 0x7c, 0xa0, 0xf9, 0x8d, 0x1e, 0x5c,
		0x58, 0x41, 0xf3, 0x9b, 0x9c, 0x39, 0x5d, 0x44, 0x5d, 0xca, 0x72, 0x3e, 0x17, 0x01, 0xaf, 0xb1,
		0xee, 0xe1, 0x13, 0x74, 0xf3, 0x15, 0x56, 0xed, 0xab, 0xca, 0xe4, 0x84, 0x55, 0x3b, 0x29, 0x3d,
		0x17, 0x61, 0x45, 0xaf, 0x73, 0xa7, 0x1f, 0x7e, 0x1d, 0x22, 0xe9, 0x36, 0xdf, 0xae, 0x4c, 0x8c,
		0xfc, 0xd9, 0xeb, 0xd0, 0xee, 0x1b, 0xed, 0xbe, 0x63, 0x82, 0xea, 0x3c, 0xbb, 0x9e, 0x1d, 0x89,
		0x76, 0x61, 0xa7, 0xe7, 0xd4, 0xb5, 0xe8, 0x3f, 0x05, 0xcf, 0xa7, 0x19, 0xcf, 0xa7, 0x64, 0xc3,
		0x1d, 0xb5, 0x46, 0x3b, 0xe8, 0x40, 0x05, 0x1f, 0x67, 0x5e, 0x3b, 0x50, 0x8d, 0xa4, 0xf0, 0x8b,
		0x13, 0x04, 0xff, 0x55, 0xc9, 0x37, 0x9b, 0x93, 0xea, 0xc9, 0x7a, 0xa8, 0xa6, 0x43, 0x39, 0x8a,
		0x61, 0x46, 0xcb, 0xc4, 0xf5, 0x44, 0x58, 0x4d, 0x97, 0xb9, 0x0b, 0x4a, 0x72, 0x07, 0x4e, 0xbf,
		0x87, 0x6a, 0xde, 0x6f, 0x3a, 0xea, 0xee, 0xb5, 0x6d, 0xf6, 0x3d, 0x3c, 0x99, 0xb2, 0xe0, 0xbe,
		0x3a, 0xc1, 0x57, 0xd6, 0xb1, 0xbf, 0x39, 0xdd, 0x3e, 0xa3, 0xa5, 0xfa, 0x47, 0xa7, 0x1b, 0x50,
		0x92, 0xbd, 0x69, 0x82, 0x6f, 0x19, 0xa9, 0x71, 0x9c, 0x55, 0x0b, 0xf1, 0x71, 0x50, 0x6b, 0x9b,
		0xf1, 0xb2, 0x50, 0x3a, 0x50, 0x3a, 0x50, 0x3a, 0x62, 0x76, 0x8d, 0xff, 0xfa, 0x12, 0x4e, 0x18,
		0x49, 0xb1, 0x82, 0xd1, 0x78, 0x10, 0x64, 0x50, 0x9e, 0xdc, 0xc5, 0x19, 0x57, 0xdb, 0xde, 0xc4,
		0x49, 0x22, 0xdf, 0x15, 0x44, 0xc4, 0xfd, 0x38, 0x73, 0xf7, 0x87, 0xe6, 0xf0, 0xee, 0xbf, 0x05,
		0xcc, 0x97, 0x6a, 0x07, 0x22, 0xe0, 0x57, 0x17, 0xf2, 0x4a, 0xcb, 0x54, 0xcb, 0x2b, 0x55, 0xc9,
		0x2b, 0xdb, 0xef, 0x35, 0xd8, 0xef, 0xb0, 0xdf, 0x61, 0xbf, 0x03, 0x4a, 0x01, 0x4a, 0xc1, 0x7e,
		0x87, 0xfd, 0x0e, 0xfb, 0x1d, 0xf6, 0x3b, 0xec, 0x77, 0x28, 0x1d, 0x28, 0x1d, 0xd8, 0xef, 0xaa,
		0x22, 0x69, 0x68, 0x1a, 0xc7, 0x96, 0x2d, 0x89, 0x2c, 0x4a, 0xd6, 0x83, 0x10, 0x82, 0x10, 0x82,
		0x10, 0x2a, 0x16, 0xf2, 0x85, 0xdf, 0x70, 0x89, 0xdf, 0x50, 0xb6, 0x95, 0x00, 0x85, 0xdb, 0x50,
		0xa2, 0x87, 0x40, 0xa9, 0xb3, 0x71, 0xd3, 0x0e, 0x49, 0x53, 0x5a, 0x6e, 0xca, 0xb1, 0x98, 0xac,
		0x88, 0x16, 0x4c, 0xb8, 0x92, 0x4b, 0xb4, 0x42, 0x66, 0x60, 0x05, 0x99, 0x81, 0x6a, 0x0e, 0xd5,
		0xb9, 0x1c, 0x67, 0xf5, 0xba, 0xe8, 0xa5, 0xcb, 0xa1, 0x36, 0x5a, 0x1f, 0x58, 0x44, 0xdc, 0x01,
		0xb5, 0xd1, 0x9a, 0xfd, 0x94, 0xa8, 0x8d, 0x96, 0x5c, 0x16, 0xb5, 0xd1, 0xd9, 0xbc, 0x1d, 0x6a,
		0xa3, 0xb5, 0x99, 0xdb, 0xe3, 0x2f, 0xd4, 0x46, 0xe7, 0xd7, 0xbc, 0x47, 0x6d, 0xb4, 0xf0, 0xa2,
		0xa8, 0x8d, 0x36, 0xe3, 0x34, 0x44, 0x6d, 0x74, 0xde, 0xbc, 0x31, 0xc2, 0xf9, 0x75, 0xf2, 0x9e,
		0x18, 0x91, 0x6c, 0x3a, 0x34, 0xa6, 0x83, 0x13, 0x06, 0x4e, 0x18, 0x38, 0x61, 0xe0, 0x84, 0x81,
		0x13, 0x06, 0x4e, 0x18, 0x38, 0x61, 0xe0, 0x84, 0x81, 0x13, 0x06, 0x4e, 0x18, 0x38, 0x61, 0xe0,
		0x84, 0x81, 0x13, 0x06, 0x4e, 0x18, 0x38, 0x61, 0xca, 0xe5, 0x84, 0xd1, 0xd9, 0xa4, 0x6e, 0xd6,
		0x07, 0x43, 0xdb, 0xa8, 0x8e, 0xc3, 0x05, 0x33, 0xa4, 0xaf, 0x40, 0xdc, 0x05, 0x33, 0xba, 0x0c,
		0x79, 0x30, 0x70, 0xc1, 0x98, 0x71, 0xc1, 0x08, 0x35, 0x73, 0xa3, 0x50, 0x37, 0xe8, 0x8e, 0x05,
		0x07, 0x4b, 0x5e, 0xab, 0x6b, 0x25, 0xdb, 0xc5, 0x2d, 0x90, 0x8b, 0x74, 0xed, 0x7e, 0x85, 0x72,
		0x38, 0x3b, 0x6a, 0x0a, 0x74, 0x30, 0x92, 0x16, 0x64, 0x5a, 0xd9, 0xf0, 0xe1, 0xec, 0xca, 0x05,
		0xed, 0x0b, 0x84, 0xa7, 0x58, 0xd2, 0x3e, 0xcf, 0x8c, 0x18, 0x81, 0x6a, 0x92, 0x59, 0xb5, 0x31,
		0xad, 0x36, 0xe6, 0xd5, 0xc2, 0xc4, 0x34, 0xce, 0xb2, 0xfc, 0x8d, 0x40, 0x55, 0x76, 0x6a, 0x11,
		0x39, 0xb7, 0xa8, 0x76, 0x48, 0xb9, 0x94, 0x5e, 0xdd, 0x61, 0x98, 0xea, 0x84, 0xd1, 0x59, 0x5a,
		0x9f, 0xc2, 0x4d, 0x04, 0x25, 0xf6, 0x4b, 0xd9, 0xa9, 0xc0, 0x5e, 0xe7, 0x5d, 0x75, 0xd5, 0xa8,
		0x5a, 0x84, 0x9f, 0xaa, 0x21, 0xd5, 0xca, 0xf0, 0xa1, 0x28, 0xa1, 0x28, 0xa1, 0x28, 0x35, 0x29,
		0x4a, 0xda, 0x32, 0x7f, 0x6a, 0xad, 0x99, 0x89, 0x38, 0xf4, 0x7b, 0x5d, 0xc2, 0x90, 0x7b, 0xb4,
		0x1a, 0x04, 0x1f, 0x04, 0x1f, 0x04, 0x5f, 0xae, 0x04, 0x9f, 0x6c, 0x82, 0x53, 0xaa, 0xa8, 0x3b,
		0x26, 0x58, 0x4b, 0x29, 0x01, 0x4a, 0x0f, 0xd4, 0xd7, 0x63, 0x56, 0x11, 0x2b, 0x0a, 0x22, 0x32,
		0xd3, 0xb8, 0x73, 0x34, 0xa9, 0x65, 0xa9, 0xdb, 0x57, 0x27, 0x5c, 0x93, 0x34, 0xf5, 0x2c, 0x75,
		0x43, 0x6e, 0xfe, 0xb8, 0xb9, 0x3d, 0xbd, 0x78, 0xf8, 0x78, 0xfa, 0xeb, 0xd9, 0xe5, 0xe9, 0xc7,
		0x87, 0xeb, 0xab, 0xf3, 0xd3, 0x1b, 0xc2, 0x9d, 0xa9, 0x10, 0xe7, 0xa7, 0xe9, 0x23, 0x91, 0x55,
		0xbb, 0x33, 0xdc, 0x95, 0x87, 0xe6, 0xc7, 0x8b, 0xb3, 0x4b, 0x8b, 0xfc, 0x7e, 0x03, 0xd2, 0x15,
		0x5b, 0x5b, 0xf9, 0x7a, 0x2e, 0xf5, 0x55, 0x5a, 0x05, 0x84, 0xae, 0x41, 0xf0, 0xd5, 0xfe, 0x8b,
		0xbd, 0xd2, 0xa1, 0xd7, 0xf1, 0x82, 0x00, 0xb0, 0x00, 0xb0, 0x00, 0xb0, 0xb9, 0x02, 0xb0, 0xb9,
		0x73, 0x71, 0x67, 0x22, 0xf1, 0x94, 0xbb, 0xf5, 0x2d, 0x1a, 0x06, 0x6a, 0xfd, 0xfa, 0x20, 0xf3,
		0x20, 0xf3, 0x20, 0xf3, 0x20, 0xf3, 0xb4, 0x5c, 0x29, 0x9b, 0x3d, 0xa1, 0xd8, 0x37, 0x70, 0x82,
		0x2f, 0xe5, 0xf3, 0x70, 0xa3, 0xac, 0xd3, 0x3d, 0xb5, 0xb9, 0x23, 0x93, 0xe7, 0x90, 0xcd, 0xd1,
		0xfd, 0x6d, 0xf8, 0x14, 0x0f, 0xd2, 0x03, 0x48, 0xe4, 0x4f, 0x6f, 0x20, 0xd5, 0x2e, 0x51, 0x66,
		0x30, 0xc9, 0x12, 0xa6, 0x91, 0x6b, 0xd7, 0x58, 0xa1, 0xcc, 0x14, 0xab, 0x21, 0x53, 0x4c, 0xa3,
		0x76, 0x42, 0xa6, 0xd8, 0xe4, 0xc9, 0x91, 0x29, 0x06, 0x48, 0x09, 0x48, 0x09, 0x48, 0x59, 0x54,
		0x48, 0x89, 0x4c, 0x31, 0x4a, 0x6e, 0x42, 0xa6, 0x18, 0xa5, 0xb7, 0x05, 0x99, 0x62, 0x50, 0x94,
		0x50, 0x94, 0x9b, 0xa9, 0x28, 0x91, 0x29, 0xb6, 0xf0, 0xec, 0xc8, 0x14, 0x83, 0xe0, 0x83, 0xe0,
		0x2b, 0xbb, 0xe0, 0x43, 0xa6, 0x58, 0x96, 0x66, 0x15, 0xb1, 0xa2, 0x20, 0x22, 0x33, 0x8d, 0x3b,
		0x87, 0x4c, 0xb1, 0xb9, 0x0d, 0x41, 0xa6, 0x18, 0xc7, 0xee, 0x20, 0x53, 0x2c, 0xbb, 0x55, 0x90,
		0x29, 0x86, 0x4c, 0x31, 0x00, 0x58, 0x00, 0xd8, 0xbc, 0x02, 0x58, 0x64, 0x8a, 0x21, 0x53, 0x0c,
		0x32, 0x0f, 0x32, 0x0f, 0x32, 0xaf, 0x90, 0x32, 0x6f, 0x83, 0x33, 0xc5, 0x54, 0x52, 0x97, 0x2a,
		0x54, 0x89, 0x62, 0x12, 0x23, 0x67, 0xe5, 0xcf, 0x4e, 0x26, 0x4f, 0x8c, 0x6e, 0x62, 0x39, 0x66,
		0x95, 0x23, 0x5b, 0x2c, 0x6b, 0x8d, 0x54, 0xd4, 0x59, 0xe5, 0x5d, 0xe6, 0x3c, 0x12, 0x0d, 0x0e,
		0x38, 0x52, 0x58, 0xe3, 0x73, 0x2c, 0x72, 0xdf, 0xbd, 0x8b, 0xf3, 0x6c, 0xf7, 0x12, 0xa6, 0x2e,
		0xc5, 0x08, 0xf4, 0x7f, 0x45, 0x4e, 0x0b, 0x59, 0x49, 0x55, 0xfe, 0xee, 0xde, 0x5e, 0xbf, 0xdb,
		0x2d, 0xeb, 0x0c, 0xfa, 0x09, 0x32, 0x30, 0x3a, 0x7d, 0x7e, 0x82, 0x05, 0x30, 0x78, 0x7e, 0xd5,
		0xc9, 0x18, 0xe9, 0xb2, 0x1d, 0x1d, 0x06, 0x59, 0x97, 0xed, 0x2d, 0x85, 0xfd, 0x16, 0xdd, 0x67,
		0x85, 0xfd, 0xb5, 0xb8, 0x06, 0xb2, 0xc9, 0xed, 0xe8, 0xea, 0xbd, 0x4c, 0xdf, 0xa1, 0x15, 0xbb,
		0x13, 0x8d, 0xc9, 0xea, 0xf9, 0xee, 0xdf, 0x7c, 0x9b, 0x33, 0x33, 0x5d, 0x6b, 0x72, 0xd9, 0x9a,
		0xdd, 0xe7, 0xab, 0x4c, 0xe0, 0xc6, 0x94, 0x22, 0xd8, 0x51, 0x1c, 0x23, 0x8a, 0x62, 0x41, 0x69,
		0xcc, 0x27, 0x8d, 0xed, 0xa4, 0x30, 0x9c, 0x1a, 0xff, 0xf0, 0x66, 0xea, 0x8b, 0x36, 0x4d, 0x96,
		0x6b, 0x92, 0x8c, 0x56, 0xf7, 0x15, 0xb4, 0xba, 0x97, 0x23, 0xd0, 0xe5, 0x72, 0x8f, 0x64, 0xd8,
		0xe0, 0xc2, 0x6a, 0x98, 0x35, 0xa8, 0xcf, 0xe2, 0x46, 0x2b, 0x7c, 0xcc, 0x1a, 0xe4, 0xfa, 0xc2,
		0xac, 0xc1, 0xf5, 0x2f, 0x88, 0x59, 0x83, 0xe6, 0xdc, 0x58, 0x1a, 0xdf, 0x0e, 0xb3, 0x06, 0xb5,
		0xf9, 0x2c, 0xc7, 0x5f, 0x98, 0x35, 0x28, 0x2e, 0xef, 0x30, 0x6b, 0x10, 0xb3, 0x06, 0xb5, 0x62,
		0xc1, 0x0a, 0x66, 0x0d, 0x12, 0xe1, 0xc9, 0x92, 0x7b, 0x41, 0x13, 0x0b, 0x4d, 0xbc, 0xaf, 0x89,
		0xa0, 0xcf, 0x2e, 0xb9, 0x93, 0x50, 0xef, 0x12, 0x9a, 0x59, 0x83, 0xec, 0x5b, 0x2c, 0x24, 0x04,
		0x5d, 0x30, 0xf1, 0x75, 0x70, 0xc1, 0xc0, 0x05, 0x63, 0xc6, 0x05, 0x13, 0x11, 0x9c, 0xbc, 0xcf,
		0x65, 0x74, 0x39, 0xe6, 0x0d, 0xc2, 0xc9, 0x92, 0x2b, 0x27, 0x0b, 0xe6, 0x0d, 0x22, 0x2f, 0x48,
		0x1b, 0x23, 0x69, 0x41, 0xa7, 0x95, 0x0d, 0xef, 0x22, 0x15, 0x29, 0x92, 0x51, 0x95, 0x3c, 0x99,
		0x4b, 0x6d, 0x6a, 0x4d, 0xa4, 0x9c, 0xeb, 0x67, 0x54, 0x6a, 0x86, 0xd5, 0xc6, 0xb8, 0xda, 0x18,
		0x58, 0x0b, 0x23, 0xd3, 0x38, 0xcd, 0xf2, 0x97, 0x72, 0x4e, 0x5b, 0xb8, 0x4b, 0x59, 0xb0, 0xab,
		0xa7, 0x50, 0x77, 0xc6, 0xd3, 0xdf, 0xfc, 0xed, 0xf6, 0x9f, 0x57, 0xd7, 0x67, 0xff, 0x69, 0xde,
		0x9e, 0x5d, 0x5d, 0x3e, 0x9c, 0xfe, 0x7e, 0x7a, 0x79, 0x4b, 0xe1, 0xf6, 0x4f, 0xee, 0xa5, 0xa1,
		0x40, 0x57, 0x53, 0xb9, 0x72, 0xda, 0x6e, 0x7c, 0xb8, 0xba, 0xfc, 0xf5, 0xec, 0x13, 0x5d, 0x75,
		0xee, 0x60, 0xb7, 0xb8, 0x3b, 0x71, 0x71, 0xd1, 0xbc, 0xfc, 0x68, 0xe5, 0xac, 0x10, 0xb8, 0x95,
		0xb5, 0x44, 0x43, 0x89, 0x08, 0xa7, 0xa3, 0x6d, 0xe4, 0x54, 0x1a, 0x7d, 0x33, 0xde, 0x4d, 0x78,
		0xe2, 0x85, 0x3b, 0x8d, 0x1e, 0x63, 0xf4, 0xad, 0x00, 0xed, 0x84, 0x09, 0x10, 0x29, 0x1d, 0x12,
		0x45, 0xa9, 0x08, 0x4c, 0x42, 0x94, 0x8a, 0xe4, 0xad, 0x54, 0x64, 0x8a, 0xad, 0xd1, 0x17, 0xdd,
		0x88, 0x47, 0x0b, 0x7d, 0xd1, 0x21, 0xbe, 0xe0, 0xd1, 0x82, 0x47, 0x0b, 0x1e, 0x2d, 0x78, 0xb4,
		0xe0, 0xd1, 0x82, 0x47, 0x0b, 0x1e, 0x2d, 0x78, 0xb4, 0xe0, 0xd1, 0xda, 0x6c, 0x8f, 0x96, 0xe1,
		0xae, 0x27, 0x29, 0x0e, 0x2d, 0xb3, 0x6d, 0x4f, 0x4c, 0xf4, 0x0c, 0x90, 0x06, 0x9b, 0xe8, 0x1a,
		0xa0, 0x7c, 0x04, 0xa6, 0xbb, 0x06, 0x2c, 0x67, 0x2d, 0xfd, 0x6d, 0x03, 0x96, 0x33, 0x13, 0xfa,
		0x06, 0xac, 0x3a, 0x1b, 0x13, 0x19, 0xb3, 0xa3, 0xd3, 0x30, 0x99, 0x31, 0x2b, 0xe6, 0xa5, 0x92,
		0xf2, 0x4a, 0x49, 0xe7, 0xcb, 0xd6, 0x90, 0x2f, 0x4b, 0x69, 0x64, 0xa2, 0x64, 0x19, 0x25, 0xcb,
		0xc8, 0xa6, 0xa5, 0xf4, 0xac, 0xa0, 0x64, 0x39, 0xfd, 0xb1, 0x51, 0xb2, 0x8c, 0x92, 0x65, 0xc5,
		0x17, 0x45, 0xc9, 0x72, 0x21, 0x5f, 0x0c, 0x25, 0xcb, 0xe6, 0x85, 0x1e, 0x4a, 0x96, 0x37, 0xcc,
		0x15, 0x82, 0x92, 0x65, 0x3d, 0xb8, 0xb0, 0x82, 0x92, 0xe5, 0xfc, 0x39, 0x60, 0x44, 0x5d, 0xcd,
		0xd2, 0xfe, 0x17, 0x01, 0x6f, 0x72, 0xd1, 0xdb, 0x36, 0xf2, 0x76, 0x30, 0x54, 0xd9, 0x4f, 0x1d,
		0x4d, 0x1b, 0x39, 0x4b, 0x05, 0xc5, 0x4a, 0x02, 0xd1, 0xa6, 0x91, 0x56, 0xaa, 0x66, 0xd0, 0xa6,
		0x51, 0x27, 0xbf, 0x70, 0x27, 0x6f, 0x0b, 0x30, 0x0a, 0x4f, 0x26, 0xb6, 0x1c, 0x87, 0x04, 0xcc,
		0xff, 0xc6, 0x7c, 0xfb, 0xc9, 0xef, 0xf5, 0x5f, 0x02, 0x7e, 0x46, 0x99, 0xbd, 0x0c, 0xfc, 0x82,
		0xb6, 0xa6, 0x8b, 0xe4, 0x24, 0x11, 0x28, 0x98, 0xbe, 0x1a, 0xfd, 0x35, 0x0c, 0xba, 0x4c, 0x37,
		0x3a, 0x5e, 0x20, 0xd9, 0x50, 0x40, 0xad, 0x91, 0x00, 0x3a, 0x6c, 0x18, 0x25, 0x70, 0x72, 0xdb,
		0xaf, 0xcc, 0x1d, 0x36, 0x68, 0x26, 0xef, 0x60, 0xea, 0x0e, 0x6a, 0x11, 0xb2, 0x60, 0xaa, 0x4c,
		0xdc, 0xb2, 0x84, 0xa5, 0x54, 0xc5, 0x73, 0xcf, 0xca, 0x54, 0x3c, 0xd1, 0x14, 0x6d, 0xa2, 0x5c,
		0x13, 0x32, 0x06, 0x32, 0x46, 0x9c, 0x5e, 0x36, 0x22, 0xee, 0x7d, 0x73, 0x7a, 0xfd, 0xfb, 0xe9,
		0x75, 0xc9, 0xe3, 0xde, 0xa3, 0x00, 0x6a, 0x19, 0x43, 0xc3, 0xa3, 0x88, 0xfe, 0xc6, 0x85, 0x85,
		0x73, 0x66, 0x44, 0x98, 0xcc, 0x72, 0x9e, 0xf1, 0x2a, 0xce, 0xfc, 0x26, 0xdf, 0x12, 0x43, 0xc0,
		0xcb, 0x7a, 0x13, 0xdd, 0xf0, 0x53, 0x74, 0xf7, 0xe9, 0x5f, 0xa4, 0x1a, 0x61, 0x08, 0x04, 0xdc,
		0x04, 0xfc, 0x43, 0x52, 0x96, 0x99, 0x8a, 0x45, 0x86, 0xd4, 0x45, 0xb8, 0x29, 0x72, 0x9f, 0xba,
		0x28, 0xdf, 0x7c, 0x42, 0xa5, 0xe9, 0xc4, 0x92, 0x66, 0x13, 0xe2, 0x33, 0x49, 0xf5, 0x88, 0x89,
		0x91, 0xe8, 0x0c, 0xe4, 0x25, 0xc5, 0x78, 0x01, 0xf8, 0x34, 0x21, 0x2c, 0xca, 0xe1, 0xd3, 0x1c,
		0x51, 0x34, 0x41, 0x8b, 0x95, 0xd1, 0x3a, 0xe8, 0x1a, 0x0c, 0x9f, 0xc3, 0x46, 0xf8, 0x1c, 0x94,
		0x7b, 0xac, 0x38, 0x9d, 0x8e, 0xcf, 0x82, 0x80, 0xce, 0xb4, 0x1f, 0x2f, 0x88, 0xee, 0x2a, 0xfa,
		0x59, 0x94, 0x9a, 0x55, 0xb5, 0xb1, 0xac, 0x36, 0xd6, 0xd5, 0xc2, 0xc2, 0x34, 0xae, 0x89, 0xfc,
		0x75, 0x57, 0x51, 0xef, 0x02, 0x47, 0x01, 0xcc, 0x39, 0x80, 0xfa, 0x58, 0x86, 0x64, 0xd5, 0x0b,
		0x42, 0x41, 0x69, 0x2a, 0x8e, 0x3f, 0x58, 0x38, 0x33, 0xe5, 0x66, 0xa3, 0x04, 0xc0, 0x06, 0xd2,
		0x14, 0xd2, 0xb4, 0xe8, 0xd2, 0x54, 0x15, 0x28, 0x91, 0x03, 0x26, 0x4d, 0xc0, 0x89, 0x18, 0x40,
		0x91, 0xb3, 0xbe, 0x0e, 0x11, 0xa0, 0x4f, 0x14, 0xe8, 0x12, 0x09, 0xda, 0x45, 0x83, 0x76, 0x11,
		0xa1, 0x55, 0x54, 0xd0, 0x88, 0x0c, 0x22, 0xd1, 0x41, 0x0f, 0xc8, 0x16, 0xe8, 0xd5, 0x7d, 0xb1,
		0x69, 0xb9, 0xbf, 0xa2, 0x58, 0xf9, 0xbd, 0x6e, 0x0f, 0xee, 0x48, 0x69, 0x88, 0x96, 0xa7, 0xe6,
		0x76, 0xf6, 0xdb, 0xa1, 0x86, 0xbd, 0x5d, 0xd8, 0xe3, 0xf7, 0x1a, 0xd6, 0xfe, 0xec, 0x84, 0x21,
		0xf3, 0x3d, 0xf2, 0xed, 0x4e, 0x6e, 0xb0, 0xbd, 0x7d, 0xb7, 0x6f, 0x1f, 0xb7, 0xde, 0xee, 0xaa,
		0xf6, 0x71, 0x6b, 0xf4, 0x63, 0x35, 0xfa, 0x36, 0xfa, 0xb9, 0x76, 0xb7, 0x6f, 0x1f, 0x8e, 0x7f,
		0xae, 0xdf, 0xed, 0xdb, 0xf5, 0xd6, 0xce, 0xfd, 0xfd, 0xbb, 0x9d, 0x1f, 0x07, 0x03, 0xf1, 0x0b,
		0x2d, 0xf2, 0x57, 0x68, 0xe9, 0xd8, 0xf2, 0xab, 0x9b, 0xb3, 0x7f, 0x6b, 0xdf, 0xf7, 0x3f, 0x4d,
		0x6e, 0xfc, 0x4f, 0x1a, 0x76, 0x9e, 0x74, 0xc5, 0xc1, 0x6e, 0x81, 0x84, 0x49, 0x03, 0xc2, 0x64,
		0xa5, 0x30, 0x71, 0xec, 0xc7, 0xa6, 0xfd, 0x6b, 0xeb, 0x47, 0x75, 0xf7, 0x70, 0x70, 0xb2, 0xf3,
		0xe3, 0x68, 0x30, 0xff, 0xc7, 0xb7, 0x65, 0x1f, 0xab, 0xee, 0x1e, 0x0d, 0x4e, 0x52, 0xfe, 0xa5,
		0x31, 0x38, 0xe1, 0x5c, 0xa3, 0x3e, 0xd8, 0x5e, 0xf8, 0xe8, 0xf0, 0xef, 0xb5, 0xb4, 0x0b, 0x0e,
		0x53, 0x2e, 0x38, 0x48, 0xbb, 0xe0, 0x20, 0xe5, 0x82, 0xd4, 0x47, 0xaa, 0xa5, 0x5c, 0x50, 0x1f,
		0xbc, 0x2d, 0x7c, 0x7e, 0x7b, 0xf9, 0x47, 0x1b, 0x83, 0x9d, 0xb7, 0xb4, 0x7f, 0x3b, 0x1a, 0xbc,
		0x9d, 0xec, 0x40, 0xb4, 0x2e, 0x8a, 0x56, 0x90, 0xa1, 0x79, 0x32, 0xcc, 0xbf, 0xa2, 0xd9, 0xca,
		0xd7, 0x73, 0x0d, 0xf2, 0x90, 0x15, 0xa8, 0x56, 0x4d, 0x92, 0xaa, 0x2a, 0x15, 0xaa, 0x4b, 0xe0,
		0xc9, 0x80, 0x27, 0x03, 0x9e, 0x8c, 0x82, 0x7a, 0x32, 0x94, 0xab, 0x63, 0xd2, 0x41, 0x71, 0x89,
		0x64, 0x6e, 0xe8, 0x3e, 0xb3, 0x5e, 0x3f, 0xa4, 0x17, 0xbb, 0xe3, 0x85, 0x21, 0x79, 0x21, 0x79,
		0x21, 0x79, 0x37, 0x4a, 0xf2, 0xf6, 0x5d, 0x2f, 0xac, 0x36, 0x34, 0x48, 0xde, 0x06, 0xe1, 0x92,
		0xd7, 0x8e, 0xf7, 0x54, 0x08, 0xff, 0xf1, 0x85, 0xeb, 0x91, 0x33, 0xaa, 0x26, 0xb1, 0xba, 0xb0,
		0x7c, 0x54, 0x0d, 0xa5, 0x71, 0xfd, 0x5f, 0x7d, 0xa7, 0x1d, 0xba, 0x3d, 0xef, 0xa3, 0xfb, 0xe4,
		0x8e, 0xba, 0xea, 0x91, 0xdf, 0x67, 0xa0, 0xc1, 0x01, 0x71, 0xe1, 0x7c, 0x2f, 0xfc, 0x91, 0x36,
		0xea, 0xf5, 0x83, 0x7a, 0x81, 0x8f, 0x15, 0xf6, 0xbc, 0xc6, 0x15, 0x54, 0x53, 0x24, 0x88, 0x86,
		0xd2, 0x24, 0xeb, 0x11, 0xd5, 0x96, 0xc5, 0xc5, 0x0e, 0xf1, 0xf7, 0x3d, 0x92, 0x84, 0xa8, 0x0a,
		0x51, 0xe9, 0xd9, 0xe8, 0xe7, 0xf1, 0xdf, 0x94, 0x46, 0x32, 0xab, 0xd3, 0x80, 0x4a, 0xda, 0x9a,
		0xef, 0x74, 0xdc, 0x3e, 0x61, 0x16, 0x70, 0xbc, 0x1e, 0xd2, 0xd6, 0xcc, 0xd9, 0x19, 0x48, 0x5b,
		0x43, 0xda, 0x5a, 0xfa, 0x42, 0x44, 0x79, 0xa9, 0x0b, 0xe4, 0x4b, 0x26, 0x8e, 0x09, 0x19, 0x1e,
		0x0e, 0x07, 0x38, 0x1c, 0xe0, 0x70, 0xa0, 0x15, 0x20, 0xc9, 0x82, 0x4e, 0xbb, 0x1d, 0xda, 0x2f,
		0x3d, 0x3f, 0xa4, 0xa7, 0xab, 0x24, 0x13, 0x36, 0xb9, 0x05, 0xf1, 0xb1, 0x7f, 0x64, 0x8f, 0x4e,
		0xbf, 0x1b, 0x9d, 0x7a, 0xf5, 0x7d, 0xf5, 0x80, 0x7a, 0x79, 0x3d, 0x46, 0x20, 0xb9, 0x14, 0xd3,
		0x29, 0xcd, 0xf4, 0x4b, 0x35, 0xdd, 0xd2, 0xcd, 0x98, 0x94, 0x33, 0x26, 0xed, 0x8c, 0x48, 0x3d,
		0x4d, 0x26, 0x3e, 0x31, 0xc5, 0x93, 0xbb, 0x5f, 0x17, 0xe8, 0x7d, 0x28, 0xb6, 0x6c, 0xaf, 0xff,
		0xfc, 0x45, 0xba, 0x0a, 0x99, 0x47, 0xc4, 0x34, 0x34, 0x2c, 0xad, 0xc7, 0x37, 0x3b, 0xfe, 0xd2,
		0xc3, 0xa4, 0x15, 0xdd, 0xbe, 0x5a, 0x43, 0x0e, 0xbe, 0x05, 0x47, 0x9f, 0xee, 0xfb, 0x18, 0x70,
		0xf6, 0x69, 0xe2, 0xe1, 0xd9, 0xa3, 0xd7, 0xe8, 0xd3, 0xcd, 0xea, 0xe8, 0x35, 0xfa, 0x78, 0x33,
		0x39, 0xfe, 0xad, 0x62, 0xac, 0x9a, 0xd7, 0x5c, 0x33, 0x42, 0xf6, 0x89, 0x86, 0x65, 0xea, 0xc6,
		0xee, 0xc9, 0x2d, 0xb4, 0x62, 0xf7, 0x1a, 0xb0, 0x3b, 0xb0, 0x3b, 0xb0, 0x3b, 0xb0, 0x3b, 0xb0,
		0x3b, 0xb0, 0x3b, 0xb0, 0x3b, 0xb0, 0x3b, 0xb0, 0x3b, 0xb0, 0x7b, 0xa9, 0xb1, 0xbb, 0xcf, 0x42,
		0xdf, 0xf1, 0x82, 0x67, 0x37, 0xb4, 0x9d, 0x30, 0x64, 0xcf, 0x2f, 0x61, 0xa0, 0x0f, 0xc5, 0x2f,
		0xbb, 0x19, 0x00, 0x37, 0x00, 0x37, 0x00, 0x37, 0x00, 0x37, 0x21, 0xbd, 0xf7, 0x5d, 0x2f, 0x7c,
		0xaf, 0x11, 0x6a, 0xd7, 0x01, 0xb5, 0x01, 0xb5, 0x01, 0xb5, 0x4b, 0x09, 0xb5, 0x6b, 0x75, 0x00,
		0x6d, 0x00, 0x6d, 0x0d, 0x40, 0x3b, 0x60, 0x6d, 0x9f, 0x85, 0xf6, 0x5f, 0xec, 0x55, 0x1f, 0xbe,
		0x9e, 0xba, 0x07, 0x60, 0x35, 0x60, 0x35, 0x60, 0x35, 0x60, 0x35, 0xa5, 0xf5, 0xde, 0xeb, 0x87,
		0xae, 0xf7, 0x64, 0xbf, 0x38, 0x41, 0x10, 0x91, 0x8f, 0xce, 0x5e, 0x45, 0x1b, 0xa5, 0x11, 0xec,
		0xaf, 0x4e, 0xf0, 0x95, 0x75, 0x4c, 0x28, 0x86, 0xf1, 0xad, 0xa0, 0x1f, 0xa0, 0x1f, 0xa0, 0x1f,
		0xa0, 0x1f, 0x08, 0xe9, 0xbd, 0xed, 0xbf, 0xbe, 0x84, 0x89, 0x76, 0xb0, 0x15, 0xa6, 0xb4, 0x42,
		0x45, 0x8c, 0x55, 0x44, 0xc4, 0xe8, 0x36, 0x75, 0x73, 0xe8, 0x45, 0xfd, 0x30, 0x7b, 0x1f, 0x28,
		0x07, 0x28, 0x07, 0x28, 0x07, 0x28, 0x07, 0x42, 0x7a, 0xd7, 0xd2, 0x8b, 0x7a, 0x41, 0x27, 0x1c,
		0x6b, 0x58, 0x5b, 0x4b, 0x6f, 0xea, 0xf1, 0x97, 0x46, 0xc7, 0xbc, 0xa1, 0x5e, 0xd5, 0x8b, 0x7a,
		0x59, 0xe3, 0x3d, 0x74, 0x37, 0xfa, 0x4c, 0x6e, 0x54, 0xec, 0x1e, 0xd6, 0xe3, 0xaf, 0x96, 0xce,
		0xa3, 0x30, 0xd1, 0x78, 0x35, 0xb9, 0x5b, 0xd1, 0x7b, 0x5b, 0x27, 0x27, 0xa2, 0xc7, 0x23, 0xbf,
		0x5b, 0x60, 0xe1, 0xd4, 0x80, 0x70, 0x92, 0x12, 0x4e, 0x68, 0x46, 0x5c, 0x86, 0x9e, 0xd8, 0xa5,
		0x15, 0xd5, 0x20, 0xcf, 0x52, 0xf4, 0xca, 0xd6, 0xac, 0xb8, 0x36, 0x27, 0x94, 0x9c, 0xab, 0xf6,
		0x0d, 0xc4, 0x3d, 0xb9, 0x26, 0xfe, 0x2a, 0x2d, 0xbd, 0xb9, 0x46, 0x5d, 0x9f, 0xf6, 0x48, 0x7b,
		0xc2, 0x54, 0xf4, 0xb4, 0xea, 0xba, 0x8e, 0x1e, 0x95, 0xa4, 0x63, 0x17, 0x1d, 0xe5, 0x0c, 0x48,
		0xba, 0x9a, 0x39, 0xa1, 0x86, 0x86, 0xee, 0xa3, 0x65, 0x73, 0xde, 0xe6, 0xa7, 0x86, 0x36, 0x3f,
		0x05, 0xf2, 0x1f, 0xa2, 0xcd, 0x0f, 0xda, 0xfc, 0xa0, 0xcd, 0xcf, 0xa2, 0x14, 0x43, 0x94, 0xc4,
		0x80, 0x74, 0x33, 0x26, 0xe5, 0x8c, 0x49, 0x3b, 0x23, 0x52, 0x4f, 0x8f, 0x3d, 0x80, 0x52, 0xe1,
		0xe5, 0x22, 0x06, 0xa5, 0xc2, 0x53, 0x0f, 0x8e, 0xfa, 0x05, 0xf1, 0xfb, 0xa0, 0x7e, 0x21, 0xb7,
		0x47, 0x8f, 0x52, 0x61, 0xb8, 0x9d, 0xf4, 0xb0, 0x0f, 0xda, 0xfc, 0x00, 0xbb, 0x03, 0xbb, 0x03,
		0xbb, 0x03, 0xbb, 0x03, 0xbb, 0x03, 0xbb, 0x03, 0xbb, 0x03, 0xbb, 0x03, 0xbb, 0x03, 0xbb, 0x17,
		0x04, 0xbb, 0xb7, 0x7b, 0x7d, 0x2f, 0x64, 0xbe, 0xc6, 0x12, 0x82, 0xe4, 0x0e, 0x7a, 0xa0, 0x75,
		0x15, 0xd0, 0x1a, 0xd0, 0x1a, 0xd0, 0x3a, 0x8f, 0xd0, 0x9a, 0x3a, 0x48, 0x38, 0x71, 0x38, 0xb4,
		0xdb, 0x2c, 0x08, 0xec, 0xe1, 0x37, 0x1d, 0x6d, 0xc9, 0x16, 0xbd, 0x0f, 0xb3, 0xf7, 0xdb, 0x2d,
		0xe4, 0x4c, 0x47, 0x5d, 0x82, 0xcd, 0x84, 0x80, 0x33, 0x27, 0xe8, 0x4c, 0x09, 0x3c, 0xe3, 0x82,
		0xcf, 0xb8, 0x00, 0x34, 0x2a, 0x08, 0x35, 0x43, 0x4b, 0x4d, 0x1c, 0xa3, 0xcd, 0xf7, 0x90, 0x06,
		0xc2, 0x1a, 0x87, 0x06, 0x72, 0xe9, 0x75, 0xa6, 0xd2, 0xeb, 0xf5, 0x48, 0xe8, 0xf7, 0x4c, 0x18,
		0xf5, 0x50, 0x18, 0x36, 0x57, 0x4d, 0x7b, 0x2c, 0xb2, 0x30, 0x5d, 0x0d, 0x78, 0x30, 0x8c, 0x7a,
		0x32, 0xb2, 0x26, 0x91, 0xea, 0xfb, 0xc3, 0xc3, 0xc6, 0xd1, 0xe1, 0xe1, 0xfe, 0xd1, 0xc1, 0xd1,
		0xfe, 0x71, 0xbd, 0x5e, 0x6d, 0x54, 0xeb, 0x25, 0xa6, 0x9a, 0xad, 0x62, 0xae, 0x5e, 0x94, 0x1c,
		0x7f, 0x1d, 0x63, 0xdc, 0x63, 0xec, 0xef, 0xb3, 0xff, 0x97, 0xb5, 0x0d, 0xda, 0x1a, 0xe3, 0xfb,
		0xc1, 0xd6, 0x80, 0xad, 0x01, 0x5b, 0x03, 0xb6, 0x06, 0x6c, 0x0d, 0xd8, 0x1a, 0xb0, 0x35, 0x60,
		0x6b, 0xc0, 0xd6, 0x80, 0xad, 0x01, 0x5b, 0xa3, 0xa4, 0xb6, 0x86, 0xcf, 0x42, 0xdf, 0x65, 0x1d,
		0x3b, 0xb1, 0x01, 0xfe, 0xaf, 0xcf, 0x02, 0x13, 0x46, 0x47, 0xda, 0x8d, 0x61, 0x7d, 0xc0, 0xfa,
		0x80, 0xf5, 0x01, 0xeb, 0x03, 0xd6, 0x07, 0xac, 0x0f, 0x58, 0x1f, 0xb0, 0x3e, 0x60, 0x7d, 0xc0,
		0xfa, 0x80, 0xf5, 0x51, 0x52, 0xeb, 0x23, 0x74, 0x9f, 0x59, 0xaf, 0x1f, 0x9a, 0xb7, 0x3e, 0xd2,
		0x6e, 0x0c, 0xeb, 0x03, 0xd6, 0x07, 0xac, 0x0f, 0x58, 0x1f, 0xb0, 0x3e, 0x60, 0x7d, 0xc0, 0xfa,
		0x80, 0xf5, 0x01, 0xeb, 0x03, 0xd6, 0x07, 0xac, 0x8f, 0x3c, 0x58, 0x1f, 0xb9, 0x2e, 0x3b, 0xd1,
		0xd4, 0xc3, 0x34, 0x59, 0x5f, 0x6b, 0x2f, 0xd3, 0xa8, 0xef, 0xe5, 0x9e, 0xa6, 0x9a, 0xb9, 0x8a,
		0xd6, 0xde, 0xa6, 0x37, 0xc3, 0x47, 0x7f, 0xf8, 0x30, 0x7e, 0xf4, 0x0d, 0x28, 0x9e, 0xf4, 0x59,
		0xe8, 0x3b, 0x5e, 0xf0, 0xec, 0x86, 0xb6, 0x13, 0x86, 0xec, 0x59, 0x47, 0x31, 0xd2, 0x4c, 0x8c,
		0x6e, 0xfe, 0x66, 0xe8, 0x56, 0x82, 0x92, 0xca, 0xcc, 0x2d, 0x5e, 0x94, 0x54, 0x9a, 0xd3, 0x6d,
		0xfa, 0xbb, 0x95, 0xf4, 0x5d, 0x2f, 0x7c, 0xaf, 0xb1, 0x4f, 0x49, 0x1d, 0x7d, 0x4a, 0xcc, 0x5a,
		0xa7, 0xe8, 0x53, 0x92, 0x47, 0xeb, 0xb3, 0x94, 0x7d, 0x4a, 0x6a, 0x75, 0x74, 0x29, 0x31, 0xbe,
		0x6a, 0x6b, 0xa3, 0x26, 0x62, 0x9b, 0x18, 0x85, 0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x58, 0x0d, 0x58,
		0x4d, 0x6a, 0xbd, 0xf7, 0xfa, 0xa1, 0xeb, 0x3d, 0x25, 0x53, 0xb0, 0x31, 0x00, 0x9b, 0x4a, 0x23,
		0xd8, 0x5f, 0x9d, 0xe0, 0x2b, 0xeb, 0x98, 0x50, 0x0c, 0xe3, 0x5b, 0x41, 0x3f, 0x40, 0x3f, 0x40,
		0x3f, 0x40, 0x3f, 0x10, 0xd2, 0x7b, 0xdb, 0x7f, 0x7d, 0x09, 0x13, 0xed, 0x60, 0x87, 0xc3, 0x1b,
		0x42, 0x45, 0xa8, 0xa9, 0x88, 0x88, 0xd1, 0x93, 0x21, 0xb2, 0xfa, 0xf4, 0xc3, 0xec, 0x7d, 0xa0,
		0x1c, 0xa0, 0x1c, 0xa0, 0x1c, 0xa0, 0x1c, 0x08, 0xe9, 0xdd, 0x7d, 0xd1, 0x38, 0x0a, 0x3b, 0xd1,
		0x09, 0xc7, 0x1a, 0xd6, 0x8e, 0xf7, 0xe6, 0xae, 0xc0, 0x63, 0xc8, 0x0f, 0x31, 0x86, 0x5c, 0xf0,
		0x46, 0x26, 0x47, 0xf2, 0x63, 0xf0, 0xf6, 0xfa, 0xbb, 0xfd, 0x69, 0xf2, 0x40, 0x8a, 0x37, 0x6a,
		0x7a, 0xb7, 0xc0, 0xc2, 0xa9, 0x01, 0xe1, 0x24, 0x25, 0x9c, 0x30, 0x84, 0xde, 0xfc, 0x10, 0x7a,
		0x88, 0x6a, 0x6e, 0x51, 0x0d, 0xf2, 0x34, 0x4f, 0x9e, 0xc5, 0x53, 0x5c, 0x9b, 0x13, 0x4a, 0xce,
		0xd5, 0xec, 0x6b, 0x4d, 0xf9, 0xc5, 0x06, 0xf2, 0x8a, 0x29, 0xa7, 0xc0, 0xeb, 0x4d, 0x23, 0xa6,
		0xe1, 0x45, 0x75, 0xba, 0x51, 0x5b, 0x41, 0x91, 0xe2, 0xa8, 0x29, 0x4d, 0x2b, 0x85, 0x11, 0xd0,
		0x96, 0x36, 0x9a, 0x52, 0xa3, 0x26, 0x79, 0x1a, 0x50, 0x38, 0x7f, 0x6b, 0xc4, 0xb0, 0xaa, 0xc7,
		0x3e, 0x71, 0x52, 0x13, 0xf0, 0x3f, 0xd1, 0xc8, 0x9d, 0x89, 0xef, 0xb9, 0xa6, 0xb8, 0x10, 0xa1,
		0xaf, 0x99, 0xde, 0xb7, 0x4c, 0xed, 0x4b, 0xd6, 0xe6, 0x3b, 0xd6, 0xe6, 0x2b, 0xd6, 0xe2, 0x1b,
		0xce, 0x56, 0x22, 0x53, 0x8d, 0xb4, 0xb1, 0xa8, 0xa3, 0x52, 0x93, 0xfe, 0xd1, 0xa4, 0xfe, 0x00,
		0xe2, 0xf0, 0x13, 0x79, 0xd8, 0x49, 0x47, 0xb8, 0x49, 0x5f, 0x98, 0x49, 0x57, 0x78, 0x49, 0x7b,
		0x58, 0x49, 0x7b, 0x38, 0x49, 0x6b, 0x18, 0x29, 0x5f, 0xe6, 0x03, 0x79, 0xb8, 0x48, 0x6f, 0x98,
		0x48, 0x47, 0x78, 0x48, 0x4f, 0x58, 0x48, 0x6b, 0x00, 0x4e, 0x6b, 0x18, 0x48, 0xa7, 0x87, 0x55,
		0xbb, 0x67, 0xb5, 0xe0, 0xe1, 0x9e, 0x96, 0x8e, 0x2d, 0x37, 0xe1, 0x33, 0x2c, 0x7c, 0x58, 0xa7,
		0x95, 0xe7, 0xa8, 0xbe, 0x5e, 0x61, 0xd2, 0x80, 0x30, 0x59, 0x29, 0x4c, 0xe0, 0xff, 0x2e, 0x43,
		0x78, 0xa6, 0xf0, 0xa2, 0x15, 0x64, 0x58, 0x8a, 0x30, 0x4c, 0x5e, 0xc3, 0x1a, 0xad, 0xbc, 0x38,
		0xb9, 0x09, 0x9c, 0x5d, 0xed, 0x9e, 0xe7, 0xb1, 0xa8, 0x34, 0xd3, 0x76, 0xbe, 0xf4, 0xfc, 0x50,
		0x83, 0x67, 0x63, 0xf1, 0x16, 0xf0, 0x71, 0xc0, 0xc7, 0x01, 0x1f, 0xc7, 0x46, 0xf9, 0x38, 0x74,
		0x34, 0x58, 0xd4, 0xd0, 0x50, 0x51, 0x53, 0x4b, 0x0a, 0x0d, 0x56, 0x89, 0xce, 0x16, 0x14, 0xba,
		0x5b, 0xed, 0x6a, 0x6e, 0x39, 0x61, 0xa2, 0xdb, 0x80, 0x8e, 0x46, 0xce, 0x3a, 0x5b, 0x4b, 0x98,
		0x3a, 0x52, 0x73, 0x0d, 0x0b, 0x8d, 0x9c, 0x32, 0x10, 0xa8, 0x49, 0x04, 0xda, 0xee, 0xf6, 0x02,
		0xa6, 0x17, 0x81, 0xc6, 0xb7, 0x00, 0x02, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x05,
		0x02, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x05, 0x02, 0x1d, 0xc2, 0xc3, 0x47, 0xc7, 0xed, 0xf6,
		0x7d, 0xcd, 0x18, 0x34, 0xb9, 0x09, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28,
		0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0xe8, 0x10, 0x20, 0xf6, 0x5e, 0x98, 0xa7,
		0x17, 0x82, 0x8e, 0xee, 0x00, 0xfc, 0x09, 0xfc, 0x09, 0xfc, 0x09, 0xfc, 0x09, 0xfc, 0x09, 0xfc,
		0x09, 0xfc, 0x09, 0xfc, 0x09, 0xfc, 0x09, 0xfc, 0x39, 0x44, 0x87, 0xf1, 0x60, 0x6f, 0xbd, 0x10,
		0x34, 0xb9, 0x09, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50, 0x28, 0x50,
		0x28, 0x50, 0x28, 0x50, 0xe8, 0x06, 0xa3, 0x50, 0xe6, 0xfb, 0x3d, 0x3f, 0xb0, 0x7d, 0xd6, 0x66,
		0xee, 0x37, 0xc2, 0xe9, 0x30, 0x89, 0xea, 0x99, 0xbf, 0x01, 0xd0, 0x27, 0xd0, 0x27, 0xd0, 0x27,
		0xd0, 0x27, 0xd0, 0x27, 0xd0, 0x27, 0xd0, 0x27, 0xd0, 0x27, 0xd0, 0xe7, 0x06, 0xa3, 0xcf, 0x67,
		0x16, 0x04, 0xce, 0x13, 0xd3, 0x89, 0x3f, 0x17, 0x6f, 0x01, 0x04, 0x0a, 0x04, 0x0a, 0x04, 0x0a,
		0x04, 0x0a, 0x04, 0x0a, 0x04, 0x0a, 0x04, 0x0a, 0x04, 0x0a, 0x04, 0x0a, 0x04, 0x1a, 0xd8, 0xc1,
		0x48, 0xc5, 0xea, 0x42, 0x9f, 0xd1, 0xf2, 0x40, 0x9e, 0x40, 0x9e, 0x40, 0x9e, 0x40, 0x9e, 0x40,
		0x9e, 0x40, 0x9e, 0x40, 0x9e, 0x40, 0x9e, 0x40, 0x9e, 0x1b, 0x8c, 0x3c, 0xe3, 0xf1, 0x4d, 0xc4,
		0x80, 0x33, 0x5a, 0x15, 0x38, 0x13, 0x38, 0x13, 0x38, 0x73, 0xa3, 0x70, 0x66, 0x10, 0xfa, 0xae,
		0xf7, 0xa4, 0x63, 0x9e, 0xc9, 0xfb, 0x12, 0xc9, 0xdc, 0x38, 0x07, 0x9e, 0x5e, 0xec, 0x8e, 0x17,
		0x86, 0xe4, 0x85, 0xe4, 0x85, 0xe4, 0xdd, 0x28, 0xc9, 0xdb, 0x77, 0xbd, 0xb0, 0xda, 0xd0, 0x20,
		0x79, 0x1b, 0x30, 0xef, 0x61, 0xde, 0xc3, 0xbc, 0xcf, 0xc5, 0x91, 0x36, 0xea, 0xf5, 0x03, 0xd8,
		0xf3, 0xe5, 0xb5, 0xe7, 0x31, 0xbe, 0x7a, 0xed, 0xf8, 0x6a, 0xaa, 0xc9, 0xe8, 0x1a, 0xa6, 0x57,
		0x13, 0x8c, 0x42, 0xcf, 0x66, 0x78, 0x75, 0xe8, 0xb4, 0x9d, 0x76, 0x40, 0x37, 0xbd, 0x3a, 0x5e,
		0x2f, 0x67, 0xe3, 0xab, 0xf7, 0x31, 0xbe, 0x3a, 0x07, 0x56, 0x05, 0xc6, 0x57, 0xf3, 0xbf, 0x11,
		0xd9, 0xf8, 0xea, 0xf6, 0x98, 0x07, 0xe8, 0xeb, 0xfa, 0x87, 0xeb, 0xd2, 0xba, 0x1b, 0xaa, 0x70,
		0x37, 0xc0, 0xdd, 0x00, 0x77, 0x03, 0xc5, 0x9b, 0x52, 0x09, 0x90, 0x64, 0xc1, 0x97, 0x9e, 0x1f,
		0xd2, 0x93, 0xd4, 0x98, 0x09, 0xa2, 0xd5, 0x89, 0x0f, 0xfb, 0x23, 0x7b, 0x74, 0xfa, 0xdd, 0xe8,
		0xac, 0x0f, 0x8f, 0xa9, 0x17, 0xd7, 0x63, 0xf6, 0x91, 0x4b, 0x2e, 0x9d, 0x12, 0x4c, 0xbf, 0x24,
		0xd3, 0x2d, 0xd1, 0x8c, 0x49, 0x36, 0x63, 0x12, 0xce, 0x88, 0xa4, 0xd3, 0x64, 0xd4, 0x13, 0x53,
		0x3c, 0xb9, 0xc3, 0x75, 0xa9, 0xd0, 0xb2, 0xbd, 0xfe, 0xf3, 0x17, 0xe6, 0x6b, 0x1c, 0x0f, 0xdd,
		0xd0, 0xb0, 0xb4, 0x1e, 0x6f, 0xec, 0xf8, 0x4b, 0x0f, 0x93, 0x56, 0x74, 0x7b, 0x67, 0x0d, 0xb9,
		0xf4, 0x16, 0x5c, 0x7b, 0xba, 0xef, 0x63, 0xc0, 0xbd, 0xa7, 0x89, 0x87, 0x67, 0x8f, 0x5e, 0xa3,
		0x17, 0x37, 0xab, 0xa3, 0xd7, 0xe8, 0xd5, 0xcd, 0xe4, 0xf8, 0xb7, 0x8a, 0xb1, 0x6a, 0x5e, 0xe7,
		0x4c, 0x13, 0xb2, 0x8f, 0x15, 0xb0, 0xb6, 0xcf, 0x42, 0xfb, 0x2f, 0xf6, 0xaa, 0x0f, 0xb5, 0x4f,
		0xdd, 0x03, 0xf0, 0x1a, 0xf0, 0x1a, 0xf0, 0x1a, 0xf0, 0x9a, 0x90, 0xde, 0xfd, 0x5e, 0x3f, 0x74,
		0xbd, 0x27, 0xfb, 0xc5, 0x09, 0x82, 0x88, 0x7c, 0xf4, 0x61, 0x6c, 0xa2, 0x1c, 0xb3, 0xa2, 0x68,
		0x04, 0xfb, 0xab, 0x13, 0x7c, 0x25, 0xec, 0x75, 0xb0, 0x42, 0x31, 0x8c, 0x6f, 0x05, 0xfd, 0x00,
		0xfd, 0x00, 0xfd, 0x00, 0xfd, 0x40, 0x48, 0xef, 0x6d, 0xff, 0xf5, 0x25, 0x4c, 0xb4, 0x83, 0x1d,
		0x0e, 0x6f, 0x08, 0x15, 0xa1, 0xa6, 0x22, 0x22, 0x46, 0xb7, 0x9d, 0x4e, 0xc7, 0x67, 0x41, 0xa0,
		0x51, 0x3f, 0xcc, 0xde, 0x07, 0xca, 0x01, 0xca, 0x01, 0xca, 0x01, 0xca, 0x81, 0x90, 0xde, 0xdd,
		0x17, 0x4d, 0xd2, 0x65, 0x46, 0x27, 0x1c, 0x6b, 0x58, 0x3b, 0xde, 0x9b, 0xc2, 0xb9, 0xe6, 0x27,
		0x3b, 0xff, 0xed, 0x50, 0xe3, 0xde, 0x2f, 0xea, 0x65, 0x8d, 0xf7, 0xf8, 0xec, 0x84, 0x21, 0xf3,
		0x3d, 0x6d, 0xc7, 0x91, 0xdc, 0x68, 0x7b, 0xfb, 0x6e, 0xdf, 0x3e, 0x6e, 0xbd, 0xdd, 0x55, 0xed,
		0xe3, 0xd6, 0xe8, 0xc7, 0x6a, 0xf4, 0x6d, 0xf4, 0x73, 0xed, 0x6e, 0xdf, 0x3e, 0x1c, 0xff, 0x5c,
		0xbf, 0xdb, 0xb7, 0xeb, 0xad, 0x9d, 0xfb, 0xfb, 0x77, 0x3b, 0x3f, 0x0e, 0x06, 0xe2, 0x17, 0x5a,
		0xda, 0x5e, 0xa5, 0xa5, 0xf3, 0x28, 0xae, 0x6e, 0xce, 0xfe, 0x6d, 0xec, 0x3c, 0xfe, 0x34, 0x79,
		0x20, 0x3f, 0x69, 0x3c, 0x11, 0x3d, 0x1e, 0xf9, 0xdd, 0x02, 0x0b, 0xa7, 0x06, 0x84, 0x93, 0x94,
		0x70, 0x72, 0xec, 0xc7, 0xa6, 0xfd, 0x6b, 0xeb, 0x47, 0x75, 0xf7, 0x70, 0x70, 0xb2, 0xf3, 0xe3,
		0x68, 0x30, 0xff, 0xc7, 0xb7, 0x65, 0x1f, 0xab, 0xee, 0x1e, 0x0d, 0x4e, 0x52, 0xfe, 0xa5, 0x31,
		0x38, 0xe1, 0x5c, 0xa3, 0x3e, 0xd8, 0x5e, 0xf8, 0xe8, 0xf0, 0xef, 0xb5, 0xb4, 0x0b, 0x0e, 0x53,
		0x2e, 0x38, 0x48, 0xbb, 0xe0, 0x20, 0xe5, 0x82, 0xd4, 0x47, 0xaa, 0xa5, 0x5c, 0x50, 0x1f, 0xbc,
		0x2d, 0x7c, 0x7e, 0x7b, 0xf9, 0x47, 0x1b, 0x83, 0x9d, 0xb7, 0xb4, 0x7f, 0x3b, 0x1a, 0xbc, 0x9d,
		0xec, 0x40, 0x54, 0xf3, 0x8b, 0x6a, 0x90, 0xa7, 0x79, 0xf2, 0x2c, 0x9e, 0xe2, 0xda, 0x9c, 0x50,
		0x72, 0xae, 0xb2, 0x51, 0x89, 0x0b, 0x8c, 0x26, 0xfe, 0x2a, 0x2d, 0x85, 0x46, 0xa3, 0x22, 0x96,
		0x3d, 0xd2, 0x14, 0xf7, 0x8a, 0x9e, 0xc2, 0xa3, 0xdb, 0xe8, 0x51, 0x1f, 0x62, 0xd7, 0x54, 0x89,
		0x1a, 0x25, 0x8c, 0x8a, 0xbd, 0xc8, 0xcb, 0x16, 0xa8, 0x6a, 0xc8, 0x2a, 0x3a, 0xab, 0x16, 0x6a,
		0xa8, 0x5a, 0x28, 0x90, 0xff, 0x10, 0x55, 0x0b, 0xa8, 0x5a, 0x20, 0x5c, 0x1b, 0x55, 0x0b, 0x7a,
		0x25, 0x98, 0x7e, 0x49, 0xa6, 0x5b, 0xa2, 0x19, 0x93, 0x6c, 0xc6, 0x24, 0x9c, 0x11, 0x49, 0xa7,
		0xc7, 0x06, 0x40, 0xd5, 0xc2, 0x72, 0x11, 0x83, 0xaa, 0x85, 0xa9, 0x07, 0x47, 0xd5, 0x82, 0xf8,
		0x7d, 0x50, 0xb5, 0x90, 0xdb, 0xa3, 0x47, 0xd5, 0x02, 0x5c, 0x4d, 0x7a, 0xd8, 0x07, 0x55, 0x0b,
		0x80, 0xd7, 0x80, 0xd7, 0x80, 0xd7, 0x05, 0x86, 0xd7, 0xa8, 0x5a, 0x40, 0xd5, 0x02, 0xf4, 0x03,
		0xf4, 0x03, 0xf4, 0x03, 0xf4, 0xc3, 0x32, 0x7a, 0x47, 0xd5, 0x02, 0xbd, 0x8a, 0x40, 0xd5, 0x02,
		0x94, 0x03, 0x94, 0x03, 0x94, 0x43, 0xe1, 0x95, 0x03, 0xaa, 0x16, 0x96, 0x7e, 0xa1, 0x6a, 0x41,
		0x4c, 0x32, 0xa3, 0x6a, 0x41, 0xe4, 0x0b, 0x55, 0x0b, 0xa8, 0x5a, 0xc8, 0xbd, 0x70, 0x42, 0xd5,
		0x82, 0x9c, 0x70, 0x42, 0x5a, 0x38, 0xaa, 0x16, 0x72, 0x2c, 0xaa, 0x41, 0x9e, 0xa8, 0x5a, 0x30,
		0x6c, 0x15, 0x55, 0x50, 0xb5, 0xc0, 0x6b, 0xf1, 0x16, 0xb1, 0x6a, 0x81, 0x32, 0xc3, 0xbd, 0xa2,
		0xb5, 0x68, 0x81, 0x60, 0x68, 0x0a, 0x1d, 0xdd, 0x60, 0x00, 0x0f, 0x2f, 0x85, 0xe5, 0x73, 0x02,
		0xcf, 0x88, 0xa6, 0x32, 0x1b, 0xc1, 0xb3, 0x65, 0x90, 0x6a, 0xac, 0x7f, 0x45, 0xd9, 0x31, 0x96,
		0x9a, 0x41, 0x60, 0x9d, 0xbb, 0x41, 0xd8, 0x0c, 0x43, 0xb5, 0x84, 0x7b, 0xeb, 0xc2, 0xf5, 0x4e,
		0xbb, 0xec, 0x99, 0x79, 0xa3, 0x24, 0x2d, 0x85, 0x51, 0x44, 0x17, 0xce, 0xf7, 0xa9, 0x95, 0x68,
		0xc7, 0x99, 0x5b, 0x57, 0x7e, 0x87, 0xf9, 0xac, 0xf3, 0xcb, 0x70, 0xe3, 0xbc, 0x7e, 0xb7, 0x6b,
		0xf4, 0xbc, 0x88, 0xb8, 0x5b, 0x0f, 0x57, 0x2b, 0xb0, 0x33, 0x3d, 0x1b, 0xcb, 0xf1, 0xaf, 0x38,
		0xf7, 0x89, 0x5d, 0x21, 0x78, 0xee, 0xaa, 0xe7, 0x4d, 0x7c, 0xce, 0x12, 0x07, 0x4c, 0x78, 0xb0,
		0x62, 0x27, 0xca, 0x7f, 0x2e, 0x02, 0x67, 0x22, 0x59, 0x4b, 0xa8, 0x54, 0x33, 0x28, 0x59, 0x1b,
		0x28, 0x5d, 0x03, 0xa8, 0x12, 0x8d, 0x53, 0x8f, 0xb6, 0xa9, 0x46, 0xd3, 0xc8, 0xa2, 0x65, 0x64,
		0xd1, 0x30, 0x92, 0x68, 0x97, 0x5e, 0x29, 0x23, 0x5b, 0x2b, 0x67, 0xc5, 0x6c, 0x2d, 0x79, 0x54,
		0x63, 0x62, 0x89, 0x56, 0x91, 0x05, 0x30, 0x4a, 0xa1, 0x6e, 0xe5, 0x90, 0x36, 0x45, 0xe8, 0x9a,
		0x2e, 0x44, 0x4d, 0x15, 0x8a, 0x26, 0x0f, 0x39, 0x93, 0x87, 0x96, 0x49, 0x43, 0xc8, 0x66, 0x21,
		0xb7, 0x72, 0xe8, 0x77, 0x4a, 0x9b, 0xf8, 0xae, 0xa7, 0xd2, 0x55, 0x40, 0x31, 0xb5, 0x47, 0x02,
		0x2c, 0x49, 0x28, 0x84, 0x50, 0x65, 0xbf, 0x26, 0xd3, 0x44, 0xe5, 0x93, 0xa3, 0x20, 0x63, 0x20,
		0x63, 0x36, 0x56, 0xc6, 0xb8, 0x1d, 0xe6, 0x85, 0x6e, 0xf8, 0xea, 0xb3, 0x47, 0x0a, 0x41, 0xa3,
		0x62, 0x78, 0x9f, 0xc5, 0x8f, 0xf2, 0x8b, 0x13, 0x30, 0xba, 0x31, 0xc3, 0xcd, 0x66, 0xf3, 0xe1,
		0xe6, 0xf4, 0xfa, 0xf7, 0xd3, 0xeb, 0x87, 0xdb, 0x3f, 0x3e, 0x9f, 0xaa, 0x12, 0x61, 0x54, 0xd8,
		0x16, 0x90, 0x04, 0x7d, 0x88, 0xfb, 0x95, 0x5c, 0x37, 0x3f, 0x9e, 0xfd, 0x76, 0x63, 0xe5, 0xa1,
		0x25, 0x0b, 0xf1, 0x9b, 0xdd, 0x36, 0x3f, 0x34, 0x3f, 0xdc, 0x64, 0x3d, 0xa7, 0xb7, 0x65, 0x5a,
		0x36, 0xc0, 0x55, 0xb1, 0xd4, 0x55, 0x21, 0x19, 0xb4, 0x20, 0x71, 0x54, 0x88, 0x87, 0x21, 0x04,
		0xdc, 0x14, 0x5b, 0x84, 0xa7, 0x36, 0x76, 0xfc, 0x0a, 0x98, 0x5e, 0x72, 0x5e, 0x5e, 0x79, 0xaf,
		0x2e, 0xa9, 0x17, 0x57, 0xce, 0x6b, 0xcb, 0xbb, 0x99, 0x92, 0xa4, 0x4f, 0x44, 0xf2, 0x96, 0x90,
		0xff, 0x4a, 0x95, 0xc8, 0xf9, 0xc8, 0x7b, 0x3d, 0xb1, 0xae, 0xfe, 0xc4, 0x9a, 0x9d, 0x17, 0xdd,
		0x71, 0xf9, 0x9d, 0xe6, 0xd8, 0x5c, 0xc9, 0x4d, 0x5d, 0xbd, 0x91, 0xe9, 0xdb, 0xb3, 0x62, 0x6b,
		0x38, 0xdd, 0x93, 0x42, 0xee, 0x48, 0x4e, 0xf7, 0x23, 0xb7, 0xbb, 0x51, 0xc4, 0x9a, 0x11, 0xb7,
		0x5a, 0x44, 0xad, 0x13, 0x69, 0x2b, 0x44, 0xda, 0xda, 0x90, 0xb2, 0x2a, 0x72, 0xcc, 0x2c, 0x9c,
		0xea, 0x56, 0x84, 0x49, 0xd6, 0x6b, 0xd1, 0x15, 0xdc, 0xb1, 0x25, 0xb0, 0x43, 0xbc, 0x3b, 0x23,
		0xb2, 0x23, 0xd6, 0x4a, 0xf6, 0xe4, 0xdc, 0x83, 0xe5, 0x6f, 0xbf, 0xf8, 0x6e, 0x4b, 0xde, 0xcb,
		0x72, 0xba, 0x8e, 0xff, 0x9c, 0x5e, 0xba, 0x94, 0xf0, 0x54, 0xfc, 0xb9, 0x94, 0x9d, 0x59, 0xcd,
		0xf5, 0x6b, 0xb9, 0x9d, 0x87, 0xcb, 0x67, 0xb8, 0x7b, 0xd5, 0xc3, 0x88, 0x30, 0xb6, 0x30, 0x43,
		0x0b, 0x33, 0xf2, 0x02, 0x03, 0x8f, 0x1e, 0x9d, 0x88, 0x22, 0xd7, 0xb9, 0xe2, 0x47, 0xc7, 0xc6,
		0x2f, 0xe2, 0x47, 0x1f, 0x27, 0x16, 0xf1, 0xfb, 0x9a, 0x44, 0xfc, 0x3a, 0x22, 0x28, 0xb0, 0x94,
		0x5f, 0x43, 0x24, 0x34, 0x82, 0x9e, 0x37, 0x8e, 0x63, 0xb5, 0xc7, 0x27, 0xc9, 0xb9, 0x7f, 0x49,
		0xc5, 0xa9, 0x48, 0x1f, 0x5b, 0xc1, 0xc0, 0xa5, 0xb0, 0x9f, 0x54, 0xc6, 0x2f, 0x2a, 0x45, 0x6e,
		0xaa, 0xae, 0x4f, 0x65, 0x57, 0xa7, 0xb2, 0x6b, 0x53, 0x96, 0x1c, 0xf5, 0xd8, 0x9e, 0xda, 0xcd,
		0xa5, 0xe8, 0xed, 0x46, 0xdf, 0xc4, 0x5b, 0x2f, 0xf3, 0x6a, 0xe9, 0xe8, 0x26, 0xa3, 0x6f, 0x42,
		0x4d, 0x93, 0x39, 0x4c, 0x23, 0x0e, 0x09, 0xe8, 0x76, 0xc4, 0xb9, 0xd7, 0xed, 0x08, 0x72, 0xee,
		0x3e, 0x38, 0x17, 0x9c, 0xab, 0x14, 0x57, 0x48, 0x4e, 0xad, 0xcb, 0x9c, 0x47, 0xb1, 0x18, 0x42,
		0xa2, 0x3e, 0x8e, 0x04, 0xae, 0xf9, 0x1c, 0x0b, 0x87, 0x77, 0xef, 0x46, 0x96, 0xc9, 0x9e, 0xdb,
		0x31, 0xc9, 0x95, 0x62, 0xe9, 0x41, 0x52, 0x69, 0x41, 0xd2, 0x5a, 0xb5, 0x06, 0xde, 0x2c, 0x35,
		0x6f, 0x8a, 0x26, 0xf1, 0x88, 0xa8, 0x10, 0x79, 0x55, 0x22, 0xa9, 0x52, 0xa4, 0x55, 0x8b, 0x0a,
		0x19, 0x93, 0x90, 0xb3, 0x2a, 0x59, 0x93, 0x91, 0x37, 0x19, 0x99, 0x53, 0x91, 0xbb, 0x78, 0xc8,
		0xa3, 0x22, 0x11, 0x86, 0x92, 0x0e, 0x7d, 0xab, 0xa7, 0xd5, 0x48, 0xa6, 0xd3, 0xe8, 0xc9, 0x54,
		0xf5, 0x59, 0x20, 0x29, 0x57, 0x93, 0xf6, 0x73, 0xe3, 0x15, 0xc0, 0xe9, 0xe0, 0x74, 0x70, 0x7a,
		0x6e, 0x39, 0x3d, 0x60, 0xdf, 0x98, 0xef, 0x86, 0xaf, 0x0a, 0x69, 0xe9, 0xe3, 0x15, 0xc0, 0xe9,
		0xe0, 0xf4, 0x52, 0x72, 0xba, 0x5a, 0x1a, 0x9b, 0x4a, 0xfa, 0x1a, 0x4d, 0xda, 0x5a, 0xf2, 0x22,
		0x57, 0x9f, 0x4f, 0x2f, 0x3f, 0x5c, 0x5d, 0xfe, 0x7a, 0xf6, 0xe9, 0xa1, 0x79, 0xde, 0xbc, 0xbe,
		0x78, 0xb8, 0x39, 0xfd, 0xfd, 0xf4, 0xfa, 0xec, 0xf6, 0x0f, 0x59, 0x4a, 0x22, 0x48, 0x58, 0x23,
		0xca, 0xc4, 0xfb, 0xed, 0xf2, 0x5f, 0x97, 0x57, 0xff, 0x7b, 0xa9, 0x90, 0x63, 0xb9, 0x9b, 0xf5,
		0x2b, 0x5c, 0x9c, 0x5d, 0x5e, 0x5d, 0x17, 0xf9, 0x05, 0xfe, 0xb7, 0x79, 0x7d, 0x79, 0x76, 0xf9,
		0xa9, 0xc8, 0xaf, 0xf0, 0xe1, 0xfa, 0xec, 0xf6, 0xec, 0x43, 0xf3, 0xbc, 0xd0, 0x74, 0xd4, 0xfc,
		0xff, 0x2b, 0xd1, 0x91, 0xd4, 0x95, 0x2d, 0xdd, 0x52, 0x5f, 0x0b, 0xfa, 0x09, 0xd9, 0xf7, 0x50,
		0x1e, 0xf9, 0x44, 0x57, 0x03, 0xf5, 0x00, 0xf5, 0xc0, 0xbe, 0xc9, 0xad, 0x7d, 0x13, 0xba, 0xcf,
		0xcc, 0x6e, 0xfb, 0xcc, 0x09, 0x99, 0x82, 0xc7, 0x72, 0x66, 0x15, 0x70, 0x3c, 0x38, 0xbe, 0x94,
		0x1c, 0x3f, 0xa4, 0xf2, 0xd0, 0x6d, 0xff, 0x15, 0x34, 0x0e, 0x15, 0xd8, 0x5e, 0xa2, 0x69, 0x9f,
		0xf5, 0x9b, 0x37, 0x1a, 0xae, 0x64, 0x79, 0x8e, 0xd7, 0x0b, 0x58, 0xbb, 0xe7, 0x75, 0xa4, 0x48,
		0x4f, 0x6d, 0x32, 0x9b, 0x5a, 0xfb, 0x11, 0x82, 0xa2, 0x36, 0x92, 0xce, 0xdb, 0x54, 0x93, 0xd1,
		0x28, 0x47, 0x5f, 0x0d, 0xd4, 0xfa, 0xb1, 0xe4, 0x6e, 0x6b, 0x69, 0xbb, 0xc2, 0x90, 0xef, 0xb6,
		0xa1, 0x92, 0xa0, 0x56, 0x1e, 0xf4, 0xfb, 0xeb, 0x0b, 0xb3, 0x55, 0x82, 0x91, 0xe3, 0x05, 0xa0,
		0xd5, 0xa1, 0xd5, 0x4b, 0xa9, 0xd5, 0xfb, 0x9e, 0xdb, 0xf3, 0x54, 0x60, 0xbc, 0x44, 0x9b, 0x76,
		0xb5, 0x36, 0xec, 0x65, 0xe8, 0x6e, 0xb0, 0x9b, 0xd5, 0x9b, 0x97, 0xbe, 0xe6, 0x7a, 0xc1, 0x89,
		0x7d, 0xfb, 0xc7, 0xe7, 0xd3, 0x87, 0xb3, 0x8f, 0xe5, 0x2d, 0xbe, 0x3e, 0xbf, 0x2a, 0x65, 0xe5,
		0xf5, 0xd5, 0x6d, 0x29, 0x5f, 0xeb, 0xf4, 0xff, 0xf9, 0x7c, 0x5b, 0xc6, 0xf7, 0x6a, 0x9e, 0xa1,
		0x4a, 0x3e, 0x3b, 0x48, 0x5c, 0xdc, 0x1c, 0x7a, 0xd1, 0x9a, 0x7a, 0x99, 0x14, 0x7a, 0x81, 0xda,
		0x79, 0xdd, 0xc5, 0xc5, 0x71, 0x6d, 0xfc, 0x5a, 0x8b, 0x42, 0xac, 0x22, 0x5e, 0xbc, 0x12, 0x9e,
		0xa4, 0x02, 0x5e, 0xac, 0xf2, 0x3d, 0xb3, 0x52, 0xd2, 0x29, 0x72, 0x23, 0xac, 0x26, 0x9d, 0x22,
		0xb0, 0x82, 0x16, 0x94, 0xae, 0xad, 0x8b, 0x14, 0xd9, 0x09, 0x95, 0xb2, 0xd2, 0x76, 0xb7, 0xd7,
		0xfe, 0x6b, 0x7d, 0x55, 0xe9, 0xe8, 0x63, 0x8a, 0x45, 0xa5, 0xfb, 0x34, 0x45, 0xa5, 0xc1, 0x6b,
		0x31, 0x2b, 0x4a, 0x87, 0xcf, 0x6d, 0xaa, 0x9c, 0x94, 0xb3, 0x12, 0x50, 0xac, 0x02, 0x30, 0x2f,
		0x05, 0xa5, 0xab, 0x09, 0x40, 0xd6, 0x2f, 0x92, 0x7d, 0x35, 0xe9, 0x4a, 0x02, 0xa1, 0xd1, 0x81,
		0xdc, 0xa5, 0xa4, 0xa1, 0xfb, 0xcc, 0xfe, 0xee, 0x79, 0xcc, 0x16, 0xea, 0x05, 0x3a, 0x13, 0xb0,
		0x98, 0x5c, 0x5e, 0x8e, 0xf2, 0x34, 0x3e, 0xb2, 0x53, 0x75, 0xcb, 0xe5, 0xaf, 0xfe, 0x85, 0x8b,
		0x2c, 0xf5, 0xc0, 0x61, 0xf9, 0xc2, 0xb4, 0x19, 0x02, 0x14, 0x9d, 0xa1, 0x2b, 0xe8, 0x62, 0x2a,
		0x6a, 0x57, 0x9c, 0x48, 0xa9, 0xf3, 0x57, 0xd2, 0x72, 0x62, 0x92, 0x0f, 0xc3, 0x55, 0xb9, 0x4a,
		0x67, 0xd1, 0x0c, 0x07, 0x8a, 0x0d, 0x8a, 0x0d, 0x8a, 0x0d, 0x8a, 0x0d, 0x8a, 0x4d, 0x83, 0x62,
		0x23, 0xee, 0x61, 0x35, 0xd2, 0x6b, 0x05, 0xee, 0x62, 0xb5, 0xca, 0x86, 0x17, 0xdd, 0x07, 0x25,
		0x97, 0xc3, 0x6a, 0xdb, 0x94, 0xcf, 0x26, 0x85, 0xd3, 0x21, 0x7f, 0x4e, 0x87, 0x4e, 0xef, 0xd9,
		0x71, 0x3d, 0x3e, 0xc5, 0x9a, 0xec, 0xed, 0xf4, 0x45, 0x7c, 0x28, 0x6d, 0x1f, 0xee, 0x87, 0xa2,
		0xa2, 0x34, 0x6e, 0xb5, 0x27, 0x41, 0x1e, 0x15, 0xc1, 0xf9, 0xc4, 0xd6, 0x39, 0xf3, 0x9e, 0x22,
		0x99, 0xc9, 0x17, 0x56, 0x16, 0x6b, 0x8e, 0x2b, 0x01, 0x8f, 0xe4, 0xf2, 0x96, 0x92, 0xc4, 0x37,
		0xc1, 0xeb, 0x14, 0xb2, 0xda, 0x06, 0x62, 0xdd, 0x7e, 0x8d, 0x6f, 0x45, 0xad, 0x7e, 0x60, 0x70,
		0x33, 0x88, 0x90, 0x14, 0xc7, 0xe0, 0x62, 0xe1, 0xc9, 0xd8, 0xd6, 0xf6, 0xf6, 0xf6, 0xf6, 0x9d,
		0x63, 0xff, 0xdd, 0xb4, 0xff, 0xb3, 0x6f, 0x1f, 0x3f, 0xb4, 0xa6, 0x7e, 0xb9, 0xbf, 0xb7, 0x1f,
		0x5a, 0x3b, 0x3f, 0xf6, 0x77, 0x1b, 0xd5, 0xc1, 0xce, 0xcf, 0x93, 0xbf, 0xb7, 0xee, 0xef, 0xdf,
		0xed, 0xfc, 0x43, 0xe6, 0xaa, 0x9f, 0x77, 0xde, 0x86, 0xd7, 0x5a, 0x34, 0xaf, 0x2a, 0x33, 0x6b,
		0xd9, 0xfa, 0x33, 0x8b, 0x17, 0xe6, 0x98, 0x16, 0xdc, 0xd2, 0xe0, 0x07, 0xf9, 0xda, 0x0b, 0x42,
		0x31, 0x55, 0x9b, 0x5c, 0x01, 0x3d, 0x0b, 0x3d, 0x0b, 0x3d, 0x0b, 0x3d, 0x0b, 0x3d, 0x0b, 0x3d,
		0x0b, 0x3d, 0xbb, 0x46, 0xcf, 0x76, 0x7b, 0x4f, 0xae, 0x67, 0x7f, 0x71, 0x3c, 0x8f, 0xf9, 0xfc,
		0xba, 0x76, 0xe6, 0x2a, 0xe8, 0x5b, 0xe8, 0xdb, 0xb9, 0xfd, 0xe6, 0x4e, 0x83, 0xe7, 0x74, 0xd9,
		0xca, 0xd1, 0xf6, 0x73, 0x2f, 0xec, 0x08, 0x93, 0xf6, 0xf4, 0x45, 0xa0, 0x6c, 0x50, 0x76, 0x76,
		0x94, 0x9d, 0xad, 0x3b, 0x7d, 0x5d, 0xdc, 0x9c, 0xd7, 0x9f, 0xbe, 0x22, 0x52, 0xce, 0xe9, 0x50,
		0x7f, 0xe9, 0x73, 0x0c, 0x86, 0x88, 0x3e, 0x95, 0x8f, 0xb1, 0x10, 0x70, 0xa6, 0x73, 0x64, 0xf0,
		0xbd, 0xf4, 0x05, 0xd2, 0xf7, 0x5e, 0xfa, 0xc8, 0xdd, 0x43, 0x8a, 0x43, 0xfc, 0x41, 0xd7, 0xeb,
		0xb0, 0xef, 0x12, 0x7d, 0xe4, 0xa3, 0xcb, 0x90, 0xd2, 0x20, 0x62, 0x40, 0x23, 0xa5, 0x41, 0x1c,
		0x29, 0x2c, 0xda, 0x4a, 0x59, 0x35, 0x91, 0x8f, 0x08, 0x1e, 0x7d, 0xe4, 0xc1, 0x98, 0xa5, 0x66,
		0x4c, 0xe1, 0x0e, 0xf2, 0x5f, 0x1d, 0xbf, 0xf3, 0x5f, 0xc7, 0x67, 0xb6, 0xeb, 0x85, 0xcc, 0xf7,
		0xfb, 0x2f, 0x0a, 0x9d, 0xd8, 0x96, 0xac, 0x25, 0xd7, 0xcf, 0xa1, 0x5a, 0xb0, 0x7e, 0x0e, 0x62,
		0x84, 0xae, 0x4a, 0xf0, 0x64, 0x84, 0x4f, 0xc6, 0x00, 0x24, 0x8c, 0x20, 0xc6, 0x10, 0x12, 0x7e,
		0x73, 0x29, 0x06, 0x49, 0x2e, 0x74, 0xbe, 0x3d, 0xa9, 0xb7, 0x7e, 0x1d, 0x2e, 0x22, 0xb9, 0xb5,
		0x6a, 0xbd, 0x73, 0xa4, 0x59, 0x84, 0x82, 0x55, 0x96, 0xb1, 0x4c, 0xf8, 0xfa, 0xc2, 0x02, 0x95,
		0xd6, 0x08, 0x8a, 0xcc, 0x43, 0xce, 0x44, 0xe4, 0xcc, 0x94, 0xc6, 0x54, 0xa3, 0x9d, 0x33, 0x5d,
		0x83, 0x2d, 0x49, 0x35, 0xd2, 0x8d, 0x53, 0x16, 0x68, 0xe6, 0x85, 0xf9, 0x6d, 0xe6, 0x85, 0xce,
		0x13, 0x23, 0x68, 0xa8, 0xa1, 0xd2, 0x4f, 0x43, 0xad, 0xbb, 0xd9, 0xf8, 0x4b, 0xbd, 0x2d, 0x00,
		0x49, 0xb7, 0x33, 0x22, 0xf1, 0xb2, 0xb0, 0x1c, 0x51, 0xf7, 0xb3, 0x64, 0x3d, 0xc2, 0xbe, 0x5c,
		0x8a, 0x24, 0x3d, 0x7b, 0x04, 0x04, 0x5d, 0xd1, 0x74, 0x1f, 0x41, 0x75, 0x3f, 0xcf, 0x87, 0xb0,
		0x95, 0xcd, 0xd5, 0x2d, 0x43, 0x9d, 0x28, 0x24, 0x88, 0xcc, 0x72, 0xbd, 0x20, 0x74, 0xbc, 0x50,
		0x1d, 0x6d, 0x8c, 0x17, 0x02, 0xe2, 0x00, 0xe2, 0x00, 0xe2, 0x00, 0xe2, 0x00, 0xe2, 0x00, 0xe2,
		0x00, 0xe2, 0x00, 0xe2, 0x58, 0x82, 0x38, 0x42, 0xe6, 0x7f, 0x73, 0xba, 0x14, 0x90, 0x23, 0x5e,
		0x09, 0x98, 0x03, 0x98, 0x03, 0x98, 0x43, 0x98, 0x66, 0x82, 0xd0, 0x09, 0x6d, 0x45, 0x26, 0xaa,
		0xa8, 0xb5, 0x81, 0x4f, 0x96, 0x20, 0x6a, 0x07, 0x0f, 0x18, 0x03, 0x18, 0x53, 0x4c, 0x18, 0x43,
		0xde, 0x5e, 0x1e, 0xb8, 0xc6, 0x2c, 0xae, 0x79, 0x56, 0xa0, 0xb2, 0x49, 0x0a, 0xac, 0xf3, 0x1d,
		0x68, 0x06, 0x68, 0x06, 0x68, 0x06, 0x1e, 0x14, 0x40, 0x0f, 0x40, 0x0f, 0x78, 0x50, 0x80, 0x34,
		0x96, 0x22, 0x0d, 0x3b, 0x74, 0x9f, 0x19, 0x09, 0xdc, 0x18, 0xad, 0x04, 0xcc, 0x01, 0xcc, 0x01,
		0xcc, 0x21, 0x4c, 0x33, 0x6a, 0xe3, 0xf3, 0xe0, 0x3f, 0x01, 0x88, 0x01, 0x88, 0x81, 0xff, 0x04,
		0xa8, 0x26, 0x42, 0x35, 0x0a, 0x8c, 0x3e, 0x01, 0x34, 0xae, 0x07, 0x2c, 0x03, 0x2c, 0x03, 0x2c,
		0x03, 0xff, 0x09, 0xa0, 0x07, 0xa0, 0x07, 0xfc, 0x27, 0x40, 0x1a, 0x4b, 0x91, 0x06, 0x95, 0xff,
		0x64, 0xbc, 0x12, 0x30, 0x07, 0x30, 0x07, 0x30, 0x07, 0xfc, 0x27, 0x00, 0x31, 0x00, 0x31, 0xf0,
		0x9f, 0x00, 0xd5, 0xa8, 0xa2, 0x1a, 0xad, 0x65, 0xc9, 0x92, 0xb3, 0x60, 0x93, 0xeb, 0xb9, 0x1b,
		0x59, 0xbd, 0xf4, 0x83, 0xe1, 0x7f, 0xe2, 0xae, 0x18, 0xca, 0x15, 0xfb, 0x15, 0x81, 0xde, 0x57,
		0x2f, 0xfd, 0x60, 0xf8, 0x9f, 0xd1, 0x58, 0x8d, 0x87, 0x7f, 0xc6, 0xb7, 0x3e, 0x4b, 0xee, 0xac,
		0x6b, 0x68, 0xaf, 0x40, 0x0b, 0x0a, 0xb7, 0xd3, 0x65, 0xf2, 0xfd, 0x0f, 0xa2, 0xab, 0xd1, 0xf1,
		0x40, 0x1f, 0x98, 0x44, 0xc7, 0x03, 0x74, 0x3c, 0x80, 0x25, 0x06, 0x4b, 0x6c, 0x33, 0x2c, 0x31,
		0x78, 0x7f, 0x61, 0x38, 0xc1, 0x70, 0x92, 0x31, 0x9c, 0xe0, 0xfd, 0xcd, 0xd0, 0x4e, 0x42, 0xc7,
		0x03, 0x20, 0x0e, 0x20, 0x0e, 0x20, 0x0e, 0x20, 0x0e, 0x20, 0x0e, 0x20, 0x0e, 0x20, 0x8e, 0x9c,
		0x22, 0x0e, 0x74, 0x3c, 0x00, 0xe6, 0x00, 0xe6, 0x40, 0xc7, 0x83, 0xe9, 0x25, 0x10, 0x71, 0x06,
		0x8c, 0xd9, 0x68, 0x18, 0x83, 0x88, 0x73, 0xc1, 0x71, 0x0d, 0x3a, 0x1e, 0x00, 0xcd, 0x00, 0xcd,
		0xc0, 0x83, 0x02, 0xe8, 0x01, 0xe8, 0x01, 0x0f, 0x0a, 0x90, 0x86, 0x56, 0xa4, 0x81, 0x8e, 0x07,
		0xc0, 0x1c, 0xc0, 0x1c, 0xc8, 0xd8, 0x87, 0xff, 0x04, 0x20, 0x06, 0x20, 0x06, 0xfe, 0x93, 0x32,
		0xa0, 0x1a, 0x74, 0x3c, 0x00, 0x96, 0x01, 0x96, 0x81, 0xff, 0x04, 0xd0, 0x03, 0xd0, 0x03, 0xfe,
		0x13, 0x20, 0x0d, 0x9d, 0x48, 0x03, 0x1d, 0x0f, 0x80, 0x39, 0x80, 0x39, 0xe0, 0x3f, 0x81, 0xff,
		0x04, 0x20, 0x06, 0x20, 0x06, 0xfe, 0x93, 0xbc, 0xa1, 0x9a, 0x32, 0x76, 0x3c, 0x90, 0xa8, 0xd1,
		0xaf, 0x48, 0xf7, 0x38, 0x38, 0x1b, 0xde, 0x2c, 0x0f, 0x6d, 0x0d, 0xbc, 0x0e, 0xfb, 0xae, 0xd0,
		0xd7, 0x20, 0xba, 0x5c, 0xae, 0xb1, 0xc1, 0x3e, 0x1a, 0x1b, 0x98, 0xc4, 0x8a, 0x9b, 0xd4, 0xd8,
		0x40, 0x1a, 0x01, 0x26, 0xe7, 0xdd, 0xf7, 0x86, 0xe2, 0x47, 0xe2, 0xb8, 0xc7, 0x5d, 0x3b, 0x8e,
		0x25, 0xae, 0x8d, 0x1f, 0x5b, 0x0e, 0x93, 0x11, 0xc0, 0x5d, 0xe6, 0xf5, 0x9f, 0x99, 0x3f, 0x92,
		0xbc, 0xea, 0x70, 0xb7, 0x7a, 0xa8, 0xb0, 0xc6, 0xa9, 0xd7, 0x7f, 0x1e, 0x9e, 0xa0, 0x51, 0xcb,
		0x81, 0x60, 0x0b, 0xfb, 0xae, 0x17, 0x1e, 0xd4, 0x08, 0x76, 0xef, 0x08, 0xe0, 0x1e, 0xe0, 0x7e,
		0x43, 0xc0, 0xfd, 0x61, 0xed, 0xf8, 0xf0, 0xb8, 0x71, 0x54, 0x3b, 0x06, 0xa4, 0xcf, 0x0c, 0xd2,
		0xb7, 0x72, 0x00, 0x46, 0xff, 0x62, 0xbe, 0xc7, 0xba, 0xf2, 0x68, 0x34, 0xbe, 0x1e, 0x7d, 0xb6,
		0x00, 0x47, 0x73, 0x05, 0x47, 0xd1, 0x67, 0x0b, 0xfe, 0x7f, 0x2d, 0x4c, 0x44, 0xce, 0x4c, 0x69,
		0x4c, 0x85, 0x9c, 0x03, 0xe4, 0x1c, 0x00, 0xd1, 0x03, 0xd1, 0xf3, 0x1e, 0x01, 0x72, 0x0e, 0x32,
		0x84, 0xf2, 0xe8, 0xb3, 0x05, 0xc4, 0x01, 0xc4, 0x01, 0xc4, 0x01, 0xc4, 0x01, 0xc4, 0x01, 0xc4,
		0x01, 0xc4, 0x91, 0x57, 0xc4, 0x81, 0x3e, 0x5b, 0xc0, 0x1c, 0xc0, 0x1c, 0xe8, 0xb3, 0x35, 0xbd,
		0x04, 0xf2, 0x1c, 0x01, 0x63, 0x36, 0x1a, 0xc6, 0x20, 0xcf, 0xb1, 0xe0, 0xb8, 0x06, 0x7d, 0xb6,
		0x80, 0x66, 0x80, 0x66, 0xe0, 0x41, 0x01, 0xf4, 0x00, 0xf4, 0x80, 0x07, 0x05, 0x48, 0x43, 0x2b,
		0xd2, 0x40, 0x9f, 0x2d, 0x60, 0x0e, 0x60, 0x0e, 0xd4, 0x89, 0xc2, 0x7f, 0x02, 0x10, 0x03, 0x10,
		0x03, 0xff, 0x49, 0x19, 0x50, 0x0d, 0xfa, 0x6c, 0x01, 0xcb, 0x00, 0xcb, 0xc0, 0x7f, 0x02, 0xe8,
		0x01, 0xe8, 0x01, 0xff, 0x09, 0x90, 0x86, 0x4e, 0xa4, 0x81, 0x3e, 0x5b, 0xc0, 0x1c, 0xc0, 0x1c,
		0xf0, 0x9f, 0xc0, 0x7f, 0x02, 0x10, 0x03, 0x10, 0x03, 0xff, 0x49, 0xde, 0x50, 0x4d, 0x19, 0xfb,
		0x6c, 0x49, 0x55, 0xe9, 0x57, 0xa4, 0x3b, 0x6d, 0xfd, 0x6b, 0x74, 0xbb, 0x1c, 0xb4, 0x37, 0xf0,
		0x5c, 0x09, 0x4c, 0x93, 0xe8, 0xc8, 0xe8, 0x6a, 0xb4, 0x36, 0xd0, 0x87, 0x1a, 0xd1, 0xda, 0x00,
		0xad, 0x0d, 0x60, 0x72, 0xc1, 0xe4, 0xda, 0x0c, 0x93, 0x0b, 0x6e, 0x5e, 0x58, 0x48, 0xb0, 0x90,
		0x64, 0x2c, 0x24, 0xb8, 0x79, 0x33, 0x34, 0x88, 0xd0, 0xda, 0x00, 0x88, 0x03, 0x88, 0x03, 0x88,
		0x03, 0x88, 0x03, 0x88, 0x03, 0x88, 0x03, 0x88, 0x23, 0xa7, 0x88, 0x03, 0xad, 0x0d, 0x80, 0x39,
		0x80, 0x39, 0xd0, 0xda, 0x60, 0x7a, 0x09, 0x84, 0x96, 0x01, 0x63, 0x36, 0x1a, 0xc6, 0x20, 0xb4,
		0x5c, 0x70, 0x5c, 0x83, 0xd6, 0x06, 0x40, 0x33, 0x40, 0x33, 0xf0, 0xa0, 0x00, 0x7a, 0x00, 0x7a,
		0xc0, 0x83, 0x02, 0xa4, 0xa1, 0x15, 0x69, 0xa0, 0xb5, 0x01, 0x30, 0x07, 0x30, 0x07, 0x52, 0xf3,
		0xe1, 0x3f, 0x01, 0x88, 0x01, 0x88, 0x81, 0xff, 0xa4, 0x0c, 0xa8, 0x06, 0xad, 0x0d, 0x80, 0x65,
		0x80, 0x65, 0xe0, 0x3f, 0x01, 0xf4, 0x00, 0xf4, 0x80, 0xff, 0x04, 0x48, 0x43, 0x27, 0xd2, 0x40,
		0x6b, 0x03, 0x60, 0x0e, 0x60, 0x0e, 0xf8, 0x4f, 0xe0, 0x3f, 0x01, 0x88, 0x01, 0x88, 0x81, 0xff,
		0x24, 0x6f, 0xa8, 0xa6, 0x8c, 0xad, 0x0d, 0x24, 0x6a, 0xf4, 0x2b, 0xd2, 0x8d, 0x0d, 0x2e, 0x87,
		0x37, 0xcb, 0x41, 0x5b, 0x83, 0xa0, 0xf7, 0x18, 0xfe, 0xd7, 0xf1, 0xd9, 0x28, 0xcf, 0xd2, 0xef,
		0xbf, 0x84, 0xf2, 0x4d, 0x0e, 0x96, 0xac, 0x85, 0x96, 0x07, 0xfa, 0xd0, 0x24, 0x5a, 0x1e, 0xa0,
		0xe5, 0x01, 0x4c, 0x31, 0x98, 0x62, 0x9b, 0x61, 0x8a, 0xc1, 0xfd, 0x0b, 0xcb, 0x09, 0x96, 0x93,
		0x8c, 0xe5, 0x04, 0xf7, 0x6f, 0x86, 0x86, 0x12, 0x5a, 0x1e, 0x00, 0x71, 0x00, 0x71, 0x00, 0x71,
		0x00, 0x71, 0x00, 0x71, 0x00, 0x71, 0x00, 0x71, 0xe4, 0x14, 0x71, 0xa0, 0xe5, 0x01, 0x30, 0x07,
		0x30, 0x07, 0x5a, 0x1e, 0x4c, 0x2f, 0x81, 0x90, 0x33, 0x60, 0xcc, 0x46, 0xc3, 0x18, 0x84, 0x9c,
		0x0b, 0x8e, 0x6b, 0xd0, 0xf2, 0x00, 0x68, 0x06, 0x68, 0x06, 0x1e, 0x14, 0x40, 0x0f, 0x40, 0x0f,
		0x78, 0x50, 0x80, 0x34, 0xb4, 0x22, 0x0d, 0xb4, 0x3c, 0x00, 0xe6, 0x00, 0xe6, 0x40, 0xca, 0x3e,
		0xfc, 0x27, 0x00, 0x31, 0x00, 0x31, 0xf0, 0x9f, 0x94, 0x01, 0xd5, 0xa0, 0xe5, 0x01, 0xb0, 0x0c,
		0xb0, 0x0c, 0xfc, 0x27, 0x80, 0x1e, 0x80, 0x1e, 0xf0, 0x9f, 0x00, 0x69, 0xe8, 0x44, 0x1a, 0x68,
		0x79, 0x00, 0xcc, 0x01, 0xcc, 0x01, 0xff, 0x09, 0xfc, 0x27, 0x00, 0x31, 0x00, 0x31, 0xf0, 0x9f,
		0xe4, 0x0d, 0xd5, 0x94, 0xb1, 0xe5, 0x81, 0x72, 0xc5, 0x7e, 0x45, 0xba, 0x01, 0xc2, 0x4d, 0x7c,
		0xeb, 0xb3, 0xe4, 0xce, 0x39, 0xe8, 0x86, 0x10, 0xf6, 0x42, 0x89, 0x2c, 0xe8, 0x89, 0xee, 0x8c,
		0x2e, 0x47, 0xcf, 0x03, 0x7d, 0x70, 0x12, 0x3d, 0x0f, 0xd0, 0xf3, 0x00, 0xb6, 0x18, 0x6c, 0xb1,
		0xcd, 0xb0, 0xc5, 0xe0, 0xff, 0x85, 0xe9, 0x04, 0xd3, 0x49, 0xc6, 0x74, 0x82, 0xff, 0x37, 0x43,
		0x4b, 0x09, 0x3d, 0x0f, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38,
		0x80, 0x38, 0x72, 0x8a, 0x38, 0xd0, 0xf3, 0x00, 0x98, 0x03, 0x98, 0x03, 0x3d, 0x0f, 0xa6, 0x97,
		0x40, 0xcc, 0x19, 0x30, 0x66, 0xa3, 0x61, 0x0c, 0x62, 0xce, 0x05, 0xc7, 0x35, 0xe8, 0x79, 0x00,
		0x34, 0x03, 0x34, 0x03, 0x0f, 0x0a, 0xa0, 0x07, 0xa0, 0x07, 0x3c, 0x28, 0x40, 0x1a, 0x5a, 0x91,
		0x06, 0x7a, 0x1e, 0x00, 0x73, 0x00, 0x73, 0x20, 0x67, 0x1f, 0xfe, 0x13, 0x80, 0x18, 0x80, 0x18,
		0xf8, 0x4f, 0xca, 0x80, 0x6a, 0xd0, 0xf3, 0x00, 0x58, 0x06, 0x58, 0x06, 0xfe, 0x13, 0x40, 0x0f,
		0x40, 0x0f, 0xf8, 0x4f, 0x80, 0x34, 0x74, 0x22, 0x0d, 0xf4, 0x3c, 0x00, 0xe6, 0x00, 0xe6, 0x80,
		0xff, 0x04, 0xfe, 0x13, 0x80, 0x18, 0x80, 0x18, 0xf8, 0x4f, 0xf2, 0x86, 0x6a, 0xca, 0xd8, 0xf3,
		0x40, 0xa6, 0x48, 0xbf, 0x22, 0xdd, 0xe6, 0xe0, 0x36, 0xba, 0x5b, 0x0e, 0x5a, 0x1b, 0xf4, 0x03,
		0xe6, 0xcb, 0x77, 0x36, 0x88, 0xae, 0x46, 0x63, 0x03, 0x7d, 0x98, 0x11, 0x8d, 0x0d, 0xd0, 0xd8,
		0x00, 0x06, 0x17, 0x0c, 0xae, 0xcd, 0x30, 0xb8, 0xe0, 0xe4, 0x85, 0x7d, 0x04, 0xfb, 0x48, 0xc6,
		0x3e, 0x82, 0x93, 0x37, 0x43, 0x73, 0x08, 0x8d, 0x0d, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80,
		0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x72, 0x8a, 0x38, 0xd0, 0xd8, 0x00, 0x98, 0x03, 0x98,
		0x03, 0x8d, 0x0d, 0xa6, 0x97, 0x40, 0x60, 0x19, 0x30, 0x66, 0xa3, 0x61, 0x0c, 0x02, 0xcb, 0x05,
		0xc7, 0x35, 0x68, 0x6c, 0x00, 0x34, 0x03, 0x34, 0x03, 0x0f, 0x0a, 0xa0, 0x07, 0xa0, 0x07, 0x3c,
		0x28, 0x40, 0x1a, 0x5a, 0x91, 0x06, 0x1a, 0x1b, 0x00, 0x73, 0x00, 0x73, 0x20, 0x31, 0x1f, 0xfe,
		0x13, 0x80, 0x18, 0x80, 0x18, 0xf8, 0x4f, 0xca, 0x80, 0x6a, 0xd0, 0xd8, 0x00, 0x58, 0x06, 0x58,
		0x06, 0xfe, 0x13, 0x40, 0x0f, 0x40, 0x0f, 0xf8, 0x4f, 0x80, 0x34, 0x74, 0x22, 0x0d, 0x34, 0x36,
		0x00, 0xe6, 0x00, 0xe6, 0x80, 0xff, 0x04, 0xfe, 0x13, 0x80, 0x18, 0x80, 0x18, 0xf8, 0x4f, 0xf2,
		0x86, 0x6a, 0xca, 0xd8, 0xd8, 0x40, 0xa2, 0x46, 0xbf, 0x22, 0xdd, 0xd7, 0xe0, 0xb7, 0xe1, 0xcd,
		0x72, 0xd0, 0xd6, 0xe0, 0xbf, 0x8e, 0x1b, 0xca, 0xb7, 0x35, 0x88, 0xae, 0x46, 0x5b, 0x03, 0x7d,
		0x88, 0x11, 0x6d, 0x0d, 0xd0, 0xd6, 0x00, 0xe6, 0x16, 0xcc, 0xad, 0xcd, 0x30, 0xb7, 0xe0, 0xe2,
		0x85, 0x75, 0x04, 0xeb, 0x48, 0xc6, 0x3a, 0x82, 0x8b, 0x37, 0x43, 0x63, 0x08, 0x6d, 0x0d, 0x80,
		0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x80, 0x38, 0x72, 0x8a, 0x38,
		0xd0, 0xd6, 0x00, 0x98, 0x03, 0x98, 0x03, 0x6d, 0x0d, 0xa6, 0x97, 0x40, 0x58, 0x19, 0x30, 0x66,
		0xa3, 0x61, 0x0c, 0xc2, 0xca, 0x05, 0xc7, 0x35, 0x68, 0x6b, 0x00, 0x34, 0x03, 0x34, 0x03, 0x0f,
		0x0a, 0xa0, 0x07, 0xa0, 0x07, 0x3c, 0x28, 0x40, 0x1a, 0x5a, 0x91, 0x06, 0xda, 0x1a, 0x00, 0x73,
		0x00, 0x73, 0x20, 0x2d, 0x1f, 0xfe, 0x13, 0x80, 0x18, 0x80, 0x18, 0xf8, 0x4f, 0xca, 0x80, 0x6a,
		0xd0, 0xd6, 0x00, 0x58, 0x06, 0x58, 0x06, 0xfe, 0x13, 0x40, 0x0f, 0x40, 0x0f, 0xf8, 0x4f, 0x80,
		0x34, 0x74, 0x22, 0x0d, 0xb4, 0x35, 0x00, 0xe6, 0x00, 0xe6, 0x80, 0xff, 0x04, 0xfe, 0x13, 0x80,
		0x18, 0x80, 0x18, 0xf8, 0x4f, 0xf2, 0x86, 0x6a, 0xca, 0xd8, 0xd6, 0x40, 0xa2, 0x46, 0xbf, 0x22,
		0xdd, 0xd6, 0xe0, 0x7f, 0x87, 0x37, 0xd3, 0xd5, 0xd6, 0x60, 0x8b, 0xf0, 0x54, 0x64, 0x4f, 0x43,
		0xf2, 0x14, 0x04, 0x0e, 0x40, 0x6a, 0xe3, 0xf9, 0xf6, 0x7c, 0xfd, 0x0e, 0xae, 0xfe, 0xc4, 0x9a,
		0xbd, 0x1d, 0xe2, 0xbf, 0x51, 0x82, 0x78, 0x87, 0xad, 0x83, 0x7e, 0xd6, 0xb9, 0x1b, 0x84, 0xcd,
		0x30, 0xe4, 0xab, 0xd4, 0x1f, 0xaa, 0xd3, 0xd3, 0x2e, 0x1b, 0x22, 0xb7, 0x80, 0x4f, 0x0a, 0x0f,
		0xa5, 0xff, 0xd4, 0x15, 0x72, 0x72, 0xd6, 0xba, 0xf2, 0x3b, 0xcc, 0x67, 0x9d, 0x5f, 0x86, 0xaf,
		0xe5, 0xf5, 0xbb, 0x5d, 0xa5, 0xdd, 0x11, 0xa4, 0x38, 0x61, 0x4a, 0xe3, 0xa0, 0x31, 0x41, 0xda,
		0x5a, 0x4d, 0x55, 0xe9, 0xb4, 0xb2, 0xfc, 0x5f, 0x52, 0xf6, 0x87, 0x77, 0x5f, 0x84, 0xf6, 0x63,
		0xc5, 0x5e, 0x08, 0xec, 0xc1, 0xf2, 0xf7, 0x5f, 0x7c, 0xbb, 0x25, 0x6f, 0x66, 0x75, 0xbc, 0x20,
		0xf5, 0x75, 0x12, 0x20, 0x3e, 0xfc, 0x50, 0xca, 0xae, 0xac, 0x6e, 0x93, 0xb2, 0xd6, 0x06, 0xe5,
		0xb1, 0x31, 0xf9, 0xdb, 0x9b, 0xf0, 0x5a, 0x88, 0xc2, 0x16, 0xa0, 0xb0, 0x85, 0x27, 0xd4, 0x7e,
		0x44, 0x8c, 0x0e, 0xd7, 0xb5, 0x0d, 0xb1, 0xda, 0xe3, 0x3d, 0x5f, 0xb3, 0x09, 0xe3, 0x6d, 0x8d,
		0x3f, 0xbf, 0x4e, 0x68, 0x72, 0xf5, 0xc3, 0xe1, 0x76, 0x3a, 0x88, 0x38, 0x17, 0xc4, 0xfb, 0xdb,
		0x88, 0xba, 0x0a, 0xa4, 0x5d, 0x02, 0xd2, 0xa6, 0xbf, 0x54, 0x7f, 0x1a, 0x35, 0xb5, 0xc7, 0xdb,
		0x6f, 0xc6, 0x0a, 0x98, 0xe3, 0xb7, 0xbf, 0xf2, 0x6f, 0x5e, 0x52, 0x31, 0x32, 0xba, 0x8e, 0x73,
		0x03, 0xc4, 0x4c, 0x15, 0x61, 0x6f, 0x96, 0x8c, 0xf7, 0x4a, 0xbe, 0x91, 0x92, 0xac, 0x6f, 0x4a,
		0xd9, 0x17, 0xa5, 0xec, 0x7b, 0x52, 0x6a, 0x94, 0x44, 0x8b, 0x75, 0x85, 0x3d, 0x47, 0x13, 0x05,
		0xd5, 0x7b, 0x76, 0x5c, 0xcf, 0x8e, 0x94, 0xa5, 0xc0, 0xa1, 0x8d, 0x65, 0x9a, 0x80, 0x6b, 0xc8,
		0x3a, 0x67, 0xde, 0x53, 0xa4, 0xda, 0xc5, 0x7c, 0x37, 0x12, 0x86, 0x94, 0x8a, 0x6f, 0x46, 0xd5,
		0x77, 0x9c, 0x18, 0xfe, 0x92, 0xd7, 0x13, 0x58, 0xf5, 0x32, 0xbe, 0x7b, 0x15, 0x5f, 0x0a, 0xd5,
		0x96, 0xd5, 0xea, 0x07, 0x19, 0x6e, 0x9a, 0x26, 0xa3, 0xb6, 0x25, 0xc0, 0x21, 0x9f, 0x9d, 0x30,
		0x64, 0xbe, 0x27, 0xcc, 0x22, 0xd6, 0xf6, 0xf6, 0xf6, 0xf6, 0x9d, 0x63, 0xff, 0xdd, 0xb4, 0xff,
		0xb3, 0x6f, 0x1f, 0x3f, 0xb4, 0xa6, 0x7e, 0xb9, 0xbf, 0xb7, 0x1f, 0x5a, 0x3b, 0x3f, 0xf6, 0x77,
		0x1b, 0xd5, 0xc1, 0xce, 0xcf, 0x93, 0xbf, 0xb7, 0xee, 0xef, 0xdf, 0xed, 0xfc, 0x43, 0xe6, 0xaa,
		0x9f, 0x77, 0xde, 0x86, 0xd7, 0x5a, 0x7a, 0xb6, 0xe0, 0xea, 0xe6, 0xec, 0xdf, 0xd2, 0xfb, 0xf0,
		0x67, 0x16, 0x1b, 0xf1, 0x93, 0xc0, 0x4e, 0x90, 0x4a, 0x7d, 0x21, 0x0b, 0x5b, 0xde, 0xd2, 0x26,
		0xb5, 0xb8, 0x97, 0x5a, 0xde, 0x92, 0xcd, 0x29, 0x25, 0xfa, 0x79, 0xaa, 0x44, 0xc2, 0xa6, 0x11,
		0x47, 0x6f, 0xf4, 0xf4, 0xf6, 0x97, 0x57, 0x19, 0xcf, 0x1b, 0x45, 0xd4, 0x6b, 0x06, 0x7d, 0xf4,
		0x75, 0x36, 0x1b, 0xcd, 0x85, 0xe7, 0x49, 0x97, 0x6f, 0xa5, 0xe3, 0x05, 0x7b, 0x5c, 0x66, 0x9c,
		0x80, 0x67, 0xe1, 0xa3, 0x17, 0x3c, 0xc4, 0xa0, 0x5b, 0xd6, 0xbf, 0xb2, 0xc2, 0x52, 0xff, 0xda,
		0x0b, 0x42, 0x9b, 0x79, 0xa1, 0xef, 0xb2, 0x80, 0xdf, 0x54, 0x9d, 0xb9, 0x0a, 0x06, 0x2b, 0x0c,
		0xd6, 0x39, 0x62, 0x7a, 0x15, 0x37, 0x5a, 0xa7, 0xae, 0x15, 0x33, 0x5c, 0xab, 0x30, 0x5c, 0x61,
		0xb8, 0x8a, 0x11, 0xaa, 0xa8, 0x8b, 0x4e, 0xcd, 0x65, 0xa7, 0x48, 0xb8, 0xd2, 0x04, 0xac, 0x42,
		0xc8, 0xea, 0x04, 0x4d, 0x81, 0x91, 0x2a, 0x68, 0x69, 0x2d, 0x65, 0x83, 0x2b, 0xb4, 0xb4, 0xee,
		0xba, 0x4e, 0x40, 0xd0, 0xd4, 0x3a, 0x5a, 0x06, 0xe9, 0x76, 0xf2, 0x6c, 0x43, 0xc5, 0x3e, 0xe4,
		0x6c, 0x44, 0xce, 0x4e, 0xa4, 0x6c, 0x25, 0xc7, 0x5e, 0x0a, 0xae, 0xae, 0x0a, 0x75, 0xb3, 0x27,
		0xdf, 0xf5, 0x9e, 0x08, 0xb2, 0xec, 0xaa, 0xef, 0x8d, 0xee, 0x80, 0x94, 0xf3, 0x80, 0xce, 0x99,
		0xa0, 0xd5, 0xb9, 0xb0, 0xd2, 0xd9, 0xb0, 0x36, 0xcc, 0x4f, 0x47, 0xa1, 0x32, 0x8e, 0xd8, 0x21,
		0xaa, 0x8e, 0x0d, 0x4c, 0x45, 0x91, 0x9e, 0xac, 0x04, 0xa9, 0x0e, 0xa9, 0x0e, 0xa9, 0x5e, 0x2c,
		0xa9, 0x6e, 0xa6, 0x65, 0xe8, 0xcb, 0xb7, 0x43, 0xdb, 0xe9, 0x74, 0x7c, 0x16, 0x10, 0x40, 0xc8,
		0x99, 0xd5, 0x20, 0x73, 0x20, 0x73, 0x20, 0x73, 0x4c, 0xf3, 0x4f, 0x45, 0x32, 0x36, 0xbf, 0xc8,
		0x07, 0x92, 0x11, 0xb8, 0x85, 0x85, 0xb6, 0xb7, 0xef, 0xf6, 0xed, 0xe3, 0xd6, 0xdb, 0x5d, 0xd5,
		0x3e, 0x6e, 0x8d, 0x7e, 0xac, 0x46, 0xdf, 0x46, 0x3f, 0xd7, 0xee, 0xf6, 0xed, 0xc3, 0xf1, 0xcf,
		0xf5, 0xbb, 0x7d, 0xbb, 0xde, 0xda, 0xb9, 0xbf, 0x7f, 0xb7, 0xf3, 0xe3, 0x60, 0x20, 0x7e, 0xa1,
		0x3c, 0xc9, 0xb4, 0x54, 0xb6, 0x4a, 0x25, 0x62, 0xb9, 0xb0, 0xda, 0x9f, 0x26, 0x37, 0xec, 0x27,
		0xcb, 0x74, 0xc6, 0x3e, 0x8c, 0x95, 0x52, 0x19, 0x2b, 0xee, 0xcb, 0xb7, 0x06, 0x29, 0x80, 0x68,
		0x00, 0x40, 0x00, 0x40, 0x00, 0x40, 0x64, 0xc6, 0x3f, 0x79, 0x05, 0x10, 0x8e, 0xfd, 0xd8, 0xb4,
		0x7f, 0x6d, 0xfd, 0xa8, 0xee, 0x1e, 0x0e, 0x4e, 0x76, 0x7e, 0x1c, 0x0d, 0xe6, 0xff, 0xf8, 0xb6,
		0xec, 0x63, 0xd5, 0xdd, 0xa3, 0xc1, 0x49, 0xca, 0xbf, 0x34, 0x06, 0x27, 0x9c, 0x6b, 0xd4, 0x07,
		0xdb, 0x0b, 0x1f, 0x1d, 0xfe, 0xbd, 0x96, 0x76, 0xc1, 0x61, 0xca, 0x05, 0x07, 0x69, 0x17, 0x1c,
		0xa4, 0x5c, 0x90, 0xfa, 0x48, 0xb5, 0x94, 0x0b, 0xea, 0x83, 0xb7, 0x85, 0xcf, 0x6f, 0x2f, 0xff,
		0x68, 0x63, 0xb0, 0xf3, 0x96, 0xf6, 0x6f, 0x47, 0x83, 0xb7, 0x93, 0x9d, 0x32, 0xc1, 0x29, 0x90,
		0x8f, 0x79, 0xf2, 0x01, 0xb8, 0x04, 0xb8, 0x94, 0xbc, 0x22, 0xaf, 0x85, 0xb7, 0x1d, 0x2f, 0xd8,
		0x9b, 0x4e, 0xa4, 0x9a, 0xfc, 0xf2, 0xba, 0x27, 0x95, 0x58, 0x50, 0x11, 0x4b, 0x2a, 0xfb, 0x67,
		0x2f, 0x08, 0x4f, 0x47, 0xb7, 0x4e, 0x7e, 0x7e, 0xe5, 0x4a, 0x35, 0x93, 0x3f, 0x0f, 0x91, 0x59,
		0xe3, 0xd2, 0xb1, 0x0b, 0xd5, 0x98, 0x85, 0x24, 0xec, 0x47, 0x82, 0x06, 0x12, 0x34, 0xb4, 0xc3,
		0xf4, 0xe4, 0xbc, 0xbb, 0xcc, 0x79, 0xf4, 0xd9, 0xa3, 0xcc, 0x81, 0x8f, 0x11, 0xf9, 0x91, 0xc4,
		0xb5, 0x9f, 0x63, 0xb1, 0xf6, 0xee, 0x5d, 0x2c, 0xa3, 0xf6, 0x12, 0x26, 0xcb, 0x81, 0xc8, 0x18,
		0x15, 0xcf, 0x4b, 0xcb, 0x0b, 0xd1, 0xda, 0xfb, 0x0a, 0x45, 0x36, 0x57, 0x0d, 0xc2, 0x02, 0xc2,
		0x62, 0xe5, 0x13, 0x22, 0x9b, 0x0b, 0x2e, 0x34, 0xb8, 0xd0, 0x0a, 0xe8, 0x42, 0x43, 0x36, 0x17,
		0x6c, 0x58, 0xc2, 0xb3, 0x41, 0x36, 0x17, 0xa4, 0x3a, 0xa4, 0x3a, 0xa4, 0x3a, 0xb2, 0xb9, 0x20,
		0x73, 0x20, 0x73, 0x36, 0x4a, 0xe6, 0x20, 0x9b, 0x0b, 0xd9, 0x5c, 0xc8, 0xe6, 0x82, 0xb1, 0x82,
		0x6c, 0x2e, 0x00, 0x08, 0x00, 0x08, 0x00, 0x88, 0x2c, 0xf8, 0xa7, 0x82, 0x6c, 0x2e, 0xa4, 0xe3,
		0x20, 0x9b, 0x0b, 0xe4, 0x83, 0x6c, 0x2e, 0x80, 0x4b, 0x4a, 0x70, 0x59, 0xfa, 0x6c, 0x2e, 0x99,
		0xbc, 0x82, 0x0a, 0x45, 0x32, 0x97, 0x40, 0xb3, 0x7f, 0xf1, 0xd3, 0xa0, 0xed, 0xdd, 0x13, 0x0f,
		0x03, 0x10, 0x0c, 0x4c, 0x94, 0xa7, 0x6b, 0x21, 0x37, 0xc3, 0xe5, 0x65, 0x62, 0xc5, 0x0a, 0x82,
		0xa7, 0x1f, 0x5f, 0x91, 0x4a, 0xe2, 0x56, 0xe9, 0xfb, 0x09, 0x0a, 0xf4, 0xda, 0x93, 0xdf, 0x50,
		0x1d, 0xad, 0x05, 0x03, 0xe6, 0x7f, 0x63, 0xbe, 0x40, 0x57, 0xc1, 0xf1, 0x05, 0x68, 0x28, 0x88,
		0x86, 0x82, 0xd3, 0x24, 0x24, 0xd3, 0x01, 0x3f, 0xba, 0x0e, 0x8d, 0x04, 0x0d, 0xfa, 0x71, 0x36,
		0xba, 0x91, 0xa0, 0xac, 0x9f, 0x73, 0x92, 0x63, 0x27, 0xe5, 0x9a, 0x41, 0xa6, 0x7a, 0x26, 0xae,
		0x4a, 0x64, 0xaa, 0x8b, 0x9c, 0x77, 0x6e, 0x32, 0xd5, 0xc7, 0x3c, 0x96, 0x83, 0x44, 0x75, 0x34,
		0x1e, 0x85, 0xb4, 0x28, 0xa3, 0xb4, 0x90, 0x4f, 0x55, 0xa7, 0x0a, 0x14, 0x22, 0x46, 0x88, 0x18,
		0x61, 0x46, 0xac, 0x25, 0xef, 0x02, 0xad, 0xe4, 0x24, 0x46, 0x48, 0x19, 0x21, 0x3c, 0x56, 0x58,
		0x23, 0x7e, 0xa7, 0xcc, 0xc7, 0x72, 0x13, 0xa7, 0x5f, 0x2d, 0xec, 0xd1, 0x7b, 0x82, 0xb5, 0xa8,
		0xe2, 0x61, 0xc9, 0x82, 0xc5, 0x48, 0xcb, 0x1a, 0x7f, 0xb5, 0x28, 0xb6, 0x90, 0x32, 0xae, 0x98,
		0xac, 0x5a, 0x94, 0x74, 0xad, 0x64, 0x27, 0xd5, 0xc6, 0x75, 0xef, 0xe6, 0x88, 0x59, 0x1b, 0x1b,
		0xc6, 0xac, 0x88, 0x61, 0x17, 0x29, 0x05, 0xa2, 0x30, 0xa2, 0x0b, 0x64, 0x55, 0xa8, 0xd4, 0x08,
		0x22, 0x41, 0x6e, 0x3a, 0x35, 0xc3, 0x48, 0x36, 0xea, 0x4b, 0xcf, 0x0f, 0xd5, 0x8d, 0xcb, 0x68,
		0x15, 0x49, 0x9c, 0xfe, 0x91, 0x3d, 0x3a, 0xfd, 0x6e, 0x64, 0x60, 0xd4, 0x0f, 0x60, 0x9e, 0xc2,
		0x3c, 0x85, 0x79, 0x2a, 0xce, 0x7c, 0xb6, 0xd7, 0x7f, 0xfe, 0x22, 0x3c, 0xa7, 0x71, 0x19, 0x0b,
		0x35, 0x14, 0x96, 0xb8, 0x76, 0xbc, 0xa7, 0x5c, 0xd8, 0xa7, 0x2a, 0xa3, 0x89, 0x89, 0x65, 0xcb,
		0xc2, 0x72, 0xe3, 0x39, 0xbc, 0x54, 0xeb, 0x11, 0x4c, 0xe5, 0x25, 0xb6, 0x59, 0x2a, 0xaa, 0xa3,
		0x8e, 0x4d, 0x1d, 0x41, 0xa3, 0x5e, 0x3f, 0xa8, 0xe7, 0xf8, 0x18, 0xca, 0x8e, 0x57, 0x4a, 0x93,
		0xe0, 0x18, 0x67, 0xe8, 0xc4, 0xdf, 0x8d, 0x74, 0xa9, 0xbb, 0x19, 0xdd, 0x32, 0xfe, 0x9e, 0xa3,
		0xf6, 0x74, 0xe8, 0x35, 0xa5, 0x19, 0xe6, 0x21, 0x80, 0x97, 0x81, 0x34, 0x41, 0x00, 0x0f, 0x16,
		0x12, 0x2c, 0x24, 0x04, 0xf0, 0x10, 0xc0, 0xe3, 0xda, 0x23, 0x04, 0xf0, 0x10, 0xc0, 0x43, 0x00,
		0xaf, 0x82, 0x00, 0x9e, 0x22, 0xb3, 0x22, 0xd2, 0x82, 0x00, 0x1e, 0x02, 0x78, 0x08, 0xe0, 0x91,
		0x08, 0x72, 0x04, 0xf0, 0x52, 0x55, 0x0b, 0x02, 0x78, 0x30, 0x4f, 0x61, 0x9e, 0x66, 0x64, 0x9e,
		0x22, 0x80, 0xb7, 0xf0, 0x20, 0x08, 0xe0, 0x55, 0x32, 0xb4, 0x59, 0x2a, 0x08, 0xe0, 0x21, 0x80,
		0x97, 0xb9, 0xcb, 0x3d, 0xc3, 0x00, 0x9e, 0x81, 0xc6, 0x24, 0x73, 0xf1, 0xbb, 0xe2, 0x75, 0x24,
		0x11, 0x73, 0x44, 0x94, 0xa7, 0x21, 0x89, 0x64, 0x5c, 0xb3, 0x1f, 0x08, 0x6b, 0x77, 0x15, 0x18,
		0x38, 0x0d, 0xfd, 0x7a, 0xa3, 0xa7, 0xb7, 0xbf, 0xbc, 0xca, 0x90, 0x34, 0x05, 0xe4, 0x9b, 0x81,
		0x79, 0xd1, 0x4e, 0x14, 0x82, 0xd2, 0x4d, 0xb4, 0x8a, 0x99, 0x95, 0x3c, 0x7a, 0x3a, 0xc4, 0xcc,
		0xca, 0x9a, 0xf2, 0xb7, 0x86, 0xe1, 0x6b, 0x98, 0x22, 0xb7, 0x89, 0x5a, 0x3a, 0xc2, 0x70, 0xa5,
		0x4c, 0x08, 0xa5, 0x48, 0x08, 0x77, 0x83, 0xa9, 0xa1, 0x1b, 0x0c, 0xb9, 0xa1, 0x6a, 0xac, 0x1b,
		0x8c, 0xe3, 0xb7, 0xbf, 0xca, 0x74, 0x83, 0x89, 0xae, 0x13, 0xeb, 0x06, 0xb3, 0x8f, 0x6e, 0x30,
		0xe8, 0x06, 0x23, 0xe9, 0x01, 0x49, 0xce, 0xab, 0xd3, 0x7b, 0x76, 0x5c, 0xcf, 0x16, 0x9c, 0xb4,
		0x23, 0x13, 0xb0, 0xb2, 0xce, 0x99, 0xf7, 0x14, 0xe9, 0x0c, 0x31, 0x9f, 0x86, 0x04, 0xe2, 0x52,
		0xf1, 0x59, 0xa8, 0xfa, 0x3f, 0xc7, 0x06, 0x71, 0x55, 0xf2, 0x7a, 0x02, 0xe3, 0x57, 0xc6, 0x79,
		0xad, 0xe2, 0x63, 0xa0, 0xda, 0xb2, 0x5a, 0xfd, 0x20, 0xc3, 0x4d, 0xd3, 0x84, 0x83, 0x05, 0x22,
		0x70, 0xd2, 0xa1, 0x5b, 0x6b, 0x7b, 0x7b, 0x7b, 0xfb, 0xce, 0xb1, 0xff, 0x6e, 0xda, 0xff, 0xd9,
		0xb7, 0x8f, 0x1f, 0x5a, 0x53, 0xbf, 0xdc, 0xdf, 0xdb, 0x0f, 0xad, 0x9d, 0x1f, 0xfb, 0xbb, 0x8d,
		0xea, 0x60, 0xe7, 0xe7, 0xc9, 0xdf, 0x5b, 0xf7, 0xf7, 0xef, 0x76, 0xfe, 0x21, 0x73, 0xd5, 0xcf,
		0x3b, 0x6f, 0xc3, 0x6b, 0x2d, 0x3d, 0x5b, 0xa0, 0x12, 0x6c, 0xb4, 0xfe, 0xcc, 0x62, 0x23, 0x04,
		0xc2, 0x69, 0x2d, 0x52, 0xa9, 0x0f, 0x43, 0x1e, 0x86, 0x7c, 0x6e, 0x0c, 0xf9, 0x22, 0x1b, 0xa9,
		0x9c, 0x3e, 0x46, 0x11, 0x13, 0x75, 0xbd, 0x13, 0x71, 0x85, 0x81, 0xba, 0x25, 0xb0, 0x43, 0xbc,
		0x3b, 0x23, 0xb2, 0x23, 0xd6, 0x4a, 0x0b, 0x99, 0x73, 0x0f, 0x96, 0xbf, 0xfd, 0xe2, 0xbb, 0x2d,
		0x79, 0x2f, 0xeb, 0xc9, 0x7f, 0x69, 0xdb, 0x6b, 0x5a, 0x6b, 0x26, 0x62, 0x60, 0xfa, 0xc3, 0x29,
		0x7b, 0xb4, 0xda, 0x04, 0x5f, 0x6b, 0x21, 0xf1, 0x58, 0x44, 0x73, 0x16, 0x90, 0xfd, 0xfc, 0xf4,
		0xbc, 0x2a, 0x8e, 0xcf, 0x2b, 0x88, 0x84, 0xcd, 0x1c, 0x61, 0xe1, 0xb2, 0xc4, 0x8c, 0x19, 0x3d,
		0x3c, 0x11, 0x7d, 0xae, 0x33, 0x9e, 0x79, 0x3b, 0xcd, 0x89, 0x75, 0x96, 0xcb, 0x51, 0x0f, 0xde,
		0x75, 0xa4, 0x50, 0x68, 0xd7, 0xcb, 0x1a, 0x52, 0x31, 0xec, 0x7f, 0x69, 0x33, 0x3f, 0x74, 0x1f,
		0xdd, 0xb6, 0x13, 0x32, 0xdb, 0xed, 0x88, 0xfb, 0x61, 0xe6, 0xae, 0x2f, 0x8d, 0x3f, 0x86, 0x97,
		0x04, 0x4b, 0xe9, 0x94, 0xe1, 0x24, 0xd1, 0xbc, 0x79, 0x66, 0x84, 0x87, 0xb8, 0x0a, 0x0e, 0x6d,
		0xe5, 0x40, 0x6c, 0x1c, 0x32, 0x8b, 0x79, 0xce, 0x97, 0x2e, 0x13, 0xe7, 0xb4, 0xf8, 0x3a, 0xde,
		0x6e, 0xc7, 0x93, 0xc4, 0xb6, 0x21, 0x49, 0x80, 0x31, 0xc1, 0x98, 0xd9, 0x31, 0xe6, 0x97, 0x5e,
		0xaf, 0xcb, 0x1c, 0x4f, 0x86, 0x33, 0xab, 0x06, 0x39, 0xb3, 0xeb, 0x06, 0x21, 0xf3, 0xc6, 0x55,
		0x0a, 0x2c, 0x10, 0xe7, 0xd1, 0x85, 0x15, 0xc0, 0x76, 0x60, 0xbb, 0xcc, 0xd8, 0xae, 0xef, 0x0d,
		0x4d, 0x5c, 0x09, 0xa6, 0x13, 0xa8, 0x12, 0x94, 0xab, 0x0a, 0x54, 0x28, 0x3d, 0x57, 0xaa, 0x87,
		0x54, 0xa9, 0x83, 0x54, 0xab, 0x7f, 0xc4, 0xbc, 0xe8, 0x34, 0x3f, 0x3c, 0xe6, 0x45, 0x0b, 0xfa,
		0xeb, 0x31, 0x2f, 0x5a, 0x0f, 0x73, 0x61, 0x96, 0x2a, 0x0a, 0xc6, 0x30, 0x4b, 0x75, 0x41, 0xd4,
		0x80, 0x7c, 0x36, 0x61, 0x96, 0xea, 0x96, 0xde, 0xfb, 0x08, 0x0a, 0x76, 0x05, 0x7c, 0xc8, 0xbc,
		0xfe, 0x33, 0xf3, 0x47, 0xd1, 0x1d, 0x05, 0x80, 0x78, 0x28, 0x71, 0xed, 0xa9, 0xd7, 0x7f, 0x1e,
		0x22, 0x75, 0x6d, 0x89, 0x11, 0x88, 0x85, 0x8f, 0x17, 0x93, 0x9b, 0xb2, 0x49, 0xe2, 0x25, 0x78,
		0x66, 0xa1, 0xd3, 0x71, 0x42, 0xc7, 0x76, 0xfa, 0xe1, 0x57, 0xe6, 0x85, 0x6e, 0x5b, 0x2c, 0xcb,
		0x3a, 0xa1, 0xd4, 0xb4, 0x85, 0xc4, 0x3d, 0x7c, 0x8f, 0x4e, 0x37, 0x80, 0x8b, 0x0f, 0xbe, 0x06,
		0xb8, 0xf8, 0xd6, 0xdd, 0x53, 0xa8, 0xe2, 0x5c, 0xa6, 0xc2, 0x7c, 0x9a, 0x2d, 0x8f, 0x0f, 0x0e,
		0x8e, 0xc1, 0x95, 0xe0, 0xca, 0xec, 0xb8, 0x52, 0xae, 0x3a, 0x5b, 0xa2, 0x1a, 0x5b, 0xb2, 0xfa,
		0xba, 0xa0, 0x99, 0xca, 0xfb, 0xc8, 0x54, 0x16, 0xdd, 0x32, 0x85, 0x6a, 0xe7, 0x5c, 0xe7, 0x2a,
		0x1b, 0xd4, 0x5d, 0xa1, 0xef, 0x78, 0x41, 0xc4, 0xd1, 0x01, 0x6b, 0xf7, 0x7d, 0x37, 0x7c, 0x15,
		0xd7, 0x64, 0x4b, 0xd6, 0x40, 0x40, 0x19, 0x7a, 0x0d, 0x68, 0x53, 0x9c, 0x63, 0x73, 0x99, 0x9c,
		0x3b, 0x95, 0xd9, 0xc9, 0xdf, 0xc9, 0x9b, 0x33, 0x43, 0xf5, 0x93, 0xff, 0xd2, 0x16, 0xe8, 0xd8,
		0x8d, 0x72, 0x52, 0x24, 0x36, 0xd2, 0x33, 0x0e, 0x12, 0x1b, 0xa1, 0xee, 0x36, 0x4e, 0xdd, 0x21,
		0xb1, 0x11, 0x38, 0x14, 0x8c, 0x09, 0x1c, 0x2a, 0xcb, 0x99, 0x48, 0x6c, 0x04, 0xdb, 0x21, 0xb1,
		0x11, 0x89, 0x8d, 0x94, 0x6f, 0x2a, 0xff, 0xc6, 0x4b, 0xde, 0x1c, 0x89, 0x8d, 0x48, 0x6c, 0x44,
		0x62, 0xa3, 0x2e, 0xe6, 0x42, 0x62, 0x23, 0x32, 0xd3, 0x90, 0xd8, 0xb8, 0x20, 0x6a, 0x40, 0x3e,
		0x48, 0x6c, 0x54, 0xbe, 0x0f, 0x12, 0x1b, 0x09, 0xb6, 0x1e, 0x89, 0x8d, 0xc9, 0x62, 0x48, 0x6c,
		0x44, 0x62, 0x23, 0x7c, 0x0d, 0x70, 0xf1, 0x89, 0x32, 0x2f, 0x12, 0x1b, 0xc1, 0x95, 0x1b, 0xc4,
		0x95, 0x48, 0x6c, 0x54, 0xe1, 0xb2, 0x85, 0xcb, 0x91, 0xd8, 0x28, 0xbd, 0x65, 0x48, 0x6c, 0x54,
		0xd6, 0x5d, 0x48, 0x6c, 0x84, 0x5e, 0x83, 0x5e, 0x43, 0x62, 0x23, 0x6f, 0x62, 0x23, 0x71, 0xf7,
		0xd1, 0xa9, 0xbc, 0xc6, 0x02, 0x37, 0x21, 0x5d, 0xdf, 0xd3, 0x53, 0x6a, 0x4b, 0x54, 0x7a, 0x92,
		0x76, 0xdd, 0x36, 0xf3, 0x02, 0xb6, 0xbe, 0x1f, 0xe9, 0xf8, 0x83, 0xf9, 0xe8, 0x45, 0xba, 0xfa,
		0x69, 0x2a, 0xb9, 0x6e, 0x45, 0x3a, 0x7e, 0x76, 0x53, 0x9d, 0x48, 0xe3, 0xfb, 0x05, 0xfc, 0x19,
		0xbb, 0xc9, 0x15, 0xc5, 0xe8, 0x46, 0xba, 0x9e, 0x18, 0x64, 0xd5, 0x67, 0xf6, 0x39, 0xbb, 0x6b,
		0x89, 0x85, 0x46, 0x25, 0x70, 0xa7, 0xec, 0xae, 0x93, 0x17, 0x92, 0xf2, 0x43, 0x92, 0xb4, 0x32,
		0x83, 0x6e, 0x62, 0x6f, 0x53, 0x2e, 0xe4, 0xc6, 0x4d, 0x92, 0x7a, 0x80, 0x1b, 0x2f, 0xa9, 0x26,
		0x17, 0x70, 0x76, 0x62, 0x4e, 0x3d, 0x6e, 0xee, 0x1a, 0x0d, 0x05, 0x02, 0x96, 0x26, 0x64, 0x15,
		0x82, 0xa6, 0x21, 0x6c, 0x55, 0x02, 0x27, 0x23, 0x74, 0x32, 0x82, 0x27, 0x23, 0x7c, 0x49, 0x07,
		0x80, 0xe0, 0xc9, 0x8b, 0x32, 0x44, 0x72, 0xa1, 0xd3, 0x0e, 0xdd, 0x6f, 0x4c, 0x7d, 0xb8, 0x7b,
		0xbc, 0x8e, 0xfa, 0x78, 0x77, 0x91, 0x50, 0x12, 0xb5, 0xaf, 0x28, 0x6f, 0x13, 0xde, 0xe5, 0x19,
		0x91, 0x8a, 0x21, 0xc9, 0x19, 0x93, 0x9c, 0x41, 0xc9, 0x19, 0x55, 0x8e, 0x61, 0x15, 0xdc, 0xa3,
		0x15, 0xda, 0x49, 0xef, 0xe2, 0xae, 0x09, 0x45, 0x57, 0x85, 0xfa, 0xc6, 0xc9, 0xf8, 0x94, 0xe3,
		0xf3, 0xb5, 0x3b, 0x4e, 0xe8, 0xa8, 0x8b, 0xaf, 0x99, 0xd5, 0x20, 0x7c, 0x20, 0x7c, 0x20, 0x7c,
		0xa4, 0xe8, 0x46, 0x34, 0xe3, 0x3f, 0x55, 0xf4, 0x1c, 0x2b, 0xac, 0xa1, 0x94, 0x27, 0x3f, 0xfe,
		0xfa, 0xa1, 0x3c, 0x99, 0x7f, 0x22, 0x91, 0x5d, 0xcf, 0xf1, 0x5f, 0x15, 0x69, 0x76, 0x7a, 0x77,
		0x8e, 0xd5, 0x66, 0xfe, 0xef, 0xe6, 0x65, 0x63, 0x84, 0xeb, 0x25, 0xd7, 0x92, 0xcd, 0x7b, 0xb5,
		0x9d, 0xc9, 0x7d, 0xd2, 0xa3, 0x8a, 0xa6, 0x14, 0xa8, 0xae, 0x5e, 0xab, 0x27, 0xb9, 0x2b, 0xad,
		0xa1, 0x25, 0xa1, 0x25, 0xa1, 0x25, 0xa9, 0xe5, 0x9e, 0xa2, 0xbc, 0x1b, 0xe4, 0xcc, 0x7b, 0x21,
		0x18, 0x8c, 0x5c, 0xb8, 0x9e, 0x37, 0xf6, 0x16, 0x13, 0xdc, 0xf8, 0x7b, 0x90, 0xfc, 0x41, 0xca,
		0xbd, 0x57, 0xe1, 0x8f, 0xd3, 0x9d, 0x8f, 0xee, 0x33, 0xfe, 0x1e, 0x24, 0x7f, 0xe0, 0x69, 0xd0,
		0x22, 0x7f, 0x16, 0x02, 0xe7, 0xa0, 0xa2, 0x25, 0xd4, 0xb5, 0x83, 0xa4, 0x56, 0x80, 0xa7, 0x14,
		0x9e, 0x52, 0x51, 0x59, 0x23, 0x2d, 0xc5, 0x27, 0x54, 0xce, 0x9c, 0x47, 0x9f, 0x3d, 0xaa, 0x14,
		0x77, 0x1c, 0x49, 0x5c, 0xfb, 0x39, 0x16, 0x6f, 0xef, 0xde, 0xc5, 0xe2, 0x6a, 0x6f, 0x8a, 0xdd,
		0x72, 0x20, 0x40, 0xf8, 0x3a, 0x42, 0xad, 0xd0, 0x89, 0x7c, 0xc9, 0x22, 0x4b, 0xf7, 0x53, 0x56,
		0x6c, 0xd4, 0x20, 0x36, 0x20, 0x36, 0xb8, 0x9e, 0x12, 0x01, 0x16, 0x58, 0x6f, 0xb0, 0xde, 0x60,
		0xbd, 0x6d, 0x4e, 0x80, 0xa5, 0xc3, 0x82, 0xb6, 0xef, 0xbe, 0x48, 0x5b, 0x65, 0x33, 0x7b, 0x36,
		0xbd, 0x18, 0x44, 0x0f, 0x44, 0x0f, 0x44, 0xcf, 0xa6, 0x38, 0x8e, 0x24, 0x24, 0x0f, 0xfb, 0xfe,
		0xe2, 0x8e, 0x0a, 0xe8, 0xed, 0x8e, 0x8c, 0x4d, 0xb1, 0xb0, 0x6d, 0xf3, 0x0b, 0x42, 0x02, 0x41,
		0x02, 0x41, 0x02, 0x49, 0xd1, 0x4d, 0xdf, 0xf5, 0xc2, 0xc6, 0x21, 0x81, 0x04, 0x52, 0xe9, 0x4f,
		0x24, 0x57, 0xeb, 0x39, 0xff, 0x45, 0x10, 0xc8, 0x54, 0xa9, 0x05, 0x25, 0x16, 0x2f, 0x0b, 0xcb,
		0x29, 0xd6, 0x8a, 0x2e, 0xac, 0x47, 0x50, 0x04, 0x49, 0x44, 0xce, 0xb3, 0x47, 0xe0, 0x7c, 0xcf,
		0xfd, 0x11, 0xa8, 0xf5, 0x1a, 0x31, 0x7e, 0x2a, 0x88, 0xa1, 0x2f, 0x87, 0x24, 0xac, 0x43, 0x04,
		0x45, 0x18, 0xa2, 0xe7, 0x80, 0x20, 0x80, 0x20, 0xf0, 0xbf, 0xac, 0x7a, 0x46, 0xd7, 0xb3, 0xfb,
		0x01, 0x81, 0xf1, 0x13, 0xaf, 0x03, 0x81, 0x03, 0x81, 0x03, 0x81, 0x03, 0x81, 0xb3, 0x42, 0xe0,
		0x04, 0x41, 0x9f, 0x11, 0x79, 0x5c, 0xa6, 0xd6, 0x82, 0xe0, 0x81, 0xe0, 0x81, 0xe0, 0x81, 0xb3,
		0x05, 0xce, 0x16, 0x38, 0x5b, 0xe0, 0x6c, 0x81, 0xb3, 0x65, 0xfd, 0x36, 0xa3, 0xb4, 0x0f, 0x60,
		0x04, 0x60, 0x24, 0x77, 0x60, 0x04, 0xa5, 0x7d, 0x4b, 0x4c, 0x43, 0x94, 0xf6, 0x2d, 0xdf, 0x18,
		0x94, 0xf6, 0x99, 0xd4, 0x94, 0x28, 0xed, 0x83, 0x96, 0x84, 0x96, 0x44, 0x86, 0x96, 0x29, 0xb9,
		0xf3, 0xcd, 0xe9, 0x52, 0x88, 0x9c, 0xd1, 0x32, 0x90, 0x36, 0x90, 0x36, 0x90, 0x36, 0x72, 0xf0,
		0xb3, 0x80, 0x91, 0x89, 0x72, 0x57, 0x12, 0xcb, 0x94, 0xb1, 0x55, 0x08, 0x0a, 0x89, 0x39, 0x3a,
		0x22, 0xcb, 0x9f, 0x04, 0x6d, 0xf3, 0xc6, 0x7f, 0xb1, 0x57, 0x29, 0xbc, 0xb9, 0x89, 0x03, 0xa3,
		0x78, 0x1b, 0xc6, 0xca, 0x91, 0xbd, 0x32, 0xb9, 0x5b, 0x42, 0xf5, 0xa1, 0x2a, 0x04, 0x6e, 0x95,
		0xba, 0x6b, 0xfa, 0xfc, 0xfe, 0xd2, 0x35, 0x4d, 0x9f, 0xdf, 0xcf, 0x62, 0x36, 0x4d, 0xe7, 0x68,
		0xf5, 0x2d, 0xb4, 0x1d, 0x4a, 0xdd, 0xd2, 0x7b, 0x4f, 0x4f, 0x43, 0x88, 0xbf, 0xbe, 0x5b, 0x7a,
		0xfc, 0xc1, 0x9c, 0x74, 0x4b, 0xef, 0x3d, 0x15, 0xb3, 0x53, 0x7a, 0xef, 0xc9, 0x58, 0x97, 0xf4,
		0x76, 0xcf, 0x0b, 0x7a, 0x5d, 0xc6, 0xdf, 0x24, 0x7d, 0x7c, 0x41, 0x41, 0x7a, 0xa4, 0xf7, 0x9e,
		0xca, 0xd9, 0x1f, 0xbd, 0xf7, 0x94, 0x9b, 0xde, 0xe8, 0x82, 0x8d, 0xa6, 0xe5, 0x1a, 0x4c, 0xe7,
		0xbe, 0x33, 0x7a, 0xef, 0x69, 0x33, 0xbb, 0xa2, 0xf7, 0x9e, 0xb2, 0xea, 0x88, 0xae, 0x1d, 0x01,
		0x8e, 0x94, 0xd9, 0x5e, 0x2c, 0xf1, 0xc4, 0x3b, 0x26, 0xf1, 0x2a, 0xe8, 0xd1, 0x7d, 0x1e, 0x3e,
		0x8c, 0xee, 0x23, 0xd4, 0x20, 0x89, 0x66, 0xca, 0x55, 0xc0, 0xba, 0xac, 0x1d, 0xf6, 0xfc, 0x40,
		0x9c, 0x89, 0x27, 0x97, 0x82, 0x8f, 0xc1, 0xc7, 0x52, 0x7c, 0x2c, 0x3c, 0xd9, 0x60, 0x4c, 0x73,
		0x0a, 0x9d, 0x77, 0xc6, 0x2b, 0x6c, 0xc8, 0x74, 0x83, 0xde, 0x13, 0x1a, 0xef, 0xa8, 0x12, 0xbd,
		0x19, 0x6f, 0x9e, 0x74, 0xd3, 0x1d, 0xc9, 0x71, 0x1f, 0x6a, 0xa8, 0x8c, 0x88, 0x41, 0xf2, 0x1b,
		0xa1, 0xe8, 0x3d, 0x21, 0x3a, 0x61, 0x8a, 0xb1, 0xb2, 0x89, 0x4c, 0xc8, 0x32, 0x5c, 0xb2, 0xc0,
		0xa3, 0xd3, 0x76, 0xbb, 0x22, 0x83, 0x41, 0xd7, 0x12, 0x5e, 0xb2, 0xa2, 0xe2, 0xa1, 0xd0, 0x64,
		0x9b, 0x2a, 0x33, 0x25, 0x25, 0x73, 0xd2, 0x33, 0x29, 0x35, 0xb3, 0x6a, 0x63, 0x5a, 0x6d, 0xcc,
		0xab, 0x85, 0x89, 0xd5, 0x98, 0x59, 0x91, 0xa9, 0x93, 0x37, 0x52, 0x0e, 0x3b, 0x2e, 0xd0, 0x9b,
		0xdb, 0x61, 0x5e, 0xe8, 0x86, 0xaf, 0x72, 0xdd, 0x30, 0x53, 0xf5, 0x25, 0x41, 0xba, 0xb6, 0x75,
		0x16, 0x3f, 0xda, 0x2f, 0x4e, 0x40, 0x48, 0xc6, 0xe3, 0x17, 0xbf, 0xf9, 0xe3, 0xe6, 0xfc, 0xea,
		0xd3, 0xc3, 0xaf, 0xcd, 0x0f, 0x67, 0xe7, 0x67, 0xb7, 0x7f, 0x58, 0x94, 0x29, 0xec, 0x81, 0x72,
		0x7e, 0xe3, 0xf4, 0xd7, 0x0f, 0xb2, 0x95, 0x66, 0x36, 0xe0, 0xf2, 0xf6, 0xb3, 0x45, 0xb6, 0xf2,
		0x60, 0x37, 0xef, 0xaf, 0xfb, 0xe1, 0xea, 0xf2, 0xe6, 0xea, 0xfc, 0x74, 0x93, 0x5e, 0xf9, 0xfc,
		0xea, 0x43, 0xf3, 0xfc, 0x60, 0x93, 0xde, 0xb8, 0xf9, 0xdb, 0xed, 0x3f, 0x37, 0xe9, 0x7d, 0x47,
		0x42, 0x6c, 0x93, 0xde, 0xf8, 0x5f, 0xa7, 0xd7, 0x97, 0xa7, 0xe7, 0x1b, 0xc7, 0xc5, 0xd5, 0x8d,
		0xe2, 0xe2, 0xf3, 0xcd, 0x3b, 0xe0, 0xda, 0xc6, 0xbd, 0x71, 0x7d, 0xb3, 0x14, 0xd3, 0xc7, 0xb3,
		0xdb, 0x8d, 0x3b, 0xe2, 0xa3, 0x4d, 0xc3, 0x1e, 0x9f, 0xaf, 0xcf, 0x7e, 0xdf, 0xa4, 0x77, 0xbe,
		0x68, 0x9e, 0x6d, 0x9e, 0xa8, 0xde, 0xdf, 0x30, 0x84, 0x79, 0x7b, 0x7a, 0xf1, 0xf0, 0xb1, 0x79,
		0x7a, 0x71, 0x75, 0xb9, 0x71, 0x47, 0xdd, 0xd8, 0xa4, 0x37, 0xfe, 0xed, 0xe6, 0xf4, 0x7a, 0xe3,
		0x4e, 0xf8, 0x90, 0xf0, 0x8d, 0x49, 0x56, 0x6a, 0x15, 0xb6, 0x1f, 0x81, 0xc2, 0x89, 0x5b, 0x01,
		0xfb, 0xc6, 0x7c, 0xd2, 0xa0, 0x43, 0xb2, 0x22, 0x82, 0x0e, 0x6b, 0xf7, 0x0a, 0x41, 0x07, 0x04,
		0x1d, 0xd2, 0xdf, 0x88, 0x3e, 0xe8, 0x10, 0xbc, 0x06, 0xdd, 0xde, 0x93, 0x4d, 0xc4, 0xa2, 0xd3,
		0x6c, 0x5a, 0x3d, 0x24, 0x58, 0xeb, 0xd4, 0xeb, 0x3f, 0x0f, 0x5f, 0x38, 0x33, 0x41, 0x6a, 0x34,
		0x60, 0xac, 0x58, 0x6f, 0x35, 0x11, 0xe1, 0x92, 0x69, 0x88, 0x49, 0xc6, 0x5d, 0xf2, 0xd3, 0x9e,
		0x52, 0xce, 0x46, 0x45, 0x3e, 0x53, 0xf1, 0x66, 0xfc, 0x28, 0xc9, 0x4f, 0x52, 0xd3, 0x1d, 0xe5,
		0xcf, 0x51, 0xa6, 0x90, 0x57, 0x39, 0x5e, 0x4f, 0x15, 0xa7, 0x2f, 0x5d, 0x39, 0x2f, 0x92, 0x65,
		0xcc, 0xab, 0xbc, 0xa2, 0x96, 0xf1, 0xca, 0x4f, 0x94, 0x5c, 0x50, 0x61, 0x47, 0x0a, 0x6b, 0x2c,
		0x4e, 0x98, 0x4c, 0x98, 0x3a, 0xc7, 0x22, 0x4c, 0x19, 0xfd, 0x53, 0xa1, 0x7e, 0x88, 0x30, 0x88,
		0x30, 0x88, 0xb0, 0xbc, 0x89, 0xb0, 0x84, 0xa9, 0xf3, 0x2c, 0xc2, 0x42, 0x92, 0xa6, 0xcb, 0xb2,
		0xbd, 0x07, 0x2a, 0x94, 0xc9, 0xca, 0x35, 0x08, 0x2f, 0x08, 0x2f, 0x23, 0xc2, 0x0b, 0xc9, 0xca,
		0xf0, 0x1b, 0xc2, 0x6f, 0x08, 0xbf, 0x21, 0x27, 0xbd, 0x21, 0x59, 0x19, 0xc9, 0xca, 0x04, 0x5f,
		0x48, 0x56, 0xce, 0xe1, 0x2b, 0x23, 0x59, 0xb9, 0xec, 0xef, 0x8b, 0x64, 0xe5, 0x0d, 0xe1, 0x62,
		0x24, 0x2b, 0x97, 0xfc, 0x80, 0x91, 0xac, 0x5c, 0x72, 0xc5, 0x84, 0x64, 0xe5, 0x0d, 0xc0, 0x1e,
		0x48, 0x56, 0xde, 0x00, 0xaa, 0x46, 0xb2, 0xf2, 0xc6, 0x1c, 0x35, 0x92, 0x95, 0xcb, 0x7e, 0xc2,
		0x48, 0x56, 0x26, 0xbb, 0x1a, 0xc9, 0xca, 0x2b, 0x96, 0x41, 0xd0, 0x41, 0x6e, 0xf7, 0x11, 0x74,
		0x40, 0xb2, 0xb2, 0x00, 0x9b, 0x22, 0x59, 0x59, 0x9c, 0x60, 0xf3, 0x97, 0xac, 0xac, 0x92, 0xb2,
		0x51, 0x21, 0xcd, 0x55, 0x96, 0x18, 0x20, 0x21, 0x7f, 0x8a, 0x7a, 0xdb, 0x06, 0xc6, 0x03, 0x26,
		0xc6, 0xc1, 0xf8, 0x8a, 0x24, 0xf7, 0xc9, 0xcd, 0x9b, 0x48, 0xae, 0x96, 0x9e, 0x3b, 0x31, 0x59,
		0x81, 0x70, 0xfe, 0x44, 0xb2, 0xa8, 0xd4, 0x1c, 0x0a, 0xd9, 0x93, 0x30, 0x36, 0x8e, 0x65, 0x2d,
		0xa7, 0x69, 0x1c, 0xc9, 0xb2, 0x96, 0xb7, 0x8a, 0x31, 0x96, 0xc5, 0x74, 0x07, 0x69, 0xd1, 0x66,
		0xc9, 0x14, 0x47, 0x62, 0xb4, 0x8f, 0xb4, 0x50, 0x52, 0x9f, 0x54, 0x12, 0x9f, 0x74, 0xff, 0xe8,
		0x1a, 0xfa, 0x47, 0x53, 0x42, 0xe4, 0x0d, 0xee, 0x03, 0x2f, 0x0a, 0x60, 0x64, 0x39, 0x98, 0x1f,
		0x9d, 0x14, 0x76, 0x06, 0xd0, 0xec, 0xce, 0x12, 0x8e, 0x00, 0x9a, 0xdd, 0x4b, 0xe9, 0x09, 0x40,
		0x2b, 0xa6, 0xc7, 0xf8, 0xec, 0xb9, 0x17, 0x32, 0x3b, 0x60, 0xfe, 0x37, 0xc6, 0xd1, 0x38, 0x3f,
		0x91, 0x11, 0x73, 0xd7, 0x61, 0x8c, 0x0a, 0xc6, 0xa8, 0x2c, 0x21, 0x28, 0x71, 0x25, 0x3a, 0x7b,
		0x39, 0x86, 0x31, 0x40, 0x99, 0x4a, 0x29, 0x53, 0xe1, 0x61, 0x0c, 0x92, 0x7d, 0xe7, 0xd5, 0xfa,
		0xcd, 0x63, 0x10, 0x43, 0x26, 0x8e, 0x56, 0x0c, 0x62, 0xe0, 0xb8, 0xf0, 0x6b, 0x2f, 0x08, 0xd5,
		0x0b, 0x9b, 0xa2, 0x55, 0x50, 0x94, 0x89, 0xba, 0x26, 0xc3, 0x4c, 0x95, 0x8d, 0x9b, 0x9a, 0xae,
		0x28, 0x53, 0x81, 0x6f, 0x66, 0x14, 0xcb, 0xb1, 0xc2, 0x1a, 0xf1, 0xdb, 0xa8, 0x15, 0x09, 0x50,
		0x96, 0x81, 0xbc, 0xd8, 0x4e, 0xa7, 0xe3, 0xb3, 0x20, 0xa0, 0x0c, 0xc6, 0x1c, 0x13, 0xac, 0x45,
		0xb2, 0x53, 0x74, 0x3b, 0xb6, 0x64, 0xe7, 0xbe, 0x1d, 0x12, 0xee, 0xdd, 0xc2, 0x1e, 0xbe, 0x27,
		0x5c, 0xf3, 0xb3, 0x13, 0x86, 0xcc, 0xf7, 0x48, 0xab, 0x53, 0xa2, 0x85, 0xb7, 0xb7, 0xef, 0xf6,
		0xed, 0xe3, 0xd6, 0xdb, 0x5d, 0xd5, 0x3e, 0x6e, 0x8d, 0x7e, 0xac, 0x46, 0xdf, 0x46, 0x3f, 0xd7,
		0xee, 0xf6, 0xed, 0xc3, 0xf1, 0xcf, 0xf5, 0xbb, 0x7d, 0xbb, 0xde, 0xda, 0xb9, 0xbf, 0x7f, 0xb7,
		0xf3, 0xe3, 0x60, 0x20, 0x7e, 0x21, 0x5d, 0xc2, 0x46, 0x8b, 0x72, 0x6b, 0xaf, 0x6e, 0xce, 0xfe,
		0xad, 0x6d, 0x7f, 0xff, 0x34, 0xb9, 0xc1, 0x3f, 0x11, 0xee, 0x30, 0xc9, 0x4a, 0x44, 0xa9, 0x44,
		0x7a, 0x98, 0xbf, 0x01, 0xe6, 0x8f, 0x48, 0xcc, 0xb1, 0x1f, 0x9b, 0xf6, 0xaf, 0xad, 0x1f, 0xd5,
		0xdd, 0xc3, 0xc1, 0xc9, 0xce, 0x8f, 0xa3, 0xc1, 0xfc, 0x1f, 0xdf, 0x96, 0x7d, 0xac, 0xba, 0x7b,
		0x34, 0x38, 0x49, 0xf9, 0x97, 0xc6, 0xe0, 0x84, 0x73, 0x8d, 0xfa, 0x60, 0x7b, 0xe1, 0xa3, 0xc3,
		0xbf, 0xd7, 0xd2, 0x2e, 0x38, 0x4c, 0xb9, 0xe0, 0x20, 0xed, 0x82, 0x83, 0x94, 0x0b, 0x52, 0x1f,
		0xa9, 0x96, 0x72, 0x41, 0x7d, 0xf0, 0xb6, 0xf0, 0xf9, 0xed, 0xe5, 0x1f, 0x6d, 0x0c, 0x76, 0xde,
		0xd2, 0xfe, 0xed, 0x68, 0xf0, 0x76, 0xb2, 0xb3, 0xc9, 0xa2, 0x10, 0xe4, 0x66, 0x9e, 0xdc, 0xf2,
		0xa7, 0x18, 0xb6, 0xb2, 0x7d, 0x0e, 0x45, 0xc5, 0x44, 0x88, 0xdf, 0x3b, 0xbd, 0x67, 0xc7, 0xf5,
		0xec, 0x28, 0xe8, 0x41, 0x08, 0xe0, 0x09, 0xf4, 0x8f, 0x75, 0xce, 0xbc, 0xa7, 0x28, 0xca, 0x93,
		0x3b, 0x08, 0x7f, 0xe1, 0x7a, 0x64, 0x99, 0x8a, 0x44, 0x9e, 0x95, 0xd4, 0x65, 0xa3, 0xba, 0x72,
		0xf9, 0x4e, 0x34, 0xa9, 0xeb, 0xfe, 0xea, 0x3b, 0xed, 0xd0, 0xed, 0x79, 0x1f, 0xdd, 0x27, 0x77,
		0x94, 0x92, 0x93, 0xc7, 0x0c, 0x70, 0xeb, 0xc2, 0xf9, 0x5e, 0xb8, 0xa3, 0xaa, 0xd5, 0x0f, 0x0a,
		0x74, 0x58, 0x79, 0x11, 0xc8, 0x04, 0x12, 0x87, 0x1a, 0x7b, 0x58, 0xdb, 0xdb, 0xdb, 0xdb, 0x77,
		0x8e, 0xfd, 0x77, 0xd3, 0xfe, 0xcf, 0xbe, 0x7d, 0xfc, 0xd0, 0x9a, 0xfa, 0xe5, 0xfe, 0xde, 0x7e,
		0x68, 0xed, 0xfc, 0xd8, 0xdf, 0x6d, 0x54, 0x07, 0x3b, 0x3f, 0x4f, 0xfe, 0xde, 0x1a, 0x9a, 0x5f,
		0xff, 0x90, 0xb9, 0xea, 0xe7, 0x9d, 0xb7, 0xe1, 0xb5, 0x56, 0x3e, 0xb6, 0x52, 0x07, 0x96, 0x1b,
		0x62, 0x38, 0xf3, 0x1b, 0x4a, 0x80, 0x5e, 0x5a, 0x19, 0x25, 0x04, 0xb7, 0x72, 0xdc, 0xa5, 0x2d,
		0x0e, 0x2a, 0xbf, 0xf4, 0x7c, 0x82, 0x90, 0xc6, 0xf4, 0x62, 0xb2, 0xfd, 0xaf, 0xd8, 0xa3, 0xd3,
		0xef, 0x46, 0x0e, 0xee, 0x7a, 0xf5, 0x10, 0xf1, 0x11, 0xc4, 0x47, 0x44, 0x16, 0x44, 0x7c, 0xa4,
		0x62, 0x0d, 0xb9, 0xcf, 0xf6, 0xfa, 0xcf, 0x5f, 0x98, 0x4f, 0x10, 0x26, 0x69, 0x28, 0x2c, 0x71,
		0xed, 0x78, 0x4f, 0xb9, 0x08, 0x93, 0x50, 0x5a, 0x0a, 0xc4, 0xb0, 0x33, 0x81, 0x9b, 0x54, 0xeb,
		0x69, 0x00, 0x99, 0x04, 0x96, 0x00, 0xa9, 0x05, 0xa0, 0xeb, 0x08, 0x1a, 0xf5, 0xfa, 0x41, 0x3d,
		0xc7, 0xc7, 0x00, 0xf8, 0xb2, 0xb0, 0xcd, 0x41, 0xa4, 0xda, 0x12, 0x1f, 0xbe, 0x7a, 0xb7, 0xd9,
		0xd9, 0xf5, 0x00, 0x3f, 0x00, 0x3f, 0x00, 0x3f, 0x84, 0xe8, 0x85, 0x24, 0x15, 0xa1, 0xa4, 0x49,
		0x1a, 0xa4, 0xa9, 0x06, 0xa4, 0x5e, 0x5e, 0x0d, 0x3e, 0x97, 0x22, 0xa5, 0x14, 0xe4, 0xda, 0xd7,
		0x52, 0xa8, 0xd4, 0x81, 0xb2, 0x44, 0x64, 0x88, 0x53, 0x03, 0x8a, 0xc0, 0xac, 0x88, 0xc9, 0x16,
		0x31, 0x05, 0x20, 0xf7, 0xa2, 0x0b, 0x64, 0x55, 0xc8, 0x50, 0x7f, 0xe9, 0x9d, 0xe5, 0xa5, 0xea,
		0x11, 0x30, 0x5b, 0x73, 0x38, 0xfb, 0xab, 0xfc, 0xf0, 0x40, 0xc1, 0x5a, 0xcc, 0xeb, 0xe8, 0xae,
		0x37, 0xa3, 0x67, 0x98, 0xf9, 0x4d, 0x6a, 0x68, 0xa0, 0x40, 0xcf, 0x00, 0x81, 0x12, 0x32, 0xa9,
		0xe2, 0x0d, 0x95, 0xe4, 0x73, 0x49, 0x6f, 0x00, 0x2a, 0x99, 0x50, 0xc9, 0xa4, 0xdd, 0x7a, 0x27,
		0x98, 0x74, 0xa5, 0x32, 0xe1, 0x6a, 0xc9, 0x64, 0xab, 0x88, 0xc1, 0x72, 0x20, 0x26, 0x26, 0x8d,
		0x3c, 0xa4, 0x65, 0x85, 0x4c, 0x2f, 0x90, 0x0a, 0x4a, 0x1f, 0x21, 0x30, 0x2a, 0xf9, 0x2d, 0x7d,
		0x4c, 0x3a, 0x0f, 0x11, 0xcc, 0xa5, 0x94, 0xee, 0x61, 0x54, 0xa1, 0x1c, 0xed, 0x06, 0x1f, 0x3b,
		0x7c, 0xec, 0x66, 0x7c, 0xec, 0xca, 0xa3, 0xdd, 0x24, 0x0b, 0xf1, 0x53, 0xc9, 0x4e, 0x79, 0xa8,
		0x38, 0x01, 0x23, 0x92, 0x31, 0x24, 0x25, 0x63, 0xd2, 0x33, 0x28, 0x35, 0xa3, 0x6a, 0x63, 0x58,
		0x6d, 0x8c, 0xab, 0x85, 0x81, 0xd5, 0xdd, 0x0d, 0x04, 0x5e, 0x67, 0x65, 0xc6, 0x4e, 0x16, 0x22,
		0x9b, 0xdd, 0xb8, 0x40, 0xc0, 0x44, 0x33, 0x1c, 0x15, 0x6d, 0x5a, 0xed, 0xcc, 0xaf, 0x43, 0x08,
		0xe8, 0x13, 0x06, 0xba, 0x84, 0x82, 0x76, 0xe1, 0xa0, 0x5d, 0x48, 0x68, 0x15, 0x16, 0x34, 0x42,
		0x83, 0x48, 0x78, 0xa8, 0xdb, 0xf0, 0x6b, 0xe9, 0x95, 0x76, 0x46, 0xe4, 0x82, 0xde, 0xaf, 0x13,
		0xae, 0xa9, 0x65, 0x66, 0xe4, 0xc2, 0x86, 0xe8, 0x99, 0x1d, 0x99, 0xdc, 0x46, 0xc3, 0x0c, 0xc9,
		0xf1, 0xd7, 0x0f, 0xf2, 0x15, 0x2b, 0xda, 0x66, 0x4a, 0x12, 0x33, 0x88, 0xc1, 0x6d, 0x20, 0x9f,
		0x35, 0x59, 0xdc, 0xad, 0xa0, 0x9e, 0x41, 0x59, 0xdc, 0x9d, 0xa0, 0x9d, 0x4d, 0x59, 0xdc, 0x7d,
		0xa0, 0x9e, 0x59, 0x59, 0xdc, 0x9d, 0xa0, 0x9e, 0x65, 0x59, 0x70, 0x29, 0x51, 0xc5, 0x4e, 0x10,
		0xcf, 0xbe, 0x2c, 0x38, 0x41, 0xd4, 0xb0, 0x13, 0xf4, 0xb3, 0x32, 0x8b, 0xac, 0x40, 0x49, 0x67,
		0x68, 0x16, 0x9c, 0x24, 0x8e, 0xb0, 0x13, 0x3a, 0x66, 0x6e, 0x16, 0x77, 0x2f, 0x68, 0x67, 0x71,
		0x16, 0x9c, 0x3b, 0xf6, 0xb1, 0x13, 0xda, 0x66, 0x77, 0x16, 0x9c, 0x34, 0x1a, 0xd8, 0x09, 0xea,
		0x59, 0x9f, 0x05, 0xa7, 0x88, 0x43, 0x0d, 0x3b, 0x41, 0xba, 0x62, 0xab, 0x74, 0x6d, 0x5e, 0x28,
		0x2a, 0x82, 0xc9, 0x66, 0x86, 0x2e, 0x50, 0x05, 0xe1, 0x60, 0xc2, 0x0a, 0x82, 0x5d, 0x08, 0x76,
		0xc5, 0x37, 0x40, 0xb0, 0xab, 0x00, 0xc1, 0x2e, 0xfa, 0xd9, 0xa4, 0xf3, 0x62, 0x80, 0x62, 0x46,
		0x69, 0xb2, 0x26, 0xcd, 0xac, 0x52, 0x42, 0xc1, 0x9e, 0x69, 0x22, 0x05, 0xd1, 0x2c, 0xd3, 0x89,
		0x8a, 0xa1, 0xac, 0xa2, 0x58, 0x32, 0xe8, 0x94, 0x24, 0x81, 0xaa, 0x42, 0x5a, 0x68, 0xb1, 0x64,
		0x08, 0xaa, 0x4c, 0xed, 0x05, 0x1d, 0x5d, 0xa8, 0x8c, 0x15, 0x27, 0xcb, 0x87, 0xa1, 0xce, 0x83,
		0xc1, 0x58, 0xf1, 0x2c, 0x55, 0x3e, 0x92, 0xde, 0x72, 0x20, 0xab, 0xe9, 0xc7, 0x8a, 0xcb, 0xd7,
		0xa0, 0xa4, 0xaa, 0xea, 0x23, 0x9a, 0x6a, 0xeb, 0xb9, 0x1a, 0x95, 0x44, 0x88, 0x14, 0x50, 0xa4,
		0x92, 0x59, 0x5d, 0xd4, 0xd6, 0x16, 0x44, 0x2a, 0x44, 0x2a, 0x44, 0xea, 0xa6, 0x8a, 0xd4, 0x44,
		0x88, 0x14, 0x51, 0xa4, 0x0a, 0xcd, 0xc4, 0x5e, 0x2f, 0x4f, 0x05, 0x87, 0x0f, 0xaf, 0x3c, 0x2d,
		0x2a, 0x61, 0x5a, 0x83, 0x30, 0x85, 0x30, 0x2d, 0x94, 0x30, 0x45, 0x51, 0x86, 0xea, 0x72, 0xf0,
		0x53, 0xc3, 0x4f, 0x6d, 0x4c, 0x58, 0xd0, 0xb9, 0x30, 0x2b, 0x28, 0xca, 0x40, 0x51, 0xc6, 0xc2,
		0x6d, 0x50, 0x94, 0xa1, 0x83, 0x41, 0x0c, 0x6e, 0x03, 0x8a, 0x32, 0x50, 0x94, 0xb1, 0xb0, 0x13,
		0x28, 0xca, 0x40, 0x51, 0xc6, 0xec, 0x4e, 0xa0, 0x28, 0x03, 0x45, 0x19, 0x0b, 0x52, 0x02, 0x45,
		0x19, 0x28, 0xca, 0x40, 0x51, 0xc6, 0x72, 0x05, 0x8a, 0xa2, 0x0c, 0x14, 0x65, 0x54, 0x50, 0x94,
		0xb1, 0x7c, 0x2f, 0x50, 0x94, 0x81, 0xa2, 0x8c, 0x05, 0xa4, 0x8d, 0xa2, 0x0c, 0x14, 0x65, 0x2c,
		0xdb, 0x09, 0x14, 0x65, 0xa0, 0x28, 0x23, 0xcb, 0x55, 0x50, 0x94, 0xa1, 0xb0, 0x1c, 0x82, 0x5d,
		0x08, 0x76, 0x2d, 0xbd, 0x01, 0x82, 0x5d, 0x04, 0xbc, 0x8f, 0xa2, 0x8c, 0xec, 0x56, 0xd8, 0xb4,
		0xa2, 0x0c, 0x8a, 0xfc, 0xa9, 0x8a, 0xee, 0x9a, 0x8c, 0x9b, 0xe8, 0x21, 0xb3, 0x4a, 0x76, 0x33,
		0xda, 0xf6, 0xf8, 0x5f, 0xec, 0x75, 0x3a, 0xd9, 0xa5, 0xa2, 0x28, 0x05, 0xac, 0x73, 0x37, 0x08,
		0x9b, 0x61, 0xa8, 0xd8, 0x4b, 0xf9, 0xc2, 0xf5, 0x4e, 0xbb, 0x6c, 0x28, 0xd8, 0x03, 0x35, 0xa5,
		0x6f, 0x5d, 0x38, 0xdf, 0xa7, 0x56, 0xaa, 0xbe, 0x3f, 0x3c, 0x6c, 0x1c, 0x1d, 0x1e, 0xee, 0x1f,
		0x1d, 0x1c, 0xed, 0x1f, 0xd7, 0xeb, 0xd5, 0x86, 0x4a, 0x2c, 0xde, 0xba, 0xf2, 0x3b, 0xcc, 0x67,
		0x9d, 0x5f, 0x86, 0x5b, 0xe8, 0xf5, 0xbb, 0x5d, 0xa3, 0x27, 0x47, 0xc4, 0xf9, 0xba, 0x39, 0xde,
		0x52, 0xca, 0xdd, 0xd4, 0xc6, 0xe3, 0x16, 0x06, 0x19, 0x69, 0x3b, 0xfb, 0x4c, 0x67, 0x19, 0x25,
		0x47, 0x9d, 0x8b, 0x39, 0x25, 0x52, 0xc9, 0xc7, 0x4a, 0xc9, 0xc6, 0xca, 0xf3, 0x49, 0x6a, 0x98,
		0x4f, 0x92, 0xa5, 0xa9, 0x53, 0xe6, 0xf9, 0x24, 0x52, 0xd3, 0xbd, 0x16, 0x88, 0x45, 0x62, 0xca,
		0x17, 0x91, 0x5f, 0x02, 0x73, 0x49, 0xcc, 0xf8, 0x11, 0x30, 0x97, 0x84, 0xd0, 0xee, 0xa7, 0xe0,
		0x9b, 0x4a, 0x79, 0xa7, 0x7e, 0xeb, 0x18, 0x23, 0x7c, 0x4c, 0xb0, 0x16, 0xc9, 0x4e, 0xd1, 0xed,
		0xd8, 0x92, 0x9d, 0x23, 0x9d, 0x97, 0xbe, 0xb0, 0x87, 0xef, 0x09, 0xd7, 0xa4, 0x1e, 0x9e, 0x9b,
		0x2c, 0x5c, 0xac, 0x39, 0xea, 0xe3, 0xaf, 0x16, 0xe5, 0xd6, 0xea, 0x18, 0x4e, 0x9c, 0xac, 0x5e,
		0xb4, 0xf9, 0xea, 0xc9, 0x0e, 0xe7, 0xc9, 0x75, 0xac, 0x87, 0xf9, 0x1b, 0x60, 0x7e, 0x0c, 0xd0,
		0x2e, 0xec, 0x5c, 0xf6, 0xc2, 0x8a, 0x42, 0x90, 0x5b, 0x21, 0xe7, 0xb5, 0x13, 0x2b, 0x86, 0xac,
		0xe7, 0xc7, 0xef, 0xe6, 0x05, 0xbf, 0x77, 0x7a, 0xcf, 0x8e, 0xeb, 0xd9, 0x91, 0xdf, 0x90, 0x10,
		0xc0, 0x13, 0xe8, 0x1f, 0xeb, 0x9c, 0x79, 0x4f, 0x91, 0x5f, 0x35, 0x77, 0x10, 0xfe, 0xc2, 0xf5,
		0x34, 0xe4, 0x12, 0x90, 0x66, 0x7c, 0x24, 0xcb, 0x46, 0x95, 0x81, 0xea, 0xbd, 0x12, 0x16, 0xd6,
		0xfd, 0xd5, 0x77, 0xda, 0xa1, 0xdb, 0xf3, 0x3e, 0xba, 0x4f, 0xee, 0x28, 0xc8, 0x44, 0x97, 0x37,
		0x40, 0xa8, 0x53, 0x2e, 0x9c, 0xef, 0x85, 0x3b, 0xaa, 0x5a, 0xfd, 0xa0, 0x40, 0x87, 0x95, 0x17,
		0x81, 0x4c, 0xd3, 0xb8, 0x85, 0x14, 0x7b, 0x58, 0xdb, 0xdb, 0xdb, 0xdb, 0x77, 0x8e, 0xfd, 0x77,
		0xd3, 0xfe, 0xcf, 0xbe, 0x7d, 0xfc, 0xd0, 0x9a, 0xfa, 0xe5, 0xfe, 0xde, 0x7e, 0x68, 0xed, 0xfc,
		0xd8, 0xdf, 0x6d, 0x54, 0x07, 0x3b, 0x3f, 0x4f, 0xfe, 0xde, 0x1a, 0x9a, 0x5f, 0xff, 0x90, 0xb9,
		0xea, 0xe7, 0x9d, 0xb7, 0xe1, 0xb5, 0x56, 0x3e, 0xb6, 0x52, 0x07, 0x96, 0x1b, 0x62, 0x38, 0xf3,
		0x1b, 0x4a, 0x80, 0x5e, 0x5a, 0x19, 0xa5, 0x42, 0xb4, 0x4c, 0x05, 0x69, 0x25, 0x02, 0x4f, 0x71,
		0xec, 0xf3, 0xa5, 0xe7, 0x13, 0x84, 0x34, 0xa6, 0x17, 0x93, 0x9d, 0x5f, 0xcd, 0x1e, 0x9d, 0x7e,
		0x37, 0x72, 0x70, 0xd7, 0xab, 0x87, 0x88, 0x8f, 0x20, 0x3e, 0x22, 0xb2, 0x20, 0xe2, 0x23, 0x15,
		0x6b, 0xc8, 0x7d, 0xb6, 0xd7, 0x7f, 0xfe, 0xc2, 0x7c, 0x82, 0x30, 0x49, 0x43, 0x61, 0x89, 0x6b,
		0xc7, 0x7b, 0xca, 0x45, 0x98, 0x84, 0xd2, 0x52, 0xa0, 0xce, 0x09, 0x1f, 0xc3, 0x4d, 0xaa, 0xf5,
		0x34, 0x80, 0x4c, 0x8a, 0x9c, 0x7f, 0x4a, 0x0b, 0x40, 0xd7, 0x11, 0x34, 0xea, 0xf5, 0x83, 0x7a,
		0x8e, 0x8f, 0x01, 0xf0, 0x65, 0x61, 0x9b, 0x83, 0x48, 0xb5, 0x25, 0x3e, 0x7c, 0x65, 0x04, 0x33,
		0xb7, 0x1e, 0xe0, 0x07, 0xe0, 0x07, 0xe0, 0x87, 0x10, 0xbd, 0x90, 0xa4, 0x22, 0x94, 0x34, 0x49,
		0x83, 0x34, 0xd5, 0x80, 0xd4, 0xcb, 0xab, 0xc1, 0xe7, 0x52, 0xa4, 0x94, 0x82, 0x5c, 0xfb, 0x5a,
		0x0a, 0x95, 0x3a, 0x50, 0x96, 0x88, 0x0c, 0x71, 0x6a, 0x40, 0x11, 0x98, 0x15, 0x31, 0xd9, 0x22,
		0xa6, 0x00, 0xe4, 0x5e, 0x74, 0x81, 0xac, 0x0a, 0x19, 0xea, 0x2f, 0xbd, 0xb3, 0x7c, 0x83, 0x2a,
		0x9a, 0x24, 0x8b, 0x55, 0x09, 0xab, 0x99, 0xc4, 0x2b, 0x51, 0x05, 0x2a, 0x99, 0xb6, 0x08, 0x4f,
		0x70, 0x5c, 0x49, 0x2a, 0x90, 0x65, 0x2e, 0x57, 0x2c, 0x2a, 0x5f, 0x1c, 0x4a, 0x5a, 0x0c, 0x2a,
		0x57, 0xfc, 0xc9, 0xbb, 0x99, 0x92, 0x6c, 0x40, 0x4a, 0xfe, 0x96, 0x50, 0xa1, 0x1b, 0x0d, 0xc1,
		0xf3, 0x91, 0xfa, 0x7a, 0xc2, 0x5d, 0xfd, 0x89, 0x35, 0xa7, 0x20, 0xba, 0xfb, 0x8a, 0xbb, 0xce,
		0xb1, 0xcf, 0x2a, 0xfb, 0xbb, 0x7a, 0x4b, 0xd3, 0x37, 0x6a, 0xf9, 0xbf, 0xa4, 0x6c, 0x1d, 0xef,
		0x96, 0x89, 0x6e, 0xd5, 0x8a, 0xbd, 0x11, 0xdb, 0x93, 0xe5, 0xbb, 0xb0, 0xf8, 0x8e, 0x4b, 0xde,
		0xcf, 0x7a, 0x66, 0xcf, 0x3d, 0x3f, 0xbd, 0xe9, 0x4e, 0x62, 0xfa, 0xc4, 0x9f, 0x4b, 0xd9, 0xa1,
		0xd5, 0x75, 0x99, 0x6b, 0x7d, 0x97, 0x3c, 0xbe, 0xc9, 0x69, 0xdf, 0x63, 0xf0, 0xba, 0x8a, 0xb0,
		0x78, 0x7d, 0x8b, 0xc2, 0xbe, 0x43, 0x61, 0xdf, 0xe0, 0xbc, 0xef, 0x6f, 0xf8, 0xdc, 0x44, 0x34,
		0xb9, 0xae, 0x4e, 0xd1, 0x6a, 0x8f, 0xf7, 0x7c, 0xcd, 0x26, 0x8c, 0xb7, 0x95, 0x6b, 0xa2, 0x28,
		0x67, 0x01, 0x2e, 0xb7, 0xb3, 0x5a, 0xc4, 0x29, 0xcd, 0x4f, 0x00, 0xb2, 0x4e, 0x66, 0x69, 0x67,
		0xb2, 0xb4, 0xd3, 0x58, 0x88, 0x40, 0xf2, 0x2d, 0xff, 0x47, 0x02, 0x82, 0x7f, 0x30, 0x2d, 0xa7,
		0x88, 0xbb, 0x88, 0x96, 0xe5, 0x9a, 0x24, 0xbb, 0x42, 0xdc, 0xaf, 0x94, 0xb4, 0x3c, 0x65, 0xec,
		0x42, 0x65, 0xeb, 0xc2, 0x5c, 0x52, 0x03, 0x97, 0xe4, 0x8c, 0x4b, 0x78, 0xcb, 0xc0, 0xad, 0x97,
		0xaf, 0xaf, 0x81, 0xdb, 0x76, 0xba, 0xfc, 0xdb, 0x97, 0xa4, 0x64, 0x8c, 0xaf, 0xe4, 0xb5, 0x41,
		0x84, 0xe2, 0x87, 0xc2, 0xf1, 0x42, 0x99, 0xf8, 0xa0, 0x38, 0xb1, 0xa9, 0xc6, 0xff, 0x94, 0xe3,
		0x7d, 0xca, 0xf1, 0x3d, 0x29, 0x62, 0xd4, 0x63, 0x95, 0x0a, 0xc7, 0xe7, 0x92, 0xf3, 0xea, 0xbb,
		0x5e, 0xd8, 0x10, 0x49, 0xa4, 0x1b, 0x53, 0x9f, 0x80, 0xa7, 0x5a, 0x32, 0xd3, 0x47, 0xc2, 0x2f,
		0xa2, 0x92, 0xc9, 0xa3, 0x1a, 0x96, 0x57, 0xcc, 0xd4, 0xa1, 0x48, 0x09, 0x91, 0x49, 0x91, 0x50,
		0xc9, 0xbc, 0xa1, 0xda, 0x32, 0xba, 0x86, 0x55, 0x24, 0xbb, 0xa8, 0xc9, 0x11, 0xd5, 0xa2, 0xb2,
		0xfa, 0x39, 0x34, 0xb9, 0xcf, 0x22, 0xb3, 0xbb, 0x23, 0xae, 0x8c, 0x92, 0x2b, 0xa1, 0x8c, 0xa0,
		0x8c, 0xa0, 0x8c, 0xa0, 0x8c, 0xa0, 0x8c, 0xa0, 0x8c, 0x0a, 0xea, 0x82, 0xe0, 0x8d, 0x6c, 0x89,
		0x79, 0x20, 0x38, 0xa2, 0x55, 0x79, 0xf5, 0x37, 0xaf, 0xf4, 0xdd, 0x0a, 0xef, 0x84, 0x9a, 0xb7,
		0x39, 0x08, 0x9c, 0x27, 0x16, 0xf0, 0xf8, 0x9b, 0xe3, 0x4f, 0xe6, 0xc3, 0xe3, 0xbc, 0xe6, 0x71,
		0xf2, 0xed, 0x76, 0x4e, 0x1e, 0x1e, 0xbe, 0x67, 0x02, 0xaf, 0x1a, 0x07, 0x29, 0x14, 0xd7, 0xb5,
		0xb6, 0x9e, 0x54, 0x0c, 0xfb, 0xd7, 0x84, 0xc7, 0x42, 0xc8, 0x8e, 0x7d, 0xc8, 0xbb, 0x49, 0x23,
		0x40, 0x76, 0xe5, 0xb3, 0x6b, 0xf8, 0xc9, 0x32, 0x6f, 0xc6, 0x8d, 0xfc, 0x00, 0x02, 0x99, 0x01,
		0x03, 0x82, 0x03, 0x04, 0x8a, 0x0b, 0xf4, 0x46, 0xe4, 0xa0, 0x21, 0xda, 0x34, 0x5a, 0x58, 0x63,
		0xbc, 0xa9, 0xc3, 0xbe, 0xf4, 0x9f, 0x6c, 0xe6, 0x85, 0xbe, 0xcb, 0x02, 0x7e, 0x15, 0x39, 0x7b,
		0x19, 0x34, 0x25, 0x34, 0xe5, 0x72, 0xc2, 0x0a, 0x98, 0xff, 0xcd, 0x15, 0xd9, 0xc8, 0x59, 0x02,
		0x1b, 0x5f, 0x2e, 0xa6, 0x33, 0xab, 0xd0, 0x99, 0xd0, 0x99, 0xb2, 0x84, 0x2b, 0x6a, 0x35, 0xa8,
		0x59, 0x11, 0x8a, 0x24, 0x2c, 0x4d, 0xca, 0x2a, 0x24, 0x4d, 0x44, 0xda, 0xaa, 0x24, 0x4e, 0x46,
		0xea, 0x64, 0x24, 0x4f, 0x47, 0xfa, 0x92, 0x8e, 0x37, 0x53, 0xcd, 0xe5, 0x99, 0xe7, 0x7c, 0xe9,
		0x0a, 0xc4, 0x75, 0x52, 0x29, 0x67, 0xbc, 0x90, 0x7a, 0x23, 0x96, 0x47, 0xa7, 0x1b, 0x30, 0xd4,
		0x42, 0xab, 0x32, 0x23, 0x15, 0x53, 0x92, 0x33, 0x27, 0x39, 0x93, 0xd2, 0x33, 0xab, 0x1c, 0xd3,
		0x2a, 0x44, 0x2a, 0x2a, 0xb4, 0x55, 0xd1, 0x5f, 0x7a, 0xbd, 0x2e, 0x73, 0x3c, 0x8a, 0x92, 0xe8,
		0x6a, 0x9e, 0xdb, 0x31, 0x08, 0x42, 0xd2, 0x15, 0x1e, 0x1d, 0x11, 0x70, 0x0a, 0xa1, 0x03, 0xa1,
		0x03, 0xa1, 0xb3, 0x40, 0x39, 0x6e, 0x87, 0x79, 0xa1, 0x1b, 0xbe, 0xfa, 0xec, 0x91, 0x42, 0xf0,
		0xa8, 0x8c, 0x98, 0x3b, 0x8b, 0x1f, 0xe5, 0x17, 0x27, 0x20, 0xa0, 0xc1, 0xf1, 0x0b, 0x7e, 0x3c,
		0xfd, 0xe5, 0xb7, 0x4f, 0x0f, 0x37, 0xa7, 0xd7, 0xbf, 0x9f, 0x7d, 0x38, 0x35, 0x7e, 0xbe, 0x1b,
		0x5a, 0x72, 0x98, 0x78, 0xe4, 0x66, 0xfc, 0x54, 0x7b, 0x33, 0x4e, 0x85, 0x3d, 0x29, 0x03, 0x4d,
		0xc6, 0x7b, 0xf7, 0x71, 0x78, 0xdb, 0xd3, 0xd1, 0x33, 0x8c, 0x7e, 0xb9, 0x19, 0x3d, 0x02, 0x97,
		0x5f, 0x4f, 0xfe, 0x84, 0x84, 0xc6, 0xa7, 0x49, 0x6a, 0x45, 0x45, 0x6d, 0x28, 0xa9, 0x05, 0x61,
		0xef, 0xc2, 0xde, 0x15, 0x97, 0x3e, 0xd2, 0x5a, 0x2b, 0x39, 0xf9, 0x2e, 0x73, 0x1e, 0xe5, 0x34,
		0x55, 0xa2, 0xa1, 0x8e, 0x24, 0xae, 0xfd, 0x1c, 0x0b, 0xbc, 0x77, 0xef, 0x62, 0xa1, 0xb5, 0x37,
		0xe6, 0x36, 0x0c, 0x5e, 0x94, 0x92, 0x1a, 0x35, 0x48, 0x0d, 0x48, 0x0d, 0x78, 0xc9, 0x60, 0xb0,
		0xc2, 0x60, 0x85, 0xc1, 0x0a, 0x2f, 0x19, 0xbc, 0x64, 0x10, 0x3a, 0x10, 0x3a, 0xf0, 0x92, 0xc1,
		0x4b, 0x06, 0x2f, 0xd9, 0xbc, 0x97, 0x4c, 0x73, 0x63, 0x2e, 0x0e, 0x27, 0x59, 0xf1, 0x1a, 0x73,
		0x09, 0xa6, 0x2d, 0xa1, 0x37, 0x17, 0x31, 0x27, 0x90, 0x72, 0x00, 0x7d, 0x6f, 0xae, 0xf5, 0x34,
		0x6f, 0x6d, 0x46, 0xbe, 0xac, 0x48, 0x16, 0xa9, 0xea, 0xfe, 0xa2, 0x59, 0x0b, 0x92, 0x65, 0x73,
		0x9b, 0x2c, 0x1b, 0x3f, 0x90, 0x78, 0x9a, 0xec, 0xf8, 0x42, 0xcd, 0x09, 0xb2, 0x35, 0x24, 0xc8,
		0x92, 0x5b, 0x3b, 0x85, 0x4f, 0x90, 0x75, 0x5e, 0x5e, 0xec, 0x58, 0x14, 0x4b, 0xfa, 0xfe, 0x93,
		0x15, 0x10, 0x34, 0xd4, 0x6c, 0xf4, 0xc3, 0xfd, 0x2f, 0x6b, 0x8c, 0xa9, 0x07, 0x0d, 0x83, 0xd0,
		0x5f, 0xdd, 0x5e, 0x73, 0xad, 0xb8, 0x7e, 0x9f, 0x83, 0x30, 0xdf, 0x73, 0xa0, 0x90, 0x0b, 0x3f,
		0xbc, 0x18, 0x3c, 0x0e, 0x1e, 0x07, 0x8f, 0xe7, 0x9d, 0xc7, 0xdd, 0x8e, 0x12, 0x97, 0xbb, 0x1d,
		0xf0, 0x39, 0xf8, 0x1c, 0x7c, 0x9e, 0x6f, 0x3e, 0x7f, 0xf1, 0xdd, 0x9e, 0x50, 0x17, 0x83, 0x85,
		0x7d, 0x48, 0x56, 0x00, 0xb7, 0x83, 0xdb, 0x4b, 0xcb, 0xed, 0x7d, 0xd7, 0x0b, 0xdf, 0x2b, 0x30,
		0xbb, 0x44, 0x9c, 0x4d, 0x71, 0x20, 0xb1, 0x42, 0xac, 0x91, 0x62, 0x00, 0x31, 0xd1, 0xd4, 0x5b,
		0xaa, 0x81, 0xc3, 0x94, 0x13, 0x6e, 0x15, 0xc6, 0xbe, 0x91, 0x0c, 0x16, 0xa6, 0xde, 0xda, 0x5a,
		0xbd, 0x9e, 0xa3, 0xcd, 0x35, 0x14, 0xb7, 0x6d, 0xe5, 0x42, 0xf9, 0xf6, 0xda, 0x2a, 0x28, 0x3b,
		0xbe, 0x1e, 0x8a, 0x17, 0x8a, 0x17, 0x30, 0xdb, 0x3c, 0xcc, 0x26, 0xf5, 0xb9, 0x9f, 0x7e, 0x8f,
		0x04, 0x27, 0xbf, 0xae, 0x97, 0x0f, 0x72, 0xf4, 0xda, 0x36, 0xfb, 0x1e, 0x9e, 0x84, 0xac, 0xcb,
		0x9e, 0x59, 0xe8, 0xbf, 0xda, 0x4e, 0xd8, 0x7b, 0x76, 0xdb, 0x6a, 0x51, 0x8f, 0x28, 0x9f, 0x58,
		0x21, 0xec, 0x41, 0x1d, 0xeb, 0x68, 0xe5, 0x2d, 0xaf, 0x20, 0x0a, 0xf9, 0xee, 0x89, 0x45, 0xe9,
		0x2a, 0x12, 0x91, 0xee, 0x28, 0x47, 0x66, 0xfc, 0xab, 0x65, 0xb0, 0xc7, 0x37, 0x1a, 0xe2, 0x21,
		0x76, 0x89, 0x86, 0x78, 0xdc, 0xd7, 0x6c, 0x58, 0x43, 0x3c, 0xf2, 0xde, 0xc7, 0xd3, 0xe2, 0xae,
		0xa8, 0xdd, 0x8f, 0xd7, 0xb7, 0xee, 0x15, 0xdb, 0x0d, 0x95, 0x0e, 0xc8, 0x5e, 0xf8, 0xb2, 0xbe,
		0xf9, 0xf1, 0xf0, 0x43, 0x98, 0xb4, 0x87, 0x49, 0x7b, 0x98, 0xb4, 0x47, 0xa6, 0x48, 0xf3, 0x3c,
		0x43, 0x6c, 0x54, 0x6e, 0x68, 0x7b, 0xe1, 0x8b, 0xed, 0xf4, 0x23, 0x71, 0x26, 0x88, 0xec, 0xe6,
		0x17, 0xe0, 0x4d, 0x40, 0x92, 0xab, 0x53, 0xc4, 0xf0, 0x97, 0x0a, 0x86, 0xbf, 0x50, 0xc1, 0x41,
		0xf1, 0xea, 0x3e, 0xc1, 0x6a, 0x3e, 0x1a, 0xab, 0x4b, 0xb4, 0xb4, 0x58, 0xb2, 0x94, 0x18, 0x2c,
		0x09, 0x96, 0x04, 0x4b, 0xf2, 0xb1, 0xe4, 0x50, 0xdb, 0x05, 0x11, 0xa1, 0xd8, 0x4e, 0xa7, 0xe3,
		0xb3, 0x20, 0x10, 0xe7, 0xce, 0x25, 0x6b, 0x80, 0xe1, 0xc0, 0x70, 0x86, 0x19, 0xce, 0x7d, 0x11,
		0xa4, 0xbe, 0x19, 0x9e, 0x3b, 0x16, 0xb8, 0x26, 0x7e, 0x46, 0xed, 0x43, 0xd0, 0x26, 0x6f, 0xf6,
		0xed, 0x50, 0xe2, 0xdd, 0x16, 0x83, 0x0b, 0x72, 0x3d, 0x7c, 0x42, 0xe6, 0x7b, 0xd2, 0x91, 0x7d,
		0x6b, 0x7b, 0xfb, 0x6e, 0xdf, 0x3e, 0x6e, 0xbd, 0xdd, 0x55, 0xed, 0xe3, 0xd6, 0xe8, 0xc7, 0x6a,
		0xf4, 0x6d, 0xf4, 0x73, 0xed, 0x6e, 0xdf, 0x3e, 0x1c, 0xff, 0x5c, 0xbf, 0xdb, 0xb7, 0xeb, 0xad,
		0x9d, 0xfb, 0xfb, 0x77, 0x3b, 0x3f, 0x0e, 0x06, 0xe2, 0x17, 0x8a, 0x47, 0x94, 0x5a, 0x32, 0x5b,
		0x72, 0x75, 0x73, 0xf6, 0x6f, 0xe5, 0x7d, 0xf9, 0xd3, 0xe4, 0xc6, 0xfc, 0x64, 0xe9, 0x8e, 0x39,
		0xef, 0x1a, 0x64, 0x86, 0x46, 0xc1, 0x99, 0xc1, 0xb1, 0x1f, 0x9b, 0xf6, 0xaf, 0xad, 0x1f, 0xd5,
		0xdd, 0xc3, 0xc1, 0xc9, 0xce, 0x8f, 0xa3, 0xc1, 0xfc, 0x1f, 0xdf, 0x96, 0x7d, 0xac, 0xba, 0x7b,
		0x34, 0x38, 0x49, 0xf9, 0x97, 0xc6, 0xe0, 0x84, 0x73, 0x8d, 0xfa, 0x60, 0x7b, 0xe1, 0xa3, 0xc3,
		0xbf, 0xd7, 0xd2, 0x2e, 0x38, 0x4c, 0xb9, 0xe0, 0x20, 0xed, 0x82, 0x83, 0x94, 0x0b, 0x52, 0x1f,
		0xa9, 0x96, 0x72, 0x41, 0x7d, 0xf0, 0xb6, 0xf0, 0xf9, 0xed, 0xe5, 0x1f, 0x6d, 0x0c, 0x76, 0xde,
		0xd2, 0xfe, 0xed, 0x68, 0xf0, 0x76, 0xb2, 0x53, 0x44, 0xd1, 0x00, 0x32, 0x31, 0x4f, 0x26, 0xfa,
		0x05, 0x25, 0xa6, 0x4c, 0x46, 0xdf, 0xbc, 0xf0, 0x85, 0x7c, 0xee, 0xd0, 0x65, 0xf8, 0xa2, 0x71,
		0xe4, 0xd0, 0xd0, 0xca, 0xf9, 0x8b, 0xbd, 0x0a, 0x4c, 0x1b, 0x4a, 0xae, 0x80, 0x93, 0x1a, 0x4e,
		0xea, 0x19, 0x22, 0x92, 0xb3, 0xb1, 0x87, 0x17, 0x96, 0x63, 0xa4, 0x10, 0x0c, 0x6b, 0xe3, 0x86,
		0x35, 0x06, 0x09, 0x51, 0x11, 0xb2, 0x3a, 0x41, 0xab, 0x12, 0x36, 0x19, 0x81, 0x93, 0x11, 0x3a,
		0x09, 0xc1, 0x8b, 0x63, 0xa4, 0x8a, 0xc9, 0xc6, 0xa8, 0x7f, 0xb1, 0x57, 0xdb, 0x25, 0xe8, 0x8b,
		0x1a, 0xaf, 0x83, 0xce, 0x82, 0xf2, 0x8c, 0x43, 0xc5, 0x40, 0xe4, 0x8c, 0x44, 0xce, 0x50, 0xa4,
		0x8c, 0x25, 0xc7, 0x60, 0x92, 0x8c, 0x26, 0xef, 0xd2, 0x4d, 0xa5, 0x97, 0xbe, 0xeb, 0x85, 0xd5,
		0x06, 0x41, 0x2b, 0xc1, 0x86, 0xc2, 0x12, 0x6a, 0x95, 0x4e, 0xf2, 0x1e, 0xb0, 0x85, 0x07, 0xa1,
		0xa8, 0x7c, 0x22, 0x12, 0x2b, 0x0b, 0xcb, 0x11, 0x55, 0x42, 0x25, 0xeb, 0x11, 0x16, 0xed, 0x28,
		0x92, 0xf3, 0xec, 0x11, 0x10, 0x54, 0x48, 0xe9, 0x3e, 0x82, 0x46, 0xbd, 0x7e, 0x50, 0xcf, 0xf1,
		0x31, 0x6c, 0x65, 0x73, 0x75, 0x2b, 0xc7, 0x5d, 0x8c, 0x87, 0x08, 0x21, 0x54, 0x91, 0x9a, 0x33,
		0x58, 0x23, 0x5a, 0x09, 0x68, 0x03, 0x68, 0x03, 0x68, 0x43, 0x88, 0x5e, 0x4a, 0xdf, 0xbd, 0xf8,
		0xf2, 0xf6, 0xf3, 0x43, 0xf3, 0xb7, 0xdb, 0x7f, 0x3e, 0xdc, 0xfe, 0xf1, 0xf9, 0xd4, 0xa2, 0x28,
		0xd0, 0x0d, 0x94, 0x71, 0x11, 0x0d, 0x36, 0x5a, 0xfe, 0x9a, 0x17, 0x1f, 0xeb, 0x56, 0xc6, 0xfa,
		0xaa, 0x95, 0xff, 0x1e, 0xd1, 0x92, 0xfa, 0xea, 0x5b, 0x0c, 0x37, 0x08, 0x14, 0xd6, 0x68, 0x29,
		0x68, 0x2c, 0x68, 0x2c, 0x68, 0x2c, 0x21, 0x7a, 0x91, 0xae, 0x3f, 0x5e, 0x50, 0x56, 0xef, 0xd1,
		0x91, 0x5e, 0x30, 0x98, 0x39, 0x0e, 0xf6, 0x8d, 0x7f, 0xd0, 0x3e, 0xa7, 0xf1, 0x32, 0x7c, 0x19,
		0xfe, 0xff, 0x5f, 0xec, 0x35, 0x88, 0xbf, 0xe7, 0x68, 0x2e, 0xa3, 0xa4, 0xaf, 0x54, 0xcd, 0x47,
		0x5a, 0xd4, 0x6e, 0x11, 0x08, 0x1e, 0x10, 0xca, 0x70, 0xcc, 0x62, 0x5c, 0x4e, 0xaa, 0x0b, 0xb3,
		0x18, 0x63, 0x16, 0xc3, 0x28, 0x46, 0x29, 0x51, 0x51, 0x83, 0xa8, 0x80, 0xa8, 0x58, 0xf9, 0x84,
		0x88, 0x33, 0xc2, 0x8e, 0x82, 0x1d, 0x55, 0x48, 0x3b, 0x0a, 0x71, 0xc6, 0xe9, 0x07, 0x41, 0x9c,
		0x51, 0xcd, 0x61, 0x88, 0x38, 0x63, 0x2e, 0x8e, 0x01, 0x71, 0xc6, 0xa5, 0x48, 0x03, 0x71, 0x46,
		0xa0, 0x0d, 0xa0, 0x8d, 0x2c, 0xd1, 0x06, 0xe2, 0x8c, 0xc2, 0xea, 0x06, 0x71, 0x46, 0x2d, 0x5a,
		0xa7, 0x82, 0x38, 0x23, 0x34, 0x16, 0x34, 0x16, 0x34, 0xd6, 0x1a, 0x7a, 0x41, 0x9c, 0x71, 0x8e,
		0x26, 0xb2, 0x8c, 0x33, 0x6a, 0x9e, 0x74, 0xbd, 0x24, 0xcc, 0x58, 0xbc, 0xc9, 0xd6, 0x42, 0xae,
		0x50, 0x0c, 0xb6, 0xa6, 0x26, 0x74, 0x25, 0x02, 0xa7, 0x6f, 0x3f, 0xbd, 0x48, 0xd2, 0x56, 0xe9,
		0x6b, 0xad, 0x39, 0x6b, 0x91, 0xe5, 0x76, 0x51, 0xcb, 0x90, 0x6a, 0xe6, 0x7f, 0x63, 0xbe, 0x40,
		0xb5, 0xf5, 0xf8, 0x02, 0x14, 0x5b, 0xa3, 0xd8, 0x7a, 0x9a, 0x84, 0x64, 0x5a, 0xbc, 0x47, 0xd7,
		0xa1, 0xd4, 0xda, 0x20, 0x70, 0xdf, 0xe8, 0x52, 0x6b, 0xd1, 0xce, 0x7b, 0x0b, 0xe7, 0x2c, 0xd7,
		0x0f, 0x09, 0xf9, 0x52, 0x99, 0xd8, 0xa6, 0xc8, 0x97, 0x12, 0x39, 0xef, 0xdc, 0xe4, 0x4b, 0x8d,
		0x79, 0x2c, 0x07, 0x09, 0x53, 0x68, 0xcd, 0x00, 0x69, 0x51, 0x46, 0x69, 0x21, 0x9d, 0x32, 0x25,
		0xab, 0x40, 0x89, 0x14, 0x29, 0x9c, 0xc2, 0x70, 0x0a, 0x6f, 0xbc, 0x53, 0xf8, 0x6b, 0x2f, 0x08,
		0x29, 0x5c, 0xc2, 0xc7, 0x0a, 0x6b, 0x48, 0x75, 0xe6, 0x9d, 0xff, 0x22, 0x48, 0x99, 0x52, 0xea,
		0x49, 0xac, 0x73, 0x87, 0x68, 0x77, 0x8a, 0x6e, 0xc7, 0x96, 0xec, 0x9c, 0x52, 0xcf, 0xe3, 0xb5,
		0x7b, 0xf8, 0x9e, 0x70, 0x4d, 0xd5, 0x86, 0x9f, 0xa9, 0x0b, 0xe7, 0xbb, 0x77, 0x72, 0xda, 0x57,
		0x8b, 0x72, 0x6b, 0x29, 0x1a, 0xaa, 0xa6, 0xae, 0x9e, 0xf7, 0x1e, 0xcc, 0xa9, 0x3b, 0x4c, 0xb2,
		0xd2, 0x60, 0x37, 0xc7, 0xcc, 0xdf, 0x00, 0xf3, 0xa3, 0x09, 0x70, 0x61, 0x7a, 0x45, 0x97, 0x46,
		0x14, 0x82, 0xdc, 0x0a, 0xd1, 0x73, 0x5a, 0xb3, 0x62, 0xd8, 0xca, 0xf6, 0x39, 0x14, 0x15, 0x13,
		0x21, 0x7e, 0xef, 0xf4, 0x9e, 0x1d, 0xd7, 0xb3, 0xa3, 0x50, 0x28, 0x21, 0x80, 0x27, 0xd0, 0x3f,
		0xd6, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x65, 0xee, 0x20, 0x3c, 0x65, 0xbd, 0x08, 0x91, 0x67, 0x25,
		0x75, 0xd9, 0x71, 0xf1, 0x42, 0x95, 0x78, 0x5d, 0x0d, 0x05, 0x0c, 0xc4, 0xb0, 0xad, 0x42, 0x5d,
		0x57, 0x62, 0xea, 0xa8, 0x6a, 0xf5, 0x83, 0x02, 0x1d, 0x56, 0x5e, 0x04, 0x32, 0x81, 0xc4, 0xa1,
		0xc6, 0x1e, 0xd6, 0xf6, 0xf6, 0xf6, 0xf6, 0x9d, 0x63, 0xff, 0xdd, 0xb4, 0xff, 0xb3, 0x6f, 0x1f,
		0x3f, 0xb4, 0xa6, 0x7e, 0xb9, 0xbf, 0xb7, 0x1f, 0x5a, 0x3b, 0x3f, 0xf6, 0x77, 0x1b, 0xd5, 0xc1,
		0xce, 0xcf, 0x93, 0xbf, 0xb7, 0x86, 0xe6, 0xd7, 0x3f, 0x64, 0xae, 0xfa, 0x79, 0xe7, 0x6d, 0x78,
		0xad, 0x95, 0x8f, 0xad, 0xd4, 0x81, 0xe5, 0x86, 0x18, 0xce, 0xfc, 0x86, 0x12, 0xa0, 0x97, 0x16,
		0x4a, 0xb3, 0x16, 0xce, 0xd2, 0x09, 0x82, 0x5e, 0xdb, 0x8d, 0x92, 0xc1, 0x88, 0x4a, 0xb4, 0x16,
		0x56, 0x94, 0xf4, 0x18, 0x4f, 0x0d, 0xd7, 0xbc, 0x39, 0xbd, 0xfe, 0xfd, 0xf4, 0x1a, 0xc1, 0x12,
		0x04, 0x4b, 0x44, 0x16, 0x44, 0xb0, 0xa4, 0x62, 0x31, 0xaf, 0xff, 0xcc, 0xfc, 0x51, 0xae, 0x27,
		0x41, 0xcc, 0xe4, 0x50, 0x61, 0x8d, 0x53, 0xaf, 0xff, 0x3c, 0x7c, 0xa9, 0x3c, 0x17, 0xfe, 0xb8,
		0x5f, 0xfa, 0x7e, 0x10, 0xaa, 0xcb, 0xc0, 0x78, 0x1d, 0x75, 0xc9, 0x27, 0x32, 0x56, 0x18, 0x82,
		0x0f, 0x82, 0x0f, 0x82, 0x4f, 0x7a, 0x2c, 0x72, 0xaa, 0xd0, 0xab, 0xe6, 0x58, 0x60, 0xbd, 0xf4,
		0x7c, 0x02, 0x71, 0x15, 0xad, 0xa2, 0x2e, 0xac, 0xaa, 0xb5, 0x03, 0x88, 0x2a, 0x88, 0x2a, 0x88,
		0x2a, 0x71, 0xee, 0xb3, 0xbd, 0xfe, 0xf3, 0x17, 0xee, 0x5a, 0x80, 0x55, 0x2c, 0x84, 0x56, 0x40,
		0x7a, 0xfd, 0x84, 0x68, 0x05, 0x94, 0x9f, 0x23, 0x40, 0x2b, 0xa0, 0xc2, 0xf9, 0x9b, 0x86, 0x7a,
		0x88, 0xf9, 0x04, 0x90, 0x65, 0xb4, 0x0e, 0x2c, 0x2c, 0xc0, 0x16, 0xc0, 0x16, 0x58, 0x58, 0xfa,
		0x04, 0xd6, 0x37, 0xe6, 0x07, 0xb2, 0x0d, 0x17, 0x66, 0xf6, 0x6b, 0xbc, 0x90, 0xba, 0xc8, 0x3a,
		0x84, 0xb8, 0x82, 0xb8, 0x82, 0xb8, 0x12, 0xa3, 0x97, 0xbe, 0xeb, 0x85, 0xef, 0x09, 0x84, 0x55,
		0x1d, 0xf6, 0x95, 0x19, 0x70, 0x5f, 0x85, 0x7d, 0x95, 0xf5, 0x11, 0x1c, 0xc2, 0xb6, 0xca, 0xcc,
		0xb6, 0x2a, 0x4d, 0x23, 0xa9, 0xb8, 0x5f, 0x4a, 0xfc, 0xdd, 0xc8, 0xb8, 0x9a, 0x9b, 0xd1, 0x2d,
		0xe3, 0xef, 0x39, 0x1a, 0x57, 0x83, 0x09, 0x14, 0x9a, 0xc1, 0x1d, 0xca, 0xa9, 0x33, 0x90, 0x26,
		0x28, 0xa7, 0x86, 0x5d, 0x04, 0xbb, 0x08, 0xe5, 0xd4, 0xd2, 0x6b, 0xa0, 0x9c, 0xda, 0xe8, 0x4e,
		0xd1, 0xed, 0xd8, 0x92, 0x9d, 0x43, 0x39, 0x35, 0xca, 0xa9, 0x51, 0x4e, 0x4d, 0x68, 0x3b, 0x6a,
		0x70, 0x3e, 0x54, 0x50, 0x4e, 0x8d, 0x72, 0x6a, 0x94, 0x53, 0x97, 0x47, 0x14, 0x82, 0xdc, 0x50,
		0x4e, 0x8d, 0x72, 0x6a, 0x94, 0x53, 0xab, 0x3c, 0x19, 0xca, 0xa9, 0x51, 0x4e, 0x8d, 0x72, 0x6a,
		0x2a, 0x51, 0x5a, 0x41, 0x39, 0x35, 0xca, 0xa9, 0xb9, 0x31, 0x1c, 0xca, 0xa9, 0xb5, 0xdf, 0x17,
		0xe5, 0xd4, 0x28, 0xa7, 0x5e, 0xd8, 0x5c, 0x04, 0x4b, 0xf8, 0x17, 0x44, 0xb0, 0x04, 0xe5, 0xd4,
		0x82, 0xcf, 0x88, 0x72, 0x6a, 0x08, 0x3e, 0x08, 0xbe, 0x32, 0x08, 0xbe, 0x0d, 0x49, 0xf6, 0xef,
		0x3d, 0x3e, 0x06, 0x8c, 0x40, 0x60, 0xc5, 0xeb, 0x40, 0xd0, 0x40, 0xd0, 0x40, 0xd0, 0x08, 0xd1,
		0x4b, 0xdf, 0xf5, 0xc2, 0xc6, 0x21, 0x81, 0x9c, 0x79, 0x8f, 0x3c, 0x7d, 0xad, 0x0e, 0x3e, 0xd4,
		0x41, 0xe7, 0xe7, 0x08, 0xd4, 0x46, 0xb9, 0x1a, 0x3f, 0x15, 0xf8, 0x8d, 0x16, 0xb6, 0xf9, 0xa5,
		0xd7, 0xed, 0xda, 0xae, 0x17, 0x32, 0xff, 0x9b, 0xd3, 0xa5, 0x68, 0xe8, 0x32, 0xbd, 0x1c, 0x60,
		0x08, 0x60, 0x08, 0x60, 0x88, 0x30, 0x0c, 0x39, 0xa8, 0x11, 0xc0, 0x90, 0x23, 0xc0, 0x10, 0xc0,
		0x90, 0x4d, 0x29, 0x17, 0xac, 0x1d, 0x1f, 0x1e, 0x37, 0x8e, 0x6a, 0xc7, 0x00, 0x1f, 0x05, 0x03,
		0x1f, 0x68, 0x22, 0x07, 0xc0, 0x02, 0xc0, 0x52, 0x41, 0x13, 0x39, 0x34, 0x91, 0x03, 0x6a, 0xd9,
		0x30, 0xd4, 0x82, 0x26, 0x72, 0xc5, 0x03, 0x2c, 0x68, 0x22, 0x07, 0xd8, 0x02, 0xd8, 0x52, 0x02,
		0xd8, 0xb2, 0x21, 0x71, 0x65, 0xbf, 0xd7, 0x0b, 0xed, 0x0e, 0xeb, 0x3a, 0xaf, 0xea, 0x42, 0x6b,
		0x6a, 0x2d, 0x08, 0x1c, 0x08, 0x1c, 0x08, 0x1c, 0x21, 0x7a, 0x81, 0x63, 0x17, 0x26, 0x12, 0x4c,
		0x24, 0xc1, 0x23, 0x80, 0x63, 0xb7, 0x98, 0x76, 0xd2, 0x08, 0x2a, 0xb8, 0xc1, 0x0b, 0x55, 0x0f,
		0xdb, 0xf9, 0x05, 0x01, 0x40, 0x00, 0x40, 0x00, 0x40, 0x84, 0x01, 0x08, 0x12, 0xdc, 0x00, 0x40,
		0x00, 0x40, 0x04, 0x8e, 0x00, 0x09, 0x6e, 0x45, 0x87, 0x22, 0x41, 0xe8, 0x3b, 0xe1, 0xa8, 0x62,
		0x49, 0x0d, 0x82, 0x8c, 0x17, 0x02, 0xf4, 0x00, 0xf4, 0x00, 0xf4, 0x10, 0x86, 0x1e, 0x68, 0x81,
		0x0f, 0xe4, 0x01, 0xe4, 0xc1, 0x7f, 0x04, 0xb5, 0x3a, 0x80, 0x46, 0xa1, 0x80, 0x06, 0xe6, 0xf5,
		0x00, 0xac, 0x00, 0xac, 0x00, 0xac, 0x00, 0xac, 0x98, 0xb6, 0xd1, 0x01, 0x56, 0xb2, 0x3e, 0x02,
		0xcc, 0xeb, 0xc9, 0x0e, 0xaa, 0x94, 0x75, 0x5e, 0x8f, 0xcc, 0xcc, 0x99, 0x8a, 0xd2, 0xb8, 0x9e,
		0x9b, 0xe8, 0x8e, 0xba, 0xa6, 0xf5, 0x6c, 0x11, 0x9e, 0xcf, 0x10, 0x4a, 0x88, 0x8f, 0x1f, 0xb1,
		0xce, 0xdd, 0x20, 0x6c, 0x86, 0xa1, 0x58, 0x02, 0xe3, 0x50, 0x07, 0x9c, 0x76, 0xd9, 0x10, 0x16,
		0x04, 0x62, 0xa2, 0x63, 0x28, 0xba, 0xa6, 0xae, 0x54, 0xf3, 0xa5, 0x5a, 0x57, 0x7e, 0x87, 0xf9,
		0xac, 0xf3, 0xcb, 0xf0, 0xc5, 0xbd, 0x7e, 0xb7, 0x4b, 0xba, 0x9f, 0x92, 0x74, 0xae, 0x40, 0xdf,
		0x96, 0xd0, 0xf4, 0x26, 0x39, 0x8a, 0xe6, 0xa3, 0xe5, 0xf5, 0x94, 0xb9, 0xfa, 0x13, 0x6b, 0xf6,
		0x58, 0x74, 0x6f, 0x65, 0xf6, 0x94, 0x63, 0x33, 0xc5, 0x37, 0x71, 0xf5, 0xee, 0xa5, 0xef, 0xc9,
		0x8a, 0xfd, 0xe0, 0x9c, 0xc3, 0x25, 0x34, 0x77, 0x8b, 0x73, 0xce, 0x16, 0xf7, 0x5c, 0x2d, 0x11,
		0xe3, 0x4b, 0xdc, 0xc8, 0x12, 0x35, 0xa6, 0xa4, 0x8d, 0x26, 0x69, 0xe3, 0x48, 0xca, 0x08, 0x52,
		0xe3, 0x10, 0xde, 0x39, 0x56, 0x96, 0xd3, 0x0f, 0xbf, 0xda, 0xcf, 0x6e, 0xf0, 0xec, 0x84, 0xed,
		0xaf, 0xfc, 0x7b, 0x98, 0xb4, 0x74, 0x9c, 0xb9, 0x9c, 0x57, 0xd5, 0x08, 0x41, 0x46, 0x61, 0xdb,
		0x5f, 0xc6, 0xd6, 0x97, 0xb7, 0xed, 0x65, 0x6d, 0x79, 0x65, 0xdb, 0x5d, 0xd9, 0x56, 0x57, 0xb2,
		0xcd, 0x69, 0xc1, 0x87, 0xb0, 0xad, 0x9d, 0x9c, 0x57, 0xbb, 0xd7, 0xf7, 0x42, 0xe6, 0x0b, 0xa5,
		0x21, 0x48, 0xa4, 0x1d, 0x48, 0xda, 0xcf, 0x12, 0xf8, 0x56, 0xc5, 0x3e, 0x56, 0xf5, 0xb2, 0x29,
		0x3a, 0xeb, 0x29, 0x8c, 0x2d, 0x19, 0x3f, 0xa9, 0x8a, 0x3d, 0x4b, 0xb5, 0x65, 0x74, 0x61, 0x7d,
		0x92, 0x5d, 0xd4, 0x64, 0x72, 0xb4, 0xa8, 0xe0, 0x1f, 0x87, 0x5a, 0x67, 0x9e, 0xf3, 0xa5, 0xcb,
		0x6c, 0x2f, 0x7c, 0xb1, 0x87, 0x5a, 0x46, 0x5c, 0x37, 0xcd, 0x2f, 0xc0, 0x29, 0x8b, 0x24, 0x6b,
		0xa1, 0xa0, 0xd5, 0xa0, 0xd5, 0xc8, 0xb4, 0x9a, 0x78, 0x2d, 0x91, 0x60, 0xed, 0x10, 0x25, 0x8b,
		0x76, 0x64, 0x59, 0xb3, 0x03, 0x96, 0x04, 0x4b, 0x82, 0x25, 0x49, 0x59, 0x72, 0xa8, 0xed, 0x82,
		0x88, 0x50, 0x6c, 0xd1, 0x91, 0xc4, 0xc9, 0xab, 0x2e, 0x59, 0x03, 0x0c, 0x07, 0x86, 0x33, 0xcc,
		0x70, 0x52, 0x93, 0x6b, 0x65, 0x26, 0xd4, 0xca, 0x4d, 0xa2, 0x55, 0x18, 0x09, 0xaf, 0x38, 0x59,
		0x56, 0x65, 0x88, 0x97, 0xf2, 0x08, 0x9d, 0x9c, 0x4f, 0x84, 0x6d, 0xc9, 0x6c, 0x09, 0xc5, 0x28,
		0x9c, 0xdc, 0x4f, 0x72, 0x6d, 0xe9, 0x8c, 0xea, 0xa9, 0x31, 0x43, 0xa3, 0xe0, 0xcc, 0x80, 0x91,
		0x95, 0x45, 0x98, 0x90, 0x9a, 0xb9, 0x68, 0x00, 0x99, 0x14, 0x62, 0xb2, 0x69, 0x2b, 0xef, 0xbe,
		0xb3, 0xfc, 0x86, 0x4e, 0x39, 0xf3, 0x2b, 0x44, 0x02, 0xa7, 0xeb, 0x13, 0x28, 0x56, 0x84, 0x4d,
		0xb7, 0x04, 0x76, 0x88, 0x77, 0x67, 0x44, 0x76, 0xc4, 0x5a, 0x19, 0xb7, 0xe5, 0xdc, 0x83, 0xe5,
		0x6f, 0xbf, 0xf8, 0x6e, 0x4b, 0xde, 0xcb, 0x1a, 0x3e, 0xdc, 0x63, 0xb7, 0xf7, 0xdf, 0xd4, 0x37,
		0x9a, 0x58, 0x47, 0xe3, 0x4f, 0xa6, 0xec, 0xce, 0xea, 0x90, 0xf0, 0x5a, 0x4b, 0x8e, 0xc7, 0x72,
		0xe3, 0x7d, 0x16, 0x11, 0xdb, 0x4c, 0xd8, 0x16, 0x13, 0xb6, 0xbd, 0x66, 0x6d, 0xad, 0xf1, 0x93,
		0x13, 0xd1, 0xe4, 0xba, 0x30, 0xae, 0xe5, 0x3c, 0x8d, 0xee, 0xcc, 0x19, 0xfd, 0x1f, 0x7d, 0x9c,
		0x38, 0xfa, 0xbf, 0xaf, 0x23, 0xfa, 0xbf, 0x9e, 0x04, 0x64, 0xcd, 0xf4, 0xac, 0xe3, 0xff, 0x6b,
		0x49, 0x84, 0x46, 0xd0, 0x73, 0x67, 0x00, 0xb4, 0xc7, 0xe7, 0x28, 0xe8, 0x25, 0x8a, 0xaf, 0x13,
		0xf3, 0x0c, 0x55, 0x73, 0xe9, 0x19, 0xe2, 0x27, 0xb6, 0xb2, 0xf9, 0x86, 0xb8, 0x89, 0x51, 0x8f,
		0x77, 0x88, 0x97, 0x48, 0x93, 0x0b, 0xbe, 0x38, 0xed, 0xbf, 0x7a, 0x8f, 0x8f, 0xf2, 0xf3, 0x25,
		0x26, 0xfe, 0xdc, 0xf9, 0x95, 0x04, 0xb7, 0x51, 0x2e, 0x6e, 0x2c, 0x5d, 0xc8, 0xa2, 0x52, 0xc0,
		0xa2, 0x42, 0xe8, 0xaa, 0x04, 0x4f, 0x46, 0xf8, 0x64, 0x0c, 0x40, 0xc4, 0x08, 0xe2, 0x06, 0x80,
		0x84, 0x5f, 0x45, 0xbe, 0x08, 0x45, 0xbd, 0x4b, 0x98, 0x42, 0x77, 0x30, 0xc5, 0x6a, 0x13, 0x85,
		0x92, 0x1b, 0x8a, 0xea, 0x12, 0xa2, 0x92, 0x06, 0xaa, 0xd2, 0x57, 0xca, 0x12, 0x06, 0x85, 0xea,
		0x11, 0x92, 0xaa, 0x11, 0xea, 0xad, 0xa5, 0xea, 0xe6, 0x45, 0xba, 0xc7, 0x86, 0xca, 0x34, 0x74,
		0xf9, 0x29, 0x04, 0x68, 0xc4, 0xea, 0x38, 0x61, 0x64, 0x09, 0xdb, 0x6e, 0x47, 0x5e, 0x13, 0x4f,
		0x2f, 0x02, 0x25, 0x0c, 0x25, 0x5c, 0x42, 0x25, 0x2c, 0x4f, 0xe2, 0xd9, 0xc7, 0x38, 0xfe, 0x9c,
		0xf6, 0xae, 0xce, 0x3b, 0x6d, 0x6b, 0x83, 0x9d, 0x1f, 0x47, 0x83, 0x9f, 0x0a, 0xe5, 0x8d, 0xd7,
		0xf3, 0x3e, 0x39, 0x90, 0xc6, 0x8f, 0x8e, 0xdb, 0xed, 0xfb, 0xcc, 0x7e, 0xee, 0x75, 0x98, 0xbc,
		0x38, 0x9e, 0x59, 0x05, 0xf2, 0x18, 0xf2, 0xb8, 0x84, 0xf2, 0x58, 0x81, 0xc6, 0x67, 0x04, 0xb2,
		0x44, 0x95, 0xb2, 0x75, 0xea, 0x8d, 0x7a, 0x87, 0x0d, 0x72, 0x20, 0x31, 0x5c, 0x6f, 0x08, 0x7b,
		0xbf, 0xb9, 0xe1, 0xab, 0xfd, 0xe2, 0xf7, 0xbe, 0x28, 0x48, 0x8d, 0x85, 0x95, 0x20, 0x39, 0x20,
		0x39, 0xe0, 0x4e, 0x81, 0x3b, 0x05, 0xee, 0x14, 0xb8, 0x53, 0xe0, 0x4e, 0xe1, 0xdb, 0xb6, 0x67,
		0xe7, 0xbb, 0x1d, 0xc7, 0x25, 0xe4, 0x35, 0xf1, 0xf4, 0x22, 0x50, 0xc2, 0x50, 0xc2, 0x50, 0xc2,
		0x50, 0xc2, 0x50, 0xc2, 0x50, 0xc2, 0x1b, 0xad, 0x84, 0x0b, 0xd5, 0xda, 0x67, 0x2c, 0xb8, 0xf7,
		0xa2, 0x74, 0xad, 0x3d, 0xa1, 0x44, 0x9b, 0x0a, 0x7f, 0x6e, 0xe1, 0x55, 0x7c, 0x9b, 0x87, 0xe6,
		0xf0, 0x36, 0x0f, 0xb1, 0x16, 0x37, 0x58, 0xab, 0xc6, 0xd7, 0xba, 0x66, 0x41, 0xfa, 0x8b, 0xb4,
		0xf1, 0x92, 0xce, 0x3b, 0xaa, 0x21, 0xef, 0x88, 0x16, 0xa2, 0x20, 0xef, 0x08, 0x79, 0x47, 0xc0,
		0xe8, 0xc0, 0xe8, 0xc0, 0xe8, 0xc0, 0xe8, 0xc0, 0xe8, 0xc0, 0xe8, 0x4a, 0x8e, 0x32, 0xe4, 0x1d,
		0x41, 0x09, 0x43, 0x09, 0xeb, 0x24, 0xf1, 0x0a, 0xf2, 0x8e, 0x26, 0xaf, 0x82, 0xbc, 0xa3, 0x95,
		0x6f, 0x86, 0xbc, 0x23, 0xc8, 0x63, 0xc8, 0x63, 0xcd, 0x34, 0x5e, 0x41, 0xde, 0xd1, 0xb2, 0x1d,
		0x45, 0xde, 0x11, 0x24, 0x07, 0xdc, 0x29, 0x70, 0xa7, 0xc0, 0x9d, 0x02, 0x77, 0x0a, 0xdc, 0x29,
		0x92, 0xea, 0x18, 0x79, 0x47, 0x50, 0xc2, 0x50, 0xc2, 0x50, 0xc2, 0x50, 0xc2, 0x50, 0xc2, 0x50,
		0xc2, 0x94, 0x4a, 0xb8, 0xc8, 0x79, 0x47, 0xa2, 0xe3, 0xf2, 0xe4, 0xd2, 0x8e, 0x04, 0x46, 0xe4,
		0x15, 0xb5, 0x37, 0xde, 0xec, 0xbe, 0xd2, 0x35, 0xc8, 0x9b, 0xdd, 0x49, 0x1d, 0xc3, 0xc5, 0xda,
		0x3d, 0x2f, 0xf4, 0x7b, 0xdd, 0x2e, 0xf3, 0x03, 0xfe, 0x26, 0x63, 0xd3, 0x17, 0xa1, 0xd5, 0x18,
		0x5a, 0x8d, 0x2d, 0x23, 0x27, 0xa9, 0x76, 0x63, 0xe3, 0x6b, 0xd1, 0x72, 0xcc, 0xa8, 0xb5, 0xb0,
		0xe1, 0xa9, 0x7f, 0x82, 0xfd, 0xf1, 0x96, 0x11, 0xae, 0x58, 0xfa, 0xae, 0x04, 0xf1, 0xc2, 0x24,
		0x86, 0x49, 0x2c, 0x63, 0x12, 0x8b, 0x32, 0x43, 0x72, 0x61, 0x0c, 0x4d, 0x24, 0x0f, 0x2b, 0x19,
		0x34, 0x32, 0xfc, 0xbe, 0x9b, 0xc9, 0xdc, 0x36, 0x59, 0x46, 0xa1, 0x60, 0x18, 0x4a, 0xc6, 0xa1,
		0x62, 0x20, 0x72, 0x46, 0x22, 0x67, 0x28, 0x62, 0xc6, 0x52, 0x34, 0x31, 0x25, 0xa9, 0x46, 0xda,
		0x07, 0xb5, 0x40, 0x33, 0x41, 0xe8, 0xbb, 0xde, 0x93, 0x0a, 0xc5, 0x24, 0xd9, 0x3d, 0x98, 0x2b,
		0x2f, 0x63, 0xcc, 0x4d, 0x99, 0x39, 0x53, 0x3f, 0xef, 0x49, 0xa9, 0x7b, 0x19, 0xa3, 0xef, 0xc3,
		0xe4, 0xfe, 0x53, 0x3f, 0x0b, 0x95, 0xf1, 0x48, 0x38, 0x34, 0x76, 0x85, 0x80, 0x93, 0xc7, 0x22,
		0x4f, 0x50, 0xa0, 0x84, 0x9e, 0x92, 0x45, 0x00, 0xa1, 0x00, 0xa1, 0xca, 0x03, 0xa1, 0x26, 0x94,
		0xad, 0x0e, 0xa4, 0xa6, 0xd6, 0x52, 0x83, 0x53, 0x55, 0xc0, 0x29, 0xc0, 0xa9, 0xe2, 0xc0, 0x29,
		0x59, 0xe6, 0x4b, 0x16, 0x70, 0xfa, 0xdf, 0x65, 0x6a, 0x08, 0x52, 0x49, 0x2f, 0x5e, 0x6f, 0x37,
		0x17, 0x91, 0x1d, 0x55, 0xa6, 0xa4, 0x64, 0x4e, 0x1d, 0x4c, 0x4a, 0xcd, 0xac, 0xda, 0x98, 0x56,
		0x1b, 0xf3, 0x6a, 0x62, 0x62, 0x35, 0x66, 0x56, 0x64, 0x6a, 0x3a, 0x5b, 0x69, 0x81, 0xe6, 0xba,
		0xcc, 0x79, 0xf4, 0xd9, 0x23, 0x05, 0xc9, 0x8d, 0xf5, 0xe5, 0x11, 0xc1, 0x5a, 0x9f, 0x63, 0xa3,
		0xe3, 0xdd, 0xbb, 0xd8, 0x7a, 0xd8, 0x8b, 0xc5, 0xc8, 0x56, 0x36, 0x87, 0xa7, 0x12, 0xd9, 0x96,
		0xf4, 0x96, 0xd2, 0x7a, 0x4f, 0x89, 0xd1, 0x0d, 0x04, 0x2a, 0x04, 0x6a, 0x19, 0x04, 0xaa, 0x2a,
		0x5a, 0x9a, 0xa0, 0x26, 0xc1, 0xc9, 0xd2, 0xfc, 0xf0, 0x49, 0x7a, 0x0e, 0xa8, 0x46, 0x1c, 0x45,
		0xce, 0xfe, 0x3a, 0xc4, 0x80, 0x4e, 0x71, 0xa0, 0x4b, 0x2c, 0x68, 0x17, 0x0f, 0xda, 0xc5, 0x84,
		0x66, 0x71, 0x41, 0x23, 0x36, 0x88, 0xc4, 0x07, 0x3d, 0x2e, 0x5b, 0xa0, 0x59, 0xa9, 0x91, 0xdf,
		0xdc, 0xca, 0xff, 0x98, 0x70, 0x4d, 0xa9, 0x91, 0xe1, 0xeb, 0xbe, 0x68, 0xb9, 0xaa, 0x42, 0x38,
		0x72, 0x9c, 0x7b, 0x8f, 0xdf, 0x6b, 0x58, 0x5b, 0xb5, 0xf2, 0x76, 0xed, 0x0d, 0xf2, 0x3d, 0xd2,
		0x7c, 0xdd, 0x57, 0x4b, 0xc7, 0x96, 0x53, 0x54, 0x3c, 0xaf, 0xbd, 0x4b, 0xde, 0x47, 0xa6, 0xaf,
		0xdd, 0x79, 0xd2, 0x15, 0x07, 0xbb, 0x05, 0x12, 0x26, 0x0d, 0x08, 0x93, 0x95, 0xc2, 0x04, 0xb3,
		0xbe, 0x8b, 0x30, 0x12, 0xbe, 0xf4, 0xa2, 0x15, 0x64, 0x58, 0x88, 0x91, 0xf3, 0x86, 0x15, 0xcd,
		0x56, 0xbe, 0x9e, 0x4b, 0xfd, 0x79, 0x08, 0x54, 0x27, 0x55, 0x24, 0x68, 0xd1, 0xa5, 0x41, 0x11,
		0x11, 0x82, 0x47, 0x03, 0x1e, 0x0d, 0x78, 0x34, 0x0a, 0xe8, 0xd1, 0x70, 0xfa, 0xdf, 0xdd, 0xae,
		0xeb, 0xf8, 0xaf, 0x74, 0x32, 0x60, 0x5a, 0x0e, 0xd4, 0x09, 0x97, 0x54, 0xab, 0x33, 0x35, 0x68,
		0x86, 0x50, 0xd4, 0xa5, 0x1a, 0x12, 0xb0, 0x0b, 0xcb, 0x13, 0xd5, 0xb1, 0xa6, 0xae, 0x4f, 0x58,
		0x7b, 0x69, 0xc8, 0x4e, 0xad, 0x50, 0xd5, 0xc3, 0x66, 0x7d, 0xa4, 0xd5, 0x7a, 0x81, 0xcf, 0x14,
		0x00, 0x53, 0x3b, 0xc0, 0x6c, 0x33, 0x3f, 0x74, 0x1f, 0xdd, 0xb6, 0x13, 0x32, 0x2d, 0x40, 0x73,
		0x6e, 0x7d, 0x00, 0x4e, 0x00, 0x4e, 0x00, 0xce, 0x8d, 0x03, 0x9c, 0xca, 0x65, 0x21, 0xe9, 0xde,
		0xd8, 0x12, 0xc9, 0xe2, 0x97, 0x9e, 0x1f, 0xd2, 0x4b, 0xe0, 0x68, 0x55, 0x22, 0x0a, 0xf9, 0xc8,
		0x1e, 0x9d, 0x7e, 0x37, 0x62, 0x86, 0x46, 0xa3, 0x7e, 0x00, 0x71, 0x0e, 0x71, 0x0e, 0x71, 0xbe,
		0x79, 0xe2, 0x7c, 0x28, 0x52, 0x6c, 0xaf, 0xff, 0xfc, 0x85, 0xbb, 0xed, 0x81, 0x88, 0x18, 0x68,
		0xc0, 0x7d, 0x00, 0xf7, 0x01, 0xdc, 0x07, 0xb9, 0x38, 0xd2, 0x46, 0xbd, 0x7e, 0x00, 0x0f, 0x02,
		0x3c, 0x08, 0xab, 0x50, 0xab, 0xef, 0xf6, 0x7c, 0x37, 0x7c, 0xd5, 0x80, 0x5c, 0xc7, 0x2b, 0x03,
		0x66, 0x02, 0x66, 0x02, 0x66, 0x6e, 0x1c, 0xcc, 0xec, 0xbb, 0x5e, 0xf8, 0x1e, 0xf1, 0x29, 0x00,
		0x4c, 0x00, 0xcc, 0xd2, 0x02, 0xcc, 0x5a, 0x1d, 0xf0, 0x12, 0xf0, 0x72, 0xc5, 0x31, 0x06, 0x11,
		0xc8, 0x18, 0x0d, 0xa6, 0x7d, 0x74, 0x28, 0xcb, 0xff, 0x12, 0xe7, 0xf4, 0xfc, 0x1d, 0x00, 0x37,
		0x01, 0x37, 0x01, 0x37, 0x37, 0x0e, 0x6e, 0x7e, 0x71, 0x82, 0x29, 0x29, 0x60, 0xd3, 0x94, 0xe4,
		0xcf, 0x4b, 0x03, 0x8a, 0xd2, 0xfc, 0x09, 0x07, 0x27, 0x7d, 0xc1, 0xda, 0xb6, 0xfb, 0x78, 0x92,
		0x3c, 0x7b, 0x30, 0xff, 0x87, 0xf8, 0xf7, 0xa8, 0x8b, 0x57, 0x89, 0x74, 0x43, 0xe8, 0x3b, 0x5e,
		0xa0, 0x27, 0x6a, 0x36, 0x59, 0x9a, 0x3e, 0x74, 0x76, 0xfb, 0xe1, 0x33, 0x74, 0x0c, 0x74, 0x0c,
		0x74, 0xcc, 0xe6, 0xe9, 0x18, 0x6a, 0xb1, 0x52, 0x51, 0x9c, 0xbf, 0x98, 0xba, 0xa6, 0xdc, 0x5c,
		0x46, 0x8d, 0xea, 0x22, 0xd3, 0x1e, 0x15, 0x8a, 0x6d, 0x3c, 0x17, 0x8d, 0x1a, 0xba, 0xb6, 0x9e,
		0xe3, 0x3e, 0x94, 0x53, 0x3f, 0xef, 0x91, 0xb4, 0xa7, 0xa9, 0x90, 0x76, 0xff, 0x1c, 0x3f, 0xe6,
		0xd4, 0xcf, 0x52, 0x4d, 0x41, 0xe9, 0xe8, 0x42, 0xa5, 0x9f, 0xd0, 0x68, 0x08, 0x09, 0x59, 0x3b,
		0x21, 0xd1, 0x99, 0x26, 0x2b, 0xa5, 0x00, 0x55, 0x37, 0xa1, 0x1a, 0xba, 0x09, 0xe5, 0x42, 0xc5,
		0xa3, 0x9b, 0x90, 0x10, 0xcc, 0x46, 0x37, 0x21, 0x58, 0x00, 0xb0, 0x00, 0x60, 0x01, 0xe4, 0xd5,
		0x02, 0x40, 0x37, 0x21, 0xe2, 0x2f, 0x74, 0x13, 0xe2, 0xb9, 0x01, 0xba, 0x09, 0x2d, 0x6c, 0x39,
		0xba, 0x09, 0xf1, 0xec, 0x3c, 0xba, 0x09, 0x41, 0x98, 0x2c, 0x17, 0x26, 0x68, 0xe3, 0x82, 0x6e,
		0x42, 0x39, 0x10, 0xad, 0x20, 0x43, 0x74, 0x13, 0xd2, 0x64, 0x4d, 0x54, 0xd0, 0x4d, 0x88, 0xcf,
		0xa5, 0x81, 0x6e, 0x42, 0xf0, 0x68, 0xc0, 0xa3, 0xb1, 0xa1, 0x1e, 0x0d, 0x74, 0x13, 0x42, 0xb6,
		0xf6, 0xf4, 0xf2, 0xc8, 0xd6, 0x5e, 0x7e, 0xa4, 0xe8, 0x26, 0x94, 0xed, 0x99, 0x02, 0x60, 0x6a,
		0x07, 0x98, 0xe8, 0x26, 0x04, 0xc0, 0x09, 0xc0, 0x09, 0xc0, 0x89, 0x6e, 0x42, 0x39, 0x90, 0xc5,
		0xa3, 0x44, 0x2b, 0xa6, 0x43, 0x0c, 0x27, 0x4b, 0x43, 0x02, 0x43, 0x02, 0x43, 0x02, 0x6f, 0x9c,
		0x04, 0xfe, 0xd2, 0xeb, 0x75, 0x99, 0xe3, 0xe9, 0x10, 0xc1, 0x55, 0x34, 0x74, 0x5b, 0xb3, 0xf9,
		0x68, 0xe8, 0x06, 0x79, 0x0e, 0x79, 0x0e, 0x79, 0x4e, 0x2c, 0x52, 0xd0, 0xd0, 0x8d, 0x94, 0x30,
		0xe1, 0xc1, 0x4d, 0x5f, 0x1f, 0x1e, 0xdc, 0xcc, 0x8e, 0x14, 0x0d, 0xdd, 0xb4, 0xac, 0x86, 0x86,
		0x6e, 0x5c, 0x6a, 0x06, 0x0d, 0xdd, 0x00, 0x33, 0x01, 0x33, 0x37, 0x16, 0x66, 0xa2, 0xa1, 0x1b,
		0x00, 0x26, 0x00, 0x66, 0xb9, 0x01, 0x26, 0x1a, 0xba, 0x01, 0x5e, 0xae, 0x3c, 0x46, 0x34, 0x74,
		0x03, 0xdc, 0x04, 0xdc, 0x04, 0xdc, 0xd4, 0x0f, 0x37, 0xd1, 0xd0, 0xad, 0x68, 0xba, 0x01, 0x0d,
		0xdd, 0xa0, 0x63, 0xa0, 0x63, 0xa0, 0x63, 0x8a, 0xa3, 0x63, 0xd0, 0xd0, 0x2d, 0x93, 0x15, 0x36,
		0xac, 0xa1, 0x1b, 0x45, 0x83, 0xb0, 0x8a, 0xf6, 0x7e, 0x6e, 0x37, 0xd1, 0x53, 0x66, 0xd5, 0xce,
		0x6d, 0xcb, 0x20, 0x1d, 0x0d, 0xc5, 0xbf, 0x72, 0xe1, 0xa3, 0x75, 0xee, 0x06, 0x61, 0x33, 0x0c,
		0xd5, 0x1a, 0x56, 0x59, 0x17, 0xae, 0x77, 0xda, 0x65, 0x43, 0x49, 0x1e, 0xa8, 0xe9, 0x79, 0xeb,
		0xc2, 0xf9, 0x3e, 0xb5, 0x52, 0xf5, 0xfd, 0xe1, 0x61, 0xe3, 0xe8, 0xf0, 0x70, 0xff, 0xe8, 0xe0,
		0x68, 0xff, 0xb8, 0x5e, 0xaf, 0x36, 0x54, 0xaa, 0x3f, 0xac, 0x2b, 0xbf, 0xc3, 0x7c, 0xd6, 0xf9,
		0x65, 0xb8, 0x6f, 0x5e, 0xbf, 0xdb, 0x35, 0x7a, 0x5c, 0x44, 0xec, 0xae, 0x99, 0xcd, 0x2d, 0xa5,
		0x8e, 0x84, 0xfa, 0x18, 0x5b, 0x8e, 0xa5, 0xc5, 0x19, 0x52, 0xec, 0x0a, 0x41, 0x5a, 0x50, 0xa5,
		0x01, 0x1d, 0x67, 0x2f, 0x71, 0xe0, 0xf4, 0x07, 0x2d, 0x76, 0xba, 0xfc, 0x67, 0x24, 0x70, 0x3e,
		0x56, 0xfc, 0x3a, 0x62, 0xa7, 0x92, 0x60, 0xb0, 0xe8, 0x6a, 0x41, 0x6a, 0x90, 0xb3, 0xb3, 0xa4,
		0xed, 0x29, 0x15, 0xbb, 0x89, 0xc2, 0x3e, 0x52, 0xb5, 0x83, 0xc8, 0xec, 0x1d, 0x32, 0xbb, 0x86,
		0xc8, 0x7e, 0xd1, 0x2b, 0x73, 0xa4, 0xed, 0x8e, 0xe4, 0xcc, 0xbb, 0xcc, 0x79, 0x94, 0x73, 0x5c,
		0xa9, 0x38, 0xa8, 0x12, 0x47, 0xd4, 0xbb, 0x77, 0x71, 0x33, 0xe1, 0x3d, 0x71, 0x57, 0x93, 0x1e,
		0x51, 0x21, 0xd7, 0x7a, 0x57, 0xa9, 0xd5, 0xae, 0x64, 0x6b, 0x5d, 0xe9, 0x56, 0xba, 0x10, 0x16,
		0x1b, 0x29, 0x2c, 0x64, 0x5b, 0xd7, 0xca, 0x69, 0x4f, 0x0a, 0x2d, 0x4a, 0xe4, 0xb5, 0x54, 0xf6,
		0x52, 0x52, 0x78, 0x25, 0x29, 0xbd, 0x90, 0x54, 0x5e, 0x47, 0x72, 0x2f, 0x23, 0xb9, 0x57, 0x91,
		0xd8, 0x8b, 0x68, 0xd6, 0x88, 0x57, 0xf6, 0x0a, 0xd2, 0x55, 0xa4, 0x2a, 0x56, 0xa0, 0xc2, 0xd6,
		0x5a, 0x6e, 0x6b, 0xc9, 0xfa, 0xcd, 0x88, 0xac, 0x2c, 0x09, 0x87, 0x98, 0x00, 0x68, 0xda, 0x22,
		0x3c, 0xb9, 0xb1, 0x43, 0x4b, 0x40, 0x09, 0xc8, 0xb9, 0xaf, 0xe4, 0xdd, 0x55, 0xa4, 0xee, 0x29,
		0x39, 0x77, 0x14, 0xef, 0x66, 0x4a, 0x92, 0x3f, 0x15, 0xd9, 0x5b, 0x42, 0x70, 0x9a, 0x80, 0xd0,
		0xf9, 0x48, 0x7c, 0x3d, 0xc1, 0xae, 0xfe, 0xc4, 0x9a, 0xdd, 0x17, 0xdd, 0x75, 0xa5, 0xdd, 0xe6,
		0xd8, 0x62, 0x85, 0xad, 0x5d, 0xbd, 0x9f, 0xe9, 0xbb, 0xb4, 0xfc, 0x5f, 0x52, 0xf6, 0x8d, 0x77,
		0xbf, 0x84, 0xf7, 0x69, 0xc5, 0xde, 0x08, 0xee, 0xc9, 0xf2, 0x7d, 0x58, 0x7c, 0xcb, 0x25, 0x6f,
		0x68, 0xbd, 0xf8, 0xbd, 0x36, 0x0b, 0x02, 0x96, 0x3e, 0xc1, 0x61, 0xaa, 0x2c, 0x61, 0xfc, 0xd1,
		0x94, 0x9d, 0x5a, 0x6d, 0xff, 0xad, 0x85, 0xaf, 0x3c, 0xf0, 0x74, 0x02, 0x3f, 0xdb, 0xf6, 0xf0,
		0x79, 0x56, 0x6d, 0x22, 0x27, 0xba, 0x14, 0x46, 0x8f, 0xc2, 0xe8, 0x70, 0x16, 0xfd, 0xc5, 0x0f,
		0x4e, 0x44, 0x9d, 0xeb, 0xac, 0xa1, 0xf1, 0xa9, 0xad, 0xdf, 0x86, 0xb9, 0x63, 0x5e, 0xb7, 0x09,
		0x7c, 0xc6, 0x3e, 0xb7, 0x71, 0x2f, 0x62, 0x9b, 0x08, 0x10, 0x81, 0xac, 0xa9, 0x21, 0x6d, 0x52,
		0x48, 0x9b, 0x0e, 0x62, 0x44, 0x42, 0xa3, 0x0a, 0x78, 0x4d, 0x69, 0xeb, 0x45, 0xa0, 0x4b, 0xd5,
		0x84, 0x90, 0xb8, 0x43, 0x7e, 0x82, 0x86, 0xb1, 0xb0, 0x21, 0x2c, 0x63, 0xf8, 0x4a, 0x10, 0x99,
		0xaa, 0x5d, 0xab, 0x6c, 0xc7, 0x2a, 0xdb, 0xad, 0x72, 0x44, 0xa8, 0x07, 0x6a, 0x0b, 0x9b, 0x9d,
		0x0a, 0xce, 0x60, 0x19, 0x27, 0xf0, 0xb4, 0xf3, 0x37, 0x32, 0xa0, 0xf6, 0x86, 0x04, 0x4f, 0x05,
		0xf1, 0xb8, 0x80, 0x93, 0x88, 0x8b, 0x57, 0xca, 0xb5, 0x2b, 0xe8, 0xd2, 0x15, 0x76, 0xe5, 0x82,
		0x31, 0x0b, 0xc8, 0x98, 0xa2, 0x0e, 0x58, 0xcb, 0xf1, 0x9f, 0x02, 0xf9, 0x50, 0x44, 0x74, 0xf5,
		0x26, 0x84, 0x2d, 0x85, 0xc9, 0x79, 0x53, 0x02, 0x11, 0xa2, 0xe4, 0x6e, 0xc6, 0x79, 0xa7, 0x1e,
		0xb4, 0x94, 0x76, 0x87, 0x4a, 0xba, 0x41, 0x45, 0xdf, 0x50, 0x29, 0xf1, 0x4a, 0x3d, 0xe1, 0x4a,
		0x4b, 0xa2, 0x95, 0x5a, 0x82, 0x95, 0x9e, 0x58, 0x6d, 0xfb, 0xa5, 0x6f, 0xf7, 0x03, 0xe7, 0x89,
		0xc5, 0x9e, 0x02, 0x79, 0x59, 0xb9, 0xb0, 0x12, 0xe4, 0x26, 0xe4, 0x66, 0xe9, 0xe4, 0x66, 0xbb,
		0xd7, 0xf7, 0x42, 0xe6, 0x37, 0x0e, 0x15, 0x44, 0xa7, 0xc4, 0x40, 0x29, 0xc5, 0x9a, 0x77, 0xb5,
		0xdc, 0x55, 0x82, 0x20, 0x29, 0x49, 0xc9, 0x0c, 0x55, 0x4d, 0x3a, 0x65, 0x99, 0xf2, 0x40, 0x2d,
		0x99, 0x37, 0x77, 0x5b, 0x4b, 0x9b, 0x52, 0x4c, 0xbe, 0xdb, 0x86, 0x42, 0xaf, 0xad, 0x5c, 0x69,
		0xe6, 0x7e, 0xc0, 0x7c, 0x0a, 0xbd, 0x1c, 0xad, 0x03, 0xad, 0x0c, 0xad, 0x0c, 0xad, 0x0c, 0xad,
		0x0c, 0xad, 0x0c, 0xad, 0x0c, 0xad, 0x2c, 0xa7, 0x95, 0x43, 0xb7, 0xeb, 0xfe, 0x2d, 0x97, 0x3b,
		0x35, 0xab, 0x96, 0xa7, 0x16, 0x82, 0x5e, 0x86, 0x5e, 0x2e, 0x9d, 0x5e, 0x7e, 0x61, 0x7e, 0x9b,
		0x79, 0xa1, 0xf3, 0xc4, 0x14, 0x14, 0x73, 0x1d, 0x8a, 0x19, 0x8a, 0x39, 0xaf, 0x8a, 0x79, 0x7f,
		0x1f, 0x7a, 0x38, 0x0b, 0x3d, 0xfc, 0xcc, 0x9e, 0x7b, 0xfe, 0xeb, 0xc8, 0xb0, 0x95, 0x57, 0xc2,
		0x33, 0xab, 0x40, 0x03, 0x43, 0x03, 0x97, 0x4e, 0x03, 0xf7, 0x5d, 0x2f, 0x84, 0x59, 0x0c, 0xed,
		0x0b, 0xb3, 0x18, 0xea, 0xd8, 0x80, 0x3a, 0xa6, 0xb0, 0x8c, 0x97, 0xac, 0x05, 0xd5, 0x0c, 0xd5,
		0x0c, 0xe3, 0x18, 0xc6, 0x31, 0xd4, 0x33, 0x8c, 0x63, 0x68, 0xe3, 0xb5, 0xdb, 0x86, 0x5e, 0x3d,
		0xd0, 0xb8, 0xd0, 0xb8, 0x8b, 0x27, 0x6e, 0x3c, 0xe9, 0x55, 0x0b, 0x77, 0xbf, 0x48, 0x8c, 0xed,
		0x97, 0x28, 0x8c, 0x02, 0x6f, 0x83, 0xb7, 0xe1, 0xe8, 0x02, 0x92, 0x06, 0x92, 0x86, 0xa3, 0x0b,
		0xd0, 0x7a, 0xbc, 0x6d, 0x41, 0xe8, 0xf8, 0xa1, 0x1d, 0xba, 0xcf, 0x6a, 0x0d, 0xee, 0xc6, 0x6b,
		0x40, 0x15, 0x43, 0x15, 0x97, 0x4e, 0x15, 0x0f, 0x29, 0x3b, 0x74, 0xdb, 0x7f, 0x05, 0xc6, 0xf5,
		0xf1, 0x6f, 0xde, 0x48, 0x96, 0x59, 0x9e, 0xe3, 0xf5, 0x02, 0xd6, 0xee, 0x79, 0x1d, 0xa9, 0x0e,
		0xbe, 0xd0, 0xeb, 0xd0, 0xeb, 0xd0, 0xeb, 0x85, 0xd7, 0xeb, 0x85, 0xea, 0x18, 0x96, 0xb4, 0x38,
		0x1a, 0xff, 0x24, 0xdc, 0x1a, 0x8f, 0xb3, 0x75, 0xd3, 0xe7, 0xf1, 0x8d, 0xc6, 0x3f, 0x89, 0x34,
		0xc1, 0xd3, 0xdd, 0x21, 0x2c, 0x6e, 0x72, 0xb7, 0xde, 0x4d, 0x21, 0x56, 0x21, 0x2c, 0x5e, 0x11,
		0x4c, 0x52, 0x01, 0x2c, 0x56, 0xf1, 0x9b, 0x55, 0xf7, 0xb4, 0x05, 0xca, 0xa3, 0x6b, 0x9d, 0xb6,
		0x40, 0x6b, 0xc5, 0xec, 0x9b, 0xb6, 0xae, 0xfd, 0x98, 0xcc, 0x8e, 0xa8, 0x74, 0x4e, 0x0b, 0x82,
		0xaf, 0x76, 0xc0, 0xfc, 0x6f, 0x2b, 0xea, 0xc2, 0x26, 0xd6, 0xc6, 0xe4, 0xb3, 0xf9, 0xe8, 0x9d,
		0x16, 0xbc, 0x06, 0x76, 0xc8, 0xfc, 0xe7, 0x42, 0xf6, 0x4f, 0x4b, 0x1e, 0xde, 0x54, 0x0f, 0xb5,
		0xf6, 0x78, 0xf7, 0x39, 0x5b, 0xa8, 0xc5, 0x9f, 0x27, 0xee, 0xa0, 0xb6, 0xaf, 0xa7, 0x83, 0x1a,
		0x07, 0x29, 0xc8, 0x1a, 0x83, 0xd9, 0x77, 0x51, 0x5b, 0x4f, 0x2a, 0x34, 0x2a, 0x93, 0xbb, 0x93,
		0x1a, 0xf3, 0x9c, 0x2f, 0x5d, 0x89, 0xae, 0x4d, 0xf1, 0x75, 0xbc, 0x2d, 0x7a, 0x26, 0x43, 0x17,
		0x87, 0x7b, 0x57, 0x92, 0x36, 0x6c, 0x02, 0x94, 0xaa, 0xea, 0xbe, 0xc8, 0x5f, 0xc7, 0x27, 0x7e,
		0x4a, 0xd6, 0x03, 0xbd, 0xe5, 0xdb, 0xb1, 0x7d, 0xe9, 0xf5, 0xba, 0xcc, 0xf1, 0x64, 0xda, 0xb1,
		0x55, 0x0d, 0xb6, 0x53, 0x7b, 0xf1, 0x7b, 0x61, 0xaf, 0xdd, 0xeb, 0xda, 0xdf, 0x98, 0x1f, 0x88,
		0x58, 0x18, 0xd3, 0x9d, 0x33, 0x67, 0x57, 0x10, 0xe7, 0xd6, 0xdf, 0x6b, 0xe0, 0x55, 0xf0, 0x6a,
		0x76, 0xbc, 0xca, 0xbc, 0xfe, 0x33, 0xf3, 0x45, 0x13, 0x3e, 0x65, 0x26, 0x71, 0x0a, 0x4e, 0xda,
		0xa4, 0xe1, 0x71, 0xdf, 0x09, 0x99, 0xdd, 0x75, 0x9f, 0xdd, 0x50, 0x9c, 0xbb, 0xa7, 0xae, 0x05,
		0x8b, 0x82, 0x45, 0x33, 0x63, 0xd1, 0xbe, 0xeb, 0x85, 0xd5, 0x86, 0x04, 0x77, 0x36, 0x04, 0x2e,
		0x91, 0x73, 0xbe, 0xcb, 0x75, 0x89, 0x53, 0x88, 0x2d, 0xa9, 0xcd, 0xd3, 0x51, 0x74, 0xae, 0x53,
		0xb8, 0x79, 0x07, 0x72, 0x6d, 0xf1, 0x32, 0xdf, 0xb2, 0x46, 0xbd, 0x7e, 0x50, 0xcf, 0x70, 0xdb,
		0x34, 0x79, 0xab, 0x5b, 0x26, 0xdb, 0xf7, 0xb2, 0x60, 0x08, 0x12, 0x65, 0xd5, 0xd1, 0xec, 0xe5,
		0xd0, 0x48, 0xd0, 0x48, 0xd0, 0x48, 0xd0, 0x48, 0xd0, 0x48, 0xd0, 0x48, 0xd2, 0x1a, 0x29, 0x74,
		0x9f, 0x59, 0xaf, 0x2f, 0xa1, 0x8b, 0xc6, 0x17, 0x42, 0x0b, 0x41, 0x0b, 0x41, 0x0b, 0x41, 0x0b,
		0x41, 0x0b, 0x41, 0x0b, 0x49, 0x7c, 0x22, 0xab, 0xdc, 0x8b, 0x49, 0x74, 0x7e, 0x8f, 0x2b, 0x72,
		0x5b, 0xe1, 0xcf, 0x34, 0xb8, 0x09, 0xbe, 0xde, 0x44, 0x2b, 0x3f, 0xc4, 0x5a, 0x4c, 0x36, 0xf5,
		0x62, 0x65, 0xce, 0x03, 0xcf, 0x1c, 0x18, 0xa1, 0xf9, 0x2f, 0x79, 0x99, 0xee, 0x85, 0xd8, 0x34,
		0x01, 0xdb, 0x20, 0x36, 0x0d, 0xd0, 0x08, 0xd0, 0xb8, 0xfc, 0xe4, 0x10, 0x9b, 0xe6, 0xe7, 0x56,
		0xc4, 0xa6, 0xc1, 0xab, 0x59, 0xf2, 0x2a, 0x62, 0xd3, 0xa9, 0x5b, 0x83, 0xd8, 0x34, 0x58, 0x14,
		0x3e, 0x18, 0xf8, 0x60, 0xe0, 0x83, 0x81, 0x0f, 0x86, 0x42, 0x17, 0x21, 0x36, 0x0d, 0x8d, 0x04,
		0x8d, 0x04, 0x8d, 0x04, 0x8d, 0x04, 0x8d, 0x94, 0x0f, 0x8d, 0x84, 0xd8, 0x34, 0xb4, 0x10, 0xb4,
		0x10, 0xb4, 0x10, 0xb4, 0x10, 0xb4, 0x90, 0x26, 0x2d, 0x94, 0xf7, 0xd8, 0x34, 0x6f, 0x2b, 0x0a,
		0xe1, 0xd0, 0x34, 0x47, 0xeb, 0x89, 0xbc, 0x36, 0x05, 0x58, 0x5b, 0x58, 0x2f, 0xb3, 0x21, 0x4a,
		0x5d, 0x01, 0x56, 0x06, 0xe3, 0xb9, 0x82, 0xf0, 0xdc, 0xbd, 0x00, 0x6a, 0x64, 0xbd, 0x00, 0x8a,
		0xda, 0x06, 0xc0, 0x58, 0x07, 0x80, 0x2f, 0xbd, 0x1e, 0x67, 0xc7, 0xb9, 0xe9, 0xd0, 0x22, 0x57,
		0x83, 0x39, 0x4e, 0xf1, 0x6e, 0xa2, 0x0f, 0x40, 0x59, 0xd3, 0x2c, 0x74, 0x67, 0x58, 0x70, 0x03,
		0x43, 0xc9, 0xf6, 0x6c, 0x02, 0xed, 0xd8, 0x64, 0xdb, 0xaf, 0x09, 0xa2, 0x47, 0x01, 0x0c, 0x2c,
		0x83, 0x16, 0x65, 0x9b, 0x2c, 0x4a, 0xa2, 0x43, 0x15, 0x78, 0x23, 0xd2, 0xb8, 0x52, 0x06, 0x05,
		0xaa, 0x6e, 0x85, 0x7a, 0x7b, 0x33, 0xa5, 0xdd, 0x21, 0x02, 0x67, 0x2d, 0x0d, 0x79, 0x73, 0xed,
		0xbe, 0xef, 0x33, 0x2f, 0xb4, 0x3b, 0x4e, 0xc8, 0xc4, 0x44, 0xfb, 0xc2, 0x95, 0x90, 0xf0, 0x90,
		0xf0, 0x73, 0xfb, 0x3d, 0xa4, 0x0d, 0xdb, 0xf1, 0x3a, 0xbc, 0x3d, 0x66, 0x27, 0xed, 0xed, 0x39,
		0x3e, 0xfb, 0xd9, 0x09, 0x43, 0xe6, 0x7b, 0xdc, 0xe2, 0xda, 0xba, 0xdb, 0xb7, 0x8f, 0x5b, 0x3f,
		0x0e, 0x07, 0xf7, 0xf7, 0xf6, 0xf6, 0xfe, 0x5d, 0xd5, 0x3e, 0x6e, 0xbd, 0x55, 0xef, 0xf6, 0xed,
		0x5a, 0x6b, 0x67, 0xea, 0x2f, 0x77, 0x55, 0xbb, 0xd6, 0x8a, 0x3e, 0xf9, 0x76, 0x70, 0xb7, 0x6f,
		0x57, 0x5b, 0x3b, 0xb7, 0xdb, 0xd1, 0xf7, 0xd1, 0xdf, 0x6a, 0x77, 0xfb, 0xf6, 0x41, 0x6b, 0xe7,
		0xe4, 0x6e, 0xdf, 0xae, 0x8f, 0xfe, 0x74, 0xb2, 0x3d, 0xf9, 0xf9, 0xad, 0xb1, 0xbf, 0xb3, 0x7d,
		0x7f, 0xff, 0x2e, 0xfa, 0xe5, 0x7f, 0x76, 0x7e, 0xde, 0xfe, 0xcf, 0xdb, 0xf6, 0xdd, 0xff, 0xd8,
		0xad, 0xd5, 0x2b, 0xec, 0xec, 0xac, 0x3f, 0xb9, 0x16, 0xcf, 0x86, 0x5c, 0xdd, 0x9c, 0xfd, 0x5b,
		0x78, 0x57, 0xfe, 0xcc, 0xef, 0xb6, 0xfc, 0x64, 0x65, 0x22, 0x13, 0x3b, 0xbd, 0x67, 0xc7, 0xf5,
		0x6c, 0xae, 0xe1, 0x25, 0x13, 0x52, 0x9f, 0xba, 0x08, 0x92, 0x10, 0x92, 0x50, 0x9a, 0x3c, 0x84,
		0xe5, 0xe0, 0x39, 0xf3, 0x9e, 0x22, 0x17, 0x41, 0x29, 0x50, 0x6b, 0x15, 0xa8, 0x75, 0xbc, 0x15,
		0xb5, 0xfa, 0x41, 0x01, 0x41, 0xaa, 0x0e, 0xcd, 0xbd, 0xbd, 0xbd, 0xbd, 0x7d, 0xe7, 0xd8, 0x7f,
		0x37, 0xed, 0xff, 0xec, 0xdb, 0xc7, 0x0f, 0xad, 0xa9, 0x5f, 0xee, 0xef, 0xed, 0x87, 0xd6, 0xce,
		0x8f, 0xfd, 0xdd, 0x46, 0x75, 0xb0, 0xf3, 0xf3, 0xe4, 0xef, 0xad, 0xfb, 0xfb, 0x77, 0x3b, 0xff,
		0x90, 0xb9, 0xea, 0xe7, 0x9d, 0xb7, 0xe1, 0xb5, 0x99, 0xea, 0xe4, 0x2c, 0x5e, 0x38, 0x23, 0x6d,
		0xfb, 0xb5, 0x17, 0x84, 0x62, 0xaa, 0x36, 0xb9, 0x02, 0x7a, 0x16, 0x7a, 0x16, 0x7a, 0x16, 0x7a,
		0x16, 0x7a, 0x16, 0x7a, 0x16, 0x7a, 0x76, 0x8d, 0x9e, 0xed, 0xf6, 0x9e, 0x5c, 0xcf, 0xfe, 0xe2,
		0x78, 0x1e, 0xf3, 0xf9, 0x75, 0xed, 0xcc, 0x55, 0xd0, 0xb7, 0xd0, 0xb7, 0x73, 0xfb, 0xcd, 0x3d,
		0xc9, 0x92, 0x73, 0x72, 0xa5, 0x1c, 0x6d, 0x3f, 0xf7, 0xc2, 0x8e, 0x30, 0x69, 0x4f, 0x5f, 0x04,
		0xca, 0x06, 0x65, 0x67, 0x47, 0xd9, 0xd9, 0x66, 0x8f, 0xac, 0xc9, 0xa8, 0xe1, 0x4d, 0x1c, 0x49,
		0xcf, 0x9f, 0xe1, 0x4b, 0x1a, 0x09, 0x59, 0xd7, 0x63, 0x21, 0xf7, 0x34, 0x89, 0xd9, 0x8f, 0x63,
		0xa0, 0x04, 0x06, 0x4a, 0xf0, 0x1c, 0xb9, 0x49, 0x51, 0x8d, 0xa6, 0x1d, 0xe5, 0x6d, 0xda, 0xf1,
		0xe8, 0x74, 0x03, 0x74, 0xed, 0x40, 0x3a, 0xbd, 0xaa, 0xcf, 0xa3, 0xfc, 0x5d, 0x3b, 0x50, 0xd1,
		0x0f, 0x56, 0x43, 0xe5, 0x0a, 0xc7, 0x25, 0xa8, 0x5c, 0xd1, 0xeb, 0x78, 0x95, 0xf0, 0x46, 0x2b,
		0x79, 0xa5, 0xa9, 0xb7, 0x0c, 0x95, 0x2b, 0xca, 0xba, 0x08, 0x15, 0xfd, 0xd0, 0x48, 0xd0, 0x48,
		0xd0, 0x48, 0xd0, 0x48, 0xd0, 0x48, 0xf9, 0xd0, 0x48, 0xa8, 0xe8, 0x87, 0x16, 0x82, 0x16, 0x82,
		0x16, 0x82, 0x16, 0x82, 0x16, 0xd2, 0xa4, 0x85, 0x72, 0x59, 0xd1, 0x3f, 0x13, 0xbd, 0x23, 0x6f,
		0x38, 0x7f, 0x1b, 0xad, 0x8e, 0x9e, 0xf3, 0x08, 0x5f, 0x29, 0x2a, 0x5c, 0x84, 0xaf, 0x80, 0x1d,
		0x81, 0x1d, 0xb5, 0x60, 0x47, 0x84, 0xaf, 0xc0, 0x6a, 0x60, 0x35, 0x98, 0x69, 0x30, 0xd3, 0x60,
		0xa6, 0xc1, 0x4c, 0x43, 0xf8, 0x0a, 0x1a, 0x09, 0x1a, 0x09, 0x1a, 0x09, 0x1a, 0x09, 0x1a, 0xa9,
		0x40, 0x1a, 0x09, 0xe1, 0x2b, 0x68, 0x21, 0x68, 0x21, 0x68, 0x21, 0x68, 0x21, 0x68, 0x21, 0x4d,
		0x5a, 0xa8, 0x00, 0xe1, 0x2b, 0xe2, 0x9e, 0xd4, 0x33, 0xd1, 0xab, 0x02, 0xb7, 0xa5, 0xe6, 0xa9,
		0xd0, 0x93, 0xdc, 0x16, 0xee, 0x3a, 0xc3, 0xad, 0x15, 0x2f, 0x6e, 0x35, 0xfb, 0x4f, 0x43, 0x3d,
		0xc6, 0x3a, 0x4b, 0xc5, 0xf3, 0x9a, 0xfa, 0xc3, 0xbd, 0x91, 0xea, 0x3b, 0x19, 0xbd, 0x6c, 0x5a,
		0x01, 0xe2, 0x47, 0x16, 0xb4, 0x7d, 0xf7, 0x25, 0xde, 0x54, 0xab, 0xd9, 0xe9, 0xb8, 0xde, 0x53,
		0x65, 0xf8, 0x8a, 0x23, 0x8c, 0x52, 0xe9, 0x38, 0xa1, 0x53, 0x09, 0x7b, 0x95, 0xf0, 0x2b, 0xab,
		0x8c, 0x96, 0xaa, 0x3c, 0xf7, 0x3a, 0xac, 0x9b, 0x8b, 0x8a, 0xc6, 0x17, 0xe6, 0x3d, 0x76, 0x7b,
		0xff, 0x2d, 0x60, 0x39, 0xe3, 0xf8, 0xc9, 0x4d, 0xd5, 0x32, 0x26, 0x37, 0xe4, 0x8e, 0x06, 0x73,
		0x6c, 0xee, 0x32, 0x0a, 0xfa, 0xd0, 0xf3, 0x42, 0xc7, 0xf5, 0x98, 0x5f, 0x79, 0xec, 0xf9, 0x11,
		0x21, 0x0d, 0x17, 0x59, 0x49, 0x33, 0x9c, 0xb4, 0x23, 0x8c, 0x9e, 0xe5, 0x62, 0xcb, 0x7c, 0xaf,
		0x5d, 0x29, 0x60, 0x60, 0x79, 0x2d, 0xcd, 0x71, 0xea, 0x34, 0x51, 0x9a, 0x5d, 0x23, 0xf5, 0x5a,
		0xf3, 0x52, 0x6f, 0xb5, 0x98, 0xe7, 0x15, 0xef, 0xd6, 0xd2, 0xbe, 0xff, 0x1c, 0x82, 0x7c, 0x76,
		0x7f, 0x26, 0xcf, 0x3a, 0xfa, 0x29, 0xe6, 0xc0, 0xb4, 0xa7, 0xb4, 0xdc, 0xe0, 0x57, 0xe7, 0x2f,
		0x76, 0xdd, 0xeb, 0x2d, 0x9e, 0xd4, 0xfc, 0x93, 0x5b, 0xd3, 0xff, 0x34, 0xf3, 0x64, 0x1f, 0xd9,
		0x37, 0xb7, 0x1d, 0x6b, 0xd5, 0xc1, 0xd6, 0xe0, 0xff, 0x03, 0x00, 0x00, 0xff, 0xff, 0x01, 0x00,
		0x00, 0xff, 0xff, 0x73, 0x81, 0xbe, 0xd3, 0x57, 0xd2, 0x45, 0x01,
	}
)

// ΛEnumTypes is a map, keyed by a YANG schema path, of the enumerated types that
// correspond with the leaf. The type is represented as a reflect.Type. The naming
// of the map ensures that there are no clashes with valid YANG identifiers.
var ΛEnumTypes = map[string][]reflect.Type{
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/config/forwarding-action": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_FORWARDING_ACTION)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/config/log-action": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_LOG_ACTION)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/state/forwarding-action": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_FORWARDING_ACTION)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/actions/state/log-action": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_LOG_ACTION)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/config/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv4/state/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/config/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/ipv6/state/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/config/ethertype": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_ETHERTYPE)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/l2/state/ethertype": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_ETHERTYPE)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/destination-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/source-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/config/tcp-flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_TCP_FLAGS)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/destination-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/source-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort)(0)),
	},
	"/acl/acl-sets/acl-set/acl-entries/acl-entry/transport/state/tcp-flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_TCP_FLAGS)(0)),
	},
	"/acl/acl-sets/acl-set/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/acl-sets/acl-set/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/acl-sets/acl-set/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/egress-acl-sets/egress-acl-set/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/egress-acl-sets/egress-acl-set/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/egress-acl-sets/egress-acl-set/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/interfaces/interface/ingress-acl-sets/ingress-acl-set/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_TYPE)(0)),
	},
	"/acl/state/counter-capability": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_ACL_COUNTER_CAPABILITY)(0)),
	},
	"/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/state/local-diagnostic-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdDiagnosticCode)(0)),
	},
	"/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/state/remote-diagnostic-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdDiagnosticCode)(0)),
	},
	"/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/state/remote-session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdSessionState)(0)),
	},
	"/bfd/interfaces/interface/micro-bfd-sessions/micro-bfd-session/state/session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdSessionState)(0)),
	},
	"/bfd/interfaces/interface/peers/peer/state/local-diagnostic-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdDiagnosticCode)(0)),
	},
	"/bfd/interfaces/interface/peers/peer/state/remote-diagnostic-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdDiagnosticCode)(0)),
	},
	"/bfd/interfaces/interface/peers/peer/state/remote-session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdSessionState)(0)),
	},
	"/bfd/interfaces/interface/peers/peer/state/session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBfd_BfdSessionState)(0)),
	},
	"/bfd/interfaces/interface/peers/peer/state/subscribed-protocols": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/global/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/global/afi-safis/afi-safi/config/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/global/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/config/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/neighbors/neighbor/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/neighbors/neighbor/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/neighbors/neighbor/config/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/bgp/neighbors/neighbor/config/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/bgp/neighbors/neighbor/config/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/bgp/neighbors/neighbor/graceful-restart/state/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/received/last-notification-error-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/received/last-notification-error-subcode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-subcode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/bgp/neighbors/neighbor/state/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/bgp/neighbors/neighbor/state/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/bgp/neighbors/neighbor/state/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/bgp/neighbors/neighbor/state/session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState)(0)),
	},
	"/bgp/neighbors/neighbor/state/supported-capabilities": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_CAPABILITY)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/config/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/peer-groups/peer-group/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/peer-groups/peer-group/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/bgp/peer-groups/peer-group/config/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/bgp/peer-groups/peer-group/config/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/bgp/peer-groups/peer-group/config/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/bgp/peer-groups/peer-group/state/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/bgp/peer-groups/peer-group/state/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/bgp/peer-groups/peer-group/state/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/bgp/rib/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/as-path/as-segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgp_AsPathSegmentType)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/as4-path/as4-segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgp_AsPathSegmentType)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/state/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgp_BgpOriginAttrType)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE)(0)),
	},
	"/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE)(0)),
	},
	"/bgp/rib/communities/community/state/community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY)(0)),
	},
	"/components/component/state/oper-status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPlatformTypes_COMPONENT_OPER_STATUS)(0)),
	},
	"/components/component/state/temperature/alarm-severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY)(0)),
	},
	"/components/component/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPlatformTypes_OPENCONFIG_HARDWARE_COMPONENT)(0)),
		reflect.TypeOf((E_OpenconfigPlatformTypes_OPENCONFIG_SOFTWARE_COMPONENT)(0)),
	},
	"/interfaces-state/interface/admin-status": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_InterfacesState_Interface_AdminStatus)(0)),
	},
	"/interfaces-state/interface/oper-status": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_InterfacesState_Interface_OperStatus)(0)),
	},
	"/interfaces-state/interface/type": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_InterfaceType)(0)),
	},
	"/interfaces/interface/admin-status": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_Interfaces_Interface_AdminStatus)(0)),
	},
	"/interfaces/interface/link-up-down-trap-enable": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_Interfaces_Interface_LinkUpDownTrapEnable)(0)),
	},
	"/interfaces/interface/oper-status": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_Interfaces_Interface_OperStatus)(0)),
	},
	"/interfaces/interface/type": []reflect.Type{
		reflect.TypeOf((E_IETFInterfaces_InterfaceType)(0)),
	},
	"/local-routes/static-routes/static/next-hops/next-hop/config/next-hop": []reflect.Type{
		reflect.TypeOf((E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP)(0)),
	},
	"/local-routes/static-routes/static/next-hops/next-hop/state/next-hop": []reflect.Type{
		reflect.TypeOf((E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP)(0)),
	},
	"/messages/config/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_SyslogSeverity)(0)),
	},
	"/messages/debug-entries/debug-service/config/service": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/messages/debug-entries/debug-service/service": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/messages/debug-entries/debug-service/state/service": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/messages/state/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_SyslogSeverity)(0)),
	},
	"/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry/state/decapsulate-header": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAft_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/afts/ipv4-unicast/ipv4-entry/state/origin-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry/state/decapsulate-header": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAft_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/afts/ipv6-unicast/ipv6-entry/state/origin-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/afts/mpls/label-entry/label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label)(0)),
	},
	"/network-instances/network-instance/afts/mpls/label-entry/state/label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_Label)(0)),
	},
	"/network-instances/network-instance/afts/mpls/label-entry/state/popped-mpls-label-stack": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_Mpls_LabelEntry_State_PoppedMplsLabelStack)(0)),
	},
	"/network-instances/network-instance/afts/next-hops/next-hop/state/encapsulate-header": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAft_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/afts/next-hops/next-hop/state/origin-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/afts/next-hops/next-hop/state/pushed-mpls-label-stack": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack)(0)),
	},
	"/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/ip-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/afts/policy-forwarding/policy-forwarding-entry/state/mpls-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_PolicyForwarding_PolicyForwardingEntry_State_MplsLabel)(0)),
	},
	"/network-instances/network-instance/config/enabled-address-families": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE)(0)),
	},
	"/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE)(0)),
	},
	"/network-instances/network-instance/connection-points/connection-point/endpoints/endpoint/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_ENDPOINT_TYPE)(0)),
	},
	"/network-instances/network-instance/encapsulation/config/encapsulation-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_ENCAPSULATION)(0)),
	},
	"/network-instances/network-instance/encapsulation/config/label-allocation-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE)(0)),
	},
	"/network-instances/network-instance/encapsulation/state/encapsulation-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_ENCAPSULATION)(0)),
	},
	"/network-instances/network-instance/encapsulation/state/label-allocation-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_LABEL_ALLOCATION_MODE)(0)),
	},
	"/network-instances/network-instance/fdb/mac-table/entries/entry/state/entry-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Fdb_MacTable_Entries_Entry_State_EntryType)(0)),
	},
	"/network-instances/network-instance/inter-instance-policies/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/inter-instance-policies/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/inter-instance-policies/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/inter-instance-policies/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/interfaces/interface/config/associated-address-families": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/interfaces/interface/state/associated-address-families": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/mpls/global/config/null-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_NULL_LABEL_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/global/config/pw-encapsulation": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION)(0)),
	},
	"/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/lower-bound": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound)(0)),
	},
	"/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/config/upper-bound": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound)(0)),
	},
	"/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/lower-bound": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_LowerBound)(0)),
	},
	"/network-instances/network-instance/mpls/global/reserved-label-blocks/reserved-label-block/state/upper-bound": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Global_ReservedLabelBlocks_ReservedLabelBlock_Config_UpperBound)(0)),
	},
	"/network-instances/network-instance/mpls/global/state/null-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_NULL_LABEL_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/global/state/pw-encapsulation": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PSEUDOWIRE_ENCAPSULATION)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/config/sid-selection-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object/config/hop-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_MplsHopType)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/explicit-route-objects/explicit-route-object/state/hop-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_MplsHopType)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/named-explicit-paths/named-explicit-path/state/sid-selection-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_ConstrainedPath_NamedExplicitPaths_NamedExplicitPath_Config_SidSelectionMode)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/config/specification-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_TeBandwidthType)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/bandwidth/state/specification-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_TeBandwidthType)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/config/admin-status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/config/metric-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_METRIC_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/config/protection-style-requested": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/config/signaling-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_TUNNEL_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/config/cspf-tiebreaker": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_CspfTieBreaking)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/config/path-computation-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/state/cspf-tiebreaker": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_CspfTieBreaking)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-primary-path/p2p-primary-path/state/path-computation-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/config/cspf-tiebreaker": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_CspfTieBreaking)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/config/path-computation-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/state/cspf-tiebreaker": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_CspfTieBreaking)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/p2p-tunnel-attributes/p2p-secondary-paths/p2p-secondary-path/state/path-computation-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_COMPUTATION_METHOD)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/admin-status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_TUNNEL_ADMIN_STATUS)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/metric-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_METRIC_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/oper-status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_OPER_STATUS)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/protection-style-requested": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/role": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_ROLE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/signaling-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/constrained-path/tunnels/tunnel/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_TUNNEL_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/incoming-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/config/push-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/incoming-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/egress/state/push-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/incoming-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/config/push-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/incoming-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/ingress/state/push-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/incoming-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/config/push-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/incoming-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_IncomingLabel)(0)),
	},
	"/network-instances/network-instance/mpls/lsps/static-lsps/static-lsp/transit/state/push-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_Lsps_StaticLsps_StaticLsp_Egress_Config_PushLabel)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/interface-attributes/interfaces/interface/address-families/address-family/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/hello-adjacencies/hello-adjacency/state/adjacency-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAdjacencyType)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/neighbors/neighbor/state/session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_Ldp_Neighbors_Neighbor_State_SessionState)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/ldp/targeted/address-families/address-family/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsLdp_MplsLdpAfi)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/priority": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/bandwidth-reservations/bandwidth-reservation/state/priority": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_InterfaceAttributes_Interface_BandwidthReservations_BandwidthReservation_State_Priority)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection/config/link-protection-style-requested": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/interface-attributes/interface/protection/state/link-protection-style-requested": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/neighbors/neighbor/state/neighbor-status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Neighbors_Neighbor_State_NeighborStatus)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Label)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/explicit-route-objects/explicit-route-object/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_ExplicitRouteObjects_ExplicitRouteObject_State_Type)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/record-route-objects/record-route-object/state/reported-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_RecordRouteObjects_RecordRouteObject_State_ReportedLabel)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-in": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelIn)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/label-out": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_LabelOut)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/protection-requested": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PROTECTION_TYPE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_RsvpTe_Sessions_Session_State_Status)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/rsvp-te/sessions/session/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_LSP_ROLE)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/mpls-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/segment-routing/aggregate-sid-counters/aggregate-sid-counter/state/mpls-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/mpls-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel)(0)),
	},
	"/network-instances/network-instance/mpls/signaling-protocols/segment-routing/interfaces/interface/sid-counters/sid-counter/state/mpls-label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_SignalingProtocols_SegmentRouting_AggregateSidCounters_AggregateSidCounter_State_MplsLabel)(0)),
	},
	"/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/config/flooding-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_MplsSrlgFloodingType)(0)),
	},
	"/network-instances/network-instance/mpls/te-global-attributes/srlgs/srlg/state/flooding-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMpls_MplsSrlgFloodingType)(0)),
	},
	"/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/config/threshold-specification": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification)(0)),
	},
	"/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/config/threshold-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType)(0)),
	},
	"/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/state/threshold-specification": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdSpecification)(0)),
	},
	"/network-instances/network-instance/mpls/te-interface-attributes/interface/igp-flooding-bandwidth/state/threshold-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Mpls_TeInterfaceAttributes_Interface_IgpFloodingBandwidth_Config_ThresholdType)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/config/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv4/state/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/config/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/ipv6/state/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_IP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/config/ethertype": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_ETHERTYPE)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/l2/state/ethertype": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_ETHERTYPE)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/destination-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/source-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/config/tcp-flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_TCP_FLAGS)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/destination-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_DestinationPort)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/source-port": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAcl_Acl_AclSets_AclSet_AclEntries_AclEntry_Transport_Config_SourcePort)(0)),
	},
	"/network-instances/network-instance/policy-forwarding/policies/policy/rules/rule/transport/state/tcp-flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPacketMatchTypes_TCP_FLAGS)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/config/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/global/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/config/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/config/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/config/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/config/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/graceful-restart/state/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Neighbors_Neighbor_GracefulRestart_State_Mode)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/received/last-notification-error-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/received/last-notification-error-subcode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-code": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_CODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/messages/sent/last-notification-error-subcode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_ERROR_SUBCODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/session-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Neighbors_Neighbor_State_SessionState)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/neighbors/neighbor/state/supported-capabilities": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_CAPABILITY)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/config/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/config/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/state/default-export-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/apply-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/config/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/config/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/config/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state/peer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_PeerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state/remove-private-as": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_RemovePrivateAsOption)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/peer-groups/peer-group/state/send-community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_CommunityType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/loc-rib/routes/route/state/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv4-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-srte-policy/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/loc-rib/routes/route/state/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-in-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-post/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/ipv6-unicast/neighbors/neighbor/adj-rib-out-pre/routes/route/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_INVALID_ROUTE_REASON)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/afi-safis/afi-safi/state/afi-safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as-path/as-segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgp_AsPathSegmentType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/as4-path/as4-segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgp_AsPathSegmentType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/state/origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgp_BgpOriginAttrType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/sid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Sid)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/segment-lists/segment-list/segments/segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_SegmentLists_SegmentList_Segments_Segment_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/binding-sid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgp_Bgp_Rib_AttrSets_AttrSet_TunnelEncapsulation_Tunnels_Tunnel_Subtlvs_Subtlv_State_BindingSid)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/attr-sets/attr-set/tunnel-encapsulation/tunnels/tunnel/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRibBgpTypes_TUNNEL_ENCAPSULATION_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/bgp/rib/communities/community/state/community": []reflect.Type{
		reflect.TypeOf((E_OpenconfigBgpTypes_BGP_WELL_KNOWN_STD_COMMUNITY)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/config/identifier": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/identifier": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/config/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/config/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/multi-topology/state/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/afi-safi/af/state/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/config/level-capability": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/config/nh-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/igp-shortcuts/afi/state/nh-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMplsTypes_PATH_SETUP_PROTOCOL)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level1-to-level2/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/inter-level-propagation-policies/level2-to-level1/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger/config/reset-trigger": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger/reset-trigger": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/lsp-bit/overload-bit/reset-triggers/reset-trigger/state/reset-trigger": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_OVERLOAD_RESET_TRIGGER_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/state/level-capability": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/timers/lsp-generation/state/adaptive-timer": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_AdaptiveTimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/global/timers/spf/state/adaptive-timer": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_AdaptiveTimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/config/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/afi-safi/af/state/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/config/circuit-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_CircuitType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/config/hello-padding": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_HelloPaddingType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/adjacency-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisInterfaceAdjState)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/adjacency-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/neighbor-circuit-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_LevelType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/nlpid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_Adjacencies_Adjacency_State_Nlpid)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/adjacencies/adjacency/state/topology": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/config/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/config/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/config/sid-id": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/sid-id": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/allocated-dynamic-local": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_State_AllocatedDynamicLocal)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/adjacency-sids/adjacency-sid/state/sid-id": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_AdjacencySids_AdjacencySid_Config_SidId)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config/label-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/config/sid-id": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/label-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_LabelOptions)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/segment-routing/prefix-sids/prefix-sid/state/sid-id": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Interfaces_Interface_Levels_Level_AfiSafi_Af_SegmentRouting_PrefixSids_PrefixSid_Config_SidId)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/state/afi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_AFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/levels/level/afi-safi/af/state/safi-name": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisTypes_SAFI_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/state/circuit-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_CircuitType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/interfaces/interface/state/hello-padding": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_HelloPaddingType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/config/metric-style": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_MetricStyle)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/state/pdu-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_State_PduType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/authentication/state/crypto-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Authentication_State_CryptoType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/extended-is-reachability/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/default-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/delay-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/error-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-external-reachability/prefixes/prefix/expense-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/default-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/delay-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/error-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-internal-reachability/prefixes/prefix/expense-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv4-srlgs/ipv4-srlg/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4Srlgs_Ipv4Srlg_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-reachability/prefixes/prefix/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/ipv6-srlgs/ipv6-srlg/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv6Srlgs_Ipv6Srlg_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/default-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Ipv4ExternalReachability_Prefixes_Prefix_DefaultMetric_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/delay-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/error-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/is-reachability/neighbors/neighbor/expense-metric/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_IsisMetricFlags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv4-reachability/prefixes/prefix/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_Flags_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/flags/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv4-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/ipv6-source-router-id/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/prefix-sids/prefix-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIpv4Reachability_Prefixes_Prefix_Subtlvs_Subtlv_PrefixSids_PrefixSid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-ipv6-reachability/prefixes/prefix/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isis-neighbor-attribute/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/adjacency-sids/adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_AdjacencySids_AdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/available-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/lan-adjacency-sids/lan-adjacency-sid/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LanAdjacencySids_LanAdjacencySid_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-attributes/state/local-protection": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkAttributes_State_LocalProtection)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/link-protection-type/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_ExtendedIsReachability_Neighbors_Neighbor_Instances_Instance_Subtlvs_Subtlv_LinkProtectionType_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/unconstrained-lsp/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/mt-isn/neighbors/neighbor/instances/instance/subtlvs/subtlv/utilized-bandwidth/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/multi-topology/topologies/topology/state/attributes": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_MultiTopology_Topologies_Topology_State_Attributes)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/nlpid/state/nlpid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_Nlpid_State_Nlpid)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-algorithms/state/algorithm": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingAlgorithms_State_Algorithm)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/srgb-descriptors/srgb-descriptor/state/label": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_SrgbDescriptors_SrgbDescriptor_State_Label)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/segment-routing-capability/state/flags": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Isis_Levels_Level_LinkStateDatabase_Lsp_Tlvs_Tlv_RouterCapabilities_Capability_Subtlvs_Subtlv_SegmentRoutingCapability_State_Flags)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/router-capabilities/capability/subtlvs/subtlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/link-state-database/lsp/tlvs/tlv/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsisLsdbTypes_ISIS_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/isis/levels/level/state/metric-style": []reflect.Type{
		reflect.TypeOf((E_OpenconfigIsis_MetricStyle)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/config/network-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/neighbors/neighbor/state/adjacency-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/interfaces/interface/state/network-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NETWORK_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/as-external-lsa/state/metric-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/nssa-external-lsa/state/metric-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_AsExternalLsa_State_MetricType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/state/link-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_ROUTER_LINK_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/adjacency-sid/state/sid-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfv2_SrSidType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-link/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTENDED_LINK_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/state/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/state/route-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_RouteType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/extended-prefix-range/state/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_State_AddressFamily)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid/state/sid-scope": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidScope)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/prefix-sid/state/sid-value-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_ExtendedPrefix_Tlvs_Tlv_PrefixSid_State_SidValueType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/ero-path/segments/segment/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTPREFIX_BINDING_ERO_PATH_SEGMENT_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/sid-label-binding/state/sid-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfv2_SrSidType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/sid-label-binding/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SID_LABEL_BINDING_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/extended-prefix/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPFV2_EXTENDED_PREFIX_SUBTLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/state/reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_GraceLsa_Tlvs_Tlv_State_Reason)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/grace-lsa/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_GRACE_LSA_TLV_TYPES)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-algorithm/state/supported-algorithms": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_SR_ALGORITHM)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/sid-label/state/entry-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfv2_SrSidType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/segment-routing-sid-label-range/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_RI_SR_SID_LABEL_TLV_TYPES)(0)),
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_SegmentRoutingSidLabelRange_Tlvs_Tlv_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/router-information/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_RI_LSA_TLV_TYPES)(0)),
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_RouterInformation_Tlvs_Tlv_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/state/scope": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_State_Scope)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_OPAQUE_LSA_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/link-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_LinkType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/link/sub-tlvs/sub-tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_Link_SubTlvs_SubTlv_State_Type)(0)),
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_TE_LINK_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/node-attribute/sub-tlvs/sub-tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_TE_NODE_ATTRIBUTE_TLV_TYPE)(0)),
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Areas_Area_Lsdb_LsaTypes_LsaType_Lsas_Lsa_OpaqueLsa_TrafficEngineering_Tlvs_Tlv_NodeAttribute_SubTlvs_SubTlv_State_Type)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/opaque-lsa/traffic-engineering/tlvs/tlv/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_TE_LSA_TLV_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/lsas/lsa/router-lsa/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_ROUTER_LSA_TYPES)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_LSA_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/lsdb/lsa-types/lsa-type/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_LSA_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/areas/area/virtual-links/virtual-link/state/adjacency-state": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_OSPF_NEIGHBOR_STATE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/config/summary-route-cost-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/inter-area-propagation-policies/inter-area-propagation-policy/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/state/summary-route-cost-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Config_SummaryRouteCostMode)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/lsa-generation/state/timer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/config/include": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/config/trigger": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/state/include": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_MAX_METRIC_INCLUDE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/max-metric/state/trigger": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOspfTypes_MAX_METRIC_TRIGGER)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/ospfv2/global/timers/spf/state/timer-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Protocols_Protocol_Ospfv2_Global_Timers_LsaGeneration_State_TimerType)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/config/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPimTypes_PIM_MODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/neighbors/neighbor/state/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPimTypes_PIM_MODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/pim/interfaces/interface/state/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPimTypes_PIM_MODE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/state/identifier": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/config/next-hop": []reflect.Type{
		reflect.TypeOf((E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP)(0)),
	},
	"/network-instances/network-instance/protocols/protocol/static-routes/static/next-hops/next-hop/state/next-hop": []reflect.Type{
		reflect.TypeOf((E_OpenconfigLocalRouting_LOCAL_DEFINED_NEXT_HOP)(0)),
	},
	"/network-instances/network-instance/route-limits/route-limit/afi": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/route-limits/route-limit/config/afi": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/route-limits/route-limit/state/afi": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/segment-routing/srgbs/srgb/config/dataplane-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSegmentRouting_SrDataplaneType)(0)),
	},
	"/network-instances/network-instance/segment-routing/srgbs/srgb/state/dataplane-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSegmentRouting_SrDataplaneType)(0)),
	},
	"/network-instances/network-instance/segment-routing/srlbs/srlb/config/dataplane-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSegmentRouting_SrDataplaneType)(0)),
	},
	"/network-instances/network-instance/segment-routing/srlbs/srlb/state/dataplane-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSegmentRouting_SrDataplaneType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/protocol-origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSrtePolicy_SrteProtocolType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/encapsulate-header": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAft_EncapsulationHeaderType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/origin-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/next-hops/next-hop/state/pushed-mpls-label-stack": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Afts_NextHops_NextHop_State_PushedMplsLabelStack)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/sids/sid/state/value": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_CandidatePaths_CandidatePath_SegmentLists_SegmentList_Sids_Sid_State_Value)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/segment-lists/segment-list/state/invalid-reason": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSrtePolicy_SrteInvalidSlReason)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/state/enlp": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSrtePolicy_EnlpType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/candidate-paths/candidate-path/state/protocol-origin": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSrtePolicy_SrteProtocolType)(0)),
	},
	"/network-instances/network-instance/segment-routing/te-policies/te-policy/state/bsid": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_SegmentRouting_TePolicies_TePolicy_State_Bsid)(0)),
	},
	"/network-instances/network-instance/state/enabled-address-families": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstanceTypes_NETWORK_INSTANCE_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/config/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/config/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/config/dst-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/config/src-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/dst-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/src-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/default-import-policy": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_DefaultPolicyType)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/dst-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/table-connections/table-connection/state/src-protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/tables/table/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/tables/table/config/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/tables/table/config/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/tables/table/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/tables/table/state/address-family": []reflect.Type{
		reflect.TypeOf((E_OpenconfigTypes_ADDRESS_FAMILY)(0)),
	},
	"/network-instances/network-instance/tables/table/state/protocol": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/network-instances/network-instance/vlans/vlan/config/status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status)(0)),
	},
	"/network-instances/network-instance/vlans/vlan/state/status": []reflect.Type{
		reflect.TypeOf((E_OpenconfigNetworkInstance_NetworkInstances_NetworkInstance_Vlans_Vlan_Config_Status)(0)),
	},
	"/routing-policy/defined-sets/prefix-sets/prefix-set/config/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode)(0)),
	},
	"/routing-policy/defined-sets/prefix-sets/prefix-set/state/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_RoutingPolicy_DefinedSets_PrefixSets_PrefixSet_Config_Mode)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/actions/config/policy-result": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_PolicyResultType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/config/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/actions/set-tag/state/mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_RoutingPolicy_PolicyDefinitions_PolicyDefinition_Statements_Statement_Actions_SetTag_Config_Mode)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/actions/state/policy-result": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_PolicyResultType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/config/install-protocol-eq": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set/config/match-set-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-neighbor-set/state/match-set-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set/config/match-set-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-prefix-set/state/match-set-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set/config/match-set-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/match-tag-set/state/match-set-options": []reflect.Type{
		reflect.TypeOf((E_OpenconfigRoutingPolicy_MatchSetOptionsRestrictedType)(0)),
	},
	"/routing-policy/policy-definitions/policy-definition/statements/statement/conditions/state/install-protocol-eq": []reflect.Type{
		reflect.TypeOf((E_OpenconfigPolicyTypes_INSTALL_PROTOCOL_TYPE)(0)),
	},
	"/system/aaa/accounting/config/accounting-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/accounting/events/event/config/event-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE)(0)),
	},
	"/system/aaa/accounting/events/event/config/record": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record)(0)),
	},
	"/system/aaa/accounting/events/event/event-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE)(0)),
	},
	"/system/aaa/accounting/events/event/state/event-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_ACCOUNTING_EVENT_TYPE)(0)),
	},
	"/system/aaa/accounting/events/event/state/record": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_Aaa_Accounting_Events_Event_Config_Record)(0)),
	},
	"/system/aaa/accounting/state/accounting-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/authentication/config/authentication-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/authentication/state/authentication-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/authentication/users/user/config/role": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES)(0)),
	},
	"/system/aaa/authentication/users/user/state/role": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_SYSTEM_DEFINED_ROLES)(0)),
	},
	"/system/aaa/authorization/config/authorization-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/authorization/events/event/config/event-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE)(0)),
	},
	"/system/aaa/authorization/events/event/event-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE)(0)),
	},
	"/system/aaa/authorization/events/event/state/event-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_AUTHORIZATION_EVENT_TYPE)(0)),
	},
	"/system/aaa/authorization/state/authorization-method": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_METHOD_TYPE)(0)),
	},
	"/system/aaa/server-groups/server-group/config/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_SERVER_TYPE)(0)),
	},
	"/system/aaa/server-groups/server-group/state/type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAaaTypes_AAA_SERVER_TYPE)(0)),
	},
	"/system/alarms/alarm/state/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_SEVERITY)(0)),
	},
	"/system/alarms/alarm/state/type-id": []reflect.Type{
		reflect.TypeOf((E_OpenconfigAlarmTypes_OPENCONFIG_ALARM_TYPE_ID)(0)),
	},
	"/system/cpus/cpu/index": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_Cpus_Cpu_State_Index)(0)),
	},
	"/system/cpus/cpu/state/index": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_Cpus_Cpu_State_Index)(0)),
	},
	"/system/grpc-server/config/listen-addresses": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses)(0)),
	},
	"/system/grpc-server/state/listen-addresses": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_GrpcServer_Config_ListenAddresses)(0)),
	},
	"/system/logging/console/selectors/selector/config/facility": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/console/selectors/selector/config/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/logging/console/selectors/selector/facility": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/console/selectors/selector/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/logging/console/selectors/selector/state/facility": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/console/selectors/selector/state/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/config/facility": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/config/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/facility": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/state/facility": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SYSLOG_FACILITY)(0)),
	},
	"/system/logging/remote-servers/remote-server/selectors/selector/state/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystemLogging_SyslogSeverity)(0)),
	},
	"/system/messages/config/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_SyslogSeverity)(0)),
	},
	"/system/messages/debug-entries/debug-service/config/service": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/system/messages/debug-entries/debug-service/service": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/system/messages/debug-entries/debug-service/state/service": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_DEBUG_SERVICE)(0)),
	},
	"/system/messages/state/severity": []reflect.Type{
		reflect.TypeOf((E_OpenconfigMessages_SyslogSeverity)(0)),
	},
	"/system/ntp/ntp-keys/ntp-key/config/key-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_NTP_AUTH_TYPE)(0)),
	},
	"/system/ntp/ntp-keys/ntp-key/state/key-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_NTP_AUTH_TYPE)(0)),
	},
	"/system/ntp/servers/server/config/association-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType)(0)),
	},
	"/system/ntp/servers/server/state/association-type": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_Ntp_Servers_Server_Config_AssociationType)(0)),
	},
	"/system/openflow/agent/config/failure-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOpenflow_FailureMode)(0)),
	},
	"/system/openflow/agent/state/failure-mode": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOpenflow_FailureMode)(0)),
	},
	"/system/openflow/controllers/controller/connections/connection/config/transport": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOpenflow_Transport)(0)),
	},
	"/system/openflow/controllers/controller/connections/connection/state/transport": []reflect.Type{
		reflect.TypeOf((E_OpenconfigOpenflow_Transport)(0)),
	},
	"/system/ssh-server/config/protocol-version": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion)(0)),
	},
	"/system/ssh-server/state/protocol-version": []reflect.Type{
		reflect.TypeOf((E_OpenconfigSystem_System_SshServer_Config_ProtocolVersion)(0)),
	},
}
